{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Notebook for data preparation"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-latest.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "## BUILT ON THE DEUS VULT VERSION; DISCARD IF IN DOUBT ##\n",
    "\n",
    "%matplotlib inline\n",
    "from pylab import rcParams\n",
    "\n",
    "import warnings\n",
    "\n",
    "import os, os.path\n",
    "import pandas as pd, numpy as np, scipy as sp\n",
    "import matplotlib.pyplot as plt\n",
    "from datetime import datetime, timedelta\n",
    "\n",
    "import cufflinks as cf, matplotlib as mp\n",
    "cf.go_offline()\n",
    "import matplotlib.pyplot as plt\n",
    "from matplotlib.dates import DateFormatter \n",
    "import matplotlib.dates as mdates\n",
    "import matplotlib.cm as cm\n",
    "from matplotlib import dates\n",
    "from matplotlib.ticker import AutoMinorLocator, LinearLocator, AutoLocator\n",
    "\n",
    "import plotly.graph_objects as go\n",
    "from plotly.subplots import make_subplots\n",
    "\n",
    "from scipy.signal import argrelextrema, find_peaks\n",
    "from functools import wraps\n",
    "\n",
    "import ipywidgets as widgets\n",
    "from ipywidgets import interact, interact_manual, fixed\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "plt.style.use('fivethirtyeight')\n",
    "mp.rcParams['font.size'] = 22\n",
    "mp.rcParams['axes.labelsize'] = 32\n",
    "mp.rcParams['figure.figsize'] = (15, 10)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "R_M = 2440 # km\n",
    "M_0 = -1.96e02 * R_M**3 # nT. Alexeev, Belenkaya et al 2010 doi:10.1016/j.icarus.2010.01.024\n",
    "z_displacement = 484"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {},
   "outputs": [],
   "source": [
    "resolution = 60\n",
    "resolutions = [60, 10, 5, 1]\n",
    "\n",
    "def load_data(resolution=60, year=None, mindoy=None, maxdoy=None):\n",
    "    if resolution not in resolutions:\n",
    "        print(\"Resolution not available, using 60sec averages\")\n",
    "        resolution = 60\n",
    "    \n",
    "    data_files = []\n",
    "    path = os.path.join(r'/home/dp/archive/messenger/full/',\"%02d\" % resolution)\n",
    "   \n",
    "    for file in sorted(os.listdir(path)):\n",
    "        if year is None or file.startswith(\"MAGMSOSCIAVG\" + str(year % 2000)) and file.endswith(\".TAB\"):\n",
    "            doy = int(file.split(\"_\")[0].replace(\"MAGMSOSCIAVG\" + str(year % 2000), \"\"), 10)\n",
    "            if (mindoy is None or doy >= mindoy) and (maxdoy is None or doy <= maxdoy):\n",
    "                data_files.append(pd.read_table(os.path.join(path, file), delim_whitespace=True, header=None))\n",
    "            if doy > maxdoy:\n",
    "                break\n",
    "\n",
    "    data = pd.concat(data_files, ignore_index=True)\n",
    "    data.columns = ['YEAR', 'DAY_OF_YEAR', 'HOUR', 'MINUTE', 'SECOND',\n",
    "        'TIME_TAG', 'NAVG', 'X_MSO', 'Y_MSO', 'Z_MSO', 'BX_MSO',\n",
    "        'BY_MSO', 'BZ_MSO', 'DBX_MSO', 'DBY_MSO', 'DBZ_MSO']\n",
    "    data['DATE'] = data.apply(lambda x: \n",
    "        datetime.strptime(\"%d-%03d_%02d:%02d:%02d\" % (x.YEAR, x.DAY_OF_YEAR, x.HOUR, x.MINUTE, x.SECOND),\n",
    "            \"%Y-%j_%H:%M:%S\"), axis=1)\n",
    "    data = data.drop(['YEAR', 'DAY_OF_YEAR', 'HOUR', 'MINUTE', 'SECOND', 'NAVG', 'TIME_TAG'], axis=1)\n",
    "    data = data.set_index('DATE')\n",
    "    grouped = data.groupby(level=0)\n",
    "    data = grouped.last()\n",
    "    return data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "1fa1336f28d3438e9da4e074a48645f4",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(Dropdown(description='resolution', options=(60, 10, 5, 1), value=60), IntSlider(value=20…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "@interact(resolution=resolutions, year=(2011, 2015, 1), start_doy=(1, 365, 1), end_doy=(1, 365, 1))\n",
    "def w_load_data(resolution=resolution, year=2011, start_doy=91, end_doy=120):\n",
    "    data = load_data(resolution, year, start_doy, end_doy)\n",
    "    return data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 78,
   "metadata": {},
   "outputs": [],
   "source": [
    "philpott_labels = pd.read_csv(\"jgra55678-sup-0002-table_si-s01-ts.csv\", parse_dates=True, index_col='Timestamp')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 83,
   "metadata": {},
   "outputs": [],
   "source": [
    "# dfs = [load_data(10, yyyy, 1, 365) for yyyy in range(2011, 2016)]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 85,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>Boundary number</th>\n",
       "      <th>Orbit number</th>\n",
       "      <th>X_MSO (km)</th>\n",
       "      <th>Y_MSO (km)</th>\n",
       "      <th>Z_MSO (km)</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>Timestamp</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>2011-03-23 23:47:02.700</th>\n",
       "      <td>1</td>\n",
       "      <td>12</td>\n",
       "      <td>6275.334</td>\n",
       "      <td>8142.117</td>\n",
       "      <td>-4504.138</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-03-23 23:59:44.400</th>\n",
       "      <td>2</td>\n",
       "      <td>12</td>\n",
       "      <td>5928.638</td>\n",
       "      <td>7831.493</td>\n",
       "      <td>-3564.992</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-03-24 01:10:00.100</th>\n",
       "      <td>3</td>\n",
       "      <td>12</td>\n",
       "      <td>2258.153</td>\n",
       "      <td>3712.435</td>\n",
       "      <td>2075.611</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-03-24 01:14:03.200</th>\n",
       "      <td>4</td>\n",
       "      <td>12</td>\n",
       "      <td>1888.531</td>\n",
       "      <td>3238.635</td>\n",
       "      <td>2347.968</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-03-24 02:14:46.100</th>\n",
       "      <td>5</td>\n",
       "      <td>12</td>\n",
       "      <td>-2025.455</td>\n",
       "      <td>-3617.479</td>\n",
       "      <td>-3305.720</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>...</th>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-04-30 10:50:18.000</th>\n",
       "      <td>4</td>\n",
       "      <td>4104</td>\n",
       "      <td>2937.147</td>\n",
       "      <td>1285.647</td>\n",
       "      <td>-534.036</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-04-30 12:20:00.000</th>\n",
       "      <td>5</td>\n",
       "      <td>4104</td>\n",
       "      <td>-7232.388</td>\n",
       "      <td>-3543.218</td>\n",
       "      <td>-1958.539</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-04-30 12:32:59.000</th>\n",
       "      <td>6</td>\n",
       "      <td>4104</td>\n",
       "      <td>-7672.303</td>\n",
       "      <td>-3871.532</td>\n",
       "      <td>-3002.659</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-04-30 14:06:17.000</th>\n",
       "      <td>7</td>\n",
       "      <td>4104</td>\n",
       "      <td>-7880.844</td>\n",
       "      <td>-4669.875</td>\n",
       "      <td>-8858.618</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-04-30 14:43:28.000</th>\n",
       "      <td>8</td>\n",
       "      <td>4104</td>\n",
       "      <td>-7072.820</td>\n",
       "      <td>-4483.617</td>\n",
       "      <td>-10367.245</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>32532 rows × 5 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "                         Boundary number  Orbit number  X_MSO (km)  \\\n",
       "Timestamp                                                            \n",
       "2011-03-23 23:47:02.700                1            12    6275.334   \n",
       "2011-03-23 23:59:44.400                2            12    5928.638   \n",
       "2011-03-24 01:10:00.100                3            12    2258.153   \n",
       "2011-03-24 01:14:03.200                4            12    1888.531   \n",
       "2011-03-24 02:14:46.100                5            12   -2025.455   \n",
       "...                                  ...           ...         ...   \n",
       "2015-04-30 10:50:18.000                4          4104    2937.147   \n",
       "2015-04-30 12:20:00.000                5          4104   -7232.388   \n",
       "2015-04-30 12:32:59.000                6          4104   -7672.303   \n",
       "2015-04-30 14:06:17.000                7          4104   -7880.844   \n",
       "2015-04-30 14:43:28.000                8          4104   -7072.820   \n",
       "\n",
       "                         Y_MSO (km)  Z_MSO (km)  \n",
       "Timestamp                                        \n",
       "2011-03-23 23:47:02.700    8142.117   -4504.138  \n",
       "2011-03-23 23:59:44.400    7831.493   -3564.992  \n",
       "2011-03-24 01:10:00.100    3712.435    2075.611  \n",
       "2011-03-24 01:14:03.200    3238.635    2347.968  \n",
       "2011-03-24 02:14:46.100   -3617.479   -3305.720  \n",
       "...                             ...         ...  \n",
       "2015-04-30 10:50:18.000    1285.647    -534.036  \n",
       "2015-04-30 12:20:00.000   -3543.218   -1958.539  \n",
       "2015-04-30 12:32:59.000   -3871.532   -3002.659  \n",
       "2015-04-30 14:06:17.000   -4669.875   -8858.618  \n",
       "2015-04-30 14:43:28.000   -4483.617  -10367.245  \n",
       "\n",
       "[32532 rows x 5 columns]"
      ]
     },
     "execution_count": 85,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "philpott_labels"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 188,
   "metadata": {},
   "outputs": [],
   "source": [
    "smallzmp = philpott_labels[(philpott_labels[\"X_MSO (km)\"] > 0) & (np.abs(philpott_labels[\"Z_MSO (km)\"]) < 814) & (np.abs(philpott_labels[\"Y_MSO (km)\"]) < 814) & (philpott_labels[\"Boundary number\"].isin([3, 6]))]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 189,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>Boundary number</th>\n",
       "      <th>Orbit number</th>\n",
       "      <th>X_MSO (km)</th>\n",
       "      <th>Y_MSO (km)</th>\n",
       "      <th>Z_MSO (km)</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>Timestamp</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>2011-08-22 09:25:19</th>\n",
       "      <td>6</td>\n",
       "      <td>315</td>\n",
       "      <td>3544.797</td>\n",
       "      <td>795.090</td>\n",
       "      <td>216.710</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-08-22 21:26:21</th>\n",
       "      <td>6</td>\n",
       "      <td>316</td>\n",
       "      <td>3654.521</td>\n",
       "      <td>693.637</td>\n",
       "      <td>64.889</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-08-23 09:24:31</th>\n",
       "      <td>6</td>\n",
       "      <td>317</td>\n",
       "      <td>3511.630</td>\n",
       "      <td>491.595</td>\n",
       "      <td>384.190</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-08-23 21:27:13</th>\n",
       "      <td>6</td>\n",
       "      <td>318</td>\n",
       "      <td>3759.002</td>\n",
       "      <td>427.960</td>\n",
       "      <td>-39.444</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2011-08-24 09:26:06</th>\n",
       "      <td>6</td>\n",
       "      <td>319</td>\n",
       "      <td>3673.590</td>\n",
       "      <td>249.131</td>\n",
       "      <td>163.598</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>...</th>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-02-05 01:39:40</th>\n",
       "      <td>3</td>\n",
       "      <td>3860</td>\n",
       "      <td>3422.122</td>\n",
       "      <td>389.147</td>\n",
       "      <td>-786.500</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-02-05 09:57:27</th>\n",
       "      <td>3</td>\n",
       "      <td>3861</td>\n",
       "      <td>3362.473</td>\n",
       "      <td>310.119</td>\n",
       "      <td>-572.979</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-02-06 02:30:27</th>\n",
       "      <td>3</td>\n",
       "      <td>3863</td>\n",
       "      <td>3381.061</td>\n",
       "      <td>121.609</td>\n",
       "      <td>-605.080</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-02-06 10:46:33</th>\n",
       "      <td>3</td>\n",
       "      <td>3864</td>\n",
       "      <td>3408.521</td>\n",
       "      <td>20.918</td>\n",
       "      <td>-692.386</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2015-02-06 19:02:53</th>\n",
       "      <td>3</td>\n",
       "      <td>3865</td>\n",
       "      <td>3419.314</td>\n",
       "      <td>-75.403</td>\n",
       "      <td>-737.280</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>140 rows × 5 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "                     Boundary number  Orbit number  X_MSO (km)  Y_MSO (km)  \\\n",
       "Timestamp                                                                    \n",
       "2011-08-22 09:25:19                6           315    3544.797     795.090   \n",
       "2011-08-22 21:26:21                6           316    3654.521     693.637   \n",
       "2011-08-23 09:24:31                6           317    3511.630     491.595   \n",
       "2011-08-23 21:27:13                6           318    3759.002     427.960   \n",
       "2011-08-24 09:26:06                6           319    3673.590     249.131   \n",
       "...                              ...           ...         ...         ...   \n",
       "2015-02-05 01:39:40                3          3860    3422.122     389.147   \n",
       "2015-02-05 09:57:27                3          3861    3362.473     310.119   \n",
       "2015-02-06 02:30:27                3          3863    3381.061     121.609   \n",
       "2015-02-06 10:46:33                3          3864    3408.521      20.918   \n",
       "2015-02-06 19:02:53                3          3865    3419.314     -75.403   \n",
       "\n",
       "                     Z_MSO (km)  \n",
       "Timestamp                        \n",
       "2011-08-22 09:25:19     216.710  \n",
       "2011-08-22 21:26:21      64.889  \n",
       "2011-08-23 09:24:31     384.190  \n",
       "2011-08-23 21:27:13     -39.444  \n",
       "2011-08-24 09:26:06     163.598  \n",
       "...                         ...  \n",
       "2015-02-05 01:39:40    -786.500  \n",
       "2015-02-05 09:57:27    -572.979  \n",
       "2015-02-06 02:30:27    -605.080  \n",
       "2015-02-06 10:46:33    -692.386  \n",
       "2015-02-06 19:02:53    -737.280  \n",
       "\n",
       "[140 rows x 5 columns]"
      ]
     },
     "execution_count": 189,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "smallzmp"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 190,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "2011-08-22 09:25:19 315\n",
      "2011-08-23 09:24:31 317\n",
      "2011-08-24 09:26:06 319\n",
      "2011-08-24 21:24:07 320\n",
      "2011-08-25 09:26:14 321\n",
      "2011-08-25 21:25:51 322\n",
      "2011-08-26 09:24:13 323\n",
      "2011-08-26 21:25:56 324\n",
      "2011-08-27 09:25:58 325\n",
      "2011-11-18 10:27:48 493\n",
      "2011-11-18 22:31:00 494\n",
      "2011-11-20 10:29:12 497\n",
      "2011-11-20 22:31:25 498\n",
      "2011-11-21 10:30:50 499\n",
      "2012-02-14 03:51:22 671\n",
      "2012-02-14 15:37:47 672\n",
      "2012-02-15 03:23:34 673\n",
      "2012-02-15 15:11:15 674\n",
      "2012-02-16 14:46:07 676\n",
      "2012-02-17 02:33:20 677\n",
      "2012-02-17 14:20:12 678\n",
      "2012-03-18 18:25:35 740\n",
      "2012-05-12 07:30:08 875\n",
      "2012-05-12 15:33:44 876\n",
      "2012-05-12 23:31:15 877\n",
      "2012-05-13 07:33:21 878\n",
      "2012-05-13 15:30:56 879\n",
      "2012-05-13 23:33:09 880\n",
      "2012-05-14 23:30:58 883\n",
      "2012-05-15 07:28:37 884\n",
      "2012-05-15 15:31:56 885\n",
      "2012-05-15 23:30:01 886\n",
      "2012-08-07 07:46:56 1136\n",
      "2012-08-08 23:50:44 1141\n",
      "2012-08-09 07:48:48 1142\n",
      "2012-08-10 23:49:20 1147\n",
      "2012-09-12 15:09:06 1245\n",
      "2012-11-03 16:09:44 1401\n",
      "2012-11-07 16:07:39 1413\n",
      "2012-11-08 00:12:22 1414\n",
      "2013-03-05 07:51:18 1766\n",
      "2013-03-08 23:50:27 1777\n",
      "2013-06-02 16:18:24 2034\n",
      "2013-08-27 08:43:14 2291\n",
      "2013-08-28 00:45:21 2293\n",
      "2013-08-28 08:44:35 2294\n",
      "2013-08-28 16:45:08 2295\n",
      "2013-08-29 00:45:31 2296\n",
      "2013-08-29 16:45:10 2298\n",
      "2013-08-31 00:46:12 2302\n",
      "2013-08-31 16:46:11 2304\n",
      "2013-09-01 00:43:56 2305\n",
      "2013-09-01 08:45:47 2306\n",
      "2013-11-22 09:13:24 2552\n",
      "2013-11-22 17:11:49 2553\n",
      "2013-11-23 01:10:21 2554\n",
      "2013-11-23 09:11:17 2555\n",
      "2013-11-23 17:09:47 2556\n",
      "2013-11-24 01:11:47 2557\n",
      "2013-11-24 09:11:07 2558\n",
      "2013-11-24 17:09:23 2559\n",
      "2013-11-25 01:10:34 2560\n",
      "2013-11-25 17:08:28 2562\n",
      "2013-11-26 01:08:07 2563\n",
      "2013-11-26 09:11:18 2564\n",
      "2013-11-27 01:08:50 2566\n",
      "2013-11-27 09:09:23 2567\n",
      "2014-02-18 01:45:43 2815\n",
      "2014-02-19 01:47:19 2818\n",
      "2014-02-19 09:46:19 2819\n",
      "2014-02-19 17:48:29 2820\n",
      "2014-02-20 01:48:11 2821\n",
      "2014-02-21 01:44:41 2824\n",
      "2014-02-21 17:46:50 2826\n",
      "2014-02-22 01:49:40 2827\n",
      "2014-02-23 17:47:12 2832\n",
      "2014-05-17 02:27:01 3079\n",
      "2014-05-18 18:24:22 3084\n",
      "[(Timestamp('2011-08-22 09:25:19'), 315), (Timestamp('2011-08-23 09:24:31'), 317), (Timestamp('2011-08-24 09:26:06'), 319), (Timestamp('2011-08-24 21:24:07'), 320), (Timestamp('2011-08-25 09:26:14'), 321), (Timestamp('2011-08-25 21:25:51'), 322), (Timestamp('2011-08-26 09:24:13'), 323), (Timestamp('2011-08-26 21:25:56'), 324), (Timestamp('2011-08-27 09:25:58'), 325), (Timestamp('2011-11-18 10:27:48'), 493), (Timestamp('2011-11-18 22:31:00'), 494), (Timestamp('2011-11-20 10:29:12'), 497), (Timestamp('2011-11-20 22:31:25'), 498), (Timestamp('2011-11-21 10:30:50'), 499), (Timestamp('2012-02-14 03:51:22'), 671), (Timestamp('2012-02-14 15:37:47'), 672), (Timestamp('2012-02-15 03:23:34'), 673), (Timestamp('2012-02-15 15:11:15'), 674), (Timestamp('2012-02-16 14:46:07'), 676), (Timestamp('2012-02-17 02:33:20'), 677), (Timestamp('2012-02-17 14:20:12'), 678), (Timestamp('2012-03-18 18:25:35'), 740), (Timestamp('2012-05-12 07:30:08'), 875), (Timestamp('2012-05-12 15:33:44'), 876), (Timestamp('2012-05-12 23:31:15'), 877), (Timestamp('2012-05-13 07:33:21'), 878), (Timestamp('2012-05-13 15:30:56'), 879), (Timestamp('2012-05-13 23:33:09'), 880), (Timestamp('2012-05-14 23:30:58'), 883), (Timestamp('2012-05-15 07:28:37'), 884), (Timestamp('2012-05-15 15:31:56'), 885), (Timestamp('2012-05-15 23:30:01'), 886), (Timestamp('2012-08-07 07:46:56'), 1136), (Timestamp('2012-08-08 23:50:44'), 1141), (Timestamp('2012-08-09 07:48:48'), 1142), (Timestamp('2012-08-10 23:49:20'), 1147), (Timestamp('2012-09-12 15:09:06'), 1245), (Timestamp('2012-11-03 16:09:44'), 1401), (Timestamp('2012-11-07 16:07:39'), 1413), (Timestamp('2012-11-08 00:12:22'), 1414), (Timestamp('2013-03-05 07:51:18'), 1766), (Timestamp('2013-03-08 23:50:27'), 1777), (Timestamp('2013-06-02 16:18:24'), 2034), (Timestamp('2013-08-27 08:43:14'), 2291), (Timestamp('2013-08-28 00:45:21'), 2293), (Timestamp('2013-08-28 08:44:35'), 2294), (Timestamp('2013-08-28 16:45:08'), 2295), (Timestamp('2013-08-29 00:45:31'), 2296), (Timestamp('2013-08-29 16:45:10'), 2298), (Timestamp('2013-08-31 00:46:12'), 2302), (Timestamp('2013-08-31 16:46:11'), 2304), (Timestamp('2013-09-01 00:43:56'), 2305), (Timestamp('2013-09-01 08:45:47'), 2306), (Timestamp('2013-11-22 09:13:24'), 2552), (Timestamp('2013-11-22 17:11:49'), 2553), (Timestamp('2013-11-23 01:10:21'), 2554), (Timestamp('2013-11-23 09:11:17'), 2555), (Timestamp('2013-11-23 17:09:47'), 2556), (Timestamp('2013-11-24 01:11:47'), 2557), (Timestamp('2013-11-24 09:11:07'), 2558), (Timestamp('2013-11-24 17:09:23'), 2559), (Timestamp('2013-11-25 01:10:34'), 2560), (Timestamp('2013-11-25 17:08:28'), 2562), (Timestamp('2013-11-26 01:08:07'), 2563), (Timestamp('2013-11-26 09:11:18'), 2564), (Timestamp('2013-11-27 01:08:50'), 2566), (Timestamp('2013-11-27 09:09:23'), 2567), (Timestamp('2014-02-18 01:45:43'), 2815), (Timestamp('2014-02-19 01:47:19'), 2818), (Timestamp('2014-02-19 09:46:19'), 2819), (Timestamp('2014-02-19 17:48:29'), 2820), (Timestamp('2014-02-20 01:48:11'), 2821), (Timestamp('2014-02-21 01:44:41'), 2824), (Timestamp('2014-02-21 17:46:50'), 2826), (Timestamp('2014-02-22 01:49:40'), 2827), (Timestamp('2014-02-23 17:47:12'), 2832), (Timestamp('2014-05-17 02:27:01'), 3079), (Timestamp('2014-05-18 18:24:22'), 3084)]\n"
     ]
    }
   ],
   "source": [
    "vzs = []\n",
    "\n",
    "def getspeed(orbit, dt):\n",
    "    try:\n",
    "        dfx = pd.read_csv(f\"~/archive/messenger/orbits/messenger-{int(orbit):04d}.csv\", parse_dates=True, index_col='DATE')\n",
    "        vx, vy, vz = dfx[\"X_MSO\"].diff()[dt], dfx[\"Y_MSO\"].diff()[dt], dfx[\"Z_MSO\"].diff()[dt]\n",
    "    except:\n",
    "        return None\n",
    "    vxy = np.sqrt(vx**2 + vy**2)\n",
    "    if np.abs(vx)*2 >= np.abs(vz):\n",
    "        return True\n",
    "    else:\n",
    "        return False\n",
    "    \n",
    "for dt, crossing in smallzmp.iterrows():\n",
    "    orbit_num = int(crossing[\"Orbit number\"])\n",
    "    for offset in [11, 12, 10]:\n",
    "        res = getspeed(orbit_num - offset, dt)\n",
    "        if res is not None:\n",
    "            break\n",
    "    if res == True:\n",
    "        print(dt, orbit_num)\n",
    "        vzs.append((dt, orbit_num))\n",
    "        \n",
    "print(vzs)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 236,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "11 1136 didnt work\n",
      "11 1141 didnt work\n",
      "11 1142 didnt work\n",
      "11 1147 didnt work\n",
      "11 1245 didnt work\n",
      "11 1401 didnt work\n",
      "11 1413 didnt work\n",
      "11 1414 didnt work\n",
      "11 1766 didnt work\n",
      "11 1777 didnt work\n",
      "11 2034 didnt work\n",
      "11 2291 didnt work\n",
      "11 2293 didnt work\n",
      "11 2294 didnt work\n",
      "11 2295 didnt work\n",
      "11 2296 didnt work\n",
      "11 2298 didnt work\n",
      "11 2302 didnt work\n",
      "11 2304 didnt work\n",
      "11 2305 didnt work\n",
      "11 2306 didnt work\n",
      "11 2552 didnt work\n",
      "11 2553 didnt work\n",
      "11 2554 didnt work\n",
      "11 2555 didnt work\n",
      "11 2556 didnt work\n",
      "11 2557 didnt work\n",
      "11 2558 didnt work\n",
      "11 2559 didnt work\n",
      "11 2560 didnt work\n",
      "11 2562 didnt work\n",
      "11 2563 didnt work\n",
      "11 2564 didnt work\n",
      "11 2566 didnt work\n",
      "11 2567 didnt work\n",
      "11 2815 didnt work\n",
      "11 2818 didnt work\n",
      "11 2819 didnt work\n",
      "11 2820 didnt work\n",
      "11 2821 didnt work\n",
      "11 2824 didnt work\n",
      "11 2826 didnt work\n",
      "11 2827 didnt work\n",
      "11 2832 didnt work\n",
      "11 3079 didnt work\n",
      "11 3084 didnt work\n"
     ]
    }
   ],
   "source": [
    "for z in vzs:\n",
    "    orbit = int(z[1])\n",
    "    xoffset = 0\n",
    "    for offset in [11, 12, 10]:\n",
    "        df = pd.read_csv(f\"~/archive/messenger/orbits/messenger-{int(orbit) - offset:04d}.csv\", parse_dates=True, index_col='DATE')\n",
    "        found = len(df[z[0] - timedelta(seconds=0):z[0] + timedelta(seconds=0)])\n",
    "        if found > 0:\n",
    "            xoffset = offset\n",
    "            break\n",
    "        else:\n",
    "            print(offset, orbit, 'didnt work')\n",
    "    df = df[z[0] - timedelta(seconds=300):z[0] + timedelta(seconds=300)]\n",
    "    df[\"BABS\"] = np.sqrt(np.power(df[\"BX_MSO\"], 2) + np.power(df[\"BY_MSO\"], 2) + np.power(df[\"BZ_MSO\"], 2))\n",
    "    fig = make_subplots(rows=8, cols=1, subplot_titles=(\"X MSO\", \"Y MSO\", \"Z MSO\", \"R\", \"BX MSO\", \"BY MSO\", \"BZ MSO\", \"|B|\"))\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['X_MSO']/R_M, mode=\"lines\", name=\"X\"), row=1, col=1);\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['Y_MSO']/R_M, mode=\"lines\", name=\"Y\"), row=2, col=1);\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['Z_MSO']/R_M, mode=\"lines\", name=\"Z\"), row=3, col=1);\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['RHO']/R_M, mode=\"lines\", name=\"R\"), row=4, col=1);\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['BX_MSO'], mode=\"lines\", name=\"BX\"), row=5, col=1);\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['BY_MSO'], mode=\"lines\", name=\"BY\"), row=6, col=1);\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['BZ_MSO'], mode=\"lines\", name=\"BZ\"), row=7, col=1);\n",
    "    fig.add_trace(go.Scatter(x=df.index, y=df['BABS'], mode=\"lines\", name=\"|B|\"), row=8, col=1);\n",
    "    \n",
    "    for i in range(1, 5):\n",
    "        fig.update_yaxes(title_text=\"Distance [R_M]\", range=[-2, 2], row=i, col=1)\n",
    "    \n",
    "    for i in range(5, 9):\n",
    "        fig.update_yaxes(title_text=\"Magnetic field [nT]\", row=i, col=1)\n",
    "    \n",
    "    for i in range(1, 9):\n",
    "        fig.add_vline(x=z[0], row=i, col=1)\n",
    "    fig.update_layout(height=1600, width=800, showlegend=False, title=f\"MESSENGER orbit {orbit-xoffset}\")\n",
    "    fig.write_image(f\"noon_crossing-{orbit-xoffset}-{z[0]}.png\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**MESSENGER** data is available in multiple resolutions from 1 second averages to 60 second averages. Most of the calculations have been performed with 60-second resolution for speed; final results have been obtained on 5-second resolution data as that nearly matches the resolution capacity of our analytical model. "
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Original MESSENGER data contains a number of artifacts. \n",
    "\n",
    "1. There are gaps in data that may lead to incorrectly calculated diffs if not approached with caution.\n",
    "1. There are spikes associated with the execution of checkout commands. These commands apply an artificial signal to the sensor so that sensor functionality and calibration can be verified. The checkouts occur nominally once per week, and the dates are noted in the documentation of the data set in the file MESS_MAGRDR_DS.CAT.\n",
    "\n",
    "These datapoints are filtered out and replaced with NaN values."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 56,
   "metadata": {},
   "outputs": [],
   "source": [
    "xyear, doy0, doy1 = 2012, 201, 288\n",
    "\n",
    "data = load_data(resolution, xyear, doy0, doy1)\n",
    "\n",
    "default_delta = np.timedelta64(resolution*10**9, 'ns')\n",
    "default_delta = np.timedelta64(60*10**9, 'ns') # 1 minute\n",
    "\n",
    "payload_columns = [\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\", \"X_MSO\", \"Y_MSO\", \"Z_MSO\"]\n",
    "\n",
    "\n",
    "def insert_gaps(data, gap_size):\n",
    "    gap_indices = np.where(np.diff(data.index) > default_delta)[0]\n",
    "    for i in gap_indices:\n",
    "        for c in payload_columns:\n",
    "            data.iat[i, data.columns.get_loc(c)] = np.nan\n",
    "        \n",
    "insert_gaps(data, resolution)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "In order to retrieve and process the checkout dates, we first execute the following commands (BASH):\n",
    "\n",
    "    wget https://pds-ppi.igpp.ucla.edu/ditdos/download?id=pds://PPI/MESS-E_V_H_SW-MAG-4-SUMM-CALIBRATED-V1.0/CATALOG/MESS_MAGRDR_DS.CAT -O MESS_MAGRDR_DS.CAT\n",
    "    sed -i 's/&nbsp;//g' MESS_MAGRDR_DS.CAT\n",
    "    grep -i checkout MESS_MAGRDR_DS.CAT  | grep '('  | sed 's/1Apr2005/01Apr2005/g' | sed 's/9Aug2005/09Apr2005/g' | awk '{ print substr($0, 0, 28)}' > checkout.dat"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {},
   "outputs": [],
   "source": [
    "def load_checkout_dates(filename, first, last):\n",
    "    res = []\n",
    "    with open(filename) as f:\n",
    "        for l in f.readlines():\n",
    "            start, end = l[0:9], l[-15:-6]\n",
    "            start = datetime.strptime(start + \"-00:00:00\", '%d%b%Y-%H:%M:%S')\n",
    "            end = datetime.strptime(end + \"-23:59:59\", '%d%b%Y-%H:%M:%S')\n",
    "            if (end > first and start < last) or (start < last and start > first):\n",
    "                res.append((start, end))\n",
    "        return res\n",
    "\n",
    "checkout = load_checkout_dates('checkout.dat', data.index[0], data.index[-1])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {},
   "outputs": [],
   "source": [
    "def filter_checkouts(data, checkout, outlier_threshold):\n",
    "    data = data.copy(True)\n",
    "    payload_columns = [\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"]\n",
    "    for c in checkout:\n",
    "        outlier_indices = np.where(data.loc[c[0]:c[1]]['BX_MSO']**2 +\n",
    "                                   data.loc[c[0]:c[1]]['BY_MSO']**2 +\n",
    "                                   data.loc[c[0]:c[1]]['BZ_MSO']**2 > outlier_threshold**2)[0]\n",
    "        for i in outlier_indices:\n",
    "            iprev = data.loc[c[0]:c[1]].index[i-1]\n",
    "            inext = data.loc[c[0]:c[1]].index[i+1]\n",
    "            i = data.loc[c[0]:c[1]].index[i]\n",
    "            for col in payload_columns:\n",
    "                for j in [iprev, i, inext]:\n",
    "                    data.at[j, col] = np.nan\n",
    "    bms = []\n",
    "    for c in checkout:\n",
    "        bms.append(np.array(np.sqrt(\n",
    "            data.loc[c[0] : c[1]]['BX_MSO']**2 +\n",
    "            data.loc[c[0] : c[1]]['BY_MSO']**2 +\n",
    "            data.loc[c[0] : c[1]]['BZ_MSO']**2)\n",
    "        ))\n",
    "        bmx = bms[-1][~np.isnan(bms[-1])]\n",
    "    if len(bms) > 0:\n",
    "        bm = np.concatenate(bms)\n",
    "        bm = bm[~np.isnan(bm)]\n",
    "    else:\n",
    "        bm = []\n",
    "    return data, bm"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 57,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Threshold manually chosen after careful examination of the resulting plot\n",
    "data, bm = filter_checkouts(data, checkout, outlier_threshold=550)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 29,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "bd61fa57c854433ab5e56a7f995eec19",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(FloatSlider(value=100.0, description='outlier_threshold', max=1000.0, min=100.0, step=10…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "@interact(data=fixed(data), checkout=fixed(checkout), outlier_threshold=widgets.FloatSlider(min=100, max=1000, step=10, continuousUpdate=False))\n",
    "def w_filter_checkouts(**kwargs):\n",
    "    _, bm = filter_checkouts(**kwargs)\n",
    "    plt.hist(bm, 100, log=True);\n",
    "    plt.xlabel('$|B|$');\n",
    "    plt.ylabel('$\\log\\,N$');"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 58,
   "metadata": {},
   "outputs": [],
   "source": [
    "data['R'] = np.sqrt((data.X_MSO**2+data.Y_MSO**2+data.Z_MSO**2))\n",
    "data['RXY'] = np.sqrt((data.X_MSO**2+data.Y_MSO**2))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 59,
   "metadata": {},
   "outputs": [],
   "source": [
    "#with warnings.catch_warnings(record=True) as w:\n",
    "#warnings.simplefilter(\"always\")\n",
    "df_apsis = pd.concat([\n",
    "    pd.DataFrame(data.R.iloc[argrelextrema(data.R.values, np.less)].rename(\"Periapsis\")),\n",
    "    pd.DataFrame(data.R.iloc[argrelextrema(data.R.values, np.greater)].rename(\"Apoapsis\"))],\n",
    "    axis=1, join='outer')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 60,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "ac2a972879f44ba38ce0bcdaaa1e2ffa",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(Output(),), _dom_classes=('widget-interact',))"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "@interact(df_apsis=fixed(df_apsis))\n",
    "def apsis_plot(df_apsis):\n",
    "    fig = go.Figure()\n",
    "    \n",
    "    lines = {'Periapsis': 'Высота перицентра', 'Apoapsis': 'Высота апоцентра'}\n",
    "    for k in lines.keys():\n",
    "        line = df_apsis[~np.isnan(df_apsis[k])]\n",
    "        fig.add_trace(go.Scatter(x=line.index, y=line[k].values,\n",
    "                    mode='lines+markers',\n",
    "                    name=lines[k]))\n",
    "    \n",
    "    fig.update_layout(\n",
    "        title=go.layout.Title(\n",
    "            text=\"Апсиды орбиты КА MESSENGER ({:%Y-%m-%d} - {:%Y-%m-%d})\".format(\n",
    "                min(df_apsis.index), max(df_apsis.index)\n",
    "            ), x=0.5, xanchor='center'),\n",
    "        xaxis=go.layout.XAxis(title=go.layout.xaxis.Title(text=\"Дата\")),\n",
    "        yaxis=go.layout.YAxis(title=go.layout.yaxis.Title(text=\"Высота [км]\")),\n",
    "    )\n",
    "    \n",
    "    fig.show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 33,
   "metadata": {},
   "outputs": [],
   "source": [
    "def dipole_field(data, psi=0.0):\n",
    "    data = data.copy(True)\n",
    "    x, y, z = data.X_MSO, data.Y_MSO, (data.Z_MSO - z_displacement)\n",
    "\n",
    "    # Distance of the spacecraft to Mercury's center in km\n",
    "    data[\"R_DIPOLE\"]=np.sqrt(x**2 + y**2 + z**2)\n",
    "    \n",
    "    # hermomagnetic colatitude in radians\n",
    "    data[\"THETA_DIPOLE\"]=np.arccos(z/data.R_DIPOLE)\n",
    "    # hermomagnetic latitude in radians\n",
    "    data[\"LAMBDA_DIPOLE\"]=np.arcsin(z/data.R_DIPOLE)\n",
    "        \n",
    "    p = z*np.cos(psi) - x*np.sin(psi)\n",
    "    Br = M_0/data.R_DIPOLE**5\n",
    "    data[\"BX_DIPOLE\"]=-Br*(- data.R_DIPOLE**2 *np.sin(psi) - 3.*x*p)\n",
    "    data[\"BY_DIPOLE\"]= Br*(3.*y*p)\n",
    "    data[\"BZ_DIPOLE\"]=-Br*(data.R_DIPOLE**2 *np.cos(psi) - 3.*z*p)\n",
    "    data[\"BABS_DIPOLE\"]=np.abs(M_0)/ data.R_DIPOLE**4 * np.sqrt(3*z**2 + data.R_DIPOLE**2)\n",
    "    return data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 49,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "ab668f08166e420488169bc81e369f59",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "interactive(children=(FloatSlider(value=0.0, continuous_update=False, description='psi', max=3.141592653589793…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "@interact(data=fixed(data), psi=widgets.FloatSlider(min=-np.pi, max=np.pi, step=np.pi/15, continuous_update=False))\n",
    "def w_dipole_field(**kwargs):\n",
    "    df_dipole = dipole_field(**kwargs)[100:250]\n",
    "    \n",
    "    fig = go.Figure()\n",
    "    \n",
    "    lines = {\"BX\": \"$B_x$\", \"BY\": \"$B_y$\", \"BZ\": \"$B_z$\", \"BABS\": \"$|B|$\"}\n",
    "    colors = ['black', 'red', 'green', 'blue']\n",
    "    for component, color in zip(sorted(lines.keys()), colors):\n",
    "        field = df_dipole[~np.isnan(df_dipole['{}_DIPOLE'.format(component)])]\n",
    "        fig.add_trace(go.Scatter(x=field.index, y=field['{}_DIPOLE'.format(component)].values, \n",
    "                mode='lines', hoverinfo='x+y',\n",
    "                name=lines[component], marker_color=color))\n",
    "    \n",
    "    fig.update_layout(\n",
    "        title=go.layout.Title(\n",
    "            text=r\"$\\text{{Магнитное поле диполя вдоль орбиты КА MESSENGER ({:%Y-%m-%d} - {:%Y-%m-%d}). }} \\psi={}$\".format(\n",
    "                min(df_dipole.index), max(df_dipole.index), kwargs['psi']\n",
    "            ), x=0.5, xanchor='center'),\n",
    "        xaxis=go.layout.XAxis(title=go.layout.xaxis.Title(text=\"Дата\")),\n",
    "        yaxis=go.layout.YAxis(title=go.layout.yaxis.Title(text=\"B [nT]\")),\n",
    "    )\n",
    "    \n",
    "    # fig.show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 35,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/home/dp/.local/lib/python3.7/site-packages/ipykernel_launcher.py:2: FutureWarning:\n",
      "\n",
      "The pandas.datetime class is deprecated and will be removed from pandas in a future version. Import from datetime module instead.\n",
      "\n"
     ]
    }
   ],
   "source": [
    "def load_mercury_horizons(resolution=60, year=None, mindoy=None, maxdoy=None):\n",
    "    dateparse = lambda x: pd.datetime.strptime(x, '%Y-%b-%dZ%H:%M:%S.0000')\n",
    "    data = pd.read_table(\"mercury-pos-min.txt\", sep=\"\\t\", engine='python', parse_dates=[0], date_parser=dateparse)\n",
    "    data.columns = [\"DATE\", \"X\", \"Y\", \"Z\", \"VX\", \"VY\", \"VZ\"]\n",
    "    data = data.drop_duplicates(\"DATE\")\n",
    "    data = data.set_index('DATE')\n",
    "    \n",
    "    if year is not None:\n",
    "        data = data[data.index.year == year]\n",
    "    if mindoy is not None:\n",
    "        data = data[data.index.dayofyear >= mindoy]\n",
    "    if maxdoy is not None:\n",
    "        data = data[data.index.dayofyear <= maxdoy]\n",
    "    \n",
    "    if resolution != 60:\n",
    "        data = data.resample('{}S'.format(resolution)).ffill()\n",
    "    \n",
    "    data['VABS'] = np.sqrt(data.VX**2 + data.VY**2 + data.VZ**2)\n",
    "    data['D'] = np.sqrt(data.X**2 + data.Y**2 + data.Z**2)\n",
    "    return data.sort_index()\n",
    "\n",
    "\n",
    "data = pd.concat([data, load_mercury_horizons(resolution, xyear, doy0, doy1)], axis=1, join='inner')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 48,
   "metadata": {},
   "outputs": [],
   "source": [
    "def load_mercury_hgi():\n",
    "    mercury_hgi = pd.read_table(\"mercury-pos-hgi.txt\", sep=r'\\s*', engine='python')\n",
    "    mercury_hgi[\"HGI_LON\"] = mercury_hgi[\"HGI_LON\"] * np.pi/180\n",
    "    mercury_hgi[\"HGI_LAT\"] = (90-mercury_hgi[\"HG_LAT\"]) * np.pi/180\n",
    "    mercury_hgi[\"X\"] = mercury_hgi[\"AU\"]*np.cos(mercury_hgi[\"HGI_LON\"])*np.sin(mercury_hgi[\"HGI_LAT\"])\n",
    "    mercury_hgi[\"Y\"] = mercury_hgi[\"AU\"]*np.sin(mercury_hgi[\"HGI_LON\"])*np.sin(mercury_hgi[\"HGI_LAT\"])\n",
    "    mercury_hgi[\"Z\"] = mercury_hgi[\"AU\"]*np.cos(mercury_hgi[\"HGI_LAT\"])\n",
    "    mercury_hgi['DATE'] = mercury_hgi.apply( lambda x: pd.datetime(year=int(x['YYYY']), month=1, day=1) +  timedelta(days=(int(x['DOY'])-1)), axis=1)\n",
    "    mercury_hgi = mercury_hgi.set_index(\"DATE\")\n",
    "    return mercury_hgi\n",
    "\n",
    "# mercury_hgi = load_mercury_hgi()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "@interact(date=widgets.SelectionSlider(\n",
    "    options=list(map(lambda x: x.strftime('%Y-%m-%d'), mercury_hgi.index)),\n",
    "    continuous_update=False\n",
    "))\n",
    "def plot_mercury_position(date):\n",
    "    orbit = go.Scatter3d(\n",
    "        # 88 = Hermean year duration\n",
    "        x=mercury_hgi[:88+1].X, y=mercury_hgi[:88+1].Y, z=mercury_hgi[:88+1].Z, mode='lines', name=\"Orbit\",\n",
    "        line=dict(\n",
    "            color='#1f77b4',\n",
    "            width=4\n",
    "        )\n",
    "    )\n",
    "\n",
    "    sun = go.Scatter3d(x=[0], y=[0], z=[0], mode='markers', name='Sun')\n",
    "    planet = go.Scatter3d(x=[mercury_hgi.X[date]], y=[mercury_hgi.Y[date]], z=[mercury_hgi.Z[date]], mode='markers', name=\"Mercury\")\n",
    "\n",
    "    layout = dict(\n",
    "        width=900,\n",
    "        height=700,\n",
    "        autosize=False,\n",
    "        title='Mercury position and orbit',\n",
    "        scene=dict(\n",
    "            camera=dict(\n",
    "                eye=dict(x=-3, y=2, z=2)\n",
    "            ),\n",
    "            aspectratio=dict(x=1, y=1, z=1),\n",
    "            aspectmode='data',\n",
    "            xaxis_title='X [a.u.]',\n",
    "            yaxis_title='Y [a.u.]',\n",
    "            zaxis_title='Z [a.u.]',\n",
    "        )\n",
    "    )\n",
    "    fig = dict(data=[orbit, sun, planet], layout=layout)\n",
    "    cf.iplot(fig)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "ax = plt.subplot()\n",
    "ax.plot(hgi_x, hgi_y);\n",
    "ax.scatter(0,0, color='r', s=240); # Position of the Sun\n",
    "plt.xlabel(\"HGI X [а.е.]\")\n",
    "plt.ylabel(\"HGI Y [а.е.]\")\n",
    "ax.set_aspect('equal', adjustable='box');"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "ax = plt.subplot()\n",
    "ax.plot(hgi_x, hgi_z)\n",
    "ax.scatter(0,0, color='r', s=240); # Position of the Sun\n",
    "plt.xlabel(\"HGI X [а.е.]\")\n",
    "plt.ylabel(\"HGI Z [а.е.]\")\n",
    "ax.set_aspect('equal', adjustable='box')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# USE WITH CAUTION #\n",
    "#backup_mess = data.copy(deep=True)\n",
    "#backup_merc = mercury_xyz.copy(deep=True)\n",
    "#print(backup_mess.shape,  backup_merc.shape)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# USE WITH CAUTION #\n",
    "#data = backup_mess.copy(deep=True)\n",
    "#mercury_xyz = backup_merc.copy(deep=True)\n",
    "#print(backup_mess.shape,  backup_merc.shape)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# USE WITH CAUTION #\n",
    "#del backup_merc\n",
    "#del backup_mess"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 37,
   "metadata": {},
   "outputs": [],
   "source": [
    "def find_extrema(data):\n",
    "    x, y, z, r, rxy = 'X_MSO', 'Y_MSO', 'Z_MSO', 'R', 'RXY'\n",
    "    \n",
    "    periapsis = find_peaks(1/data[r].values[~np.isnan(data[r].values)].round(0))[0]\n",
    "    \n",
    "    extrema=pd.DataFrame(index=data.index)\n",
    "    extrema['TYPE']=0\n",
    "    \n",
    "    xy_edges = find_peaks(data[rxy].round(0).values[~np.isnan(data[rxy].values)])[0]\n",
    "    \n",
    "    if xy_edges[0] < periapsis[0] and xy_edges[1] > periapsis[0]:\n",
    "        xy_edges = xy_edges[1:]\n",
    "    xy1, xy2 = xy_edges[1::2], xy_edges[0::2]\n",
    "    \n",
    "    #extrema.iloc[xy_edges] = 1\n",
    "    extrema.iloc[xy1] = 1\n",
    "    extrema.iloc[xy2] = -1\n",
    "    \n",
    "    cosine_array = pd.DataFrame(index=data.index)\n",
    "    cosine_array['VALUE'] = np.nan\n",
    "    \n",
    "    size = np.min([len(data[x].iloc[xy1].values), len(data[x].iloc[xy2].values)])\n",
    "    \n",
    "    dx = np.abs(data[x].iloc[xy1].values[:size] - data[x].iloc[xy2].values[:size])\n",
    "    dx *= np.sign(data[x].iloc[xy1].values[:size]  - data[x].iloc[xy2].values[:size] )\n",
    "    dy = data[y].iloc[xy1].values[:size] - data[y].iloc[xy2].values[:size]\n",
    "    cosine = np.cos(np.arctan2(dy, dx))\n",
    "\n",
    "    max_delta_cosine = 0.06 # Empirically chosen to cut off rogue data points\n",
    "    cosine_diff = np.abs(np.diff(np.abs(cosine)))\n",
    "    cosine[np.append(cosine_diff > max_delta_cosine, False)] = np.nan\n",
    "    \n",
    "    i_from, i_to = extrema.iloc[periapsis].index, extrema.iloc[periapsis].index[1:]\n",
    "    i_to = i_to\n",
    "    for i in range(len(i_to)):\n",
    "        cosine_array.loc[i_from[i] : i_to[i]]['VALUE'] = cosine[i]\n",
    "    cosine_array.loc[i_to[-1]:]['VALUE'] = cosine[-1]\n",
    "    return extrema, cosine_array\n",
    "\n",
    "\n",
    "def show_extrema(data):\n",
    "    plot_size = 350000\n",
    "    plt.plot((data.R[:plot_size])/max(data.R[:plot_size]), label=r'Относительное расстояние $R/R_{max}$')\n",
    "    plt.plot(data.EXTREMA[:plot_size]/2, 'black', label=r'Экстремумы $R_{XY}$')\n",
    "    plt.plot(data.COSALPHA[:plot_size], 'green', label=r'$\\cos\\,\\alpha$')\n",
    "    plt.xlabel(\"Дата\")\n",
    "    plt.gca().xaxis.set_major_formatter(mdates.DateFormatter('%Y-%m-%d'))\n",
    "    plt.legend()\n",
    "    \n",
    "def show_extrema(data, plot_size=350000):\n",
    "    fig = go.Figure()\n",
    "    \n",
    "    fig.add_trace(go.Scatter(\n",
    "        x=data.index,\n",
    "        y=((data.R[:plot_size])/max(data.R[:plot_size])).values, \n",
    "        mode='lines', hoverinfo='x+y',\n",
    "        name=r'$R/R_{max}$', marker={'color':'navy'}\n",
    "    ))\n",
    "    \n",
    "    fig.add_trace(go.Scatter(\n",
    "        x=data.index,\n",
    "        y=(data.EXTREMA[:plot_size]/5).T.values[0],\n",
    "        mode='lines', hoverinfo='x',\n",
    "        name=r'Экстремумы $R_{XY}$', marker={'color':'orange'}\n",
    "    ))\n",
    "    \n",
    "    fig.add_trace(go.Scatter(\n",
    "        x=data.index,\n",
    "        y=data.COSALPHA[:plot_size].T.values[0], \n",
    "        mode='lines', hoverinfo='x+y',\n",
    "        name=r'$\\cos\\,\\alpha$', marker={'color':'green'}\n",
    "    ))\n",
    "    fig.update_layout(\n",
    "        title=go.layout.Title(\n",
    "            text=r\"$\\text{{Апсиды орбиты КА MESSENGER и фаза орбиты Меркурия ({:%Y-%m-%d} - {:%Y-%m-%d}). }}$\".format(\n",
    "                min(data.index), max(data.index)\n",
    "            ), x=0.5, xanchor='center'),\n",
    "        xaxis=go.layout.XAxis(title=go.layout.xaxis.Title(text=\"Дата\"))\n",
    "    )\n",
    "    \n",
    "    fig.show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 38,
   "metadata": {},
   "outputs": [],
   "source": [
    "data['EXTREMA'], data['COSALPHA'] = find_extrema(data)\n",
    "#show_extrema(data, 24*60*10)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 46,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>X_MSO</th>\n",
       "      <th>Y_MSO</th>\n",
       "      <th>Z_MSO</th>\n",
       "      <th>BX_MSO</th>\n",
       "      <th>BY_MSO</th>\n",
       "      <th>BZ_MSO</th>\n",
       "      <th>DBX_MSO</th>\n",
       "      <th>DBY_MSO</th>\n",
       "      <th>DBZ_MSO</th>\n",
       "      <th>R</th>\n",
       "      <th>...</th>\n",
       "      <th>X</th>\n",
       "      <th>Y</th>\n",
       "      <th>Z</th>\n",
       "      <th>VX</th>\n",
       "      <th>VY</th>\n",
       "      <th>VZ</th>\n",
       "      <th>VABS</th>\n",
       "      <th>D</th>\n",
       "      <th>EXTREMA</th>\n",
       "      <th>COSALPHA</th>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>DATE</th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "      <th></th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>2012-07-19 00:00:00</th>\n",
       "      <td>806.203</td>\n",
       "      <td>4704.321</td>\n",
       "      <td>-1599.129</td>\n",
       "      <td>-8.371</td>\n",
       "      <td>-28.223</td>\n",
       "      <td>-49.810</td>\n",
       "      <td>5.329</td>\n",
       "      <td>4.761</td>\n",
       "      <td>4.302</td>\n",
       "      <td>5033.667938</td>\n",
       "      <td>...</td>\n",
       "      <td>7.445013e+06</td>\n",
       "      <td>-6.815936e+07</td>\n",
       "      <td>-6.252117e+06</td>\n",
       "      <td>38.655274</td>\n",
       "      <td>7.792708</td>\n",
       "      <td>-2.910057</td>\n",
       "      <td>39.540169</td>\n",
       "      <td>6.884922e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-07-19 00:01:00</th>\n",
       "      <td>799.885</td>\n",
       "      <td>4745.575</td>\n",
       "      <td>-1737.642</td>\n",
       "      <td>-9.576</td>\n",
       "      <td>-25.721</td>\n",
       "      <td>-48.751</td>\n",
       "      <td>6.955</td>\n",
       "      <td>5.847</td>\n",
       "      <td>3.918</td>\n",
       "      <td>5116.609992</td>\n",
       "      <td>...</td>\n",
       "      <td>7.447332e+06</td>\n",
       "      <td>-6.815889e+07</td>\n",
       "      <td>-6.252291e+06</td>\n",
       "      <td>38.655093</td>\n",
       "      <td>7.794371</td>\n",
       "      <td>-2.909905</td>\n",
       "      <td>39.540308</td>\n",
       "      <td>6.884903e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-07-19 00:02:00</th>\n",
       "      <td>793.075</td>\n",
       "      <td>4784.040</td>\n",
       "      <td>-1875.378</td>\n",
       "      <td>-7.972</td>\n",
       "      <td>-28.599</td>\n",
       "      <td>-43.524</td>\n",
       "      <td>7.648</td>\n",
       "      <td>5.359</td>\n",
       "      <td>5.077</td>\n",
       "      <td>5199.331622</td>\n",
       "      <td>...</td>\n",
       "      <td>7.449651e+06</td>\n",
       "      <td>-6.815842e+07</td>\n",
       "      <td>-6.252466e+06</td>\n",
       "      <td>38.654911</td>\n",
       "      <td>7.796034</td>\n",
       "      <td>-2.909752</td>\n",
       "      <td>39.540447</td>\n",
       "      <td>6.884883e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-07-19 00:03:00</th>\n",
       "      <td>785.819</td>\n",
       "      <td>4819.807</td>\n",
       "      <td>-2012.057</td>\n",
       "      <td>-15.363</td>\n",
       "      <td>-22.648</td>\n",
       "      <td>-43.007</td>\n",
       "      <td>4.972</td>\n",
       "      <td>5.242</td>\n",
       "      <td>4.021</td>\n",
       "      <td>5281.706579</td>\n",
       "      <td>...</td>\n",
       "      <td>7.451971e+06</td>\n",
       "      <td>-6.815796e+07</td>\n",
       "      <td>-6.252641e+06</td>\n",
       "      <td>38.654729</td>\n",
       "      <td>7.797697</td>\n",
       "      <td>-2.909600</td>\n",
       "      <td>39.540586</td>\n",
       "      <td>6.884863e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-07-19 00:04:00</th>\n",
       "      <td>778.143</td>\n",
       "      <td>4852.978</td>\n",
       "      <td>-2147.652</td>\n",
       "      <td>-9.397</td>\n",
       "      <td>-28.434</td>\n",
       "      <td>-42.773</td>\n",
       "      <td>7.009</td>\n",
       "      <td>6.553</td>\n",
       "      <td>4.060</td>\n",
       "      <td>5363.703115</td>\n",
       "      <td>...</td>\n",
       "      <td>7.454290e+06</td>\n",
       "      <td>-6.815749e+07</td>\n",
       "      <td>-6.252815e+06</td>\n",
       "      <td>38.654547</td>\n",
       "      <td>7.799360</td>\n",
       "      <td>-2.909447</td>\n",
       "      <td>39.540725</td>\n",
       "      <td>6.884844e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>NaN</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>...</th>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-10-14 23:55:00</th>\n",
       "      <td>785.287</td>\n",
       "      <td>2623.216</td>\n",
       "      <td>1832.337</td>\n",
       "      <td>-18.145</td>\n",
       "      <td>-132.473</td>\n",
       "      <td>82.594</td>\n",
       "      <td>2.807</td>\n",
       "      <td>5.954</td>\n",
       "      <td>2.825</td>\n",
       "      <td>3294.752910</td>\n",
       "      <td>...</td>\n",
       "      <td>7.535683e+06</td>\n",
       "      <td>-6.814099e+07</td>\n",
       "      <td>-6.258954e+06</td>\n",
       "      <td>38.648227</td>\n",
       "      <td>7.857560</td>\n",
       "      <td>-2.904085</td>\n",
       "      <td>39.545675</td>\n",
       "      <td>6.884152e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>-0.218838</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-10-14 23:56:00</th>\n",
       "      <td>806.209</td>\n",
       "      <td>2774.202</td>\n",
       "      <td>1713.205</td>\n",
       "      <td>-13.675</td>\n",
       "      <td>-112.477</td>\n",
       "      <td>89.612</td>\n",
       "      <td>4.001</td>\n",
       "      <td>5.507</td>\n",
       "      <td>1.780</td>\n",
       "      <td>3358.755880</td>\n",
       "      <td>...</td>\n",
       "      <td>7.538002e+06</td>\n",
       "      <td>-6.814052e+07</td>\n",
       "      <td>-6.259128e+06</td>\n",
       "      <td>38.648043</td>\n",
       "      <td>7.859223</td>\n",
       "      <td>-2.903932</td>\n",
       "      <td>39.545815</td>\n",
       "      <td>6.884133e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>-0.218838</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-10-14 23:57:00</th>\n",
       "      <td>825.452</td>\n",
       "      <td>2919.384</td>\n",
       "      <td>1590.485</td>\n",
       "      <td>-9.331</td>\n",
       "      <td>-93.291</td>\n",
       "      <td>94.030</td>\n",
       "      <td>3.181</td>\n",
       "      <td>5.492</td>\n",
       "      <td>0.827</td>\n",
       "      <td>3425.465878</td>\n",
       "      <td>...</td>\n",
       "      <td>7.540321e+06</td>\n",
       "      <td>-6.814005e+07</td>\n",
       "      <td>-6.259302e+06</td>\n",
       "      <td>38.647859</td>\n",
       "      <td>7.860886</td>\n",
       "      <td>-2.903780</td>\n",
       "      <td>39.545954</td>\n",
       "      <td>6.884113e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>-0.218838</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-10-14 23:58:00</th>\n",
       "      <td>843.077</td>\n",
       "      <td>3058.805</td>\n",
       "      <td>1464.623</td>\n",
       "      <td>-5.617</td>\n",
       "      <td>-76.563</td>\n",
       "      <td>95.951</td>\n",
       "      <td>2.157</td>\n",
       "      <td>4.110</td>\n",
       "      <td>1.455</td>\n",
       "      <td>3494.594023</td>\n",
       "      <td>...</td>\n",
       "      <td>7.542640e+06</td>\n",
       "      <td>-6.813957e+07</td>\n",
       "      <td>-6.259476e+06</td>\n",
       "      <td>38.647675</td>\n",
       "      <td>7.862549</td>\n",
       "      <td>-2.903627</td>\n",
       "      <td>39.546094</td>\n",
       "      <td>6.884093e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>-0.218838</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>2012-10-14 23:59:00</th>\n",
       "      <td>859.144</td>\n",
       "      <td>3192.543</td>\n",
       "      <td>1336.037</td>\n",
       "      <td>-3.257</td>\n",
       "      <td>-61.664</td>\n",
       "      <td>96.662</td>\n",
       "      <td>1.478</td>\n",
       "      <td>4.451</td>\n",
       "      <td>1.655</td>\n",
       "      <td>3565.873537</td>\n",
       "      <td>...</td>\n",
       "      <td>7.544958e+06</td>\n",
       "      <td>-6.813910e+07</td>\n",
       "      <td>-6.259650e+06</td>\n",
       "      <td>38.647491</td>\n",
       "      <td>7.864212</td>\n",
       "      <td>-2.903474</td>\n",
       "      <td>39.546233</td>\n",
       "      <td>6.884074e+07</td>\n",
       "      <td>0</td>\n",
       "      <td>-0.218838</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>126720 rows × 21 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "                       X_MSO     Y_MSO     Z_MSO  BX_MSO   BY_MSO  BZ_MSO  \\\n",
       "DATE                                                                        \n",
       "2012-07-19 00:00:00  806.203  4704.321 -1599.129  -8.371  -28.223 -49.810   \n",
       "2012-07-19 00:01:00  799.885  4745.575 -1737.642  -9.576  -25.721 -48.751   \n",
       "2012-07-19 00:02:00  793.075  4784.040 -1875.378  -7.972  -28.599 -43.524   \n",
       "2012-07-19 00:03:00  785.819  4819.807 -2012.057 -15.363  -22.648 -43.007   \n",
       "2012-07-19 00:04:00  778.143  4852.978 -2147.652  -9.397  -28.434 -42.773   \n",
       "...                      ...       ...       ...     ...      ...     ...   \n",
       "2012-10-14 23:55:00  785.287  2623.216  1832.337 -18.145 -132.473  82.594   \n",
       "2012-10-14 23:56:00  806.209  2774.202  1713.205 -13.675 -112.477  89.612   \n",
       "2012-10-14 23:57:00  825.452  2919.384  1590.485  -9.331  -93.291  94.030   \n",
       "2012-10-14 23:58:00  843.077  3058.805  1464.623  -5.617  -76.563  95.951   \n",
       "2012-10-14 23:59:00  859.144  3192.543  1336.037  -3.257  -61.664  96.662   \n",
       "\n",
       "                     DBX_MSO  DBY_MSO  DBZ_MSO            R  ...  \\\n",
       "DATE                                                         ...   \n",
       "2012-07-19 00:00:00    5.329    4.761    4.302  5033.667938  ...   \n",
       "2012-07-19 00:01:00    6.955    5.847    3.918  5116.609992  ...   \n",
       "2012-07-19 00:02:00    7.648    5.359    5.077  5199.331622  ...   \n",
       "2012-07-19 00:03:00    4.972    5.242    4.021  5281.706579  ...   \n",
       "2012-07-19 00:04:00    7.009    6.553    4.060  5363.703115  ...   \n",
       "...                      ...      ...      ...          ...  ...   \n",
       "2012-10-14 23:55:00    2.807    5.954    2.825  3294.752910  ...   \n",
       "2012-10-14 23:56:00    4.001    5.507    1.780  3358.755880  ...   \n",
       "2012-10-14 23:57:00    3.181    5.492    0.827  3425.465878  ...   \n",
       "2012-10-14 23:58:00    2.157    4.110    1.455  3494.594023  ...   \n",
       "2012-10-14 23:59:00    1.478    4.451    1.655  3565.873537  ...   \n",
       "\n",
       "                                X             Y             Z         VX  \\\n",
       "DATE                                                                       \n",
       "2012-07-19 00:00:00  7.445013e+06 -6.815936e+07 -6.252117e+06  38.655274   \n",
       "2012-07-19 00:01:00  7.447332e+06 -6.815889e+07 -6.252291e+06  38.655093   \n",
       "2012-07-19 00:02:00  7.449651e+06 -6.815842e+07 -6.252466e+06  38.654911   \n",
       "2012-07-19 00:03:00  7.451971e+06 -6.815796e+07 -6.252641e+06  38.654729   \n",
       "2012-07-19 00:04:00  7.454290e+06 -6.815749e+07 -6.252815e+06  38.654547   \n",
       "...                           ...           ...           ...        ...   \n",
       "2012-10-14 23:55:00  7.535683e+06 -6.814099e+07 -6.258954e+06  38.648227   \n",
       "2012-10-14 23:56:00  7.538002e+06 -6.814052e+07 -6.259128e+06  38.648043   \n",
       "2012-10-14 23:57:00  7.540321e+06 -6.814005e+07 -6.259302e+06  38.647859   \n",
       "2012-10-14 23:58:00  7.542640e+06 -6.813957e+07 -6.259476e+06  38.647675   \n",
       "2012-10-14 23:59:00  7.544958e+06 -6.813910e+07 -6.259650e+06  38.647491   \n",
       "\n",
       "                           VY        VZ       VABS             D  EXTREMA  \\\n",
       "DATE                                                                        \n",
       "2012-07-19 00:00:00  7.792708 -2.910057  39.540169  6.884922e+07        0   \n",
       "2012-07-19 00:01:00  7.794371 -2.909905  39.540308  6.884903e+07        0   \n",
       "2012-07-19 00:02:00  7.796034 -2.909752  39.540447  6.884883e+07        0   \n",
       "2012-07-19 00:03:00  7.797697 -2.909600  39.540586  6.884863e+07        0   \n",
       "2012-07-19 00:04:00  7.799360 -2.909447  39.540725  6.884844e+07        0   \n",
       "...                       ...       ...        ...           ...      ...   \n",
       "2012-10-14 23:55:00  7.857560 -2.904085  39.545675  6.884152e+07        0   \n",
       "2012-10-14 23:56:00  7.859223 -2.903932  39.545815  6.884133e+07        0   \n",
       "2012-10-14 23:57:00  7.860886 -2.903780  39.545954  6.884113e+07        0   \n",
       "2012-10-14 23:58:00  7.862549 -2.903627  39.546094  6.884093e+07        0   \n",
       "2012-10-14 23:59:00  7.864212 -2.903474  39.546233  6.884074e+07        0   \n",
       "\n",
       "                     COSALPHA  \n",
       "DATE                           \n",
       "2012-07-19 00:00:00       NaN  \n",
       "2012-07-19 00:01:00       NaN  \n",
       "2012-07-19 00:02:00       NaN  \n",
       "2012-07-19 00:03:00       NaN  \n",
       "2012-07-19 00:04:00       NaN  \n",
       "...                       ...  \n",
       "2012-10-14 23:55:00 -0.218838  \n",
       "2012-10-14 23:56:00 -0.218838  \n",
       "2012-10-14 23:57:00 -0.218838  \n",
       "2012-10-14 23:58:00 -0.218838  \n",
       "2012-10-14 23:59:00 -0.218838  \n",
       "\n",
       "[126720 rows x 21 columns]"
      ]
     },
     "execution_count": 46,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "data"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 63,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "marker": {
          "color": "blue",
          "colorscale": [
           [
            0,
            "#440154"
           ],
           [
            0.1111111111111111,
            "#482878"
           ],
           [
            0.2222222222222222,
            "#3e4989"
           ],
           [
            0.3333333333333333,
            "#31688e"
           ],
           [
            0.4444444444444444,
            "#26828e"
           ],
           [
            0.5555555555555556,
            "#1f9e89"
           ],
           [
            0.6666666666666666,
            "#35b779"
           ],
           [
            0.7777777777777778,
            "#6ece58"
           ],
           [
            0.8888888888888888,
            "#b5de2b"
           ],
           [
            1,
            "#fde725"
           ]
          ],
          "opacity": 0.8,
          "size": 1
         },
         "mode": "lines",
         "type": "scatter3d",
         "x": [
          806.203,
          799.885,
          793.075,
          785.819,
          778.143,
          770.069,
          761.6189999999999,
          752.812,
          743.669,
          734.206,
          724.441,
          714.3889999999999,
          704.067,
          693.487,
          682.663,
          671.6089999999999,
          660.335,
          648.8530000000001,
          637.175,
          625.309,
          613.266,
          601.054,
          588.683,
          576.16,
          563.494,
          550.691,
          537.759,
          524.705,
          511.535,
          498.254,
          484.869,
          471.38599999999997,
          457.809,
          444.14300000000003,
          430.394,
          416.565,
          402.662,
          388.68800000000005,
          374.648,
          360.545,
          346.38300000000004,
          332.165,
          317.895,
          303.577,
          289.212,
          274.805,
          260.357,
          245.873,
          231.354,
          216.803,
          202.222,
          187.614,
          172.981,
          158.326,
          143.65,
          128.955,
          114.243,
          99.516,
          84.777,
          70.02600000000001,
          55.266000000000005,
          40.498000000000005,
          25.724,
          10.944,
          -3.838,
          -18.623,
          -33.408,
          -48.192,
          -62.973,
          -77.752,
          -92.52600000000001,
          -107.294,
          -122.055,
          -136.808,
          -151.55200000000002,
          -166.285,
          -181.00799999999998,
          -195.718,
          -210.415,
          -225.09799999999998,
          -239.766,
          -254.418,
          -269.053,
          -283.671,
          -298.27,
          -312.85,
          -327.41,
          -341.949,
          -356.466,
          -370.962,
          -385.434,
          -399.88300000000004,
          -414.30800000000005,
          -428.708,
          -443.082,
          -457.43,
          -471.751,
          -486.045,
          -500.311,
          -514.548,
          -528.756,
          -542.935,
          -557.0830000000001,
          -571.201,
          -585.2869999999999,
          -599.341,
          -613.364,
          -627.3530000000001,
          -641.31,
          -655.232,
          -669.1210000000001,
          -682.975,
          -696.793,
          -710.577,
          -724.324,
          -738.035,
          -751.709,
          -765.346,
          -778.946,
          -792.507,
          -806.03,
          -819.515,
          -832.96,
          -846.365,
          -859.7310000000001,
          -873.056,
          -886.341,
          -899.584,
          -912.7860000000001,
          -925.947,
          -939.065,
          -952.1410000000001,
          -965.174,
          -978.163,
          -991.11,
          -1004.012,
          -1016.8710000000001,
          -1029.685,
          -1042.454,
          -1055.178,
          -1067.856,
          -1080.489,
          -1093.076,
          -1105.616,
          -1118.109,
          -1130.556,
          -1142.955,
          -1155.306,
          -1167.61,
          -1179.865,
          -1192.072,
          -1204.229,
          -1216.338,
          -1228.397,
          -1240.406,
          -1252.365,
          -1264.274,
          -1276.132,
          -1287.9389999999999,
          -1299.695,
          -1311.4,
          -1323.0520000000001,
          -1334.652,
          -1346.2,
          -1357.695,
          -1369.136,
          -1380.525,
          -1391.859,
          -1403.14,
          -1414.3670000000002,
          -1425.539,
          -1436.656,
          -1447.717,
          -1458.724,
          -1469.674,
          -1480.569,
          -1491.4070000000002,
          -1502.1879999999999,
          -1512.9129999999998,
          -1523.611,
          -1534.221,
          -1544.7720000000002,
          -1555.266,
          -1565.701,
          -1576.0770000000002,
          -1586.394,
          -1596.651,
          -1606.848,
          -1616.986,
          -1627.0629999999999,
          -1637.079,
          -1647.035,
          -1656.9279999999999,
          -1666.761,
          -1676.531,
          -1686.2379999999998,
          -1695.8829999999998,
          -1705.465,
          -1714.984,
          -1724.4389999999999,
          -1733.83,
          -1743.156,
          -1752.418,
          -1761.615,
          -1770.746,
          -1779.8110000000001,
          -1788.81,
          -1797.743,
          -1806.609,
          -1815.408,
          -1824.139,
          -1832.8020000000001,
          -1841.3970000000002,
          -1849.9229999999998,
          -1858.379,
          -1866.767,
          -1875.085,
          -1883.332,
          -1891.509,
          -1899.614,
          -1907.649,
          -1915.611,
          -1923.501,
          -1931.319,
          -1939.0629999999999,
          -1946.734,
          -1954.3310000000001,
          -1961.854,
          -1969.3020000000001,
          -1976.674,
          -1983.971,
          -1991.192,
          -1998.3370000000002,
          -2005.404,
          -2012.394,
          -2019.306,
          -2026.14,
          -2032.895,
          -2039.57,
          -2046.1660000000002,
          -2052.681,
          -2059.116,
          -2065.469,
          -2071.741,
          -2077.93,
          -2084.036,
          -2090.0589999999997,
          -2095.998,
          -2101.853,
          -2107.6220000000003,
          -2113.306,
          -2118.904,
          -2124.416,
          -2129.84,
          -2135.177,
          -2140.425,
          -2145.584,
          -2150.654,
          -2155.633,
          -2160.522,
          -2165.319,
          -2170.025,
          -2174.637,
          -2179.157,
          -2183.5820000000003,
          -2187.913,
          -2192.149,
          -2196.288,
          -2200.331,
          -2204.277,
          -2208.125,
          -2211.874,
          -2215.5229999999997,
          -2219.072,
          -2222.521,
          -2225.867,
          -2229.112,
          -2232.2529999999997,
          -2235.2889999999998,
          -2238.222,
          -2241.048,
          -2243.768,
          -2246.38,
          -2248.885,
          -2251.28,
          -2253.5660000000003,
          -2255.74,
          -2257.803,
          -2259.754,
          -2261.591,
          -2263.313,
          -2264.92,
          -2266.411,
          -2267.784,
          -2269.0389999999998,
          -2270.174,
          -2271.189,
          -2272.083,
          -2272.854,
          -2273.501,
          -2274.024,
          -2274.4210000000003,
          -2274.69,
          -2274.8320000000003,
          -2274.844,
          -2274.726,
          -2274.476,
          -2274.093,
          -2273.575,
          -2272.922,
          -2272.133,
          -2271.205,
          -2270.137,
          -2268.929,
          -2267.578,
          -2266.084,
          -2264.444,
          -2262.658,
          -2260.724,
          -2258.64,
          -2256.404,
          -2254.016,
          -2251.473,
          -2248.774,
          -2245.917,
          -2242.901,
          -2239.723,
          -2236.383,
          -2232.877,
          -2229.2039999999997,
          -2225.363,
          -2221.351,
          -2217.167,
          -2212.808,
          -2208.272,
          -2203.5570000000002,
          -2198.6620000000003,
          -2193.584,
          -2188.32,
          -2182.868,
          -2177.2270000000003,
          -2171.393,
          -2165.365,
          -2159.139,
          -2152.7129999999997,
          -2146.085,
          -2139.252,
          -2132.21,
          -2124.959,
          -2117.493,
          -2109.811,
          -2101.91,
          -2093.786,
          -2085.437,
          -2076.859,
          -2068.048,
          -2059.002,
          -2049.718,
          -2040.19,
          -2030.4160000000002,
          -2020.3929999999998,
          -2010.116,
          -1999.5810000000001,
          -1988.7839999999999,
          -1977.7220000000002,
          -1966.389,
          -1954.7820000000002,
          -1942.896,
          -1930.727,
          -1918.269,
          -1905.5179999999998,
          -1892.469,
          -1879.118,
          -1865.4579999999999,
          -1851.484,
          -1837.19,
          -1822.5720000000001,
          -1807.622,
          -1792.336,
          -1776.7060000000001,
          -1760.726,
          -1744.39,
          -1727.691,
          -1710.622,
          -1693.175,
          -1675.3429999999998,
          -1657.119,
          -1638.494,
          -1619.461,
          -1600.011,
          -1580.135,
          -1559.825,
          -1539.0710000000001,
          -1517.864,
          -1496.194,
          -1474.0520000000001,
          -1451.4270000000001,
          -1428.308,
          -1404.684,
          -1380.545,
          -1355.878,
          -1330.672,
          -1304.915,
          -1278.595,
          -1251.698,
          -1224.212,
          -1196.124,
          -1167.4189999999999,
          -1138.085,
          -1108.108,
          -1077.473,
          -1046.167,
          -1014.176,
          -981.4860000000001,
          -948.0830000000001,
          -913.955,
          -879.087,
          -843.4689999999999,
          -807.0880000000001,
          -769.936,
          -732.003,
          -693.2819999999999,
          -653.769,
          -613.4630000000001,
          -572.365,
          -530.48,
          -487.81800000000004,
          -444.39599999999996,
          -400.235,
          -355.36400000000003,
          -309.82099999999997,
          -263.653,
          -216.919,
          -169.68599999999998,
          -122.039,
          -74.072,
          -25.896,
          22.365,
          70.57300000000001,
          118.57600000000001,
          166.213,
          213.31099999999998,
          259.693,
          305.178,
          349.589,
          392.75199999999995,
          434.506,
          474.704,
          513.2180000000001,
          549.939,
          584.7819999999999,
          617.684,
          648.604,
          677.5219999999999,
          704.442,
          729.38,
          752.37,
          773.456,
          792.696,
          810.15,
          825.887,
          839.9789999999999,
          852.497,
          863.518,
          873.115,
          881.36,
          888.324,
          894.074,
          898.677,
          902.195,
          904.689,
          906.215,
          906.827,
          906.577,
          905.5110000000001,
          903.677,
          901.1160000000001,
          897.868,
          893.972,
          889.462,
          884.3739999999999,
          878.737,
          872.582,
          865.937,
          858.827,
          851.2760000000001,
          843.309,
          834.947,
          826.211,
          817.1189999999999,
          807.69,
          797.942,
          787.89,
          777.55,
          766.936,
          756.062,
          744.941,
          733.585,
          722.007,
          710.216,
          698.2230000000001,
          686.038,
          673.671,
          661.1310000000001,
          648.4259999999999,
          635.563,
          622.552,
          609.398,
          596.11,
          582.694,
          569.155,
          555.501,
          541.736,
          527.867,
          513.899,
          499.836,
          485.68300000000005,
          471.44599999999997,
          457.12800000000004,
          442.73400000000004,
          428.267,
          413.73199999999997,
          399.13300000000004,
          384.472,
          369.754,
          354.98199999999997,
          340.158,
          325.286,
          310.369,
          295.409,
          280.41,
          265.374,
          250.303,
          235.2,
          220.06799999999998,
          204.907,
          189.722,
          174.513,
          159.283,
          144.033,
          128.766,
          113.484,
          98.18799999999999,
          82.87899999999999,
          67.56,
          52.233000000000004,
          36.898,
          21.557,
          6.212000000000001,
          -9.136000000000001,
          -24.485,
          -39.835,
          -55.183,
          -70.53,
          -85.87299999999999,
          -101.211,
          -116.54299999999999,
          -131.868,
          -147.185,
          -162.493,
          -177.791,
          -193.078,
          -208.35299999999998,
          -223.614,
          -238.862,
          -254.095,
          -269.312,
          -284.512,
          -299.695,
          -314.86,
          -330.006,
          -345.131,
          -360.23699999999997,
          -375.32099999999997,
          -390.38300000000004,
          -405.42199999999997,
          -420.43699999999995,
          -435.42900000000003,
          -450.39599999999996,
          -465.337,
          -480.25300000000004,
          -495.14099999999996,
          -510.00300000000004,
          -524.836,
          -539.641,
          -554.4169999999999,
          -569.163,
          -583.879,
          -598.564,
          -613.2180000000001,
          -627.841,
          -642.431,
          -656.988,
          -671.512,
          -686.002,
          -700.457,
          -714.878,
          -729.2639999999999,
          -743.6139999999999,
          -757.928,
          -772.205,
          -786.446,
          -800.648,
          -814.813,
          -828.94,
          -843.0269999999999,
          -857.076,
          -871.085,
          -885.054,
          -898.982,
          -912.87,
          -926.716,
          -940.5210000000001,
          -954.284,
          -968.005,
          -981.682,
          -995.317,
          -1008.908,
          -1022.456,
          -1035.9589999999998,
          -1049.417,
          -1062.8310000000001,
          -1076.1989999999998,
          -1089.522,
          -1102.799,
          -1116.029,
          -1129.213,
          -1142.349,
          -1155.438,
          -1168.479,
          -1181.473,
          -1194.417,
          -1207.313,
          -1220.16,
          -1232.958,
          -1245.705,
          -1258.403,
          -1271.05,
          -1283.646,
          -1296.191,
          -1308.685,
          -1321.1270000000002,
          -1333.517,
          -1345.854,
          -1358.139,
          -1370.37,
          -1382.5479999999998,
          -1394.672,
          -1406.7420000000002,
          -1418.7579999999998,
          -1430.719,
          -1442.625,
          -1454.475,
          -1466.27,
          -1478.009,
          -1489.691,
          -1501.316,
          -1512.884,
          -1524.395,
          -1535.848,
          -1547.243,
          -1558.58,
          -1569.858,
          -1581.076,
          -1592.235,
          -1603.335,
          -1614.374,
          -1625.3529999999998,
          -1636.271,
          -1647.1270000000002,
          -1657.9229999999998,
          -1668.656,
          -1679.3270000000002,
          -1689.935,
          -1700.481,
          -1710.963,
          -1721.381,
          -1731.736,
          -1742.026,
          -1752.251,
          -1762.411,
          -1772.506,
          -1782.535,
          -1792.497,
          -1802.3929999999998,
          -1812.2220000000002,
          -1821.983,
          -1831.6770000000001,
          -1841.3020000000001,
          -1850.859,
          -1860.3470000000002,
          -1869.765,
          -1879.114,
          -1888.392,
          -1897.6,
          -1906.737,
          -1915.8029999999999,
          -1924.796,
          -1933.7179999999998,
          -1942.566,
          -1951.342,
          -1960.0439999999999,
          -1968.672,
          -1977.225,
          -1985.704,
          -1994.1070000000002,
          -2002.435,
          -2010.6860000000001,
          -2018.861,
          -2026.9579999999999,
          -2034.9779999999998,
          -2042.92,
          -2050.783,
          -2058.567,
          -2066.271,
          -2073.896,
          -2081.44,
          -2088.902,
          -2096.283,
          -2103.5820000000003,
          -2110.799,
          -2117.9320000000002,
          -2124.981,
          -2131.947,
          -2138.827,
          -2145.6220000000003,
          -2152.331,
          -2158.9539999999997,
          -2165.49,
          -2171.938,
          -2178.298,
          -2184.569,
          -2190.751,
          -2196.842,
          -2202.844,
          -2208.7529999999997,
          -2214.571,
          -2220.297,
          -2225.929,
          -2231.468,
          -2236.9120000000003,
          -2242.261,
          -2247.515,
          -2252.6710000000003,
          -2257.731,
          -2262.6929999999998,
          -2267.556,
          -2272.32,
          -2276.9829999999997,
          -2281.5460000000003,
          -2286.008,
          -2290.367,
          -2294.623,
          -2298.775,
          -2302.822,
          -2306.764,
          -2310.6,
          -2314.3289999999997,
          -2317.949,
          -2321.4610000000002,
          -2324.864,
          -2328.156,
          -2331.3360000000002,
          -2334.404,
          -2337.359,
          -2340.2,
          -2342.925,
          -2345.535,
          -2348.027,
          -2350.402,
          -2352.657,
          -2354.7929999999997,
          -2356.8070000000002,
          -2358.699,
          -2360.468,
          -2362.113,
          -2363.633,
          -2365.026,
          -2366.291,
          -2367.428,
          -2368.4339999999997,
          -2369.31,
          -2370.053,
          -2370.6620000000003,
          -2371.137,
          -2371.476,
          -2371.677,
          -2371.74,
          -2371.6620000000003,
          -2371.4429999999998,
          -2371.081,
          -2370.575,
          -2369.924,
          -2369.125,
          -2368.177,
          -2367.08,
          -2365.831,
          -2364.428,
          -2362.871,
          -2361.157,
          -2359.285,
          -2357.2529999999997,
          -2355.06,
          -2352.703,
          -2350.181,
          -2347.492,
          -2344.635,
          -2341.606,
          -2338.405,
          -2335.03,
          -2331.4770000000003,
          -2327.746,
          -2323.834,
          -2319.739,
          -2315.459,
          -2310.991,
          -2306.333,
          -2301.484,
          -2296.44,
          -2291.2,
          -2285.76,
          -2280.118,
          -2274.272,
          -2268.218,
          -2261.955,
          -2255.479,
          -2248.788,
          -2241.8779999999997,
          -2234.746,
          -2227.391,
          -2219.8070000000002,
          -2211.993,
          -2203.945,
          -2195.659,
          -2187.133,
          -2178.362,
          -2169.344,
          -2160.073,
          -2150.548,
          -2140.763,
          -2130.714,
          -2120.3979999999997,
          -2109.811,
          -2098.947,
          -2087.804,
          -2076.375,
          -2064.657,
          -2052.645,
          -2040.3329999999999,
          -2027.7160000000001,
          -2014.7910000000002,
          -2001.55,
          -1987.99,
          -1974.1029999999998,
          -1959.884,
          -1945.328,
          -1930.4279999999999,
          -1915.1779999999999,
          -1899.5710000000001,
          -1883.6,
          -1867.259,
          -1850.54,
          -1833.4370000000001,
          -1815.941,
          -1798.045,
          -1779.741,
          -1761.021,
          -1741.875,
          -1722.296,
          -1702.274,
          -1681.799,
          -1660.8629999999998,
          -1639.4560000000001,
          -1617.566,
          -1595.183,
          -1572.2979999999998,
          -1548.898,
          -1524.9720000000002,
          -1500.5079999999998,
          -1475.494,
          -1449.918,
          -1423.766,
          -1397.026,
          -1369.683,
          -1341.724,
          -1313.135,
          -1283.9,
          -1254.006,
          -1223.4360000000001,
          -1192.177,
          -1160.212,
          -1127.525,
          -1094.1019999999999,
          -1059.9260000000002,
          -1024.983,
          -989.2560000000001,
          -952.732,
          -915.395,
          -877.2339999999999,
          -838.235,
          -798.3889999999999,
          -757.686,
          -716.1210000000001,
          -673.688,
          -630.388,
          -586.225,
          -541.206,
          -495.345,
          -448.664,
          -401.19,
          -352.959,
          -304.02,
          -254.43,
          -204.26,
          -153.594,
          -102.529,
          -51.18,
          0.324,
          51.84,
          103.21,
          154.263,
          204.817,
          254.685,
          303.67400000000004,
          351.593,
          398.259,
          443.49699999999996,
          487.14599999999996,
          529.065,
          569.135,
          607.259,
          643.366,
          677.405,
          709.3530000000001,
          739.203,
          766.971,
          792.686,
          816.393,
          838.145,
          858.007,
          876.046,
          892.336,
          906.952,
          919.971,
          931.4689999999999,
          941.5210000000001,
          950.202,
          957.5830000000001,
          963.7310000000001,
          968.7139999999999,
          972.5939999999999,
          975.432,
          977.285,
          978.205,
          978.245,
          977.451,
          975.8710000000001,
          973.545,
          970.515,
          966.818,
          962.4889999999999,
          957.564,
          952.072,
          946.044,
          939.508,
          932.4889999999999,
          925.013,
          917.1030000000001,
          908.7810000000001,
          900.068,
          890.9830000000001,
          881.545,
          871.77,
          861.677,
          851.28,
          840.5930000000001,
          829.632,
          818.409,
          806.937,
          795.227,
          783.291,
          771.14,
          758.784,
          746.232,
          733.493,
          720.577,
          707.492,
          694.2460000000001,
          680.845,
          667.299,
          653.612,
          639.793,
          625.846,
          611.779,
          597.597,
          583.305,
          568.908,
          554.4119999999999,
          539.822,
          525.1419999999999,
          510.376,
          495.529,
          480.605,
          465.60699999999997,
          450.54,
          435.407,
          420.212,
          404.957,
          389.647,
          374.283,
          358.87,
          343.41,
          327.906,
          312.36,
          296.775,
          281.154,
          265.499,
          249.812,
          234.095,
          218.351,
          202.581,
          186.78900000000002,
          170.975,
          155.141,
          139.29,
          123.42299999999999,
          107.542,
          91.649,
          75.745,
          59.831,
          43.91,
          27.982,
          12.049000000000001,
          -3.887,
          -19.825,
          -35.764,
          -51.702,
          -67.639,
          -83.573,
          -99.50299999999999,
          -115.427,
          -131.345,
          -147.256,
          -163.159,
          -179.05200000000002,
          -194.93400000000003,
          -210.805,
          -226.66299999999998,
          -242.50900000000001,
          -258.34,
          -274.155,
          -289.955,
          -305.738,
          -321.503,
          -337.25,
          -352.977,
          -368.685,
          -384.371,
          -400.036,
          -415.67900000000003,
          -431.29900000000004,
          -446.895,
          -462.466,
          -478.01300000000003,
          -493.534,
          -509.029,
          -524.496,
          -539.936,
          -555.3480000000001,
          -570.731,
          -586.085,
          -601.408,
          -616.701,
          -631.9630000000001,
          -647.194,
          -662.3919999999999,
          -677.557,
          -692.689,
          -707.788,
          -722.852,
          -737.8810000000001,
          -752.875,
          -767.8330000000001,
          -782.755,
          -797.64,
          -812.4889999999999,
          -827.299,
          -842.071,
          -856.805,
          -871.4989999999999,
          -886.155,
          -900.77,
          -915.345,
          -929.8789999999999,
          -944.372,
          -958.823,
          -973.232,
          -987.5989999999999,
          -1001.923,
          -1016.204,
          -1030.44,
          -1044.633,
          -1058.782,
          -1072.885,
          -1086.943,
          -1100.9560000000001,
          -1114.922,
          -1128.8419999999999,
          -1142.715,
          -1156.5410000000002,
          -1170.32,
          -1184.05,
          -1197.732,
          -1211.366,
          -1224.95,
          -1238.485,
          -1251.97,
          -1265.405,
          -1278.789,
          -1292.123,
          -1305.405,
          -1318.635,
          -1331.8129999999999,
          -1344.9389999999999,
          -1358.0120000000002,
          -1371.0320000000002,
          -1383.999,
          -1396.912,
          -1409.77,
          -1422.5739999999998,
          -1435.3229999999999,
          -1448.017,
          -1460.655,
          -1473.237,
          -1485.7620000000002,
          -1498.231,
          -1510.6429999999998,
          -1522.997,
          -1535.2939999999999,
          -1547.5320000000002,
          -1559.7120000000002,
          -1571.832,
          -1583.894,
          -1595.896,
          -1607.8370000000002,
          -1619.719,
          -1631.539,
          -1643.2979999999998,
          -1654.996,
          -1666.632,
          -1678.205,
          -1689.7160000000001,
          -1701.164,
          -1712.5479999999998,
          -1723.868,
          -1735.125,
          -1746.316,
          -1757.443,
          -1768.504,
          -1779.499,
          -1790.4279999999999,
          -1801.2910000000002,
          -1812.086,
          -1822.8139999999999,
          -1833.475,
          -1844.067,
          -1854.59,
          -1865.0439999999999,
          -1875.4289999999999,
          -1885.744,
          -1895.9879999999998,
          -1906.162,
          -1916.265,
          -1926.295,
          -1936.254,
          -1946.141,
          -1955.954,
          -1965.694,
          -1975.36,
          -1984.9520000000002,
          -1994.469,
          -2003.91,
          -2013.276,
          -2022.566,
          -2031.779,
          -2040.915,
          -2049.974,
          -2058.9539999999997,
          -2067.856,
          -2076.678,
          -2085.4210000000003,
          -2094.084,
          -2102.666,
          -2111.167,
          -2119.5860000000002,
          -2127.923,
          -2136.178,
          -2144.349,
          -2152.436,
          -2160.439,
          -2168.357,
          -2176.189,
          -2183.935,
          -2191.595,
          -2199.1679999999997,
          -2206.652,
          -2214.048,
          -2221.356,
          -2228.573,
          -2235.7,
          -2242.737,
          -2249.6820000000002,
          -2256.535,
          -2263.295,
          -2269.9610000000002,
          -2276.534,
          -2283.012,
          -2289.394,
          -2295.681,
          -2301.87,
          -2307.962,
          -2313.956,
          -2319.851,
          -2325.646,
          -2331.341,
          -2336.935,
          -2342.426,
          -2347.815,
          -2353.101,
          -2358.283,
          -2363.359,
          -2368.33,
          -2373.194,
          -2377.95,
          -2382.598,
          -2387.137,
          -2391.5660000000003,
          -2395.884,
          -2400.09,
          -2404.183,
          -2408.163,
          -2412.028,
          -2415.778,
          -2419.4120000000003,
          -2422.928,
          -2426.325,
          -2429.603,
          -2432.761,
          -2435.798,
          -2438.712,
          -2441.502,
          -2444.1679999999997,
          -2446.708,
          -2449.121,
          -2451.406,
          -2453.562,
          -2455.5879999999997,
          -2457.482,
          -2459.244,
          -2460.8720000000003,
          -2462.365,
          -2463.721,
          -2464.94,
          -2466.02,
          -2466.959,
          -2467.757,
          -2468.4120000000003,
          -2468.923,
          -2469.2870000000003,
          -2469.505,
          -2469.573,
          -2469.492,
          -2469.258,
          -2468.8720000000003,
          -2468.33,
          -2467.632,
          -2466.776,
          -2465.76,
          -2464.5820000000003,
          -2463.242,
          -2461.736,
          -2460.063,
          -2458.222,
          -2456.2110000000002,
          -2454.027,
          -2451.6679999999997,
          -2449.134,
          -2446.4210000000003,
          -2443.527,
          -2440.451,
          -2437.1910000000003,
          -2433.744,
          -2430.107,
          -2426.28,
          -2422.258,
          -2418.041,
          -2413.625,
          -2409.008,
          -2404.188,
          -2399.1620000000003,
          -2393.927,
          -2388.481,
          -2382.82,
          -2376.9429999999998,
          -2370.846,
          -2364.526,
          -2357.98,
          -2351.205,
          -2344.199,
          -2336.956,
          -2329.476,
          -2321.7529999999997,
          -2313.784,
          -2305.567,
          -2297.097,
          -2288.37,
          -2279.383,
          -2270.132,
          -2260.612,
          -2250.82,
          -2240.751,
          -2230.402,
          -2219.766,
          -2208.841,
          -2197.621,
          -2186.101,
          -2174.277,
          -2162.143,
          -2149.694,
          -2136.924,
          -2123.8289999999997,
          -2110.402,
          -2096.638,
          -2082.53,
          -2068.072,
          -2053.259,
          -2038.0829999999999,
          -2022.537,
          -2006.616,
          -1990.31,
          -1973.614,
          -1956.519,
          -1939.0179999999998,
          -1921.102,
          -1902.763,
          -1883.993,
          -1864.783,
          -1845.1229999999998,
          -1825.004,
          -1804.4170000000001,
          -1783.351,
          -1761.796,
          -1739.741,
          -1717.175,
          -1694.088,
          -1670.467,
          -1646.3,
          -1621.575,
          -1596.279,
          -1570.399,
          -1543.922,
          -1516.832,
          -1489.116,
          -1460.76,
          -1431.747,
          -1402.0629999999999,
          -1371.691,
          -1340.616,
          -1308.8210000000001,
          -1276.289,
          -1243.003,
          -1208.9460000000001,
          -1174.101,
          -1138.4489999999998,
          -1101.975,
          -1064.661,
          -1026.49,
          -987.446,
          -947.515,
          -906.682,
          -864.935,
          -822.262,
          -778.655,
          -734.1080000000001,
          -688.618,
          -642.188,
          -594.8240000000001,
          -546.536,
          -497.347,
          -447.281,
          -396.376,
          -344.67800000000005,
          -292.245,
          -239.148,
          -185.47400000000002,
          -131.322,
          -76.81,
          -22.070999999999998,
          32.746,
          87.47399999999999,
          141.937,
          195.942,
          249.291,
          301.782,
          353.21,
          403.38,
          452.101,
          499.204,
          544.534,
          587.9590000000001,
          629.372,
          668.69,
          705.8580000000001,
          740.8430000000001,
          773.635,
          804.243,
          832.695,
          859.033,
          883.311,
          905.591,
          925.944,
          944.445,
          961.17,
          976.199,
          989.61,
          1001.4810000000001,
          1011.8910000000001,
          1020.9119999999999,
          1028.618,
          1035.077,
          1040.355,
          1044.514,
          1047.617,
          1049.718,
          1050.872,
          1051.13,
          1050.539,
          1049.145,
          1046.99,
          1044.114,
          1040.665,
          1036.349,
          1031.529,
          1026.127,
          1020.173,
          1013.694,
          1006.717,
          999.2669999999999,
          991.367,
          983.04,
          974.306,
          965.185,
          955.696,
          945.8560000000001,
          935.682,
          925.19,
          914.3960000000001,
          903.312,
          891.953,
          880.331,
          868.4580000000001,
          856.347,
          844.007,
          831.449,
          818.684,
          805.721,
          792.568,
          779.2339999999999,
          765.727,
          752.056,
          738.227,
          724.248,
          710.125,
          695.865,
          681.475,
          666.959,
          652.3240000000001,
          637.575,
          622.717,
          607.756,
          592.696,
          577.5419999999999,
          562.298,
          546.9680000000001,
          531.557,
          516.068,
          500.506,
          484.87300000000005,
          469.17400000000004,
          453.411,
          437.589,
          421.709,
          405.776,
          389.792,
          373.759,
          357.681,
          341.56,
          325.399,
          309.2,
          292.966,
          276.698,
          260.399,
          244.071,
          227.717,
          211.33700000000002,
          194.935,
          178.512,
          162.069,
          145.609,
          129.134,
          112.64399999999999,
          96.14200000000001,
          79.63,
          63.108000000000004,
          46.578,
          30.041,
          13.5,
          -3.045,
          -19.592,
          -36.14,
          -52.688,
          -69.234,
          -85.77799999999999,
          -102.318,
          -118.853,
          -135.382,
          -151.903,
          -168.417,
          -184.921,
          -201.415,
          -217.898,
          -234.368,
          -250.826,
          -267.269,
          -283.698,
          -300.111,
          -316.507,
          -332.88599999999997,
          -349.246,
          -365.587,
          -381.909,
          -398.209,
          -414.48900000000003,
          -430.746,
          -446.98,
          -463.191,
          -479.37699999999995,
          -495.538,
          -511.67400000000004,
          -527.784,
          -543.866,
          -559.9209999999999,
          -575.947,
          -591.945,
          -607.913,
          -623.851,
          -639.759,
          -655.635,
          -671.4789999999999,
          -687.2919999999999,
          -703.071,
          -718.816,
          -734.528,
          -750.205,
          -765.847,
          -781.453,
          -797.023,
          -812.557,
          -828.053,
          -843.512,
          -858.932,
          -874.315,
          -889.6569999999999,
          -904.961,
          -920.2239999999999,
          -935.447,
          -950.6289999999999,
          -965.7689999999999,
          -980.868,
          -995.924,
          -1010.938,
          -1025.9080000000001,
          -1040.835,
          -1055.7169999999999,
          -1070.555,
          -1085.348,
          -1100.096,
          -1114.798,
          -1129.454,
          -1144.063,
          -1158.625,
          -1173.139,
          -1187.606,
          -1202.024,
          -1216.394,
          -1230.715,
          -1244.986,
          -1259.2069999999999,
          -1273.378,
          -1287.498,
          -1301.567,
          -1315.585,
          -1329.55,
          -1343.464,
          -1357.3239999999998,
          -1371.132,
          -1384.886,
          -1398.586,
          -1412.2320000000002,
          -1425.8229999999999,
          -1439.359,
          -1452.839,
          -1466.264,
          -1479.632,
          -1492.944,
          -1506.1989999999998,
          -1519.396,
          -1532.536,
          -1545.6170000000002,
          -1558.639,
          -1571.6029999999998,
          -1584.507,
          -1597.351,
          -1610.135,
          -1622.859,
          -1635.521,
          -1648.122,
          -1660.661,
          -1673.138,
          -1685.5520000000001,
          -1697.9029999999998,
          -1710.191,
          -1722.414,
          -1734.5739999999998,
          -1746.6689999999999,
          -1758.6979999999999,
          -1770.662,
          -1782.56,
          -1794.392,
          -1806.1570000000002,
          -1817.855,
          -1829.485,
          -1841.047,
          -1852.54,
          -1863.964,
          -1875.319,
          -1886.604,
          -1897.819,
          -1908.963,
          -1920.035,
          -1931.036,
          -1941.965,
          -1952.8210000000001,
          -1963.605,
          -1974.3139999999999,
          -1984.95,
          -1995.511,
          -2005.997,
          -2016.408,
          -2026.743,
          -2037.001,
          -2047.183,
          -2057.2870000000003,
          -2067.313,
          -2077.261,
          -2087.13,
          -2096.919,
          -2106.6279999999997,
          -2116.257,
          -2125.805,
          -2135.271,
          -2144.655,
          -2153.9570000000003,
          -2163.175,
          -2172.31,
          -2181.36,
          -2190.325,
          -2199.205,
          -2207.999,
          -2216.706,
          -2225.326,
          -2233.8579999999997,
          -2242.301,
          -2250.656,
          -2258.9210000000003,
          -2267.096,
          -2275.179,
          -2283.172,
          -2291.072,
          -2298.879,
          -2306.593,
          -2314.212,
          -2321.737,
          -2329.166,
          -2336.499,
          -2343.735,
          -2350.874,
          -2357.9139999999998,
          -2364.855,
          -2371.696,
          -2378.437,
          -2385.077,
          -2391.614,
          -2398.049,
          -2404.38,
          -2410.607,
          -2416.728,
          -2422.744,
          -2428.653,
          -2434.4539999999997,
          -2440.146,
          -2445.73,
          -2451.203,
          -2456.565,
          -2461.815,
          -2466.952,
          -2471.976,
          -2476.884,
          -2481.677,
          -2486.354,
          -2490.913,
          -2495.353,
          -2499.674,
          -2503.874,
          -2507.953,
          -2511.909,
          -2515.741,
          -2519.449,
          -2523.031,
          -2526.486,
          -2529.813,
          -2533.01,
          -2536.078,
          -2539.014,
          -2541.817,
          -2544.486,
          -2547.021,
          -2549.419,
          -2551.679,
          -2553.8,
          -2555.781,
          -2557.621,
          -2559.317,
          -2560.869,
          -2562.276,
          -2563.535,
          -2564.646,
          -2565.607,
          -2566.416,
          -2567.072,
          -2567.573,
          -2567.9179999999997,
          -2568.106,
          -2568.134,
          -2568,
          -2567.7039999999997,
          -2567.244,
          -2566.617,
          -2565.822,
          -2564.857,
          -2563.72,
          -2562.41,
          -2560.924,
          -2559.26,
          -2557.417,
          -2555.3920000000003,
          -2553.183,
          -2550.788,
          -2548.206,
          -2545.433,
          -2542.467,
          -2539.3070000000002,
          -2535.95,
          -2532.393,
          -2528.633,
          -2524.669,
          -2520.498,
          -2516.117,
          -2511.524,
          -2506.716,
          -2501.69,
          -2496.4429999999998,
          -2490.972,
          -2485.274,
          -2479.347,
          -2473.187,
          -2466.79,
          -2460.155,
          -2453.276,
          -2446.152,
          -2438.777,
          -2431.15,
          -2423.265,
          -2415.12,
          -2406.71,
          -2398.032,
          -2389.08,
          -2379.853,
          -2370.344,
          -2360.549,
          -2350.465,
          -2340.0860000000002,
          -2329.407,
          -2318.425,
          -2307.133,
          -2295.527,
          -2283.601,
          -2271.35,
          -2258.769,
          -2245.851,
          -2232.591,
          -2218.9829999999997,
          -2205.02,
          -2190.697,
          -2176.006,
          -2160.9410000000003,
          -2145.494,
          -2129.659,
          -2113.428,
          -2096.794,
          -2079.748,
          -2062.283,
          -2044.389,
          -2026.059,
          -2007.2839999999999,
          -1988.0539999999999,
          -1968.36,
          -1948.193,
          -1927.5410000000002,
          -1906.395,
          -1884.744,
          -1862.576,
          -1839.882,
          -1816.648,
          -1792.8629999999998,
          -1768.513,
          -1743.5870000000002,
          -1718.0710000000001,
          -1691.95,
          -1665.2120000000002,
          -1637.84,
          -1609.8210000000001,
          -1581.138,
          -1551.776,
          -1521.7179999999998,
          -1490.9470000000001,
          -1459.4470000000001,
          -1427.2,
          -1394.1879999999999,
          -1360.392,
          -1325.795,
          -1290.376,
          -1254.118,
          -1217.001,
          -1179.006,
          -1140.114,
          -1100.307,
          -1059.567,
          -1017.877,
          -975.22,
          -931.582,
          -886.949,
          -841.312,
          -794.6619999999999,
          -746.9939999999999,
          -698.307,
          -648.609,
          -597.908,
          -546.222,
          -493.577,
          -440.00800000000004,
          -385.56199999999995,
          -330.29699999999997,
          -274.285,
          -217.613,
          -160.384,
          -102.719,
          -44.755,
          13.353,
          71.432,
          129.297,
          186.74599999999998,
          243.571,
          299.559,
          354.49300000000005,
          408.164,
          460.37,
          510.92800000000005,
          559.668,
          606.451,
          651.156,
          693.693,
          733.9960000000001,
          772.0239999999999,
          807.765,
          841.221,
          872.418,
          901.3960000000001,
          928.2080000000001,
          952.9169999999999,
          975.5930000000001,
          996.314,
          1015.1569999999999,
          1032.205,
          1047.539,
          1061.24,
          1073.387,
          1084.059,
          1093.3310000000001,
          1101.274,
          1107.9589999999998,
          1113.451,
          1117.812,
          1121.103,
          1123.381,
          1124.698,
          1125.106,
          1124.652,
          1123.38,
          1121.333,
          1118.552,
          1115.0739999999998,
          1110.933,
          1106.165,
          1100.8,
          1094.869,
          1088.3980000000001,
          1081.415,
          1073.945,
          1066.011,
          1057.635,
          1048.838,
          1039.641,
          1030.062,
          1020.118,
          1009.828,
          999.206,
          988.268,
          977.028,
          965.5,
          953.697,
          941.632,
          929.315,
          916.758,
          903.972,
          890.966,
          877.7510000000001,
          864.336,
          850.7289999999999,
          836.939,
          822.9730000000001,
          808.84,
          794.547,
          780.1,
          765.5060000000001,
          750.7710000000001,
          735.903,
          720.9060000000001,
          705.7860000000001,
          690.549,
          675.2,
          659.7439999999999,
          644.185,
          628.528,
          612.778,
          596.938,
          581.014,
          565.008,
          548.925,
          532.768,
          516.54,
          500.246,
          483.88800000000003,
          467.47,
          450.994,
          434.464,
          417.88199999999995,
          401.251,
          384.574,
          367.853,
          351.091,
          334.29,
          317.453,
          300.582,
          283.678,
          266.744,
          249.783,
          232.795,
          215.78400000000002,
          198.75099999999998,
          181.697,
          164.62400000000002,
          147.535,
          130.431,
          113.31299999999999,
          96.18299999999999,
          79.043,
          61.893,
          44.736999999999995,
          27.574,
          10.405999999999999,
          -6.765,
          -23.938000000000002,
          -41.111999999999995,
          -58.285,
          -75.457,
          -92.626,
          -109.791,
          -126.95100000000001,
          -144.105,
          -161.252,
          -178.39,
          -195.519,
          -212.638,
          -229.745,
          -246.84,
          -263.922,
          -280.98900000000003,
          -298.04200000000003,
          -315.079,
          -332.099,
          -349.101,
          -366.085,
          -383.05,
          -399.995,
          -416.91900000000004,
          -433.82099999999997,
          -450.70099999999996,
          -467.55800000000005,
          -484.39099999999996,
          -501.199,
          -517.9830000000001,
          -534.74,
          -551.471,
          -568.174,
          -584.85,
          -601.497,
          -618.115,
          -634.703,
          -651.26,
          -667.7869999999999,
          -684.2810000000001,
          -700.7439999999999,
          -717.173,
          -733.57,
          -749.932,
          -766.26,
          -782.552,
          -798.809,
          -815.03,
          -831.2130000000001,
          -847.36,
          -863.4689999999999,
          -879.539,
          -895.571,
          -911.563,
          -927.5160000000001,
          -943.428,
          -959.299,
          -975.1289999999999,
          -990.9169999999999,
          -1006.663,
          -1022.3660000000001,
          -1038.026,
          -1053.642,
          -1069.214,
          -1084.741,
          -1100.223,
          -1115.6589999999999,
          -1131.05,
          -1146.394,
          -1161.691,
          -1176.94,
          -1192.142,
          -1207.295,
          -1222.4,
          -1237.4560000000001,
          -1252.462,
          -1267.417,
          -1282.323,
          -1297.177,
          -1311.981,
          -1326.7320000000002,
          -1341.431,
          -1356.078,
          -1370.671,
          -1385.211,
          -1399.6970000000001,
          -1414.129,
          -1428.506,
          -1442.828,
          -1457.094,
          -1471.3039999999999,
          -1485.4579999999999,
          -1499.5539999999999,
          -1513.594,
          -1527.575,
          -1541.499,
          -1555.364,
          -1569.17,
          -1582.9160000000002,
          -1596.602,
          -1610.229,
          -1623.7939999999999,
          -1637.2979999999998,
          -1650.741,
          -1664.121,
          -1677.4389999999999,
          -1690.694,
          -1703.886,
          -1717.014,
          -1730.078,
          -1743.0770000000002,
          -1756.011,
          -1768.879,
          -1781.681,
          -1794.4170000000001,
          -1807.086,
          -1819.6879999999999,
          -1832.2220000000002,
          -1844.6870000000001,
          -1857.0839999999998,
          -1869.412,
          -1881.67,
          -1893.8570000000002,
          -1905.974,
          -1918.021,
          -1929.995,
          -1941.898,
          -1953.7279999999998,
          -1965.485,
          -1977.1689999999999,
          -1988.7779999999998,
          -2000.3129999999999,
          -2011.774,
          -2023.158,
          -2034.467,
          -2045.6989999999998,
          -2056.854,
          -2067.9320000000002,
          -2078.9320000000002,
          -2089.853,
          -2100.695,
          -2111.4570000000003,
          -2122.14,
          -2132.741,
          -2143.262,
          -2153.7,
          -2164.056,
          -2174.3289999999997,
          -2184.519,
          -2194.624,
          -2204.645,
          -2214.581,
          -2224.431,
          -2234.194,
          -2243.871,
          -2253.46,
          -2262.96,
          -2272.3720000000003,
          -2281.694,
          -2290.926,
          -2300.0679999999998,
          -2309.118,
          -2318.076,
          -2326.9410000000003,
          -2335.7129999999997,
          -2344.391,
          -2352.974,
          -2361.4610000000002,
          -2369.853,
          -2378.1479999999997,
          -2386.345,
          -2394.444,
          -2402.444,
          -2410.344,
          -2418.144,
          -2425.843,
          -2433.439,
          -2440.933,
          -2448.324,
          -2455.61,
          -2462.791,
          -2469.866,
          -2476.834,
          -2483.695,
          -2490.447,
          -2497.09,
          -2503.623,
          -2510.045,
          -2516.355,
          -2522.552,
          -2528.635,
          -2534.604,
          -2540.4570000000003,
          -2546.194,
          -2551.813,
          -2557.314,
          -2562.695,
          -2567.956,
          -2573.095,
          -2578.112,
          -2583.005,
          -2587.774,
          -2592.416,
          -2596.933,
          -2601.321,
          -2605.58,
          -2609.709,
          -2613.7070000000003,
          -2617.572,
          -2621.303,
          -2624.9,
          -2628.36,
          -2631.683,
          -2634.868,
          -2637.9120000000003,
          -2640.815,
          -2643.5759999999996,
          -2646.192,
          -2648.664,
          -2650.988,
          -2653.164,
          -2655.191,
          -2657.067,
          -2658.79,
          -2660.3579999999997,
          -2661.7709999999997,
          -2663.027,
          -2664.1240000000003,
          -2665.0609999999997,
          -2665.835,
          -2666.446,
          -2666.89,
          -2667.1679999999997,
          -2667.276,
          -2667.2140000000004,
          -2666.9790000000003,
          -2666.5690000000004,
          -2665.982,
          -2665.217,
          -2664.2709999999997,
          -2663.143,
          -2661.83,
          -2660.33,
          -2658.6420000000003,
          -2656.762,
          -2654.688,
          -2652.4190000000003,
          -2649.953,
          -2647.285,
          -2644.415,
          -2641.3390000000004,
          -2638.0559999999996,
          -2634.562,
          -2630.855,
          -2626.9320000000002,
          -2622.7909999999997,
          -2618.428,
          -2613.841,
          -2609.027,
          -2603.982,
          -2598.705,
          -2593.1910000000003,
          -2587.437,
          -2581.44,
          -2575.197,
          -2568.7039999999997,
          -2561.958,
          -2554.955,
          -2547.6910000000003,
          -2540.1620000000003,
          -2532.366,
          -2524.297,
          -2515.951,
          -2507.325,
          -2498.415,
          -2489.214,
          -2479.72,
          -2469.928,
          -2459.8320000000003,
          -2449.428,
          -2438.712,
          -2427.676,
          -2416.3179999999998,
          -2404.63,
          -2392.6079999999997,
          -2380.246,
          -2367.5370000000003,
          -2354.476,
          -2341.0570000000002,
          -2327.2729999999997,
          -2313.118,
          -2298.583,
          -2283.6639999999998,
          -2268.3520000000003,
          -2252.641,
          -2236.522,
          -2219.988,
          -2203.03,
          -2185.641,
          -2167.811,
          -2149.532,
          -2130.794,
          -2111.589,
          -2091.905,
          -2071.734,
          -2051.065,
          -2029.888,
          -2008.19,
          -1985.961,
          -1963.1889999999999,
          -1939.861,
          -1915.9660000000001,
          -1891.49,
          -1866.42,
          -1840.741,
          -1814.441,
          -1787.503,
          -1759.914,
          -1731.6570000000002,
          -1702.7160000000001,
          -1673.0739999999998,
          -1642.715,
          -1611.62,
          -1579.773,
          -1547.154,
          -1513.744,
          -1479.524,
          -1444.473,
          -1408.5729999999999,
          -1371.8029999999999,
          -1334.142,
          -1295.569,
          -1256.0639999999999,
          -1215.605,
          -1174.173,
          -1131.747,
          -1088.309,
          -1043.839,
          -998.321,
          -951.74,
          -904.084,
          -855.342,
          -805.508,
          -754.579,
          -702.558,
          -649.455,
          -595.285,
          -540.073,
          -483.852,
          -426.671,
          -368.586,
          -309.671,
          -250.013,
          -189.71900000000002,
          -128.912,
          -67.733,
          -6.343999999999999,
          55.077,
          116.336,
          177.22299999999998,
          237.519,
          296.999,
          355.435,
          412.60400000000004,
          468.293,
          522.305,
          574.4590000000001,
          624.602,
          672.6030000000001,
          718.3610000000001,
          761.804,
          802.8839999999999,
          841.58,
          877.8919999999999,
          911.842,
          943.4689999999999,
          972.824,
          999.971,
          1024.979,
          1047.9289999999999,
          1068.901,
          1087.9769999999999,
          1105.244,
          1120.782,
          1134.678,
          1147.01,
          1157.858,
          1167.296,
          1175.397,
          1182.229,
          1187.859,
          1192.349,
          1195.759,
          1198.145,
          1199.56,
          1200.053,
          1199.673,
          1198.465,
          1196.469,
          1193.726,
          1190.274,
          1186.1480000000001,
          1181.381,
          1176.003,
          1170.047,
          1163.539,
          1156.505,
          1148.971,
          1140.96,
          1132.495,
          1123.597,
          1114.285,
          1104.579,
          1094.496,
          1084.0539999999999,
          1073.269,
          1062.155,
          1050.728,
          1039.001,
          1026.988,
          1014.7,
          1002.15,
          989.3489999999999,
          976.309,
          963.038,
          949.547,
          935.846,
          921.942,
          907.846,
          893.564,
          879.105,
          864.477,
          849.685,
          834.738,
          819.6410000000001,
          804.4019999999999,
          789.025,
          773.518,
          757.885,
          742.1310000000001,
          726.263,
          710.284,
          694.199,
          678.0139999999999,
          661.732,
          645.3580000000001,
          628.896,
          612.349,
          595.722,
          579.018,
          562.24,
          545.3919999999999,
          528.4780000000001,
          511.5,
          494.462,
          477.366,
          460.215,
          443.01300000000003,
          425.76099999999997,
          408.462,
          391.12,
          373.735,
          356.31199999999995,
          338.851,
          321.356,
          303.827,
          286.269,
          268.681,
          251.067,
          233.428,
          215.767,
          198.084,
          180.382,
          162.662,
          144.92700000000002,
          127.177,
          109.414,
          91.64,
          73.857,
          56.065,
          38.266,
          20.462,
          2.653,
          -15.158,
          -32.971,
          -50.784,
          -68.596,
          -86.406,
          -104.213,
          -122.016,
          -139.813,
          -157.60299999999998,
          -175.386,
          -193.16,
          -210.924,
          -228.678,
          -246.419,
          -264.149,
          -281.86400000000003,
          -299.565,
          -317.251,
          -334.92,
          -352.57199999999995,
          -370.20599999999996,
          -387.82199999999995,
          -405.417,
          -422.99199999999996,
          -440.546,
          -458.07800000000003,
          -475.587,
          -493.07199999999995,
          -510.533,
          -527.969,
          -545.379,
          -562.763,
          -580.12,
          -597.4490000000001,
          -614.749,
          -632.02,
          -649.262,
          -666.472,
          -683.6519999999999,
          -700.8,
          -717.916,
          -734.998,
          -752.048,
          -769.062,
          -786.043,
          -802.987,
          -819.8960000000001,
          -836.7689999999999,
          -853.6039999999999,
          -870.4019999999999,
          -887.1610000000001,
          -903.882,
          -920.564,
          -937.206,
          -953.807,
          -970.368,
          -986.887,
          -1003.3639999999999,
          -1019.799,
          -1036.191,
          -1052.54,
          -1068.844,
          -1085.104,
          -1101.32,
          -1117.489,
          -1133.613,
          -1149.691,
          -1165.721,
          -1181.705,
          -1197.64,
          -1213.527,
          -1229.366,
          -1245.155,
          -1260.894,
          -1276.583,
          -1292.221,
          -1307.808,
          -1323.344,
          -1338.828,
          -1354.2579999999998,
          -1369.636,
          -1384.961,
          -1400.231,
          -1415.4479999999999,
          -1430.609,
          -1445.715,
          -1460.765,
          -1475.759,
          -1490.6970000000001,
          -1505.5770000000002,
          -1520.4,
          -1535.164,
          -1549.871,
          -1564.5179999999998,
          -1579.105,
          -1593.6329999999998,
          -1608.101,
          -1622.5079999999998,
          -1636.8529999999998,
          -1651.1370000000002,
          -1665.359,
          -1679.5179999999998,
          -1693.614,
          -1707.646,
          -1721.615,
          -1735.519,
          -1749.358,
          -1763.131,
          -1776.839,
          -1790.48,
          -1804.0539999999999,
          -1817.5610000000001,
          -1831,
          -1844.371,
          -1857.6729999999998,
          -1870.906,
          -1884.069,
          -1897.162,
          -1910.184,
          -1923.135,
          -1936.014,
          -1948.82,
          -1961.5539999999999,
          -1974.215,
          -1986.8020000000001,
          -1999.315,
          -2011.753,
          -2024.115,
          -2036.402,
          -2048.612,
          -2060.746,
          -2072.802,
          -2084.78,
          -2096.679,
          -2108.5,
          -2120.24,
          -2131.901,
          -2143.481,
          -2154.979,
          -2166.396,
          -2177.73,
          -2188.981,
          -2200.149,
          -2211.232,
          -2222.23,
          -2233.143,
          -2243.971,
          -2254.7110000000002,
          -2265.364,
          -2275.93,
          -2286.406,
          -2296.794,
          -2307.092,
          -2317.3,
          -2327.416,
          -2337.4410000000003,
          -2347.374,
          -2357.2129999999997,
          -2366.959,
          -2376.61,
          -2386.166,
          -2395.627,
          -2404.99,
          -2414.257,
          -2423.425,
          -2432.495,
          -2441.466,
          -2450.3360000000002,
          -2459.106,
          -2467.7729999999997,
          -2476.3379999999997,
          -2484.8,
          -2493.158,
          -2501.411,
          -2509.558,
          -2517.599,
          -2525.533,
          -2533.3579999999997,
          -2541.074,
          -2548.68,
          -2556.176,
          -2563.56,
          -2570.831,
          -2577.989,
          -2585.033,
          -2591.9610000000002,
          -2598.7729999999997,
          -2605.468,
          -2612.045,
          -2618.502,
          -2624.84,
          -2631.0559999999996,
          -2637.15,
          -2643.12,
          -2648.967,
          -2654.688,
          -2660.282,
          -2665.7490000000003,
          -2671.0879999999997,
          -2676.296,
          -2681.3740000000003,
          -2686.3190000000004,
          -2691.132,
          -2695.809,
          -2700.3520000000003,
          -2704.757,
          -2709.0240000000003,
          -2713.151,
          -2717.138,
          -2720.9829999999997,
          -2724.684,
          -2728.241,
          -2731.651,
          -2734.914,
          -2738.028,
          -2740.991,
          -2743.803,
          -2746.461,
          -2748.9640000000004,
          -2751.3109999999997,
          -2753.5,
          -2755.5290000000005,
          -2757.397,
          -2759.1009999999997,
          -2760.6420000000003,
          -2762.0159999999996,
          -2763.222,
          -2764.258,
          -2765.1220000000003,
          -2765.813,
          -2766.328,
          -2766.667,
          -2766.8259999999996,
          -2766.803,
          -2766.598,
          -2766.2070000000003,
          -2765.6290000000004,
          -2764.861,
          -2763.902,
          -2762.7490000000003,
          -2761.3990000000003,
          -2759.8509999999997,
          -2758.1020000000003,
          -2756.15,
          -2753.992,
          -2751.6259999999997,
          -2749.0490000000004,
          -2746.259,
          -2743.2529999999997,
          -2740.028,
          -2736.5809999999997,
          -2732.91,
          -2729.012,
          -2724.883,
          -2720.5209999999997,
          -2715.923,
          -2711.085,
          -2706.0040000000004,
          -2700.677,
          -2695.1,
          -2689.2709999999997,
          -2683.185,
          -2676.8390000000004,
          -2670.2290000000003,
          -2663.3509999999997,
          -2656.202,
          -2648.778,
          -2641.073,
          -2633.085,
          -2624.809,
          -2616.24,
          -2607.374,
          -2598.206,
          -2588.732,
          -2578.946,
          -2568.844,
          -2558.42,
          -2547.67,
          -2536.587,
          -2525.167,
          -2513.403,
          -2501.29,
          -2488.821,
          -2475.991,
          -2462.7929999999997,
          -2449.22,
          -2435.265,
          -2420.922,
          -2406.1839999999997,
          -2391.042,
          -2375.49,
          -2359.52,
          -2343.124,
          -2326.2929999999997,
          -2309.019,
          -2291.292,
          -2273.105,
          -2254.446,
          -2235.308,
          -2215.679,
          -2195.549,
          -2174.909,
          -2153.745,
          -2132.049,
          -2109.8070000000002,
          -2087.007,
          -2063.638,
          -2039.6860000000001,
          -2015.1370000000002,
          -1989.979,
          -1964.195,
          -1937.774,
          -1910.6979999999999,
          -1882.953,
          -1854.521,
          -1825.388,
          -1795.5339999999999,
          -1764.943,
          -1733.596,
          -1701.475,
          -1668.56,
          -1634.832,
          -1600.269,
          -1564.851,
          -1528.558,
          -1491.3670000000002,
          -1453.256,
          -1414.204,
          -1374.1870000000001,
          -1333.183,
          -1291.1689999999999,
          -1248.123,
          -1204.024,
          -1158.85,
          -1112.579,
          -1065.195,
          -1016.68,
          -967.0189999999999,
          -916.199,
          -864.2130000000001,
          -811.055,
          -756.7260000000001,
          -701.2339999999999,
          -644.594,
          -586.8290000000001,
          -527.9730000000001,
          -468.07,
          -407.18,
          -345.375,
          -282.745,
          -219.398,
          -155.461,
          -91.08,
          -26.42,
          38.333,
          102.977,
          167.294,
          231.055,
          294.022,
          355.957,
          416.624,
          475.796,
          533.264,
          588.8330000000001,
          642.34,
          693.643,
          742.6310000000001,
          789.221,
          833.36,
          875.02,
          914.199,
          950.913,
          985.199,
          1017.1080000000001,
          1046.704,
          1074.058,
          1099.248,
          1122.359,
          1143.476,
          1162.6860000000001,
          1180.076,
          1195.73,
          1209.734,
          1222.1680000000001,
          1233.111,
          1242.639,
          1250.822,
          1257.731,
          1263.43,
          1267.982,
          1271.4460000000001,
          1273.878,
          1275.329,
          1275.851,
          1275.489,
          1274.3210000000001,
          1272.29,
          1269.5339999999999,
          1266.058,
          1261.897,
          1257.083,
          1251.6480000000001,
          1245.623,
          1239.0339999999999,
          1231.9080000000001,
          1224.271,
          1216.145,
          1207.553,
          1198.516,
          1189.0539999999999,
          1179.1860000000001,
          1168.931,
          1158.305,
          1147.3239999999998,
          1136.005,
          1124.36,
          1112.406,
          1100.154,
          1087.618,
          1074.809,
          1061.738,
          1048.4180000000001,
          1034.858,
          1021.068,
          1007.058,
          992.836,
          978.4119999999999,
          963.794,
          948.99,
          934.0060000000001,
          918.852,
          903.533,
          888.057,
          872.429,
          856.6569999999999,
          840.745,
          824.7,
          808.5269999999999,
          792.232,
          775.819,
          759.293,
          742.659,
          725.922,
          709.085,
          692.154,
          675.1310000000001,
          658.0219999999999,
          640.8290000000001,
          623.557,
          606.2090000000001,
          588.788,
          571.298,
          553.742,
          536.122,
          518.443,
          500.70599999999996,
          482.914,
          465.07099999999997,
          447.17800000000005,
          429.23900000000003,
          411.256,
          393.23,
          375.166,
          357.064,
          338.926,
          320.756,
          302.555,
          284.325,
          266.068,
          247.78599999999997,
          229.481,
          211.15400000000002,
          192.808,
          174.44299999999998,
          156.062,
          137.666,
          119.257,
          100.837,
          82.406,
          63.966,
          45.519,
          27.066,
          8.607999999999999,
          -9.853,
          -28.316,
          -46.778999999999996,
          -65.243,
          -83.704,
          -102.163,
          -120.617,
          -139.067,
          -157.51,
          -175.946,
          -194.37400000000002,
          -212.792,
          -231.2,
          -249.59599999999998,
          -267.98,
          -286.351,
          -304.707,
          -323.04900000000004,
          -341.374,
          -359.68199999999996,
          -377.972,
          -396.244,
          -414.496,
          -432.727,
          -450.93800000000005,
          -469.126,
          -487.292,
          -505.434,
          -523.552,
          -541.645,
          -559.712,
          -577.752,
          -595.765,
          -613.75,
          -631.707,
          -649.634,
          -667.5310000000001,
          -685.398,
          -703.2330000000001,
          -721.0360000000001,
          -738.806,
          -756.543,
          -774.247,
          -791.915,
          -809.549,
          -827.1469999999999,
          -844.7080000000001,
          -862.2330000000001,
          -879.7189999999999,
          -897.168,
          -914.578,
          -931.949,
          -949.28,
          -966.57,
          -983.82,
          -1001.0269999999999,
          -1018.193,
          -1035.316,
          -1052.396,
          -1069.433,
          -1086.425,
          -1103.372,
          -1120.274,
          -1137.13,
          -1153.94,
          -1170.702,
          -1187.4180000000001,
          -1204.086,
          -1220.705,
          -1237.275,
          -1253.796,
          -1270.267,
          -1286.687,
          -1303.057,
          -1319.375,
          -1335.641,
          -1351.855,
          -1368.015,
          -1384.1229999999998,
          -1400.1760000000002,
          -1416.175,
          -1432.12,
          -1448.009,
          -1463.842,
          -1479.618,
          -1495.338,
          -1511,
          -1526.605,
          -1542.151,
          -1557.639,
          -1573.067,
          -1588.4360000000001,
          -1603.744,
          -1618.991,
          -1634.1779999999999,
          -1649.3020000000001,
          -1664.364,
          -1679.364,
          -1694.3,
          -1709.1729999999998,
          -1723.9820000000002,
          -1738.725,
          -1753.404,
          -1768.017,
          -1782.5639999999999,
          -1797.0439999999999,
          -1811.457,
          -1825.8020000000001,
          -1840.079,
          -1854.2879999999998,
          -1868.4270000000001,
          -1882.496,
          -1896.495,
          -1910.424,
          -1924.281,
          -1938.066,
          -1951.779,
          -1965.4189999999999,
          -1978.986,
          -1992.479,
          -2005.8970000000002,
          -2019.24,
          -2032.5079999999998,
          -2045.6989999999998,
          -2058.814,
          -2071.8520000000003,
          -2084.812,
          -2097.694,
          -2110.496,
          -2123.22,
          -2135.863,
          -2148.426,
          -2160.907,
          -2173.3070000000002,
          -2185.624,
          -2197.8579999999997,
          -2210.009,
          -2222.075,
          -2234.0570000000002,
          -2245.953,
          -2257.764,
          -2269.487,
          -2281.124,
          -2292.672,
          -2304.132,
          -2315.5029999999997,
          -2326.784,
          -2337.974,
          -2349.073,
          -2360.08,
          -2370.995,
          -2381.817,
          -2392.544,
          -2403.177,
          -2413.715,
          -2424.156,
          -2434.501,
          -2444.748,
          -2454.897,
          -2464.948,
          -2474.8979999999997,
          -2484.748,
          -2494.4970000000003,
          -2504.143,
          -2513.687,
          -2523.127,
          -2532.4629999999997,
          -2541.6929999999998,
          -2550.8179999999998,
          -2559.835,
          -2568.745,
          -2577.547,
          -2586.238,
          -2594.82,
          -2603.29,
          -2611.6479999999997,
          -2619.894,
          -2628.025,
          -2636.042,
          -2643.942,
          -2651.7259999999997,
          -2659.3920000000003,
          -2666.94,
          -2674.368,
          -2681.675,
          -2688.861,
          -2695.9240000000004,
          -2702.863,
          -2709.677,
          -2716.365,
          -2722.927,
          -2729.36,
          -2735.664,
          -2741.8379999999997,
          -2747.88,
          -2753.789,
          -2759.565,
          -2765.205,
          -2770.71,
          -2776.0759999999996,
          -2781.304,
          -2786.3920000000003,
          -2791.3390000000004,
          -2796.143,
          -2800.803,
          -2805.3179999999998,
          -2809.6859999999997,
          -2813.906,
          -2817.9759999999997,
          -2821.8959999999997,
          -2825.6620000000003,
          -2829.275,
          -2832.7329999999997,
          -2836.033,
          -2839.175,
          -2842.157,
          -2844.9770000000003,
          -2847.634,
          -2850.125,
          -2852.45,
          -2854.6059999999998,
          -2856.592,
          -2858.405,
          -2860.045,
          -2861.509,
          -2862.795,
          -2863.902,
          -2864.827,
          -2865.5679999999998,
          -2866.1240000000003,
          -2866.492,
          -2866.67,
          -2866.656,
          -2866.448,
          -2866.0440000000003,
          -2865.441,
          -2864.637,
          -2863.6290000000004,
          -2862.4159999999997,
          -2860.995,
          -2859.362,
          -2857.5170000000003,
          -2855.455,
          -2853.1740000000004,
          -2850.672,
          -2847.946,
          -2844.993,
          -2841.81,
          -2838.3940000000002,
          -2834.742,
          -2830.8509999999997,
          -2826.717,
          -2822.3379999999997,
          -2817.71,
          -2812.83,
          -2807.6940000000004,
          -2802.298,
          -2796.64,
          -2790.715,
          -2784.52,
          -2778.05,
          -2771.302,
          -2764.272,
          -2756.955,
          -2749.347,
          -2741.4429999999998,
          -2733.24,
          -2724.7329999999997,
          -2715.9159999999997,
          -2706.785,
          -2697.335,
          -2687.56,
          -2677.4570000000003,
          -2667.018,
          -2656.239,
          -2645.114,
          -2633.636,
          -2621.801,
          -2609.6020000000003,
          -2597.032,
          -2584.085,
          -2570.754,
          -2557.033,
          -2542.913,
          -2528.389,
          -2513.451,
          -2498.093,
          -2482.3070000000002,
          -2466.084,
          -2449.416,
          -2432.294,
          -2414.709,
          -2396.651,
          -2378.112,
          -2359.081,
          -2339.548,
          -2319.502,
          -2298.933,
          -2277.8289999999997,
          -2256.179,
          -2233.97,
          -2211.1910000000003,
          -2187.828,
          -2163.868,
          -2139.299,
          -2114.104,
          -2088.27,
          -2061.782,
          -2034.625,
          -2006.7820000000002,
          -1978.237,
          -1948.9720000000002,
          -1918.97,
          -1888.2120000000002,
          -1856.681,
          -1824.355,
          -1791.2160000000001,
          -1757.243,
          -1722.414,
          -1686.707,
          -1650.102,
          -1612.575,
          -1574.1029999999998,
          -1534.662,
          -1494.2279999999998,
          -1452.777,
          -1410.285,
          -1366.727,
          -1322.079,
          -1276.317,
          -1229.4180000000001,
          -1181.36,
          -1132.122,
          -1081.684,
          -1030.029,
          -977.1439999999999,
          -923.0169999999999,
          -867.6419999999999,
          -811.018,
          -753.1519999999999,
          -694.055,
          -633.75,
          -572.27,
          -509.659,
          -445.976,
          -381.29400000000004,
          -315.704,
          -249.317,
          -182.261,
          -114.68799999999999,
          -46.769,
          21.305999999999997,
          89.32600000000001,
          157.064,
          224.28099999999998,
          290.728,
          356.156,
          420.316,
          482.968,
          543.889,
          602.875,
          659.7460000000001,
          714.352,
          766.571,
          816.313,
          863.5139999999999,
          908.1439999999999,
          950.194,
          989.679,
          1026.631,
          1061.1019999999999,
          1093.154,
          1122.86,
          1150.3,
          1175.558,
          1198.724,
          1219.886,
          1239.134,
          1256.557,
          1272.24,
          1286.269,
          1298.726,
          1309.688,
          1319.2320000000002,
          1327.4279999999999,
          1334.345,
          1340.047,
          1344.598,
          1348.0539999999999,
          1350.471,
          1351.901,
          1352.394,
          1351.995,
          1350.75,
          1348.6979999999999,
          1345.88,
          1342.332,
          1338.089,
          1333.184,
          1327.649,
          1321.5120000000002,
          1314.8010000000002,
          1307.5439999999999,
          1299.764,
          1291.485,
          1282.73,
          1273.52,
          1263.874,
          1253.812,
          1243.3519999999999,
          1232.511,
          1221.305,
          1209.75,
          1197.861,
          1185.651,
          1173.134,
          1160.323,
          1147.23,
          1133.866,
          1120.243,
          1106.37,
          1092.259,
          1077.9189999999999,
          1063.358,
          1048.587,
          1033.612,
          1018.443,
          1003.087,
          987.552,
          971.8439999999999,
          955.971,
          939.939,
          923.7539999999999,
          907.423,
          890.951,
          874.3439999999999,
          857.6080000000001,
          840.7460000000001,
          823.7660000000001,
          806.67,
          789.465,
          772.154,
          754.742,
          737.232,
          719.63,
          701.938,
          684.1610000000001,
          666.302,
          648.365,
          630.3530000000001,
          612.269,
          594.117,
          575.9,
          557.62,
          539.28,
          520.884,
          502.434,
          483.93199999999996,
          465.38199999999995,
          446.785,
          428.144,
          409.462,
          390.74,
          371.981,
          353.18699999999995,
          334.36,
          315.502,
          296.616,
          277.702,
          258.763,
          239.8,
          220.81599999999997,
          201.812,
          182.79,
          163.752,
          144.69799999999998,
          125.631,
          106.552,
          87.463,
          68.365,
          49.25899999999999,
          30.147,
          11.03,
          -8.09,
          -27.212,
          -46.336000000000006,
          -65.459,
          -84.58,
          -103.699,
          -122.814,
          -141.924,
          -161.028,
          -180.12400000000002,
          -199.21200000000002,
          -218.291,
          -237.36,
          -256.41700000000003,
          -275.462,
          -294.494,
          -313.512,
          -332.514,
          -351.5,
          -370.469,
          -389.42,
          -408.352,
          -427.265,
          -446.157,
          -465.028,
          -483.87699999999995,
          -502.702,
          -521.504,
          -540.2819999999999,
          -559.034,
          -577.76,
          -596.46,
          -615.131,
          -633.775,
          -652.389,
          -670.9739999999999,
          -689.528,
          -708.051,
          -726.543,
          -745.002,
          -763.428,
          -781.82,
          -800.177,
          -818.5,
          -836.7860000000001,
          -855.0369999999999,
          -873.25,
          -891.426,
          -909.563,
          -927.6619999999999,
          -945.721,
          -963.74,
          -981.7189999999999,
          -999.6560000000001,
          -1017.551,
          -1035.404,
          -1053.214,
          -1070.981,
          -1088.703,
          -1106.381,
          -1124.013,
          -1141.6,
          -1159.14,
          -1176.634,
          -1194.08,
          -1211.478,
          -1228.827,
          -1246.127,
          -1263.378,
          -1280.579,
          -1297.728,
          -1314.8270000000002,
          -1331.874,
          -1348.869,
          -1365.81,
          -1382.6989999999998,
          -1399.533,
          -1416.3139999999999,
          -1433.039,
          -1449.7089999999998,
          -1466.3229999999999,
          -1482.88,
          -1499.381,
          -1515.8239999999998,
          -1532.2089999999998,
          -1548.535,
          -1564.8020000000001,
          -1581.01,
          -1597.158,
          -1613.245,
          -1629.271,
          -1645.235,
          -1661.1370000000002,
          -1676.977,
          -1692.753,
          -1708.465,
          -1724.1129999999998,
          -1739.6970000000001,
          -1755.215,
          -1770.6670000000001,
          -1786.0529999999999,
          -1801.372,
          -1816.6229999999998,
          -1831.807,
          -1846.922,
          -1861.9679999999998,
          -1876.944,
          -1891.85,
          -1906.6860000000001,
          -1921.45,
          -1936.1429999999998,
          -1950.763,
          -1965.3110000000001,
          -1979.785,
          -1994.185,
          -2008.511,
          -2022.7620000000002,
          -2036.9370000000001,
          -2051.035,
          -2065.0570000000002,
          -2079.002,
          -2092.869,
          -2106.656,
          -2120.365,
          -2133.994,
          -2147.5429999999997,
          -2161.011,
          -2174.3979999999997,
          -2187.702,
          -2200.923,
          -2214.062,
          -2227.116,
          -2240.085,
          -2252.97,
          -2265.768,
          -2278.48,
          -2291.105,
          -2303.6420000000003,
          -2316.091,
          -2328.45,
          -2340.72,
          -2352.899,
          -2364.987,
          -2376.9829999999997,
          -2388.886,
          -2400.697,
          -2412.413,
          -2424.035,
          -2435.561,
          -2446.991,
          -2458.325,
          -2469.561,
          -2480.698,
          -2491.736,
          -2502.675,
          -2513.513,
          -2524.25,
          -2534.884,
          -2545.415,
          -2555.843,
          -2566.166,
          -2576.383,
          -2586.495,
          -2596.499,
          -2606.395,
          -2616.183,
          -2625.861,
          -2635.428,
          -2644.883,
          -2654.2270000000003,
          -2663.4570000000003,
          -2672.573,
          -2681.574,
          -2690.458,
          -2699.2259999999997,
          -2707.8759999999997,
          -2716.407,
          -2724.817,
          -2733.107,
          -2741.275,
          -2749.3190000000004,
          -2757.24,
          -2765.035,
          -2772.704,
          -2780.2459999999996,
          -2787.659,
          -2794.9429999999998,
          -2802.0959999999995,
          -2809.117,
          -2816.005,
          -2822.759,
          -2829.3779999999997,
          -2835.86,
          -2842.204,
          -2848.409,
          -2854.473,
          -2860.3959999999997,
          -2866.175,
          -2871.8109999999997,
          -2877.3,
          -2882.643,
          -2887.837,
          -2892.881,
          -2897.7740000000003,
          -2902.514,
          -2907.1,
          -2911.53,
          -2915.802,
          -2919.9159999999997,
          -2923.87,
          -2927.6609999999996,
          -2931.288,
          -2934.7509999999997,
          -2938.046,
          -2941.172,
          -2944.1279999999997,
          -2946.9109999999996,
          -2949.5209999999997,
          -2951.954,
          -2954.21,
          -2956.285,
          -2958.179,
          -2959.89,
          -2961.414,
          -2962.7509999999997,
          -2963.8979999999997,
          -2964.853,
          -2965.614,
          -2966.178,
          -2966.5440000000003,
          -2966.7090000000003,
          -2966.671,
          -2966.427,
          -2965.975,
          -2965.312,
          -2964.4359999999997,
          -2963.345,
          -2962.035,
          -2960.505,
          -2958.75,
          -2956.7690000000002,
          -2954.559,
          -2952.116,
          -2949.438,
          -2946.522,
          -2943.364,
          -2939.961,
          -2936.3109999999997,
          -2932.409,
          -2928.2529999999997,
          -2923.8390000000004,
          -2919.163,
          -2914.2209999999995,
          -2909.01,
          -2903.527,
          -2897.7670000000003,
          -2891.7259999999997,
          -2885.401,
          -2878.7870000000003,
          -2871.8790000000004,
          -2864.6740000000004,
          -2857.167,
          -2849.3520000000003,
          -2841.2270000000003,
          -2832.785,
          -2824.022,
          -2814.9320000000002,
          -2805.511,
          -2795.7529999999997,
          -2785.652,
          -2775.203,
          -2764.4,
          -2753.237,
          -2741.708,
          -2729.8059999999996,
          -2717.526,
          -2704.86,
          -2691.802,
          -2678.344,
          -2664.4790000000003,
          -2650.2009999999996,
          -2635.5,
          -2620.369,
          -2604.8,
          -2588.786,
          -2572.3160000000003,
          -2555.382,
          -2537.975,
          -2520.0860000000002,
          -2501.7039999999997,
          -2482.819,
          -2463.422,
          -2443.501,
          -2423.045,
          -2402.0429999999997,
          -2380.4829999999997,
          -2358.3520000000003,
          -2335.639,
          -2312.33,
          -2288.411,
          -2263.869,
          -2238.689,
          -2212.856,
          -2186.356,
          -2159.1710000000003,
          -2131.2870000000003,
          -2102.685,
          -2073.348,
          -2043.2579999999998,
          -2012.3970000000002,
          -1980.744,
          -1948.281,
          -1914.986,
          -1880.839,
          -1845.816,
          -1809.8970000000002,
          -1773.058,
          -1735.275,
          -1696.525,
          -1656.7820000000002,
          -1616.021,
          -1574.217,
          -1531.344,
          -1487.375,
          -1442.2839999999999,
          -1396.045,
          -1348.6329999999998,
          -1300.022,
          -1250.1889999999999,
          -1199.108,
          -1146.761,
          -1093.126,
          -1038.188,
          -981.934,
          -924.357,
          -865.453,
          -805.225,
          -743.686,
          -680.855,
          -616.766,
          -551.461,
          -484.99800000000005,
          -417.45300000000003,
          -348.917,
          -279.504,
          -209.34400000000002,
          -138.592,
          -67.425,
          3.96,
          75.345,
          146.495,
          217.16099999999997,
          287.082,
          355.99699999999996,
          423.645,
          489.773,
          554.146,
          616.5459999999999,
          676.783,
          734.694,
          790.1469999999999,
          843.044,
          893.315,
          940.92,
          985.8480000000001,
          1028.109,
          1067.736,
          1104.776,
          1139.2930000000001,
          1171.36,
          1201.058,
          1228.473,
          1253.6960000000001,
          1276.82,
          1297.9360000000001,
          1317.135,
          1334.5079999999998,
          1350.141,
          1364.12,
          1376.527,
          1387.4389999999999,
          1396.931,
          1405.0739999999998,
          1411.9370000000001,
          1417.5810000000001,
          1422.0710000000001,
          1425.4620000000002,
          1427.81,
          1429.1660000000002,
          1429.578,
          1429.0929999999998,
          1427.753,
          1425.601,
          1422.674,
          1419.01,
          1414.642,
          1409.604,
          1403.9260000000002,
          1397.639,
          1390.769,
          1383.342,
          1375.384,
          1366.918,
          1357.9660000000001,
          1348.549,
          1338.6879999999999,
          1328.401,
          1317.7060000000001,
          1306.621,
          1295.162,
          1283.344,
          1271.183,
          1258.692,
          1245.886,
          1232.776,
          1219.375,
          1205.694,
          1191.746,
          1177.54,
          1163.087,
          1148.396,
          1133.476,
          1118.338,
          1102.989,
          1087.437,
          1071.691,
          1055.758,
          1039.645,
          1023.3589999999999,
          1006.9069999999999,
          990.295,
          973.53,
          956.617,
          939.563,
          922.372,
          905.049,
          887.6010000000001,
          870.0319999999999,
          852.347,
          834.55,
          816.6460000000001,
          798.6389999999999,
          780.533,
          762.332,
          744.04,
          725.6610000000001,
          707.198,
          688.655,
          670.035,
          651.342,
          632.5790000000001,
          613.748,
          594.8530000000001,
          575.896,
          556.881,
          537.81,
          518.686,
          499.51099999999997,
          480.288,
          461.019,
          441.70599999999996,
          422.353,
          402.96,
          383.531,
          364.06699999999995,
          344.57,
          325.043,
          305.487,
          285.904,
          266.297,
          246.666,
          227.013,
          207.34099999999998,
          187.65099999999998,
          167.94400000000002,
          148.22299999999998,
          128.488,
          108.741,
          88.984,
          69.218,
          49.445,
          29.666,
          9.882,
          -9.906,
          -29.695999999999998,
          -49.486000000000004,
          -69.27600000000001,
          -89.065,
          -108.85,
          -128.632,
          -148.409,
          -168.179,
          -187.942,
          -207.697,
          -227.442,
          -247.17700000000002,
          -266.9,
          -286.611,
          -306.308,
          -325.991,
          -345.658,
          -365.309,
          -384.94300000000004,
          -404.55800000000005,
          -424.154,
          -443.731,
          -463.286,
          -482.82,
          -502.332,
          -521.82,
          -541.284,
          -560.7230000000001,
          -580.136,
          -599.523,
          -618.882,
          -638.214,
          -657.5160000000001,
          -676.789,
          -696.0319999999999,
          -715.2439999999999,
          -734.424,
          -753.572,
          -772.686,
          -791.7669999999999,
          -810.813,
          -829.825,
          -848.8,
          -867.7389999999999,
          -886.64,
          -905.5039999999999,
          -924.329,
          -943.1160000000001,
          -961.862,
          -980.568,
          -999.2339999999999,
          -1017.857,
          -1036.4389999999999,
          -1054.9769999999999,
          -1073.472,
          -1091.923,
          -1110.33,
          -1128.691,
          -1147.007,
          -1165.276,
          -1183.498,
          -1201.672,
          -1219.799,
          -1237.876,
          -1255.905,
          -1273.883,
          -1291.81,
          -1309.687,
          -1327.513,
          -1345.286,
          -1363.007,
          -1380.674,
          -1398.2879999999998,
          -1415.848,
          -1433.352,
          -1450.8010000000002,
          -1468.194,
          -1485.531,
          -1502.81,
          -1520.0320000000002,
          -1537.195,
          -1554.3,
          -1571.345,
          -1588.3310000000001,
          -1605.256,
          -1622.12,
          -1638.9229999999998,
          -1655.664,
          -1672.342,
          -1688.957,
          -1705.5079999999998,
          -1721.995,
          -1738.4170000000001,
          -1754.774,
          -1771.0639999999999,
          -1787.289,
          -1803.4460000000001,
          -1819.536,
          -1835.558,
          -1851.51,
          -1867.394,
          -1883.2079999999999,
          -1898.951,
          -1914.6229999999998,
          -1930.224,
          -1945.753,
          -1961.2089999999998,
          -1976.592,
          -1991.9,
          -2007.135,
          -2022.2939999999999,
          -2037.378,
          -2052.385,
          -2067.3160000000003,
          -2082.169,
          -2096.945,
          -2111.641,
          -2126.259,
          -2140.7960000000003,
          -2155.2529999999997,
          -2169.629,
          -2183.923,
          -2198.135,
          -2212.264,
          -2226.3089999999997,
          -2240.27,
          -2254.147,
          -2267.937,
          -2281.641,
          -2295.259,
          -2308.7889999999998,
          -2322.231,
          -2335.583,
          -2348.847,
          -2362.02,
          -2375.1020000000003,
          -2388.092,
          -2400.99,
          -2413.795,
          -2426.506,
          -2439.123,
          -2451.644,
          -2464.069,
          -2476.3979999999997,
          -2488.629,
          -2500.762,
          -2512.7960000000003,
          -2524.73,
          -2536.563,
          -2548.295,
          -2559.925,
          -2571.452,
          -2582.875,
          -2594.1929999999998,
          -2605.406,
          -2616.513,
          -2627.513,
          -2638.4040000000005,
          -2649.187,
          -2659.86,
          -2670.422,
          -2680.873,
          -2691.212,
          -2701.437,
          -2711.547,
          -2721.5429999999997,
          -2731.422,
          -2741.184,
          -2750.828,
          -2760.353,
          -2769.757,
          -2779.0409999999997,
          -2788.202,
          -2797.241,
          -2806.1540000000005,
          -2814.9429999999998,
          -2823.605,
          -2832.14,
          -2840.546,
          -2848.822,
          -2856.967,
          -2864.98,
          -2872.861,
          -2880.6059999999998,
          -2888.216,
          -2895.69,
          -2903.025,
          -2910.2209999999995,
          -2917.276,
          -2924.19,
          -2930.96,
          -2937.586,
          -2944.066,
          -2950.3990000000003,
          -2956.583,
          -2962.617,
          -2968.5,
          -2974.2290000000003,
          -2979.805,
          -2985.224,
          -2990.486,
          -2995.5890000000004,
          -3000.531,
          -3005.312,
          -3009.928,
          -3014.3790000000004,
          -3018.663,
          -3022.7790000000005,
          -3026.723,
          -3030.495,
          -3034.094,
          -3037.5159999999996,
          -3040.76,
          -3043.825,
          -3046.708,
          -3049.408,
          -3051.922,
          -3054.248,
          -3056.385,
          -3058.33,
          -3060.0809999999997,
          -3061.636,
          -3062.993,
          -3064.1490000000003,
          -3065.103,
          -3065.8509999999997,
          -3066.3909999999996,
          -3066.722,
          -3066.84,
          -3066.743,
          -3066.428,
          -3065.893,
          -3065.134,
          -3064.15,
          -3062.938,
          -3061.494,
          -3059.816,
          -3057.9,
          -3055.744,
          -3053.345,
          -3050.699,
          -3047.803,
          -3044.653,
          -3041.2470000000003,
          -3037.5809999999997,
          -3033.651,
          -3029.454,
          -3024.986,
          -3020.244,
          -3015.222,
          -3009.9179999999997,
          -3004.327,
          -2998.445,
          -2992.2690000000002,
          -2985.792,
          -2979.012,
          -2971.923,
          -2964.52,
          -2956.8,
          -2948.756,
          -2940.384,
          -2931.68,
          -2922.636,
          -2913.2490000000003,
          -2903.511,
          -2893.4190000000003,
          -2882.965,
          -2872.143,
          -2860.948,
          -2849.3720000000003,
          -2837.41,
          -2825.054,
          -2812.298,
          -2799.134,
          -2785.555,
          -2771.554,
          -2757.1220000000003,
          -2742.2509999999997,
          -2726.934,
          -2711.1609999999996,
          -2694.9240000000004,
          -2678.2140000000004,
          -2661.0209999999997,
          -2643.336,
          -2625.1490000000003,
          -2606.45,
          -2587.2270000000003,
          -2567.471,
          -2547.17,
          -2526.311,
          -2504.884,
          -2482.875,
          -2460.272,
          -2437.062,
          -2413.231,
          -2388.765,
          -2363.649,
          -2337.868,
          -2311.406,
          -2284.248,
          -2256.376,
          -2227.7729999999997,
          -2198.4210000000003,
          -2168.303,
          -2137.3979999999997,
          -2105.687,
          -2073.15,
          -2039.765,
          -2005.5120000000002,
          -1970.3670000000002,
          -1934.307,
          -1897.309,
          -1859.3470000000002,
          -1820.399,
          -1780.4370000000001,
          -1739.4360000000001,
          -1697.368,
          -1654.2060000000001,
          -1609.9229999999998,
          -1564.491,
          -1517.881,
          -1470.066,
          -1421.0179999999998,
          -1370.7089999999998,
          -1319.114,
          -1266.2060000000001,
          -1211.964,
          -1156.365,
          -1099.391,
          -1041.027,
          -981.262,
          -920.0930000000001,
          -857.5210000000001,
          -793.555,
          -728.216,
          -661.533,
          -593.55,
          -524.325,
          -453.934,
          -382.469,
          -310.04400000000004,
          -236.794,
          -162.878,
          -88.476,
          -13.793,
          60.946000000000005,
          135.498,
          209.60299999999998,
          282.991,
          355.38800000000003,
          426.52,
          496.12300000000005,
          563.946,
          629.763,
          693.367,
          754.587,
          813.2810000000001,
          869.3389999999999,
          922.685,
          973.275,
          1021.09,
          1066.139,
          1108.4489999999998,
          1148.07,
          1185.062,
          1219.501,
          1251.468,
          1281.052,
          1308.345,
          1333.441,
          1356.435,
          1377.422,
          1396.495,
          1413.745,
          1429.2579999999998,
          1443.119,
          1455.41,
          1466.2079999999999,
          1475.588,
          1483.619,
          1490.369,
          1495.902,
          1500.277,
          1503.5520000000001,
          1505.78,
          1506.994,
          1507.296,
          1506.6770000000001,
          1505.2,
          1502.9029999999998,
          1499.825,
          1496.004,
          1491.4720000000002,
          1486.2620000000002,
          1480.406,
          1473.931,
          1466.866,
          1459.235,
          1451.065,
          1442.379,
          1433.1989999999998,
          1423.545,
          1413.4379999999999,
          1402.8970000000002,
          1391.94,
          1380.5829999999999,
          1368.845,
          1356.739,
          1344.2820000000002,
          1331.486,
          1318.366,
          1304.934,
          1291.204,
          1277.1860000000001,
          1262.891,
          1248.3310000000001,
          1233.517,
          1218.4560000000001,
          1203.16,
          1187.637,
          1171.896,
          1155.9460000000001,
          1139.7930000000001,
          1123.4460000000001,
          1106.912,
          1090.1989999999998,
          1073.312,
          1056.26,
          1039.047,
          1021.679,
          1004.164,
          986.5060000000001,
          968.711,
          950.784,
          932.7289999999999,
          914.553,
          896.2589999999999,
          877.8530000000001,
          859.3380000000001,
          840.7180000000001,
          821.9989999999999,
          803.183,
          784.2739999999999,
          765.2769999999999,
          746.195,
          727.0310000000001,
          707.789,
          688.472,
          669.0830000000001,
          649.625,
          630.101,
          610.514,
          590.867,
          571.163,
          551.404,
          531.592,
          511.731,
          491.82199999999995,
          471.869,
          451.87300000000005,
          431.836,
          411.76099999999997,
          391.65,
          371.505,
          351.32800000000003,
          331.12,
          310.885,
          290.623,
          270.336,
          250.02700000000002,
          229.697,
          209.347,
          188.98,
          168.597,
          148.19899999999998,
          127.788,
          107.365,
          86.93299999999999,
          66.492,
          46.044,
          25.59,
          5.132000000000001,
          -15.33,
          -35.793,
          -56.257,
          -76.72,
          -97.181,
          -117.639,
          -138.093,
          -158.541,
          -178.983,
          -199.418,
          -219.843,
          -240.25900000000001,
          -260.663,
          -281.056,
          -301.436,
          -321.802,
          -342.154,
          -362.48900000000003,
          -382.80699999999996,
          -403.108,
          -423.39,
          -443.653,
          -463.895,
          -484.116,
          -504.314,
          -524.49,
          -544.641,
          -564.768,
          -584.87,
          -604.945,
          -624.993,
          -645.013,
          -665.0039999999999,
          -684.965,
          -704.8969999999999,
          -724.797,
          -744.666,
          -764.502,
          -784.305,
          -804.074,
          -823.808,
          -843.508,
          -863.171,
          -882.797,
          -902.3860000000001,
          -921.936,
          -941.448,
          -960.921,
          -980.3530000000001,
          -999.745,
          -1019.095,
          -1038.403,
          -1057.6680000000001,
          -1076.89,
          -1096.068,
          -1115.202,
          -1134.29,
          -1153.3319999999999,
          -1172.328,
          -1191.277,
          -1210.178,
          -1229.03,
          -1247.8339999999998,
          -1266.588,
          -1285.292,
          -1303.9460000000001,
          -1322.5479999999998,
          -1341.098,
          -1359.595,
          -1378.04,
          -1396.431,
          -1414.767,
          -1433.049,
          -1451.275,
          -1469.445,
          -1487.559,
          -1505.615,
          -1523.6129999999998,
          -1541.5529999999999,
          -1559.435,
          -1577.256,
          -1595.0179999999998,
          -1612.719,
          -1630.358,
          -1647.9360000000001,
          -1665.451,
          -1682.904,
          -1700.2920000000001,
          -1717.6170000000002,
          -1734.8770000000002,
          -1752.0710000000001,
          -1769.2,
          -1786.2620000000002,
          -1803.257,
          -1820.184,
          -1837.043,
          -1853.8329999999999,
          -1870.5539999999999,
          -1887.205,
          -1903.785,
          -1920.2939999999999,
          -1936.731,
          -1953.095,
          -1969.3870000000002,
          -1985.605,
          -2001.749,
          -2017.817,
          -2033.8110000000001,
          -2049.728,
          -2065.569,
          -2081.3320000000003,
          -2097.0170000000003,
          -2112.624,
          -2128.151,
          -2143.599,
          -2158.966,
          -2174.252,
          -2189.456,
          -2204.578,
          -2219.617,
          -2234.572,
          -2249.4429999999998,
          -2264.228,
          -2278.928,
          -2293.541,
          -2308.067,
          -2322.506,
          -2336.856,
          -2351.116,
          -2365.2870000000003,
          -2379.367,
          -2393.356,
          -2407.2529999999997,
          -2421.0570000000002,
          -2434.768,
          -2448.384,
          -2461.906,
          -2475.331,
          -2488.661,
          -2501.893,
          -2515.026,
          -2528.062,
          -2540.9970000000003,
          -2553.8320000000003,
          -2566.5660000000003,
          -2579.198,
          -2591.7270000000003,
          -2604.153,
          -2616.474,
          -2628.69,
          -2640.7990000000004,
          -2652.802,
          -2664.697,
          -2676.4829999999997,
          -2688.159,
          -2699.725,
          -2711.179,
          -2722.5209999999997,
          -2733.7490000000003,
          -2744.864,
          -2755.863,
          -2766.7459999999996,
          -2777.512,
          -2788.159,
          -2798.688,
          -2809.097,
          -2819.384,
          -2829.55,
          -2839.592,
          -2849.51,
          -2859.302,
          -2868.968,
          -2878.507,
          -2887.917,
          -2897.197,
          -2906.347,
          -2915.364,
          -2924.248,
          -2932.998,
          -2941.613,
          -2950.09,
          -2958.429,
          -2966.6290000000004,
          -2974.6890000000003,
          -2982.6059999999998,
          -2990.381,
          -2998.01,
          -3005.495,
          -3012.8309999999997,
          -3020.02,
          -3027.058,
          -3033.945,
          -3040.679,
          -3047.259,
          -3053.683,
          -3059.95,
          -3066.058,
          -3072.005,
          -3077.79,
          -3083.4120000000003,
          -3088.868,
          -3094.158,
          -3099.278,
          -3104.2290000000003,
          -3109.007,
          -3113.612,
          -3118.0409999999997,
          -3122.292,
          -3126.364,
          -3130.2540000000004,
          -3133.962,
          -3137.4840000000004,
          -3140.8190000000004,
          -3143.9640000000004,
          -3146.9190000000003,
          -3149.68,
          -3152.245,
          -3154.613,
          -3156.781,
          -3158.7459999999996,
          -3160.507,
          -3162.0609999999997,
          -3163.406,
          -3164.539,
          -3165.4570000000003,
          -3166.159,
          -3166.6409999999996,
          -3166.902,
          -3166.937,
          -3166.7459999999996,
          -3166.323,
          -3165.6679999999997,
          -3164.777,
          -3163.6459999999997,
          -3162.2740000000003,
          -3160.656,
          -3158.79,
          -3156.672,
          -3154.2990000000004,
          -3151.6679999999997,
          -3148.775,
          -3145.617,
          -3142.19,
          -3138.49,
          -3134.514,
          -3130.258,
          -3125.717,
          -3120.888,
          -3115.7670000000003,
          -3110.349,
          -3104.63,
          -3098.605,
          -3092.2709999999997,
          -3085.6220000000003,
          -3078.653,
          -3071.36,
          -3063.737,
          -3055.78,
          -3047.4829999999997,
          -3038.841,
          -3029.849,
          -3020.5,
          -3010.788,
          -3000.708,
          -2990.2540000000004,
          -2979.4179999999997,
          -2968.196,
          -2956.579,
          -2944.5609999999997,
          -2932.135,
          -2919.2940000000003,
          -2906.03,
          -2892.335,
          -2878.202,
          -2863.6220000000003,
          -2848.587,
          -2833.0890000000004,
          -2817.117,
          -2800.664,
          -2783.72,
          -2766.2740000000003,
          -2748.3179999999998,
          -2729.8390000000004,
          -2710.829,
          -2691.275,
          -2671.1659999999997,
          -2650.491,
          -2629.237,
          -2607.391,
          -2584.94,
          -2561.873,
          -2538.173,
          -2513.828,
          -2488.822,
          -2463.14,
          -2436.765,
          -2409.6820000000002,
          -2381.874,
          -2353.322,
          -2324.01,
          -2293.917,
          -2263.026,
          -2231.315,
          -2198.763,
          -2165.351,
          -2131.054,
          -2095.851,
          -2059.718,
          -2022.63,
          -1984.5620000000001,
          -1945.49,
          -1905.386,
          -1864.224,
          -1821.974,
          -1778.61,
          -1734.102,
          -1688.421,
          -1641.537,
          -1593.42,
          -1544.04,
          -1493.368,
          -1441.3729999999998,
          -1388.029,
          -1333.308,
          -1277.184,
          -1219.634,
          -1160.637,
          -1100.1760000000002,
          -1038.239,
          -974.819,
          -909.916,
          -843.539,
          -775.704,
          -706.444,
          -635.798,
          -563.826,
          -490.603,
          -416.223,
          -340.801,
          -264.475,
          -187.408,
          -109.785,
          -31.816,
          46.265,
          124.208,
          201.74200000000002,
          278.587,
          354.458,
          429.06699999999995,
          502.139,
          573.41,
          642.638,
          709.6080000000001,
          774.1360000000001,
          836.069,
          895.291,
          951.716,
          1005.2919999999999,
          1055.998,
          1103.837,
          1148.837,
          1191.0439999999999,
          1230.518,
          1267.3339999999998,
          1301.577,
          1333.336,
          1362.705,
          1389.781,
          1414.662,
          1437.445,
          1458.225,
          1477.0970000000002,
          1494.151,
          1509.475,
          1523.1529999999998,
          1535.266,
          1545.889,
          1555.098,
          1562.96,
          1569.5439999999999,
          1574.91,
          1579.12,
          1582.227,
          1584.286,
          1585.3470000000002,
          1585.457,
          1584.661,
          1583.0020000000002,
          1580.5179999999998,
          1577.249,
          1573.231,
          1568.496,
          1563.0770000000002,
          1557.005,
          1550.308,
          1543.013,
          1535.146,
          1526.733,
          1517.795,
          1508.356,
          1498.4360000000001,
          1488.055,
          1477.233,
          1465.986,
          1454.3329999999999,
          1442.289,
          1429.871,
          1417.0929999999998,
          1403.969,
          1390.514,
          1376.739,
          1362.6570000000002,
          1348.281,
          1333.621,
          1318.6879999999999,
          1303.492,
          1288.045,
          1272.354,
          1256.4289999999999,
          1240.28,
          1223.913,
          1207.338,
          1190.563,
          1173.594,
          1156.438,
          1139.103,
          1121.596,
          1103.922,
          1086.088,
          1068.1,
          1049.963,
          1031.683,
          1013.265,
          994.715,
          976.0369999999999,
          957.237,
          938.318,
          919.285,
          900.143,
          880.895,
          861.547,
          842.1010000000001,
          822.561,
          802.932,
          783.216,
          763.418,
          743.54,
          723.585,
          703.558,
          683.46,
          663.295,
          643.066,
          622.776,
          602.427,
          582.0219999999999,
          561.563,
          541.053,
          520.495,
          499.89,
          479.24199999999996,
          458.551,
          437.82199999999995,
          417.055,
          396.25199999999995,
          375.417,
          354.55,
          333.653,
          312.73,
          291.78,
          270.807,
          249.81099999999998,
          228.796,
          207.761,
          186.709,
          165.642,
          144.561,
          123.46700000000001,
          102.363,
          81.249,
          60.126999999999995,
          38.998000000000005,
          17.864,
          -3.2739999999999996,
          -24.415,
          -45.556000000000004,
          -66.69800000000001,
          -87.839,
          -108.977,
          -130.112,
          -151.24200000000002,
          -172.365,
          -193.482,
          -214.59099999999998,
          -235.69,
          -256.779,
          -277.857,
          -298.922,
          -319.973,
          -341.01,
          -362.032,
          -383.037,
          -404.025,
          -424.994,
          -445.944,
          -466.874,
          -487.782,
          -508.66900000000004,
          -529.5319999999999,
          -550.372,
          -571.188,
          -591.977,
          -612.741,
          -633.477,
          -654.185,
          -674.865,
          -695.515,
          -716.1339999999999,
          -736.7230000000001,
          -757.279,
          -777.803,
          -798.294,
          -818.75,
          -839.171,
          -859.557,
          -879.9060000000001,
          -900.2189999999999,
          -920.493,
          -940.7289999999999,
          -960.925,
          -981.082,
          -1001.198,
          -1021.273,
          -1041.306,
          -1061.296,
          -1081.243,
          -1101.146,
          -1121.004,
          -1140.817,
          -1160.5839999999998,
          -1180.3039999999999,
          -1199.9769999999999,
          -1219.6019999999999,
          -1239.1789999999999,
          -1258.7060000000001,
          -1278.184,
          -1297.611,
          -1316.987,
          -1336.3110000000001,
          -1355.5839999999998,
          -1374.8029999999999,
          -1393.9679999999998,
          -1413.079,
          -1432.136,
          -1451.1370000000002,
          -1470.082,
          -1488.97,
          -1507.8010000000002,
          -1526.5739999999998,
          -1545.289,
          -1563.944,
          -1582.54,
          -1601.075,
          -1619.55,
          -1637.963,
          -1656.3139999999999,
          -1674.602,
          -1692.826,
          -1710.987,
          -1729.0829999999999,
          -1747.114,
          -1765.079,
          -1782.977,
          -1800.809,
          -1818.5720000000001,
          -1836.2679999999998,
          -1853.895,
          -1871.4520000000002,
          -1888.9389999999999,
          -1906.355,
          -1923.7,
          -1940.9720000000002,
          -1958.172,
          -1975.299,
          -1992.352,
          -2009.3310000000001,
          -2026.234,
          -2043.0610000000001,
          -2059.812,
          -2076.486,
          -2093.0820000000003,
          -2109.6,
          -2126.038,
          -2142.397,
          -2158.676,
          -2174.873,
          -2190.989,
          -2207.022,
          -2222.973,
          -2238.839,
          -2254.621,
          -2270.3179999999998,
          -2285.929,
          -2301.4539999999997,
          -2316.8920000000003,
          -2332.241,
          -2347.502,
          -2362.673,
          -2377.755,
          -2392.746,
          -2407.645,
          -2422.451,
          -2437.165,
          -2451.785,
          -2466.311,
          -2480.741,
          -2495.075,
          -2509.312,
          -2523.452,
          -2537.493,
          -2551.435,
          -2565.277,
          -2579.018,
          -2592.658,
          -2606.195,
          -2619.629,
          -2632.958,
          -2646.183,
          -2659.301,
          -2672.313,
          -2685.218,
          -2698.013,
          -2710.7,
          -2723.276,
          -2735.741,
          -2748.094,
          -2760.3340000000003,
          -2772.4590000000003,
          -2784.47,
          -2796.365,
          -2808.143,
          -2819.803,
          -2831.344,
          -2842.765,
          -2854.065,
          -2865.244,
          -2876.2990000000004,
          -2887.23,
          -2898.0359999999996,
          -2908.716,
          -2919.2690000000002,
          -2929.6929999999998,
          -2939.987,
          -2950.151,
          -2960.183,
          -2970.0820000000003,
          -2979.847,
          -2989.4770000000003,
          -2998.969,
          -3008.324,
          -3017.54,
          -3026.615,
          -3035.5490000000004,
          -3044.34,
          -3052.986,
          -3061.487,
          -3069.841,
          -3078.046,
          -3086.1020000000003,
          -3094.007,
          -3101.758,
          -3109.3559999999998,
          -3116.798,
          -3124.083,
          -3131.21,
          -3138.177,
          -3144.9809999999998,
          -3151.623,
          -3158.099,
          -3164.409,
          -3170.551,
          -3176.5229999999997,
          -3182.323,
          -3187.95,
          -3193.401,
          -3198.675,
          -3203.7709999999997,
          -3208.685,
          -3213.417,
          -3217.965,
          -3222.325,
          -3226.4970000000003,
          -3230.4790000000003,
          -3234.268,
          -3237.861,
          -3241.258,
          -3244.4559999999997,
          -3247.452,
          -3250.245,
          -3252.8309999999997,
          -3255.2090000000003,
          -3257.3759999999997,
          -3259.33,
          -3261.0690000000004,
          -3262.5890000000004,
          -3263.888,
          -3264.9640000000004,
          -3265.813,
          -3266.434,
          -3266.822,
          -3266.9759999999997,
          -3266.893,
          -3266.5690000000004,
          -3266.002,
          -3265.188,
          -3264.1240000000003,
          -3262.8070000000002,
          -3261.2340000000004,
          -3259.401,
          -3257.305,
          -3254.942,
          -3252.309,
          -3249.402,
          -3246.217,
          -3242.7509999999997,
          -3238.9990000000003,
          -3234.958,
          -3230.623,
          -3225.99,
          -3221.0559999999996,
          -3215.8140000000003,
          -3210.262,
          -3204.3940000000002,
          -3198.205,
          -3191.691,
          -3184.847,
          -3177.6679999999997,
          -3170.1479999999997,
          -3162.281,
          -3154.0640000000003,
          -3145.489,
          -3136.552,
          -3127.2459999999996,
          -3117.5640000000003,
          -3107.502,
          -3097.052,
          -3086.208,
          -3074.9629999999997,
          -3063.31,
          -3051.242,
          -3038.7509999999997,
          -3025.83,
          -3012.4709999999995,
          -2998.667,
          -2984.407,
          -2969.6859999999997,
          -2954.492,
          -2938.8190000000004,
          -2922.655,
          -2905.992,
          -2888.8190000000004,
          -2871.127,
          -2852.905,
          -2834.1420000000003,
          -2814.827,
          -2794.949,
          -2774.494,
          -2753.452,
          -2731.809,
          -2709.552,
          -2686.6690000000003,
          -2663.143,
          -2638.962,
          -2614.111,
          -2588.572,
          -2562.3320000000003,
          -2535.3720000000003,
          -2507.676,
          -2479.226,
          -2450.004,
          -2419.991,
          -2389.166,
          -2357.511,
          -2325.002,
          -2291.62,
          -2257.342,
          -2222.143,
          -2186.001,
          -2148.889,
          -2110.784,
          -2071.659,
          -2031.486,
          -1990.237,
          -1947.885,
          -1904.4,
          -1859.751,
          -1813.9089999999999,
          -1766.8410000000001,
          -1718.5179999999998,
          -1668.906,
          -1617.975,
          -1565.691,
          -1512.025,
          -1456.9470000000001,
          -1400.4260000000002,
          -1342.435,
          -1282.948,
          -1221.942,
          -1159.4,
          -1095.305,
          -1029.65,
          -962.432,
          -893.659,
          -823.347,
          -751.5239999999999,
          -678.232,
          -603.528,
          -527.489,
          -450.21,
          -371.806,
          -292.42,
          -212.217,
          -131.388,
          -50.147,
          31.264,
          112.585,
          193.53799999999998,
          273.83099999999996,
          353.166,
          431.246,
          507.78,
          582.494,
          655.131,
          725.466,
          793.3,
          858.4739999999999,
          920.86,
          980.3660000000001,
          1036.934,
          1090.535,
          1141.171,
          1188.866,
          1233.664,
          1275.628,
          1314.83,
          1351.355,
          1385.297,
          1416.75,
          1445.815,
          1472.59,
          1497.1770000000001,
          1519.6729999999998,
          1540.1760000000002,
          1558.78,
          1575.575,
          1590.648,
          1604.0829999999999,
          1615.9589999999998,
          1626.3529999999998,
          1635.3370000000002,
          1642.979,
          1649.345,
          1654.496,
          1658.4920000000002,
          1661.386,
          1663.2320000000002,
          1664.078,
          1663.9720000000002,
          1662.957,
          1661.076,
          1658.3670000000002,
          1654.869,
          1650.6170000000002,
          1645.6429999999998,
          1639.981,
          1633.66,
          1626.707,
          1619.151,
          1611.017,
          1602.33,
          1593.1129999999998,
          1583.3870000000002,
          1573.1729999999998,
          1562.4920000000002,
          1551.362,
          1539.8,
          1527.826,
          1515.454,
          1502.7,
          1489.579,
          1476.106,
          1462.293,
          1448.155,
          1433.703,
          1418.9489999999998,
          1403.904,
          1388.58,
          1372.987,
          1357.135,
          1341.033,
          1324.69,
          1308.117,
          1291.32,
          1274.308,
          1257.089,
          1239.67,
          1222.06,
          1204.264,
          1186.289,
          1168.142,
          1149.829,
          1131.357,
          1112.73,
          1093.954,
          1075.036,
          1055.98,
          1036.7910000000002,
          1017.4730000000001,
          998.033,
          978.4739999999999,
          958.8,
          939.0169999999999,
          919.127,
          899.135,
          879.046,
          858.862,
          838.587,
          818.225,
          797.78,
          777.2539999999999,
          756.65,
          735.9730000000001,
          715.225,
          694.408,
          673.5260000000001,
          652.582,
          631.578,
          610.5169999999999,
          589.401,
          568.2330000000001,
          547.016,
          525.751,
          504.44199999999995,
          483.09,
          461.69699999999995,
          440.26599999999996,
          418.79900000000004,
          397.29699999999997,
          375.764,
          354.199,
          332.60699999999997,
          310.988,
          289.344,
          267.677,
          245.989,
          224.28099999999998,
          202.55599999999998,
          180.81400000000002,
          159.05700000000002,
          137.287,
          115.506,
          93.714,
          71.913,
          50.106,
          28.291999999999998,
          6.474,
          -15.347999999999999,
          -37.171,
          -58.995,
          -80.819,
          -102.64,
          -124.458,
          -146.27200000000002,
          -168.081,
          -189.88299999999998,
          -211.67700000000002,
          -233.46200000000002,
          -255.237,
          -277.001,
          -298.753,
          -320.491,
          -342.216,
          -363.925,
          -385.61699999999996,
          -407.293,
          -428.95,
          -450.588,
          -472.20599999999996,
          -493.80300000000005,
          -515.378,
          -536.93,
          -558.4580000000001,
          -579.962,
          -601.44,
          -622.891,
          -644.316,
          -665.712,
          -687.079,
          -708.416,
          -729.7230000000001,
          -750.9989999999999,
          -772.242,
          -793.452,
          -814.6289999999999,
          -835.7710000000001,
          -856.877,
          -877.948,
          -898.982,
          -919.9780000000001,
          -940.936,
          -961.855,
          -982.7339999999999,
          -1003.572,
          -1024.37,
          -1045.125,
          -1065.838,
          -1086.508,
          -1107.133,
          -1127.714,
          -1148.249,
          -1168.738,
          -1189.181,
          -1209.575,
          -1229.922,
          -1250.22,
          -1270.469,
          -1290.667,
          -1310.815,
          -1330.911,
          -1350.955,
          -1370.9460000000001,
          -1390.8829999999998,
          -1410.767,
          -1430.596,
          -1450.369,
          -1470.0870000000002,
          -1489.747,
          -1509.351,
          -1528.896,
          -1548.3829999999998,
          -1567.8110000000001,
          -1587.1779999999999,
          -1606.486,
          -1625.7320000000002,
          -1644.9160000000002,
          -1664.037,
          -1683.096,
          -1702.0910000000001,
          -1721.021,
          -1739.8870000000002,
          -1758.6870000000001,
          -1777.42,
          -1796.0870000000002,
          -1814.6860000000001,
          -1833.2160000000001,
          -1851.6779999999999,
          -1870.0710000000001,
          -1888.3929999999998,
          -1906.644,
          -1924.8239999999998,
          -1942.932,
          -1960.967,
          -1978.9279999999999,
          -1996.816,
          -2014.628,
          -2032.366,
          -2050.027,
          -2067.611,
          -2085.118,
          -2102.547,
          -2119.897,
          -2137.1679999999997,
          -2154.3579999999997,
          -2171.468,
          -2188.496,
          -2205.442,
          -2222.305,
          -2239.085,
          -2255.78,
          -2272.39,
          -2288.9139999999998,
          -2305.3520000000003,
          -2321.702,
          -2337.965,
          -2354.139,
          -2370.224,
          -2386.218,
          -2402.1220000000003,
          -2417.9339999999997,
          -2433.654,
          -2449.28,
          -2464.812,
          -2480.25,
          -2495.593,
          -2510.839,
          -2525.988,
          -2541.0389999999998,
          -2555.991,
          -2570.844,
          -2585.597,
          -2600.248,
          -2614.798,
          -2629.244,
          -2643.587,
          -2657.825,
          -2671.958,
          -2685.985,
          -2699.905,
          -2713.716,
          -2727.4190000000003,
          -2741.011,
          -2754.493,
          -2767.863,
          -2781.12,
          -2794.264,
          -2807.2929999999997,
          -2820.2070000000003,
          -2833.0040000000004,
          -2845.683,
          -2858.244,
          -2870.6859999999997,
          -2883.007,
          -2895.2059999999997,
          -2907.282,
          -2919.235,
          -2931.063,
          -2942.7659999999996,
          -2954.341,
          -2965.788,
          -2977.1059999999998,
          -2988.2940000000003,
          -2999.35,
          -3010.2729999999997,
          -3021.062,
          -3031.717,
          -3042.235,
          -3052.616,
          -3062.8579999999997,
          -3072.96,
          -3082.92,
          -3092.738,
          -3102.4120000000003,
          -3111.941,
          -3121.323,
          -3130.5570000000002,
          -3139.6420000000003,
          -3148.5759999999996,
          -3157.3579999999997,
          -3165.987,
          -3174.46,
          -3182.776,
          -3190.934,
          -3198.933,
          -3206.7709999999997,
          -3214.445,
          -3221.955,
          -3229.2990000000004,
          -3236.4759999999997,
          -3243.4829999999997,
          -3250.3190000000004,
          -3256.982,
          -3263.4709999999995,
          -3269.783,
          -3275.917,
          -3281.8709999999996,
          -3287.643,
          -3293.2309999999998,
          -3298.633,
          -3303.847,
          -3308.8720000000003,
          -3313.705,
          -3318.343,
          -3322.7859999999996,
          -3327.031,
          -3331.075,
          -3334.9159999999997,
          -3338.552,
          -3341.9809999999998,
          -3345.2009999999996,
          -3348.2090000000003,
          -3351.002,
          -3353.578,
          -3355.934,
          -3358.0690000000004,
          -3359.978,
          -3361.6609999999996,
          -3363.113,
          -3364.3320000000003,
          -3365.316,
          -3366.06,
          -3366.563,
          -3366.822,
          -3366.8320000000003,
          -3366.592,
          -3366.097,
          -3365.345,
          -3364.3320000000003,
          -3363.055,
          -3361.511,
          -3359.6940000000004,
          -3357.603,
          -3355.2340000000004,
          -3352.5809999999997,
          -3349.643,
          -3346.414,
          -3342.89,
          -3339.0679999999998,
          -3334.9429999999998,
          -3330.511,
          -3325.7659999999996,
          -3320.7059999999997,
          -3315.324,
          -3309.617,
          -3303.579,
          -3297.204,
          -3290.489,
          -3283.428,
          -3276.015,
          -3268.244,
          -3260.111,
          -3251.6079999999997,
          -3242.7309999999998,
          -3233.473,
          -3223.828,
          -3213.788,
          -3203.348,
          -3192.5009999999997,
          -3181.239,
          -3169.555,
          -3157.442,
          -3144.893,
          -3131.8979999999997,
          -3118.45,
          -3104.542,
          -3090.163,
          -3075.3059999999996,
          -3059.96,
          -3044.118,
          -3027.768,
          -3010.902,
          -2993.508,
          -2975.577,
          -2957.097,
          -2938.0559999999996,
          -2918.4440000000004,
          -2898.2490000000003,
          -2877.4570000000003,
          -2856.0559999999996,
          -2834.032,
          -2811.3720000000003,
          -2788.063,
          -2764.0890000000004,
          -2739.435,
          -2714.085,
          -2688.0240000000003,
          -2661.2340000000004,
          -2633.698,
          -2605.399,
          -2576.317,
          -2546.4339999999997,
          -2515.73,
          -2484.183,
          -2451.774,
          -2418.48,
          -2384.277,
          -2349.144,
          -2313.054,
          -2275.984,
          -2237.907,
          -2198.7960000000003,
          -2158.625,
          -2117.364,
          -2074.984,
          -2031.455,
          -1986.747,
          -1940.8270000000002,
          -1893.664,
          -1845.225,
          -1795.477,
          -1744.385,
          -1691.9170000000001,
          -1638.0379999999998,
          -1582.717,
          -1525.92,
          -1467.615,
          -1407.773,
          -1346.3670000000002,
          -1283.371,
          -1218.764,
          -1152.53,
          -1084.6580000000001,
          -1015.143,
          -943.993,
          -871.222,
          -796.855,
          -720.936,
          -643.52,
          -564.684,
          -484.523,
          -403.157,
          -320.728,
          -237.40599999999998,
          -153.385,
          -68.888,
          15.839,
          100.52600000000001,
          184.885,
          268.616,
          351.408,
          432.952,
          512.944,
          591.096,
          667.1419999999999,
          740.841,
          811.9860000000001,
          880.403,
          945.9580000000001,
          1008.55,
          1068.116,
          1124.621,
          1178.0610000000001,
          1228.46,
          1275.86,
          1320.3220000000001,
          1361.92,
          1400.739,
          1436.874,
          1470.422,
          1501.485,
          1530.1660000000002,
          1556.567,
          1580.79,
          1602.935,
          1623.098,
          1641.374,
          1657.8529999999998,
          1672.62,
          1685.759,
          1697.348,
          1707.4620000000002,
          1716.1729999999998,
          1723.5479999999998,
          1729.651,
          1734.543,
          1738.2220000000002,
          1740.921,
          1742.513,
          1743.105,
          1742.744,
          1741.473,
          1739.3329999999999,
          1736.364,
          1732.602,
          1728.082,
          1722.838,
          1716.9,
          1710.2979999999998,
          1703.0610000000001,
          1695.215,
          1686.785,
          1677.797,
          1668.2720000000002,
          1658.233,
          1647.701,
          1636.694,
          1625.233,
          1613.3339999999998,
          1601.015,
          1588.2920000000001,
          1575.182,
          1561.6979999999999,
          1547.855,
          1533.6660000000002,
          1519.145,
          1504.3039999999999,
          1489.154,
          1473.7079999999999,
          1457.976,
          1441.969,
          1425.6960000000001,
          1409.1670000000001,
          1392.392,
          1375.38,
          1358.138,
          1340.6760000000002,
          1323.001,
          1305.12,
          1287.0410000000002,
          1268.772,
          1250.318,
          1231.687,
          1212.884,
          1193.9160000000002,
          1174.789,
          1155.508,
          1136.079,
          1116.508,
          1096.798,
          1076.955,
          1056.985,
          1036.891,
          1016.678,
          996.35,
          975.9119999999999,
          955.368,
          934.721,
          913.9760000000001,
          893.1360000000001,
          872.204,
          851.185,
          830.081,
          808.8960000000001,
          787.6339999999999,
          766.296,
          744.887,
          723.408,
          701.8639999999999,
          680.257,
          658.5889999999999,
          636.863,
          615.082,
          593.248,
          571.364,
          549.431,
          527.453,
          505.43199999999996,
          483.369,
          461.267,
          439.12800000000004,
          416.954,
          394.74699999999996,
          372.509,
          350.24199999999996,
          327.94699999999995,
          305.627,
          283.284,
          260.918,
          238.532,
          216.128,
          193.707,
          171.27,
          148.82,
          126.35700000000001,
          103.884,
          81.40100000000001,
          58.911,
          36.414,
          13.912,
          -8.594,
          -31.101999999999997,
          -53.61,
          -76.119,
          -98.626,
          -121.131,
          -143.631,
          -166.12599999999998,
          -188.615,
          -211.09599999999998,
          -233.56799999999998,
          -256.031,
          -278.483,
          -300.922,
          -323.349,
          -345.76199999999994,
          -368.159,
          -390.54,
          -412.904,
          -435.249,
          -457.57599999999996,
          -479.88199999999995,
          -502.167,
          -524.43,
          -546.67,
          -568.886,
          -591.078,
          -613.243,
          -635.382,
          -657.493,
          -679.576,
          -701.63,
          -723.654,
          -745.6469999999999,
          -767.6080000000001,
          -789.5360000000001,
          -811.431,
          -833.2919999999999,
          -855.117,
          -876.9069999999999,
          -898.6610000000001,
          -920.377,
          -942.055,
          -963.694,
          -985.293,
          -1006.852,
          -1028.369,
          -1049.845,
          -1071.278,
          -1092.6680000000001,
          -1114.013,
          -1135.3139999999999,
          -1156.569,
          -1177.778,
          -1198.94,
          -1220.0539999999999,
          -1241.12,
          -1262.136,
          -1283.103,
          -1304.019,
          -1324.885,
          -1345.6979999999999,
          -1366.4579999999999,
          -1387.1660000000002,
          -1407.819,
          -1428.418,
          -1448.961,
          -1469.4479999999999,
          -1489.879,
          -1510.2520000000002,
          -1530.568,
          -1550.8239999999998,
          -1571.021,
          -1591.1589999999999,
          -1611.235,
          -1631.25,
          -1651.203,
          -1671.094,
          -1690.921,
          -1710.683,
          -1730.382,
          -1750.014,
          -1769.5810000000001,
          -1789.0810000000001,
          -1808.513,
          -1827.878,
          -1847.1729999999998,
          -1866.4,
          -1885.556,
          -1904.641,
          -1923.655,
          -1942.596,
          -1961.465,
          -1980.261,
          -1998.9820000000002,
          -2017.628,
          -2036.1989999999998,
          -2054.6929999999998,
          -2073.11,
          -2091.45,
          -2109.7110000000002,
          -2127.894,
          -2145.996,
          -2164.018,
          -2181.959,
          -2199.8179999999998,
          -2217.594,
          -2235.2870000000003,
          -2252.896,
          -2270.42,
          -2287.8579999999997,
          -2305.21,
          -2322.475,
          -2339.653,
          -2356.742,
          -2373.741,
          -2390.65,
          -2407.469,
          -2424.196,
          -2440.83,
          -2457.3720000000003,
          -2473.819,
          -2490.172,
          -2506.429,
          -2522.59,
          -2538.654,
          -2554.619,
          -2570.486,
          -2586.2529999999997,
          -2601.92,
          -2617.485,
          -2632.948,
          -2648.308,
          -2663.5640000000003,
          -2678.716,
          -2693.761,
          -2708.7009999999996,
          -2723.532,
          -2738.255,
          -2752.869,
          -2767.373,
          -2781.765,
          -2796.045,
          -2810.2129999999997,
          -2824.2659999999996,
          -2838.204,
          -2852.026,
          -2865.7309999999998,
          -2879.3179999999998,
          -2892.7870000000003,
          -2906.135,
          -2919.361,
          -2932.466,
          -2945.448,
          -2958.305,
          -2971.0370000000003,
          -2983.6420000000003,
          -2996.12,
          -3008.469,
          -3020.6890000000003,
          -3032.777,
          -3044.7329999999997,
          -3056.5559999999996,
          -3068.244,
          -3079.796,
          -3091.212,
          -3102.489,
          -3113.6259999999997,
          -3124.623,
          -3135.478,
          -3146.1890000000003,
          -3156.756,
          -3167.177,
          -3177.45,
          -3187.574,
          -3197.5490000000004,
          -3207.3709999999996,
          -3217.0409999999997,
          -3226.5559999999996,
          -3235.915,
          -3245.117,
          -3254.159,
          -3263.0409999999997,
          -3271.761,
          -3280.317,
          -3288.708,
          -3296.9309999999996,
          -3304.986,
          -3312.8709999999996,
          -3320.583,
          -3328.1220000000003,
          -3335.485,
          -3342.671,
          -3349.678,
          -3356.5040000000004,
          -3363.1459999999997,
          -3369.6040000000003,
          -3375.875,
          -3381.9570000000003,
          -3387.848,
          -3393.547,
          -3399.05,
          -3404.357,
          -3409.4640000000004,
          -3414.37,
          -3419.071,
          -3423.567,
          -3427.855,
          -3431.9320000000002,
          -3435.796,
          -3439.445,
          -3442.8759999999997,
          -3446.086,
          -3449.073,
          -3451.8340000000003,
          -3454.367,
          -3456.6690000000003,
          -3458.737,
          -3460.5679999999998,
          -3462.159,
          -3463.508,
          -3464.611,
          -3465.466,
          -3466.0690000000004,
          -3466.4159999999997,
          -3466.506,
          -3466.3340000000003,
          -3465.8959999999997,
          -3465.19,
          -3464.2129999999997,
          -3462.9590000000003,
          -3461.426,
          -3459.61,
          -3457.507,
          -3455.113,
          -3452.423,
          -3449.435,
          -3446.143,
          -3442.5440000000003,
          -3438.632,
          -3434.403,
          -3429.853,
          -3424.978,
          -3419.7709999999997,
          -3414.228,
          -3408.344,
          -3402.114,
          -3395.532,
          -3388.593,
          -3381.2909999999997,
          -3373.62,
          -3365.575,
          -3357.15,
          -3348.3379999999997,
          -3339.133,
          -3329.527,
          -3319.5159999999996,
          -3309.091,
          -3298.245,
          -3286.9709999999995,
          -3275.262,
          -3263.11,
          -3250.506,
          -3237.4429999999998,
          -3223.913,
          -3209.906,
          -3195.413,
          -3180.426,
          -3164.934,
          -3148.929,
          -3132.4,
          -3115.337,
          -3097.728,
          -3079.5640000000003,
          -3060.8320000000003,
          -3041.5209999999997,
          -3021.619,
          -3001.113,
          -2979.99,
          -2958.238,
          -2935.841,
          -2912.7859999999996,
          -2889.058,
          -2864.6420000000003,
          -2839.5229999999997,
          -2813.683,
          -2787.107,
          -2759.776,
          -2731.673,
          -2702.7790000000005,
          -2673.074,
          -2642.539,
          -2611.152,
          -2578.893,
          -2545.74,
          -2511.669,
          -2476.656,
          -2440.677,
          -2403.7070000000003,
          -2365.719,
          -2326.686,
          -2286.581,
          -2245.375,
          -2203.0370000000003,
          -2159.536,
          -2114.843,
          -2068.923,
          -2021.745,
          -1973.274,
          -1923.475,
          -1872.315,
          -1819.756,
          -1765.764,
          -1710.305,
          -1653.3410000000001,
          -1594.839,
          -1534.765,
          -1473.088,
          -1409.777,
          -1344.805,
          -1278.149,
          -1209.79,
          -1139.7169999999999,
          -1067.924,
          -994.413,
          -919.198,
          -842.305,
          -763.7739999999999,
          -683.663,
          -602.0459999999999,
          -519.021,
          -434.707,
          -349.25199999999995,
          -262.827,
          -175.63099999999997,
          -87.89299999999999,
          0.135,
          88.17399999999999,
          175.929,
          263.085,
          349.32300000000004,
          434.32,
          517.762,
          599.347,
          678.795,
          755.8539999999999,
          830.304,
          901.9639999999999,
          970.687,
          1036.366,
          1098.93,
          1158.34,
          1214.589,
          1267.695,
          1317.7,
          1364.665,
          1408.664,
          1449.783,
          1488.115,
          1523.764,
          1556.832,
          1587.425,
          1615.6470000000002,
          1641.604,
          1665.3970000000002,
          1687.1270000000002,
          1706.891,
          1724.7820000000002,
          1740.889,
          1755.297,
          1768.089,
          1779.3410000000001,
          1789.128,
          1797.519,
          1804.5810000000001,
          1810.3770000000002,
          1814.967,
          1818.408,
          1820.751,
          1822.049,
          1822.349,
          1821.6960000000001,
          1820.132,
          1817.6989999999998,
          1814.435,
          1810.375,
          1805.556,
          1800.0079999999998,
          1793.764,
          1786.852,
          1779.3010000000002,
          1771.136,
          1762.384,
          1753.067,
          1743.21,
          1732.8329999999999,
          1721.957,
          1710.601,
          1698.785,
          1686.526,
          1673.842,
          1660.747,
          1647.259,
          1633.392,
          1619.16,
          1604.576,
          1589.654,
          1574.4070000000002,
          1558.845,
          1542.98,
          1526.8239999999998,
          1510.386,
          1493.6779999999999,
          1476.7079999999999,
          1459.486,
          1442.021,
          1424.3210000000001,
          1406.395,
          1388.251,
          1369.896,
          1351.338,
          1332.5829999999999,
          1313.639,
          1294.513,
          1275.21,
          1255.737,
          1236.1,
          1216.3039999999999,
          1196.355,
          1176.259,
          1156.02,
          1135.644,
          1115.135,
          1094.498,
          1073.738,
          1052.859,
          1031.866,
          1010.762,
          989.551,
          968.238,
          946.826,
          925.319,
          903.721,
          882.034,
          860.262,
          838.409,
          816.4780000000001,
          794.471,
          772.3919999999999,
          750.243,
          728.028,
          705.75,
          683.41,
          661.012,
          638.557,
          616.05,
          593.491,
          570.884,
          548.231,
          525.533,
          502.79400000000004,
          480.015,
          457.199,
          434.347,
          411.461,
          388.54400000000004,
          365.597,
          342.62199999999996,
          319.621,
          296.596,
          273.54900000000004,
          250.481,
          227.394,
          204.29,
          181.17,
          158.035,
          134.888,
          111.73,
          88.56200000000001,
          65.38600000000001,
          42.20399999999999,
          19.016,
          -4.176,
          -27.371,
          -50.567,
          -73.763,
          -96.95700000000001,
          -120.149,
          -143.33700000000002,
          -166.52,
          -189.697,
          -212.86599999999999,
          -236.02700000000002,
          -259.178,
          -282.318,
          -305.44599999999997,
          -328.561,
          -351.662,
          -374.74699999999996,
          -397.81699999999995,
          -420.869,
          -443.902,
          -466.917,
          -489.911,
          -512.883,
          -535.8340000000001,
          -558.761,
          -581.664,
          -604.5409999999999,
          -627.393,
          -650.2180000000001,
          -673.015,
          -695.783,
          -718.5219999999999,
          -741.23,
          -763.9060000000001,
          -786.551,
          -809.1619999999999,
          -831.74,
          -854.2819999999999,
          -876.789,
          -899.26,
          -921.693,
          -944.0889999999999,
          -966.445,
          -988.762,
          -1011.039,
          -1033.274,
          -1055.468,
          -1077.618,
          -1099.726,
          -1121.788,
          -1143.806,
          -1165.779,
          -1187.704,
          -1209.583,
          -1231.413,
          -1253.195,
          -1274.927,
          -1296.609,
          -1318.24,
          -1339.819,
          -1361.346,
          -1382.82,
          -1404.241,
          -1425.606,
          -1446.9170000000001,
          -1468.171,
          -1489.369,
          -1510.51,
          -1531.592,
          -1552.616,
          -1573.58,
          -1594.484,
          -1615.328,
          -1636.109,
          -1656.829,
          -1677.485,
          -1698.078,
          -1718.606,
          -1739.069,
          -1759.467,
          -1779.7979999999998,
          -1800.0620000000001,
          -1820.2579999999998,
          -1840.386,
          -1860.444,
          -1880.432,
          -1900.35,
          -1920.1960000000001,
          -1939.97,
          -1959.671,
          -1979.299,
          -1998.852,
          -2018.3310000000001,
          -2037.734,
          -2057.061,
          -2076.31,
          -2095.482,
          -2114.575,
          -2133.5879999999997,
          -2152.522,
          -2171.375,
          -2190.147,
          -2208.8360000000002,
          -2227.442,
          -2245.965,
          -2264.403,
          -2282.756,
          -2301.0229999999997,
          -2319.203,
          -2337.2960000000003,
          -2355.3,
          -2373.215,
          -2391.04,
          -2408.775,
          -2426.4179999999997,
          -2443.969,
          -2461.427,
          -2478.792,
          -2496.061,
          -2513.235,
          -2530.313,
          -2547.2929999999997,
          -2564.176,
          -2580.959,
          -2597.643,
          -2614.2270000000003,
          -2630.7090000000003,
          -2647.0890000000004,
          -2663.365,
          -2679.538,
          -2695.6059999999998,
          -2711.567,
          -2727.423,
          -2743.17,
          -2758.809,
          -2774.3379999999997,
          -2789.757,
          -2805.0640000000003,
          -2820.259,
          -2835.341,
          -2850.308,
          -2865.16,
          -2879.8959999999997,
          -2894.514,
          -2909.014,
          -2923.395,
          -2937.655,
          -2951.7940000000003,
          -2965.81,
          -2979.702,
          -2993.47,
          -3007.112,
          -3020.627,
          -3034.014,
          -3047.272,
          -3060.3990000000003,
          -3073.395,
          -3086.258,
          -3098.987,
          -3111.5809999999997,
          -3124.039,
          -3136.3590000000004,
          -3148.5409999999997,
          -3160.5820000000003,
          -3172.482,
          -3184.239,
          -3195.8520000000003,
          -3207.32,
          -3218.6409999999996,
          -3229.8140000000003,
          -3240.8379999999997,
          -3251.711,
          -3262.4309999999996,
          -3272.998,
          -3283.41,
          -3293.664,
          -3303.761,
          -3313.698,
          -3323.473,
          -3333.086,
          -3342.534,
          -3351.816,
          -3360.93,
          -3369.875,
          -3378.6490000000003,
          -3387.25,
          -3395.676,
          -3403.925,
          -3411.9970000000003,
          -3419.888,
          -3427.598,
          -3435.1240000000003,
          -3442.4640000000004,
          -3449.617,
          -3456.58,
          -3463.3509999999997,
          -3469.929,
          -3476.3109999999997,
          -3482.494,
          -3488.478,
          -3494.26,
          -3499.837,
          -3505.2070000000003,
          -3510.369,
          -3515.3179999999998,
          -3520.054,
          -3524.574,
          -3528.875,
          -3532.954,
          -3536.81,
          -3540.4390000000003,
          -3543.84,
          -3547.008,
          -3549.941,
          -3552.637,
          -3555.093,
          -3557.3059999999996,
          -3559.272,
          -3560.989,
          -3562.453,
          -3563.6609999999996,
          -3564.611,
          -3565.2990000000004,
          -3565.7209999999995,
          -3565.8740000000003,
          -3565.7540000000004,
          -3565.3579999999997,
          -3564.6820000000002,
          -3563.723,
          -3562.4770000000003,
          -3560.9390000000003,
          -3559.105,
          -3556.972,
          -3554.5359999999996,
          -3551.792,
          -3548.735,
          -3545.362,
          -3541.667,
          -3537.6459999999997,
          -3533.2940000000003,
          -3528.607,
          -3523.579,
          -3518.204,
          -3512.4790000000003,
          -3506.397,
          -3499.952,
          -3493.14,
          -3485.954,
          -3478.388,
          -3470.4359999999997,
          -3462.092,
          -3453.349,
          -3444.202,
          -3434.6420000000003,
          -3424.663,
          -3414.258,
          -3403.4190000000003,
          -3392.139,
          -3380.409,
          -3368.223,
          -3355.571,
          -3342.446,
          -3328.8379999999997,
          -3314.738,
          -3300.137,
          -3285.026,
          -3269.395,
          -3253.2340000000004,
          -3236.531,
          -3219.277,
          -3201.461,
          -3183.07,
          -3164.094,
          -3144.5190000000002,
          -3124.3340000000003,
          -3103.525,
          -3082.079,
          -3059.982,
          -3037.219,
          -3013.776,
          -2989.638,
          -2964.789,
          -2939.2129999999997,
          -2912.8920000000003,
          -2885.809,
          -2857.946,
          -2829.284,
          -2799.803,
          -2769.485,
          -2738.3070000000002,
          -2706.248,
          -2673.2859999999996,
          -2639.3979999999997,
          -2604.561,
          -2568.748,
          -2531.935,
          -2494.094,
          -2455.2,
          -2415.223,
          -2374.135,
          -2331.904,
          -2288.501,
          -2243.893,
          -2198.047,
          -2150.929,
          -2102.504,
          -2052.738,
          -2001.594,
          -1949.0339999999999,
          -1895.023,
          -1839.523,
          -1782.496,
          -1723.905,
          -1663.714,
          -1601.8870000000002,
          -1538.389,
          -1473.19,
          -1406.259,
          -1337.57,
          -1267.105,
          -1194.849,
          -1120.7930000000001,
          -1044.9389999999999,
          -967.299,
          -887.898,
          -806.775,
          -723.9860000000001,
          -639.606,
          -553.735,
          -466.494,
          -378.03,
          -288.519,
          -198.166,
          -107.20299999999999,
          -15.89,
          75.488,
          166.622,
          257.192,
          346.865,
          435.30800000000005,
          522.191,
          607.2,
          690.044,
          770.459,
          848.2130000000001,
          923.113,
          995.005,
          1063.771,
          1129.335,
          1191.653,
          1250.714,
          1306.532,
          1359.1470000000002,
          1408.62,
          1455.026,
          1498.45,
          1538.989,
          1576.745,
          1611.825,
          1644.336,
          1674.3870000000002,
          1702.085,
          1727.535,
          1750.84,
          1772.1,
          1791.411,
          1808.865,
          1824.5510000000002,
          1838.5529999999999,
          1850.951,
          1861.8210000000001,
          1871.237,
          1879.265,
          1885.974,
          1891.4229999999998,
          1895.672,
          1898.776,
          1900.787,
          1901.755,
          1901.727,
          1900.747,
          1898.858,
          1896.099,
          1892.507,
          1888.12,
          1882.971,
          1877.0910000000001,
          1870.5120000000002,
          1863.263,
          1855.37,
          1846.861,
          1837.76,
          1828.0910000000001,
          1817.8770000000002,
          1807.138,
          1795.896,
          1784.1689999999999,
          1771.977,
          1759.338,
          1746.267,
          1732.7820000000002,
          1718.8970000000002,
          1704.628,
          1689.989,
          1674.993,
          1659.6529999999998,
          1643.9820000000002,
          1627.9920000000002,
          1611.693,
          1595.098,
          1578.2160000000001,
          1561.058,
          1543.6329999999998,
          1525.951,
          1508.02,
          1489.85,
          1471.4479999999999,
          1452.8229999999999,
          1433.9820000000002,
          1414.933,
          1395.683,
          1376.239,
          1356.6070000000002,
          1336.7939999999999,
          1316.806,
          1296.65,
          1276.33,
          1255.853,
          1235.224,
          1214.448,
          1193.53,
          1172.476,
          1151.289,
          1129.976,
          1108.539,
          1086.983,
          1065.313,
          1043.5330000000001,
          1021.6469999999999,
          999.6569999999999,
          977.569,
          955.3860000000001,
          933.1110000000001,
          910.748,
          888.3,
          865.77,
          843.1610000000001,
          820.477,
          797.721,
          774.895,
          752.0010000000001,
          729.044,
          706.0260000000001,
          682.948,
          659.814,
          636.627,
          613.388,
          590.101,
          566.766,
          543.387,
          519.966,
          496.505,
          473.006,
          449.471,
          425.902,
          402.301,
          378.67,
          355.01099999999997,
          331.32599999999996,
          307.616,
          283.884,
          260.13,
          236.357,
          212.56599999999997,
          188.76,
          164.93900000000002,
          141.105,
          117.259,
          93.404,
          69.541,
          45.67,
          21.794,
          -2.086,
          -25.969,
          -49.853,
          -73.737,
          -97.62,
          -121.5,
          -145.377,
          -169.24900000000002,
          -193.114,
          -216.972,
          -240.821,
          -264.661,
          -288.48900000000003,
          -312.305,
          -336.10900000000004,
          -359.897,
          -383.671,
          -407.42800000000005,
          -431.167,
          -454.88800000000003,
          -478.589,
          -502.27,
          -525.929,
          -549.566,
          -573.178,
          -596.7669999999999,
          -620.3290000000001,
          -643.866,
          -667.375,
          -690.855,
          -714.306,
          -737.7280000000001,
          -761.118,
          -784.4760000000001,
          -807.801,
          -831.0930000000001,
          -854.35,
          -877.572,
          -900.757,
          -923.905,
          -947.0160000000001,
          -970.087,
          -993.1189999999999,
          -1016.1110000000001,
          -1039.0610000000001,
          -1061.969,
          -1084.835,
          -1107.656,
          -1130.434,
          -1153.1660000000002,
          -1175.8519999999999,
          -1198.491,
          -1221.083,
          -1243.627,
          -1266.121,
          -1288.566,
          -1310.96,
          -1333.3029999999999,
          -1355.5929999999998,
          -1377.8310000000001,
          -1400.015,
          -1422.144,
          -1444.219,
          -1466.2379999999998,
          -1488.2,
          -1510.105,
          -1531.9520000000002,
          -1553.739,
          -1575.4679999999998,
          -1597.136,
          -1618.743,
          -1640.289,
          -1661.7720000000002,
          -1683.192,
          -1704.5479999999998,
          -1725.839,
          -1747.065,
          -1768.225,
          -1789.318,
          -1810.3429999999998,
          -1831.3,
          -1852.1879999999999,
          -1873.007,
          -1893.755,
          -1914.431,
          -1935.036,
          -1955.568,
          -1976.026,
          -1996.411,
          -2016.72,
          -2036.954,
          -2057.112,
          -2077.192,
          -2097.194,
          -2117.118,
          -2136.962,
          -2156.7270000000003,
          -2176.41,
          -2196.011,
          -2215.53,
          -2234.966,
          -2254.3179999999998,
          -2273.585,
          -2292.7670000000003,
          -2311.862,
          -2330.87,
          -2349.79,
          -2368.621,
          -2387.363,
          -2406.015,
          -2424.575,
          -2443.0429999999997,
          -2461.419,
          -2479.701,
          -2497.888,
          -2515.98,
          -2533.976,
          -2551.875,
          -2569.676,
          -2587.379,
          -2604.982,
          -2622.4840000000004,
          -2639.885,
          -2657.184,
          -2674.38,
          -2691.472,
          -2708.4590000000003,
          -2725.3390000000004,
          -2742.114,
          -2758.78,
          -2775.3379999999997,
          -2791.7859999999996,
          -2808.1240000000003,
          -2824.35,
          -2840.4629999999997,
          -2856.4640000000004,
          -2872.349,
          -2888.119,
          -2903.7729999999997,
          -2919.309,
          -2934.7259999999997,
          -2950.0240000000003,
          -2965.2009999999996,
          -2980.257,
          -2995.1890000000003,
          -3009.998,
          -3024.6820000000002,
          -3039.239,
          -3053.6690000000003,
          -3067.9709999999995,
          -3082.1440000000002,
          -3096.185,
          -3110.095,
          -3123.8720000000003,
          -3137.514,
          -3151.0209999999997,
          -3164.3909999999996,
          -3177.623,
          -3190.716,
          -3203.6679999999997,
          -3216.478,
          -3229.1459999999997,
          -3241.6679999999997,
          -3254.045,
          -3266.275,
          -3278.3559999999998,
          -3290.2870000000003,
          -3302.067,
          -3313.6940000000004,
          -3325.167,
          -3336.4840000000004,
          -3347.643,
          -3358.6440000000002,
          -3369.4840000000004,
          -3380.163,
          -3390.678,
          -3401.028,
          -3411.212,
          -3421.2259999999997,
          -3431.071,
          -3440.745,
          -3450.244,
          -3459.5690000000004,
          -3468.716,
          -3477.685,
          -3486.473,
          -3495.079,
          -3503.5,
          -3511.7340000000004,
          -3519.781,
          -3527.637,
          -3535.3,
          -3542.77,
          -3550.0429999999997,
          -3557.117,
          -3563.991,
          -3570.6620000000003,
          -3577.1279999999997,
          -3583.386,
          -3589.435,
          -3595.272,
          -3600.8940000000002,
          -3606.3,
          -3611.486,
          -3616.45,
          -3621.19,
          -3625.702,
          -3629.985,
          -3634.0359999999996,
          -3637.8509999999997,
          -3641.429,
          -3644.765,
          -3647.8579999999997,
          -3650.704,
          -3653.3,
          -3655.6440000000002,
          -3657.7309999999998,
          -3659.559,
          -3661.125,
          -3662.4240000000004,
          -3663.454,
          -3664.212,
          -3664.6929999999998,
          -3664.8940000000002,
          -3664.8109999999997,
          -3664.441,
          -3663.7790000000005,
          -3662.822,
          -3661.566,
          -3660.006,
          -3658.138,
          -3655.958,
          -3653.461,
          -3650.6440000000002,
          -3647.5,
          -3644.026,
          -3640.217,
          -3636.0679999999998,
          -3631.573,
          -3626.728,
          -3621.526,
          -3615.9640000000004,
          -3610.034,
          -3603.732,
          -3597.051,
          -3589.985,
          -3582.5290000000005,
          -3574.675,
          -3566.417,
          -3557.7490000000003,
          -3548.664,
          -3539.155,
          -3529.2140000000004,
          -3518.835,
          -3508.008,
          -3496.7270000000003,
          -3484.9840000000004,
          -3472.7690000000002,
          -3460.0759999999996,
          -3446.8940000000002,
          -3433.2140000000004,
          -3419.028,
          -3404.3259999999996,
          -3389.098,
          -3373.3340000000003,
          -3357.0229999999997,
          -3340.1540000000005,
          -3322.717,
          -3304.7,
          -3286.09,
          -3266.8759999999997,
          -3247.046,
          -3226.585,
          -3205.4809999999998,
          -3183.72,
          -3161.2870000000003,
          -3138.167,
          -3114.345,
          -3089.8059999999996,
          -3064.533,
          -3038.508,
          -3011.715,
          -2984.135,
          -2955.75,
          -2926.539,
          -2896.4829999999997,
          -2865.56,
          -2833.75,
          -2801.03,
          -2767.3759999999997,
          -2732.765,
          -2697.172,
          -2660.571,
          -2622.935,
          -2584.237,
          -2544.448,
          -2503.54,
          -2461.482,
          -2418.241,
          -2373.786,
          -2328.084,
          -2281.099,
          -2232.797,
          -2183.1420000000003,
          -2132.096,
          -2079.621,
          -2025.6789999999999,
          -1970.2320000000002,
          -1913.239,
          -1854.662,
          -1794.4620000000002,
          -1732.599,
          -1669.036,
          -1603.737,
          -1536.668,
          -1467.796,
          -1397.096,
          -1324.545,
          -1250.125,
          -1173.827,
          -1095.651,
          -1015.607,
          -933.7189999999999,
          -850.0239999999999,
          -764.578,
          -677.459,
          -588.764,
          -498.615,
          -407.163,
          -314.586,
          -221.09400000000002,
          -126.92299999999999,
          -32.342,
          62.357,
          156.858,
          250.829,
          343.926,
          435.80300000000005,
          526.119,
          614.549,
          700.785,
          784.553,
          865.61,
          943.752,
          1018.814,
          1090.672,
          1159.241,
          1224.473,
          1286.3519999999999,
          1344.889,
          1400.124,
          1452.114,
          1500.934,
          1546.674,
          1589.4279999999999,
          1629.3020000000001,
          1666.4029999999998,
          1700.844,
          1732.733,
          1762.182,
          1789.2979999999998,
          1814.1879999999999,
          1836.953,
          1857.695,
          1876.506,
          1893.479,
          1908.701,
          1922.254,
          1934.217,
          1944.6660000000002,
          1953.672,
          1961.3010000000002,
          1967.5439999999999,
          1972.685,
          1976.558,
          1979.2920000000001,
          1980.9370000000001,
          1981.5420000000001,
          1981.155,
          1979.818,
          1977.5720000000001,
          1974.457,
          1970.511,
          1965.7679999999998,
          1960.261,
          1954.023,
          1947.0829999999999,
          1939.471,
          1931.2120000000002,
          1922.335,
          1912.8629999999998,
          1902.818,
          1892.225,
          1881.104,
          1869.474,
          1857.3570000000002,
          1844.769,
          1831.73,
          1818.254,
          1804.36,
          1790.0610000000001,
          1775.374,
          1760.3110000000001,
          1744.886,
          1729.1129999999998,
          1713.004,
          1696.5710000000001,
          1679.8239999999998,
          1662.776,
          1645.4360000000001,
          1627.815,
          1609.922,
          1591.7679999999998,
          1573.36,
          1554.707,
          1535.819,
          1516.7020000000002,
          1497.365,
          1477.815,
          1458.06,
          1438.106,
          1417.9589999999998,
          1397.628,
          1377.1170000000002,
          1356.432,
          1335.5810000000001,
          1314.568,
          1293.3980000000001,
          1272.078,
          1250.612,
          1229.005,
          1207.263,
          1185.389,
          1163.388,
          1141.264,
          1119.0230000000001,
          1096.6680000000001,
          1074.202,
          1051.631,
          1028.9569999999999,
          1006.185,
          983.317,
          960.3580000000001,
          937.311,
          914.178,
          890.9639999999999,
          867.672,
          844.304,
          820.863,
          797.352,
          773.775,
          750.133,
          726.43,
          702.6669999999999,
          678.8489999999999,
          654.976,
          631.052,
          607.0790000000001,
          583.058,
          558.994,
          534.886,
          510.73900000000003,
          486.55300000000005,
          462.33099999999996,
          438.07599999999996,
          413.788,
          389.469,
          365.12300000000005,
          340.75,
          316.35200000000003,
          291.931,
          267.48900000000003,
          243.028,
          218.549,
          194.054,
          169.544,
          145.02100000000002,
          120.48700000000001,
          95.943,
          71.39,
          46.831,
          22.266,
          -2.3040000000000003,
          -26.875,
          -51.449,
          -76.02199999999999,
          -100.594,
          -125.163,
          -149.72899999999998,
          -174.28900000000002,
          -198.843,
          -223.389,
          -247.92700000000002,
          -272.454,
          -296.971,
          -321.475,
          -345.965,
          -370.441,
          -394.902,
          -419.345,
          -443.77099999999996,
          -468.17800000000005,
          -492.564,
          -516.93,
          -541.274,
          -565.595,
          -589.891,
          -614.163,
          -638.408,
          -662.627,
          -686.818,
          -710.9789999999999,
          -735.1110000000001,
          -759.2130000000001,
          -783.2819999999999,
          -807.319,
          -831.322,
          -855.291,
          -879.225,
          -903.122,
          -926.9830000000001,
          -950.804,
          -974.5880000000001,
          -998.332,
          -1022.0360000000001,
          -1045.698,
          -1069.318,
          -1092.895,
          -1116.4289999999999,
          -1139.917,
          -1163.361,
          -1186.758,
          -1210.107,
          -1233.41,
          -1256.663,
          -1279.867,
          -1303.02,
          -1326.1229999999998,
          -1349.174,
          -1372.172,
          -1395.116,
          -1418.007,
          -1440.8429999999998,
          -1463.622,
          -1486.346,
          -1509.0120000000002,
          -1531.62,
          -1554.1689999999999,
          -1576.6589999999999,
          -1599.088,
          -1621.4560000000001,
          -1643.763,
          -1666.006,
          -1688.1870000000001,
          -1710.3029999999999,
          -1732.354,
          -1754.34,
          -1776.26,
          -1798.112,
          -1819.896,
          -1841.611,
          -1863.2579999999998,
          -1884.8339999999998,
          -1906.338,
          -1927.7720000000002,
          -1949.132,
          -1970.42,
          -1991.6329999999998,
          -2012.7720000000002,
          -2033.835,
          -2054.822,
          -2075.731,
          -2096.563,
          -2117.3160000000003,
          -2137.99,
          -2158.583,
          -2179.095,
          -2199.526,
          -2219.874,
          -2240.138,
          -2260.3179999999998,
          -2280.4139999999998,
          -2300.423,
          -2320.346,
          -2340.1820000000002,
          -2359.929,
          -2379.587,
          -2399.155,
          -2418.632,
          -2438.018,
          -2457.312,
          -2476.512,
          -2495.618,
          -2514.629,
          -2533.544,
          -2552.363,
          -2571.084,
          -2589.706,
          -2608.229,
          -2626.652,
          -2644.974,
          -2663.1940000000004,
          -2681.3109999999997,
          -2699.323,
          -2717.232,
          -2735.034,
          -2752.73,
          -2770.3179999999998,
          -2787.797,
          -2805.167,
          -2822.426,
          -2839.574,
          -2856.6090000000004,
          -2873.531,
          -2890.3379999999997,
          -2907.03,
          -2923.605,
          -2940.063,
          -2956.402,
          -2972.6209999999996,
          -2988.719,
          -3004.696,
          -3020.55,
          -3036.2790000000005,
          -3051.883,
          -3067.361,
          -3082.712,
          -3097.934,
          -3113.026,
          -3127.988,
          -3142.817,
          -3157.513,
          -3172.074,
          -3186.4990000000003,
          -3200.788,
          -3214.938,
          -3228.949,
          -3242.8179999999998,
          -3256.546,
          -3270.13,
          -3283.5690000000004,
          -3296.862,
          -3310.008,
          -3323.005,
          -3335.8509999999997,
          -3348.545,
          -3361.087,
          -3373.473,
          -3385.704,
          -3397.776,
          -3409.69,
          -3421.4429999999998,
          -3433.033,
          -3444.46,
          -3455.7209999999995,
          -3466.815,
          -3477.74,
          -3488.494,
          -3499.077,
          -3509.485,
          -3519.718,
          -3529.7729999999997,
          -3539.6490000000003,
          -3549.344,
          -3558.8559999999998,
          -3568.183,
          -3577.323,
          -3586.275,
          -3595.0359999999996,
          -3603.6040000000003,
          -3611.9770000000003,
          -3620.153,
          -3628.131,
          -3635.907,
          -3643.48,
          -3650.847,
          -3658.006,
          -3664.9559999999997,
          -3671.6929999999998,
          -3678.215,
          -3684.5190000000002,
          -3690.6040000000003,
          -3696.467,
          -3702.105,
          -3707.5159999999996,
          -3712.696,
          -3717.6440000000002,
          -3722.3559999999998,
          -3726.83,
          -3731.063,
          -3735.052,
          -3738.7929999999997,
          -3742.285,
          -3745.5240000000003,
          -3748.506,
          -3751.2290000000003,
          -3753.69,
          -3755.884,
          -3757.809,
          -3759.461,
          -3760.837,
          -3761.933,
          -3762.745,
          -3763.27,
          -3763.5029999999997,
          -3763.441,
          -3763.08,
          -3762.4159999999997,
          -3761.445,
          -3760.1609999999996,
          -3758.562,
          -3756.6420000000003,
          -3754.3959999999997,
          -3751.821,
          -3748.9120000000003,
          -3745.663,
          -3742.0690000000004,
          -3738.1259999999997,
          -3733.828,
          -3729.1690000000003,
          -3724.145,
          -3718.75,
          -3712.9770000000003,
          -3706.821,
          -3700.276,
          -3693.336,
          -3685.993,
          -3678.242,
          -3670.0759999999996,
          -3661.489,
          -3652.4709999999995,
          -3643.018,
          -3633.12,
          -3622.7709999999997,
          -3611.962,
          -3600.6859999999997,
          -3588.934,
          -3576.697,
          -3563.967,
          -3550.735,
          -3536.99,
          -3522.725,
          -3507.927,
          -3492.5890000000004,
          -3476.698,
          -3460.244,
          -3443.216,
          -3425.6020000000003,
          -3407.3909999999996,
          -3388.57,
          -3369.1259999999997,
          -3349.047,
          -3328.3190000000004,
          -3306.927,
          -3284.8590000000004,
          -3262.098,
          -3238.6290000000004,
          -3214.437,
          -3189.505,
          -3163.816,
          -3137.353,
          -3110.097,
          -3082.0290000000005,
          -3053.13,
          -3023.38,
          -2992.757,
          -2961.24,
          -2928.808,
          -2895.437,
          -2861.1009999999997,
          -2825.778,
          -2789.441,
          -2752.062,
          -2713.616,
          -2674.072,
          -2633.401,
          -2591.574,
          -2548.5570000000002,
          -2504.319,
          -2458.825,
          -2412.042,
          -2363.9320000000002,
          -2314.46,
          -2263.587,
          -2211.275,
          -2157.485,
          -2102.176,
          -2045.308,
          -1986.839,
          -1926.7279999999998,
          -1864.934,
          -1801.4160000000002,
          -1736.134,
          -1669.0510000000002,
          -1600.13,
          -1529.336,
          -1456.642,
          -1382.023,
          -1305.458,
          -1226.938,
          -1146.4589999999998,
          -1064.031,
          -979.676,
          -893.43,
          -805.35,
          -715.51,
          -624.009,
          -530.972,
          -436.551,
          -340.92900000000003,
          -244.31599999999997,
          -146.957,
          -49.123999999999995,
          48.88,
          146.732,
          244.08900000000003,
          340.596,
          435.897,
          529.637,
          621.476,
          711.0980000000001,
          798.2139999999999,
          882.57,
          963.95,
          1042.182,
          1117.131,
          1188.7060000000001,
          1256.854,
          1321.5529999999999,
          1382.8139999999999,
          1440.671,
          1495.184,
          1546.424,
          1594.484,
          1639.46,
          1681.4579999999999,
          1720.588,
          1756.964,
          1790.6989999999998,
          1821.905,
          1850.695,
          1877.1770000000001,
          1901.4560000000001,
          1923.635,
          1943.8120000000001,
          1962.079,
          1978.5279999999998,
          1993.244,
          2006.308,
          2017.7979999999998,
          2027.787,
          2036.346,
          2043.54,
          2049.4320000000002,
          2054.081,
          2057.544,
          2059.874,
          2061.121,
          2061.333,
          2060.556,
          2058.831,
          2056.2,
          2052.702,
          2048.3720000000003,
          2043.246,
          2037.356,
          2030.734,
          2023.4089999999999,
          2015.41,
          2006.763,
          1997.494,
          1987.6270000000002,
          1977.1860000000001,
          1966.192,
          1954.6670000000001,
          1942.631,
          1930.1029999999998,
          1917.102,
          1903.6429999999998,
          1889.746,
          1875.425,
          1860.6960000000001,
          1845.5729999999999,
          1830.0710000000001,
          1814.203,
          1797.9820000000002,
          1781.42,
          1764.529,
          1747.3210000000001,
          1729.806,
          1711.996,
          1693.9,
          1675.527,
          1656.889,
          1637.9920000000002,
          1618.8470000000002,
          1599.461,
          1579.842,
          1559.999,
          1539.9389999999999,
          1519.6689999999999,
          1499.1960000000001,
          1478.526,
          1457.6670000000001,
          1436.625,
          1415.405,
          1394.014,
          1372.4579999999999,
          1350.741,
          1328.87,
          1306.849,
          1284.683,
          1262.378,
          1239.938,
          1217.368,
          1194.671,
          1171.853,
          1148.9180000000001,
          1125.869,
          1102.71,
          1079.447,
          1056.0810000000001,
          1032.617,
          1009.058,
          985.408,
          961.67,
          937.847,
          913.943,
          889.96,
          865.9019999999999,
          841.7719999999999,
          817.571,
          793.304,
          768.9730000000001,
          744.58,
          720.128,
          695.62,
          671.057,
          646.443,
          621.78,
          597.071,
          572.316,
          547.519,
          522.682,
          497.806,
          472.894,
          447.94800000000004,
          422.97,
          397.962,
          372.925,
          347.86199999999997,
          322.774,
          297.664,
          272.532,
          247.38,
          222.21099999999998,
          197.02599999999998,
          171.826,
          146.613,
          121.389,
          96.155,
          70.91199999999999,
          45.663000000000004,
          20.408,
          -4.85,
          -30.112,
          -55.373999999999995,
          -80.63600000000001,
          -105.897,
          -131.155,
          -156.409,
          -181.658,
          -206.9,
          -232.13400000000001,
          -257.358,
          -282.573,
          -307.776,
          -332.967,
          -358.14300000000003,
          -383.305,
          -408.45,
          -433.579,
          -458.689,
          -483.78,
          -508.85,
          -533.899,
          -558.925,
          -583.927,
          -608.905,
          -633.8580000000001,
          -658.783,
          -683.682,
          -708.551,
          -733.3910000000001,
          -758.201,
          -782.9780000000001,
          -807.7239999999999,
          -832.436,
          -857.1139999999999,
          -881.757,
          -906.363,
          -930.933,
          -955.4639999999999,
          -979.957,
          -1004.41,
          -1028.823,
          -1053.194,
          -1077.522,
          -1101.808,
          -1126.049,
          -1150.246,
          -1174.397,
          -1198.501,
          -1222.558,
          -1246.567,
          -1270.526,
          -1294.4360000000001,
          -1318.295,
          -1342.102,
          -1365.8570000000002,
          -1389.559,
          -1413.207,
          -1436.8,
          -1460.338,
          -1483.819,
          -1507.243,
          -1530.609,
          -1553.9160000000002,
          -1577.1629999999998,
          -1600.351,
          -1623.477,
          -1646.5410000000002,
          -1669.5420000000001,
          -1692.48,
          -1715.354,
          -1738.162,
          -1760.905,
          -1783.58,
          -1806.1889999999999,
          -1828.729,
          -1851.2,
          -1873.601,
          -1895.932,
          -1918.191,
          -1940.378,
          -1962.4920000000002,
          -1984.5320000000002,
          -2006.497,
          -2028.388,
          -2050.202,
          -2071.938,
          -2093.598,
          -2115.178,
          -2136.679,
          -2158.1,
          -2179.44,
          -2200.698,
          -2221.873,
          -2242.965,
          -2263.973,
          -2284.895,
          -2305.732,
          -2326.481,
          -2347.143,
          -2367.717,
          -2388.201,
          -2408.595,
          -2428.897,
          -2449.1079999999997,
          -2469.2270000000003,
          -2489.251,
          -2509.181,
          -2529.016,
          -2548.754,
          -2568.395,
          -2587.938,
          -2607.382,
          -2626.7259999999997,
          -2645.969,
          -2665.111,
          -2684.15,
          -2703.085,
          -2721.9159999999997,
          -2740.6409999999996,
          -2759.26,
          -2777.7709999999997,
          -2796.1740000000004,
          -2814.468,
          -2832.651,
          -2850.723,
          -2868.6820000000002,
          -2886.528,
          -2904.26,
          -2921.8759999999997,
          -2939.3759999999997,
          -2956.758,
          -2974.0209999999997,
          -2991.165,
          -3008.188,
          -3025.09,
          -3041.868,
          -3058.522,
          -3075.051,
          -3091.454,
          -3107.7290000000003,
          -3123.875,
          -3139.8920000000003,
          -3155.777,
          -3171.531,
          -3187.151,
          -3202.636,
          -3217.985,
          -3233.197,
          -3248.2709999999997,
          -3263.205,
          -3277.998,
          -3292.6490000000003,
          -3307.156,
          -3321.518,
          -3335.7329999999997,
          -3349.801,
          -3363.72,
          -3377.488,
          -3391.1040000000003,
          -3404.567,
          -3417.8740000000003,
          -3431.026,
          -3444.0190000000002,
          -3456.853,
          -3469.526,
          -3482.0359999999996,
          -3494.382,
          -3506.562,
          -3518.575,
          -3530.4190000000003,
          -3542.092,
          -3553.592,
          -3564.9190000000003,
          -3576.0690000000004,
          -3587.0409999999997,
          -3597.8340000000003,
          -3608.446,
          -3618.8740000000003,
          -3629.117,
          -3639.172,
          -3649.039,
          -3658.715,
          -3668.198,
          -3677.485,
          -3686.5759999999996,
          -3695.467,
          -3704.157,
          -3712.643,
          -3720.923,
          -3728.9959999999996,
          -3736.8579999999997,
          -3744.507,
          -3751.941,
          -3759.157,
          -3766.1540000000005,
          -3772.928,
          -3779.4770000000003,
          -3785.7990000000004,
          -3791.8909999999996,
          -3797.7490000000003,
          -3803.3720000000003,
          -3808.757,
          -3813.9,
          -3818.7990000000004,
          -3823.4509999999996,
          -3827.853,
          -3832.002,
          -3835.895,
          -3839.5290000000005,
          -3842.9,
          -3846.005,
          -3848.841,
          -3851.4040000000005,
          -3853.691,
          -3855.698,
          -3857.422,
          -3858.8590000000004,
          -3860.005,
          -3860.8559999999998,
          -3861.408,
          -3861.658,
          -3861.6009999999997,
          -3861.2329999999997,
          -3860.5490000000004,
          -3859.545,
          -3858.218,
          -3856.5609999999997,
          -3854.57,
          -3852.242,
          -3849.5690000000004,
          -3846.5490000000004,
          -3843.1740000000004,
          -3839.441,
          -3835.344,
          -3830.8759999999997,
          -3826.033,
          -3820.809,
          -3815.197,
          -3809.192,
          -3802.7870000000003,
          -3795.9770000000003,
          -3788.7529999999997,
          -3781.11,
          -3773.04,
          -3764.5370000000003,
          -3755.592,
          -3746.2,
          -3736.35,
          -3726.0370000000003,
          -3715.252,
          -3703.986,
          -3692.2309999999998,
          -3679.978,
          -3667.217,
          -3653.94,
          -3640.137,
          -3625.797,
          -3610.9109999999996,
          -3595.468,
          -3579.4570000000003,
          -3562.867,
          -3545.6859999999997,
          -3527.903,
          -3509.505,
          -3490.4790000000003,
          -3470.813,
          -3450.493,
          -3429.5040000000004,
          -3407.8340000000003,
          -3385.465,
          -3362.385,
          -3338.575,
          -3314.0209999999997,
          -3288.704,
          -3262.6079999999997,
          -3235.715,
          -3208.0040000000004,
          -3179.458,
          -3150.055,
          -3119.775,
          -3088.5959999999995,
          -3056.4959999999996,
          -3023.452,
          -2989.4390000000003,
          -2954.433,
          -2918.408,
          -2881.3379999999997,
          -2843.1929999999998,
          -2803.947,
          -2763.5690000000004,
          -2722.028,
          -2679.2929999999997,
          -2635.3309999999997,
          -2590.1079999999997,
          -2543.589,
          -2495.738,
          -2446.5170000000003,
          -2395.888,
          -2343.813,
          -2290.25,
          -2235.159,
          -2178.498,
          -2120.224,
          -2060.295,
          -1998.6660000000002,
          -1935.295,
          -1870.139,
          -1803.1570000000002,
          -1734.307,
          -1663.5510000000002,
          -1590.855,
          -1516.1860000000001,
          -1439.5179999999998,
          -1360.829,
          -1280.105,
          -1197.344,
          -1112.553,
          -1025.751,
          -936.975,
          -846.28,
          -753.74,
          -659.456,
          -563.553,
          -466.185,
          -367.536,
          -267.823,
          -167.295,
          -66.23100000000001,
          35.061,
          136.247,
          236.975,
          336.879,
          435.59,
          532.741,
          627.982,
          720.9810000000001,
          811.438,
          899.087,
          983.702,
          1065.1,
          1143.14,
          1217.722,
          1288.785,
          1356.307,
          1420.293,
          1480.777,
          1537.815,
          1591.4820000000002,
          1641.8670000000002,
          1689.069,
          1733.1970000000001,
          1774.362,
          1812.681,
          1848.2679999999998,
          1881.24,
          1911.7089999999998,
          1939.7910000000002,
          1965.5910000000001,
          1989.215,
          2010.763,
          2030.3339999999998,
          2048.018,
          2063.904,
          2078.076,
          2090.615,
          2101.596,
          2111.09,
          2119.1679999999997,
          2125.893,
          2131.327,
          2135.527,
          2138.55,
          2140.446,
          2141.265,
          2141.055,
          2139.859,
          2137.72,
          2134.677,
          2130.769,
          2126.031,
          2120.496,
          2114.199,
          2107.169,
          2099.436,
          2091.027,
          2081.969,
          2072.2870000000003,
          2062.005,
          2051.147,
          2039.734,
          2027.787,
          2015.325,
          2002.369,
          1988.935,
          1975.0420000000001,
          1960.705,
          1945.942,
          1930.766,
          1915.194,
          1899.237,
          1882.911,
          1866.2279999999998,
          1849.2,
          1831.839,
          1814.1570000000002,
          1796.164,
          1777.871,
          1759.2879999999998,
          1740.425,
          1721.2920000000001,
          1701.896,
          1682.2479999999998,
          1662.355,
          1642.225,
          1621.8670000000002,
          1601.287,
          1580.494,
          1559.493,
          1538.293,
          1516.899,
          1495.318,
          1473.556,
          1451.619,
          1429.5120000000002,
          1407.2420000000002,
          1384.8129999999999,
          1362.231,
          1339.501,
          1316.628,
          1293.617,
          1270.472,
          1247.197,
          1223.798,
          1200.278,
          1176.641,
          1152.892,
          1129.0339999999999,
          1105.0710000000001,
          1081.007,
          1056.845,
          1032.589,
          1008.242,
          983.808,
          959.29,
          934.69,
          910.012,
          885.2589999999999,
          860.433,
          835.539,
          810.577,
          785.552,
          760.465,
          735.32,
          710.118,
          684.863,
          659.556,
          634.2,
          608.797,
          583.35,
          557.86,
          532.33,
          506.76199999999994,
          481.158,
          455.52,
          429.85,
          404.15,
          378.421,
          352.666,
          326.887,
          301.085,
          275.26099999999997,
          249.419,
          223.55900000000003,
          197.68200000000002,
          171.792,
          145.888,
          119.97399999999999,
          94.05,
          68.117,
          42.178000000000004,
          16.234,
          -9.714,
          -35.664,
          -61.615,
          -87.566,
          -113.515,
          -139.461,
          -165.40200000000002,
          -191.338,
          -217.266,
          -243.18599999999998,
          -269.097,
          -294.997,
          -320.88599999999997,
          -346.76099999999997,
          -372.621,
          -398.467,
          -424.296,
          -450.10699999999997,
          -475.899,
          -501.671,
          -527.422,
          -553.151,
          -578.857,
          -604.539,
          -630.195,
          -655.825,
          -681.428,
          -707.002,
          -732.547,
          -758.062,
          -783.545,
          -808.997,
          -834.414,
          -859.798,
          -885.1460000000001,
          -910.459,
          -935.7339999999999,
          -960.971,
          -986.17,
          -1011.328,
          -1036.4460000000001,
          -1061.522,
          -1086.556,
          -1111.546,
          -1136.492,
          -1161.393,
          -1186.248,
          -1211.056,
          -1235.816,
          -1260.527,
          -1285.1889999999999,
          -1309.8010000000002,
          -1334.361,
          -1358.87,
          -1383.325,
          -1407.727,
          -1432.0739999999998,
          -1456.365,
          -1480.601,
          -1504.779,
          -1528.9,
          -1552.961,
          -1576.963,
          -1600.905,
          -1624.786,
          -1648.604,
          -1672.36,
          -1696.0520000000001,
          -1719.6789999999999,
          -1743.2420000000002,
          -1766.7379999999998,
          -1790.1670000000001,
          -1813.5279999999998,
          -1836.8210000000001,
          -1860.045,
          -1883.1979999999999,
          -1906.28,
          -1929.29,
          -1952.2279999999998,
          -1975.092,
          -1997.882,
          -2020.5970000000002,
          -2043.235,
          -2065.797,
          -2088.282,
          -2110.688,
          -2133.014,
          -2155.261,
          -2177.426,
          -2199.51,
          -2221.511,
          -2243.429,
          -2265.262,
          -2287.01,
          -2308.672,
          -2330.2470000000003,
          -2351.734,
          -2373.133,
          -2394.442,
          -2415.66,
          -2436.788,
          -2457.823,
          -2478.765,
          -2499.613,
          -2520.367,
          -2541.024,
          -2561.585,
          -2582.049,
          -2602.413,
          -2622.679,
          -2642.844,
          -2662.908,
          -2682.869,
          -2702.7270000000003,
          -2722.482,
          -2742.131,
          -2761.673,
          -2781.1090000000004,
          -2800.437,
          -2819.656,
          -2838.764,
          -2857.762,
          -2876.647,
          -2895.4190000000003,
          -2914.077,
          -2932.62,
          -2951.046,
          -2969.355,
          -2987.546,
          -3005.617,
          -3023.5679999999998,
          -3041.397,
          -3059.103,
          -3076.685,
          -3094.1420000000003,
          -3111.472,
          -3128.675,
          -3145.75,
          -3162.695,
          -3179.509,
          -3196.19,
          -3212.739,
          -3229.152,
          -3245.43,
          -3261.571,
          -3277.573,
          -3293.435,
          -3309.156,
          -3324.735,
          -3340.17,
          -3355.46,
          -3370.6040000000003,
          -3385.6,
          -3400.446,
          -3415.1420000000003,
          -3429.6859999999997,
          -3444.077,
          -3458.312,
          -3472.39,
          -3486.3109999999997,
          -3500.072,
          -3513.672,
          -3527.1090000000004,
          -3540.382,
          -3553.489,
          -3566.429,
          -3579.199,
          -3591.798,
          -3604.225,
          -3616.4770000000003,
          -3628.553,
          -3640.4509999999996,
          -3652.17,
          -3663.7070000000003,
          -3675.06,
          -3686.228,
          -3697.2090000000003,
          -3708.0009999999997,
          -3718.6009999999997,
          -3729.009,
          -3739.2209999999995,
          -3749.235,
          -3759.051,
          -3768.664,
          -3778.075,
          -3787.2790000000005,
          -3796.275,
          -3805.0609999999997,
          -3813.633,
          -3821.991,
          -3830.131,
          -3838.052,
          -3845.7490000000003,
          -3853.222,
          -3860.467,
          -3867.482,
          -3874.264,
          -3880.8109999999997,
          -3887.119,
          -3893.1859999999997,
          -3899.01,
          -3904.586,
          -3909.9120000000003,
          -3914.986,
          -3919.804,
          -3924.362,
          -3928.658,
          -3932.6890000000003,
          -3936.4509999999996,
          -3939.94,
          -3943.1540000000005,
          -3946.0890000000004,
          -3948.74,
          -3951.105,
          -3953.18,
          -3954.961,
          -3956.4440000000004,
          -3957.6240000000003,
          -3958.4990000000003,
          -3959.063,
          -3959.313,
          -3959.244,
          -3958.8520000000003,
          -3958.132,
          -3957.079,
          -3955.6890000000003,
          -3953.9570000000003,
          -3951.8779999999997,
          -3949.447,
          -3946.659,
          -3943.508,
          -3939.989,
          -3936.097,
          -3931.824,
          -3927.167,
          -3922.119,
          -3916.673,
          -3910.823,
          -3904.5640000000003,
          -3897.887,
          -3890.7870000000003,
          -3883.257,
          -3875.288,
          -3866.875,
          -3858.009,
          -3848.683,
          -3838.888,
          -3828.616,
          -3817.86,
          -3806.611,
          -3794.8590000000004,
          -3782.595,
          -3769.8109999999997,
          -3756.4959999999996,
          -3742.64,
          -3728.2329999999997,
          -3713.265,
          -3697.725,
          -3681.6009999999997,
          -3664.882,
          -3647.5570000000002,
          -3629.611,
          -3611.034,
          -3591.812,
          -3571.9320000000002,
          -3551.3790000000004,
          -3530.139,
          -3508.197,
          -3485.538,
          -3462.147,
          -3438.006,
          -3413.098,
          -3387.407,
          -3360.914,
          -3333.6,
          -3305.446,
          -3276.4309999999996,
          -3246.535,
          -3215.735,
          -3184.012,
          -3151.3390000000004,
          -3117.695,
          -3083.053,
          -3047.389,
          -3010.675,
          -2972.883,
          -2933.986,
          -2893.954,
          -2852.755,
          -2810.3579999999997,
          -2766.73,
          -2721.837,
          -2675.6440000000002,
          -2628.115,
          -2579.2110000000002,
          -2528.895,
          -2477.126,
          -2423.865,
          -2369.069,
          -2312.695,
          -2254.699,
          -2195.038,
          -2133.667,
          -2070.5389999999998,
          -2005.611,
          -1938.838,
          -1870.175,
          -1799.58,
          -1727.0120000000002,
          -1652.435,
          -1575.8129999999999,
          -1497.119,
          -1416.328,
          -1333.4260000000002,
          -1248.407,
          -1161.276,
          -1072.052,
          -980.77,
          -887.485,
          -792.2719999999999,
          -695.23,
          -596.485,
          -496.19300000000004,
          -394.542,
          -291.751,
          -188.076,
          -83.8,
          20.76,
          125.262,
          229.345,
          332.631,
          434.73900000000003,
          535.2919999999999,
          633.9259999999999,
          730.296,
          824.09,
          915.028,
          1002.878,
          1087.443,
          1168.575,
          1246.167,
          1320.1529999999998,
          1390.5020000000002,
          1457.221,
          1520.339,
          1579.911,
          1636.0120000000002,
          1688.7320000000002,
          1738.17,
          1784.4370000000001,
          1827.6470000000002,
          1867.9170000000001,
          1905.3670000000002,
          1940.114,
          1972.275,
          2001.965,
          2029.296,
          2054.375,
          2077.305,
          2098.188,
          2117.116,
          2134.183,
          2149.473,
          2163.07,
          2175.053,
          2185.493,
          2194.45,
          2202.031,
          2208.258,
          2213.205,
          2216.929,
          2219.4829999999997,
          2220.919,
          2221.285,
          2220.627,
          2218.988,
          2216.409,
          2212.93,
          2208.5879999999997,
          2203.419,
          2197.4539999999997,
          2190.7270000000003,
          2183.268,
          2175.106,
          2166.2670000000003,
          2156.779,
          2146.665,
          2135.95,
          2124.656,
          2112.806,
          2100.419,
          2087.516,
          2074.114,
          2060.2329999999997,
          2045.889,
          2031.099,
          2015.878,
          2000.2420000000002,
          1984.205,
          1967.7820000000002,
          1950.985,
          1933.8270000000002,
          1916.3210000000001,
          1898.4779999999998,
          1880.31,
          1861.828,
          1843.0420000000001,
          1823.9620000000002,
          1804.598,
          1784.96,
          1765.056,
          1744.896,
          1724.487,
          1703.8370000000002,
          1682.955,
          1661.849,
          1640.524,
          1618.99,
          1597.251,
          1575.315,
          1553.1889999999999,
          1530.878,
          1508.388,
          1485.726,
          1462.896,
          1439.905,
          1416.757,
          1393.457,
          1370.0120000000002,
          1346.424,
          1322.7,
          1298.843,
          1274.859,
          1250.75,
          1226.522,
          1202.178,
          1177.723,
          1153.16,
          1128.493,
          1103.725,
          1078.86,
          1053.902,
          1028.854,
          1003.7189999999999,
          978.5,
          953.2,
          927.823,
          902.3710000000001,
          876.847,
          851.2539999999999,
          825.595,
          799.873,
          774.0889999999999,
          748.247,
          722.3489999999999,
          696.3969999999999,
          670.395,
          644.3430000000001,
          618.246,
          592.1030000000001,
          565.919,
          539.695,
          513.433,
          487.135,
          460.80300000000005,
          434.44,
          408.046,
          381.625,
          355.17699999999996,
          328.70599999999996,
          302.211,
          275.69599999999997,
          249.162,
          222.61,
          196.043,
          169.46200000000002,
          142.868,
          116.26299999999999,
          89.649,
          63.028,
          36.399,
          9.767000000000001,
          -16.87,
          -43.508,
          -70.14699999999999,
          -96.785,
          -123.42,
          -150.053,
          -176.68,
          -203.301,
          -229.91400000000002,
          -256.519,
          -283.11400000000003,
          -309.698,
          -336.269,
          -362.82599999999996,
          -389.369,
          -415.895,
          -442.404,
          -468.895,
          -495.36699999999996,
          -521.818,
          -548.247,
          -574.653,
          -601.035,
          -627.393,
          -653.724,
          -680.028,
          -706.305,
          -732.552,
          -758.768,
          -784.954,
          -811.107,
          -837.227,
          -863.313,
          -889.3639999999999,
          -915.3789999999999,
          -941.3560000000001,
          -967.296,
          -993.196,
          -1019.057,
          -1044.876,
          -1070.654,
          -1096.389,
          -1122.08,
          -1147.7269999999999,
          -1173.328,
          -1198.883,
          -1224.39,
          -1249.85,
          -1275.26,
          -1300.62,
          -1325.93,
          -1351.1870000000001,
          -1376.3929999999998,
          -1401.5439999999999,
          -1426.641,
          -1451.683,
          -1476.6689999999999,
          -1501.598,
          -1526.47,
          -1551.2820000000002,
          -1576.035,
          -1600.7279999999998,
          -1625.359,
          -1649.9279999999999,
          -1674.435,
          -1698.878,
          -1723.256,
          -1747.568,
          -1771.8139999999999,
          -1795.993,
          -1820.105,
          -1844.1470000000002,
          -1868.119,
          -1892.021,
          -1915.852,
          -1939.61,
          -1963.295,
          -1986.9070000000002,
          -2010.443,
          -2033.904,
          -2057.288,
          -2080.595,
          -2103.824,
          -2126.974,
          -2150.0429999999997,
          -2173.032,
          -2195.94,
          -2218.764,
          -2241.505,
          -2264.1620000000003,
          -2286.734,
          -2309.22,
          -2331.619,
          -2353.93,
          -2376.152,
          -2398.285,
          -2420.327,
          -2442.278,
          -2464.136,
          -2485.901,
          -2507.572,
          -2529.1479999999997,
          -2550.6279999999997,
          -2572.011,
          -2593.2960000000003,
          -2614.482,
          -2635.5679999999998,
          -2656.554,
          -2677.438,
          -2698.219,
          -2718.897,
          -2739.469,
          -2759.937,
          -2780.297,
          -2800.55,
          -2820.695,
          -2840.73,
          -2860.6540000000005,
          -2880.466,
          -2900.165,
          -2919.7509999999997,
          -2939.222,
          -2958.577,
          -2977.8140000000003,
          -2996.934,
          -3015.935,
          -3034.815,
          -3053.573,
          -3072.2090000000003,
          -3090.722,
          -3109.1090000000004,
          -3127.37,
          -3145.505,
          -3163.51,
          -3181.387,
          -3199.132,
          -3216.745,
          -3234.2259999999997,
          -3251.571,
          -3268.781,
          -3285.8540000000003,
          -3302.788,
          -3319.583,
          -3336.237,
          -3352.7490000000003,
          -3369.117,
          -3385.3390000000004,
          -3401.4159999999997,
          -3417.345,
          -3433.125,
          -3448.7540000000004,
          -3464.2309999999998,
          -3479.554,
          -3494.723,
          -3509.735,
          -3524.5879999999997,
          -3539.283,
          -3553.816,
          -3568.187,
          -3582.393,
          -3596.433,
          -3610.3059999999996,
          -3624.01,
          -3637.542,
          -3650.902,
          -3664.0879999999997,
          -3677.0959999999995,
          -3689.928,
          -3702.58,
          -3715.05,
          -3727.337,
          -3739.4390000000003,
          -3751.353,
          -3763.078,
          -3774.612,
          -3785.953,
          -3797.099,
          -3808.047,
          -3818.797,
          -3829.344,
          -3839.688,
          -3849.8259999999996,
          -3859.756,
          -3869.4759999999997,
          -3878.9829999999997,
          -3888.275,
          -3897.349,
          -3906.204,
          -3914.836,
          -3923.243,
          -3931.4240000000004,
          -3939.3740000000003,
          -3947.091,
          -3954.573,
          -3961.8179999999998,
          -3968.821,
          -3975.58,
          -3982.094,
          -3988.357,
          -3994.368,
          -4000.1240000000003,
          -4005.6209999999996,
          -4010.8559999999998,
          -4015.8259999999996,
          -4020.527,
          -4024.9570000000003,
          -4029.112,
          -4032.988,
          -4036.5820000000003,
          -4039.8909999999996,
          -4042.909,
          -4045.635,
          -4048.063,
          -4050.191,
          -4052.013,
          -4053.526,
          -4054.725,
          -4055.607,
          -4056.167,
          -4056.4,
          -4056.303,
          -4055.869,
          -4055.095,
          -4053.9759999999997,
          -4052.506,
          -4050.6809999999996,
          -4048.495,
          -4045.942,
          -4043.0190000000002,
          -4039.718,
          -4036.034,
          -4031.961,
          -4027.494,
          -4022.6259999999997,
          -4017.35,
          -4011.66,
          -4005.55,
          -3999.013,
          -3992.0409999999997,
          -3984.6279999999997,
          -3976.7659999999996,
          -3968.448,
          -3959.6659999999997,
          -3950.4109999999996,
          -3940.676,
          -3930.452,
          -3919.7309999999998,
          -3908.5040000000004,
          -3896.761,
          -3884.493,
          -3871.69,
          -3858.343,
          -3844.442,
          -3829.975,
          -3814.9309999999996,
          -3799.3,
          -3783.071,
          -3766.23,
          -3748.7659999999996,
          -3730.6659999999997,
          -3711.917,
          -3692.506,
          -3672.4190000000003,
          -3651.6409999999996,
          -3630.157,
          -3607.953,
          -3585.012,
          -3561.3179999999998,
          -3536.8540000000003,
          -3511.6020000000003,
          -3485.545,
          -3458.664,
          -3430.9390000000003,
          -3402.35,
          -3372.8759999999997,
          -3342.4970000000003,
          -3311.19,
          -3278.9309999999996,
          -3245.697,
          -3211.4629999999997,
          -3176.203,
          -3139.8909999999996,
          -3102.4990000000003,
          -3063.9990000000003,
          -3024.361,
          -2983.554,
          -2941.547,
          -2898.3059999999996,
          -2853.798,
          -2807.988,
          -2760.8379999999997,
          -2712.312,
          -2662.3709999999996,
          -2610.974,
          -2558.081,
          -2503.6479999999997,
          -2447.634,
          -2389.992,
          -2330.679,
          -2269.647,
          -2206.85,
          -2142.242,
          -2075.774,
          -2007.401,
          -1937.076,
          -1864.755,
          -1790.394,
          -1713.955,
          -1635.401,
          -1554.701,
          -1471.83,
          -1386.77,
          -1299.513,
          -1210.0639999999999,
          -1118.44,
          -1024.6760000000002,
          -928.824,
          -830.959,
          -731.18,
          -629.615,
          -526.422,
          -421.791,
          -315.945,
          -209.142,
          -101.675,
          6.132999999999999,
          113.93299999999999,
          221.352,
          328.004,
          433.495,
          537.436,
          639.45,
          739.18,
          836.301,
          930.5239999999999,
          1021.6010000000001,
          1109.328,
          1193.549,
          1274.149,
          1351.055,
          1424.234,
          1493.685,
          1559.4379999999999,
          1621.547,
          1680.085,
          1735.1429999999998,
          1786.8220000000001,
          1835.233,
          1880.4920000000002,
          1922.719,
          1962.036,
          1998.5639999999999,
          2032.422,
          2063.7270000000003,
          2092.594,
          2119.134,
          2143.4539999999997,
          2165.655,
          2185.835,
          2204.0879999999997,
          2220.504,
          2235.166,
          2248.156,
          2259.55,
          2269.4210000000003,
          2277.8379999999997,
          2284.865,
          2290.5660000000003,
          2294.998,
          2298.218,
          2300.277,
          2301.2270000000003,
          2301.113,
          2299.982,
          2297.875,
          2294.833,
          2290.895,
          2286.096,
          2280.473,
          2274.056,
          2266.879,
          2258.97,
          2250.3579999999997,
          2241.07,
          2231.131,
          2220.567,
          2209.401,
          2197.655,
          2185.35,
          2172.506,
          2159.144,
          2145.282,
          2130.938,
          2116.1279999999997,
          2100.87,
          2085.178,
          2069.0679999999998,
          2052.554,
          2035.651,
          2018.37,
          2000.726,
          1982.73,
          1964.394,
          1945.73,
          1926.747,
          1907.4579999999999,
          1887.871,
          1867.997,
          1847.845,
          1827.4229999999998,
          1806.7420000000002,
          1785.809,
          1764.632,
          1743.2179999999998,
          1721.5770000000002,
          1699.715,
          1677.638,
          1655.355,
          1632.871,
          1610.193,
          1587.3270000000002,
          1564.279,
          1541.055,
          1517.661,
          1494.102,
          1470.3829999999998,
          1446.51,
          1422.487,
          1398.319,
          1374.0120000000002,
          1349.569,
          1324.995,
          1300.295,
          1275.472,
          1250.531,
          1225.475,
          1200.309,
          1175.036,
          1149.66,
          1124.184,
          1098.613,
          1072.948,
          1047.195,
          1021.355,
          995.432,
          969.429,
          943.3489999999999,
          917.195,
          890.97,
          864.677,
          838.317,
          811.895,
          785.4119999999999,
          758.8710000000001,
          732.275,
          705.625,
          678.925,
          652.177,
          625.382,
          598.544,
          571.663,
          544.744,
          517.7869999999999,
          490.79400000000004,
          463.76800000000003,
          436.71,
          409.62300000000005,
          382.509,
          355.369,
          328.204,
          301.018,
          273.811,
          246.58599999999998,
          219.343,
          192.085,
          164.81400000000002,
          137.531,
          110.23700000000001,
          82.934,
          55.623999999999995,
          28.308000000000003,
          0.988,
          -26.335,
          -53.66,
          -80.985,
          -108.30799999999999,
          -135.629,
          -162.945,
          -190.25599999999997,
          -217.56,
          -244.857,
          -272.143,
          -299.42,
          -326.684,
          -353.935,
          -381.17199999999997,
          -408.39300000000003,
          -435.598,
          -462.784,
          -489.952,
          -517.099,
          -544.225,
          -571.3290000000001,
          -598.408,
          -625.464,
          -652.493,
          -679.495,
          -706.47,
          -733.415,
          -760.33,
          -787.2139999999999,
          -814.066,
          -840.885,
          -867.67,
          -894.419,
          -921.132,
          -947.808,
          -974.446,
          -1001.044,
          -1027.603,
          -1054.12,
          -1080.595,
          -1107.027,
          -1133.415,
          -1159.759,
          -1186.056,
          -1212.307,
          -1238.51,
          -1264.664,
          -1290.769,
          -1316.8229999999999,
          -1342.826,
          -1368.776,
          -1394.674,
          -1420.517,
          -1446.305,
          -1472.0379999999998,
          -1497.713,
          -1523.3310000000001,
          -1548.891,
          -1574.391,
          -1599.83,
          -1625.2089999999998,
          -1650.525,
          -1675.7779999999998,
          -1700.9679999999998,
          -1726.0929999999998,
          -1751.152,
          -1776.145,
          -1801.07,
          -1825.9270000000001,
          -1850.715,
          -1875.433,
          -1900.08,
          -1924.655,
          -1949.158,
          -1973.588,
          -1997.942,
          -2022.2220000000002,
          -2046.4260000000002,
          -2070.552,
          -2094.601,
          -2118.571,
          -2142.4610000000002,
          -2166.27,
          -2189.999,
          -2213.644,
          -2237.2070000000003,
          -2260.685,
          -2284.078,
          -2307.386,
          -2330.606,
          -2353.739,
          -2376.783,
          -2399.737,
          -2422.601,
          -2445.373,
          -2468.053,
          -2490.64,
          -2513.132,
          -2535.529,
          -2557.83,
          -2580.033,
          -2602.139,
          -2624.145,
          -2646.052,
          -2667.857,
          -2689.56,
          -2711.1609999999996,
          -2732.657,
          -2754.048,
          -2775.333,
          -2796.511,
          -2817.5809999999997,
          -2838.542,
          -2859.393,
          -2880.132,
          -2900.76,
          -2921.2740000000003,
          -2941.673,
          -2961.9570000000003,
          -2982.1240000000003,
          -3002.1740000000004,
          -3022.105,
          -3041.9159999999997,
          -3061.6059999999998,
          -3081.173,
          -3100.618,
          -3119.937,
          -3139.131,
          -3158.199,
          -3177.138,
          -3195.948,
          -3214.627,
          -3233.1740000000004,
          -3251.5890000000004,
          -3269.87,
          -3288.014,
          -3306.0229999999997,
          -3323.893,
          -3341.623,
          -3359.2129999999997,
          -3376.6609999999996,
          -3393.966,
          -3411.125,
          -3428.139,
          -3445.005,
          -3461.722,
          -3478.288,
          -3494.703,
          -3510.9640000000004,
          -3527.071,
          -3543.0209999999997,
          -3558.813,
          -3574.446,
          -3589.9179999999997,
          -3605.2270000000003,
          -3620.373,
          -3635.3520000000003,
          -3650.164,
          -3664.8070000000002,
          -3679.2790000000005,
          -3693.579,
          -3707.705,
          -3721.6540000000005,
          -3735.426,
          -3749.018,
          -3762.429,
          -3775.656,
          -3788.699,
          -3801.554,
          -3814.22,
          -3826.696,
          -3838.978,
          -3851.066,
          -3862.9559999999997,
          -3874.647,
          -3886.137,
          -3897.423,
          -3908.5040000000004,
          -3919.377,
          -3930.04,
          -3940.49,
          -3950.7259999999997,
          -3960.744,
          -3970.5429999999997,
          -3980.12,
          -3989.472,
          -3998.598,
          -4007.493,
          -4016.157,
          -4024.585,
          -4032.776,
          -4040.7270000000003,
          -4048.435,
          -4055.8959999999997,
          -4063.1079999999997,
          -4070.0690000000004,
          -4076.7740000000003,
          -4083.222,
          -4089.408,
          -4095.33,
          -4100.984,
          -4106.367,
          -4111.476,
          -4116.308,
          -4120.858,
          -4125.123,
          -4129.099,
          -4132.782999999999,
          -4136.1720000000005,
          -4139.26,
          -4142.044,
          -4144.52,
          -4146.685,
          -4148.532999999999,
          -4150.06,
          -4151.262,
          -4152.135,
          -4152.674,
          -4152.874,
          -4152.73,
          -4152.238,
          -4151.392,
          -4150.188,
          -4148.62,
          -4146.682,
          -4144.37,
          -4141.677,
          -4138.598,
          -4135.127,
          -4131.258,
          -4126.984,
          -4122.3,
          -4117.1990000000005,
          -4111.674,
          -4105.718,
          -4099.3240000000005,
          -4092.486,
          -4085.195,
          -4077.445,
          -4069.2259999999997,
          -4060.533,
          -4051.355,
          -4041.685,
          -4031.514,
          -4020.833,
          -4009.633,
          -3997.905,
          -3985.639,
          -3972.825,
          -3959.452,
          -3945.511,
          -3930.989,
          -3915.877,
          -3900.163,
          -3883.8340000000003,
          -3866.8779999999997,
          -3849.283,
          -3831.0359999999996,
          -3812.123,
          -3792.531,
          -3772.244,
          -3751.2490000000003,
          -3729.53,
          -3707.071,
          -3683.8559999999998,
          -3659.868,
          -3635.09,
          -3609.5040000000004,
          -3583.09,
          -3555.83,
          -3527.703,
          -3498.69,
          -3468.768,
          -3437.915,
          -3406.11,
          -3373.3259999999996,
          -3339.5409999999997,
          -3304.7290000000003,
          -3268.862,
          -3231.915,
          -3193.857,
          -3154.66,
          -3114.2929999999997,
          -3072.724,
          -3029.922,
          -2985.8509999999997,
          -2940.4759999999997,
          -2893.762,
          -2845.67,
          -2796.1620000000003,
          -2745.197,
          -2692.735,
          -2638.732,
          -2583.145,
          -2525.928,
          -2467.036,
          -2406.4210000000003,
          -2344.036,
          -2279.8320000000003,
          -2213.76,
          -2145.772,
          -2075.8179999999998,
          -2003.85,
          -1929.8229999999999,
          -1853.69,
          -1775.41,
          -1694.944,
          -1612.26,
          -1527.33,
          -1440.135,
          -1350.664,
          -1258.921,
          -1164.921,
          -1068.698,
          -970.302,
          -869.809,
          -767.319,
          -662.959,
          -556.889,
          -449.301,
          -340.423,
          -230.517,
          -119.881,
          -8.846,
          102.23100000000001,
          212.968,
          322.968,
          431.82599999999996,
          539.141,
          644.521,
          747.6,
          848.039,
          945.5369999999999,
          1039.836,
          1130.721,
          1218.027,
          1301.632,
          1381.457,
          1457.464,
          1529.65,
          1598.04,
          1662.6879999999999,
          1723.6670000000001,
          1781.066,
          1834.99,
          1885.549,
          1932.8629999999998,
          1977.0529999999999,
          2018.244,
          2056.558,
          2092.119,
          2125.0460000000003,
          2155.4570000000003,
          2183.465,
          2209.18,
          2232.706,
          2254.145,
          2273.593,
          2291.14,
          2306.875,
          2320.88,
          2333.235,
          2344.014,
          2353.2870000000003,
          2361.123,
          2367.585,
          2372.734,
          2376.626,
          2379.317,
          2380.857,
          2381.2960000000003,
          2380.68,
          2379.052,
          2376.455,
          2372.928,
          2368.509,
          2363.2329999999997,
          2357.135,
          2350.2470000000003,
          2342.599,
          2334.221,
          2325.141,
          2315.386,
          2304.98,
          2293.948,
          2282.313,
          2270.098,
          2257.322,
          2244.007,
          2230.172,
          2215.835,
          2201.013,
          2185.724,
          2169.984,
          2153.8089999999997,
          2137.212,
          2120.209,
          2102.814,
          2085.0389999999998,
          2066.897,
          2048.4,
          2029.5610000000001,
          2010.39,
          1990.898,
          1971.095,
          1950.993,
          1930.599,
          1909.925,
          1888.9779999999998,
          1867.7679999999998,
          1846.3029999999999,
          1824.5910000000001,
          1802.639,
          1780.457,
          1758.05,
          1735.425,
          1712.5910000000001,
          1689.5529999999999,
          1666.318,
          1642.892,
          1619.281,
          1595.491,
          1571.527,
          1547.396,
          1523.102,
          1498.65,
          1474.046,
          1449.295,
          1424.401,
          1399.369,
          1374.203,
          1348.9070000000002,
          1323.487,
          1297.9460000000001,
          1272.287,
          1246.516,
          1220.635,
          1194.649,
          1168.5610000000001,
          1142.374,
          1116.0919999999999,
          1089.719,
          1063.257,
          1036.7089999999998,
          1010.08,
          983.3710000000001,
          956.586,
          929.7280000000001,
          902.8,
          875.803,
          848.742,
          821.618,
          794.434,
          767.193,
          739.8969999999999,
          712.548,
          685.15,
          657.703,
          630.211,
          602.6759999999999,
          575.099,
          547.484,
          519.831,
          492.144,
          464.423,
          436.67199999999997,
          408.892,
          381.084,
          353.251,
          325.395,
          297.518,
          269.62,
          241.704,
          213.77200000000002,
          185.825,
          157.865,
          129.893,
          101.912,
          73.922,
          45.925,
          17.923,
          -10.083,
          -38.091,
          -66.09899999999999,
          -94.10799999999999,
          -122.11399999999999,
          -150.11700000000002,
          -178.115,
          -206.107,
          -234.092,
          -262.068,
          -290.034,
          -317.988,
          -345.93,
          -373.858,
          -401.77099999999996,
          -429.667,
          -457.546,
          -485.407,
          -513.247,
          -541.066,
          -568.863,
          -596.637,
          -624.386,
          -652.11,
          -679.807,
          -707.475,
          -735.115,
          -762.725,
          -790.304,
          -817.8510000000001,
          -845.3639999999999,
          -872.8439999999999,
          -900.2869999999999,
          -927.695,
          -955.065,
          -982.3969999999999,
          -1009.69,
          -1036.942,
          -1064.152,
          -1091.3210000000001,
          -1118.4460000000001,
          -1145.527,
          -1172.562,
          -1199.5510000000002,
          -1226.493,
          -1253.387,
          -1280.232,
          -1307.027,
          -1333.77,
          -1360.4620000000002,
          -1387.101,
          -1413.6860000000001,
          -1440.2160000000001,
          -1466.691,
          -1493.109,
          -1519.469,
          -1545.771,
          -1572.014,
          -1598.1960000000001,
          -1624.318,
          -1650.3770000000002,
          -1676.3729999999998,
          -1702.306,
          -1728.1729999999998,
          -1753.975,
          -1779.71,
          -1805.378,
          -1830.977,
          -1856.507,
          -1881.967,
          -1907.355,
          -1932.672,
          -1957.915,
          -1983.085,
          -2008.18,
          -2033.1989999999998,
          -2058.1420000000003,
          -2083.007,
          -2107.7929999999997,
          -2132.501,
          -2157.1279999999997,
          -2181.674,
          -2206.138,
          -2230.519,
          -2254.8160000000003,
          -2279.028,
          -2303.154,
          -2327.194,
          -2351.146,
          -2375.009,
          -2398.783,
          -2422.466,
          -2446.058,
          -2469.558,
          -2492.964,
          -2516.275,
          -2539.492,
          -2562.612,
          -2585.635,
          -2608.5589999999997,
          -2631.385,
          -2654.11,
          -2676.7340000000004,
          -2699.255,
          -2721.673,
          -2743.987,
          -2766.196,
          -2788.298,
          -2810.2929999999997,
          -2832.18,
          -2853.9559999999997,
          -2875.623,
          -2897.177,
          -2918.619,
          -2939.947,
          -2961.1609999999996,
          -2982.258,
          -3003.238,
          -3024.099,
          -3044.842,
          -3065.4640000000004,
          -3085.9640000000004,
          -3106.341,
          -3126.594,
          -3146.722,
          -3166.724,
          -3186.598,
          -3206.343,
          -3225.958,
          -3245.441,
          -3264.7929999999997,
          -3284.01,
          -3303.092,
          -3322.038,
          -3340.8459999999995,
          -3359.515,
          -3378.0440000000003,
          -3396.4309999999996,
          -3414.675,
          -3432.775,
          -3450.728,
          -3468.535,
          -3486.1929999999998,
          -3503.7,
          -3521.0570000000002,
          -3538.26,
          -3555.308,
          -3572.2009999999996,
          -3588.9359999999997,
          -3605.512,
          -3621.927,
          -3638.18,
          -3654.2690000000002,
          -3670.1929999999998,
          -3685.95,
          -3701.5370000000003,
          -3716.955,
          -3732.2,
          -3747.2709999999997,
          -3762.1659999999997,
          -3776.884,
          -3791.423,
          -3805.781,
          -3819.955,
          -3833.945,
          -3847.748,
          -3861.362,
          -3874.7859999999996,
          -3888.0170000000003,
          -3901.053,
          -3913.893,
          -3926.534,
          -3938.974,
          -3951.211,
          -3963.242,
          -3975.066,
          -3986.6809999999996,
          -3998.083,
          -4009.2709999999997,
          -4020.242,
          -4030.994,
          -4041.525,
          -4051.8320000000003,
          -4061.9120000000003,
          -4071.763,
          -4081.382,
          -4090.7670000000003,
          -4099.915,
          -4108.8240000000005,
          -4117.4890000000005,
          -4125.91,
          -4134.082,
          -4142.003,
          -4149.669,
          -4157.079000000001,
          -4164.228,
          -4171.113,
          -4177.732,
          -4184.08,
          -4190.156,
          -4195.954000000001,
          -4201.473,
          -4206.707,
          -4211.654,
          -4216.311,
          -4220.6720000000005,
          -4224.734,
          -4228.495,
          -4231.948,
          -4235.090999999999,
          -4237.919,
          -4240.428,
          -4242.6140000000005,
          -4244.472,
          -4245.998,
          -4247.187,
          -4248.034000000001,
          -4248.535,
          -4248.685,
          -4248.478,
          -4247.909000000001,
          -4246.974,
          -4245.667,
          -4243.981,
          -4241.913,
          -4239.455,
          -4236.602,
          -4233.348,
          -4229.687,
          -4225.612,
          -4221.116,
          -4216.194,
          -4210.838,
          -4205.041,
          -4198.7970000000005,
          -4192.096,
          -4184.933,
          -4177.299,
          -4169.187,
          -4160.587,
          -4151.492,
          -4141.893,
          -4131.78,
          -4121.146,
          -4109.98,
          -4098.273,
          -4086.015,
          -4073.196,
          -4059.804,
          -4045.83,
          -4031.262,
          -4016.0879999999997,
          -4000.297,
          -3983.8759999999997,
          -3966.8140000000003,
          -3949.0959999999995,
          -3930.7090000000003,
          -3911.64,
          -3891.875,
          -3871.3979999999997,
          -3850.195,
          -3828.2490000000003,
          -3805.545,
          -3782.065,
          -3757.7929999999997,
          -3732.711,
          -3706.7990000000004,
          -3680.039,
          -3652.41,
          -3623.893,
          -3594.465,
          -3564.1059999999998,
          -3532.792,
          -3500.5,
          -3467.204,
          -3432.881,
          -3397.502,
          -3361.0409999999997,
          -3323.4709999999995,
          -3284.76,
          -3244.88,
          -3203.798,
          -3161.4829999999997,
          -3117.8990000000003,
          -3073.013,
          -3026.7870000000003,
          -2979.184,
          -2930.1659999999997,
          -2879.6929999999998,
          -2827.722,
          -2774.211,
          -2719.116,
          -2662.3920000000003,
          -2603.992,
          -2543.868,
          -2481.971,
          -2418.2529999999997,
          -2352.6620000000003,
          -2285.149,
          -2215.661,
          -2144.1479999999997,
          -2070.561,
          -1994.85,
          -1916.9679999999998,
          -1836.871,
          -1754.519,
          -1669.8770000000002,
          -1582.914,
          -1493.608,
          -1401.951,
          -1307.941,
          -1211.593,
          -1112.938,
          -1012.0269999999999,
          -908.934,
          -803.76,
          -696.632,
          -587.7130000000001,
          -477.195,
          -365.311,
          -252.328,
          -138.548,
          -24.308000000000003,
          90.025,
          204.06,
          317.389,
          429.598,
          540.271,
          649.007,
          755.425,
          859.174,
          959.941,
          1057.4569999999999,
          1151.498,
          1241.888,
          1328.5,
          1411.247,
          1490.086,
          1565.01,
          1636.043,
          1703.236,
          1766.662,
          1826.411,
          1882.5870000000002,
          1935.3029999999999,
          1984.68,
          2030.8410000000001,
          2073.9139999999998,
          2114.024,
          2151.2960000000003,
          2185.855,
          2217.819,
          2247.304,
          2274.423,
          2299.285,
          2321.992,
          2342.6420000000003,
          2361.331,
          2378.1479999999997,
          2393.177,
          2406.501,
          2418.18,
          2428.3360000000002,
          2436.989,
          2444.221,
          2450.095,
          2454.669,
          2458,
          2460.14,
          2461.14,
          2461.047,
          2459.908,
          2457.764,
          2454.657,
          2450.625,
          2445.706,
          2439.935,
          2433.344,
          2425.966,
          2417.831,
          2408.967,
          2399.402,
          2389.163,
          2378.274,
          2366.759,
          2354.6420000000003,
          2341.942,
          2328.6820000000002,
          2314.882,
          2300.56,
          2285.734,
          2270.423,
          2254.643,
          2238.409,
          2221.738,
          2204.644,
          2187.141,
          2169.243,
          2150.9629999999997,
          2132.314,
          2113.3070000000002,
          2093.955,
          2074.268,
          2054.258,
          2033.934,
          2013.307,
          1992.3870000000002,
          1971.183,
          1949.704,
          1927.9579999999999,
          1905.954,
          1883.7,
          1861.205,
          1838.474,
          1815.517,
          1792.34,
          1768.9489999999998,
          1745.352,
          1721.555,
          1697.5639999999999,
          1673.385,
          1649.025,
          1624.4879999999998,
          1599.78,
          1574.908,
          1549.875,
          1524.6870000000001,
          1499.349,
          1473.865,
          1448.241,
          1422.48,
          1396.588,
          1370.567,
          1344.424,
          1318.161,
          1291.782,
          1265.292,
          1238.694,
          1211.992,
          1185.1889999999999,
          1158.289,
          1131.2939999999999,
          1104.2089999999998,
          1077.037,
          1049.781,
          1022.443,
          995.0269999999999,
          967.535,
          939.972,
          912.3380000000001,
          884.638,
          856.873,
          829.047,
          801.1610000000001,
          773.2189999999999,
          745.2230000000001,
          717.175,
          689.078,
          660.933,
          632.743,
          604.511,
          576.238,
          547.927,
          519.58,
          491.19800000000004,
          462.784,
          434.34,
          405.86699999999996,
          377.36800000000005,
          348.844,
          320.297,
          291.72900000000004,
          263.142,
          234.537,
          205.917,
          177.283,
          148.636,
          119.978,
          91.311,
          62.636,
          33.955,
          5.269,
          -23.419,
          -52.108999999999995,
          -80.8,
          -109.48899999999999,
          -138.175,
          -166.857,
          -195.53400000000002,
          -224.204,
          -252.86599999999999,
          -281.518,
          -310.159,
          -338.788,
          -367.404,
          -396.005,
          -424.59,
          -453.158,
          -481.707,
          -510.23699999999997,
          -538.746,
          -567.2330000000001,
          -595.697,
          -624.136,
          -652.55,
          -680.937,
          -709.297,
          -737.627,
          -765.928,
          -794.197,
          -822.434,
          -850.638,
          -878.808,
          -906.942,
          -935.04,
          -963.1,
          -991.122,
          -1019.1039999999999,
          -1047.045,
          -1074.945,
          -1102.802,
          -1130.615,
          -1158.384,
          -1186.107,
          -1213.7830000000001,
          -1241.412,
          -1268.992,
          -1296.5230000000001,
          -1324.0020000000002,
          -1351.431,
          -1378.806,
          -1406.129,
          -1433.396,
          -1460.609,
          -1487.765,
          -1514.8629999999998,
          -1541.904,
          -1568.885,
          -1595.806,
          -1622.6660000000002,
          -1649.4479999999999,
          -1676.183,
          -1702.854,
          -1729.46,
          -1756.001,
          -1782.474,
          -1808.88,
          -1835.217,
          -1861.485,
          -1887.682,
          -1913.808,
          -1939.862,
          -1965.842,
          -1991.749,
          -2017.58,
          -2043.335,
          -2069.012,
          -2094.612,
          -2120.134,
          -2145.575,
          -2170.935,
          -2196.214,
          -2221.41,
          -2246.5229999999997,
          -2271.551,
          -2296.493,
          -2321.349,
          -2346.117,
          -2370.797,
          -2395.388,
          -2419.888,
          -2444.297,
          -2468.614,
          -2492.837,
          -2516.966,
          -2541,
          -2564.937,
          -2588.777,
          -2612.519,
          -2636.1609999999996,
          -2659.704,
          -2683.1440000000002,
          -2706.4829999999997,
          -2729.717,
          -2752.848,
          -2775.873,
          -2798.7909999999997,
          -2821.6009999999997,
          -2844.303,
          -2866.895,
          -2889.3759999999997,
          -2911.745,
          -2934.0009999999997,
          -2956.143,
          -2978.17,
          -3000.08,
          -3021.8720000000003,
          -3043.546,
          -3065.099,
          -3086.532,
          -3107.842,
          -3129.0290000000005,
          -3150.092,
          -3171.028,
          -3191.8379999999997,
          -3212.5190000000002,
          -3233.071,
          -3253.492,
          -3273.781,
          -3293.9359999999997,
          -3313.958,
          -3333.843,
          -3353.591,
          -3373.2,
          -3392.67,
          -3411.998,
          -3431.184,
          -3450.2259999999997,
          -3469.1220000000003,
          -3487.8720000000003,
          -3506.474,
          -3524.925,
          -3543.2259999999997,
          -3561.3740000000003,
          -3579.368,
          -3597.2070000000003,
          -3614.888,
          -3632.4109999999996,
          -3649.7729999999997,
          -3666.974,
          -3684.011,
          -3700.883,
          -3717.5890000000004,
          -3734.1259999999997,
          -3750.493,
          -3766.688,
          -3782.71,
          -3798.5559999999996,
          -3814.225,
          -3829.716,
          -3845.026,
          -3860.153,
          -3875.0959999999995,
          -3889.853,
          -3904.421,
          -3918.7990000000004,
          -3932.985,
          -3946.9770000000003,
          -3960.7729999999997,
          -3974.37,
          -3987.7670000000003,
          -4000.961,
          -4013.9509999999996,
          -4026.7329999999997,
          -4039.3070000000002,
          -4051.6690000000003,
          -4063.817,
          -4075.7490000000003,
          -4087.462,
          -4098.955,
          -4110.224,
          -4121.268,
          -4132.083,
          -4142.667,
          -4153.017,
          -4163.1320000000005,
          -4173.0070000000005,
          -4182.64,
          -4192.029,
          -4201.170999999999,
          -4210.062,
          -4218.6990000000005,
          -4227.081,
          -4235.2029999999995,
          -4243.063,
          -4250.657,
          -4257.982,
          -4265.034000000001,
          -4271.811,
          -4278.309,
          -4284.525,
          -4290.455,
          -4296.094,
          -4301.441,
          -4306.49,
          -4311.238,
          -4315.681,
          -4319.816,
          -4323.637,
          -4327.141,
          -4330.323,
          -4333.18,
          -4335.706,
          -4337.898,
          -4339.75,
          -4341.258,
          -4342.417,
          -4343.221,
          -4343.667,
          -4343.749,
          -4343.460999999999,
          -4342.798,
          -4341.755,
          -4340.326,
          -4338.505,
          -4336.286,
          -4333.663,
          -4330.63,
          -4327.181,
          -4323.308,
          -4319.005999999999,
          -4314.267,
          -4309.085,
          -4303.452,
          -4297.36,
          -4290.803,
          -4283.772,
          -4276.26,
          -4268.258,
          -4259.758,
          -4250.751,
          -4241.228,
          -4231.18,
          -4220.598,
          -4209.472,
          -4197.792,
          -4185.548,
          -4172.73,
          -4159.326,
          -4145.325,
          -4130.717000000001,
          -4115.488,
          -4099.628,
          -4083.123,
          -4065.96,
          -4048.127,
          -4029.6090000000004,
          -4010.3920000000003,
          -3990.461,
          -3969.802,
          -3948.3990000000003,
          -3926.235,
          -3903.2940000000003,
          -3879.559,
          -3855.011,
          -3829.633,
          -3803.405,
          -3776.308,
          -3748.321,
          -3719.4240000000004,
          -3689.593,
          -3658.8070000000002,
          -3627.042,
          -3594.2740000000003,
          -3560.4770000000003,
          -3525.625,
          -3489.692,
          -3452.65,
          -3414.468,
          -3375.117,
          -3334.567,
          -3292.783,
          -3249.7329999999997,
          -3205.382,
          -3159.6940000000004,
          -3112.631,
          -3064.155,
          -3014.2259999999997,
          -2962.801,
          -2909.8390000000004,
          -2855.296,
          -2799.125,
          -2741.28,
          -2681.7140000000004,
          -2620.375,
          -2557.215,
          -2492.181,
          -2425.223,
          -2356.286,
          -2285.3179999999998,
          -2212.2670000000003,
          -2137.08,
          -2059.706,
          -1980.096,
          -1898.205,
          -1813.9879999999998,
          -1727.4089999999999,
          -1638.4370000000001,
          -1547.047,
          -1453.226,
          -1356.974,
          -1258.3010000000002,
          -1157.24,
          -1053.839,
          -948.172,
          -840.34,
          -730.471,
          -618.727,
          -505.306,
          -390.44199999999995,
          -274.405,
          -157.505,
          -40.085,
          77.48100000000001,
          194.792,
          311.43,
          426.97,
          540.984,
          653.058,
          762.8,
          869.846,
          973.87,
          1074.594,
          1171.782,
          1265.251,
          1354.8629999999998,
          1440.527,
          1522.195,
          1599.855,
          1673.53,
          1743.267,
          1809.141,
          1871.24,
          1929.67,
          1984.545,
          2035.9879999999998,
          2084.124,
          2129.0820000000003,
          2170.992,
          2209.981,
          2246.175,
          2279.697,
          2310.665,
          2339.196,
          2365.3979999999997,
          2389.3779999999997,
          2411.238,
          2431.075,
          2448.979,
          2465.04,
          2479.34,
          2491.959,
          2502.971,
          2512.448,
          2520.458,
          2527.063,
          2532.326,
          2536.304,
          2539.051,
          2540.62,
          2541.058,
          2540.4139999999998,
          2538.731,
          2536.051,
          2532.415,
          2527.86,
          2522.423,
          2516.137,
          2509.0370000000003,
          2501.151,
          2492.512,
          2483.146,
          2473.081,
          2462.343,
          2450.956,
          2438.9429999999998,
          2426.328,
          2413.131,
          2399.373,
          2385.074,
          2370.252,
          2354.926,
          2339.113,
          2322.83,
          2306.092,
          2288.9139999999998,
          2271.311,
          2253.298,
          2234.888,
          2216.094,
          2196.928,
          2177.402,
          2157.528,
          2137.3179999999998,
          2116.781,
          2095.929,
          2074.771,
          2053.317,
          2031.576,
          2009.558,
          1987.27,
          1964.721,
          1941.92,
          1918.875,
          1895.592,
          1872.079,
          1848.3429999999998,
          1824.392,
          1800.2320000000002,
          1775.868,
          1751.309,
          1726.559,
          1701.624,
          1676.511,
          1651.224,
          1625.769,
          1600.152,
          1574.3770000000002,
          1548.45,
          1522.375,
          1496.156,
          1469.799,
          1443.307,
          1416.6860000000001,
          1389.9389999999999,
          1363.07,
          1336.0829999999999,
          1308.983,
          1281.772,
          1254.455,
          1227.035,
          1199.516,
          1171.901,
          1144.193,
          1116.396,
          1088.512,
          1060.545,
          1032.498,
          1004.3739999999999,
          976.176,
          947.9060000000001,
          919.568,
          891.163,
          862.695,
          834.1669999999999,
          805.58,
          776.937,
          748.2410000000001,
          719.4939999999999,
          690.698,
          661.8560000000001,
          632.97,
          604.0419999999999,
          575.0740000000001,
          546.069,
          517.028,
          487.95300000000003,
          458.847,
          429.711,
          400.548,
          371.358,
          342.145,
          312.91,
          283.654,
          254.38,
          225.08900000000003,
          195.78400000000002,
          166.46400000000003,
          137.13299999999998,
          107.792,
          78.442,
          49.085,
          19.723,
          -9.642000000000001,
          -39.010999999999996,
          -68.38,
          -97.74799999999999,
          -127.11399999999999,
          -156.477,
          -185.835,
          -215.18599999999998,
          -244.53,
          -273.865,
          -303.189,
          -332.501,
          -361.801,
          -391.086,
          -420.355,
          -449.608,
          -478.842,
          -508.05699999999996,
          -537.251,
          -566.424,
          -595.573,
          -624.698,
          -653.798,
          -682.872,
          -711.9169999999999,
          -740.934,
          -769.92,
          -798.8760000000001,
          -827.799,
          -856.689,
          -885.544,
          -914.3639999999999,
          -943.1469999999999,
          -971.8919999999999,
          -1000.5980000000001,
          -1029.265,
          -1057.891,
          -1086.474,
          -1115.015,
          -1143.512,
          -1171.963,
          -1200.369,
          -1228.7269999999999,
          -1257.037,
          -1285.298,
          -1313.509,
          -1341.6689999999999,
          -1369.777,
          -1397.8310000000001,
          -1425.8310000000001,
          -1453.776,
          -1481.665,
          -1509.497,
          -1537.271,
          -1564.986,
          -1592.64,
          -1620.234,
          -1647.766,
          -1675.234,
          -1702.639,
          -1729.979,
          -1757.253,
          -1784.461,
          -1811.6,
          -1838.671,
          -1865.672,
          -1892.6029999999998,
          -1919.4620000000002,
          -1946.2479999999998,
          -1972.961,
          -1999.599,
          -2026.162,
          -2052.6479999999997,
          -2079.0570000000002,
          -2105.388,
          -2131.639,
          -2157.81,
          -2183.9,
          -2209.907,
          -2235.8320000000003,
          -2261.672,
          -2287.426,
          -2313.095,
          -2338.677,
          -2364.17,
          -2389.574,
          -2414.888,
          -2440.111,
          -2465.242,
          -2490.28,
          -2515.223,
          -2540.071,
          -2564.823,
          -2589.478,
          -2614.034,
          -2638.492,
          -2662.848,
          -2687.1040000000003,
          -2711.257,
          -2735.3059999999996,
          -2759.2509999999997,
          -2783.09,
          -2806.822,
          -2830.447,
          -2853.9629999999997,
          -2877.368,
          -2900.663,
          -2923.845,
          -2946.914,
          -2969.868,
          -2992.7070000000003,
          -3015.428,
          -3038.032,
          -3060.5170000000003,
          -3082.881,
          -3105.1240000000003,
          -3127.245,
          -3149.241,
          -3171.112,
          -3192.857,
          -3214.474,
          -3235.9629999999997,
          -3257.321,
          -3278.548,
          -3299.643,
          -3320.603,
          -3341.429,
          -3362.117,
          -3382.6679999999997,
          -3403.08,
          -3423.35,
          -3443.4790000000003,
          -3463.465,
          -3483.3059999999996,
          -3503,
          -3522.547,
          -3541.945,
          -3561.1929999999998,
          -3580.288,
          -3599.23,
          -3618.0170000000003,
          -3636.647,
          -3655.119,
          -3673.4320000000002,
          -3691.583,
          -3709.571,
          -3727.395,
          -3745.053,
          -3762.542,
          -3779.863,
          -3797.012,
          -3813.988,
          -3830.789,
          -3847.414,
          -3863.861,
          -3880.1279999999997,
          -3896.212,
          -3912.113,
          -3927.828,
          -3943.3559999999998,
          -3958.6940000000004,
          -3973.84,
          -3988.792,
          -4003.55,
          -4018.1090000000004,
          -4032.469,
          -4046.6259999999997,
          -4060.58,
          -4074.327,
          -4087.866,
          -4101.194,
          -4114.309,
          -4127.209,
          -4139.891,
          -4152.353,
          -4164.592000000001,
          -4176.606,
          -4188.393,
          -4199.9490000000005,
          -4211.273,
          -4222.361,
          -4233.212,
          -4243.821,
          -4254.187,
          -4264.306,
          -4274.1759999999995,
          -4283.794,
          -4293.157,
          -4302.2609999999995,
          -4311.105,
          -4319.683,
          -4327.994000000001,
          -4336.034000000001,
          -4343.8,
          -4351.288,
          -4358.495,
          -4365.417,
          -4372.0509999999995,
          -4378.393,
          -4384.44,
          -4390.187,
          -4395.630999999999,
          -4400.768,
          -4405.594,
          -4410.105,
          -4414.295999999999,
          -4418.163,
          -4421.702,
          -4424.907999999999,
          -4427.778,
          -4430.305,
          -4432.486,
          -4434.316,
          -4435.789000000001,
          -4436.901,
          -4437.646,
          -4438.019,
          -4438.015,
          -4437.628,
          -4436.853,
          -4435.683,
          -4434.113,
          -4432.1359999999995,
          -4429.747,
          -4426.939,
          -4423.705,
          -4420.039000000001,
          -4415.935,
          -4411.384,
          -4406.379,
          -4400.914000000001,
          -4394.981,
          -4388.572,
          -4381.678,
          -4374.293,
          -4366.406,
          -4358.0109999999995,
          -4349.097,
          -4339.656,
          -4329.678,
          -4319.154,
          -4308.0740000000005,
          -4296.427,
          -4284.204000000001,
          -4271.393,
          -4257.983,
          -4243.963,
          -4229.32,
          -4214.044,
          -4198.121,
          -4181.539000000001,
          -4164.284000000001,
          -4146.342000000001,
          -4127.7,
          -4108.343,
          -4088.255,
          -4067.422,
          -4045.827,
          -4023.454,
          -4000.285,
          -3976.303,
          -3951.489,
          -3925.8259999999996,
          -3899.292,
          -3871.868,
          -3843.532,
          -3814.264,
          -3784.04,
          -3752.8379999999997,
          -3720.633,
          -3687.4,
          -3653.113,
          -3617.7459999999996,
          -3581.2709999999997,
          -3543.658,
          -3504.8779999999997,
          -3464.9,
          -3423.692,
          -3381.22,
          -3337.45,
          -3292.3459999999995,
          -3245.87,
          -3197.985,
          -3148.651,
          -3097.825,
          -3045.466,
          -2991.53,
          -2935.97,
          -2878.741,
          -2819.7929999999997,
          -2759.078,
          -2696.5429999999997,
          -2632.138,
          -2565.8089999999997,
          -2497.501,
          -2427.1620000000003,
          -2354.735,
          -2280.166,
          -2203.401,
          -2124.387,
          -2043.0729999999999,
          -1959.41,
          -1873.3529999999998,
          -1784.8629999999998,
          -1693.905,
          -1600.4560000000001,
          -1504.4979999999998,
          -1406.029,
          -1305.059,
          -1201.618,
          -1095.755,
          -987.543,
          -877.08,
          -764.497,
          -649.9580000000001,
          -533.661,
          -415.843,
          -296.78,
          -176.78599999999997,
          -56.211000000000006,
          64.563,
          185.127,
          305.053,
          423.903,
          541.24,
          656.6360000000001,
          769.687,
          880.0160000000001,
          987.2869999999999,
          1091.2069999999999,
          1191.535,
          1288.0739999999998,
          1380.681,
          1469.259,
          1553.753,
          1634.149,
          1710.464,
          1782.747,
          1851.069,
          1915.52,
          1976.207,
          2033.244,
          2086.756,
          2136.871,
          2183.72,
          2227.4339999999997,
          2268.144,
          2305.979,
          2341.064,
          2373.521,
          2403.467,
          2431.016,
          2456.277,
          2479.3520000000003,
          2500.343,
          2519.342,
          2536.44,
          2551.723,
          2565.272,
          2577.1639999999998,
          2587.472,
          2596.266,
          2603.611,
          2609.57,
          2614.202,
          2617.563,
          2619.7070000000003,
          2620.6839999999997,
          2620.5429999999997,
          2619.328,
          2617.083,
          2613.849,
          2609.666,
          2604.57,
          2598.598,
          2591.782,
          2584.154,
          2575.746,
          2566.587,
          2556.7039999999997,
          2546.124,
          2534.8720000000003,
          2522.972,
          2510.448,
          2497.322,
          2483.614,
          2469.346,
          2454.536,
          2439.203,
          2423.365,
          2407.0389999999998,
          2390.241,
          2372.988,
          2355.294,
          2337.173,
          2318.64,
          2299.708,
          2280.391,
          2260.699,
          2240.646,
          2220.243,
          2199.501,
          2178.431,
          2157.0429999999997,
          2135.346,
          2113.3520000000003,
          2091.0679999999998,
          2068.504,
          2045.668,
          2022.569,
          1999.2160000000001,
          1975.615,
          1951.774,
          1927.701,
          1903.4029999999998,
          1878.8870000000002,
          1854.1589999999999,
          1829.226,
          1804.094,
          1778.769,
          1753.257,
          1727.5639999999999,
          1701.695,
          1675.656,
          1649.4520000000002,
          1623.088,
          1596.569,
          1569.9,
          1543.085,
          1516.13,
          1489.0379999999998,
          1461.8139999999999,
          1434.4620000000002,
          1406.986,
          1379.39,
          1351.6789999999999,
          1323.855,
          1295.923,
          1267.885,
          1239.747,
          1211.51,
          1183.1789999999999,
          1154.757,
          1126.247,
          1097.651,
          1068.974,
          1040.218,
          1011.3860000000001,
          982.48,
          953.505,
          924.461,
          895.3530000000001,
          866.182,
          836.952,
          807.664,
          778.322,
          748.927,
          719.482,
          689.9889999999999,
          660.451,
          630.87,
          601.247,
          571.586,
          541.888,
          512.155,
          482.389,
          452.593,
          422.76800000000003,
          392.916,
          363.039,
          333.139,
          303.217,
          273.277,
          243.31799999999998,
          213.34400000000002,
          183.355,
          153.35399999999998,
          123.34200000000001,
          93.32,
          63.291000000000004,
          33.256,
          3.216,
          -26.826,
          -56.87,
          -86.914,
          -116.95700000000001,
          -146.996,
          -177.03099999999998,
          -207.06,
          -237.082,
          -267.096,
          -297.099,
          -327.09,
          -357.07,
          -387.035,
          -416.98400000000004,
          -446.917,
          -476.832,
          -506.728,
          -536.6030000000001,
          -566.457,
          -596.288,
          -626.094,
          -655.8760000000001,
          -685.63,
          -715.357,
          -745.055,
          -774.7230000000001,
          -804.36,
          -833.9639999999999,
          -863.535,
          -893.071,
          -922.571,
          -952.035,
          -981.46,
          -1010.847,
          -1040.193,
          -1069.498,
          -1098.761,
          -1127.98,
          -1157.155,
          -1186.2839999999999,
          -1215.367,
          -1244.402,
          -1273.388,
          -1302.325,
          -1331.211,
          -1360.045,
          -1388.826,
          -1417.5539999999999,
          -1446.227,
          -1474.844,
          -1503.404,
          -1531.906,
          -1560.349,
          -1588.733,
          -1617.055,
          -1645.316,
          -1673.514,
          -1701.648,
          -1729.717,
          -1757.72,
          -1785.656,
          -1813.525,
          -1841.325,
          -1869.055,
          -1896.714,
          -1924.3010000000002,
          -1951.815,
          -1979.256,
          -2006.622,
          -2033.912,
          -2061.126,
          -2088.261,
          -2115.3179999999998,
          -2142.295,
          -2169.192,
          -2196.006,
          -2222.738,
          -2249.387,
          -2275.95,
          -2302.428,
          -2328.8179999999998,
          -2355.1220000000003,
          -2381.3360000000002,
          -2407.46,
          -2433.494,
          -2459.435,
          -2485.284,
          -2511.0389999999998,
          -2536.699,
          -2562.262,
          -2587.729,
          -2613.097,
          -2638.366,
          -2663.535,
          -2688.603,
          -2713.5679999999998,
          -2738.43,
          -2763.187,
          -2787.8379999999997,
          -2812.382,
          -2836.8190000000004,
          -2861.1459999999997,
          -2885.364,
          -2909.47,
          -2933.4640000000004,
          -2957.344,
          -2981.1090000000004,
          -3004.758,
          -3028.2909999999997,
          -3051.705,
          -3075,
          -3098.1740000000004,
          -3121.2259999999997,
          -3144.155,
          -3166.96,
          -3189.64,
          -3212.192,
          -3234.617,
          -3256.9120000000003,
          -3279.077,
          -3301.11,
          -3323.01,
          -3344.775,
          -3366.405,
          -3387.897,
          -3409.2509999999997,
          -3430.465,
          -3451.5370000000003,
          -3472.468,
          -3493.2540000000004,
          -3513.8940000000002,
          -3534.388,
          -3554.7329999999997,
          -3574.928,
          -3594.973,
          -3614.864,
          -3634.6009999999997,
          -3654.1820000000002,
          -3673.605,
          -3692.87,
          -3711.974,
          -3730.9159999999997,
          -3749.6940000000004,
          -3768.3070000000002,
          -3786.752,
          -3805.0290000000005,
          -3823.135,
          -3841.0679999999998,
          -3858.828,
          -3876.4120000000003,
          -3893.8190000000004,
          -3911.046,
          -3928.092,
          -3944.954,
          -3961.632,
          -3978.123,
          -3994.425,
          -4010.5359999999996,
          -4026.454,
          -4042.177,
          -4057.704,
          -4073.031,
          -4088.157,
          -4103.08,
          -4117.798,
          -4132.308,
          -4146.608,
          -4160.696,
          -4174.569,
          -4188.226,
          -4201.663,
          -4214.879,
          -4227.87,
          -4240.635,
          -4253.170999999999,
          -4265.475,
          -4277.544,
          -4289.377,
          -4300.97,
          -4312.321,
          -4323.4259999999995,
          -4334.282999999999,
          -4344.889,
          -4355.241,
          -4365.335999999999,
          -4375.170999999999,
          -4384.7429999999995,
          -4394.049,
          -4403.085,
          -4411.848,
          -4420.335,
          -4428.543,
          -4436.468,
          -4444.106,
          -4451.454000000001,
          -4458.508,
          -4465.264,
          -4471.72,
          -4477.87,
          -4483.710999999999,
          -4489.238,
          -4494.4490000000005,
          -4499.337,
          -4503.9,
          -4508.133,
          -4512.031,
          -4515.59,
          -4518.805,
          -4521.670999999999,
          -4524.183,
          -4526.338,
          -4528.128,
          -4529.55,
          -4530.597,
          -4531.265,
          -4531.548,
          -4531.441,
          -4530.936,
          -4530.03,
          -4528.714,
          -4526.984,
          -4524.832,
          -4522.253,
          -4519.24,
          -4515.785,
          -4511.8820000000005,
          -4507.523,
          -4502.701,
          -4497.409000000001,
          -4491.639,
          -4485.3820000000005,
          -4478.6320000000005,
          -4471.378,
          -4463.613,
          -4455.327,
          -4446.513,
          -4437.159000000001,
          -4427.2570000000005,
          -4416.7970000000005,
          -4405.769,
          -4394.162,
          -4381.965,
          -4369.168,
          -4355.759,
          -4341.726,
          -4327.058,
          -4311.741,
          -4295.763,
          -4279.111,
          -4261.772,
          -4243.73,
          -4224.972,
          -4205.483,
          -4185.247,
          -4164.249,
          -4142.471,
          -4119.898,
          -4096.51,
          -4072.2909999999997,
          -4047.2209999999995,
          -4021.282,
          -3994.452,
          -3966.711,
          -3938.038,
          -3908.4109999999996,
          -3877.805,
          -3846.198,
          -3813.565,
          -3779.88,
          -3745.116,
          -3709.2459999999996,
          -3672.241,
          -3634.072,
          -3594.7070000000003,
          -3554.116,
          -3512.265,
          -3469.119,
          -3424.6440000000002,
          -3378.802,
          -3331.555,
          -3282.864,
          -3232.688,
          -3180.9829999999997,
          -3127.7070000000003,
          -3072.8140000000003,
          -3016.257,
          -2957.988,
          -2897.9570000000003,
          -2836.112,
          -2772.402,
          -2706.7729999999997,
          -2639.1690000000003,
          -2569.535,
          -2497.815,
          -2423.953,
          -2347.89,
          -2269.572,
          -2188.942,
          -2105.949,
          -2020.54,
          -1932.67,
          -1842.295,
          -1749.381,
          -1653.9,
          -1555.8339999999998,
          -1455.1779999999999,
          -1351.942,
          -1246.152,
          -1137.857,
          -1027.129,
          -914.067,
          -798.802,
          -681.498,
          -562.355,
          -441.615,
          -319.555,
          -196.49599999999998,
          -72.793,
          51.163999999999994,
          174.956,
          298.147,
          420.288,
          540.928,
          659.63,
          775.9739999999999,
          889.574,
          1000.081,
          1107.191,
          1210.65,
          1310.256,
          1405.856,
          1497.346,
          1584.6660000000002,
          1667.797,
          1746.755,
          1821.586,
          1892.36,
          1959.1689999999999,
          2022.1170000000002,
          2081.321,
          2136.909,
          2189.008,
          2237.754,
          2283.28,
          2325.719,
          2365.202,
          2401.857,
          2435.81,
          2467.18,
          2496.083,
          2522.631,
          2546.931,
          2569.083,
          2589.185,
          2607.3289999999997,
          2623.603,
          2638.1679999999997,
          2650.869,
          2662.0159999999996,
          2671.6020000000003,
          2679.695,
          2686.3579999999997,
          2691.653,
          2695.636,
          2698.364,
          2699.888,
          2700.257,
          2699.5190000000002,
          2697.717,
          2694.8940000000002,
          2691.091,
          2686.345,
          2680.6929999999998,
          2674.17,
          2666.809,
          2658.6409999999996,
          2649.696,
          2640.0029999999997,
          2629.5890000000004,
          2618.48,
          2606.702,
          2594.278,
          2581.23,
          2567.581,
          2553.351,
          2538.561,
          2523.23,
          2507.375,
          2491.015,
          2474.166,
          2456.845,
          2439.067,
          2420.847,
          2402.2,
          2383.139,
          2363.677,
          2343.828,
          2323.604,
          2303.016,
          2282.077,
          2260.797,
          2239.186,
          2217.256,
          2195.015,
          2172.474,
          2149.641,
          2126.527,
          2103.138,
          2079.485,
          2055.574,
          2031.4129999999998,
          2007.011,
          1982.374,
          1957.51,
          1932.425,
          1907.126,
          1881.62,
          1855.912,
          1830.009,
          1803.918,
          1777.6429999999998,
          1751.1889999999999,
          1724.5639999999999,
          1697.771,
          1670.816,
          1643.704,
          1616.44,
          1589.0279999999998,
          1561.474,
          1533.78,
          1505.953,
          1477.995,
          1449.912,
          1421.707,
          1393.384,
          1364.9460000000001,
          1336.399,
          1307.745,
          1278.987,
          1250.13,
          1221.1760000000002,
          1192.13,
          1162.993,
          1133.77,
          1104.463,
          1075.076,
          1045.611,
          1016.072,
          986.46,
          956.78,
          927.0319999999999,
          897.222,
          867.3489999999999,
          837.418,
          807.431,
          777.3910000000001,
          747.298,
          717.1569999999999,
          686.9689999999999,
          656.737,
          626.462,
          596.148,
          565.795,
          535.4069999999999,
          504.98400000000004,
          474.53,
          444.046,
          413.535,
          382.99699999999996,
          352.435,
          321.851,
          291.247,
          260.625,
          229.985,
          199.33,
          168.66299999999998,
          137.983,
          107.294,
          76.596,
          45.891000000000005,
          15.182,
          -15.532,
          -46.247,
          -76.962,
          -107.677,
          -138.389,
          -169.097,
          -199.8,
          -230.49599999999998,
          -261.183,
          -291.861,
          -322.528,
          -353.18199999999996,
          -383.82300000000004,
          -414.44800000000004,
          -445.05699999999996,
          -475.648,
          -506.22,
          -536.7719999999999,
          -567.302,
          -597.809,
          -628.2919999999999,
          -658.75,
          -689.181,
          -719.585,
          -749.959,
          -780.303,
          -810.6160000000001,
          -840.8969999999999,
          -871.143,
          -901.355,
          -931.5310000000001,
          -961.67,
          -991.77,
          -1021.831,
          -1051.8519999999999,
          -1081.8310000000001,
          -1111.767,
          -1141.6589999999999,
          -1171.507,
          -1201.308,
          -1231.063,
          -1260.769,
          -1290.4260000000002,
          -1320.033,
          -1349.588,
          -1379.0910000000001,
          -1408.5410000000002,
          -1437.9360000000001,
          -1467.275,
          -1496.558,
          -1525.7839999999999,
          -1554.95,
          -1584.057,
          -1613.104,
          -1642.088,
          -1671.01,
          -1699.868,
          -1728.661,
          -1757.388,
          -1786.049,
          -1814.641,
          -1843.165,
          -1871.619,
          -1900.0020000000002,
          -1928.3120000000001,
          -1956.55,
          -1984.714,
          -2012.8029999999999,
          -2040.816,
          -2068.751,
          -2096.609,
          -2124.388,
          -2152.0860000000002,
          -2179.703,
          -2207.238,
          -2234.69,
          -2262.058,
          -2289.34,
          -2316.536,
          -2343.645,
          -2370.665,
          -2397.596,
          -2424.436,
          -2451.185,
          -2477.841,
          -2504.404,
          -2530.8720000000003,
          -2557.244,
          -2583.519,
          -2609.696,
          -2635.7740000000003,
          -2661.752,
          -2687.6290000000004,
          -2713.403,
          -2739.074,
          -2764.6409999999996,
          -2790.1009999999997,
          -2815.455,
          -2840.7009999999996,
          -2865.8390000000004,
          -2890.865,
          -2915.781,
          -2940.5840000000003,
          -2965.2729999999997,
          -2989.848,
          -3014.3059999999996,
          -3038.647,
          -3062.87,
          -3086.973,
          -3110.9559999999997,
          -3134.816,
          -3158.553,
          -3182.165,
          -3205.651,
          -3229.011,
          -3252.242,
          -3275.343,
          -3298.3140000000003,
          -3321.152,
          -3343.857,
          -3366.426,
          -3388.86,
          -3411.155,
          -3433.312,
          -3455.328,
          -3477.203,
          -3498.934,
          -3520.5209999999997,
          -3541.962,
          -3563.255,
          -3584.3990000000003,
          -3605.3920000000003,
          -3626.2340000000004,
          -3646.922,
          -3667.455,
          -3687.8309999999997,
          -3708.0490000000004,
          -3728.1079999999997,
          -3748.005,
          -3767.738,
          -3787.308,
          -3806.711,
          -3825.946,
          -3845.011,
          -3863.905,
          -3882.625,
          -3901.171,
          -3919.54,
          -3937.73,
          -3955.74,
          -3973.5679999999998,
          -3991.211,
          -4008.6690000000003,
          -4025.938,
          -4043.018,
          -4059.905,
          -4076.599,
          -4093.0959999999995,
          -4109.396,
          -4125.495,
          -4141.392,
          -4157.084,
          -4172.57,
          -4187.846,
          -4202.912,
          -4217.764,
          -4232.4,
          -4246.818,
          -4261.016,
          -4274.99,
          -4288.7390000000005,
          -4302.26,
          -4315.5509999999995,
          -4328.608,
          -4341.429,
          -4354.012,
          -4366.354,
          -4378.452,
          -4390.302,
          -4401.904,
          -4413.252,
          -4424.345,
          -4435.18,
          -4445.752,
          -4456.06,
          -4466.101,
          -4475.869000000001,
          -4485.3640000000005,
          -4494.58,
          -4503.516,
          -4512.166,
          -4520.529,
          -4528.599,
          -4536.374,
          -4543.85,
          -4551.022,
          -4557.887,
          -4564.442,
          -4570.681,
          -4576.601,
          -4582.198,
          -4587.467000000001,
          -4592.404,
          -4597.004,
          -4601.263,
          -4605.1759999999995,
          -4608.7390000000005,
          -4611.946,
          -4614.793,
          -4617.274,
          -4619.385,
          -4621.119000000001,
          -4622.472,
          -4623.438,
          -4624.0109999999995,
          -4624.186,
          -4623.956,
          -4623.315,
          -4622.258,
          -4620.778,
          -4618.8679999999995,
          -4616.521,
          -4613.732,
          -4610.492,
          -4606.795,
          -4602.6320000000005,
          -4597.998,
          -4592.883,
          -4587.281,
          -4581.182,
          -4574.5779999999995,
          -4567.460999999999,
          -4559.822,
          -4551.652,
          -4542.942,
          -4533.682,
          -4523.862,
          -4513.472,
          -4502.501,
          -4490.94,
          -4478.776,
          -4466,
          -4452.598,
          -4438.559,
          -4423.871,
          -4408.521,
          -4392.495,
          -4375.781,
          -4358.365,
          -4340.231,
          -4321.365,
          -4301.752,
          -4281.376,
          -4260.221,
          -4238.269,
          -4215.504,
          -4191.907999999999,
          -4167.460999999999,
          -4142.144,
          -4115.939,
          -4088.823,
          -4060.776,
          -4031.776,
          -4001.7990000000004,
          -3970.823,
          -3938.823,
          -3905.7729999999997,
          -3871.6459999999997,
          -3836.417,
          -3800.0559999999996,
          -3762.534,
          -3723.821,
          -3683.886,
          -3642.6940000000004,
          -3600.2140000000004,
          -3556.409,
          -3511.243,
          -3464.678,
          -3416.6740000000004,
          -3367.1929999999998,
          -3316.19,
          -3263.623,
          -3209.446,
          -3153.614,
          -3096.0759999999996,
          -3036.785,
          -2975.69,
          -2912.735,
          -2847.868,
          -2781.034,
          -2712.177,
          -2641.237,
          -2568.158,
          -2492.881,
          -2415.347,
          -2335.498,
          -2253.277,
          -2168.6279999999997,
          -2081.498,
          -1991.84,
          -1899.6070000000002,
          -1804.7620000000002,
          -1707.277,
          -1607.13,
          -1504.315,
          -1398.839,
          -1290.73,
          -1180.032,
          -1066.818,
          -951.187,
          -833.2689999999999,
          -713.2289999999999,
          -591.271,
          -467.63599999999997,
          -342.60900000000004,
          -216.513,
          -89.71,
          37.403,
          164.399,
          290.83,
          416.23800000000006,
          540.161,
          662.148,
          781.7689999999999,
          898.6239999999999,
          1012.352,
          1122.638,
          1229.219,
          1331.882,
          1430.467,
          1524.862,
          1615.003,
          1700.866,
          1782.464,
          1859.8410000000001,
          1933.067,
          2002.2320000000002,
          2067.442,
          2128.815,
          2186.48,
          2240.567,
          2291.212,
          2338.552,
          2382.723,
          2423.8579999999997,
          2462.0879999999997,
          2497.541,
          2530.339,
          2560.603,
          2588.444,
          2613.972,
          2637.292,
          2658.502,
          2677.697,
          2694.968,
          2710.3990000000003,
          2724.073,
          2736.065,
          2746.45,
          2755.297,
          2762.671,
          2768.634,
          2773.2470000000003,
          2776.566,
          2778.6440000000002,
          2779.531,
          2779.276,
          2777.9240000000004,
          2775.5190000000002,
          2772.103,
          2767.7140000000004,
          2762.3909999999996,
          2756.1679999999997,
          2749.08,
          2741.16,
          2732.437,
          2722.941,
          2712.702,
          2701.744,
          2690.094,
          2677.777,
          2664.816,
          2651.2329999999997,
          2637.05,
          2622.2870000000003,
          2606.965,
          2591.101,
          2574.714,
          2557.822,
          2540.4410000000003,
          2522.587,
          2504.276,
          2485.522,
          2466.34,
          2446.743,
          2426.744,
          2406.356,
          2385.592,
          2364.4629999999997,
          2342.981,
          2321.156,
          2298.999,
          2276.521,
          2253.73,
          2230.637,
          2207.251,
          2183.581,
          2159.635,
          2135.422,
          2110.95,
          2086.226,
          2061.258,
          2036.0529999999999,
          2010.619,
          1984.963,
          1959.09,
          1933.0079999999998,
          1906.723,
          1880.24,
          1853.566,
          1826.707,
          1799.668,
          1772.454,
          1745.0710000000001,
          1717.524,
          1689.818,
          1661.9579999999999,
          1633.9479999999999,
          1605.793,
          1577.4979999999998,
          1549.066,
          1520.503,
          1491.8120000000001,
          1462.997,
          1434.0629999999999,
          1405.013,
          1375.851,
          1346.58,
          1317.204,
          1287.7269999999999,
          1258.152,
          1228.482,
          1198.721,
          1168.87,
          1138.937,
          1108.92,
          1078.8239999999998,
          1048.652,
          1018.405,
          988.09,
          957.706,
          927.2560000000001,
          896.745,
          866.173,
          835.543,
          804.8589999999999,
          774.122,
          743.336,
          712.5,
          681.62,
          650.696,
          619.731,
          588.727,
          557.686,
          526.61,
          495.501,
          464.36199999999997,
          433.194,
          401.999,
          370.779,
          339.536,
          308.272,
          276.98900000000003,
          245.688,
          214.372,
          183.041,
          151.69799999999998,
          120.345,
          88.98200000000001,
          57.611999999999995,
          26.237,
          -5.143,
          -36.525,
          -67.908,
          -99.29,
          -130.671,
          -162.047,
          -193.419,
          -224.78400000000002,
          -256.14099999999996,
          -287.48900000000003,
          -318.82599999999996,
          -350.151,
          -381.462,
          -412.75800000000004,
          -444.038,
          -475.3,
          -506.54400000000004,
          -537.7669999999999,
          -568.9680000000001,
          -600.1469999999999,
          -631.3009999999999,
          -662.43,
          -693.533,
          -724.6080000000001,
          -755.653,
          -786.668,
          -817.6519999999999,
          -848.6030000000001,
          -879.52,
          -910.403,
          -941.248,
          -972.057,
          -1002.827,
          -1033.556,
          -1064.245,
          -1094.892,
          -1125.496,
          -1156.056,
          -1186.5710000000001,
          -1217.038,
          -1247.4589999999998,
          -1277.83,
          -1308.152,
          -1338.4229999999998,
          -1368.642,
          -1398.808,
          -1428.9189999999999,
          -1458.976,
          -1488.976,
          -1518.9189999999999,
          -1548.8039999999999,
          -1578.63,
          -1608.3929999999998,
          -1638.096,
          -1667.737,
          -1697.3129999999999,
          -1726.825,
          -1756.271,
          -1785.65,
          -1814.9620000000002,
          -1844.204,
          -1873.376,
          -1902.4779999999998,
          -1931.507,
          -1960.463,
          -1989.345,
          -2018.152,
          -2046.882,
          -2075.535,
          -2104.11,
          -2132.605,
          -2161.02,
          -2189.353,
          -2217.603,
          -2245.77,
          -2273.853,
          -2301.849,
          -2329.759,
          -2357.581,
          -2385.313,
          -2412.956,
          -2440.508,
          -2467.967,
          -2495.333,
          -2522.605,
          -2549.782,
          -2576.861,
          -2603.843,
          -2630.7270000000003,
          -2657.51,
          -2684.1929999999998,
          -2710.7729999999997,
          -2737.25,
          -2763.623,
          -2789.89,
          -2816.05,
          -2842.103,
          -2868.047,
          -2893.88,
          -2919.6020000000003,
          -2945.212,
          -2970.708,
          -2996.0890000000004,
          -3021.3540000000003,
          -3046.502,
          -3071.531,
          -3096.441,
          -3121.2290000000003,
          -3145.895,
          -3170.438,
          -3194.8559999999998,
          -3219.1479999999997,
          -3243.313,
          -3267.349,
          -3291.255,
          -3315.0290000000005,
          -3338.672,
          -3362.18,
          -3385.553,
          -3408.789,
          -3431.888,
          -3454.8459999999995,
          -3477.665,
          -3500.34,
          -3522.8720000000003,
          -3545.259,
          -3567.5,
          -3589.592,
          -3611.535,
          -3633.327,
          -3654.966,
          -3676.4509999999996,
          -3697.78,
          -3718.952,
          -3739.965,
          -3760.8179999999998,
          -3781.509,
          -3802.0359999999996,
          -3822.397,
          -3842.592,
          -3862.618,
          -3882.473,
          -3902.156,
          -3921.665,
          -3940.998,
          -3960.153,
          -3979.1290000000004,
          -3997.9240000000004,
          -4016.5359999999996,
          -4034.962,
          -4053.202,
          -4071.252,
          -4089.112,
          -4106.778,
          -4124.25,
          -4141.524,
          -4158.6,
          -4175.474,
          -4192.145,
          -4208.61,
          -4224.867,
          -4240.914000000001,
          -4256.749,
          -4272.369000000001,
          -4287.773,
          -4302.956,
          -4317.918,
          -4332.656,
          -4347.167,
          -4361.4490000000005,
          -4375.499,
          -4389.314,
          -4402.892,
          -4416.231,
          -4429.326,
          -4442.177,
          -4454.779,
          -4467.13,
          -4479.227,
          -4491.067,
          -4502.648,
          -4513.965,
          -4525.015,
          -4535.7970000000005,
          -4546.305,
          -4556.538,
          -4566.491,
          -4576.162,
          -4585.545999999999,
          -4594.64,
          -4603.441,
          -4611.945,
          -4620.148,
          -4628.045999999999,
          -4635.635,
          -4642.912,
          -4649.872,
          -4656.5109999999995,
          -4662.825,
          -4668.809,
          -4674.46,
          -4679.773,
          -4684.742,
          -4689.365,
          -4693.634,
          -4697.5470000000005,
          -4701.097,
          -4704.281,
          -4707.090999999999,
          -4709.524,
          -4711.5740000000005,
          -4713.235,
          -4714.501,
          -4715.367,
          -4715.827,
          -4715.875,
          -4715.504,
          -4714.709,
          -4713.482,
          -4711.816,
          -4709.706,
          -4707.144,
          -4704.123,
          -4700.6359999999995,
          -4696.674,
          -4692.231,
          -4687.298,
          -4681.8679999999995,
          -4675.931,
          -4669.479,
          -4662.504,
          -4654.997,
          -4646.947,
          -4638.347,
          -4629.185,
          -4619.452,
          -4609.137,
          -4598.231,
          -4586.721,
          -4574.597,
          -4561.847,
          -4548.459,
          -4534.420999999999,
          -4519.72,
          -4504.343,
          -4488.278,
          -4471.509,
          -4454.022,
          -4435.804,
          -4416.838,
          -4397.109,
          -4376.602,
          -4355.298,
          -4333.181,
          -4310.233,
          -4286.436,
          -4261.771,
          -4236.217000000001,
          -4209.755,
          -4182.3640000000005,
          -4154.021,
          -4124.704000000001,
          -4094.39,
          -4063.054,
          -4030.671,
          -3997.216,
          -3962.6609999999996,
          -3926.978,
          -3890.139,
          -3852.113,
          -3812.869,
          -3772.375,
          -3730.597,
          -3687.5009999999997,
          -3643.051,
          -3597.2090000000003,
          -3549.935,
          -3501.191,
          -3450.935,
          -3399.1220000000003,
          -3345.7090000000003,
          -3290.6490000000003,
          -3233.893,
          -3175.3940000000002,
          -3115.099,
          -3052.9559999999997,
          -2988.9109999999996,
          -2922.907,
          -2854.889,
          -2784.798,
          -2712.574,
          -2638.158,
          -2561.489,
          -2482.507,
          -2401.151,
          -2317.361,
          -2231.0820000000003,
          -2142.257,
          -2050.8360000000002,
          -1956.771,
          -1860.024,
          -1760.5610000000001,
          -1658.362,
          -1553.4170000000001,
          -1445.7320000000002,
          -1335.3329999999999,
          -1222.263,
          -1106.594,
          -988.425,
          -867.885,
          -745.1419999999999,
          -620.399,
          -493.902,
          -365.93800000000005,
          -236.835,
          -106.961,
          23.279,
          153.45,
          283.096,
          411.746,
          538.928,
          664.18,
          787.058,
          907.1489999999999,
          1024.083,
          1137.532,
          1247.222,
          1352.931,
          1454.491,
          1551.7839999999999,
          1644.739,
          1733.33,
          1817.565,
          1897.486,
          1973.161,
          2044.682,
          2112.154,
          2175.697,
          2235.44,
          2291.516,
          2344.063,
          2393.221,
          2439.126,
          2481.917,
          2521.726,
          2558.6839999999997,
          2592.915,
          2624.5429999999997,
          2653.6820000000002,
          2680.445,
          2704.937,
          2727.261,
          2747.514,
          2765.788,
          2782.17,
          2796.743,
          2809.5879999999997,
          2820.778,
          2830.385,
          2838.4759999999997,
          2845.116,
          2850.365,
          2854.282,
          2856.92,
          2858.3320000000003,
          2858.5679999999998,
          2857.6740000000004,
          2855.6940000000004,
          2852.673,
          2848.6490000000003,
          2843.6609999999996,
          2837.7459999999996,
          2830.94,
          2823.2740000000003,
          2814.781,
          2805.491,
          2795.4320000000002,
          2784.634,
          2773.1209999999996,
          2760.9190000000003,
          2748.052,
          2734.5429999999997,
          2720.414,
          2705.687,
          2690.381,
          2674.5170000000003,
          2658.112,
          2641.184,
          2623.7509999999997,
          2605.83,
          2587.435,
          2568.5820000000003,
          2549.2870000000003,
          2529.562,
          2509.422,
          2488.879,
          2467.946,
          2446.636,
          2424.96,
          2402.928,
          2380.553,
          2357.845,
          2334.813,
          2311.468,
          2287.819,
          2263.875,
          2239.646,
          2215.138,
          2190.362,
          2165.325,
          2140.034,
          2114.498,
          2088.723,
          2062.716,
          2036.486,
          2010.037,
          1983.3770000000002,
          1956.5120000000002,
          1929.4470000000001,
          1902.19,
          1874.745,
          1847.119,
          1819.316,
          1791.342,
          1763.2020000000002,
          1734.901,
          1706.444,
          1677.836,
          1649.0810000000001,
          1620.183,
          1591.148,
          1561.98,
          1532.681,
          1503.2579999999998,
          1473.713,
          1444.0510000000002,
          1414.274,
          1384.388,
          1354.395,
          1324.299,
          1294.103,
          1263.812,
          1233.427,
          1202.953,
          1172.392,
          1141.747,
          1111.022,
          1080.219,
          1049.3410000000001,
          1018.3919999999999,
          987.3739999999999,
          956.289,
          925.14,
          893.93,
          862.6610000000001,
          831.336,
          799.9580000000001,
          768.528,
          737.049,
          705.523,
          673.953,
          642.341,
          610.688,
          578.998,
          547.2719999999999,
          515.513,
          483.722,
          451.901,
          420.05300000000005,
          388.17900000000003,
          356.281,
          324.361,
          292.421,
          260.46299999999997,
          228.489,
          196.5,
          164.498,
          132.484,
          100.462,
          68.431,
          36.394,
          4.353,
          -27.691999999999997,
          -59.736999999999995,
          -91.78299999999999,
          -123.82700000000001,
          -155.86700000000002,
          -187.903,
          -219.93200000000002,
          -251.954,
          -283.967,
          -315.969,
          -347.959,
          -379.936,
          -411.898,
          -443.843,
          -475.77099999999996,
          -507.681,
          -539.57,
          -571.437,
          -603.2819999999999,
          -635.102,
          -666.8969999999999,
          -698.665,
          -730.4060000000001,
          -762.117,
          -793.797,
          -825.446,
          -857.062,
          -888.6439999999999,
          -920.19,
          -951.7,
          -983.172,
          -1014.605,
          -1045.998,
          -1077.35,
          -1108.66,
          -1139.925,
          -1171.146,
          -1202.3210000000001,
          -1233.45,
          -1264.53,
          -1295.56,
          -1326.5410000000002,
          -1357.469,
          -1388.345,
          -1419.168,
          -1449.935,
          -1480.6470000000002,
          -1511.3020000000001,
          -1541.898,
          -1572.435,
          -1602.912,
          -1633.328,
          -1663.681,
          -1693.97,
          -1724.195,
          -1754.354,
          -1784.4460000000001,
          -1814.47,
          -1844.4260000000002,
          -1874.3110000000001,
          -1904.126,
          -1933.868,
          -1963.536,
          -1993.131,
          -2022.65,
          -2052.093,
          -2081.458,
          -2110.744,
          -2139.951,
          -2169.077,
          -2198.121,
          -2227.0820000000003,
          -2255.959,
          -2284.751,
          -2313.456,
          -2342.075,
          -2370.605,
          -2399.045,
          -2427.395,
          -2455.653,
          -2483.8179999999998,
          -2511.89,
          -2539.866,
          -2567.746,
          -2595.529,
          -2623.2129999999997,
          -2650.798,
          -2678.282,
          -2705.665,
          -2732.9440000000004,
          -2760.119,
          -2787.1890000000003,
          -2814.152,
          -2841.008,
          -2867.755,
          -2894.3920000000003,
          -2920.9179999999997,
          -2947.3309999999997,
          -2973.631,
          -2999.816,
          -3025.885,
          -3051.836,
          -3077.6690000000003,
          -3103.383,
          -3128.975,
          -3154.445,
          -3179.7909999999997,
          -3205.012,
          -3230.1079999999997,
          -3255.0759999999996,
          -3279.915,
          -3304.623,
          -3329.2009999999996,
          -3353.6459999999997,
          -3377.9559999999997,
          -3402.131,
          -3426.1690000000003,
          -3450.0690000000004,
          -3473.828,
          -3497.447,
          -3520.923,
          -3544.255,
          -3567.442,
          -3590.4809999999998,
          -3613.373,
          -3636.114,
          -3658.703,
          -3681.14,
          -3703.421,
          -3725.547,
          -3747.515,
          -3769.323,
          -3790.9709999999995,
          -3812.455,
          -3833.776,
          -3854.93,
          -3875.917,
          -3896.7340000000004,
          -3917.38,
          -3937.853,
          -3958.151,
          -3978.2729999999997,
          -3998.217,
          -4017.98,
          -4037.5609999999997,
          -4056.958,
          -4076.1690000000003,
          -4095.1929999999998,
          -4114.026,
          -4132.668,
          -4151.116,
          -4169.3679999999995,
          -4187.4220000000005,
          -4205.276,
          -4222.928,
          -4240.375,
          -4257.616,
          -4274.648,
          -4291.469,
          -4308.077,
          -4324.468,
          -4340.642,
          -4356.595,
          -4372.326,
          -4387.831,
          -4403.108,
          -4418.155,
          -4432.968,
          -4447.545999999999,
          -4461.8859999999995,
          -4475.985,
          -4489.84,
          -4503.448,
          -4516.807,
          -4529.913,
          -4542.765,
          -4555.358,
          -4567.689,
          -4579.7570000000005,
          -4591.556,
          -4603.085,
          -4614.34,
          -4625.318,
          -4636.014,
          -4646.427,
          -4656.552,
          -4666.3859999999995,
          -4675.924,
          -4685.165,
          -4694.103,
          -4702.734,
          -4711.056,
          -4719.063,
          -4726.752,
          -4734.119000000001,
          -4741.16,
          -4747.869000000001,
          -4754.2429999999995,
          -4760.278,
          -4765.968,
          -4771.309,
          -4776.295999999999,
          -4780.924,
          -4785.189,
          -4789.085,
          -4792.607,
          -4795.75,
          -4798.508,
          -4800.875,
          -4802.847,
          -4804.417,
          -4805.579000000001,
          -4806.3279999999995,
          -4806.656,
          -4806.559,
          -4806.028,
          -4805.058,
          -4803.641,
          -4801.771,
          -4799.441,
          -4796.643,
          -4793.369000000001,
          -4789.613,
          -4785.366,
          -4780.619000000001,
          -4775.365,
          -4769.595,
          -4763.3009999999995,
          -4756.473,
          -4749.102,
          -4741.179,
          -4732.693,
          -4723.6359999999995,
          -4713.996,
          -4703.763,
          -4692.927,
          -4681.475,
          -4669.397,
          -4656.68,
          -4643.313,
          -4629.282999999999,
          -4614.577,
          -4599.181,
          -4583.082,
          -4566.266,
          -4548.718,
          -4530.424,
          -4511.366,
          -4491.531,
          -4470.9,
          -4449.457,
          -4427.185,
          -4404.064,
          -4380.076,
          -4355.202,
          -4329.4220000000005,
          -4302.714,
          -4275.057,
          -4246.43,
          -4216.807,
          -4186.167,
          -4154.483,
          -4121.731,
          -4087.882,
          -4052.9109999999996,
          -4016.788,
          -3979.4840000000004,
          -3940.968,
          -3901.2070000000003,
          -3860.17,
          -3817.821,
          -3774.125,
          -3729.045,
          -3682.542,
          -3634.578,
          -3585.11,
          -3534.0959999999995,
          -3481.491,
          -3427.25,
          -3371.325,
          -3313.667,
          -3254.225,
          -3192.947,
          -3129.778,
          -3064.664,
          -2997.546,
          -2928.366,
          -2857.065,
          -2783.5809999999997,
          -2707.8520000000003,
          -2629.817,
          -2549.4120000000003,
          -2466.575,
          -2381.246,
          -2293.364,
          -2202.873,
          -2109.718,
          -2013.852,
          -1915.2320000000002,
          -1813.8239999999998,
          -1709.604,
          -1602.5620000000001,
          -1492.7020000000002,
          -1380.046,
          -1264.639,
          -1146.55,
          -1025.878,
          -902.752,
          -777.34,
          -649.8480000000001,
          -520.523,
          -389.655,
          -257.578,
          -124.666,
          8.671,
          141.988,
          274.82099999999997,
          406.689,
          537.107,
          665.602,
          791.717,
          915.029,
          1035.153,
          1151.752,
          1264.5410000000002,
          1373.289,
          1477.818,
          1578.004,
          1673.77,
          1765.086,
          1851.957,
          1934.422,
          2012.5479999999998,
          2086.427,
          2156.1639999999998,
          2221.88,
          2283.705,
          2341.774,
          2396.229,
          2447.209,
          2494.855,
          2539.3070000000002,
          2580.701,
          2619.17,
          2654.841,
          2687.8390000000004,
          2718.283,
          2746.2870000000003,
          2771.9590000000003,
          2795.405,
          2816.722,
          2836.006,
          2853.317,
          2868.827,
          2882.531,
          2894.534,
          2904.909,
          2913.7259999999997,
          2921.05,
          2926.9429999999998,
          2931.465,
          2934.672,
          2936.617,
          2937.3520000000003,
          2936.923,
          2935.377,
          2932.758,
          2929.107,
          2924.4629999999997,
          2918.865,
          2912.347,
          2904.945,
          2896.6890000000003,
          2887.613,
          2877.745,
          2867.113,
          2855.745,
          2843.667,
          2830.902,
          2817.4759999999997,
          2803.41,
          2788.7270000000003,
          2773.447,
          2757.5890000000004,
          2741.1740000000004,
          2724.22,
          2706.744,
          2688.763,
          2670.2929999999997,
          2651.35,
          2631.95,
          2612.106,
          2591.8320000000003,
          2571.143,
          2550.05,
          2528.567,
          2506.705,
          2484.476,
          2461.8920000000003,
          2438.962,
          2415.698,
          2392.109,
          2368.205,
          2343.996,
          2319.491,
          2294.698,
          2269.626,
          2244.284,
          2218.679,
          2192.819,
          2166.712,
          2140.364,
          2113.784,
          2086.9770000000003,
          2059.951,
          2032.711,
          2005.265,
          1977.618,
          1949.776,
          1921.745,
          1893.53,
          1865.138,
          1836.5720000000001,
          1807.839,
          1778.944,
          1749.89,
          1720.684,
          1691.329,
          1661.83,
          1632.192,
          1602.418,
          1572.514,
          1542.483,
          1512.328,
          1482.055,
          1451.6660000000002,
          1421.165,
          1390.557,
          1359.844,
          1329.03,
          1298.118,
          1267.112,
          1236.015,
          1204.83,
          1173.56,
          1142.208,
          1110.777,
          1079.271,
          1047.691,
          1016.04,
          984.323,
          952.54,
          920.695,
          888.789,
          856.827,
          824.81,
          792.7410000000001,
          760.6210000000001,
          728.454,
          696.2410000000001,
          663.9860000000001,
          631.689,
          599.354,
          566.982,
          534.575,
          502.13599999999997,
          469.667,
          437.16900000000004,
          404.645,
          372.097,
          339.526,
          306.934,
          274.323,
          241.695,
          209.05200000000002,
          176.396,
          143.727,
          111.04899999999999,
          78.362,
          45.669,
          12.970999999999998,
          -19.730999999999998,
          -52.434,
          -85.137,
          -117.84,
          -150.539,
          -183.233,
          -215.922,
          -248.60299999999998,
          -281.276,
          -313.937,
          -346.587,
          -379.224,
          -411.846,
          -444.452,
          -477.04,
          -509.61,
          -542.159,
          -574.687,
          -607.191,
          -639.672,
          -672.127,
          -704.555,
          -736.955,
          -769.326,
          -801.666,
          -833.9739999999999,
          -866.248,
          -898.4889999999999,
          -930.693,
          -962.8610000000001,
          -994.9910000000001,
          -1027.0810000000001,
          -1059.131,
          -1091.139,
          -1123.105,
          -1155.026,
          -1186.902,
          -1218.731,
          -1250.513,
          -1282.246,
          -1313.93,
          -1345.5620000000001,
          -1377.142,
          -1408.6689999999999,
          -1440.141,
          -1471.558,
          -1502.918,
          -1534.22,
          -1565.464,
          -1596.6470000000002,
          -1627.769,
          -1658.828,
          -1689.825,
          -1720.756,
          -1751.6229999999998,
          -1782.422,
          -1813.154,
          -1843.816,
          -1874.4089999999999,
          -1904.93,
          -1935.38,
          -1965.755,
          -1996.056,
          -2026.2820000000002,
          -2056.431,
          -2086.5029999999997,
          -2116.495,
          -2146.409,
          -2176.239,
          -2205.989,
          -2235.655,
          -2265.236,
          -2294.7329999999997,
          -2324.1420000000003,
          -2353.464,
          -2382.697,
          -2411.839,
          -2440.891,
          -2469.85,
          -2498.716,
          -2527.488,
          -2556.1639999999998,
          -2584.742,
          -2613.223,
          -2641.605,
          -2669.887,
          -2698.067,
          -2726.1440000000002,
          -2754.118,
          -2781.986,
          -2809.7490000000003,
          -2837.4040000000005,
          -2864.95,
          -2892.387,
          -2919.712,
          -2946.926,
          -2974.026,
          -3001.011,
          -3027.881,
          -3054.633,
          -3081.2659999999996,
          -3107.78,
          -3134.173,
          -3160.4440000000004,
          -3186.591,
          -3212.614,
          -3238.51,
          -3264.278,
          -3289.9179999999997,
          -3315.427,
          -3340.805,
          -3366.05,
          -3391.1609999999996,
          -3416.136,
          -3440.973,
          -3465.673,
          -3490.232,
          -3514.65,
          -3538.925,
          -3563.0559999999996,
          -3587.04,
          -3610.8779999999997,
          -3634.567,
          -3658.105,
          -3681.492,
          -3704.725,
          -3727.803,
          -3750.724,
          -3773.487,
          -3796.09,
          -3818.532,
          -3840.8109999999997,
          -3862.9240000000004,
          -3884.8720000000003,
          -3906.651,
          -3928.26,
          -3949.697,
          -3970.96,
          -3992.0490000000004,
          -4012.96,
          -4033.692,
          -4054.243,
          -4074.612,
          -4094.796,
          -4114.793,
          -4134.602,
          -4154.22,
          -4173.646,
          -4192.877,
          -4211.911,
          -4230.747,
          -4249.380999999999,
          -4267.813,
          -4286.039000000001,
          -4304.058,
          -4321.8679999999995,
          -4339.465,
          -4356.848,
          -4374.014,
          -4390.962,
          -4407.688,
          -4424.19,
          -4440.465,
          -4456.512,
          -4472.3279999999995,
          -4487.909000000001,
          -4503.254,
          -4518.359,
          -4533.223,
          -4547.840999999999,
          -4562.212,
          -4576.332,
          -4590.1990000000005,
          -4603.809,
          -4617.16,
          -4630.249,
          -4643.072,
          -4655.626,
          -4667.907999999999,
          -4679.915,
          -4691.644,
          -4703.09,
          -4714.252,
          -4725.124,
          -4735.704000000001,
          -4745.987,
          -4755.971,
          -4765.651,
          -4775.024,
          -4784.085999999999,
          -4792.832,
          -4801.258,
          -4809.361,
          -4817.1359999999995,
          -4824.579000000001,
          -4831.685,
          -4838.45,
          -4844.87,
          -4850.939,
          -4856.653,
          -4862.0070000000005,
          -4866.996,
          -4871.615,
          -4875.858,
          -4879.721,
          -4883.198,
          -4886.284000000001,
          -4888.972,
          -4891.2570000000005,
          -4893.133,
          -4894.594,
          -4895.634,
          -4896.247,
          -4896.425,
          -4896.163,
          -4895.4529999999995,
          -4894.288,
          -4892.663,
          -4890.568,
          -4887.996,
          -4884.941,
          -4881.394,
          -4877.346,
          -4872.791,
          -4867.718,
          -4862.12,
          -4855.988,
          -4849.312,
          -4842.083,
          -4834.291,
          -4825.9259999999995,
          -4816.978,
          -4807.438,
          -4797.292,
          -4786.532,
          -4775.145,
          -4763.119000000001,
          -4750.442,
          -4737.103,
          -4723.087,
          -4708.383,
          -4692.975,
          -4676.851,
          -4659.996,
          -4642.395,
          -4624.032,
          -4604.891,
          -4584.957,
          -4564.212,
          -4542.639,
          -4520.22,
          -4496.935,
          -4472.767,
          -4447.695,
          -4421.697,
          -4394.754,
          -4366.843,
          -4337.941,
          -4308.025,
          -4277.07,
          -4245.049,
          -4211.939,
          -4177.71,
          -4142.335,
          -4105.785,
          -4068.0290000000005,
          -4029.0359999999996,
          -3988.7729999999997,
          -3947.2070000000003,
          -3904.301,
          -3860.02,
          -3814.3259999999996,
          -3767.18,
          -3718.54,
          -3668.365,
          -3616.61,
          -3563.2309999999998,
          -3508.18,
          -3451.409,
          -3392.866,
          -3332.5009999999997,
          -3270.26,
          -3206.086,
          -3139.923,
          -3071.712,
          -3001.393,
          -2928.9040000000005,
          -2854.183,
          -2777.1659999999997,
          -2697.788,
          -2615.986,
          -2531.695,
          -2444.851,
          -2355.394,
          -2263.263,
          -2168.404,
          -2070.765,
          -1970.3020000000001,
          -1866.979,
          -1760.7720000000002,
          -1651.665,
          -1539.661,
          -1424.7820000000002,
          -1307.0710000000001,
          -1186.596,
          -1063.454,
          -937.7760000000001,
          -809.73,
          -679.523,
          -547.404,
          -413.667,
          -278.65,
          -142.731,
          -6.329,
          130.105,
          266.096,
          401.153,
          534.7819999999999,
          666.4960000000001,
          795.827,
          922.3389999999999,
          1045.636,
          1165.37,
          1281.243,
          1393.017,
          1500.505,
          1603.575,
          1702.146,
          1796.18,
          1885.681,
          1970.6860000000001,
          2051.261,
          2127.4970000000003,
          2199.498,
          2267.386,
          2331.294,
          2391.3579999999997,
          2447.721,
          2500.526,
          2549.916,
          2596.034,
          2639.0159999999996,
          2678.9990000000003,
          2716.113,
          2750.486,
          2782.239,
          2811.489,
          2838.3459999999995,
          2862.9179999999997,
          2885.305,
          2905.6040000000003,
          2923.908,
          2940.303,
          2954.8740000000003,
          2967.696,
          2978.8459999999995,
          2988.3940000000002,
          2996.408,
          3002.952,
          3008.087,
          3011.869,
          3014.3540000000003,
          3015.594,
          3015.638,
          3014.533,
          3012.324,
          3009.053,
          3004.761,
          2999.486,
          2993.265,
          2986.133,
          2978.1240000000003,
          2969.2690000000002,
          2959.598,
          2949.1420000000003,
          2937.926,
          2925.9790000000003,
          2913.3259999999996,
          2899.99,
          2885.995,
          2871.364,
          2856.118,
          2840.276,
          2823.8590000000004,
          2806.886,
          2789.375,
          2771.342,
          2752.8059999999996,
          2733.781,
          2714.284,
          2694.33,
          2673.9309999999996,
          2653.103,
          2631.8590000000004,
          2610.212,
          2588.173,
          2565.754,
          2542.969,
          2519.826,
          2496.337,
          2472.513,
          2448.363,
          2423.8979999999997,
          2399.125,
          2374.055,
          2348.697,
          2323.058,
          2297.147,
          2270.972,
          2244.541,
          2217.861,
          2190.939,
          2163.783,
          2136.399,
          2108.7929999999997,
          2080.974,
          2052.945,
          2024.715,
          1996.2879999999998,
          1967.67,
          1938.8670000000002,
          1909.885,
          1880.7279999999998,
          1851.402,
          1821.912,
          1792.2620000000002,
          1762.4579999999999,
          1732.504,
          1702.405,
          1672.164,
          1641.787,
          1611.2779999999998,
          1580.64,
          1549.8770000000002,
          1518.994,
          1487.995,
          1456.882,
          1425.66,
          1394.332,
          1362.902,
          1331.372,
          1299.747,
          1268.03,
          1236.224,
          1204.3310000000001,
          1172.355,
          1140.3,
          1108.167,
          1075.96,
          1043.681,
          1011.3330000000001,
          978.92,
          946.443,
          913.905,
          881.309,
          848.6569999999999,
          815.952,
          783.196,
          750.3910000000001,
          717.54,
          684.645,
          651.7080000000001,
          618.732,
          585.7180000000001,
          552.669,
          519.587,
          486.473,
          453.33099999999996,
          420.162,
          386.967,
          353.749,
          320.51,
          287.251,
          253.975,
          220.683,
          187.377,
          154.059,
          120.73,
          87.39299999999999,
          54.049,
          20.699,
          -12.655,
          -46.01,
          -79.366,
          -112.721,
          -146.07399999999998,
          -179.422,
          -212.764,
          -246.09900000000002,
          -279.425,
          -312.741,
          -346.045,
          -379.336,
          -412.61199999999997,
          -445.87199999999996,
          -479.11400000000003,
          -512.3380000000001,
          -545.5419999999999,
          -578.724,
          -611.882,
          -645.0169999999999,
          -678.1260000000001,
          -711.207,
          -744.2610000000001,
          -777.285,
          -810.278,
          -843.238,
          -876.166,
          -909.058,
          -941.914,
          -974.7339999999999,
          -1007.5139999999999,
          -1040.255,
          -1072.9560000000001,
          -1105.613,
          -1138.228,
          -1170.798,
          -1203.322,
          -1235.799,
          -1268.228,
          -1300.608,
          -1332.9370000000001,
          -1365.214,
          -1397.4389999999999,
          -1429.609,
          -1461.725,
          -1493.7839999999999,
          -1525.785,
          -1557.7279999999998,
          -1589.611,
          -1621.433,
          -1653.193,
          -1684.89,
          -1716.5220000000002,
          -1748.089,
          -1779.589,
          -1811.0220000000002,
          -1842.385,
          -1873.6789999999999,
          -1904.901,
          -1936.0520000000001,
          -1967.128,
          -1998.13,
          -2029.057,
          -2059.907,
          -2090.678,
          -2121.371,
          -2151.984,
          -2182.515,
          -2212.964,
          -2243.3289999999997,
          -2273.609,
          -2303.804,
          -2333.911,
          -2363.93,
          -2393.86,
          -2423.7,
          -2453.448,
          -2483.103,
          -2512.6639999999998,
          -2542.13,
          -2571.5,
          -2600.772,
          -2629.946,
          -2659.0190000000002,
          -2687.992,
          -2716.863,
          -2745.63,
          -2774.2929999999997,
          -2802.85,
          -2831.3,
          -2859.6409999999996,
          -2887.873,
          -2915.995,
          -2944.0040000000004,
          -2971.9,
          -2999.6820000000002,
          -3027.348,
          -3054.897,
          -3082.328,
          -3109.639,
          -3136.829,
          -3163.8979999999997,
          -3190.842,
          -3217.6620000000003,
          -3244.3559999999998,
          -3270.922,
          -3297.3590000000004,
          -3323.667,
          -3349.842,
          -3375.885,
          -3401.7929999999997,
          -3427.565,
          -3453.2009999999996,
          -3478.697,
          -3504.054,
          -3529.268,
          -3554.34,
          -3579.268,
          -3604.0490000000004,
          -3628.683,
          -3653.1679999999997,
          -3677.502,
          -3701.684,
          -3725.712,
          -3749.585,
          -3773.301,
          -3796.8579999999997,
          -3820.255,
          -3843.491,
          -3866.562,
          -3889.469,
          -3912.2090000000003,
          -3934.7790000000005,
          -3957.18,
          -3979.408,
          -4001.462,
          -4023.341,
          -4045.0409999999997,
          -4066.562,
          -4087.902,
          -4109.059,
          -4130.03,
          -4150.814,
          -4171.409000000001,
          -4191.812,
          -4212.023,
          -4232.038,
          -4251.856,
          -4271.474,
          -4290.891,
          -4310.104,
          -4329.111,
          -4347.91,
          -4366.498,
          -4384.874,
          -4403.035,
          -4420.978,
          -4438.702,
          -4456.2029999999995,
          -4473.479,
          -4490.529,
          -4507.348,
          -4523.936,
          -4540.288,
          -4556.403,
          -4572.278,
          -4587.909000000001,
          -4603.295,
          -4618.433,
          -4633.318,
          -4647.95,
          -4662.3240000000005,
          -4676.437,
          -4690.287,
          -4703.871,
          -4717.185,
          -4730.225,
          -4742.99,
          -4755.475,
          -4767.677,
          -4779.592000000001,
          -4791.218,
          -4802.55,
          -4813.585,
          -4824.318,
          -4834.748,
          -4844.8679999999995,
          -4854.6759999999995,
          -4864.168,
          -4873.339,
          -4882.185,
          -4890.702,
          -4898.8859999999995,
          -4906.733,
          -4914.237,
          -4921.394,
          -4928.2,
          -4934.65,
          -4940.738,
          -4946.46,
          -4951.812,
          -4956.786,
          -4961.38,
          -4965.585999999999,
          -4969.399,
          -4972.814,
          -4975.825,
          -4978.4259999999995,
          -4980.611,
          -4982.374,
          -4983.708,
          -4984.607,
          -4985.064,
          -4985.0740000000005,
          -4984.627,
          -4983.718,
          -4982.34,
          -4980.484,
          -4978.143,
          -4975.31,
          -4971.976,
          -4968.133,
          -4963.772,
          -4958.8859999999995,
          -4953.464,
          -4947.498,
          -4940.979,
          -4933.897,
          -4926.241,
          -4918.003,
          -4909.170999999999,
          -4899.734,
          -4889.683,
          -4879.004,
          -4867.687,
          -4855.72,
          -4843.090999999999,
          -4829.785,
          -4815.792,
          -4801.096,
          -4785.685,
          -4769.543,
          -4752.656,
          -4735.009,
          -4716.585999999999,
          -4697.371,
          -4677.346,
          -4656.496,
          -4634.802,
          -4612.245,
          -4588.806,
          -4564.467000000001,
          -4539.206,
          -4513.002,
          -4485.834,
          -4457.679,
          -4428.514,
          -4398.314,
          -4367.055,
          -4334.710999999999,
          -4301.254,
          -4266.657999999999,
          -4230.892,
          -4193.928,
          -4155.734,
          -4116.278,
          -4075.526,
          -4033.445,
          -3989.9970000000003,
          -3945.147,
          -3898.855,
          -3851.08,
          -3801.781,
          -3750.915,
          -3698.438,
          -3644.302,
          -3588.4590000000003,
          -3530.861,
          -3471.454,
          -3410.1859999999997,
          -3347.0009999999997,
          -3281.843,
          -3214.653,
          -3145.3709999999996,
          -3073.935,
          -3000.282,
          -2924.348,
          -2846.066,
          -2765.3720000000003,
          -2682.198,
          -2596.479,
          -2508.149,
          -2417.144,
          -2323.403,
          -2226.869,
          -2127.488,
          -2025.214,
          -1920.0079999999998,
          -1811.844,
          -1700.705,
          -1586.592,
          -1469.524,
          -1349.5439999999999,
          -1226.718,
          -1101.142,
          -972.949,
          -842.305,
          -709.419,
          -574.5419999999999,
          -437.973,
          -300.05,
          -161.16,
          -21.726999999999997,
          117.791,
          256.91,
          395.12800000000004,
          531.94,
          666.847,
          799.3710000000001,
          929.062,
          1055.513,
          1178.363,
          1297.306,
          1412.092,
          1522.526,
          1628.471,
          1729.8370000000002,
          1826.5829999999999,
          1918.7089999999998,
          2006.25,
          2089.271,
          2167.859,
          2242.123,
          2312.1839999999997,
          2378.174,
          2440.234,
          2498.507,
          2553.138,
          2604.2729999999997,
          2652.0570000000002,
          2696.631,
          2738.132,
          2776.6940000000004,
          2812.446,
          2845.513,
          2876.013,
          2904.06,
          2929.763,
          2953.225,
          2974.546,
          2993.8190000000004,
          3011.134,
          3026.575,
          3040.223,
          3052.153,
          3062.44,
          3071.151,
          3078.3520000000003,
          3084.1059999999998,
          3088.4709999999995,
          3091.5029999999997,
          3093.255,
          3093.7790000000005,
          3093.1220000000003,
          3091.33,
          3088.447,
          3084.513,
          3079.57,
          3073.653,
          3066.8,
          3059.0429999999997,
          3050.417,
          3040.952,
          3030.678,
          3019.6240000000003,
          3007.816,
          2995.281,
          2982.0440000000003,
          2968.1279999999997,
          2953.5570000000002,
          2938.3520000000003,
          2922.534,
          2906.1240000000003,
          2889.14,
          2871.6020000000003,
          2853.527,
          2834.9320000000002,
          2815.8340000000003,
          2796.2490000000003,
          2776.192,
          2755.677,
          2734.719,
          2713.3320000000003,
          2691.528,
          2669.321,
          2646.722,
          2623.743,
          2600.396,
          2576.692,
          2552.641,
          2528.254,
          2503.54,
          2478.509,
          2453.1710000000003,
          2427.534,
          2401.6079999999997,
          2375.4,
          2348.919,
          2322.172,
          2295.1679999999997,
          2267.9139999999998,
          2240.416,
          2212.683,
          2184.721,
          2156.536,
          2128.135,
          2099.525,
          2070.7110000000002,
          2041.6989999999998,
          2012.494,
          1983.104,
          1953.5320000000002,
          1923.7839999999999,
          1893.866,
          1863.7820000000002,
          1833.5379999999998,
          1803.1370000000002,
          1772.586,
          1741.8870000000002,
          1711.046,
          1680.067,
          1648.954,
          1617.711,
          1586.3429999999998,
          1554.8529999999998,
          1523.245,
          1491.5220000000002,
          1459.6889999999999,
          1427.749,
          1395.705,
          1363.5610000000001,
          1331.32,
          1298.985,
          1266.5610000000001,
          1234.049,
          1201.452,
          1168.775,
          1136.019,
          1103.188,
          1070.285,
          1037.3110000000001,
          1004.2710000000001,
          971.166,
          937.9989999999999,
          904.7739999999999,
          871.4910000000001,
          838.154,
          804.7660000000001,
          771.328,
          737.842,
          704.313,
          670.74,
          637.127,
          603.477,
          569.79,
          536.069,
          502.31699999999995,
          468.534,
          434.724,
          400.889,
          367.029,
          333.148,
          299.247,
          265.328,
          231.392,
          197.442,
          163.47899999999998,
          129.506,
          95.523,
          61.533,
          27.538,
          -6.462000000000001,
          -40.464,
          -74.467,
          -108.469,
          -142.468,
          -176.46400000000003,
          -210.453,
          -244.43599999999998,
          -278.41,
          -312.373,
          -346.325,
          -380.264,
          -414.18800000000005,
          -448.096,
          -481.98699999999997,
          -515.859,
          -549.71,
          -583.539,
          -617.346,
          -651.128,
          -684.8839999999999,
          -718.612,
          -752.313,
          -785.9830000000001,
          -819.622,
          -853.2289999999999,
          -886.802,
          -920.34,
          -953.841,
          -987.305,
          -1020.73,
          -1054.115,
          -1087.458,
          -1120.758,
          -1154.015,
          -1187.2269999999999,
          -1220.392,
          -1253.51,
          -1286.579,
          -1319.598,
          -1352.565,
          -1385.481,
          -1418.342,
          -1451.149,
          -1483.9,
          -1516.594,
          -1549.23,
          -1581.806,
          -1614.3210000000001,
          -1646.775,
          -1679.165,
          -1711.4920000000002,
          -1743.753,
          -1775.9470000000001,
          -1808.0739999999998,
          -1840.132,
          -1872.12,
          -1904.037,
          -1935.882,
          -1967.6529999999998,
          -1999.349,
          -2030.97,
          -2062.514,
          -2093.98,
          -2125.367,
          -2156.673,
          -2187.8979999999997,
          -2219.04,
          -2250.098,
          -2281.071,
          -2311.958,
          -2342.757,
          -2373.468,
          -2404.089,
          -2434.62,
          -2465.058,
          -2495.403,
          -2525.653,
          -2555.808,
          -2585.866,
          -2615.826,
          -2645.687,
          -2675.447,
          -2705.1059999999998,
          -2734.6609999999996,
          -2764.113,
          -2793.4590000000003,
          -2822.699,
          -2851.8309999999997,
          -2880.853,
          -2909.7659999999996,
          -2938.567,
          -2967.255,
          -2995.828,
          -3024.2870000000003,
          -3052.6279999999997,
          -3080.8520000000003,
          -3108.9559999999997,
          -3136.94,
          -3164.801,
          -3192.54,
          -3220.1540000000005,
          -3247.6409999999996,
          -3275.002,
          -3302.2329999999997,
          -3329.335,
          -3356.305,
          -3383.1420000000003,
          -3409.844,
          -3436.4109999999996,
          -3462.841,
          -3489.132,
          -3515.283,
          -3541.292,
          -3567.158,
          -3592.88,
          -3618.455,
          -3643.883,
          -3669.1620000000003,
          -3694.29,
          -3719.265,
          -3744.087,
          -3768.7529999999997,
          -3793.262,
          -3817.612,
          -3841.801,
          -3865.829,
          -3889.692,
          -3913.3909999999996,
          -3936.921,
          -3960.283,
          -3983.474,
          -4006.493,
          -4029.337,
          -4052.005,
          -4074.494,
          -4096.804,
          -4118.932,
          -4140.876,
          -4162.635,
          -4184.206,
          -4205.587,
          -4226.776,
          -4247.772,
          -4268.572,
          -4289.174,
          -4309.576,
          -4329.776,
          -4349.771,
          -4369.56,
          -4389.14,
          -4408.509,
          -4427.665,
          -4446.605,
          -4465.327,
          -4483.829000000001,
          -4502.107,
          -4520.16,
          -4537.985,
          -4555.58,
          -4572.942,
          -4590.068,
          -4606.956,
          -4623.602,
          -4640.005,
          -4656.162,
          -4672.069,
          -4687.723,
          -4703.123,
          -4718.264,
          -4733.144,
          -4747.76,
          -4762.109,
          -4776.186,
          -4789.99,
          -4803.517,
          -4816.763,
          -4829.725,
          -4842.4,
          -4854.784000000001,
          -4866.874,
          -4878.665,
          -4890.155,
          -4901.339,
          -4912.213,
          -4922.775,
          -4933.018,
          -4942.94,
          -4952.537,
          -4961.804,
          -4970.736,
          -4979.33,
          -4987.58,
          -4995.483,
          -5003.034000000001,
          -5010.227,
          -5017.058,
          -5023.523,
          -5029.615,
          -5035.33,
          -5040.662,
          -5045.607,
          -5050.157999999999,
          -5054.309,
          -5058.056,
          -5061.392,
          -5064.311,
          -5066.808,
          -5068.874,
          -5070.505999999999,
          -5071.694,
          -5072.434,
          -5072.717000000001,
          -5072.538,
          -5071.888,
          -5070.76,
          -5069.147,
          -5067.041,
          -5064.433,
          -5061.317,
          -5057.682,
          -5053.521,
          -5048.825,
          -5043.584,
          -5037.79,
          -5031.432,
          -5024.502,
          -5016.988,
          -5008.880999999999,
          -5000.17,
          -4990.844,
          -4980.892,
          -4970.302,
          -4959.062,
          -4947.16,
          -4934.583,
          -4921.319,
          -4907.354,
          -4892.675,
          -4877.267,
          -4861.115,
          -4844.204000000001,
          -4826.519,
          -4808.044,
          -4788.763,
          -4768.657,
          -4747.710999999999,
          -4725.904,
          -4703.22,
          -4679.637,
          -4655.1359999999995,
          -4629.697,
          -4603.2970000000005,
          -4575.915,
          -4547.528,
          -4518.111,
          -4487.64,
          -4456.09,
          -4423.433,
          -4389.644,
          -4354.692,
          -4318.55,
          -4281.185,
          -4242.567,
          -4202.662,
          -4161.437,
          -4118.856,
          -4074.883,
          -4029.4790000000003,
          -3982.605,
          -3934.219,
          -3884.2790000000005,
          -3832.741,
          -3779.558,
          -3724.685,
          -3668.07,
          -3609.664,
          -3549.413,
          -3487.262,
          -3423.156,
          -3357.0370000000003,
          -3288.843,
          -3218.513,
          -3145.9840000000004,
          -3071.192,
          -2994.071,
          -2914.551,
          -2832.567,
          -2748.05,
          -2660.9309999999996,
          -2571.144,
          -2478.6220000000003,
          -2383.302,
          -2285.125,
          -2184.034,
          -2079.982,
          -1972.9289999999999,
          -1862.842,
          -1749.707,
          -1633.521,
          -1514.3020000000001,
          -1392.09,
          -1266.951,
          -1138.982,
          -1008.312,
          -875.1089999999999,
          -739.5830000000001,
          -601.989,
          -462.62300000000005,
          -321.83299999999997,
          -180.00799999999998,
          -37.578,
          104.98899999999999,
          247.202,
          388.54900000000004,
          528.515,
          666.59,
          802.2819999999999,
          935.13,
          1064.714,
          1190.663,
          1312.66,
          1430.444,
          1543.8139999999999,
          1652.6229999999998,
          1756.777,
          1856.229,
          1950.975,
          2041.0479999999998,
          2126.511,
          2207.451,
          2283.9770000000003,
          2356.21,
          2424.284,
          2488.34,
          2548.525,
          2604.985,
          2657.869,
          2707.323,
          2753.492,
          2796.515,
          2836.5290000000005,
          2873.665,
          2908.05,
          2939.8059999999996,
          2969.048,
          2995.888,
          3020.4309999999996,
          3042.7790000000005,
          3063.067,
          3081.268,
          3097.586,
          3112.066,
          3124.784,
          3135.816,
          3145.2309999999998,
          3153.0959999999995,
          3159.4759999999997,
          3164.4309999999996,
          3168.0170000000003,
          3170.289,
          3171.3,
          3171.099,
          3169.7309999999998,
          3167.243,
          3163.676,
          3159.072,
          3153.467,
          3146.9,
          3139.405,
          3131.0159999999996,
          3121.765,
          3111.6820000000002,
          3100.797,
          3089.136,
          3076.728,
          3063.598,
          3049.7690000000002,
          3035.2659999999996,
          3020.112,
          3004.3259999999996,
          2987.9309999999996,
          2970.945,
          2953.388,
          2935.2790000000005,
          2916.634,
          2897.472,
          2877.8070000000002,
          2857.656,
          2837.034,
          2815.955,
          2794.433,
          2772.482,
          2750.115,
          2727.344,
          2704.1820000000002,
          2680.64,
          2656.728,
          2632.46,
          2607.844,
          2582.891,
          2557.611,
          2532.013,
          2506.107,
          2479.901,
          2453.405,
          2426.627,
          2399.574,
          2372.255,
          2344.677,
          2316.848,
          2288.775,
          2260.464,
          2231.924,
          2203.159,
          2174.178,
          2144.985,
          2115.5879999999997,
          2085.991,
          2056.201,
          2026.224,
          1996.0629999999999,
          1965.726,
          1935.217,
          1904.5410000000002,
          1873.703,
          1842.7079999999999,
          1811.56,
          1780.265,
          1748.825,
          1717.246,
          1685.5320000000002,
          1653.6879999999999,
          1621.7160000000001,
          1589.621,
          1557.4070000000002,
          1525.0770000000002,
          1492.636,
          1460.0870000000002,
          1427.432,
          1394.6770000000001,
          1361.8229999999999,
          1328.875,
          1295.835,
          1262.708,
          1229.494,
          1196.1989999999998,
          1162.825,
          1129.374,
          1095.849,
          1062.254,
          1028.5910000000001,
          994.863,
          961.072,
          927.22,
          893.312,
          859.3480000000001,
          825.332,
          791.265,
          757.1510000000001,
          722.9910000000001,
          688.788,
          654.544,
          620.261,
          585.941,
          551.5880000000001,
          517.201,
          482.785,
          448.34,
          413.86800000000005,
          379.37300000000005,
          344.855,
          310.317,
          275.76,
          241.187,
          206.59900000000002,
          171.998,
          137.385,
          102.76299999999999,
          68.134,
          33.498000000000005,
          -1.141,
          -35.784,
          -70.42699999999999,
          -105.07,
          -139.71,
          -174.34599999999998,
          -208.977,
          -243.601,
          -278.216,
          -312.82099999999997,
          -347.415,
          -381.995,
          -416.56,
          -451.11,
          -485.642,
          -520.154,
          -554.6469999999999,
          -589.117,
          -623.564,
          -657.9860000000001,
          -692.383,
          -726.752,
          -761.092,
          -795.4019999999999,
          -829.68,
          -863.926,
          -898.137,
          -932.313,
          -966.452,
          -1000.554,
          -1034.615,
          -1068.636,
          -1102.616,
          -1136.552,
          -1170.443,
          -1204.289,
          -1238.088,
          -1271.839,
          -1305.54,
          -1339.191,
          -1372.79,
          -1406.335,
          -1439.8270000000002,
          -1473.2620000000002,
          -1506.642,
          -1539.963,
          -1573.225,
          -1606.4260000000002,
          -1639.566,
          -1672.6429999999998,
          -1705.6570000000002,
          -1738.605,
          -1771.487,
          -1804.3010000000002,
          -1837.046,
          -1869.7220000000002,
          -1902.3270000000002,
          -1934.859,
          -1967.318,
          -1999.7020000000002,
          -2032.011,
          -2064.242,
          -2096.396,
          -2128.469,
          -2160.4629999999997,
          -2192.375,
          -2224.203,
          -2255.948,
          -2287.607,
          -2319.18,
          -2350.665,
          -2382.061,
          -2413.368,
          -2444.5820000000003,
          -2475.705,
          -2506.7329999999997,
          -2537.667,
          -2568.505,
          -2599.245,
          -2629.886,
          -2660.428,
          -2690.869,
          -2721.2070000000003,
          -2751.442,
          -2781.572,
          -2811.5959999999995,
          -2841.513,
          -2871.321,
          -2901.0190000000002,
          -2930.6059999999998,
          -2960.08,
          -2989.441,
          -3018.687,
          -3047.816,
          -3076.828,
          -3105.7209999999995,
          -3134.493,
          -3163.1440000000002,
          -3191.672,
          -3220.075,
          -3248.353,
          -3276.5029999999997,
          -3304.525,
          -3332.417,
          -3360.177,
          -3387.805,
          -3415.298,
          -3442.656,
          -3469.877,
          -3496.9590000000003,
          -3523.901,
          -3550.702,
          -3577.3590000000004,
          -3603.8720000000003,
          -3630.239,
          -3656.458,
          -3682.527,
          -3708.446,
          -3734.2129999999997,
          -3759.825,
          -3785.282,
          -3810.5820000000003,
          -3835.723,
          -3860.703,
          -3885.52,
          -3910.1740000000004,
          -3934.6620000000003,
          -3958.9829999999997,
          -3983.134,
          -4007.114,
          -4030.921,
          -4054.554,
          -4078.01,
          -4101.288,
          -4124.3859999999995,
          -4147.3009999999995,
          -4170.032,
          -4192.5779999999995,
          -4214.935,
          -4237.102,
          -4259.077,
          -4280.858,
          -4302.443,
          -4323.829000000001,
          -4345.015,
          -4365.998,
          -4386.777,
          -4407.348,
          -4427.71,
          -4447.861,
          -4467.7970000000005,
          -4487.518,
          -4507.02,
          -4526.3,
          -4545.358,
          -4564.189,
          -4582.792,
          -4601.163,
          -4619.3009999999995,
          -4637.2029999999995,
          -4654.866,
          -4672.287,
          -4689.464,
          -4706.394,
          -4723.073,
          -4739.499,
          -4755.67,
          -4771.582,
          -4787.231,
          -4802.616,
          -4817.733,
          -4832.579000000001,
          -4847.15,
          -4861.442,
          -4875.454000000001,
          -4889.181,
          -4902.62,
          -4915.767,
          -4928.619000000001,
          -4941.173,
          -4953.423,
          -4965.367,
          -4977.001,
          -4988.321,
          -4999.323,
          -5010.002,
          -5020.355,
          -5030.377,
          -5040.065,
          -5049.413,
          -5058.417,
          -5067.072,
          -5075.375,
          -5083.319,
          -5090.901,
          -5098.115,
          -5104.956,
          -5111.42,
          -5117.5,
          -5123.191,
          -5128.488,
          -5133.3859999999995,
          -5137.878,
          -5141.958,
          -5145.621,
          -5148.861,
          -5151.67,
          -5154.044,
          -5155.974,
          -5157.455,
          -5158.48,
          -5159.041,
          -5159.130999999999,
          -5158.7429999999995,
          -5157.87,
          -5156.503,
          -5154.634,
          -5152.255999999999,
          -5149.361,
          -5145.938,
          -5141.981,
          -5137.479,
          -5132.424,
          -5126.806,
          -5120.615,
          -5113.840999999999,
          -5106.475,
          -5098.504,
          -5089.92,
          -5080.71,
          -5070.863,
          -5060.367,
          -5049.21,
          -5037.38,
          -5024.863,
          -5011.647,
          -4997.718,
          -4983.061,
          -4967.663,
          -4951.508,
          -4934.582,
          -4916.867,
          -4898.349,
          -4879.009,
          -4858.831,
          -4837.7970000000005,
          -4815.888,
          -4793.084,
          -4769.367,
          -4744.715,
          -4719.108,
          -4692.522,
          -4664.937,
          -4636.3279999999995,
          -4606.6720000000005,
          -4575.941,
          -4544.112,
          -4511.156,
          -4477.045,
          -4441.752,
          -4405.245,
          -4367.494000000001,
          -4328.465,
          -4288.127,
          -4246.443,
          -4203.377,
          -4158.893,
          -4112.951,
          -4065.511,
          -4016.531,
          -3965.967,
          -3913.7740000000003,
          -3859.905,
          -3804.312,
          -3746.945,
          -3687.7509999999997,
          -3626.676,
          -3563.664,
          -3498.658,
          -3431.598,
          -3362.423,
          -3291.0690000000004,
          -3217.472,
          -3141.565,
          -3063.28,
          -2982.5490000000004,
          -2899.301,
          -2813.467,
          -2724.9770000000003,
          -2633.763,
          -2539.7529999999997,
          -2442.885,
          -2343.095,
          -2240.327,
          -2134.529,
          -2025.661,
          -1913.6870000000001,
          -1798.5910000000001,
          -1680.3670000000002,
          -1559.0339999999999,
          -1434.628,
          -1307.214,
          -1176.889,
          -1043.781,
          -908.059,
          -769.932,
          -629.6569999999999,
          -487.535,
          -343.916,
          -199.19299999999998,
          -53.805,
          91.777,
          237.05,
          381.494,
          524.582,
          665.794,
          804.6260000000001,
          940.605,
          1073.3,
          1202.328,
          1327.359,
          1448.126,
          1564.4160000000002,
          1676.076,
          1783.005,
          1885.1529999999998,
          1982.51,
          2075.1079999999997,
          2163.008,
          2246.295,
          2325.078,
          2399.479,
          2469.636,
          2535.687,
          2597.783,
          2656.072,
          2710.704,
          2761.8309999999997,
          2809.595,
          2854.1420000000003,
          2895.61,
          2934.132,
          2969.8379999999997,
          3002.853,
          3033.2940000000003,
          3061.275,
          3086.9040000000005,
          3110.283,
          3131.512,
          3150.6820000000002,
          3167.883,
          3183.2,
          3196.711,
          3208.492,
          3218.618,
          3227.1540000000005,
          3234.1659999999997,
          3239.716,
          3243.863,
          3246.6620000000003,
          3248.167,
          3248.427,
          3247.492,
          3245.405,
          3242.212,
          3237.954,
          3232.6690000000003,
          3226.395,
          3219.1690000000003,
          3211.025,
          3201.995,
          3192.111,
          3181.403,
          3169.8979999999997,
          3157.625,
          3144.6090000000004,
          3130.8759999999997,
          3116.449,
          3101.3520000000003,
          3085.607,
          3069.2340000000004,
          3052.255,
          3034.688,
          3016.553,
          2997.868,
          2978.6490000000003,
          2958.913,
          2938.677,
          2917.9559999999997,
          2896.764,
          2875.117,
          2853.028,
          2830.509,
          2807.575,
          2784.238,
          2760.509,
          2736.4,
          2711.922,
          2687.086,
          2661.903,
          2636.383,
          2610.534,
          2584.368,
          2557.893,
          2531.117,
          2504.05,
          2476.7,
          2449.075,
          2421.183,
          2393.031,
          2364.627,
          2335.978,
          2307.09,
          2277.972,
          2248.629,
          2219.067,
          2189.2929999999997,
          2159.313,
          2129.133,
          2098.759,
          2068.196,
          2037.4489999999998,
          2006.524,
          1975.4260000000002,
          1944.1589999999999,
          1912.73,
          1881.142,
          1849.401,
          1817.51,
          1785.475,
          1753.299,
          1720.987,
          1688.543,
          1655.97,
          1623.274,
          1590.457,
          1557.524,
          1524.4779999999998,
          1491.3220000000001,
          1458.0610000000001,
          1424.6979999999999,
          1391.236,
          1357.6779999999999,
          1324.027,
          1290.287,
          1256.462,
          1222.553,
          1188.563,
          1154.497,
          1120.356,
          1086.144,
          1051.863,
          1017.5160000000001,
          983.105,
          948.6339999999999,
          914.1039999999999,
          879.518,
          844.8789999999999,
          810.189,
          775.451,
          740.6669999999999,
          705.8380000000001,
          670.9680000000001,
          636.059,
          601.112,
          566.131,
          531.116,
          496.07099999999997,
          460.99699999999996,
          425.89599999999996,
          390.77,
          355.62199999999996,
          320.453,
          285.265,
          250.06,
          214.84,
          179.606,
          144.361,
          109.10600000000001,
          73.844,
          38.575,
          3.301,
          -31.975,
          -67.252,
          -102.529,
          -137.803,
          -173.074,
          -208.33900000000003,
          -243.597,
          -278.847,
          -314.086,
          -349.314,
          -384.529,
          -419.72900000000004,
          -454.912,
          -490.07800000000003,
          -525.225,
          -560.351,
          -595.455,
          -630.536,
          -665.591,
          -700.6210000000001,
          -735.622,
          -770.595,
          -805.5369999999999,
          -840.447,
          -875.324,
          -910.1669999999999,
          -944.9730000000001,
          -979.743,
          -1014.4739999999999,
          -1049.165,
          -1083.8139999999999,
          -1118.422,
          -1152.986,
          -1187.504,
          -1221.9769999999999,
          -1256.402,
          -1290.778,
          -1325.104,
          -1359.378,
          -1393.6,
          -1427.7679999999998,
          -1461.881,
          -1495.9379999999999,
          -1529.9370000000001,
          -1563.8770000000002,
          -1597.757,
          -1631.576,
          -1665.3329999999999,
          -1699.026,
          -1732.654,
          -1766.215,
          -1799.71,
          -1833.136,
          -1866.4920000000002,
          -1899.777,
          -1932.99,
          -1966.129,
          -1999.194,
          -2032.183,
          -2065.095,
          -2097.929,
          -2130.683,
          -2163.356,
          -2195.948,
          -2228.4570000000003,
          -2260.881,
          -2293.22,
          -2325.472,
          -2357.636,
          -2389.7110000000002,
          -2421.695,
          -2453.5879999999997,
          -2485.388,
          -2517.093,
          -2548.7039999999997,
          -2580.217,
          -2611.633,
          -2642.95,
          -2674.1659999999997,
          -2705.281,
          -2736.2929999999997,
          -2767.2009999999996,
          -2798.0029999999997,
          -2828.698,
          -2859.2859999999996,
          -2889.764,
          -2920.131,
          -2950.388,
          -2980.53,
          -3010.558,
          -3040.47,
          -3070.264,
          -3099.94,
          -3129.4959999999996,
          -3158.9309999999996,
          -3188.243,
          -3217.4309999999996,
          -3246.494,
          -3275.429,
          -3304.237,
          -3332.915,
          -3361.461,
          -3389.875,
          -3418.156,
          -3446.3,
          -3474.308,
          -3502.177,
          -3529.907,
          -3557.495,
          -3584.94,
          -3612.24,
          -3639.395,
          -3666.401,
          -3693.259,
          -3719.966,
          -3746.52,
          -3772.921,
          -3799.1659999999997,
          -3825.2529999999997,
          -3851.1820000000002,
          -3876.95,
          -3902.555,
          -3927.9959999999996,
          -3953.272,
          -3978.38,
          -4003.3190000000004,
          -4028.086,
          -4052.68,
          -4077.1,
          -4101.343,
          -4125.407,
          -4149.291,
          -4172.992,
          -4196.51,
          -4219.84,
          -4242.983,
          -4265.935,
          -4288.695,
          -4311.26,
          -4333.629,
          -4355.799,
          -4377.769,
          -4399.535,
          -4421.096,
          -4442.45,
          -4463.594,
          -4484.526,
          -4505.244000000001,
          -4525.746,
          -4546.028,
          -4566.089,
          -4585.925,
          -4605.536,
          -4624.917,
          -4644.067,
          -4662.983,
          -4681.662,
          -4700.101,
          -4718.299,
          -4736.251,
          -4753.956,
          -4771.41,
          -4788.61,
          -4805.554,
          -4822.2390000000005,
          -4838.661,
          -4854.818,
          -4870.706,
          -4886.322,
          -4901.662,
          -4916.725,
          -4931.505,
          -4946.001,
          -4960.208,
          -4974.122,
          -4987.741,
          -5001.06,
          -5014.076,
          -5026.785,
          -5039.183,
          -5051.267,
          -5063.031,
          -5074.473,
          -5085.588,
          -5096.372,
          -5106.82,
          -5116.928,
          -5126.692,
          -5136.107,
          -5145.168,
          -5153.87,
          -5162.209,
          -5170.18,
          -5177.778,
          -5184.997,
          -5191.832,
          -5198.278,
          -5204.33,
          -5209.981,
          -5215.227,
          -5220.06,
          -5224.476,
          -5228.468,
          -5232.03,
          -5235.155,
          -5237.837,
          -5240.069,
          -5241.845,
          -5243.156999999999,
          -5243.9980000000005,
          -5244.361,
          -5244.238,
          -5243.621999999999,
          -5242.504,
          -5240.877,
          -5238.732,
          -5236.061,
          -5232.855,
          -5229.105,
          -5224.802,
          -5219.937,
          -5214.499,
          -5208.479,
          -5201.867,
          -5194.653,
          -5186.8240000000005,
          -5178.372,
          -5169.282999999999,
          -5159.5470000000005,
          -5149.151,
          -5138.083,
          -5126.331,
          -5113.88,
          -5100.719,
          -5086.832,
          -5072.205,
          -5056.825,
          -5040.675,
          -5023.74,
          -5006.004,
          -4987.45,
          -4968.061,
          -4947.819,
          -4926.706,
          -4904.7029999999995,
          -4881.791,
          -4857.948,
          -4833.155,
          -4807.389,
          -4780.629,
          -4752.851,
          -4724.032,
          -4694.146,
          -4663.168,
          -4631.071,
          -4597.8279999999995,
          -4563.41,
          -4527.787,
          -4490.93,
          -4452.805,
          -4413.380999999999,
          -4372.623,
          -4330.495,
          -4286.96,
          -4241.981,
          -4195.517,
          -4147.528,
          -4097.971,
          -4046.8,
          -3993.97,
          -3939.434,
          -3883.1409999999996,
          -3825.04,
          -3765.078,
          -3703.199,
          -3639.347,
          -3573.4629999999997,
          -3505.486,
          -3435.353,
          -3362.998,
          -3288.357,
          -3211.36,
          -3131.938,
          -3050.0209999999997,
          -2965.538,
          -2878.4159999999997,
          -2788.585,
          -2695.97,
          -2600.504,
          -2502.118,
          -2400.748,
          -2296.3360000000002,
          -2188.827,
          -2078.178,
          -1964.3529999999998,
          -1847.332,
          -1727.109,
          -1603.6989999999998,
          -1477.1370000000002,
          -1347.489,
          -1214.847,
          -1079.3410000000001,
          -941.14,
          -800.454,
          -657.54,
          -512.702,
          -366.29400000000004,
          -218.71400000000003,
          -70.405,
          78.153,
          226.45,
          373.95599999999996,
          520.134,
          664.452,
          806.395,
          945.4789999999999,
          1081.259,
          1213.3410000000001,
          1341.3870000000002,
          1465.1170000000002,
          1584.31,
          1698.806,
          1808.499,
          1913.33,
          2013.289,
          2108.403,
          2198.732,
          2284.36,
          2365.395,
          2441.962,
          2514.196,
          2582.241,
          2646.245,
          2706.362,
          2762.743,
          2815.54,
          2864.902,
          2910.974,
          2953.897,
          2993.808,
          3030.8379999999997,
          3065.114,
          3096.756,
          3125.882,
          3152.599,
          3177.014,
          3199.2270000000003,
          3219.333,
          3237.421,
          3253.579,
          3267.888,
          3280.426,
          3291.2659999999996,
          3300.478,
          3308.1290000000004,
          3314.28,
          3318.994,
          3322.3259999999996,
          3324.3309999999997,
          3325.06,
          3324.563,
          3322.886,
          3320.073,
          3316.1679999999997,
          3311.21,
          3305.237,
          3298.2870000000003,
          3290.395,
          3281.594,
          3271.9159999999997,
          3261.393,
          3250.051,
          3237.92,
          3225.027,
          3211.3979999999997,
          3197.0559999999996,
          3182.025,
          3166.329,
          3149.988,
          3133.0229999999997,
          3115.455,
          3097.302,
          3078.5840000000003,
          3059.317,
          3039.5190000000002,
          3019.2070000000003,
          2998.395,
          2977.1,
          2955.336,
          2933.117,
          2910.4570000000003,
          2887.368,
          2863.865,
          2839.958,
          2815.66,
          2790.9829999999997,
          2765.9359999999997,
          2740.532,
          2714.78,
          2688.69,
          2662.2729999999997,
          2635.5370000000003,
          2608.492,
          2581.146,
          2553.508,
          2525.5860000000002,
          2497.388,
          2468.923,
          2440.197,
          2411.218,
          2381.994,
          2352.53,
          2322.834,
          2292.913,
          2262.7729999999997,
          2232.419,
          2201.859,
          2171.097,
          2140.14,
          2108.992,
          2077.661,
          2046.15,
          2014.464,
          1982.61,
          1950.592,
          1918.414,
          1886.082,
          1853.599,
          1820.971,
          1788.201,
          1755.2939999999999,
          1722.254,
          1689.0839999999998,
          1655.79,
          1622.374,
          1588.8410000000001,
          1555.194,
          1521.4370000000001,
          1487.5729999999999,
          1453.606,
          1419.539,
          1385.375,
          1351.119,
          1316.7720000000002,
          1282.338,
          1247.82,
          1213.221,
          1178.5439999999999,
          1143.792,
          1108.9669999999999,
          1074.073,
          1039.113,
          1004.0880000000001,
          969.0010000000001,
          933.855,
          898.653,
          863.3969999999999,
          828.09,
          792.7330000000001,
          757.33,
          721.882,
          686.3919999999999,
          650.862,
          615.294,
          579.691,
          544.055,
          508.38699999999994,
          472.69,
          436.966,
          401.217,
          365.444,
          329.651,
          293.83799999999997,
          258.008,
          222.162,
          186.303,
          150.43200000000002,
          114.551,
          78.66199999999999,
          42.766999999999996,
          6.867000000000001,
          -29.035999999999998,
          -64.94,
          -100.844,
          -136.745,
          -172.643,
          -208.53599999999997,
          -244.421,
          -280.298,
          -316.164,
          -352.019,
          -387.861,
          -423.68699999999995,
          -459.49800000000005,
          -495.29,
          -531.063,
          -566.816,
          -602.5459999999999,
          -638.252,
          -673.934,
          -709.5880000000001,
          -745.215,
          -780.812,
          -816.378,
          -851.9119999999999,
          -887.413,
          -922.8789999999999,
          -958.308,
          -993.7,
          -1029.052,
          -1064.364,
          -1099.635,
          -1134.863,
          -1170.046,
          -1205.184,
          -1240.274,
          -1275.317,
          -1310.31,
          -1345.2520000000002,
          -1380.142,
          -1414.979,
          -1449.761,
          -1484.487,
          -1519.1570000000002,
          -1553.767,
          -1588.318,
          -1622.808,
          -1657.236,
          -1691.601,
          -1725.901,
          -1760.135,
          -1794.3010000000002,
          -1828.4,
          -1862.4289999999999,
          -1896.386,
          -1930.2720000000002,
          -1964.085,
          -1997.8229999999999,
          -2031.485,
          -2065.07,
          -2098.576,
          -2132.0029999999997,
          -2165.35,
          -2198.614,
          -2231.795,
          -2264.8920000000003,
          -2297.903,
          -2330.827,
          -2363.663,
          -2396.409,
          -2429.064,
          -2461.6279999999997,
          -2494.098,
          -2526.474,
          -2558.754,
          -2590.937,
          -2623.022,
          -2655.007,
          -2686.8909999999996,
          -2718.673,
          -2750.3520000000003,
          -2781.925,
          -2813.393,
          -2844.7529999999997,
          -2876.005,
          -2907.147,
          -2938.177,
          -2969.095,
          -2999.8990000000003,
          -3030.587,
          -3061.159,
          -3091.612,
          -3121.946,
          -3152.16,
          -3182.2509999999997,
          -3212.218,
          -3242.06,
          -3271.776,
          -3301.363,
          -3330.823,
          -3360.151,
          -3389.3459999999995,
          -3418.408,
          -3447.335,
          -3476.125,
          -3504.777,
          -3533.289,
          -3561.66,
          -3589.888,
          -3617.972,
          -3645.9109999999996,
          -3673.7009999999996,
          -3701.343,
          -3728.8340000000003,
          -3756.173,
          -3783.357,
          -3810.387,
          -3837.259,
          -3863.972,
          -3890.5240000000003,
          -3916.914,
          -3943.14,
          -3969.2009999999996,
          -3995.093,
          -4020.816,
          -4046.368,
          -4071.7470000000003,
          -4096.951,
          -4121.979,
          -4146.827,
          -4171.495,
          -4195.981,
          -4220.282,
          -4244.396,
          -4268.323,
          -4292.058,
          -4315.601,
          -4338.95,
          -4362.102,
          -4385.055,
          -4407.807,
          -4430.355,
          -4452.698,
          -4474.834,
          -4496.76,
          -4518.473,
          -4539.972,
          -4561.254,
          -4582.317,
          -4603.157,
          -4623.774,
          -4644.164000000001,
          -4664.3240000000005,
          -4684.253,
          -4703.947,
          -4723.404,
          -4742.621,
          -4761.596,
          -4780.325,
          -4798.806,
          -4817.036,
          -4835.012,
          -4852.732,
          -4870.191,
          -4887.388,
          -4904.319,
          -4920.98,
          -4937.369000000001,
          -4953.483,
          -4969.318,
          -4984.87,
          -5000.137,
          -5015.115,
          -5029.8,
          -5044.189,
          -5058.278,
          -5072.063,
          -5085.541,
          -5098.707,
          -5111.559,
          -5124.090999999999,
          -5136.3,
          -5148.181,
          -5159.731,
          -5170.945,
          -5181.819,
          -5192.348,
          -5202.527,
          -5212.353,
          -5221.819,
          -5230.9220000000005,
          -5239.656,
          -5248.016,
          -5255.9980000000005,
          -5263.596,
          -5270.804,
          -5277.616999999999,
          -5284.03,
          -5290.036999999999,
          -5295.632,
          -5300.809,
          -5305.562,
          -5309.884,
          -5313.77,
          -5317.213000000001,
          -5320.205,
          -5322.741999999999,
          -5324.814,
          -5326.416,
          -5327.54,
          -5328.178000000001,
          -5328.323,
          -5327.967,
          -5327.102,
          -5325.72,
          -5323.812,
          -5321.369000000001,
          -5318.383000000001,
          -5314.845,
          -5310.745,
          -5306.073,
          -5300.821,
          -5294.977,
          -5288.531,
          -5281.473000000001,
          -5273.7919999999995,
          -5265.477,
          -5256.515,
          -5246.895,
          -5236.606,
          -5225.634,
          -5213.965,
          -5201.587,
          -5188.487,
          -5174.65,
          -5160.061,
          -5144.705,
          -5128.568,
          -5111.633,
          -5093.883,
          -5075.302,
          -5055.872,
          -5035.576,
          -5014.393,
          -4992.306,
          -4969.294,
          -4945.335999999999,
          -4920.412,
          -4894.499,
          -4867.575,
          -4839.616,
          -4810.597,
          -4780.495,
          -4749.281,
          -4716.929,
          -4683.411,
          -4648.6990000000005,
          -4612.7609999999995,
          -4575.566,
          -4537.083,
          -4497.278,
          -4456.115,
          -4413.559,
          -4369.571,
          -4324.1140000000005,
          -4277.145,
          -4228.625,
          -4178.508,
          -4126.749,
          -4073.302,
          -4018.116,
          -3961.143,
          -3902.33,
          -3841.6209999999996,
          -3778.961,
          -3714.292,
          -3647.553,
          -3578.6809999999996,
          -3507.615,
          -3434.285,
          -3358.6240000000003,
          -3280.5640000000003,
          -3200.034,
          -3116.96,
          -3031.27,
          -2942.89,
          -2851.7459999999996,
          -2757.765,
          -2660.8740000000003,
          -2561.004,
          -2458.089,
          -2352.067,
          -2242.884,
          -2130.491,
          -2014.8529999999998,
          -1895.9460000000001,
          -1773.764,
          -1648.317,
          -1519.642,
          -1387.8,
          -1252.885,
          -1115.024,
          -974.387,
          -831.184,
          -685.675,
          -538.165,
          -389.01099999999997,
          -238.61599999999999,
          -87.427,
          64.067,
          215.34900000000002,
          365.88199999999995,
          515.115,
          662.507,
          807.5310000000001,
          949.691,
          1088.53,
          1223.644,
          1354.683,
          1481.3570000000002,
          1603.4370000000001,
          1720.754,
          1833.1960000000001,
          1940.701,
          2043.2520000000002,
          2140.874,
          2233.624,
          2321.5879999999997,
          2404.871,
          2483.598,
          2557.907,
          2627.9429999999998,
          2693.855,
          2755.7990000000004,
          2813.929,
          2868.3979999999997,
          2919.3579999999997,
          2966.9559999999997,
          3011.337,
          3052.638,
          3090.995,
          3126.5359999999996,
          3159.383,
          3189.657,
          3217.467,
          3242.922,
          3266.155,
          3287.1679999999997,
          3306.1490000000003,
          3323.155,
          3338.2670000000003,
          3351.566,
          3363.1259999999997,
          3373.0209999999997,
          3381.315,
          3388.075,
          3393.362,
          3397.2340000000004,
          3399.745,
          3400.95,
          3400.8979999999997,
          3399.637,
          3397.2129999999997,
          3393.6679999999997,
          3389.0440000000003,
          3383.38,
          3376.7140000000004,
          3369.0809999999997,
          3360.5170000000003,
          3351.053,
          3340.722,
          3329.552,
          3317.572,
          3304.81,
          3291.292,
          3277.0429999999997,
          3262.087,
          3246.448,
          3230.147,
          3213.2059999999997,
          3195.645,
          3177.4840000000004,
          3158.741,
          3139.4359999999997,
          3119.5840000000003,
          3099.204,
          3078.3109999999997,
          3056.922,
          3035.05,
          3012.71,
          2989.917,
          2966.683,
          2943.0229999999997,
          2918.948,
          2894.47,
          2869.6020000000003,
          2844.3540000000003,
          2818.738,
          2792.764,
          2766.4429999999998,
          2739.784,
          2712.797,
          2685.491,
          2657.875,
          2629.9590000000003,
          2601.75,
          2573.257,
          2544.488,
          2515.45,
          2486.151,
          2456.599,
          2426.8,
          2396.762,
          2366.49,
          2335.993,
          2305.275,
          2274.344,
          2243.2039999999997,
          2211.863,
          2180.325,
          2148.596,
          2116.6820000000002,
          2084.5879999999997,
          2052.319,
          2019.88,
          1987.276,
          1954.511,
          1921.5910000000001,
          1888.52,
          1855.3020000000001,
          1821.942,
          1788.443,
          1754.8110000000001,
          1721.049,
          1687.161,
          1653.15,
          1619.021,
          1584.7779999999998,
          1550.4229999999998,
          1515.961,
          1481.395,
          1446.7279999999998,
          1411.964,
          1377.106,
          1342.1570000000002,
          1307.12,
          1271.998,
          1236.795,
          1201.513,
          1166.155,
          1130.724,
          1095.222,
          1059.654,
          1024.02,
          988.324,
          952.569,
          916.7560000000001,
          880.8889999999999,
          844.97,
          809.0010000000001,
          772.985,
          736.924,
          700.821,
          664.677,
          628.494,
          592.276,
          556.024,
          519.741,
          483.42699999999996,
          447.087,
          410.721,
          374.33099999999996,
          337.92,
          301.48900000000003,
          265.041,
          228.577,
          192.1,
          155.61,
          119.11,
          82.602,
          46.088,
          9.568999999999999,
          -26.954,
          -63.477,
          -100,
          -136.52200000000002,
          -173.03900000000002,
          -209.551,
          -246.05599999999998,
          -282.552,
          -319.038,
          -355.51199999999994,
          -391.973,
          -428.418,
          -464.848,
          -501.259,
          -537.65,
          -574.021,
          -610.369,
          -646.693,
          -682.992,
          -719.2639999999999,
          -755.507,
          -791.721,
          -827.903,
          -864.053,
          -900.169,
          -936.2489999999999,
          -972.293,
          -1008.298,
          -1044.264,
          -1080.1889999999999,
          -1116.072,
          -1151.911,
          -1187.7060000000001,
          -1223.454,
          -1259.154,
          -1294.806,
          -1330.4070000000002,
          -1365.957,
          -1401.454,
          -1436.8970000000002,
          -1472.2839999999999,
          -1507.615,
          -1542.888,
          -1578.102,
          -1613.255,
          -1648.346,
          -1683.374,
          -1718.3370000000002,
          -1753.235,
          -1788.066,
          -1822.829,
          -1857.523,
          -1892.145,
          -1926.6960000000001,
          -1961.174,
          -1995.576,
          -2029.904,
          -2064.154,
          -2098.326,
          -2132.4179999999997,
          -2166.429,
          -2200.359,
          -2234.205,
          -2267.966,
          -2301.6420000000003,
          -2335.23,
          -2368.73,
          -2402.14,
          -2435.459,
          -2468.686,
          -2501.819,
          -2534.8579999999997,
          -2567.8,
          -2600.645,
          -2633.3920000000003,
          -2666.038,
          -2698.5820000000003,
          -2731.025,
          -2763.363,
          -2795.5959999999995,
          -2827.722,
          -2859.74,
          -2891.6490000000003,
          -2923.447,
          -2955.134,
          -2986.7070000000003,
          -3018.165,
          -3049.507,
          -3080.732,
          -3111.837,
          -3142.823,
          -3173.687,
          -3204.427,
          -3235.0429999999997,
          -3265.534,
          -3295.8959999999997,
          -3326.13,
          -3356.2340000000004,
          -3386.204,
          -3416.0429999999997,
          -3445.7459999999996,
          -3475.3140000000003,
          -3504.743,
          -3534.033,
          -3563.1820000000002,
          -3592.1890000000003,
          -3621.052,
          -3649.7690000000002,
          -3678.3390000000004,
          -3706.76,
          -3735.031,
          -3763.1490000000003,
          -3791.114,
          -3818.9240000000004,
          -3846.577,
          -3874.07,
          -3901.4040000000005,
          -3928.575,
          -3955.5820000000003,
          -3982.423,
          -4009.097,
          -4035.6009999999997,
          -4061.935,
          -4088.095,
          -4114.081,
          -4139.89,
          -4165.52,
          -4190.969,
          -4216.236,
          -4241.319,
          -4266.215,
          -4290.9220000000005,
          -4315.44,
          -4339.764,
          -4363.894,
          -4387.827,
          -4411.561,
          -4435.093,
          -4458.423,
          -4481.5470000000005,
          -4504.463,
          -4527.169,
          -4549.663,
          -4571.942,
          -4594.004,
          -4615.847,
          -4637.467000000001,
          -4658.863,
          -4680.032,
          -4700.971,
          -4721.678,
          -4742.151,
          -4762.3859999999995,
          -4782.380999999999,
          -4802.134,
          -4821.64,
          -4840.899,
          -4859.906,
          -4878.659000000001,
          -4897.155,
          -4915.39,
          -4933.363,
          -4951.069,
          -4968.505999999999,
          -4985.67,
          -5002.558,
          -5019.168,
          -5035.494000000001,
          -5051.535,
          -5067.286,
          -5082.745,
          -5097.907,
          -5112.768,
          -5127.326,
          -5141.576,
          -5155.514,
          -5169.137,
          -5182.441,
          -5195.420999999999,
          -5208.073,
          -5220.394,
          -5232.378,
          -5244.021,
          -5255.32,
          -5266.269,
          -5276.863,
          -5287.099,
          -5296.971,
          -5306.474,
          -5315.603,
          -5324.354,
          -5332.72,
          -5340.696999999999,
          -5348.279,
          -5355.460999999999,
          -5362.236,
          -5368.599,
          -5374.544,
          -5380.066,
          -5385.156999999999,
          -5389.811,
          -5394.023,
          -5397.785,
          -5401.09,
          -5403.932,
          -5406.304,
          -5408.198,
          -5409.607,
          -5410.524,
          -5410.939,
          -5410.846,
          -5410.236999999999,
          -5409.102,
          -5407.434,
          -5405.224,
          -5402.4619999999995,
          -5399.139,
          -5395.245,
          -5390.772,
          -5385.709,
          -5380.045999999999,
          -5373.771,
          -5366.875,
          -5359.347,
          -5351.174,
          -5342.345,
          -5332.847,
          -5322.669,
          -5311.798000000001,
          -5300.219,
          -5287.920999999999,
          -5274.889,
          -5261.108,
          -5246.564,
          -5231.241,
          -5215.123,
          -5198.196,
          -5180.44,
          -5161.840999999999,
          -5142.379,
          -5122.036,
          -5100.793,
          -5078.6320000000005,
          -5055.53,
          -5031.467000000001,
          -5006.4220000000005,
          -4980.373,
          -4953.295,
          -4925.166,
          -4895.959,
          -4865.651,
          -4834.213,
          -4801.619000000001,
          -4767.839,
          -4732.845,
          -4696.606,
          -4659.089,
          -4620.262,
          -4580.09,
          -4538.538,
          -4495.569,
          -4451.144,
          -4405.224,
          -4357.768,
          -4308.733,
          -4258.0740000000005,
          -4205.746,
          -4151.7,
          -4095.886,
          -4038.252,
          -3978.7459999999996,
          -3917.312,
          -3853.893,
          -3788.428,
          -3720.857,
          -3651.116,
          -3579.139,
          -3504.8579999999997,
          -3428.205,
          -3349.1090000000004,
          -3267.4970000000003,
          -3183.2940000000003,
          -3096.425,
          -3006.816,
          -2914.3909999999996,
          -2819.073,
          -2720.7909999999997,
          -2619.471,
          -2515.044,
          -2407.448,
          -2296.625,
          -2182.526,
          -2065.112,
          -1944.358,
          -1820.255,
          -1692.8129999999999,
          -1562.065,
          -1428.0710000000001,
          -1290.924,
          -1150.752,
          -1007.7230000000001,
          -862.048,
          -713.987,
          -563.8480000000001,
          -411.991,
          -258.822,
          -104.796,
          49.593,
          203.821,
          357.339,
          509.591,
          660.0219999999999,
          808.0939999999999,
          953.299,
          1095.17,
          1233.289,
          1367.295,
          1496.891,
          1621.838,
          1741.9579999999999,
          1857.1329999999998,
          1967.295,
          2072.425,
          2172.5429999999997,
          2267.7039999999997,
          2357.993,
          2443.516,
          2524.399,
          2600.776,
          2672.797,
          2740.614,
          2804.381,
          2864.256,
          2920.395,
          2972.952,
          3022.075,
          3067.913,
          3110.605,
          3150.289,
          3187.0959999999995,
          3221.15,
          3252.572,
          3281.4770000000003,
          3307.974,
          3332.167,
          3354.156,
          3374.033,
          3391.889,
          3407.809,
          3421.873,
          3434.159,
          3444.739,
          3453.683,
          3461.0570000000002,
          3466.922,
          3471.3379999999997,
          3474.363,
          3476.0490000000004,
          3476.449,
          3475.61,
          3473.58,
          3470.402,
          3466.118,
          3460.77,
          3454.3940000000002,
          3447.0290000000005,
          3438.7090000000003,
          3429.467,
          3419.335,
          3408.343,
          3396.522,
          3383.8990000000003,
          3370.5,
          3356.3520000000003,
          3341.4790000000003,
          3325.905,
          3309.652,
          3292.743,
          3275.197,
          3257.0359999999996,
          3238.278,
          3218.942,
          3199.046,
          3178.607,
          3157.6420000000003,
          3136.1659999999997,
          3114.196,
          3091.745,
          3068.828,
          3045.4590000000003,
          3021.65,
          2997.4159999999997,
          2972.768,
          2947.718,
          2922.2790000000005,
          2896.46,
          2870.2740000000003,
          2843.73,
          2816.8379999999997,
          2789.6090000000004,
          2762.053,
          2734.177,
          2705.992,
          2677.505,
          2648.7259999999997,
          2619.663,
          2590.323,
          2560.714,
          2530.843,
          2500.719,
          2470.348,
          2439.736,
          2408.891,
          2377.819,
          2346.526,
          2315.019,
          2283.303,
          2251.384,
          2219.268,
          2186.9610000000002,
          2154.468,
          2121.794,
          2088.944,
          2055.924,
          2022.737,
          1989.39,
          1955.886,
          1922.23,
          1888.4270000000001,
          1854.48,
          1820.395,
          1786.175,
          1751.8239999999998,
          1717.346,
          1682.746,
          1648.026,
          1613.191,
          1578.244,
          1543.1879999999999,
          1508.0279999999998,
          1472.767,
          1437.4070000000002,
          1401.953,
          1366.4070000000002,
          1330.773,
          1295.053,
          1259.251,
          1223.369,
          1187.411,
          1151.38,
          1115.277,
          1079.107,
          1042.87,
          1006.572,
          970.2130000000001,
          933.796,
          897.325,
          860.801,
          824.2260000000001,
          787.6039999999999,
          750.937,
          714.2260000000001,
          677.475,
          640.685,
          603.859,
          566.998,
          530.106,
          493.184,
          456.23400000000004,
          419.25800000000004,
          382.259,
          345.23699999999997,
          308.197,
          271.138,
          234.063,
          196.975,
          159.874,
          122.76299999999999,
          85.64399999999999,
          48.518,
          11.387,
          -25.747,
          -62.882,
          -100.01700000000001,
          -137.149,
          -174.278,
          -211.40099999999998,
          -248.518,
          -285.625,
          -322.722,
          -359.80800000000005,
          -396.879,
          -433.936,
          -470.975,
          -507.99699999999996,
          -544.999,
          -581.979,
          -618.937,
          -655.87,
          -692.778,
          -729.658,
          -766.5089999999999,
          -803.331,
          -840.1210000000001,
          -876.877,
          -913.6,
          -950.2860000000001,
          -986.935,
          -1023.546,
          -1060.116,
          -1096.645,
          -1133.131,
          -1169.573,
          -1205.97,
          -1242.319,
          -1278.62,
          -1314.872,
          -1351.0729999999999,
          -1387.221,
          -1423.316,
          -1459.356,
          -1495.339,
          -1531.266,
          -1567.1329999999998,
          -1602.94,
          -1638.6860000000001,
          -1674.369,
          -1709.987,
          -1745.5410000000002,
          -1781.0279999999998,
          -1816.4460000000001,
          -1851.796,
          -1887.075,
          -1922.2820000000002,
          -1957.4160000000002,
          -1992.476,
          -2027.46,
          -2062.367,
          -2097.195,
          -2131.945,
          -2166.613,
          -2201.199,
          -2235.702,
          -2270.12,
          -2304.452,
          -2338.696,
          -2372.8520000000003,
          -2406.9179999999997,
          -2440.893,
          -2474.776,
          -2508.564,
          -2542.258,
          -2575.855,
          -2609.354,
          -2642.7540000000004,
          -2676.053,
          -2709.2509999999997,
          -2742.3459999999995,
          -2775.336,
          -2808.22,
          -2840.998,
          -2873.6659999999997,
          -2906.225,
          -2938.673,
          -2971.008,
          -3003.2290000000003,
          -3035.3340000000003,
          -3067.323,
          -3099.1929999999998,
          -3130.9440000000004,
          -3162.573,
          -3194.0809999999997,
          -3225.4640000000004,
          -3256.722,
          -3287.853,
          -3318.855,
          -3349.728,
          -3380.469,
          -3411.078,
          -3441.552,
          -3471.8909999999996,
          -3502.092,
          -3532.1540000000005,
          -3562.0759999999996,
          -3591.8559999999998,
          -3621.492,
          -3650.9829999999997,
          -3680.327,
          -3709.522,
          -3738.5679999999998,
          -3767.461,
          -3796.2009999999996,
          -3824.7870000000003,
          -3853.215,
          -3881.485,
          -3909.594,
          -3937.542,
          -3965.3259999999996,
          -3992.9440000000004,
          -4020.395,
          -4047.677,
          -4074.788,
          -4101.726,
          -4128.4890000000005,
          -4155.076,
          -4181.484,
          -4207.712,
          -4233.7570000000005,
          -4259.6179999999995,
          -4285.292,
          -4310.778,
          -4336.0740000000005,
          -4361.177,
          -4386.085,
          -4410.795999999999,
          -4435.309,
          -4459.62,
          -4483.728,
          -4507.630999999999,
          -4531.326,
          -4554.81,
          -4578.082,
          -4601.14,
          -4623.98,
          -4646.601,
          -4668.999,
          -4691.174,
          -4713.121,
          -4734.838,
          -4756.323,
          -4777.5740000000005,
          -4798.587,
          -4819.359,
          -4839.889,
          -4860.173,
          -4880.209,
          -4899.9929999999995,
          -4919.523,
          -4938.795,
          -4957.807,
          -4976.556,
          -4995.039000000001,
          -5013.252,
          -5031.192,
          -5048.856,
          -5066.241,
          -5083.344,
          -5100.16,
          -5116.686,
          -5132.92,
          -5148.857,
          -5164.4929999999995,
          -5179.826,
          -5194.85,
          -5209.563,
          -5223.960999999999,
          -5238.038,
          -5251.793000000001,
          -5265.219,
          -5278.313,
          -5291.071,
          -5303.4890000000005,
          -5315.561,
          -5327.284000000001,
          -5338.651999999999,
          -5349.661,
          -5360.307,
          -5370.5830000000005,
          -5380.486,
          -5390.0109999999995,
          -5399.151,
          -5407.901999999999,
          -5416.258000000001,
          -5424.214,
          -5431.764,
          -5438.901999999999,
          -5445.621999999999,
          -5451.918000000001,
          -5457.785,
          -5463.215,
          -5468.203,
          -5472.741,
          -5476.8240000000005,
          -5480.443,
          -5483.593000000001,
          -5486.266,
          -5488.454000000001,
          -5490.15,
          -5491.347,
          -5492.035,
          -5492.2080000000005,
          -5491.857,
          -5490.973000000001,
          -5489.548000000001,
          -5487.571999999999,
          -5485.036999999999,
          -5481.933000000001,
          -5478.25,
          -5473.979,
          -5469.109,
          -5463.63,
          -5457.531,
          -5450.802,
          -5443.43,
          -5435.405,
          -5426.713000000001,
          -5417.343000000001,
          -5407.281999999999,
          -5396.517,
          -5385.036,
          -5372.823,
          -5359.865,
          -5346.147,
          -5331.654,
          -5316.37,
          -5300.28,
          -5283.368,
          -5265.615,
          -5247.004,
          -5227.518,
          -5207.137,
          -5185.843,
          -5163.616,
          -5140.433,
          -5116.275,
          -5091.119000000001,
          -5064.943,
          -5037.723,
          -5009.434,
          -4980.0509999999995,
          -4949.549,
          -4917.899,
          -4885.075,
          -4851.045999999999,
          -4815.782999999999,
          -4779.255,
          -4741.43,
          -4702.272,
          -4661.748,
          -4619.821,
          -4576.454000000001,
          -4531.608,
          -4485.2429999999995,
          -4437.316,
          -4387.782999999999,
          -4336.601,
          -4283.721,
          -4229.094,
          -4172.67,
          -4114.396,
          -4054.218,
          -3992.079,
          -3927.921,
          -3861.684,
          -3793.304,
          -3722.715,
          -3649.853,
          -3574.647,
          -3497.026,
          -3416.92,
          -3334.2529999999997,
          -3248.949,
          -3160.9309999999996,
          -3070.123,
          -2976.447,
          -2879.8259999999996,
          -2780.183,
          -2677.445,
          -2571.541,
          -2462.406,
          -2349.98,
          -2234.212,
          -2115.06,
          -1992.4979999999998,
          -1866.515,
          -1737.118,
          -1604.339,
          -1468.236,
          -1328.902,
          -1186.463,
          -1041.086,
          -892.9830000000001,
          -742.416,
          -589.694,
          -435.17900000000003,
          -279.284,
          -122.465,
          34.775999999999996,
          191.907,
          348.371,
          503.601,
          657.0319999999999,
          808.115,
          956.331,
          1101.1989999999998,
          1242.2939999999999,
          1379.241,
          1511.7320000000002,
          1639.5220000000002,
          1762.4229999999998,
          1880.3110000000001,
          1993.114,
          2100.805,
          2203.404,
          2300.965,
          2393.5679999999998,
          2481.32,
          2564.348,
          2642.7870000000003,
          2716.7859999999996,
          2786.5,
          2852.086,
          2913.702,
          2971.507,
          3025.657,
          3076.305,
          3123.598,
          3167.68,
          3208.69,
          3246.763,
          3282.025,
          3314.597,
          3344.599,
          3372.139,
          3397.3259999999996,
          3420.26,
          3441.0359999999996,
          3459.7459999999996,
          3476.4770000000003,
          3491.3109999999997,
          3504.3259999999996,
          3515.597,
          3525.195,
          3533.187,
          3539.636,
          3544.6020000000003,
          3548.145,
          3550.3190000000004,
          3551.176,
          3550.765,
          3549.135,
          3546.3309999999997,
          3542.395,
          3537.368,
          3531.2909999999997,
          3524.2,
          3516.131,
          3507.117,
          3497.192,
          3486.388,
          3474.732,
          3462.256,
          3448.985,
          3434.946,
          3420.164,
          3404.663,
          3388.467,
          3371.598,
          3354.0759999999996,
          3335.923,
          3317.159,
          3297.801,
          3277.869,
          3257.38,
          3236.3509999999997,
          3214.7990000000004,
          3192.739,
          3170.185,
          3147.153,
          3123.657,
          3099.711,
          3075.3259999999996,
          3050.5170000000003,
          3025.296,
          2999.6740000000004,
          2973.6620000000003,
          2947.2729999999997,
          2920.5159999999996,
          2893.402,
          2865.941,
          2838.1440000000002,
          2810.018,
          2781.574,
          2752.82,
          2723.764,
          2694.417,
          2664.784,
          2634.875,
          2604.697,
          2574.257,
          2543.563,
          2512.621,
          2481.439,
          2450.022,
          2418.379,
          2386.514,
          2354.4339999999997,
          2322.145,
          2289.652,
          2256.962,
          2224.08,
          2191.012,
          2157.761,
          2124.335,
          2090.737,
          2056.972,
          2023.046,
          1988.9620000000002,
          1954.726,
          1920.342,
          1885.8139999999999,
          1851.1470000000002,
          1816.344,
          1781.4089999999999,
          1746.3470000000002,
          1711.162,
          1675.8570000000002,
          1640.435,
          1604.901,
          1569.2579999999998,
          1533.51,
          1497.66,
          1461.711,
          1425.6660000000002,
          1389.53,
          1353.3039999999999,
          1316.9920000000002,
          1280.598,
          1244.123,
          1207.5710000000001,
          1170.9460000000001,
          1134.248,
          1097.483,
          1060.651,
          1023.7560000000001,
          986.8,
          949.7869999999999,
          912.717,
          875.595,
          838.423,
          801.202,
          763.935,
          726.625,
          689.2739999999999,
          651.884,
          614.457,
          576.996,
          539.502,
          501.97900000000004,
          464.42699999999996,
          426.85,
          389.24800000000005,
          351.625,
          313.981,
          276.32,
          238.643,
          200.951,
          163.248,
          125.53399999999999,
          87.811,
          50.082,
          12.347999999999999,
          -25.389,
          -63.126999999999995,
          -100.865,
          -138.601,
          -176.333,
          -214.05900000000003,
          -251.778,
          -289.488,
          -327.188,
          -364.875,
          -402.54900000000004,
          -440.208,
          -477.849,
          -515.472,
          -553.075,
          -590.656,
          -628.215,
          -665.748,
          -703.2560000000001,
          -740.7360000000001,
          -778.186,
          -815.607,
          -852.995,
          -890.3489999999999,
          -927.669,
          -964.952,
          -1002.198,
          -1039.404,
          -1076.57,
          -1113.693,
          -1150.7730000000001,
          -1187.809,
          -1224.798,
          -1261.739,
          -1298.632,
          -1335.474,
          -1372.264,
          -1409.0020000000002,
          -1445.685,
          -1482.3120000000001,
          -1518.8829999999998,
          -1555.395,
          -1591.8470000000002,
          -1628.2379999999998,
          -1664.567,
          -1700.8310000000001,
          -1737.031,
          -1773.165,
          -1809.231,
          -1845.227,
          -1881.154,
          -1917.009,
          -1952.7910000000002,
          -1988.4979999999998,
          -2024.13,
          -2059.685,
          -2095.1620000000003,
          -2130.5589999999997,
          -2165.876,
          -2201.11,
          -2236.261,
          -2271.327,
          -2306.3070000000002,
          -2341.2,
          -2376.004,
          -2410.717,
          -2445.34,
          -2479.869,
          -2514.304,
          -2548.645,
          -2582.888,
          -2617.033,
          -2651.079,
          -2685.0240000000003,
          -2718.866,
          -2752.6059999999998,
          -2786.24,
          -2819.768,
          -2853.188,
          -2886.5,
          -2919.7,
          -2952.79,
          -2985.765,
          -3018.627,
          -3051.3720000000003,
          -3083.9990000000003,
          -3116.508,
          -3148.8959999999997,
          -3181.163,
          -3213.3059999999996,
          -3245.325,
          -3277.217,
          -3308.9809999999998,
          -3340.617,
          -3372.1209999999996,
          -3403.494,
          -3434.732,
          -3465.836,
          -3496.802,
          -3527.63,
          -3558.3179999999998,
          -3588.865,
          -3619.268,
          -3649.527,
          -3679.639,
          -3709.603,
          -3739.4179999999997,
          -3769.0809999999997,
          -3798.591,
          -3827.946,
          -3857.145,
          -3886.1859999999997,
          -3915.067,
          -3943.7859999999996,
          -3972.342,
          -4000.732,
          -4028.9559999999997,
          -4057.01,
          -4084.8940000000002,
          -4112.606,
          -4140.142,
          -4167.503,
          -4194.685,
          -4221.687,
          -4248.5070000000005,
          -4275.142,
          -4301.590999999999,
          -4327.852,
          -4353.923,
          -4379.8009999999995,
          -4405.484,
          -4430.971,
          -4456.259,
          -4481.347,
          -4506.231,
          -4530.909000000001,
          -4555.38,
          -4579.64,
          -4603.689,
          -4627.522,
          -4651.139,
          -4674.535,
          -4697.71,
          -4720.661,
          -4743.384,
          -4765.878,
          -4788.14,
          -4810.167,
          -4831.957,
          -4853.505999999999,
          -4874.812,
          -4895.873,
          -4916.685,
          -4937.246,
          -4957.552,
          -4977.601,
          -4997.39,
          -5016.916,
          -5036.175,
          -5055.164000000001,
          -5073.880999999999,
          -5092.322,
          -5110.483,
          -5128.362,
          -5145.955,
          -5163.258,
          -5180.268,
          -5196.981,
          -5213.394,
          -5229.503,
          -5245.304,
          -5260.794,
          -5275.968000000001,
          -5290.821999999999,
          -5305.353,
          -5319.556,
          -5333.427,
          -5346.9619999999995,
          -5360.156999999999,
          -5373.005999999999,
          -5385.505999999999,
          -5397.651999999999,
          -5409.439,
          -5420.861999999999,
          -5431.9169999999995,
          -5442.598000000001,
          -5452.901,
          -5462.819,
          -5472.349,
          -5481.484,
          -5490.219,
          -5498.549,
          -5506.468000000001,
          -5513.969,
          -5521.047,
          -5527.695,
          -5533.908,
          -5539.678000000001,
          -5545,
          -5549.866999999999,
          -5554.271,
          -5558.206999999999,
          -5561.666,
          -5564.641,
          -5567.126,
          -5569.111,
          -5570.59,
          -5571.554,
          -5571.995,
          -5571.905,
          -5571.275,
          -5570.096,
          -5568.358,
          -5566.054,
          -5563.172,
          -5559.704000000001,
          -5555.639,
          -5550.965999999999,
          -5545.6759999999995,
          -5539.757,
          -5533.1990000000005,
          -5525.9890000000005,
          -5518.116,
          -5509.566999999999,
          -5500.33,
          -5490.393,
          -5479.741,
          -5468.361999999999,
          -5456.241,
          -5443.3640000000005,
          -5429.715999999999,
          -5415.281,
          -5400.045,
          -5383.99,
          -5367.1,
          -5349.357,
          -5330.745,
          -5311.243,
          -5290.834,
          -5269.496999999999,
          -5247.214,
          -5223.960999999999,
          -5199.717000000001,
          -5174.460999999999,
          -5148.169,
          -5120.817,
          -5092.38,
          -5062.833,
          -5032.149,
          -5000.3009999999995,
          -4967.259,
          -4932.994000000001,
          -4897.477,
          -4860.674,
          -4822.554,
          -4783.081,
          -4742.22,
          -4699.935,
          -4656.187,
          -4610.937,
          -4564.143,
          -4515.762,
          -4465.751,
          -4414.064,
          -4360.651,
          -4305.464,
          -4248.451,
          -4189.558,
          -4128.73,
          -4065.909,
          -4001.0359999999996,
          -3934.05,
          -3864.884,
          -3793.475,
          -3719.7529999999997,
          -3643.6479999999997,
          -3565.0879999999997,
          -3484.0009999999997,
          -3400.308,
          -3313.9320000000002,
          -3224.797,
          -3132.822,
          -3037.928,
          -2940.0359999999996,
          -2839.0690000000004,
          -2734.949,
          -2627.605,
          -2516.969,
          -2402.98,
          -2285.5820000000003,
          -2164.735,
          -2040.4070000000002,
          -1912.5870000000002,
          -1781.279,
          -1646.514,
          -1508.349,
          -1366.874,
          -1222.215,
          -1074.538,
          -924.057,
          -771.0319999999999,
          -615.775,
          -458.652,
          -300.077,
          -140.512,
          19.535,
          179.523,
          338.89,
          497.05800000000005,
          653.45,
          807.508,
          958.7,
          1106.535,
          1250.5739999999998,
          1390.434,
          1525.796,
          1656.405,
          1782.067,
          1902.649,
          2018.0739999999998,
          2128.314,
          2233.381,
          2333.328,
          2428.234,
          2518.2070000000003,
          2603.371,
          2683.865,
          2759.837,
          2831.4429999999998,
          2898.844,
          2962.198,
          3021.667,
          3077.408,
          3129.578,
          3178.3259999999996,
          3223.798,
          3266.135,
          3305.474,
          3341.9440000000004,
          3375.6690000000003,
          3406.7690000000002,
          3435.3559999999998,
          3461.594,
          3485.421,
          3507.1,
          3526.6679999999997,
          3544.2140000000004,
          3559.821,
          3573.571,
          3585.5370000000003,
          3595.7940000000003,
          3604.409,
          3611.447,
          3616.97,
          3621.0370000000003,
          3623.704,
          3625.0240000000003,
          3625.0490000000004,
          3623.8259999999996,
          3621.402,
          3617.82,
          3613.123,
          3607.35,
          3600.54,
          3592.73,
          3583.953,
          3574.244,
          3563.633,
          3552.152,
          3539.83,
          3526.695,
          3512.7729999999997,
          3498.091,
          3482.672,
          3466.5409999999997,
          3449.72,
          3432.232,
          3414.0959999999995,
          3395.3340000000003,
          3375.9640000000004,
          3356.005,
          3335.4759999999997,
          3314.3920000000003,
          3292.772,
          3270.632,
          3247.986,
          3224.848,
          3201.235,
          3177.16,
          3152.635,
          3127.675,
          3102.292,
          3076.4970000000003,
          3050.303,
          3023.72,
          2996.76,
          2969.434,
          2941.752,
          2913.723,
          2885.357,
          2856.664,
          2827.652,
          2798.3320000000003,
          2768.71,
          2738.795,
          2708.597,
          2678.1209999999996,
          2647.3759999999997,
          2616.369,
          2585.1079999999997,
          2553.599,
          2521.849,
          2489.865,
          2457.653,
          2425.22,
          2392.571,
          2359.7129999999997,
          2326.651,
          2293.391,
          2259.938,
          2226.298,
          2192.476,
          2158.4770000000003,
          2124.306,
          2089.969,
          2055.468,
          2020.81,
          1985.999,
          1951.04,
          1915.935,
          1880.691,
          1845.3110000000001,
          1809.7979999999998,
          1774.158,
          1738.3929999999998,
          1702.5079999999998,
          1666.506,
          1630.391,
          1594.1670000000001,
          1557.8370000000002,
          1521.404,
          1484.872,
          1448.244,
          1411.523,
          1374.713,
          1337.816,
          1300.835,
          1263.775,
          1226.636,
          1189.423,
          1152.139,
          1114.785,
          1077.365,
          1039.881,
          1002.336,
          964.732,
          927.073,
          889.3610000000001,
          851.597,
          813.785,
          775.927,
          738.025,
          700.082,
          662.1,
          624.08,
          586.026,
          547.94,
          509.82300000000004,
          471.67800000000005,
          433.506,
          395.311,
          357.094,
          318.856,
          280.601,
          242.329,
          204.043,
          165.745,
          127.43700000000001,
          89.12,
          50.797,
          12.468,
          -25.863000000000003,
          -64.196,
          -102.52799999999999,
          -140.858,
          -179.18400000000003,
          -217.50400000000002,
          -255.817,
          -294.121,
          -332.414,
          -370.694,
          -408.961,
          -447.212,
          -485.44599999999997,
          -523.661,
          -561.856,
          -600.029,
          -638.179,
          -676.303,
          -714.4010000000001,
          -752.471,
          -790.5110000000001,
          -828.5210000000001,
          -866.497,
          -904.44,
          -942.3480000000001,
          -980.2180000000001,
          -1018.05,
          -1055.8419999999999,
          -1093.593,
          -1131.302,
          -1168.9660000000001,
          -1206.585,
          -1244.157,
          -1281.681,
          -1319.155,
          -1356.578,
          -1393.9479999999999,
          -1431.265,
          -1468.526,
          -1505.731,
          -1542.878,
          -1579.965,
          -1616.9920000000002,
          -1653.957,
          -1690.859,
          -1727.6960000000001,
          -1764.467,
          -1801.17,
          -1837.805,
          -1874.369,
          -1910.862,
          -1947.283,
          -1983.629,
          -2019.9,
          -2056.094,
          -2092.21,
          -2128.246,
          -2164.202,
          -2200.076,
          -2235.866,
          -2271.571,
          -2307.19,
          -2342.721,
          -2378.1639999999998,
          -2413.5170000000003,
          -2448.777,
          -2483.945,
          -2519.019,
          -2553.9970000000003,
          -2588.8779999999997,
          -2623.6609999999996,
          -2658.344,
          -2692.925,
          -2727.405,
          -2761.78,
          -2796.05,
          -2830.2129999999997,
          -2864.268,
          -2898.2140000000004,
          -2932.0490000000004,
          -2965.7709999999997,
          -2999.38,
          -3032.873,
          -3066.25,
          -3099.509,
          -3132.6479999999997,
          -3165.6659999999997,
          -3198.5609999999997,
          -3231.333,
          -3263.9790000000003,
          -3296.498,
          -3328.888,
          -3361.1479999999997,
          -3393.277,
          -3425.2729999999997,
          -3457.134,
          -3488.8590000000004,
          -3520.446,
          -3551.8940000000002,
          -3583.2,
          -3614.365,
          -3645.385,
          -3676.259,
          -3706.985,
          -3737.563,
          -3767.989,
          -3798.263,
          -3828.383,
          -3858.347,
          -3888.153,
          -3917.7990000000004,
          -3947.284,
          -3976.607,
          -4005.764,
          -4034.755,
          -4063.577,
          -4092.2290000000003,
          -4120.708,
          -4149.014,
          -4177.143,
          -4205.095,
          -4232.866,
          -4260.456,
          -4287.861,
          -4315.081,
          -4342.113,
          -4368.954000000001,
          -4395.604,
          -4422.059,
          -4448.317,
          -4474.378,
          -4500.237,
          -4525.893,
          -4551.344,
          -4576.588,
          -4601.621,
          -4626.443,
          -4651.05,
          -4675.44,
          -4699.61,
          -4723.559,
          -4747.284000000001,
          -4770.781,
          -4794.05,
          -4817.085999999999,
          -4839.887,
          -4862.451,
          -4884.776,
          -4906.857,
          -4928.693,
          -4950.28,
          -4971.616,
          -4992.698,
          -5013.523,
          -5034.088,
          -5054.389,
          -5074.424,
          -5094.19,
          -5113.683,
          -5132.9,
          -5151.839,
          -5170.494000000001,
          -5188.8640000000005,
          -5206.944,
          -5224.731,
          -5242.222,
          -5259.4130000000005,
          -5276.299,
          -5292.878000000001,
          -5309.146,
          -5325.098000000001,
          -5340.731,
          -5356.04,
          -5371.022,
          -5385.672,
          -5399.986999999999,
          -5413.96,
          -5427.59,
          -5440.87,
          -5453.795999999999,
          -5466.3640000000005,
          -5478.568,
          -5490.404,
          -5501.866999999999,
          -5512.951999999999,
          -5523.654,
          -5533.967,
          -5543.8859999999995,
          -5553.405,
          -5562.519,
          -5571.223000000001,
          -5579.51,
          -5587.374,
          -5594.81,
          -5601.811,
          -5608.37,
          -5614.482,
          -5620.139,
          -5625.335,
          -5630.063,
          -5634.316,
          -5638.085,
          -5641.365,
          -5644.148,
          -5646.425,
          -5648.188,
          -5649.43,
          -5650.142,
          -5650.315,
          -5649.941999999999,
          -5649.012,
          -5647.516,
          -5645.445,
          -5642.79,
          -5639.539000000001,
          -5635.684,
          -5631.213000000001,
          -5626.116,
          -5620.382,
          -5614,
          -5606.956999999999,
          -5599.241,
          -5590.84,
          -5581.741999999999,
          -5571.933000000001,
          -5561.4,
          -5550.13,
          -5538.107,
          -5525.318,
          -5511.746,
          -5497.378000000001,
          -5482.196,
          -5466.184,
          -5449.3240000000005,
          -5431.601,
          -5412.995,
          -5393.486999999999,
          -5373.058000000001,
          -5351.689,
          -5329.358,
          -5306.044,
          -5281.726,
          -5256.38,
          -5229.983,
          -5202.5109999999995,
          -5173.938,
          -5144.238,
          -5113.3859999999995,
          -5081.351,
          -5048.105,
          -5013.6179999999995,
          -4977.859,
          -4940.7970000000005,
          -4902.396,
          -4862.623,
          -4821.441,
          -4778.814,
          -4734.702,
          -4689.064,
          -4641.859,
          -4593.043,
          -4542.572,
          -4490.398,
          -4436.474,
          -4380.747,
          -4323.165,
          -4263.675,
          -4202.219,
          -4138.7390000000005,
          -4073.1740000000004,
          -4005.4629999999997,
          -3935.5370000000003,
          -3863.3320000000003,
          -3788.777,
          -3711.801,
          -3632.3309999999997,
          -3550.289,
          -3465.6,
          -3378.184,
          -3287.9629999999997,
          -3194.8540000000003,
          -3098.775,
          -2999.647,
          -2897.39,
          -2791.926,
          -2683.179,
          -2571.081,
          -2455.5679999999998,
          -2336.5820000000003,
          -2214.08,
          -2088.029,
          -1958.4160000000002,
          -1825.243,
          -1688.537,
          -1548.3570000000002,
          -1404.789,
          -1257.9569999999999,
          -1108.03,
          -955.22,
          -799.7869999999999,
          -642.0459999999999,
          -482.36199999999997,
          -321.156,
          -158.894,
          3.911,
          166.71200000000002,
          328.935,
          489.996,
          649.308,
          806.301,
          960.433,
          1111.1989999999998,
          1258.15,
          1400.8929999999998,
          1539.098,
          1672.499,
          1800.899,
          1924.154,
          2042.183,
          2154.951,
          2262.47,
          2364.7889999999998,
          2461.986,
          2554.1679999999997,
          2641.458,
          2723.9970000000003,
          2801.934,
          2875.426,
          2944.634,
          3009.7209999999995,
          3070.849,
          3128.178,
          3181.867,
          3232.067,
          3278.927,
          3322.591,
          3363.195,
          3400.873,
          3435.7509999999997,
          3467.95,
          3497.585,
          3524.7670000000003,
          3549.599,
          3572.1820000000002,
          3592.61,
          3610.975,
          3627.36,
          3641.847,
          3654.513,
          3665.433,
          3674.675,
          3682.3070000000002,
          3688.3920000000003,
          3692.988,
          3696.1540000000005,
          3697.9440000000004,
          3698.409,
          3697.6,
          3695.562,
          3692.341,
          3687.98,
          3682.5190000000002,
          3675.998,
          3668.453,
          3659.92,
          3650.433,
          3640.025,
          3628.7259999999997,
          3616.566,
          3603.575,
          3589.7790000000005,
          3575.204,
          3559.8759999999997,
          3543.8190000000004,
          3527.055,
          3509.6079999999997,
          3491.4990000000003,
          3472.7490000000003,
          3453.375,
          3433.3990000000003,
          3412.8379999999997,
          3391.71,
          3370.031,
          3347.8190000000004,
          3325.0890000000004,
          3301.8559999999998,
          3278.136,
          3253.941,
          3229.2859999999996,
          3204.185,
          3178.6490000000003,
          3152.692,
          3126.325,
          3099.559,
          3072.407,
          3044.8779999999997,
          3016.9840000000004,
          2988.7340000000004,
          2960.139,
          2931.2070000000003,
          2901.949,
          2872.373,
          2842.488,
          2812.302,
          2781.824,
          2751.062,
          2720.0229999999997,
          2688.7140000000004,
          2657.1440000000002,
          2625.3190000000004,
          2593.2470000000003,
          2560.933,
          2528.385,
          2495.609,
          2462.611,
          2429.3979999999997,
          2395.974,
          2362.347,
          2328.521,
          2294.502,
          2260.2960000000003,
          2225.907,
          2191.341,
          2156.6020000000003,
          2121.696,
          2086.6279999999997,
          2051.401,
          2016.02,
          1980.491,
          1944.816,
          1909.001,
          1873.049,
          1836.965,
          1800.7520000000002,
          1764.414,
          1727.9560000000001,
          1691.381,
          1654.692,
          1617.892,
          1580.987,
          1543.9779999999998,
          1506.87,
          1469.665,
          1432.368,
          1394.98,
          1357.505,
          1319.9460000000001,
          1282.307,
          1244.589,
          1206.797,
          1168.932,
          1130.998,
          1092.997,
          1054.932,
          1016.805,
          978.62,
          940.3789999999999,
          902.084,
          863.738,
          825.3430000000001,
          786.9019999999999,
          748.4169999999999,
          709.89,
          671.323,
          632.72,
          594.082,
          555.411,
          516.7090000000001,
          477.97900000000004,
          439.223,
          400.44300000000004,
          361.64099999999996,
          322.818,
          283.97700000000003,
          245.12,
          206.24900000000002,
          167.36599999999999,
          128.472,
          89.57,
          50.661,
          11.748,
          -27.169,
          -66.086,
          -105.00299999999999,
          -143.918,
          -182.828,
          -221.733,
          -260.63,
          -299.518,
          -338.395,
          -377.259,
          -416.10900000000004,
          -454.944,
          -493.76,
          -532.558,
          -571.335,
          -610.09,
          -648.82,
          -687.5260000000001,
          -726.204,
          -764.8539999999999,
          -803.4739999999999,
          -842.063,
          -880.618,
          -919.1389999999999,
          -957.6239999999999,
          -996.072,
          -1034.48,
          -1072.848,
          -1111.175,
          -1149.458,
          -1187.6960000000001,
          -1225.888,
          -1264.0330000000001,
          -1302.128,
          -1340.1729999999998,
          -1378.1660000000002,
          -1416.106,
          -1453.9920000000002,
          -1491.8210000000001,
          -1529.5929999999998,
          -1567.306,
          -1604.9589999999998,
          -1642.55,
          -1680.078,
          -1717.5420000000001,
          -1754.941,
          -1792.2720000000002,
          -1829.535,
          -1866.7279999999998,
          -1903.849,
          -1940.899,
          -1977.874,
          -2014.774,
          -2051.597,
          -2088.343,
          -2125.009,
          -2161.594,
          -2198.097,
          -2234.5170000000003,
          -2270.8520000000003,
          -2307.101,
          -2343.262,
          -2379.334,
          -2415.3160000000003,
          -2451.206,
          -2487.004,
          -2522.706,
          -2558.313,
          -2593.823,
          -2629.2340000000004,
          -2664.545,
          -2699.755,
          -2734.861,
          -2769.864,
          -2804.761,
          -2839.551,
          -2874.232,
          -2908.803,
          -2943.263,
          -2977.61,
          -3011.843,
          -3045.96,
          -3079.96,
          -3113.841,
          -3147.6020000000003,
          -3181.241,
          -3214.757,
          -3248.1490000000003,
          -3281.414,
          -3314.551,
          -3347.56,
          -3380.437,
          -3413.1820000000002,
          -3445.7929999999997,
          -3478.2690000000002,
          -3510.607,
          -3542.8070000000002,
          -3574.866,
          -3606.784,
          -3638.558,
          -3670.1859999999997,
          -3701.6679999999997,
          -3733.0009999999997,
          -3764.184,
          -3795.216,
          -3826.093,
          -3856.815,
          -3887.38,
          -3917.7859999999996,
          -3948.031,
          -3978.113,
          -4008.031,
          -4037.783,
          -4067.367,
          -4096.781,
          -4126.023,
          -4155.092000000001,
          -4183.985,
          -4212.7,
          -4241.236,
          -4269.59,
          -4297.7609999999995,
          -4325.746,
          -4353.544,
          -4381.151,
          -4408.568,
          -4435.79,
          -4462.816,
          -4489.643,
          -4516.271,
          -4542.695,
          -4568.915,
          -4594.927,
          -4620.73,
          -4646.321,
          -4671.698,
          -4696.858,
          -4721.799,
          -4746.519,
          -4771.014,
          -4795.282999999999,
          -4819.323,
          -4843.130999999999,
          -4866.704000000001,
          -4890.041,
          -4913.138,
          -4935.992,
          -4958.601,
          -4980.960999999999,
          -5003.071,
          -5024.927,
          -5046.526,
          -5067.865,
          -5088.941,
          -5109.751,
          -5130.292,
          -5150.56,
          -5170.553,
          -5190.267,
          -5209.698,
          -5228.844,
          -5247.701999999999,
          -5266.266,
          -5284.534000000001,
          -5302.5019999999995,
          -5320.1669999999995,
          -5337.524,
          -5354.57,
          -5371.3009999999995,
          -5387.714,
          -5403.803000000001,
          -5419.565,
          -5434.995,
          -5450.09,
          -5464.846,
          -5479.257,
          -5493.319,
          -5507.028,
          -5520.379,
          -5533.366999999999,
          -5545.986999999999,
          -5558.235,
          -5570.105,
          -5581.593000000001,
          -5592.691999999999,
          -5603.398,
          -5613.706,
          -5623.609,
          -5633.102,
          -5642.179,
          -5650.834,
          -5659.062,
          -5666.855,
          -5674.209,
          -5681.116,
          -5687.569,
          -5693.562,
          -5699.088000000001,
          -5704.14,
          -5708.710999999999,
          -5712.793000000001,
          -5716.379,
          -5719.46,
          -5722.03,
          -5724.08,
          -5725.602,
          -5726.5869999999995,
          -5727.026999999999,
          -5726.911999999999,
          -5726.234,
          -5724.982,
          -5723.149,
          -5720.722,
          -5717.694,
          -5714.052,
          -5709.786999999999,
          -5704.887,
          -5699.342,
          -5693.139,
          -5686.268,
          -5678.714,
          -5670.467,
          -5661.513000000001,
          -5651.839,
          -5641.431,
          -5630.275,
          -5618.357,
          -5605.661999999999,
          -5592.174,
          -5577.878000000001,
          -5562.758000000001,
          -5546.795999999999,
          -5529.975,
          -5512.279,
          -5493.687,
          -5474.182,
          -5453.741999999999,
          -5432.349,
          -5409.981,
          -5386.616999999999,
          -5362.234,
          -5336.809,
          -5310.318,
          -5282.736999999999,
          -5254.039000000001,
          -5224.1990000000005,
          -5193.189,
          -5160.98,
          -5127.544,
          -5092.848,
          -5056.863,
          -5019.554,
          -4980.888,
          -4940.83,
          -4899.343,
          -4856.39,
          -4811.929,
          -4765.920999999999,
          -4718.323,
          -4669.090999999999,
          -4618.178,
          -4565.537,
          -4511.12,
          -4454.874,
          -4396.745,
          -4336.678,
          -4274.617,
          -4210.501,
          -4144.268,
          -4075.8559999999998,
          -4005.196,
          -3932.2209999999995,
          -3856.86,
          -3779.04,
          -3698.6859999999997,
          -3615.7209999999995,
          -3530.067,
          -3441.6420000000003,
          -3350.366,
          -3256.1540000000005,
          -3158.926,
          -3058.597,
          -2955.087,
          -2848.3140000000003,
          -2738.203,
          -2624.6809999999996,
          -2507.6839999999997,
          -2387.152,
          -2263.038,
          -2135.3089999999997,
          -2003.9470000000001,
          -1868.953,
          -1730.355,
          -1588.207,
          -1442.594,
          -1293.641,
          -1141.514,
          -986.424,
          -828.635,
          -668.46,
          -506.26800000000003,
          -342.48199999999997,
          -177.575,
          -12.062000000000001,
          153.502,
          318.53700000000003,
          482.445,
          644.633,
          804.5189999999999,
          961.548,
          1115.208,
          1265.036,
          1410.6270000000002,
          1551.644,
          1687.8110000000001,
          1818.921,
          1944.825,
          2065.4339999999997,
          2180.7110000000002,
          2290.663,
          2395.337,
          2494.81,
          2589.186,
          2678.591,
          2763.163,
          2843.055,
          2918.423,
          2989.4309999999996,
          3056.244,
          3119.025,
          3177.937,
          3233.1409999999996,
          3284.789,
          3333.033,
          3378.02,
          3419.889,
          3458.7740000000003,
          3494.803,
          3528.1009999999997,
          3558.785,
          3586.966,
          3612.75,
          3636.239,
          3657.53,
          3676.715,
          3693.88,
          3709.107,
          3722.4770000000003,
          3734.0640000000003,
          3743.938,
          3752.1679999999997,
          3758.8190000000004,
          3763.95,
          3767.62,
          3769.884,
          3770.796,
          3770.406,
          3768.761,
          3765.907,
          3761.888,
          3756.7459999999996,
          3750.52,
          3743.248,
          3734.967,
          3725.7090000000003,
          3715.511,
          3704.401,
          3692.4120000000003,
          3679.573,
          3665.91,
          3651.4509999999996,
          3636.222,
          3620.2470000000003,
          3603.55,
          3586.153,
          3568.079,
          3549.349,
          3529.9809999999998,
          3509.9959999999996,
          3489.413,
          3468.2490000000003,
          3446.522,
          3424.2490000000003,
          3401.445,
          3378.1259999999997,
          3354.308,
          3330.0040000000004,
          3305.2290000000003,
          3279.9959999999996,
          3254.3179999999998,
          3228.208,
          3201.679,
          3174.741,
          3147.406,
          3119.685,
          3091.59,
          3063.13,
          3034.316,
          3005.156,
          2975.6620000000003,
          2945.841,
          2915.704,
          2885.257,
          2854.511,
          2823.473,
          2792.15,
          2760.551,
          2728.683,
          2696.553,
          2664.1679999999997,
          2631.5359999999996,
          2598.663,
          2565.556,
          2532.22,
          2498.663,
          2464.89,
          2430.906,
          2396.719,
          2362.333,
          2327.7529999999997,
          2292.986,
          2258.036,
          2222.908,
          2187.6079999999997,
          2152.14,
          2116.509,
          2080.719,
          2044.775,
          2008.682,
          1972.444,
          1936.0639999999999,
          1899.547,
          1862.898,
          1826.12,
          1789.2160000000001,
          1752.192,
          1715.049,
          1677.793,
          1640.4270000000001,
          1602.953,
          1565.3770000000002,
          1527.7,
          1489.9260000000002,
          1452.059,
          1414.101,
          1376.056,
          1337.9270000000001,
          1299.7169999999999,
          1261.428,
          1223.0639999999999,
          1184.627,
          1146.121,
          1107.548,
          1068.91,
          1030.211,
          991.453,
          952.638,
          913.7689999999999,
          874.8489999999999,
          835.88,
          796.865,
          757.805,
          718.703,
          679.562,
          640.384,
          601.17,
          561.924,
          522.6469999999999,
          483.342,
          444.01,
          404.654,
          365.276,
          325.877,
          286.461,
          247.028,
          207.582,
          168.123,
          128.653,
          89.176,
          49.691,
          10.203,
          -29.289,
          -68.782,
          -108.274,
          -147.763,
          -187.24900000000002,
          -226.72799999999998,
          -266.199,
          -305.661,
          -345.111,
          -384.54900000000004,
          -423.972,
          -463.38,
          -502.769,
          -542.138,
          -581.487,
          -620.813,
          -660.115,
          -699.3910000000001,
          -738.64,
          -777.8589999999999,
          -817.048,
          -856.206,
          -895.329,
          -934.418,
          -973.47,
          -1012.4839999999999,
          -1051.458,
          -1090.392,
          -1129.282,
          -1168.129,
          -1206.931,
          -1245.685,
          -1284.392,
          -1323.0479999999998,
          -1361.654,
          -1400.2060000000001,
          -1438.705,
          -1477.148,
          -1515.5339999999999,
          -1553.862,
          -1592.131,
          -1630.338,
          -1668.4820000000002,
          -1706.5629999999999,
          -1744.578,
          -1782.527,
          -1820.408,
          -1858.219,
          -1895.9589999999998,
          -1933.626,
          -1971.221,
          -2008.74,
          -2046.182,
          -2083.547,
          -2120.833,
          -2158.038,
          -2195.161,
          -2232.2,
          -2269.155,
          -2306.0229999999997,
          -2342.804,
          -2379.496,
          -2416.098,
          -2452.6079999999997,
          -2489.025,
          -2525.347,
          -2561.573,
          -2597.702,
          -2633.732,
          -2669.6609999999996,
          -2705.489,
          -2741.2140000000004,
          -2776.835,
          -2812.349,
          -2847.756,
          -2883.054,
          -2918.242,
          -2953.3179999999998,
          -2988.281,
          -3023.1279999999997,
          -3057.86,
          -3092.474,
          -3126.969,
          -3161.343,
          -3195.594,
          -3229.722,
          -3263.725,
          -3297.6009999999997,
          -3331.348,
          -3364.965,
          -3398.4509999999996,
          -3431.804,
          -3465.022,
          -3498.1040000000003,
          -3531.047,
          -3563.8509999999997,
          -3596.514,
          -3629.034,
          -3661.41,
          -3693.639,
          -3725.7209999999995,
          -3757.653,
          -3789.433,
          -3821.0609999999997,
          -3852.534,
          -3883.85,
          -3915.008,
          -3946.006,
          -3976.842,
          -4007.514,
          -4038.0209999999997,
          -4068.36,
          -4098.53,
          -4128.529,
          -4158.354,
          -4188.004,
          -4217.477,
          -4246.771,
          -4275.885,
          -4304.815,
          -4333.56,
          -4362.1179999999995,
          -4390.486,
          -4418.664000000001,
          -4446.648,
          -4474.436,
          -4502.026,
          -4529.417,
          -4556.605,
          -4583.588,
          -4610.365,
          -4636.933,
          -4663.289000000001,
          -4689.432,
          -4715.358,
          -4741.065,
          -4766.5509999999995,
          -4791.814,
          -4816.851,
          -4841.657999999999,
          -4866.235,
          -4890.577,
          -4914.682,
          -4938.549,
          -4962.173,
          -4985.552,
          -5008.683,
          -5031.564,
          -5054.191,
          -5076.562,
          -5098.673,
          -5120.522,
          -5142.105,
          -5163.419,
          -5184.460999999999,
          -5205.228,
          -5225.715999999999,
          -5245.923000000001,
          -5265.844,
          -5285.477,
          -5304.816999999999,
          -5323.861999999999,
          -5342.608,
          -5361.05,
          -5379.186,
          -5397.01,
          -5414.52,
          -5431.7119999999995,
          -5448.581,
          -5465.124,
          -5481.335999999999,
          -5497.2119999999995,
          -5512.75,
          -5527.944,
          -5542.79,
          -5557.283,
          -5571.418000000001,
          -5585.191999999999,
          -5598.598000000001,
          -5611.633000000001,
          -5624.291,
          -5636.566999999999,
          -5648.456,
          -5659.951999999999,
          -5671.05,
          -5681.745,
          -5692.031,
          -5701.901999999999,
          -5711.353,
          -5720.376,
          -5728.967,
          -5737.118,
          -5744.8240000000005,
          -5752.078,
          -5758.874,
          -5765.203,
          -5771.06,
          -5776.437,
          -5781.326999999999,
          -5785.722,
          -5789.615,
          -5792.9980000000005,
          -5795.861999999999,
          -5798.201,
          -5800.004,
          -5801.264,
          -5801.972,
          -5802.119000000001,
          -5801.695,
          -5800.691,
          -5799.097,
          -5796.904,
          -5794.1,
          -5790.6759999999995,
          -5786.62,
          -5781.922,
          -5776.57,
          -5770.552,
          -5763.856,
          -5756.47,
          -5748.380999999999,
          -5739.576,
          -5730.0419999999995,
          -5719.765,
          -5708.73,
          -5696.923000000001,
          -5684.329000000001,
          -5670.931,
          -5656.715999999999,
          -5641.665,
          -5625.7609999999995,
          -5608.986999999999,
          -5591.326,
          -5572.757,
          -5553.262,
          -5532.821,
          -5511.414000000001,
          -5489.019,
          -5465.6140000000005,
          -5441.177,
          -5415.684,
          -5389.111,
          -5361.432,
          -5332.621,
          -5302.653,
          -5271.4980000000005,
          -5239.129,
          -5205.514,
          -5170.624,
          -5134.427,
          -5096.887,
          -5057.971,
          -5017.644,
          -4975.8679999999995,
          -4932.604,
          -4887.814,
          -4841.4529999999995,
          -4793.48,
          -4743.849,
          -4692.514,
          -4639.427,
          -4584.538,
          -4527.793,
          -4469.139,
          -4408.519,
          -4345.875,
          -4281.147,
          -4214.271,
          -4145.183,
          -4073.8140000000003,
          -4000.097,
          -3923.958,
          -3845.322,
          -3764.114,
          -3680.257,
          -3593.6679999999997,
          -3504.2659999999996,
          -3411.967,
          -3316.69,
          -3218.3459999999995,
          -3116.8520000000003,
          -3012.1259999999997,
          -2904.0840000000003,
          -2792.6479999999997,
          -2677.745,
          -2559.305,
          -2437.269,
          -2311.5879999999997,
          -2182.225,
          -2049.1620000000003,
          -1912.3970000000002,
          -1771.955,
          -1627.889,
          -1480.2820000000002,
          -1329.259,
          -1174.985,
          -1017.669,
          -857.576,
          -695.0219999999999,
          -530.377,
          -364.065,
          -196.563,
          -28.394000000000002,
          139.881,
          307.675,
          474.38300000000004,
          639.401,
          802.135,
          962.02,
          1118.5339999999999,
          1271.2,
          1419.606,
          1563.402,
          1702.3039999999999,
          1836.095,
          1964.622,
          2087.7889999999998,
          2205.553,
          2317.919,
          2424.93,
          2526.6620000000003,
          2623.219,
          2714.723,
          2801.3179999999998,
          2883.153,
          2960.388,
          3033.188,
          3101.718,
          3166.147,
          3226.635,
          3283.348,
          3336.441,
          3386.066,
          3432.3740000000003,
          3475.505,
          3515.595,
          3552.776,
          3587.173,
          3618.9040000000005,
          3648.2009999999996,
          3674.821,
          3699.219,
          3721.3740000000003,
          3741.381,
          3759.328,
          3775.301,
          3789.377,
          3801.635,
          3812.145,
          3820.978,
          3828.198,
          3833.869,
          3838.048,
          3840.7929999999997,
          3842.157,
          3842.192,
          3840.946,
          3838.466,
          3834.796,
          3829.9790000000003,
          3824.0559999999996,
          3817.0640000000003,
          3809.04,
          3800.0209999999997,
          3790.039,
          3779.1279999999997,
          3767.317,
          3754.637,
          3741.117,
          3726.783,
          3711.6620000000003,
          3695.778,
          3679.156,
          3661.8179999999998,
          3643.788,
          3625.086,
          3605.7329999999997,
          3585.7490000000003,
          3565.153,
          3543.9640000000004,
          3522.198,
          3499.873,
          3477.005,
          3453.61,
          3429.705,
          3405.302,
          3380.4179999999997,
          3355.0640000000003,
          3329.2540000000004,
          3303.002,
          3276.321,
          3249.22,
          3221.7140000000004,
          3193.813,
          3165.527,
          3136.868,
          3107.845,
          3078.469,
          3048.7490000000003,
          3018.695,
          2988.316,
          2957.62,
          2926.616,
          2895.313,
          2863.718,
          2831.8390000000004,
          2799.684,
          2767.261,
          2734.577,
          2701.638,
          2668.4509999999996,
          2635.0240000000003,
          2601.362,
          2567.473,
          2533.361,
          2499.033,
          2464.496,
          2429.754,
          2394.814,
          2359.68,
          2324.3579999999997,
          2288.853,
          2253.1710000000003,
          2217.315,
          2181.292,
          2145.105,
          2108.759,
          2072.259,
          2035.609,
          1998.8139999999999,
          1961.8770000000002,
          1924.8029999999999,
          1887.596,
          1850.26,
          1812.7979999999998,
          1775.215,
          1737.513,
          1699.6979999999999,
          1661.7720000000002,
          1623.739,
          1585.601,
          1547.364,
          1509.03,
          1470.601,
          1432.082,
          1393.476,
          1354.7839999999999,
          1316.0120000000002,
          1277.161,
          1238.234,
          1199.234,
          1160.165,
          1121.028,
          1081.827,
          1042.563,
          1003.2410000000001,
          963.862,
          924.429,
          884.944,
          845.41,
          805.83,
          766.205,
          726.538,
          686.831,
          647.087,
          607.308,
          567.497,
          527.654,
          487.783,
          447.88599999999997,
          407.964,
          368.02,
          328.056,
          288.074,
          248.076,
          208.063,
          168.03900000000002,
          128.004,
          87.961,
          47.912,
          7.858,
          -32.199,
          -72.257,
          -112.31299999999999,
          -152.36700000000002,
          -192.416,
          -232.459,
          -272.494,
          -312.519,
          -352.533,
          -392.534,
          -432.519,
          -472.48800000000006,
          -512.439,
          -552.37,
          -592.28,
          -632.1669999999999,
          -672.028,
          -711.8639999999999,
          -751.672,
          -791.45,
          -831.198,
          -870.9119999999999,
          -910.5930000000001,
          -950.238,
          -989.846,
          -1029.415,
          -1068.945,
          -1108.432,
          -1147.876,
          -1187.276,
          -1226.629,
          -1265.935,
          -1305.192,
          -1344.398,
          -1383.5529999999999,
          -1422.654,
          -1461.7,
          -1500.6889999999999,
          -1539.621,
          -1578.494,
          -1617.306,
          -1656.056,
          -1694.7420000000002,
          -1733.364,
          -1771.9189999999999,
          -1810.406,
          -1848.825,
          -1887.172,
          -1925.4479999999999,
          -1963.65,
          -2001.7779999999998,
          -2039.829,
          -2077.803,
          -2115.697,
          -2153.511,
          -2191.244,
          -2228.8920000000003,
          -2266.4570000000003,
          -2303.935,
          -2341.325,
          -2378.627,
          -2415.8379999999997,
          -2452.9570000000003,
          -2489.9829999999997,
          -2526.915,
          -2563.75,
          -2600.488,
          -2637.127,
          -2673.665,
          -2710.1020000000003,
          -2746.435,
          -2782.663,
          -2818.785,
          -2854.8,
          -2890.705,
          -2926.5,
          -2962.1820000000002,
          -2997.7509999999997,
          -3033.204,
          -3068.5409999999997,
          -3103.76,
          -3138.8590000000004,
          -3173.837,
          -3208.692,
          -3243.422,
          -3278.027,
          -3312.5040000000004,
          -3346.8520000000003,
          -3381.0690000000004,
          -3415.155,
          -3449.1059999999998,
          -3482.922,
          -3516.6009999999997,
          -3550.1409999999996,
          -3583.5409999999997,
          -3616.7990000000004,
          -3649.913,
          -3682.881,
          -3715.703,
          -3748.3759999999997,
          -3780.8979999999997,
          -3813.268,
          -3845.4840000000004,
          -3877.5440000000003,
          -3909.446,
          -3941.1890000000003,
          -3972.7709999999997,
          -4004.19,
          -4035.4429999999998,
          -4066.53,
          -4097.4490000000005,
          -4128.197,
          -4158.772,
          -4189.173,
          -4219.397,
          -4249.443,
          -4279.308,
          -4308.992,
          -4338.49,
          -4367.802,
          -4396.9259999999995,
          -4425.858,
          -4454.598,
          -4483.143,
          -4511.49,
          -4539.638,
          -4567.584,
          -4595.327,
          -4622.863,
          -4650.19,
          -4677.306,
          -4704.21,
          -4730.897,
          -4757.366,
          -4783.615,
          -4809.64,
          -4835.44,
          -4861.0109999999995,
          -4886.352,
          -4911.459,
          -4936.33,
          -4960.963,
          -4985.353,
          -5009.499,
          -5033.398,
          -5057.0470000000005,
          -5080.442,
          -5103.582,
          -5126.462,
          -5149.081,
          -5171.434,
          -5193.519,
          -5215.333,
          -5236.872,
          -5258.133000000001,
          -5279.113,
          -5299.808000000001,
          -5320.214,
          -5340.33,
          -5360.15,
          -5379.670999999999,
          -5398.89,
          -5417.802,
          -5436.404,
          -5454.693,
          -5472.664000000001,
          -5490.313,
          -5507.6359999999995,
          -5524.629,
          -5541.286999999999,
          -5557.608,
          -5573.585,
          -5589.215,
          -5604.493,
          -5619.415,
          -5633.975,
          -5648.169,
          -5661.993,
          -5675.44,
          -5688.505999999999,
          -5701.186,
          -5713.475,
          -5725.366999999999,
          -5736.856,
          -5747.938,
          -5758.605,
          -5768.854,
          -5778.6759999999995,
          -5788.068,
          -5797.021,
          -5805.53,
          -5813.589,
          -5821.19,
          -5828.326999999999,
          -5834.993,
          -5841.181,
          -5846.884,
          -5852.094,
          -5856.804,
          -5861.005,
          -5864.69,
          -5867.851,
          -5870.48,
          -5872.566999999999,
          -5874.105,
          -5875.0830000000005,
          -5875.494000000001,
          -5875.326999999999,
          -5874.573,
          -5873.223000000001,
          -5871.265,
          -5868.69,
          -5865.486,
          -5861.644,
          -5857.151,
          -5851.996999999999,
          -5846.168000000001,
          -5839.653,
          -5832.44,
          -5824.515,
          -5815.865,
          -5806.477,
          -5796.335999999999,
          -5785.428000000001,
          -5773.7390000000005,
          -5761.2519999999995,
          -5747.953,
          -5733.8240000000005,
          -5718.85,
          -5703.012,
          -5686.293000000001,
          -5668.675,
          -5650.139,
          -5630.664000000001,
          -5610.231,
          -5588.82,
          -5566.408,
          -5542.973000000001,
          -5518.493,
          -5492.941999999999,
          -5466.298000000001,
          -5438.533,
          -5409.621999999999,
          -5379.5380000000005,
          -5348.253000000001,
          -5315.736,
          -5281.9580000000005,
          -5246.888000000001,
          -5210.492,
          -5172.737,
          -5133.588,
          -5093.008,
          -5050.959,
          -5007.403,
          -4962.3,
          -4915.605,
          -4867.276,
          -4817.266,
          -4765.53,
          -4712.017,
          -4656.677,
          -4599.456,
          -4540.299,
          -4479.149,
          -4415.947,
          -4350.6320000000005,
          -4283.138,
          -4213.401,
          -4141.351,
          -4066.9190000000003,
          -3990.03,
          -3910.6090000000004,
          -3828.578,
          -3743.8590000000004,
          -3656.368,
          -3566.0229999999997,
          -3472.738,
          -3376.429,
          -3277.007,
          -3174.386,
          -3068.4840000000004,
          -2959.212,
          -2846.493,
          -2730.2509999999997,
          -2610.413,
          -2486.919,
          -2359.717,
          -2228.768,
          -2094.052,
          -1955.565,
          -1813.33,
          -1667.399,
          -1517.852,
          -1364.8129999999999,
          -1208.4460000000001,
          -1048.96,
          -886.62,
          -721.743,
          -554.6990000000001,
          -385.917,
          -215.877,
          -45.107,
          125.82799999999999,
          296.329,
          465.786,
          633.5840000000001,
          799.1210000000001,
          961.819,
          1121.144,
          1276.612,
          1427.795,
          1574.336,
          1715.94,
          1852.385,
          1983.5079999999998,
          2109.2070000000003,
          2229.436,
          2344.195,
          2453.5229999999997,
          2557.4970000000003,
          2656.218,
          2749.81,
          2838.4120000000003,
          2922.18,
          3001.2709999999997,
          3075.8540000000003,
          3146.094,
          3212.1620000000003,
          3274.2209999999995,
          3332.437,
          3386.97,
          3437.973,
          3485.597,
          3529.988,
          3571.281,
          3609.611,
          3645.1059999999998,
          3677.885,
          3708.065,
          3735.756,
          3761.062,
          3784.0840000000003,
          3804.9159999999997,
          3823.6479999999997,
          3840.366,
          3855.1540000000005,
          3868.085,
          3879.235,
          3888.675,
          3896.47,
          3902.684,
          3907.3779999999997,
          3910.6090000000004,
          3912.43,
          3912.8959999999997,
          3912.055,
          3909.955,
          3906.6409999999996,
          3902.156,
          3896.542,
          3889.837,
          3882.079,
          3873.305,
          3863.548,
          3852.842,
          3841.218,
          3828.7070000000003,
          3815.336,
          3801.135,
          3786.13,
          3770.3459999999995,
          3753.808,
          3736.539,
          3718.562,
          3699.8990000000003,
          3680.57,
          3660.597,
          3639.998,
          3618.792,
          3596.9970000000003,
          3574.63,
          3551.7090000000003,
          3528.2490000000003,
          3504.2659999999996,
          3479.775,
          3454.79,
          3429.3259999999996,
          3403.395,
          3377.012,
          3350.1890000000003,
          3322.938,
          3295.2709999999997,
          3267.199,
          3238.7340000000004,
          3209.886,
          3180.667,
          3151.085,
          3121.152,
          3090.875,
          3060.2659999999996,
          3029.3320000000003,
          2998.0820000000003,
          2966.526,
          2934.67,
          2902.5240000000003,
          2870.095,
          2837.39,
          2804.417,
          2771.183,
          2737.695,
          2703.9590000000003,
          2669.9840000000004,
          2635.7729999999997,
          2601.3360000000002,
          2566.676,
          2531.801,
          2496.715,
          2461.426,
          2425.938,
          2390.256,
          2354.386,
          2318.333,
          2282.1020000000003,
          2245.699,
          2209.127,
          2172.391,
          2135.4970000000003,
          2098.448,
          2061.249,
          2023.905,
          1986.4189999999999,
          1948.795,
          1911.0379999999998,
          1873.152,
          1835.14,
          1797.006,
          1758.754,
          1720.388,
          1681.911,
          1643.326,
          1604.6370000000002,
          1565.848,
          1526.9620000000002,
          1487.981,
          1448.9089999999999,
          1409.75,
          1370.506,
          1331.18,
          1291.776,
          1252.296,
          1212.742,
          1173.119,
          1133.428,
          1093.673,
          1053.855,
          1013.9780000000001,
          974.045,
          934.057,
          894.0169999999999,
          853.929,
          813.793,
          773.613,
          733.3910000000001,
          693.1289999999999,
          652.83,
          612.496,
          572.128,
          531.73,
          491.30400000000003,
          450.851,
          410.374,
          369.875,
          329.356,
          288.819,
          248.265,
          207.69799999999998,
          167.11900000000003,
          126.529,
          85.932,
          45.328,
          4.72,
          -35.891,
          -76.502,
          -117.11200000000001,
          -157.719,
          -198.322,
          -238.918,
          -279.505,
          -320.08299999999997,
          -360.648,
          -401.2,
          -441.73699999999997,
          -482.25699999999995,
          -522.758,
          -563.24,
          -603.6990000000001,
          -644.134,
          -684.545,
          -724.929,
          -765.284,
          -805.61,
          -845.904,
          -886.165,
          -926.3910000000001,
          -966.581,
          -1006.7330000000001,
          -1046.846,
          -1086.9189999999999,
          -1126.948,
          -1166.934,
          -1206.875,
          -1246.769,
          -1286.614,
          -1326.41,
          -1366.154,
          -1405.846,
          -1445.483,
          -1485.0639999999999,
          -1524.588,
          -1564.0539999999999,
          -1603.4589999999998,
          -1642.8029999999999,
          -1682.0839999999998,
          -1721.3,
          -1760.451,
          -1799.5339999999999,
          -1838.5479999999998,
          -1877.4920000000002,
          -1916.365,
          -1955.164,
          -1993.889,
          -2032.5379999999998,
          -2071.109,
          -2109.601,
          -2148.014,
          -2186.344,
          -2224.591,
          -2262.754,
          -2300.831,
          -2338.82,
          -2376.72,
          -2414.53,
          -2452.248,
          -2489.873,
          -2527.403,
          -2564.837,
          -2602.173,
          -2639.4109999999996,
          -2676.547,
          -2713.5820000000003,
          -2750.513,
          -2787.3390000000004,
          -2824.058,
          -2860.67,
          -2897.172,
          -2933.563,
          -2969.842,
          -3006.006,
          -3042.055,
          -3077.987,
          -3113.801,
          -3149.494,
          -3185.065,
          -3220.514,
          -3255.837,
          -3291.034,
          -3326.103,
          -3361.042,
          -3395.85,
          -3430.526,
          -3465.066,
          -3499.4709999999995,
          -3533.737,
          -3567.865,
          -3601.8509999999997,
          -3635.6940000000004,
          -3669.393,
          -3702.946,
          -3736.35,
          -3769.605,
          -3802.7090000000003,
          -3835.659,
          -3868.455,
          -3901.093,
          -3933.573,
          -3965.893,
          -3998.05,
          -4030.0429999999997,
          -4061.87,
          -4093.5290000000005,
          -4125.018,
          -4156.335999999999,
          -4187.48,
          -4218.448,
          -4249.238,
          -4279.849,
          -4310.278,
          -4340.523,
          -4370.582,
          -4400.454000000001,
          -4430.135,
          -4459.624,
          -4488.919,
          -4518.017,
          -4546.916,
          -4575.6140000000005,
          -4604.109,
          -4632.398,
          -4660.479,
          -4688.35,
          -4716.008,
          -4743.451,
          -4770.677,
          -4797.682,
          -4824.465,
          -4851.023,
          -4877.354,
          -4903.454000000001,
          -4929.321,
          -4954.9529999999995,
          -4980.346,
          -5005.499,
          -5030.407,
          -5055.069,
          -5079.482,
          -5103.642,
          -5127.5470000000005,
          -5151.193,
          -5174.5779999999995,
          -5197.6990000000005,
          -5220.5509999999995,
          -5243.133000000001,
          -5265.441,
          -5287.472,
          -5309.222,
          -5330.688,
          -5351.866999999999,
          -5372.755,
          -5393.348000000001,
          -5413.643,
          -5433.6359999999995,
          -5453.3240000000005,
          -5472.703,
          -5491.769,
          -5510.517,
          -5528.945,
          -5547.047,
          -5564.821,
          -5582.2609999999995,
          -5599.363,
          -5616.1230000000005,
          -5632.536999999999,
          -5648.6,
          -5664.307,
          -5679.655,
          -5694.637,
          -5709.25,
          -5723.486999999999,
          -5737.344,
          -5750.816999999999,
          -5763.899,
          -5776.585999999999,
          -5788.871,
          -5800.75,
          -5812.217,
          -5823.265,
          -5833.89,
          -5844.084,
          -5853.842,
          -5863.156999999999,
          -5872.023,
          -5880.434,
          -5888.383000000001,
          -5895.861999999999,
          -5902.865,
          -5909.384,
          -5915.4130000000005,
          -5920.944,
          -5925.969,
          -5930.479,
          -5934.468000000001,
          -5937.9259999999995,
          -5940.846,
          -5943.219,
          -5945.035,
          -5946.286999999999,
          -5946.964,
          -5947.056,
          -5946.556,
          -5945.451,
          -5943.732,
          -5941.388000000001,
          -5938.409000000001,
          -5934.784000000001,
          -5930.5,
          -5925.547,
          -5919.911999999999,
          -5913.5830000000005,
          -5906.547,
          -5898.791,
          -5890.3009999999995,
          -5881.064,
          -5871.066,
          -5860.291,
          -5848.726,
          -5836.353,
          -5823.158,
          -5809.124,
          -5794.234,
          -5778.47,
          -5761.814,
          -5744.246999999999,
          -5725.7519999999995,
          -5706.306,
          -5685.891,
          -5664.484,
          -5642.065,
          -5618.61,
          -5594.098000000001,
          -5568.501,
          -5541.797,
          -5513.9580000000005,
          -5484.959,
          -5454.772,
          -5423.369000000001,
          -5390.718000000001,
          -5356.79,
          -5321.555,
          -5284.975,
          -5247.02,
          -5207.652,
          -5166.835,
          -5124.531,
          -5080.7,
          -5035.3009999999995,
          -4988.291,
          -4939.624,
          -4889.255999999999,
          -4837.137,
          -4783.219,
          -4727.45,
          -4669.774,
          -4610.137,
          -4548.48,
          -4484.744000000001,
          -4418.866,
          -4350.78,
          -4280.42,
          -4207.715999999999,
          -4132.598,
          -4054.987,
          -3974.81,
          -3891.988,
          -3806.4390000000003,
          -3718.078,
          -3626.823,
          -3532.587,
          -3435.281,
          -3334.817,
          -3231.1090000000004,
          -3124.067,
          -3013.607,
          -2899.647,
          -2782.1059999999998,
          -2660.914,
          -2536.007,
          -2407.33,
          -2274.843,
          -2138.524,
          -1998.365,
          -1854.39,
          -1706.644,
          -1555.211,
          -1400.211,
          -1241.805,
          -1080.2060000000001,
          -915.677,
          -748.5319999999999,
          -579.1469999999999,
          -407.95300000000003,
          -235.43200000000002,
          -62.117,
          111.42,
          284.575,
          456.728,
          627.255,
          795.544,
          961.008,
          1123.099,
          1281.322,
          1435.243,
          1584.49,
          1728.763,
          1867.826,
          2001.514,
          2129.717,
          2252.384,
          2369.511,
          2481.134,
          2587.3289999999997,
          2688.1940000000004,
          2783.855,
          2874.45,
          2960.135,
          3041.0690000000004,
          3117.422,
          3189.361,
          3257.0570000000002,
          3320.678,
          3380.39,
          3436.3559999999998,
          3488.73,
          3537.6659999999997,
          3583.3109999999997,
          3625.804,
          3665.281,
          3701.8709999999996,
          3735.696,
          3766.8740000000003,
          3795.5170000000003,
          3821.732,
          3845.6209999999996,
          3867.278,
          3886.797,
          3904.263,
          3919.762,
          3933.3709999999996,
          3945.164,
          3955.2129999999997,
          3963.587,
          3970.349,
          3975.562,
          3979.282,
          3981.567,
          3982.469,
          3982.038,
          3980.324,
          3977.3709999999996,
          3973.224,
          3967.926,
          3961.5159999999996,
          3954.031,
          3945.509,
          3935.9840000000004,
          3925.491,
          3914.062,
          3901.7259999999997,
          3888.515,
          3874.455,
          3859.575,
          3843.8990000000003,
          3827.454,
          3810.262,
          3792.347,
          3773.732,
          3754.438,
          3734.4840000000004,
          3713.8920000000003,
          3692.679,
          3670.865,
          3648.467,
          3625.502,
          3601.986,
          3577.937,
          3553.367,
          3528.2940000000003,
          3502.73,
          3476.6890000000003,
          3450.185,
          3423.232,
          3395.84,
          3368.0240000000003,
          3339.7929999999997,
          3311.16,
          3282.136,
          3252.73,
          3222.955,
          3192.8190000000004,
          3162.3320000000003,
          3131.5040000000004,
          3100.344,
          3068.861,
          3037.063,
          3004.9590000000003,
          2972.5570000000002,
          2939.864,
          2906.89,
          2873.6409999999996,
          2840.1240000000003,
          2806.3459999999995,
          2772.315,
          2738.038,
          2703.52,
          2668.768,
          2633.789,
          2598.5879999999997,
          2563.172,
          2527.5460000000003,
          2491.715,
          2455.686,
          2419.464,
          2383.053,
          2346.46,
          2309.689,
          2272.745,
          2235.632,
          2198.356,
          2160.9210000000003,
          2123.3320000000003,
          2085.592,
          2047.707,
          2009.68,
          1971.515,
          1933.217,
          1894.79,
          1856.236,
          1817.5610000000001,
          1778.767,
          1739.859,
          1700.84,
          1661.713,
          1622.4820000000002,
          1583.151,
          1543.721,
          1504.1979999999999,
          1464.5839999999998,
          1424.881,
          1385.094,
          1345.225,
          1305.277,
          1265.253,
          1225.156,
          1184.99,
          1144.755,
          1104.4560000000001,
          1064.094,
          1023.673,
          983.195,
          942.663,
          902.079,
          861.446,
          820.7660000000001,
          780.041,
          739.275,
          698.4680000000001,
          657.625,
          616.746,
          575.8340000000001,
          534.8919999999999,
          493.921,
          452.92400000000004,
          411.903,
          370.85900000000004,
          329.796,
          288.715,
          247.618,
          206.507,
          165.38400000000001,
          124.251,
          83.111,
          41.964,
          0.813,
          -40.34,
          -81.494,
          -122.646,
          -163.795,
          -204.93900000000002,
          -246.076,
          -287.204,
          -328.32199999999995,
          -369.42800000000005,
          -410.52,
          -451.596,
          -492.655,
          -533.695,
          -574.714,
          -615.711,
          -656.684,
          -697.6310000000001,
          -738.551,
          -779.443,
          -820.303,
          -861.132,
          -901.927,
          -942.686,
          -983.409,
          -1024.094,
          -1064.738,
          -1105.3410000000001,
          -1145.901,
          -1186.417,
          -1226.886,
          -1267.308,
          -1307.681,
          -1348.003,
          -1388.2720000000002,
          -1428.489,
          -1468.65,
          -1508.754,
          -1548.8010000000002,
          -1588.7879999999998,
          -1628.713,
          -1668.5770000000002,
          -1708.376,
          -1748.11,
          -1787.777,
          -1827.375,
          -1866.904,
          -1906.361,
          -1945.746,
          -1985.056,
          -2024.2910000000002,
          -2063.448,
          -2102.527,
          -2141.526,
          -2180.444,
          -2219.278,
          -2258.028,
          -2296.692,
          -2335.268,
          -2373.756,
          -2412.153,
          -2450.459,
          -2488.6710000000003,
          -2526.7889999999998,
          -2564.81,
          -2602.734,
          -2640.558,
          -2678.282,
          -2715.9040000000005,
          -2753.422,
          -2790.835,
          -2828.1409999999996,
          -2865.3390000000004,
          -2902.427,
          -2939.4040000000005,
          -2976.268,
          -3013.018,
          -3049.652,
          -3086.1690000000003,
          -3122.566,
          -3158.843,
          -3194.998,
          -3231.0290000000005,
          -3266.935,
          -3302.7140000000004,
          -3338.364,
          -3373.885,
          -3409.2729999999997,
          -3444.528,
          -3479.6479999999997,
          -3514.631,
          -3549.4759999999997,
          -3584.18,
          -3618.743,
          -3653.163,
          -3687.437,
          -3721.5640000000003,
          -3755.542,
          -3789.37,
          -3823.045,
          -3856.567,
          -3889.9320000000002,
          -3923.14,
          -3956.188,
          -3989.075,
          -4021.7990000000004,
          -4054.357,
          -4086.748,
          -4118.971,
          -4151.022,
          -4182.901,
          -4214.604,
          -4246.130999999999,
          -4277.479,
          -4308.646,
          -4339.63,
          -4370.429,
          -4401.041,
          -4431.463,
          -4461.695,
          -4491.731,
          -4521.5740000000005,
          -4551.217000000001,
          -4580.66,
          -4609.901,
          -4638.936,
          -4667.765,
          -4696.384,
          -4724.791,
          -4752.983,
          -4780.959,
          -4808.715999999999,
          -4836.25,
          -4863.561,
          -4890.644,
          -4917.498,
          -4944.12,
          -4970.5070000000005,
          -4996.657,
          -5022.566,
          -5048.232,
          -5073.652,
          -5098.8240000000005,
          -5123.744000000001,
          -5148.409000000001,
          -5172.817,
          -5196.964,
          -5220.847,
          -5244.464,
          -5267.81,
          -5290.884,
          -5313.681,
          -5336.198,
          -5358.432,
          -5380.379,
          -5402.036,
          -5423.4,
          -5444.467,
          -5465.233,
          -5485.694,
          -5505.846,
          -5525.687,
          -5545.210999999999,
          -5564.416,
          -5583.295999999999,
          -5601.848000000001,
          -5620.068,
          -5637.951,
          -5655.493,
          -5672.69,
          -5689.536999999999,
          -5706.03,
          -5722.1630000000005,
          -5737.933000000001,
          -5753.334,
          -5768.361999999999,
          -5783.0109999999995,
          -5797.276,
          -5811.151999999999,
          -5824.635,
          -5837.717,
          -5850.395,
          -5862.661999999999,
          -5874.512,
          -5885.94,
          -5896.939,
          -5907.503000000001,
          -5917.6269999999995,
          -5927.303000000001,
          -5936.526,
          -5945.2880000000005,
          -5953.5830000000005,
          -5961.404,
          -5968.744000000001,
          -5975.595,
          -5981.95,
          -5987.802,
          -5993.142,
          -5997.9619999999995,
          -6002.255999999999,
          -6006.014,
          -6009.226,
          -6011.8859999999995,
          -6013.983,
          -6015.509,
          -6016.454000000001,
          -6016.809,
          -6016.563,
          -6015.706999999999,
          -6014.23,
          -6012.121999999999,
          -6009.37,
          -6005.965,
          -6001.896,
          -5997.148,
          -5991.710999999999,
          -5985.571999999999,
          -5978.717,
          -5971.135,
          -5962.811,
          -5953.731,
          -5943.880999999999,
          -5933.246,
          -5921.81,
          -5909.559,
          -5896.476,
          -5882.543000000001,
          -5867.745,
          -5852.062,
          -5835.477,
          -5817.971,
          -5799.525,
          -5780.118,
          -5759.73,
          -5738.339,
          -5715.923000000001,
          -5692.459,
          -5667.923000000001,
          -5642.2919999999995,
          -5615.539000000001,
          -5587.639,
          -5558.565,
          -5528.289000000001,
          -5496.78,
          -5464.01,
          -5429.946999999999,
          -5394.559,
          -5357.812,
          -5319.672,
          -5280.103,
          -5239.066,
          -5196.524,
          -5152.435,
          -5106.759,
          -5059.452,
          -5010.468,
          -4959.7609999999995,
          -4907.281,
          -4852.979,
          -4796.803,
          -4738.696,
          -4678.602,
          -4616.463,
          -4552.218,
          -4485.803,
          -4417.152,
          -4346.196,
          -4272.867,
          -4197.09,
          -4118.789000000001,
          -4037.888,
          -3954.305,
          -3867.958,
          -3778.764,
          -3686.634,
          -3591.4809999999998,
          -3493.217,
          -3391.75,
          -3286.992,
          -3178.8540000000003,
          -3067.248,
          -2952.0890000000004,
          -2833.296,
          -2710.797,
          -2584.524,
          -2454.4210000000003,
          -2320.448,
          -2182.575,
          -2040.7979999999998,
          -1895.134,
          -1745.632,
          -1592.369,
          -1435.464,
          -1275.0810000000001,
          -1111.427,
          -944.7669999999999,
          -775.4169999999999,
          -603.753,
          -430.20599999999996,
          -255.264,
          -79.464,
          96.617,
          272.368,
          447.162,
          620.364,
          791.3530000000001,
          959.5319999999999,
          1124.3419999999999,
          1285.278,
          1441.8929999999998,
          1593.808,
          1740.71,
          1882.359,
          2018.578,
          2149.256,
          2274.333,
          2393.802,
          2507.698,
          2616.092,
          2719.0820000000003,
          2816.7929999999997,
          2909.366,
          2996.952,
          3079.717,
          3157.8259999999996,
          3231.453,
          3300.768,
          3365.942,
          3427.1420000000003,
          3484.533,
          3538.2729999999997,
          3588.515,
          3635.4109999999996,
          3679.099,
          3719.72,
          3757.402,
          3792.2709999999997,
          3824.455,
          3854.0429999999997,
          3881.1659999999997,
          3905.921,
          3928.405,
          3948.712,
          3966.929,
          3983.1409999999996,
          3997.429,
          4009.869,
          4020.532,
          4029.488,
          4036.802,
          4042.5370000000003,
          4046.7540000000004,
          4049.506,
          4050.85,
          4050.836,
          4049.513,
          4046.928,
          4043.127,
          4038.151,
          4032.0409999999997,
          4024.836,
          4016.574,
          4007.29,
          3997.018,
          3985.7909999999997,
          3973.64,
          3960.5959999999995,
          3946.6859999999997,
          3931.9390000000003,
          3916.381,
          3900.0370000000003,
          3882.9320000000002,
          3865.09,
          3846.532,
          3827.281,
          3807.3579999999997,
          3786.782,
          3765.574,
          3743.7509999999997,
          3721.3320000000003,
          3698.3340000000003,
          3674.7740000000003,
          3650.667,
          3626.03,
          3600.8779999999997,
          3575.225,
          3549.086,
          3522.473,
          3495.4,
          3467.88,
          3439.925,
          3411.547,
          3382.758,
          3353.5690000000004,
          3323.99,
          3294.032,
          3263.7059999999997,
          3233.0209999999997,
          3201.987,
          3170.613,
          3138.908,
          3106.881,
          3074.5409999999997,
          3041.895,
          3008.953,
          2975.7209999999995,
          2942.208,
          2908.421,
          2874.367,
          2840.053,
          2805.486,
          2770.673,
          2735.62,
          2700.3340000000003,
          2664.821,
          2629.086,
          2593.136,
          2556.9770000000003,
          2520.614,
          2484.052,
          2447.297,
          2410.354,
          2373.229,
          2335.926,
          2298.45,
          2260.805,
          2222.998,
          2185.031,
          2146.91,
          2108.638,
          2070.221,
          2031.6629999999998,
          1992.9660000000001,
          1954.1370000000002,
          1915.1770000000001,
          1876.092,
          1836.885,
          1797.559,
          1758.119,
          1718.567,
          1678.908,
          1639.145,
          1599.281,
          1559.319,
          1519.263,
          1479.116,
          1438.881,
          1398.5610000000001,
          1358.1589999999999,
          1317.6779999999999,
          1277.121,
          1236.491,
          1195.7910000000002,
          1155.0230000000001,
          1114.19,
          1073.296,
          1032.3410000000001,
          991.33,
          950.265,
          909.1469999999999,
          867.9810000000001,
          826.7669999999999,
          785.51,
          744.21,
          702.87,
          661.493,
          620.082,
          578.637,
          537.1619999999999,
          495.658,
          454.12800000000004,
          412.574,
          370.99800000000005,
          329.403,
          287.789,
          246.16,
          204.518,
          162.863,
          121.199,
          79.527,
          37.849000000000004,
          -3.833,
          -45.516000000000005,
          -87.2,
          -128.882,
          -170.56099999999998,
          -212.234,
          -253.9,
          -295.556,
          -337.20300000000003,
          -378.836,
          -420.455,
          -462.059,
          -503.644,
          -545.21,
          -586.755,
          -628.2769999999999,
          -669.775,
          -711.247,
          -752.69,
          -794.105,
          -835.488,
          -876.8389999999999,
          -918.155,
          -959.435,
          -1000.678,
          -1041.882,
          -1083.046,
          -1124.167,
          -1165.244,
          -1206.276,
          -1247.262,
          -1288.1989999999998,
          -1329.086,
          -1369.921,
          -1410.704,
          -1451.4370000000001,
          -1492.109,
          -1532.724,
          -1573.28,
          -1613.775,
          -1654.2079999999999,
          -1694.578,
          -1734.8829999999998,
          -1775.121,
          -1815.2910000000002,
          -1855.392,
          -1895.422,
          -1935.38,
          -1975.263,
          -2015.0720000000001,
          -2054.803,
          -2094.456,
          -2134.029,
          -2173.522,
          -2212.931,
          -2252.256,
          -2291.495,
          -2330.647,
          -2369.71,
          -2408.683,
          -2447.565,
          -2486.353,
          -2525.047,
          -2563.644,
          -2602.143,
          -2640.5440000000003,
          -2678.843,
          -2717.0409999999997,
          -2755.134,
          -2793.1220000000003,
          -2831.0040000000004,
          -2868.777,
          -2906.44,
          -2943.992,
          -2981.43,
          -3018.7540000000004,
          -3055.962,
          -3093.052,
          -3130.0229999999997,
          -3166.873,
          -3203.6009999999997,
          -3240.204,
          -3276.6820000000002,
          -3313.032,
          -3349.2529999999997,
          -3385.344,
          -3421.302,
          -3457.127,
          -3492.816,
          -3528.367,
          -3563.7790000000005,
          -3599.051,
          -3634.18,
          -3669.165,
          -3704.0040000000004,
          -3738.696,
          -3773.238,
          -3807.6279999999997,
          -3841.866,
          -3875.949,
          -3909.875,
          -3943.6420000000003,
          -3977.2490000000003,
          -4010.6940000000004,
          -4043.974,
          -4077.0879999999997,
          -4110.035,
          -4142.811,
          -4175.415,
          -4207.846,
          -4240.1,
          -4272.1759999999995,
          -4304.073,
          -4335.787,
          -4367.317,
          -4398.661,
          -4429.817,
          -4460.782,
          -4491.553,
          -4522.130999999999,
          -4552.5109999999995,
          -4582.691,
          -4612.670999999999,
          -4642.445,
          -4672.014,
          -4701.374,
          -4730.522,
          -4759.457,
          -4788.177,
          -4816.677,
          -4844.957,
          -4873.013,
          -4900.844,
          -4928.445,
          -4955.816,
          -4982.952,
          -5009.852,
          -5036.512,
          -5062.93,
          -5089.104,
          -5115.029,
          -5140.7029999999995,
          -5166.124,
          -5191.288,
          -5216.193,
          -5240.834,
          -5265.21,
          -5289.316999999999,
          -5313.151,
          -5336.71,
          -5359.99,
          -5382.986999999999,
          -5405.7,
          -5428.1230000000005,
          -5450.253000000001,
          -5472.0869999999995,
          -5493.621999999999,
          -5514.853,
          -5535.776999999999,
          -5556.39,
          -5576.687,
          -5596.666,
          -5616.321999999999,
          -5635.65,
          -5654.648,
          -5673.31,
          -5691.632,
          -5709.61,
          -5727.24,
          -5744.516,
          -5761.435,
          -5777.991999999999,
          -5794.181,
          -5809.9980000000005,
          -5825.438,
          -5840.495,
          -5855.166,
          -5869.443,
          -5883.323,
          -5896.799,
          -5909.866999999999,
          -5922.519,
          -5934.751,
          -5946.556,
          -5957.928000000001,
          -5968.861,
          -5979.35,
          -5989.3859999999995,
          -5998.964,
          -6008.078,
          -6016.719,
          -6024.880999999999,
          -6032.557,
          -6039.74,
          -6046.420999999999,
          -6052.594,
          -6058.25,
          -6063.382,
          -6067.98,
          -6072.0380000000005,
          -6075.545,
          -6078.493,
          -6080.871999999999,
          -6082.675,
          -6083.89,
          -6084.509,
          -6084.521,
          -6083.9169999999995,
          -6082.684,
          -6080.814,
          -6078.294,
          -6075.113,
          -6071.26,
          -6066.722,
          -6061.486999999999,
          -6055.5419999999995,
          -6048.875,
          -6041.472,
          -6033.319,
          -6024.401,
          -6014.705,
          -6004.215999999999,
          -5992.9169999999995,
          -5980.794,
          -5967.829000000001,
          -5954.005,
          -5939.306,
          -5923.713000000001,
          -5907.206999999999,
          -5889.77,
          -5871.382,
          -5852.023,
          -5831.670999999999,
          -5810.306,
          -5787.903,
          -5764.441,
          -5739.895,
          -5714.24,
          -5687.451,
          -5659.5019999999995,
          -5630.365,
          -5600.012,
          -5568.411999999999,
          -5535.536,
          -5501.353,
          -5465.828,
          -5428.929,
          -5390.62,
          -5350.865,
          -5309.626,
          -5266.863,
          -5222.535,
          -5176.601,
          -5129.017,
          -5079.735,
          -5028.709,
          -4975.89,
          -4921.226,
          -4864.665,
          -4806.149,
          -4745.623,
          -4683.026,
          -4618.298,
          -4551.372,
          -4482.182,
          -4410.66,
          -4336.734,
          -4260.3279999999995,
          -4181.367,
          -4099.773,
          -4015.4629999999997,
          -3928.3520000000003,
          -3838.357,
          -3745.388,
          -3649.3559999999998,
          -3550.172,
          -3447.741,
          -3341.975,
          -3232.782,
          -3120.071,
          -3003.758,
          -2883.759,
          -2759.9990000000003,
          -2632.408,
          -2500.93,
          -2365.518,
          -2226.146,
          -2082.804,
          -1935.5079999999998,
          -1784.3039999999999,
          -1629.269,
          -1470.52,
          -1308.2169999999999,
          -1142.5710000000001,
          -973.842,
          -802.3480000000001,
          -628.465,
          -452.63,
          -275.33,
          -97.10600000000001,
          81.459,
          259.746,
          437.121,
          612.943,
          786.578,
          957.419,
          1124.899,
          1288.499,
          1447.764,
          1602.3020000000001,
          1751.796,
          1895.9920000000002,
          2034.71,
          2167.8289999999997,
          2295.286,
          2417.07,
          2533.212,
          2643.78,
          2748.875,
          2848.616,
          2943.145,
          3032.618,
          3117.195,
          3197.048,
          3272.349,
          3343.272,
          3409.988,
          3472.667,
          3531.474,
          3586.571,
          3638.113,
          3686.2529999999997,
          3731.132,
          3772.8909999999996,
          3811.663,
          3847.574,
          3880.744,
          3911.2909999999997,
          3939.322,
          3964.9429999999998,
          3988.2540000000004,
          4009.349,
          4028.317,
          4045.2459999999996,
          4060.215,
          4073.303,
          4084.583,
          4094.1240000000003,
          4101.995,
          4108.2570000000005,
          4112.973,
          4116.1990000000005,
          4117.9890000000005,
          4118.396,
          4117.471,
          4115.26,
          4111.81,
          4107.164000000001,
          4101.362,
          4094.4440000000004,
          4086.449,
          4077.413,
          4067.37,
          4056.353,
          4044.395,
          4031.527,
          4017.776,
          4003.171,
          3987.739,
          3971.507,
          3954.498,
          3936.737,
          3918.2470000000003,
          3899.0490000000004,
          3879.1659999999997,
          3858.617,
          3837.423,
          3815.6020000000003,
          3793.172,
          3770.152,
          3746.558,
          3722.406,
          3697.7129999999997,
          3672.494,
          3646.764,
          3620.5370000000003,
          3593.8259999999996,
          3566.6459999999997,
          3539.009,
          3510.928,
          3482.415,
          3453.4809999999998,
          3424.139,
          3394.3979999999997,
          3364.2709999999997,
          3333.7670000000003,
          3302.8959999999997,
          3271.6679999999997,
          3240.092,
          3208.178,
          3175.935,
          3143.3709999999996,
          3110.495,
          3077.316,
          3043.84,
          3010.0759999999996,
          2976.032,
          2941.7140000000004,
          2907.13,
          2872.2870000000003,
          2837.192,
          2801.8520000000003,
          2766.272,
          2730.46,
          2694.42,
          2658.1609999999996,
          2621.6859999999997,
          2585.002,
          2548.114,
          2511.029,
          2473.75,
          2436.284,
          2398.636,
          2360.81,
          2322.811,
          2284.644,
          2246.314,
          2207.825,
          2169.1820000000002,
          2130.389,
          2091.45,
          2052.369,
          2013.151,
          1973.799,
          1934.318,
          1894.711,
          1854.9820000000002,
          1815.135,
          1775.1729999999998,
          1735.099,
          1694.9189999999999,
          1654.634,
          1614.2479999999998,
          1573.764,
          1533.1860000000001,
          1492.5179999999998,
          1451.761,
          1410.9189999999999,
          1369.995,
          1328.993,
          1287.914,
          1246.762,
          1205.54,
          1164.25,
          1122.896,
          1081.479,
          1040.003,
          998.47,
          956.883,
          915.2439999999999,
          873.556,
          831.821,
          790.0419999999999,
          748.221,
          706.36,
          664.462,
          622.529,
          580.564,
          538.568,
          496.543,
          454.49300000000005,
          412.41900000000004,
          370.32300000000004,
          328.207,
          286.074,
          243.925,
          201.763,
          159.59,
          117.40700000000001,
          75.21600000000001,
          33.02,
          -9.18,
          -51.382,
          -93.583,
          -135.782,
          -177.977,
          -220.167,
          -262.349,
          -304.522,
          -346.68300000000005,
          -388.832,
          -430.965,
          -473.083,
          -515.182,
          -557.261,
          -599.319,
          -641.3530000000001,
          -683.363,
          -725.345,
          -767.3,
          -809.2239999999999,
          -851.1160000000001,
          -892.9760000000001,
          -934.8,
          -976.5880000000001,
          -1018.3380000000001,
          -1060.049,
          -1101.7169999999999,
          -1143.343,
          -1184.925,
          -1226.46,
          -1267.948,
          -1309.387,
          -1350.775,
          -1392.111,
          -1433.3929999999998,
          -1474.62,
          -1515.79,
          -1556.901,
          -1597.953,
          -1638.943,
          -1679.87,
          -1720.733,
          -1761.529,
          -1802.259,
          -1842.9189999999999,
          -1883.509,
          -1924.026,
          -1964.471,
          -2004.84,
          -2045.132,
          -2085.347,
          -2125.482,
          -2165.536,
          -2205.508,
          -2245.396,
          -2285.198,
          -2324.9120000000003,
          -2364.5389999999998,
          -2404.075,
          -2443.52,
          -2482.8720000000003,
          -2522.129,
          -2561.29,
          -2600.353,
          -2639.317,
          -2678.18,
          -2716.941,
          -2755.598,
          -2794.15,
          -2832.595,
          -2870.9309999999996,
          -2909.158,
          -2947.272,
          -2985.2740000000003,
          -3023.16,
          -3060.9309999999996,
          -3098.583,
          -3136.116,
          -3173.527,
          -3210.816,
          -3247.98,
          -3285.018,
          -3321.928,
          -3358.7090000000003,
          -3395.3590000000004,
          -3431.877,
          -3468.259,
          -3504.506,
          -3540.615,
          -3576.5840000000003,
          -3612.4120000000003,
          -3648.097,
          -3683.637,
          -3719.031,
          -3754.276,
          -3789.3709999999996,
          -3824.3140000000003,
          -3859.103,
          -3893.737,
          -3928.2129999999997,
          -3962.53,
          -3996.685,
          -4030.678,
          -4064.505,
          -4098.165,
          -4131.657,
          -4164.977,
          -4198.125,
          -4231.097,
          -4263.893,
          -4296.509,
          -4328.945,
          -4361.197,
          -4393.264,
          -4425.144,
          -4456.833,
          -4488.332,
          -4519.6359999999995,
          -4550.744000000001,
          -4581.654,
          -4612.363,
          -4642.869000000001,
          -4673.168,
          -4703.262,
          -4733.144,
          -4762.814,
          -4792.269,
          -4821.5070000000005,
          -4850.525,
          -4879.32,
          -4907.89,
          -4936.232,
          -4964.344,
          -4992.223,
          -5019.866,
          -5047.271,
          -5074.435,
          -5101.355,
          -5128.028,
          -5154.451,
          -5180.621,
          -5206.536,
          -5232.192,
          -5257.585999999999,
          -5282.715999999999,
          -5307.576999999999,
          -5332.1669999999995,
          -5356.483,
          -5380.521,
          -5404.278,
          -5427.75,
          -5450.935,
          -5473.828,
          -5496.4259999999995,
          -5518.725,
          -5540.722,
          -5562.4130000000005,
          -5583.794,
          -5604.861,
          -5625.611,
          -5646.039000000001,
          -5666.141,
          -5685.914000000001,
          -5705.352,
          -5724.451999999999,
          -5743.209,
          -5761.619000000001,
          -5779.678000000001,
          -5797.38,
          -5814.721,
          -5831.696999999999,
          -5848.302,
          -5864.531,
          -5880.38,
          -5895.844,
          -5910.916,
          -5925.592,
          -5939.866999999999,
          -5953.734,
          -5967.188,
          -5980.224,
          -5992.835,
          -6005.015,
          -6016.759,
          -6028.06,
          -6038.911999999999,
          -6049.307,
          -6059.24,
          -6068.703,
          -6077.69,
          -6086.193,
          -6094.205,
          -6101.719,
          -6108.727,
          -6115.221,
          -6121.194,
          -6126.637,
          -6131.541,
          -6135.899,
          -6139.701999999999,
          -6142.939,
          -6145.603,
          -6147.684,
          -6149.172,
          -6150.057,
          -6150.329000000001,
          -6149.979,
          -6148.994000000001,
          -6147.3640000000005,
          -6145.079000000001,
          -6142.126,
          -6138.493,
          -6134.17,
          -6129.141,
          -6123.396,
          -6116.920999999999,
          -6109.701,
          -6101.724,
          -6092.975,
          -6083.44,
          -6073.102,
          -6061.946999999999,
          -6049.9580000000005,
          -6037.119000000001,
          -6023.411,
          -6008.819,
          -5993.3240000000005,
          -5976.906,
          -5959.547,
          -5941.227,
          -5921.9259999999995,
          -5901.62,
          -5880.289000000001,
          -5857.911,
          -5834.460999999999,
          -5809.916,
          -5784.25,
          -5757.438,
          -5729.453,
          -5700.266,
          -5669.849,
          -5638.172,
          -5605.205,
          -5570.916,
          -5535.271,
          -5498.235,
          -5459.774,
          -5419.85,
          -5378.4259999999995,
          -5335.460999999999,
          -5290.9130000000005,
          -5244.74,
          -5196.897,
          -5147.339,
          -5096.016,
          -5042.879,
          -4987.876,
          -4930.9529999999995,
          -4872.054,
          -4811.12,
          -4748.090999999999,
          -4682.905,
          -4615.496,
          -4545.795999999999,
          -4473.736,
          -4399.242,
          -4322.2390000000005,
          -4242.651,
          -4160.396,
          -4075.3909999999996,
          -3987.553,
          -3896.7929999999997,
          -3803.022,
          -3706.15,
          -3606.083,
          -3502.7309999999998,
          -3395.9970000000003,
          -3285.792,
          -3172.022,
          -3054.6009999999997,
          -2933.442,
          -2808.47,
          -2679.612,
          -2546.8089999999997,
          -2410.014,
          -2269.196,
          -2124.345,
          -1975.475,
          -1822.6270000000002,
          -1665.88,
          -1505.3470000000002,
          -1341.1879999999999,
          -1173.61,
          -1002.8760000000001,
          -829.303,
          -653.268,
          -475.207,
          -295.613,
          -115.03,
          65.954,
          246.715,
          426.611,
          604.992,
          781.2139999999999,
          954.663,
          1124.758,
          1290.973,
          1452.838,
          1609.957,
          1761.997,
          1908.701,
          2049.879,
          2185.404,
          2315.208,
          2439.276,
          2557.636,
          2670.3540000000003,
          2777.527,
          2879.276,
          2975.743,
          3067.08,
          3153.455,
          3235.0359999999996,
          3311.9959999999996,
          3384.513,
          3452.758,
          3516.905,
          3577.119,
          3633.565,
          3686.3990000000003,
          3735.776,
          3781.84,
          3824.7340000000004,
          3864.59,
          3901.538,
          3935.7009999999996,
          3967.196,
          3996.133,
          4022.62,
          4046.757,
          4068.64,
          4088.361,
          4106.0070000000005,
          4121.66,
          4135.398,
          4147.2970000000005,
          4157.428,
          4165.858,
          4172.652,
          4177.871,
          4181.5740000000005,
          4183.816,
          4184.651,
          4184.129,
          4182.298,
          4179.205,
          4174.895,
          4169.407999999999,
          4162.785,
          4155.064,
          4146.282999999999,
          4136.477,
          4125.68,
          4113.923,
          4101.238,
          4087.655,
          4073.2009999999996,
          4057.905,
          4041.7929999999997,
          4024.89,
          4007.2209999999995,
          3988.808,
          3969.675,
          3949.842,
          3929.3309999999997,
          3908.1609999999996,
          3886.3520000000003,
          3863.923,
          3840.8909999999996,
          3817.2740000000003,
          3793.0879999999997,
          3768.3509999999997,
          3743.0759999999996,
          3717.28,
          3690.9770000000003,
          3664.1820000000002,
          3636.907,
          3609.165,
          3580.97,
          3552.333,
          3523.268,
          3493.785,
          3463.895,
          3433.61,
          3402.941,
          3371.8959999999997,
          3340.487,
          3308.723,
          3276.613,
          3244.167,
          3211.393,
          3178.3,
          3144.8959999999997,
          3111.1890000000003,
          3077.1890000000003,
          3042.901,
          3008.333,
          2973.493,
          2938.388,
          2903.025,
          2867.4109999999996,
          2831.551,
          2795.454,
          2759.1240000000003,
          2722.5679999999998,
          2685.7909999999997,
          2648.801,
          2611.6020000000003,
          2574.2,
          2536.6,
          2498.8070000000002,
          2460.828,
          2422.666,
          2384.327,
          2345.815,
          2307.136,
          2268.294,
          2229.2929999999997,
          2190.137,
          2150.8320000000003,
          2111.382,
          2071.79,
          2032.06,
          1992.1979999999999,
          1952.205,
          1912.0870000000002,
          1871.848,
          1831.49,
          1791.017,
          1750.433,
          1709.7420000000002,
          1668.9470000000001,
          1628.0510000000002,
          1587.057,
          1545.969,
          1504.79,
          1463.523,
          1422.171,
          1380.7379999999998,
          1339.225,
          1297.636,
          1255.975,
          1214.243,
          1172.444,
          1130.58,
          1088.653,
          1046.6680000000001,
          1004.6260000000001,
          962.53,
          920.382,
          878.184,
          835.941,
          793.653,
          751.323,
          708.954,
          666.547,
          624.106,
          581.632,
          539.128,
          496.596,
          454.038,
          411.457,
          368.85400000000004,
          326.231,
          283.591,
          240.93599999999998,
          198.268,
          155.588,
          112.899,
          70.203,
          27.502,
          -15.202,
          -57.908,
          -100.61399999999999,
          -143.317,
          -186.015,
          -228.708,
          -271.393,
          -314.068,
          -356.731,
          -399.381,
          -442.01599999999996,
          -484.63300000000004,
          -527.2330000000001,
          -569.811,
          -612.368,
          -654.901,
          -697.408,
          -739.888,
          -782.3389999999999,
          -824.76,
          -867.148,
          -909.503,
          -951.821,
          -994.1030000000001,
          -1036.346,
          -1078.549,
          -1120.7089999999998,
          -1162.826,
          -1204.8980000000001,
          -1246.923,
          -1288.899,
          -1330.826,
          -1372.701,
          -1414.523,
          -1456.2910000000002,
          -1498.0020000000002,
          -1539.655,
          -1581.249,
          -1622.783,
          -1664.254,
          -1705.661,
          -1747.0020000000002,
          -1788.277,
          -1829.483,
          -1870.619,
          -1911.684,
          -1952.675,
          -1993.592,
          -2034.432,
          -2075.195,
          -2115.879,
          -2156.482,
          -2197.0029999999997,
          -2237.44,
          -2277.792,
          -2318.056,
          -2358.2329999999997,
          -2398.32,
          -2438.315,
          -2478.217,
          -2518.025,
          -2557.736,
          -2597.351,
          -2636.865,
          -2676.28,
          -2715.592,
          -2754.8,
          -2793.902,
          -2832.8979999999997,
          -2871.785,
          -2910.562,
          -2949.2270000000003,
          -2987.7790000000005,
          -3026.216,
          -3064.5370000000003,
          -3102.739,
          -3140.821,
          -3178.782,
          -3216.62,
          -3254.333,
          -3291.92,
          -3329.3790000000004,
          -3366.708,
          -3403.905,
          -3440.97,
          -3477.8990000000003,
          -3514.692,
          -3551.347,
          -3587.861,
          -3624.2340000000004,
          -3660.4640000000004,
          -3696.547,
          -3732.4840000000004,
          -3768.272,
          -3803.909,
          -3839.3940000000002,
          -3874.724,
          -3909.897,
          -3944.913,
          -3979.768,
          -4014.462,
          -4048.992,
          -4083.355,
          -4117.5509999999995,
          -4151.5779999999995,
          -4185.432,
          -4219.112,
          -4252.617,
          -4285.944,
          -4319.09,
          -4352.055,
          -4384.835,
          -4417.429,
          -4449.835,
          -4482.049,
          -4514.071,
          -4545.898,
          -4577.528,
          -4608.957,
          -4640.185,
          -4671.209,
          -4702.025,
          -4732.633,
          -4763.029,
          -4793.212,
          -4823.178,
          -4852.925,
          -4882.451,
          -4911.753,
          -4940.8279999999995,
          -4969.674,
          -4998.288,
          -5026.667,
          -5054.81,
          -5082.712,
          -5110.371,
          -5137.785,
          -5164.95,
          -5191.863,
          -5218.522,
          -5244.924,
          -5271.064,
          -5296.941,
          -5322.5509999999995,
          -5347.892,
          -5372.9580000000005,
          -5397.749,
          -5422.259,
          -5446.486,
          -5470.427,
          -5494.076999999999,
          -5517.434,
          -5540.493,
          -5563.251,
          -5585.705,
          -5607.849,
          -5629.682,
          -5651.198,
          -5672.395,
          -5693.266,
          -5713.81,
          -5734.021,
          -5753.895,
          -5773.428000000001,
          -5792.615,
          -5811.453,
          -5829.936,
          -5848.06,
          -5865.819,
          -5883.21,
          -5900.227,
          -5916.866,
          -5933.12,
          -5948.986,
          -5964.456999999999,
          -5979.528,
          -5994.195,
          -6008.45,
          -6022.289000000001,
          -6035.706,
          -6048.694,
          -6061.2480000000005,
          -6073.361,
          -6085.026999999999,
          -6096.24,
          -6106.993,
          -6117.279,
          -6127.090999999999,
          -6136.422,
          -6145.265,
          -6153.613,
          -6161.456999999999,
          -6168.7919999999995,
          -6175.607,
          -6181.896,
          -6187.651,
          -6192.861999999999,
          -6197.521,
          -6201.62,
          -6205.148,
          -6208.098000000001,
          -6210.4580000000005,
          -6212.22,
          -6213.374,
          -6213.909000000001,
          -6213.815,
          -6213.08,
          -6211.695,
          -6209.647,
          -6206.925,
          -6203.517,
          -6199.411,
          -6194.594,
          -6189.053000000001,
          -6182.774,
          -6175.744000000001,
          -6167.948,
          -6159.3730000000005,
          -6150.004,
          -6139.8240000000005,
          -6128.819,
          -6116.972,
          -6104.265,
          -6090.682,
          -6076.205,
          -6060.815,
          -6044.494000000001,
          -6027.222,
          -6008.979,
          -5989.744000000001,
          -5969.495,
          -5948.21,
          -5925.866999999999,
          -5902.441,
          -5877.908,
          -5852.241999999999,
          -5825.419,
          -5797.41,
          -5768.187,
          -5737.72,
          -5705.981,
          -5672.937,
          -5638.558000000001,
          -5602.808000000001,
          -5565.651999999999,
          -5527.056,
          -5486.981,
          -5445.389,
          -5402.24,
          -5357.491,
          -5311.099,
          -5263.02,
          -5213.206,
          -5161.607,
          -5108.175,
          -5052.855,
          -4995.596,
          -4936.337,
          -4875.02,
          -4811.585999999999,
          -4745.97,
          -4678.105,
          -4607.923,
          -4535.355,
          -4460.3240000000005,
          -4382.755999999999,
          -4302.573,
          -4219.69,
          -4134.027,
          -4045.4959999999996,
          -3954.008,
          -3859.474,
          -3761.8,
          -3660.893,
          -3556.659,
          -3449.002,
          -3337.829,
          -3223.046,
          -3104.5640000000003,
          -2982.295,
          -2856.16,
          -2726.087,
          -2592.013,
          -2453.888,
          -2311.6820000000002,
          -2165.379,
          -2014.993,
          -1860.5639999999999,
          -1702.1660000000002,
          -1539.912,
          -1373.961,
          -1204.518,
          -1031.846,
          -856.2610000000001,
          -678.14,
          -497.923,
          -316.10200000000003,
          -133.227,
          50.11,
          233.27900000000002,
          415.63199999999995,
          596.508,
          775.2589999999999,
          951.2560000000001,
          1123.912,
          1292.6860000000001,
          1457.1029999999998,
          1616.751,
          1771.293,
          1920.463,
          2064.06,
          2201.9539999999997,
          2334.071,
          2460.39,
          2580.937,
          2695.776,
          2805.0009999999997,
          2908.735,
          3007.115,
          3100.2990000000004,
          3188.4509999999996,
          3271.741,
          3350.3459999999995,
          3424.442,
          3494.204,
          3559.8059999999996,
          3621.4159999999997,
          3679.2009999999996,
          3733.3190000000004,
          3783.925,
          3831.167,
          3875.1890000000003,
          3916.125,
          3954.1059999999998,
          3989.2,
          4021.698,
          4051.539,
          4078.89,
          4103.853,
          4126.524,
          4146.997,
          4165.361,
          4181.698,
          4196.089,
          4208.61,
          4219.333,
          4228.325,
          4235.654,
          4241.380999999999,
          4245.567,
          4248.265,
          4249.532,
          4249.419,
          4247.974,
          4245.245,
          4241.277,
          4236.112,
          4229.79,
          4222.352,
          4213.834,
          4204.272,
          4193.702,
          4182.155,
          4169.663,
          4156.255999999999,
          4141.963,
          4126.812,
          4110.83,
          4094.0429999999997,
          4076.474,
          4058.1490000000003,
          4039.09,
          4019.3179999999998,
          3998.8540000000003,
          3977.72,
          3955.935,
          3933.5170000000003,
          3910.485,
          3886.857,
          3862.6490000000003,
          3837.8779999999997,
          3812.56,
          3786.711,
          3760.344,
          3733.475,
          3706.116,
          3678.282,
          3649.985,
          3621.238,
          3592.054,
          3562.4429999999998,
          3532.4179999999997,
          3501.988,
          3471.1659999999997,
          3439.962,
          3408.385,
          3376.446,
          3344.1540000000005,
          3311.518,
          3278.547,
          3245.25,
          3211.636,
          3177.7129999999997,
          3143.489,
          3108.9709999999995,
          3074.167,
          3039.085,
          3003.732,
          2968.115,
          2932.241,
          2896.116,
          2859.748,
          2823.1409999999996,
          2786.304,
          2749.24,
          2711.958,
          2674.462,
          2636.757,
          2598.851,
          2560.7470000000003,
          2522.451,
          2483.968,
          2445.303,
          2406.462,
          2367.448,
          2328.268,
          2288.924,
          2249.422,
          2209.766,
          2169.9610000000002,
          2130.01,
          2089.9179999999997,
          2049.689,
          2009.3270000000002,
          1968.835,
          1928.2179999999998,
          1887.479,
          1846.622,
          1805.651,
          1764.568,
          1723.379,
          1682.085,
          1640.691,
          1599.1989999999998,
          1557.6129999999998,
          1515.9370000000001,
          1474.172,
          1432.3229999999999,
          1390.391,
          1348.382,
          1306.296,
          1264.137,
          1221.9080000000001,
          1179.612,
          1137.252,
          1094.829,
          1052.347,
          1009.809,
          967.216,
          924.572,
          881.8789999999999,
          839.14,
          796.3560000000001,
          753.5310000000001,
          710.666,
          667.765,
          624.8290000000001,
          581.861,
          538.862,
          495.836,
          452.784,
          409.709,
          366.61199999999997,
          323.496,
          280.363,
          237.21599999999998,
          194.055,
          150.88299999999998,
          107.70200000000001,
          64.515,
          21.322,
          -21.873,
          -65.069,
          -108.265,
          -151.458,
          -194.646,
          -237.827,
          -281,
          -324.163,
          -367.314,
          -410.45099999999996,
          -453.57300000000004,
          -496.67699999999996,
          -539.762,
          -582.826,
          -625.867,
          -668.8839999999999,
          -711.875,
          -754.8380000000001,
          -797.7710000000001,
          -840.674,
          -883.543,
          -926.378,
          -969.177,
          -1011.938,
          -1054.66,
          -1097.34,
          -1139.978,
          -1182.5710000000001,
          -1225.118,
          -1267.618,
          -1310.069,
          -1352.469,
          -1394.816,
          -1437.11,
          -1479.348,
          -1521.529,
          -1563.652,
          -1605.714,
          -1647.715,
          -1689.652,
          -1731.524,
          -1773.33,
          -1815.067,
          -1856.736,
          -1898.3329999999999,
          -1939.8570000000002,
          -1981.308,
          -2022.682,
          -2063.98,
          -2105.198,
          -2146.3360000000002,
          -2187.3920000000003,
          -2228.365,
          -2269.2529999999997,
          -2310.054,
          -2350.7670000000003,
          -2391.391,
          -2431.923,
          -2472.362,
          -2512.7070000000003,
          -2552.956,
          -2593.1079999999997,
          -2633.16,
          -2673.112,
          -2712.962,
          -2752.708,
          -2792.348,
          -2831.882,
          -2871.3070000000002,
          -2910.6209999999996,
          -2949.824,
          -2988.914,
          -3027.888,
          -3066.7459999999996,
          -3105.485,
          -3144.105,
          -3182.603,
          -3220.9770000000003,
          -3259.2270000000003,
          -3297.35,
          -3335.344,
          -3373.2090000000003,
          -3410.942,
          -3448.5409999999997,
          -3486.005,
          -3523.3320000000003,
          -3560.5209999999997,
          -3597.5690000000004,
          -3634.475,
          -3671.236,
          -3707.8520000000003,
          -3744.321,
          -3780.639,
          -3816.8070000000002,
          -3852.821,
          -3888.6809999999996,
          -3924.383,
          -3959.927,
          -3995.309,
          -4030.5290000000005,
          -4065.585,
          -4100.474,
          -4135.194,
          -4169.744000000001,
          -4204.121,
          -4238.3240000000005,
          -4272.35,
          -4306.197,
          -4339.863,
          -4373.346,
          -4406.644,
          -4439.755,
          -4472.6759999999995,
          -4505.405,
          -4537.941,
          -4570.28,
          -4602.420999999999,
          -4634.361,
          -4666.098,
          -4697.63,
          -4728.9529999999995,
          -4760.067,
          -4790.967000000001,
          -4821.653,
          -4852.121,
          -4882.3679999999995,
          -4912.393,
          -4942.192,
          -4971.764,
          -5001.105,
          -5030.212,
          -5059.083,
          -5087.715999999999,
          -5116.107,
          -5144.253,
          -5172.152,
          -5199.8009999999995,
          -5227.196,
          -5254.335999999999,
          -5281.215999999999,
          -5307.8330000000005,
          -5334.185,
          -5360.269,
          -5386.08,
          -5411.616,
          -5436.874,
          -5461.85,
          -5486.54,
          -5510.941999999999,
          -5535.0509999999995,
          -5558.865,
          -5582.379,
          -5605.589,
          -5628.493,
          -5651.085999999999,
          -5673.3640000000005,
          -5695.3240000000005,
          -5716.96,
          -5738.271,
          -5759.25,
          -5779.894,
          -5800.198,
          -5820.159000000001,
          -5839.772,
          -5859.031,
          -5877.934,
          -5896.475,
          -5914.648,
          -5932.45,
          -5949.875,
          -5966.918000000001,
          -5983.5740000000005,
          -5999.838000000001,
          -6015.704000000001,
          -6031.168000000001,
          -6046.222,
          -6060.863,
          -6075.084,
          -6088.878000000001,
          -6102.241,
          -6115.166,
          -6127.646,
          -6139.675,
          -6151.2480000000005,
          -6162.356,
          -6172.993,
          -6183.153,
          -6192.826999999999,
          -6202.009,
          -6210.691999999999,
          -6218.866999999999,
          -6226.526999999999,
          -6233.664000000001,
          -6240.269,
          -6246.335,
          -6251.853,
          -6256.814,
          -6261.21,
          -6265.031,
          -6268.266,
          -6270.908,
          -6272.946,
          -6274.37,
          -6275.17,
          -6275.335,
          -6274.853,
          -6273.715,
          -6271.908,
          -6269.420999999999,
          -6266.241,
          -6262.357,
          -6257.755,
          -6252.422,
          -6246.344,
          -6239.508000000001,
          -6231.9,
          -6223.505,
          -6214.307,
          -6204.2919999999995,
          -6193.443,
          -6181.744000000001,
          -6169.178000000001,
          -6155.726,
          -6141.371999999999,
          -6126.097,
          -6109.880999999999,
          -6092.704000000001,
          -6074.548000000001,
          -6055.389,
          -6035.206999999999,
          -6013.979,
          -5991.681,
          -5968.29,
          -5943.781999999999,
          -5918.129,
          -5891.308000000001,
          -5863.2880000000005,
          -5834.0419999999995,
          -5803.54,
          -5771.753000000001,
          -5738.648,
          -5704.193,
          -5668.354,
          -5631.095,
          -5592.380999999999,
          -5552.173000000001,
          -5510.433000000001,
          -5467.119000000001,
          -5422.188,
          -5375.598000000001,
          -5327.302,
          -5277.254,
          -5225.402,
          -5171.697,
          -5116.085,
          -5058.513,
          -4998.919,
          -4937.247,
          -4873.433,
          -4807.415,
          -4739.123,
          -4668.49,
          -4595.443,
          -4519.907,
          -4441.806,
          -4361.061,
          -4277.585999999999,
          -4191.299,
          -4102.112,
          -4009.934,
          -3914.676,
          -3816.24,
          -3714.534,
          -3609.462,
          -3500.926,
          -3388.8309999999997,
          -3273.0809999999997,
          -3153.587,
          -3030.257,
          -2903.013,
          -2771.776,
          -2636.486,
          -2497.089,
          -2353.55,
          -2205.856,
          -2054.015,
          -1898.066,
          -1738.0810000000001,
          -1574.1729999999998,
          -1406.495,
          -1235.255,
          -1060.712,
          -883.183,
          -703.048,
          -520.743,
          -336.76599999999996,
          -151.668,
          33.953,
          219.463,
          404.205,
          587.512,
          768.727,
          947.212,
          1122.367,
          1293.646,
          1460.559,
          1622.6870000000001,
          1779.684,
          1931.2720000000002,
          2077.245,
          2217.467,
          2351.859,
          2480.394,
          2603.095,
          2720.0240000000003,
          2831.2740000000003,
          2936.965,
          3037.235,
          3132.241,
          3222.1490000000003,
          3307.1290000000004,
          3387.361,
          3463.0190000000002,
          3534.283,
          3601.327,
          3664.321,
          3723.4320000000002,
          3778.823,
          3830.65,
          3879.062,
          3924.203,
          3966.2129999999997,
          4005.222,
          4041.357,
          4074.738,
          4105.481,
          4133.693,
          4159.479,
          4182.938,
          4204.163,
          4223.245,
          4240.268,
          4255.312,
          4268.456,
          4279.772,
          4289.331,
          4297.198,
          4303.436,
          4308.107,
          4311.267,
          4312.972,
          4313.272,
          4312.219,
          4309.86,
          4306.24,
          4301.403,
          4295.39,
          4288.241,
          4279.9929999999995,
          4270.685,
          4260.349,
          4249.02,
          4236.729,
          4223.5070000000005,
          4209.384,
          4194.388,
          4178.545999999999,
          4161.884,
          4144.427,
          4126.1990000000005,
          4107.223,
          4087.522,
          4067.118,
          4046.03,
          4024.2790000000005,
          4001.884,
          3978.864,
          3955.236,
          3931.018,
          3906.2259999999997,
          3880.8759999999997,
          3854.985,
          3828.566,
          3801.635,
          3774.2059999999997,
          3746.292,
          3717.907,
          3689.062,
          3659.7709999999997,
          3630.046,
          3599.8979999999997,
          3569.3379999999997,
          3538.3779999999997,
          3507.027,
          3475.296,
          3443.195,
          3410.7340000000004,
          3377.923,
          3344.7690000000002,
          3311.283,
          3277.472,
          3243.3459999999995,
          3208.9120000000003,
          3174.179,
          3139.1540000000005,
          3103.844,
          3068.258,
          3032.401,
          2996.282,
          2959.907,
          2923.282,
          2886.415,
          2849.31,
          2811.975,
          2774.415,
          2736.637,
          2698.6459999999997,
          2660.447,
          2622.047,
          2583.45,
          2544.661,
          2505.687,
          2466.531,
          2427.198,
          2387.695,
          2348.024,
          2308.19,
          2268.199,
          2228.054,
          2187.76,
          2147.321,
          2106.742,
          2066.025,
          2025.175,
          1984.1960000000001,
          1943.0929999999998,
          1901.8670000000002,
          1860.524,
          1819.066,
          1777.4979999999998,
          1735.8229999999999,
          1694.0439999999999,
          1652.164,
          1610.1870000000001,
          1568.1170000000002,
          1525.955,
          1483.7060000000001,
          1441.372,
          1398.957,
          1356.463,
          1313.8929999999998,
          1271.251,
          1228.539,
          1185.759,
          1142.915,
          1100.009,
          1057.045,
          1014.023,
          970.948,
          927.822,
          884.6469999999999,
          841.426,
          798.1610000000001,
          754.8539999999999,
          711.508,
          668.1260000000001,
          624.7090000000001,
          581.26,
          537.7819999999999,
          494.275,
          450.744,
          407.189,
          363.61300000000006,
          320.019,
          276.407,
          232.78099999999998,
          189.142,
          145.493,
          101.835,
          58.17100000000001,
          14.502,
          -29.17,
          -72.842,
          -116.51299999999999,
          -160.181,
          -203.84400000000002,
          -247.49900000000002,
          -291.14599999999996,
          -334.783,
          -378.406,
          -422.01599999999996,
          -465.60900000000004,
          -509.184,
          -552.74,
          -596.274,
          -639.785,
          -683.2719999999999,
          -726.7310000000001,
          -770.1619999999999,
          -813.563,
          -856.932,
          -900.268,
          -943.568,
          -986.832,
          -1030.057,
          -1073.242,
          -1116.385,
          -1159.484,
          -1202.539,
          -1245.547,
          -1288.506,
          -1331.4160000000002,
          -1374.274,
          -1417.078,
          -1459.828,
          -1502.5220000000002,
          -1545.158,
          -1587.734,
          -1630.249,
          -1672.701,
          -1715.089,
          -1757.412,
          -1799.6660000000002,
          -1841.852,
          -1883.967,
          -1926.01,
          -1967.979,
          -2009.8729999999998,
          -2051.69,
          -2093.429,
          -2135.0879999999997,
          -2176.665,
          -2218.159,
          -2259.569,
          -2300.8920000000003,
          -2342.127,
          -2383.2729999999997,
          -2424.328,
          -2465.29,
          -2506.158,
          -2546.931,
          -2587.606,
          -2628.1820000000002,
          -2668.658,
          -2709.031,
          -2749.301,
          -2789.466,
          -2829.5229999999997,
          -2869.472,
          -2909.3109999999997,
          -2949.038,
          -2988.652,
          -3028.15,
          -3067.532,
          -3106.795,
          -3145.9390000000003,
          -3184.96,
          -3223.8579999999997,
          -3262.631,
          -3301.277,
          -3339.7940000000003,
          -3378.1809999999996,
          -3416.437,
          -3454.558,
          -3492.5440000000003,
          -3530.393,
          -3568.1020000000003,
          -3605.671,
          -3643.097,
          -3680.3790000000004,
          -3717.515,
          -3754.502,
          -3791.34,
          -3828.026,
          -3864.558,
          -3900.934,
          -3937.153,
          -3973.2129999999997,
          -4009.111,
          -4044.8459999999995,
          -4080.4159999999997,
          -4115.818,
          -4151.052,
          -4186.113,
          -4221.002,
          -4255.715,
          -4290.251,
          -4324.607,
          -4358.781,
          -4392.772,
          -4426.576,
          -4460.193,
          -4493.619000000001,
          -4526.852,
          -4559.89,
          -4592.731,
          -4625.373,
          -4657.813,
          -4690.049,
          -4722.0779999999995,
          -4753.898,
          -4785.5070000000005,
          -4816.902,
          -4848.081,
          -4879.041,
          -4909.779,
          -4940.293,
          -4970.581,
          -5000.639,
          -5030.465999999999,
          -5060.057,
          -5089.411,
          -5118.525,
          -5147.395,
          -5176.02,
          -5204.395,
          -5232.519,
          -5260.388000000001,
          -5287.999,
          -5315.349,
          -5342.435,
          -5369.254,
          -5395.802,
          -5422.076999999999,
          -5448.0740000000005,
          -5473.7919999999995,
          -5499.225,
          -5524.371,
          -5549.227,
          -5573.7880000000005,
          -5598.0509999999995,
          -5622.013000000001,
          -5645.67,
          -5669.017,
          -5692.052,
          -5714.769,
          -5737.165,
          -5759.236,
          -5780.978,
          -5802.387,
          -5823.459,
          -5844.188,
          -5864.571,
          -5884.603,
          -5904.28,
          -5923.597,
          -5942.548000000001,
          -5961.130999999999,
          -5979.338000000001,
          -5997.166,
          -6014.61,
          -6031.6630000000005,
          -6048.321999999999,
          -6064.58,
          -6080.431,
          -6095.871,
          -6110.893,
          -6125.491999999999,
          -6139.661999999999,
          -6153.396,
          -6166.689,
          -6179.533,
          -6191.924,
          -6203.853,
          -6215.314,
          -6226.3009999999995,
          -6236.806,
          -6246.823,
          -6256.343000000001,
          -6265.358,
          -6273.863,
          -6281.848000000001,
          -6289.305,
          -6296.227,
          -6302.605,
          -6308.43,
          -6313.693,
          -6318.3859999999995,
          -6322.499,
          -6326.022,
          -6328.946999999999,
          -6331.263000000001,
          -6332.959,
          -6334.025,
          -6334.451,
          -6334.225,
          -6333.335999999999,
          -6331.773,
          -6329.524,
          -6326.576999999999,
          -6322.918000000001,
          -6318.535,
          -6313.414000000001,
          -6307.543000000001,
          -6300.906,
          -6293.49,
          -6285.28,
          -6276.2609999999995,
          -6266.416,
          -6255.731,
          -6244.186,
          -6231.767,
          -6218.455,
          -6204.232,
          -6189.078,
          -6172.977,
          -6155.906,
          -6137.844,
          -6118.772,
          -6098.666,
          -6077.505,
          -6055.264,
          -6031.920999999999,
          -6007.4490000000005,
          -5981.821,
          -5955.013000000001,
          -5926.996,
          -5897.741999999999,
          -5867.219,
          -5835.398,
          -5802.246999999999,
          -5767.733,
          -5731.821,
          -5694.477,
          -5655.661999999999,
          -5615.339,
          -5573.468000000001,
          -5530.009,
          -5484.9169999999995,
          -5438.148,
          -5389.658,
          -5339.397,
          -5287.315,
          -5233.361,
          -5177.482,
          -5119.62,
          -5059.719,
          -4997.717000000001,
          -4933.552,
          -4867.159000000001,
          -4798.47,
          -4727.415,
          -4653.920999999999,
          -4577.913,
          -4499.312,
          -4418.038,
          -4334.0070000000005,
          -4247.133,
          -4157.3279999999995,
          -4064.4990000000003,
          -3968.5559999999996,
          -3869.401,
          -3766.9390000000003,
          -3661.072,
          -3551.703,
          -3438.732,
          -3322.066,
          -3201.6079999999997,
          -3077.27,
          -2948.968,
          -2816.6240000000003,
          -2680.173,
          -2539.56,
          -2394.75,
          -2245.725,
          -2092.492,
          -1935.088,
          -1773.5829999999999,
          -1608.086,
          -1438.7520000000002,
          -1265.7839999999999,
          -1089.442,
          -910.0419999999999,
          -727.9639999999999,
          -543.645,
          -357.585,
          -170.33700000000002,
          17.495,
          205.274,
          392.335,
          578.005,
          761.617,
          942.5239999999999,
          1120.119,
          1293.84,
          1463.193,
          1627.747,
          1787.144,
          1941.102,
          2089.407,
          2231.915,
          2368.54,
          2499.254,
          2624.074,
          2743.06,
          2856.302,
          2963.922,
          3066.0559999999996,
          3162.861,
          3254.502,
          3341.152,
          3422.99,
          3500.1940000000004,
          3572.9429999999998,
          3641.413,
          3705.778,
          3766.204,
          3822.857,
          3875.893,
          3925.466,
          3971.72,
          4014.796,
          4054.827,
          4091.942,
          4126.26,
          4157.9,
          4186.971,
          4213.5779999999995,
          4237.823,
          4259.799,
          4279.598,
          4297.307,
          4313.0070000000005,
          4326.775,
          4338.687,
          4348.814,
          4357.222,
          4363.976,
          4369.1359999999995,
          4372.762,
          4374.907999999999,
          4375.628,
          4374.972,
          4372.9890000000005,
          4369.724,
          4365.222,
          4359.524,
          4352.6720000000005,
          4344.7029999999995,
          4335.654,
          4325.563,
          4314.46,
          4302.379,
          4289.352,
          4275.407,
          4260.575,
          4244.883,
          4228.356,
          4211.02,
          4192.901,
          4174.02,
          4154.401,
          4134.066,
          4113.036,
          4091.3309999999997,
          4068.97,
          4045.973,
          4022.3579999999997,
          3998.1409999999996,
          3973.34,
          3947.972,
          3922.051,
          3895.594,
          3868.615,
          3841.1279999999997,
          3813.147,
          3784.6859999999997,
          3755.758,
          3726.3740000000003,
          3696.548,
          3666.2909999999997,
          3635.614,
          3604.5290000000005,
          3573.045,
          3541.175,
          3508.927,
          3476.312,
          3443.3379999999997,
          3410.0170000000003,
          3376.355,
          3342.364,
          3308.0490000000004,
          3273.421,
          3238.487,
          3203.255,
          3167.7329999999997,
          3131.928,
          3095.848,
          3059.4990000000003,
          3022.888,
          2986.0229999999997,
          2948.909,
          2911.553,
          2873.962,
          2836.1409999999996,
          2798.0959999999995,
          2759.8340000000003,
          2721.3590000000004,
          2682.678,
          2643.796,
          2604.718,
          2565.449,
          2525.994,
          2486.359,
          2446.548,
          2406.5660000000003,
          2366.4179999999997,
          2326.107,
          2285.639,
          2245.018,
          2204.249,
          2163.334,
          2122.28,
          2081.0879999999997,
          2039.764,
          1998.3120000000001,
          1956.734,
          1915.035,
          1873.219,
          1831.289,
          1789.249,
          1747.101,
          1704.85,
          1662.499,
          1620.0510000000002,
          1577.509,
          1534.876,
          1492.156,
          1449.352,
          1406.467,
          1363.503,
          1320.464,
          1277.3519999999999,
          1234.17,
          1190.922,
          1147.609,
          1104.235,
          1060.802,
          1017.312,
          973.7689999999999,
          930.175,
          886.533,
          842.845,
          799.112,
          755.3389999999999,
          711.5269999999999,
          667.678,
          623.7959999999999,
          579.881,
          535.937,
          491.966,
          447.97,
          403.95099999999996,
          359.911,
          315.85200000000003,
          271.777,
          227.688,
          183.58700000000002,
          139.475,
          95.355,
          51.229,
          7.099,
          -37.034,
          -81.167,
          -125.29799999999999,
          -169.425,
          -213.547,
          -257.661,
          -301.76599999999996,
          -345.86,
          -389.941,
          -434.00800000000004,
          -478.05699999999996,
          -522.0880000000001,
          -566.099,
          -610.0880000000001,
          -654.053,
          -697.993,
          -741.905,
          -785.789,
          -829.6410000000001,
          -873.461,
          -917.247,
          -960.998,
          -1004.71,
          -1048.384,
          -1092.016,
          -1135.606,
          -1179.152,
          -1222.652,
          -1266.105,
          -1309.508,
          -1352.861,
          -1396.161,
          -1439.4070000000002,
          -1482.598,
          -1525.731,
          -1568.806,
          -1611.82,
          -1654.7720000000002,
          -1697.66,
          -1740.483,
          -1783.239,
          -1825.9270000000001,
          -1868.545,
          -1911.0910000000001,
          -1953.5639999999999,
          -1995.9620000000002,
          -2038.2839999999999,
          -2080.528,
          -2122.692,
          -2164.775,
          -2206.775,
          -2248.6910000000003,
          -2290.522,
          -2332.264,
          -2373.9179999999997,
          -2415.481,
          -2456.951,
          -2498.328,
          -2539.609,
          -2580.7929999999997,
          -2621.8779999999997,
          -2662.863,
          -2703.7459999999996,
          -2744.526,
          -2785.2,
          -2825.7670000000003,
          -2866.2259999999997,
          -2906.575,
          -2946.812,
          -2986.9359999999997,
          -3026.9440000000004,
          -3066.836,
          -3106.6090000000004,
          -3146.262,
          -3185.7929999999997,
          -3225.2009999999996,
          -3264.4829999999997,
          -3303.639,
          -3342.6659999999997,
          -3381.562,
          -3420.3259999999996,
          -3458.9559999999997,
          -3497.45,
          -3535.8070000000002,
          -3574.025,
          -3612.1009999999997,
          -3650.035,
          -3687.824,
          -3725.466,
          -3762.9590000000003,
          -3800.303,
          -3837.494,
          -3874.531,
          -3911.4120000000003,
          -3948.135,
          -3984.699,
          -4021.1,
          -4057.3379999999997,
          -4093.409,
          -4129.313,
          -4165.0470000000005,
          -4200.609,
          -4235.997,
          -4271.209,
          -4306.242,
          -4341.096,
          -4375.767,
          -4410.253,
          -4444.553,
          -4478.664000000001,
          -4512.583,
          -4546.309,
          -4579.839,
          -4613.170999999999,
          -4646.303,
          -4679.232,
          -4711.955,
          -4744.472,
          -4776.778,
          -4808.872,
          -4840.75,
          -4872.412,
          -4903.853,
          -4935.072,
          -4966.065,
          -4996.831,
          -5027.366,
          -5057.668,
          -5087.734,
          -5117.561,
          -5147.146,
          -5176.487,
          -5205.581,
          -5234.424,
          -5263.014,
          -5291.347,
          -5319.420999999999,
          -5347.233,
          -5374.779,
          -5402.056,
          -5429.061,
          -5455.791,
          -5482.241999999999,
          -5508.41,
          -5534.294,
          -5559.888000000001,
          -5585.189,
          -5610.195,
          -5634.9,
          -5659.303000000001,
          -5683.397,
          -5707.181,
          -5730.65,
          -5753.8,
          -5776.626,
          -5799.125,
          -5821.293000000001,
          -5843.125,
          -5864.618,
          -5885.766,
          -5906.566,
          -5927.012,
          -5947.1,
          -5966.826,
          -5986.184,
          -6005.17,
          -6023.779,
          -6042.005,
          -6059.844,
          -6077.291,
          -6094.339,
          -6110.984,
          -6127.22,
          -6143.041,
          -6158.441,
          -6173.415,
          -6187.956,
          -6202.059,
          -6215.717,
          -6228.923000000001,
          -6241.672,
          -6253.956,
          -6265.769,
          -6277.103,
          -6287.951999999999,
          -6298.309,
          -6308.165,
          -6317.513000000001,
          -6326.346,
          -6334.655,
          -6342.433000000001,
          -6349.670999999999,
          -6356.36,
          -6362.493,
          -6368.059,
          -6373.05,
          -6377.456,
          -6381.268,
          -6384.477,
          -6387.071999999999,
          -6389.0419999999995,
          -6390.3769999999995,
          -6391.066,
          -6391.099,
          -6390.463000000001,
          -6389.147,
          -6387.139,
          -6384.428000000001,
          -6380.999,
          -6376.839,
          -6371.936,
          -6366.275,
          -6359.844,
          -6352.626,
          -6344.607,
          -6335.772,
          -6326.105,
          -6315.589,
          -6304.2080000000005,
          -6291.943,
          -6278.778,
          -6264.695,
          -6249.673000000001,
          -6233.694,
          -6216.738,
          -6198.781999999999,
          -6179.807,
          -6159.789000000001,
          -6138.706,
          -6116.534000000001,
          -6093.25,
          -6068.826,
          -6043.238,
          -6016.456999999999,
          -5988.456999999999,
          -5959.2080000000005,
          -5928.681,
          -5896.842,
          -5863.661999999999,
          -5829.105,
          -5793.139,
          -5755.726,
          -5716.83,
          -5676.411,
          -5634.43,
          -5590.846,
          -5545.6140000000005,
          -5498.69,
          -5450.026999999999,
          -5399.576999999999,
          -5347.289000000001,
          -5293.111999999999,
          -5236.99,
          -5178.8679999999995,
          -5118.685,
          -5056.383,
          -4991.896,
          -4925.159000000001,
          -4856.104,
          -4784.66,
          -4710.752,
          -4634.306,
          -4555.241,
          -4473.476,
          -4388.9259999999995,
          -4301.504,
          -4211.121,
          -4117.684,
          -4021.099,
          -3921.2690000000002,
          -3818.097,
          -3711.4829999999997,
          -3601.329,
          -3487.534,
          -3370.0009999999997,
          -3248.635,
          -3123.343,
          -2994.0409999999997,
          -2860.647,
          -2723.0959999999995,
          -2581.3320000000003,
          -2435.313,
          -2285.0229999999997,
          -2130.466,
          -1971.675,
          -1808.72,
          -1641.7060000000001,
          -1470.789,
          -1296.167,
          -1118.1019999999999,
          -936.9069999999999,
          -752.962,
          -566.706,
          -378.64,
          -189.32,
          0.649,
          190.622,
          379.92900000000003,
          567.891,
          753.831,
          937.095,
          1117.063,
          1293.1689999999999,
          1464.9029999999998,
          1631.8270000000002,
          1793.575,
          1949.855,
          2100.445,
          2245.195,
          2384.014,
          2516.869,
          2643.7729999999997,
          2764.784,
          2879.991,
          2989.511,
          3093.4829999999997,
          3192.062,
          3285.414,
          3373.7140000000004,
          3457.1409999999996,
          3535.8720000000003,
          3610.091,
          3679.974,
          3745.695,
          3807.426,
          3865.3309999999997,
          3919.5679999999998,
          3970.2929999999997,
          4017.652,
          4061.789,
          4102.835999999999,
          4140.914000000001,
          4176.1759999999995,
          4208.709,
          4238.637,
          4266.065,
          4291.094,
          4313.822,
          4334.339,
          4352.734,
          4369.090999999999,
          4383.486,
          4395.997,
          4406.695,
          4415.648,
          4422.920999999999,
          4428.575,
          4432.6720000000005,
          4435.266,
          4436.411,
          4436.157999999999,
          4434.557,
          4431.655,
          4427.495,
          4422.12,
          4415.572,
          4407.89,
          4399.11,
          4389.271,
          4378.404,
          4366.543,
          4353.719,
          4339.964,
          4325.306,
          4309.773,
          4293.392,
          4276.189,
          4258.188,
          4239.414000000001,
          4219.889,
          4199.635,
          4178.675,
          4157.028,
          4134.714,
          4111.752,
          4088.1620000000003,
          4063.9590000000003,
          4039.1620000000003,
          4013.788,
          3987.8509999999997,
          3961.369,
          3934.355,
          3906.824,
          3878.79,
          3850.268,
          3821.2690000000002,
          3791.8070000000002,
          3761.8940000000002,
          3731.542,
          3700.763,
          3669.567,
          3637.966,
          3605.97,
          3573.59,
          3540.835,
          3507.716,
          3474.241,
          3440.42,
          3406.262,
          3371.775,
          3336.968,
          3301.849,
          3266.426,
          3230.7070000000003,
          3194.7,
          3158.4109999999996,
          3121.848,
          3085.018,
          3047.928,
          3010.5840000000003,
          2972.993,
          2935.1620000000003,
          2897.0959999999995,
          2858.801,
          2820.284,
          2781.5490000000004,
          2742.6040000000003,
          2703.453,
          2664.1020000000003,
          2624.555,
          2584.819,
          2544.897,
          2504.7960000000003,
          2464.52,
          2424.073,
          2383.46,
          2342.686,
          2301.755,
          2260.6710000000003,
          2219.44,
          2178.064,
          2136.547,
          2094.895,
          2053.111,
          2011.1989999999998,
          1969.162,
          1927.004,
          1884.729,
          1842.34,
          1799.842,
          1757.236,
          1714.5279999999998,
          1671.719,
          1628.8139999999999,
          1585.816,
          1542.727,
          1499.5520000000001,
          1456.2920000000001,
          1412.951,
          1369.5320000000002,
          1326.0379999999998,
          1282.472,
          1238.836,
          1195.134,
          1151.367,
          1107.539,
          1063.653,
          1019.711,
          975.716,
          931.669,
          887.575,
          843.435,
          799.2510000000001,
          755.0269999999999,
          710.7639999999999,
          666.465,
          622.132,
          577.7669999999999,
          533.374,
          488.95300000000003,
          444.50800000000004,
          400.04,
          355.55199999999996,
          311.045,
          266.52299999999997,
          221.986,
          177.438,
          132.88,
          88.314,
          43.742,
          -0.833,
          -45.411,
          -89.988,
          -134.563,
          -179.13400000000001,
          -223.69799999999998,
          -268.255,
          -312.803,
          -357.338,
          -401.86,
          -446.36699999999996,
          -490.85699999999997,
          -535.327,
          -579.7769999999999,
          -624.205,
          -668.6080000000001,
          -712.9839999999999,
          -757.3330000000001,
          -801.6519999999999,
          -845.94,
          -890.195,
          -934.415,
          -978.5989999999999,
          -1022.7439999999999,
          -1066.85,
          -1110.913,
          -1154.934,
          -1198.9089999999999,
          -1242.838,
          -1286.719,
          -1330.55,
          -1374.329,
          -1418.055,
          -1461.726,
          -1505.3410000000001,
          -1548.8970000000002,
          -1592.394,
          -1635.83,
          -1679.2020000000002,
          -1722.51,
          -1765.7520000000002,
          -1808.925,
          -1852.03,
          -1895.0629999999999,
          -1938.024,
          -1980.91,
          -2023.721,
          -2066.4539999999997,
          -2109.1079999999997,
          -2151.681,
          -2194.172,
          -2236.5789999999997,
          -2278.901,
          -2321.135,
          -2363.281,
          -2405.3360000000002,
          -2447.3,
          -2489.169,
          -2530.944,
          -2572.6220000000003,
          -2614.201,
          -2655.68,
          -2697.0570000000002,
          -2738.3309999999997,
          -2779.5,
          -2820.563,
          -2861.5159999999996,
          -2902.36,
          -2943.092,
          -2983.711,
          -3024.215,
          -3064.6020000000003,
          -3104.8709999999996,
          -3145.0190000000002,
          -3185.046,
          -3224.949,
          -3264.7259999999997,
          -3304.377,
          -3343.8990000000003,
          -3383.29,
          -3422.5490000000004,
          -3461.6740000000004,
          -3500.663,
          -3539.514,
          -3578.2259999999997,
          -3616.797,
          -3655.224,
          -3693.506,
          -3731.6409999999996,
          -3769.6279999999997,
          -3807.4629999999997,
          -3845.147,
          -3882.675,
          -3920.048,
          -3957.262,
          -3994.315,
          -4031.2070000000003,
          -4067.934,
          -4104.494000000001,
          -4140.887,
          -4177.109,
          -4213.157999999999,
          -4249.032999999999,
          -4284.731,
          -4320.251,
          -4355.589,
          -4390.745,
          -4425.715,
          -4460.498,
          -4495.090999999999,
          -4529.492,
          -4563.698,
          -4597.709,
          -4631.52,
          -4665.13,
          -4698.537,
          -4731.737,
          -4764.729,
          -4797.5109999999995,
          -4830.0779999999995,
          -4862.43,
          -4894.563,
          -4926.476,
          -4958.164000000001,
          -4989.626,
          -5020.86,
          -5051.861,
          -5082.628,
          -5113.157999999999,
          -5143.448,
          -5173.495,
          -5203.2970000000005,
          -5232.849,
          -5262.15,
          -5291.196999999999,
          -5319.985,
          -5348.513000000001,
          -5376.776999999999,
          -5404.774,
          -5432.5,
          -5459.953,
          -5487.13,
          -5514.025,
          -5540.638000000001,
          -5566.9619999999995,
          -5592.996,
          -5618.736,
          -5644.178000000001,
          -5669.318,
          -5694.153,
          -5718.679,
          -5742.891,
          -5766.786999999999,
          -5790.361,
          -5813.611,
          -5836.531,
          -5859.118,
          -5881.366999999999,
          -5903.274,
          -5924.835,
          -5946.045,
          -5966.9,
          -5987.394,
          -6007.523,
          -6027.281999999999,
          -6046.6669999999995,
          -6065.670999999999,
          -6084.291,
          -6102.521,
          -6120.356,
          -6137.79,
          -6154.816999999999,
          -6171.433000000001,
          -6187.630999999999,
          -6203.405,
          -6218.751,
          -6233.661,
          -6248.129,
          -6262.149,
          -6275.714,
          -6288.818,
          -6301.455,
          -6313.616999999999,
          -6325.295999999999,
          -6336.486999999999,
          -6347.182,
          -6357.3730000000005,
          -6367.053000000001,
          -6376.213000000001,
          -6384.847,
          -6392.944,
          -6400.4980000000005,
          -6407.499,
          -6413.938,
          -6419.808000000001,
          -6425.097,
          -6429.798000000001,
          -6433.901,
          -6437.395,
          -6440.27,
          -6442.516,
          -6444.1230000000005,
          -6445.078,
          -6445.371,
          -6444.991,
          -6443.9259999999995,
          -6442.1630000000005,
          -6439.691,
          -6436.496,
          -6432.565,
          -6427.884,
          -6422.44,
          -6416.218000000001,
          -6409.204000000001,
          -6401.383000000001,
          -6392.7390000000005,
          -6383.257,
          -6372.918000000001,
          -6361.706999999999,
          -6349.606,
          -6336.597,
          -6322.661,
          -6307.781,
          -6291.934,
          -6275.102,
          -6257.263000000001,
          -6238.395,
          -6218.477,
          -6197.485,
          -6175.394,
          -6152.181,
          -6127.819,
          -6102.283,
          -6075.545999999999,
          -6047.578,
          -6018.349,
          -5987.831,
          -5955.991999999999,
          -5922.8,
          -5888.219,
          -5852.215999999999,
          -5814.753000000001,
          -5775.795999999999,
          -5735.3009999999995,
          -5693.231,
          -5649.543000000001,
          -5604.194,
          -5557.137,
          -5508.326,
          -5457.7119999999995,
          -5405.244000000001,
          -5350.869000000001,
          -5294.531999999999,
          -5236.1759999999995,
          -5175.742,
          -5113.169,
          -5048.39,
          -4981.340999999999,
          -4911.954000000001,
          -4840.153,
          -4765.8679999999995,
          -4689.019,
          -4609.527,
          -4527.309,
          -4442.28,
          -4354.352,
          -4263.432,
          -4169.43,
          -4072.248,
          -3971.79,
          -3867.955,
          -3760.6440000000002,
          -3649.756,
          -3535.1890000000003,
          -3416.845,
          -3294.6259999999997,
          -3168.437,
          -3038.1940000000004,
          -2903.813,
          -2765.225,
          -2622.3720000000003,
          -2475.2129999999997,
          -2323.726,
          -2167.913,
          -2007.808,
          -1843.476,
          -1675.021,
          -1502.596,
          -1326.4,
          -1146.688,
          -963.779,
          -778.047,
          -589.934,
          -399.941,
          -208.628,
          -16.602,
          175.488,
          366.967,
          557.146,
          745.3439999999999,
          930.8939999999999,
          1113.171,
          1291.597,
          1465.651,
          1634.889,
          1798.933,
          1957.484,
          2110.312,
          2257.259,
          2398.231,
          2533.187,
          2662.14,
          2785.1420000000003,
          2902.281,
          3013.673,
          3119.4559999999997,
          3219.784,
          3314.825,
          3404.7529999999997,
          3489.748,
          3569.991,
          3645.663,
          3716.9429999999998,
          3784.008,
          3847.0290000000005,
          3906.173,
          3961.6020000000003,
          4013.4709999999995,
          4061.928,
          4107.117,
          4149.174,
          4188.232,
          4224.413,
          4257.838,
          4288.6179999999995,
          4316.8640000000005,
          4342.677,
          4366.155,
          4387.392,
          4406.474,
          4423.487,
          4438.513,
          4451.625,
          4462.896,
          4472.398,
          4480.194,
          4486.348,
          4490.919,
          4493.967000000001,
          4495.542,
          4495.6990000000005,
          4494.487,
          4491.954000000001,
          4488.143,
          4483.1,
          4476.8640000000005,
          4469.477,
          4460.976,
          4451.397,
          4440.774,
          4429.142,
          4416.532999999999,
          4402.977,
          4388.503,
          4373.141,
          4356.917,
          4339.857,
          4321.987,
          4303.33,
          4283.91,
          4263.75,
          4242.872,
          4221.295999999999,
          4199.041,
          4176.127,
          4152.5740000000005,
          4128.399,
          4103.619000000001,
          4078.252,
          4052.313,
          4025.8190000000004,
          3998.784,
          3971.224,
          3943.152,
          3914.5820000000003,
          3885.527,
          3856.0009999999997,
          3826.0159999999996,
          3795.583,
          3764.716,
          3733.425,
          3701.7209999999995,
          3669.616,
          3637.119,
          3604.24,
          3570.991,
          3537.3790000000004,
          3503.414,
          3469.105,
          3434.462,
          3399.492,
          3364.204,
          3328.607,
          3292.7070000000003,
          3256.513,
          3220.032,
          3183.272,
          3146.239,
          3108.94,
          3071.383,
          3033.574,
          2995.5190000000002,
          2957.224,
          2918.696,
          2879.941,
          2840.965,
          2801.7729999999997,
          2762.37,
          2722.763,
          2682.9559999999997,
          2642.955,
          2602.765,
          2562.39,
          2521.837,
          2481.109,
          2440.2110000000002,
          2399.149,
          2357.925,
          2316.545,
          2275.014,
          2233.334,
          2191.511,
          2149.548,
          2107.45,
          2065.22,
          2022.8629999999998,
          1980.381,
          1937.779,
          1895.06,
          1852.2279999999998,
          1809.287,
          1766.239,
          1723.088,
          1679.838,
          1636.4920000000002,
          1593.0520000000001,
          1549.523,
          1505.9070000000002,
          1462.207,
          1418.4260000000002,
          1374.568,
          1330.635,
          1286.63,
          1242.555,
          1198.415,
          1154.211,
          1109.945,
          1065.622,
          1021.243,
          976.811,
          932.329,
          887.798,
          843.222,
          798.6039999999999,
          753.944,
          709.247,
          664.5139999999999,
          619.747,
          574.9490000000001,
          530.122,
          485.269,
          440.39099999999996,
          395.491,
          350.57099999999997,
          305.633,
          260.68,
          215.713,
          170.734,
          125.74600000000001,
          80.751,
          35.75,
          -9.254,
          -54.25899999999999,
          -99.264,
          -144.266,
          -189.263,
          -234.25400000000002,
          -279.237,
          -324.209,
          -369.17,
          -414.116,
          -459.046,
          -503.959,
          -548.852,
          -593.724,
          -638.573,
          -683.3960000000001,
          -728.193,
          -772.962,
          -817.7,
          -862.4060000000001,
          -907.079,
          -951.716,
          -996.316,
          -1040.876,
          -1085.397,
          -1129.875,
          -1174.309,
          -1218.697,
          -1263.038,
          -1307.33,
          -1351.5710000000001,
          -1395.759,
          -1439.894,
          -1483.973,
          -1527.995,
          -1571.957,
          -1615.859,
          -1659.6989999999998,
          -1703.475,
          -1747.185,
          -1790.828,
          -1834.402,
          -1877.906,
          -1921.338,
          -1964.6960000000001,
          -2007.979,
          -2051.1839999999997,
          -2094.312,
          -2137.359,
          -2180.324,
          -2223.206,
          -2266.0029999999997,
          -2308.7129999999997,
          -2351.334,
          -2393.866,
          -2436.306,
          -2478.653,
          -2520.905,
          -2563.06,
          -2605.118,
          -2647.075,
          -2688.9309999999996,
          -2730.684,
          -2772.3320000000003,
          -2813.873,
          -2855.3059999999996,
          -2896.63,
          -2937.842,
          -2978.94,
          -3019.9240000000004,
          -3060.7909999999997,
          -3101.54,
          -3142.1690000000003,
          -3182.675,
          -3223.059,
          -3263.317,
          -3303.448,
          -3343.45,
          -3383.321,
          -3423.06,
          -3462.665,
          -3502.134,
          -3541.465,
          -3580.656,
          -3619.7059999999997,
          -3658.613,
          -3697.3740000000003,
          -3735.988,
          -3774.453,
          -3812.768,
          -3850.929,
          -3888.935,
          -3926.785,
          -3964.4759999999997,
          -4002.007,
          -4039.375,
          -4076.578,
          -4113.6140000000005,
          -4150.482,
          -4187.178,
          -4223.702,
          -4260.0509999999995,
          -4296.223,
          -4332.215,
          -4368.026,
          -4403.653,
          -4439.094,
          -4474.347,
          -4509.41,
          -4544.28,
          -4578.955,
          -4613.433,
          -4647.712,
          -4681.788,
          -4715.66,
          -4749.325,
          -4782.781,
          -4816.026,
          -4849.056,
          -4881.869000000001,
          -4914.463,
          -4946.835,
          -4978.982,
          -5010.902,
          -5042.592000000001,
          -5074.049,
          -5105.271,
          -5136.254,
          -5166.997,
          -5197.495,
          -5227.747,
          -5257.7480000000005,
          -5287.496999999999,
          -5316.99,
          -5346.224,
          -5375.196,
          -5403.901999999999,
          -5432.340999999999,
          -5460.507,
          -5488.398,
          -5516.012,
          -5543.343000000001,
          -5570.39,
          -5597.147,
          -5623.613,
          -5649.781999999999,
          -5675.651999999999,
          -5701.218000000001,
          -5726.478,
          -5751.4259999999995,
          -5776.06,
          -5800.375,
          -5824.366999999999,
          -5848.031999999999,
          -5871.366,
          -5894.365,
          -5917.024,
          -5939.339,
          -5961.306,
          -5982.919,
          -6004.1759999999995,
          -6025.069,
          -6045.596,
          -6065.75,
          -6085.528,
          -6104.923000000001,
          -6123.931,
          -6142.547,
          -6160.764,
          -6178.579000000001,
          -6195.985,
          -6212.976,
          -6229.547,
          -6245.691,
          -6261.404,
          -6276.678000000001,
          -6291.508000000001,
          -6305.887,
          -6319.809,
          -6333.266,
          -6346.2519999999995,
          -6358.76,
          -6370.783,
          -6382.314,
          -6393.346,
          -6403.87,
          -6413.879,
          -6423.366,
          -6432.321999999999,
          -6440.7390000000005,
          -6448.607,
          -6455.92,
          -6462.6669999999995,
          -6468.84,
          -6474.429,
          -6479.425,
          -6483.818,
          -6487.599,
          -6490.757,
          -6493.281,
          -6495.16,
          -6496.384,
          -6496.941999999999,
          -6496.82,
          -6496.009,
          -6494.495,
          -6492.266,
          -6489.309,
          -6485.611,
          -6481.158,
          -6475.935,
          -6469.929,
          -6463.125,
          -6455.508000000001,
          -6447.061,
          -6437.77,
          -6427.616,
          -6416.5830000000005,
          -6404.653,
          -6391.809,
          -6378.03,
          -6363.3,
          -6347.596,
          -6330.899,
          -6313.187,
          -6294.438,
          -6274.63,
          -6253.741,
          -6231.744000000001,
          -6208.616,
          -6184.33,
          -6158.86,
          -6132.18,
          -6104.258000000001,
          -6075.066999999999,
          -6044.576,
          -6012.753000000001,
          -5979.565,
          -5944.978,
          -5908.956999999999,
          -5871.465,
          -5832.465,
          -5791.916,
          -5749.778,
          -5706.009,
          -5660.565,
          -5613.399,
          -5564.464,
          -5513.7119999999995,
          -5461.089,
          -5406.543000000001,
          -5350.019,
          -5291.459,
          -5230.803,
          -5167.9890000000005,
          -5102.951,
          -5035.623,
          -4965.935,
          -4893.815,
          -4819.187,
          -4741.972,
          -4662.092000000001,
          -4579.460999999999,
          -4493.9929999999995,
          -4405.6,
          -4314.189,
          -4219.666,
          -4121.934,
          -4020.8940000000002,
          -3916.447,
          -3808.489,
          -3696.92,
          -3581.636,
          -3462.5359999999996,
          -3339.522,
          -3212.4970000000003,
          -3081.373,
          -2946.0679999999998,
          -2806.508,
          -2662.634,
          -2514.402,
          -2361.7889999999998,
          -2204.795,
          -2043.45,
          -1877.817,
          -1707.999,
          -1534.145,
          -1356.453,
          -1175.1789999999999,
          -990.635,
          -803.2,
          -613.314,
          -421.478,
          -228.253,
          -34.251999999999995,
          159.874,
          353.444,
          545.764,
          736.1419999999999,
          923.908,
          1108.424,
          1289.1019999999999,
          1465.415,
          1636.906,
          1803.19,
          1963.957,
          2118.973,
          2268.07,
          2411.15,
          2548.167,
          2679.1290000000004,
          2804.086,
          2923.1240000000003,
          3036.357,
          3143.921,
          3245.973,
          3342.677,
          3434.211,
          3520.7540000000004,
          3602.488,
          3679.595,
          3752.256,
          3820.651,
          3884.95,
          3945.322,
          4001.9309999999996,
          4054.933,
          4104.479,
          4150.714,
          4193.775,
          4233.795,
          4270.901,
          4305.212,
          4336.844,
          4365.905,
          4392.501,
          4416.728,
          4438.683,
          4458.454000000001,
          4476.126,
          4491.782,
          4505.497,
          4517.346,
          4527.399,
          4535.723,
          4542.38,
          4547.432,
          4550.938,
          4552.95,
          4553.523,
          4552.706,
          4550.549,
          4547.096,
          4542.391,
          4536.476,
          4529.392,
          4521.177,
          4511.869000000001,
          4501.501,
          4490.108,
          4477.723,
          4464.376,
          4450.097,
          4434.917,
          4418.86,
          4401.955,
          4384.227,
          4365.7,
          4346.398,
          4326.344,
          4305.56,
          4284.067,
          4261.884,
          4239.032,
          4215.529,
          4191.395,
          4166.646,
          4141.3,
          4115.373,
          4088.882,
          4061.84,
          4034.265,
          4006.1679999999997,
          3977.566,
          3948.47,
          3918.895,
          3888.853,
          3858.3559999999998,
          3827.417,
          3796.046,
          3764.255,
          3732.0559999999996,
          3699.458,
          3666.4709999999995,
          3633.107,
          3599.3740000000003,
          3565.281,
          3530.8390000000004,
          3496.055,
          3460.9390000000003,
          3425.4990000000003,
          3389.744,
          3353.68,
          3317.317,
          3280.6609999999996,
          3243.72,
          3206.502,
          3169.012,
          3131.259,
          3093.2490000000003,
          3054.988,
          3016.4829999999997,
          2977.739,
          2938.764,
          2899.563,
          2860.1409999999996,
          2820.5040000000004,
          2780.659,
          2740.6090000000004,
          2700.362,
          2659.921,
          2619.291,
          2578.479,
          2537.488,
          2496.324,
          2454.99,
          2413.493,
          2371.835,
          2330.022,
          2288.0570000000002,
          2245.945,
          2203.69,
          2161.297,
          2118.768,
          2076.1079999999997,
          2033.3210000000001,
          1990.411,
          1947.38,
          1904.234,
          1860.974,
          1817.606,
          1774.131,
          1730.555,
          1686.879,
          1643.1070000000002,
          1599.243,
          1555.289,
          1511.249,
          1467.126,
          1422.922,
          1378.641,
          1334.285,
          1289.858,
          1245.362,
          1200.8,
          1156.174,
          1111.489,
          1066.745,
          1021.946,
          977.0939999999999,
          932.193,
          887.2439999999999,
          842.2489999999999,
          797.212,
          752.135,
          707.02,
          661.87,
          616.686,
          571.472,
          526.229,
          480.96,
          435.667,
          390.353,
          345.01800000000003,
          299.66700000000003,
          254.3,
          208.919,
          163.528,
          118.12799999999999,
          72.721,
          27.309,
          -18.105999999999998,
          -63.522,
          -108.93700000000001,
          -154.34799999999998,
          -199.755,
          -245.155,
          -290.546,
          -335.925,
          -381.293,
          -426.64599999999996,
          -471.98199999999997,
          -517.3,
          -562.5980000000001,
          -607.874,
          -653.126,
          -698.3530000000001,
          -743.552,
          -788.7230000000001,
          -833.862,
          -878.9689999999999,
          -924.041,
          -969.077,
          -1014.076,
          -1059.0339999999999,
          -1103.952,
          -1148.826,
          -1193.656,
          -1238.4389999999999,
          -1283.174,
          -1327.859,
          -1372.493,
          -1417.0729999999999,
          -1461.599,
          -1506.068,
          -1550.4779999999998,
          -1594.829,
          -1639.119,
          -1683.345,
          -1727.506,
          -1771.601,
          -1815.628,
          -1859.585,
          -1903.47,
          -1947.283,
          -1991.02,
          -2034.682,
          -2078.265,
          -2121.769,
          -2165.1910000000003,
          -2208.531,
          -2251.786,
          -2294.9539999999997,
          -2338.035,
          -2381.026,
          -2423.926,
          -2466.734,
          -2509.446,
          -2552.063,
          -2594.5820000000003,
          -2637.0009999999997,
          -2679.3190000000004,
          -2721.534,
          -2763.645,
          -2805.6490000000003,
          -2847.545,
          -2889.3320000000003,
          -2931.008,
          -2972.57,
          -3014.018,
          -3055.349,
          -3096.562,
          -3137.655,
          -3178.6259999999997,
          -3219.474,
          -3260.197,
          -3300.792,
          -3341.259,
          -3381.595,
          -3421.7990000000004,
          -3461.869,
          -3501.802,
          -3541.598,
          -3581.2529999999997,
          -3620.768,
          -3660.138,
          -3699.364,
          -3738.442,
          -3777.3709999999996,
          -3816.1490000000003,
          -3854.7740000000003,
          -3893.244,
          -3931.5559999999996,
          -3969.71,
          -4007.703,
          -4045.533,
          -4083.198,
          -4120.696,
          -4158.025,
          -4195.183,
          -4232.167,
          -4268.976,
          -4305.608,
          -4342.06,
          -4378.329000000001,
          -4414.415,
          -4450.314,
          -4486.024,
          -4521.544,
          -4556.87,
          -4592.001,
          -4626.934,
          -4661.667,
          -4696.197,
          -4730.522,
          -4764.639,
          -4798.5470000000005,
          -4832.242,
          -4865.722,
          -4898.985,
          -4932.027,
          -4964.847,
          -4997.441,
          -5029.807,
          -5061.942,
          -5093.843,
          -5125.508,
          -5156.934,
          -5188.1179999999995,
          -5219.057,
          -5249.7480000000005,
          -5280.188,
          -5310.374,
          -5340.303000000001,
          -5369.972,
          -5399.378000000001,
          -5428.517,
          -5457.3859999999995,
          -5485.983,
          -5514.303000000001,
          -5542.344,
          -5570.101,
          -5597.573,
          -5624.753000000001,
          -5651.641,
          -5678.231,
          -5704.519,
          -5730.504,
          -5756.179,
          -5781.5419999999995,
          -5806.589,
          -5831.315,
          -5855.717,
          -5879.791,
          -5903.531,
          -5926.934,
          -5949.996,
          -5972.7119999999995,
          -5995.076999999999,
          -6017.088000000001,
          -6038.7390000000005,
          -6060.025,
          -6080.943,
          -6101.486,
          -6121.651,
          -6141.431,
          -6160.821999999999,
          -6179.816999999999,
          -6198.4130000000005,
          -6216.603,
          -6234.382,
          -6251.744000000001,
          -6268.683000000001,
          -6285.194,
          -6301.269,
          -6316.904,
          -6332.092,
          -6346.826,
          -6361.1,
          -6374.906999999999,
          -6388.24,
          -6401.092,
          -6413.456,
          -6425.325,
          -6436.691,
          -6447.547,
          -6457.884,
          -6467.696,
          -6476.973000000001,
          -6485.706999999999,
          -6493.891,
          -6501.515,
          -6508.57,
          -6515.045999999999,
          -6520.935,
          -6526.228,
          -6530.9130000000005,
          -6534.981,
          -6538.423000000001,
          -6541.227,
          -6543.382,
          -6544.8769999999995,
          -6545.7,
          -6545.840999999999,
          -6545.286999999999,
          -6544.025,
          -6542.044,
          -6539.33,
          -6535.869000000001,
          -6531.648,
          -6526.651999999999,
          -6520.868,
          -6514.28,
          -6506.8730000000005,
          -6498.630999999999,
          -6489.5380000000005,
          -6479.576,
          -6468.729,
          -6456.979,
          -6444.308000000001,
          -6430.696999999999,
          -6416.126,
          -6400.5740000000005,
          -6384.022,
          -6366.448,
          -6347.83,
          -6328.146,
          -6307.371,
          -6285.481,
          -6262.451,
          -6238.255999999999,
          -6212.868,
          -6186.258000000001,
          -6158.4,
          -6129.262,
          -6098.815,
          -6067.025,
          -6033.86,
          -5999.285,
          -5963.266,
          -5925.765,
          -5886.743,
          -5846.161,
          -5803.978,
          -5760.151,
          -5714.635,
          -5667.3859999999995,
          -5618.352,
          -5567.486,
          -5514.736999999999,
          -5460.049,
          -5403.366,
          -5344.632,
          -5283.784000000001,
          -5220.7609999999995,
          -5155.498,
          -5087.924,
          -5017.972,
          -4945.567,
          -4870.634,
          -4793.093,
          -4712.8640000000005,
          -4629.861,
          -4543.998,
          -4455.184,
          -4363.326,
          -4268.329000000001,
          -4170.096,
          -4068.526,
          -3963.5159999999996,
          -3854.965,
          -3742.7690000000002,
          -3626.824,
          -3507.027,
          -3383.278,
          -3255.4790000000003,
          -3123.54,
          -2987.3759999999997,
          -2846.9120000000003,
          -2702.086,
          -2552.854,
          -2399.189,
          -2241.089,
          -2078.581,
          -1911.726,
          -1740.626,
          -1565.4260000000002,
          -1386.3229999999999,
          -1203.57,
          -1017.48,
          -828.427,
          -636.854,
          -443.26199999999994,
          -248.213,
          -52.321999999999996,
          143.756,
          339.334,
          533.714,
          726.196,
          916.1010000000001,
          1102.7830000000001,
          1285.644,
          1464.149,
          1637.83,
          1806.2939999999999,
          1969.2220000000002,
          2126.3720000000003,
          2277.571,
          2422.712,
          2561.7470000000003,
          2694.678,
          2821.553,
          2942.455,
          3057.4959999999996,
          3166.813,
          3270.559,
          3368.902,
          3462.018,
          3550.086,
          3633.29,
          3711.8140000000003,
          3785.841,
          3855.548,
          3921.111,
          3982.698,
          4040.4759999999997,
          4094.6020000000003,
          4145.227,
          4192.499,
          4236.556,
          4277.688,
          4315.56,
          4350.754,
          4383.232,
          4413.108,
          4440.483,
          4465.459,
          4488.130999999999,
          4508.590999999999,
          4526.923,
          4543.210999999999,
          4557.532999999999,
          4569.962,
          4580.569,
          4589.424,
          4596.59,
          4602.127,
          4606.096,
          4608.5509999999995,
          4609.545999999999,
          4609.1320000000005,
          4607.357,
          4604.269,
          4599.911,
          4594.325,
          4587.554,
          4579.635,
          4570.606,
          4560.502,
          4549.358,
          4537.207,
          4524.08,
          4510.008,
          4495.02,
          4479.143,
          4462.404,
          4444.83,
          4426.445,
          4407.273,
          4387.338,
          4366.661,
          4345.263,
          4323.166,
          4300.389,
          4276.951,
          4252.872,
          4228.169,
          4202.858,
          4176.958,
          4150.483,
          4123.45,
          4095.873,
          4067.768,
          4039.1479999999997,
          4010.027,
          3980.4179999999997,
          3950.335,
          3919.79,
          3888.795,
          3857.361,
          3825.4990000000003,
          3793.222,
          3760.539,
          3727.461,
          3693.998,
          3660.1609999999996,
          3625.9570000000003,
          3591.3979999999997,
          3556.491,
          3521.2459999999996,
          3485.671,
          3449.775,
          3413.566,
          3377.051,
          3340.238,
          3303.135,
          3265.748,
          3228.086,
          3190.155,
          3151.961,
          3113.512,
          3074.8140000000003,
          3035.873,
          2996.696,
          2957.288,
          2917.655,
          2877.803,
          2837.738,
          2797.4640000000004,
          2756.988,
          2716.315,
          2675.45,
          2634.397,
          2593.163,
          2551.75,
          2510.166,
          2468.413,
          2426.496,
          2384.42,
          2342.189,
          2299.808,
          2257.28,
          2214.61,
          2171.802,
          2128.859,
          2085.786,
          2042.586,
          1999.263,
          1955.8210000000001,
          1912.263,
          1868.5929999999998,
          1824.815,
          1780.931,
          1736.945,
          1692.861,
          1648.681,
          1604.4089999999999,
          1560.0479999999998,
          1515.601,
          1471.0710000000001,
          1426.461,
          1381.775,
          1337.014,
          1292.182,
          1247.282,
          1202.316,
          1157.287,
          1112.198,
          1067.052,
          1021.85,
          976.597,
          931.294,
          885.943,
          840.548,
          795.1110000000001,
          749.6339999999999,
          704.1189999999999,
          658.57,
          612.987,
          567.375,
          521.734,
          476.06800000000004,
          430.37800000000004,
          384.666,
          338.936,
          293.188,
          247.426,
          201.65099999999998,
          155.865,
          110.071,
          64.27,
          18.465,
          -27.343000000000004,
          -73.15100000000001,
          -118.95700000000001,
          -164.76,
          -210.558,
          -256.347,
          -302.128,
          -347.897,
          -393.653,
          -439.394,
          -485.11699999999996,
          -530.822,
          -576.507,
          -622.168,
          -667.806,
          -713.4169999999999,
          -759,
          -804.554,
          -850.076,
          -895.565,
          -941.0189999999999,
          -986.435,
          -1031.8139999999999,
          -1077.152,
          -1122.447,
          -1167.7,
          -1212.906,
          -1258.066,
          -1303.1760000000002,
          -1348.236,
          -1393.244,
          -1438.1970000000001,
          -1483.095,
          -1527.9360000000001,
          -1572.717,
          -1617.4379999999999,
          -1662.096,
          -1706.69,
          -1751.2179999999998,
          -1795.6789999999999,
          -1840.0710000000001,
          -1884.3929999999998,
          -1928.641,
          -1972.816,
          -2016.915,
          -2060.936,
          -2104.879,
          -2148.741,
          -2192.52,
          -2236.215,
          -2279.825,
          -2323.347,
          -2366.78,
          -2410.123,
          -2453.373,
          -2496.529,
          -2539.589,
          -2582.552,
          -2625.4159999999997,
          -2668.179,
          -2710.8390000000004,
          -2753.395,
          -2795.8459999999995,
          -2838.188,
          -2880.422,
          -2922.5440000000003,
          -2964.553,
          -3006.448,
          -3048.2270000000003,
          -3089.888,
          -3131.429,
          -3172.848,
          -3214.1440000000002,
          -3255.315,
          -3296.3590000000004,
          -3337.275,
          -3378.059,
          -3418.712,
          -3459.23,
          -3499.612,
          -3539.8559999999998,
          -3579.961,
          -3619.9240000000004,
          -3659.743,
          -3699.417,
          -3738.9440000000004,
          -3778.322,
          -3817.548,
          -3856.6209999999996,
          -3895.539,
          -3934.3,
          -3972.901,
          -4011.342,
          -4049.619,
          -4087.732,
          -4125.6759999999995,
          -4163.452,
          -4201.056,
          -4238.486,
          -4275.741,
          -4312.818,
          -4349.715,
          -4386.429,
          -4422.959,
          -4459.302,
          -4495.456,
          -4531.419,
          -4567.187,
          -4602.76,
          -4638.135,
          -4673.308,
          -4708.279,
          -4743.044,
          -4777.601,
          -4811.947,
          -4846.08,
          -4879.998,
          -4913.697,
          -4947.175,
          -4980.43,
          -5013.459,
          -5046.259,
          -5078.827,
          -5111.161,
          -5143.2570000000005,
          -5175.1140000000005,
          -5206.727,
          -5238.095,
          -5269.214,
          -5300.081,
          -5330.693,
          -5361.047,
          -5391.14,
          -5420.969,
          -5450.53,
          -5479.82,
          -5508.8369999999995,
          -5537.576,
          -5566.034000000001,
          -5594.2080000000005,
          -5622.094,
          -5649.688,
          -5676.988,
          -5703.9890000000005,
          -5730.688,
          -5757.08,
          -5783.1630000000005,
          -5808.932,
          -5834.383000000001,
          -5859.512,
          -5884.315,
          -5908.7880000000005,
          -5932.927,
          -5956.727,
          -5980.183000000001,
          -6003.2919999999995,
          -6026.049,
          -6048.4490000000005,
          -6070.488,
          -6092.161,
          -6113.463000000001,
          -6134.388000000001,
          -6154.933000000001,
          -6175.090999999999,
          -6194.859,
          -6214.229,
          -6233.196999999999,
          -6251.757,
          -6269.904,
          -6287.632,
          -6304.934,
          -6321.806,
          -6338.241,
          -6354.232,
          -6369.773,
          -6384.859,
          -6399.481,
          -6413.635,
          -6427.311,
          -6440.505,
          -6453.206999999999,
          -6465.411,
          -6477.109,
          -6488.295,
          -6498.959,
          -6509.094,
          -6518.691,
          -6527.743,
          -6536.24,
          -6544.174,
          -6551.536,
          -6558.316999999999,
          -6564.505999999999,
          -6570.095,
          -6575.073,
          -6579.431,
          -6583.156999999999,
          -6586.243,
          -6588.675,
          -6590.444,
          -6591.536,
          -6591.941999999999,
          -6591.648,
          -6590.643,
          -6588.9130000000005,
          -6586.446,
          -6583.228,
          -6579.244000000001,
          -6574.481,
          -6568.923000000001,
          -6562.557,
          -6555.366999999999,
          -6547.3369999999995,
          -6538.4490000000005,
          -6528.688,
          -6518.035,
          -6506.474,
          -6493.985,
          -6480.549,
          -6466.148,
          -6450.76,
          -6434.3640000000005,
          -6416.94,
          -6398.464,
          -6378.915,
          -6358.268,
          -6336.4980000000005,
          -6313.58,
          -6289.4890000000005,
          -6264.196999999999,
          -6237.675,
          -6209.895,
          -6180.828,
          -6150.441,
          -6118.703,
          -6085.58,
          -6051.036999999999,
          -6015.039000000001,
          -5977.549,
          -5938.528,
          -5897.935,
          -5855.73,
          -5811.868,
          -5766.306,
          -5718.996999999999,
          -5669.892,
          -5618.941,
          -5566.092,
          -5511.29,
          -5454.479,
          -5395.601,
          -5334.594,
          -5271.396,
          -5205.939,
          -5138.156,
          -5067.975,
          -4995.323,
          -4920.124,
          -4842.295999999999,
          -4761.76,
          -4678.427,
          -4592.212,
          -4503.022,
          -4410.765,
          -4315.342000000001,
          -4216.657,
          -4114.607,
          -4009.0890000000004,
          -3900,
          -3787.2340000000004,
          -3670.6859999999997,
          -3550.252,
          -3425.83,
          -3297.321,
          -3164.632,
          -3027.677,
          -2886.3790000000004,
          -2740.675,
          -2590.515,
          -2435.874,
          -2276.746,
          -2113.155,
          -1945.161,
          -1772.862,
          -1596.401,
          -1415.974,
          -1231.83,
          -1044.282,
          -853.703,
          -660.5319999999999,
          -465.273,
          -268.49,
          -70.798,
          127.14299999999999,
          324.645,
          521,
          715.503,
          907.4689999999999,
          1096.24,
          1281.212,
          1461.84,
          1637.645,
          1808.226,
          1973.256,
          2132.484,
          2285.732,
          2432.886,
          2573.8920000000003,
          2708.7490000000003,
          2837.502,
          2960.2290000000003,
          3077.045,
          3188.0809999999997,
          3293.492,
          3393.446,
          3488.116,
          3577.6859999999997,
          3662.34,
          3742.261,
          3817.633,
          3888.636,
          3955.447,
          4018.236,
          4077.1690000000003,
          4132.406,
          4184.101,
          4232.401,
          4277.447,
          4319.375,
          4358.313,
          4394.385,
          4427.707,
          4458.392,
          4486.545,
          4512.268,
          4535.657,
          4556.805,
          4575.798,
          4592.719,
          4607.647,
          4620.659000000001,
          4631.825,
          4641.214,
          4648.893,
          4654.92,
          4659.357,
          4662.2609999999995,
          4663.684,
          4663.679,
          4662.294,
          4659.579000000001,
          4655.575,
          4650.327,
          4643.876,
          4636.262,
          4627.522,
          4617.692,
          4606.807,
          4594.9,
          4582.004,
          4568.15,
          4553.365,
          4537.679,
          4521.119000000001,
          4503.710999999999,
          4485.48,
          4466.451,
          4446.648,
          4426.090999999999,
          4404.803,
          4382.805,
          4360.117,
          4336.758,
          4312.747,
          4288.104,
          4262.843,
          4236.984,
          4210.541,
          4183.531,
          4155.969,
          4127.871,
          4099.249,
          4070.119,
          4040.493,
          4010.385,
          3979.8070000000002,
          3948.772,
          3917.2909999999997,
          3885.3759999999997,
          3853.0370000000003,
          3820.2870000000003,
          3787.135,
          3753.591,
          3719.6659999999997,
          3685.37,
          3650.711,
          3615.699,
          3580.343,
          3544.651,
          3508.632,
          3472.2940000000003,
          3435.645,
          3398.6929999999998,
          3361.446,
          3323.91,
          3286.093,
          3248.002,
          3209.6440000000002,
          3171.026,
          3132.1540000000005,
          3093.035,
          3053.6740000000004,
          3014.078,
          2974.2540000000004,
          2934.205,
          2893.9390000000003,
          2853.461,
          2812.777,
          2771.8909999999996,
          2730.808,
          2689.535,
          2648.0759999999996,
          2606.435,
          2564.618,
          2522.629,
          2480.473,
          2438.154,
          2395.677,
          2353.0460000000003,
          2310.265,
          2267.3379999999997,
          2224.27,
          2181.064,
          2137.725,
          2094.256,
          2050.661,
          2006.943,
          1963.1070000000002,
          1919.156,
          1875.0929999999998,
          1830.922,
          1786.646,
          1742.269,
          1697.7939999999999,
          1653.224,
          1608.5620000000001,
          1563.8120000000001,
          1518.977,
          1474.059,
          1429.0610000000001,
          1383.987,
          1338.84,
          1293.621,
          1248.335,
          1202.984,
          1157.57,
          1112.096,
          1066.566,
          1020.9810000000001,
          975.3439999999999,
          929.658,
          883.925,
          838.148,
          792.329,
          746.471,
          700.575,
          654.646,
          608.683,
          562.691,
          516.672,
          470.62699999999995,
          424.55800000000005,
          378.469,
          332.361,
          286.237,
          240.09799999999998,
          193.947,
          147.786,
          101.617,
          55.441,
          9.262,
          -36.919000000000004,
          -83.1,
          -129.279,
          -175.454,
          -221.623,
          -267.784,
          -313.934,
          -360.07300000000004,
          -406.199,
          -452.30800000000005,
          -498.4,
          -544.4730000000001,
          -590.525,
          -636.553,
          -682.556,
          -728.533,
          -774.4810000000001,
          -820.398,
          -866.284,
          -912.135,
          -957.951,
          -1003.7289999999999,
          -1049.468,
          -1095.1660000000002,
          -1140.8210000000001,
          -1186.432,
          -1231.997,
          -1277.513,
          -1322.98,
          -1368.395,
          -1413.7579999999998,
          -1459.065,
          -1504.316,
          -1549.509,
          -1594.642,
          -1639.713,
          -1684.721,
          -1729.664,
          -1774.54,
          -1819.348,
          -1864.086,
          -1908.7520000000002,
          -1953.345,
          -1997.8629999999998,
          -2042.3039999999999,
          -2086.666,
          -2130.949,
          -2175.149,
          -2219.2670000000003,
          -2263.299,
          -2307.244,
          -2351.101,
          -2394.867,
          -2438.542,
          -2482.123,
          -2525.609,
          -2568.998,
          -2612.288,
          -2655.478,
          -2698.566,
          -2741.55,
          -2784.428,
          -2827.199,
          -2869.861,
          -2912.413,
          -2954.8520000000003,
          -2997.176,
          -3039.385,
          -3081.4759999999997,
          -3123.447,
          -3165.297,
          -3207.0240000000003,
          -3248.6259999999997,
          -3290.1020000000003,
          -3331.449,
          -3372.665,
          -3413.75,
          -3454.7,
          -3495.514,
          -3536.191,
          -3576.7270000000003,
          -3617.123,
          -3657.3740000000003,
          -3697.4809999999998,
          -3737.44,
          -3777.25,
          -3816.908,
          -3856.414,
          -3895.764,
          -3934.9570000000003,
          -3973.99,
          -4012.863,
          -4051.572,
          -4090.116,
          -4128.492,
          -4166.6990000000005,
          -4204.734,
          -4242.596,
          -4280.281,
          -4317.788,
          -4355.115,
          -4392.259,
          -4429.219,
          -4465.991,
          -4502.5740000000005,
          -4538.965,
          -4575.162,
          -4611.163,
          -4646.965,
          -4682.566,
          -4717.963,
          -4753.154,
          -4788.137,
          -4822.907999999999,
          -4857.465999999999,
          -4891.807,
          -4925.93,
          -4959.831,
          -4993.508,
          -5026.959,
          -5060.18,
          -5093.168,
          -5125.9220000000005,
          -5158.437,
          -5190.712,
          -5222.7429999999995,
          -5254.526999999999,
          -5286.062,
          -5317.344,
          -5348.37,
          -5379.138000000001,
          -5409.643,
          -5439.884,
          -5469.856,
          -5499.556,
          -5528.981,
          -5558.128000000001,
          -5586.991999999999,
          -5615.571999999999,
          -5643.863,
          -5671.861,
          -5699.563,
          -5726.965999999999,
          -5754.065,
          -5780.856,
          -5807.3369999999995,
          -5833.5019999999995,
          -5859.348000000001,
          -5884.871,
          -5910.066,
          -5934.93,
          -5959.4580000000005,
          -5983.646,
          -6007.4890000000005,
          -6030.983,
          -6054.1230000000005,
          -6076.906,
          -6099.325,
          -6121.3769999999995,
          -6143.056,
          -6164.357,
          -6185.275,
          -6205.805,
          -6225.941999999999,
          -6245.681,
          -6265.015,
          -6283.939,
          -6302.4490000000005,
          -6320.536999999999,
          -6338.198,
          -6355.4259999999995,
          -6372.215,
          -6388.558000000001,
          -6404.4490000000005,
          -6419.880999999999,
          -6434.849,
          -6449.344,
          -6463.361,
          -6476.892,
          -6489.929,
          -6502.465999999999,
          -6514.495,
          -6526.007,
          -6536.996,
          -6547.453,
          -6557.369000000001,
          -6566.736,
          -6575.545999999999,
          -6583.791,
          -6591.459,
          -6598.543000000001,
          -6605.033,
          -6610.919,
          -6616.191,
          -6620.839,
          -6624.852,
          -6628.22,
          -6630.932,
          -6632.976,
          -6634.340999999999,
          -6635.014,
          -6634.985,
          -6634.2390000000005,
          -6632.764,
          -6630.548000000001,
          -6627.576999999999,
          -6623.835999999999,
          -6619.31,
          -6613.986,
          -6607.849,
          -6600.882,
          -6593.07,
          -6584.396,
          -6574.842,
          -6564.392,
          -6553.028,
          -6540.73,
          -6527.481,
          -6513.259,
          -6498.044,
          -6481.816,
          -6464.553000000001,
          -6446.232,
          -6426.83,
          -6406.323,
          -6384.688,
          -6361.897,
          -6337.925,
          -6312.743,
          -6286.326,
          -6258.642,
          -6229.661999999999,
          -6199.353,
          -6167.685,
          -6134.6230000000005,
          -6100.132,
          -6064.177,
          -6026.719,
          -5987.72,
          -5947.139,
          -5904.935,
          -5861.064,
          -5815.48,
          -5768.139,
          -5718.988,
          -5667.98,
          -5615.06,
          -5560.175,
          -5503.267,
          -5444.276999999999,
          -5383.143,
          -5319.803000000001,
          -5254.188,
          -5186.232,
          -5115.86,
          -5043.001,
          -4967.5740000000005,
          -4889.502,
          -4808.7,
          -4725.082,
          -4638.561,
          -4549.042,
          -4456.433,
          -4360.635,
          -4261.55,
          -4159.0740000000005,
          -4053.103,
          -3943.532,
          -3830.255,
          -3713.165,
          -3592.157,
          -3467.1259999999997,
          -3337.974,
          -3204.6040000000003,
          -3066.929,
          -2924.87,
          -2778.362,
          -2627.3540000000003,
          -2471.815,
          -2311.74,
          -2147.15,
          -1978.102,
          -1804.691,
          -1627.059,
          -1445.398,
          -1259.955,
          -1071.0410000000002,
          -879.029,
          -684.355,
          -487.525,
          -289.101,
          -89.7,
          110.01299999999999,
          309.347,
          507.59,
          704.03,
          897.972,
          1088.754,
          1275.76,
          1458.4370000000001,
          1636.297,
          1808.93,
          1976,
          2137.249,
          2292.491,
          2441.606,
          2584.535,
          2721.2740000000003,
          2851.863,
          2976.3779999999997,
          3094.93,
          3207.652,
          3314.697,
          3416.2309999999998,
          3512.4309999999996,
          3603.478,
          3689.5570000000002,
          3770.8540000000003,
          3847.553,
          3919.835,
          3987.877,
          4051.853,
          4111.927,
          4168.264,
          4221.018,
          4270.335999999999,
          4316.363,
          4359.234,
          4399.0779999999995,
          4436.022,
          4470.183,
          4501.674,
          4530.601,
          4557.07,
          4581.175,
          4603.0109999999995,
          4622.664000000001,
          4640.22,
          4655.758,
          4669.355,
          4681.082,
          4691.01,
          4699.204000000001,
          4705.726,
          4710.638,
          4713.996,
          4715.853,
          4716.264,
          4715.277,
          4712.941,
          4709.3,
          4704.398,
          4698.276,
          4690.976,
          4682.535,
          4672.9890000000005,
          4662.374,
          4650.723,
          4638.069,
          4624.443,
          4609.874,
          4594.391,
          4578.021,
          4560.793,
          4542.73,
          4523.856,
          4504.197,
          4483.774,
          4462.609,
          4440.725,
          4418.14,
          4394.875,
          4370.948,
          4346.378,
          4321.183,
          4295.38,
          4268.985,
          4242.015,
          4214.484,
          4186.407999999999,
          4157.8009999999995,
          4128.677,
          4099.0509999999995,
          4068.934,
          4038.341,
          4007.282,
          3975.7709999999997,
          3943.8190000000004,
          3911.438,
          3878.637,
          3845.429,
          3811.823,
          3777.829,
          3743.4570000000003,
          3708.717,
          3673.618,
          3638.1690000000003,
          3602.3779999999997,
          3566.255,
          3529.8070000000002,
          3493.0440000000003,
          3455.9709999999995,
          3418.598,
          3380.9320000000002,
          3342.98,
          3304.7490000000003,
          3266.2470000000003,
          3227.4790000000003,
          3188.452,
          3149.1740000000004,
          3109.65,
          3069.886,
          3029.889,
          2989.664,
          2949.217,
          2908.554,
          2867.6809999999996,
          2826.6020000000003,
          2785.323,
          2743.849,
          2702.185,
          2660.336,
          2618.3070000000002,
          2576.103,
          2533.728,
          2491.186,
          2448.4829999999997,
          2405.623,
          2362.609,
          2319.447,
          2276.14,
          2232.6910000000003,
          2189.107,
          2145.389,
          2101.542,
          2057.57,
          2013.476,
          1969.264,
          1924.9379999999999,
          1880.501,
          1835.9560000000001,
          1791.308,
          1746.558,
          1701.711,
          1656.77,
          1611.737,
          1566.6170000000002,
          1521.412,
          1476.125,
          1430.7579999999998,
          1385.316,
          1339.8010000000002,
          1294.2160000000001,
          1248.563,
          1202.845,
          1157.066,
          1111.2269999999999,
          1065.3310000000001,
          1019.382,
          973.3810000000001,
          927.332,
          881.2360000000001,
          835.097,
          788.916,
          742.696,
          696.439,
          650.149,
          603.826,
          557.474,
          511.095,
          464.691,
          418.265,
          371.81800000000004,
          325.35200000000003,
          278.871,
          232.37599999999998,
          185.86900000000003,
          139.352,
          92.82700000000001,
          46.297,
          -0.23600000000000002,
          -46.771,
          -93.305,
          -139.836,
          -186.363,
          -232.88400000000001,
          -279.39599999999996,
          -325.897,
          -372.38599999999997,
          -418.861,
          -465.319,
          -511.76,
          -558.18,
          -604.578,
          -650.953,
          -697.302,
          -743.6239999999999,
          -789.9169999999999,
          -836.179,
          -882.4069999999999,
          -928.602,
          -974.7589999999999,
          -1020.8789999999999,
          -1066.9589999999998,
          -1112.997,
          -1158.991,
          -1204.94,
          -1250.8419999999999,
          -1296.6960000000001,
          -1342.499,
          -1388.25,
          -1433.9470000000001,
          -1479.589,
          -1525.1729999999998,
          -1570.6979999999999,
          -1616.162,
          -1661.5639999999999,
          -1706.901,
          -1752.1729999999998,
          -1797.378,
          -1842.513,
          -1887.5770000000002,
          -1932.568,
          -1977.485,
          -2022.326,
          -2067.089,
          -2111.7729999999997,
          -2156.376,
          -2200.896,
          -2245.331,
          -2289.68,
          -2333.942,
          -2378.113,
          -2422.194,
          -2466.181,
          -2510.073,
          -2553.869,
          -2597.567,
          -2641.165,
          -2684.6620000000003,
          -2728.055,
          -2771.343,
          -2814.5240000000003,
          -2857.5959999999995,
          -2900.559,
          -2943.409,
          -2986.145,
          -3028.7659999999996,
          -3071.2690000000002,
          -3113.653,
          -3155.9159999999997,
          -3198.0559999999996,
          -3240.071,
          -3281.96,
          -3323.7209999999995,
          -3365.3509999999997,
          -3406.85,
          -3448.2140000000004,
          -3489.4429999999998,
          -3530.535,
          -3571.486,
          -3612.297,
          -3652.9640000000004,
          -3693.485,
          -3733.86,
          -3774.085,
          -3814.159,
          -3854.08,
          -3893.8459999999995,
          -3933.454,
          -3972.9040000000005,
          -4012.192,
          -4051.317,
          -4090.276,
          -4129.068,
          -4167.69,
          -4206.14,
          -4244.417,
          -4282.517,
          -4320.439,
          -4358.181,
          -4395.74,
          -4433.1140000000005,
          -4470.3,
          -4507.2970000000005,
          -4544.101,
          -4580.712,
          -4617.125,
          -4653.34,
          -4689.353,
          -4725.162,
          -4760.765,
          -4796.159000000001,
          -4831.340999999999,
          -4866.309,
          -4901.061,
          -4935.593,
          -4969.904,
          -5003.99,
          -5037.848,
          -5071.477,
          -5104.873,
          -5138.032999999999,
          -5170.955,
          -5203.635,
          -5236.071,
          -5268.259,
          -5300.196999999999,
          -5331.882,
          -5363.311,
          -5394.479,
          -5425.385,
          -5456.025,
          -5486.396,
          -5516.495,
          -5546.316999999999,
          -5575.86,
          -5605.121,
          -5634.095,
          -5662.779,
          -5691.170999999999,
          -5719.264,
          -5747.058000000001,
          -5774.545999999999,
          -5801.727,
          -5828.595,
          -5855.147,
          -5881.378000000001,
          -5907.285,
          -5932.8640000000005,
          -5958.109,
          -5983.018,
          -6007.585,
          -6031.806,
          -6055.677,
          -6079.193,
          -6102.349,
          -6125.141,
          -6147.564,
          -6169.611999999999,
          -6191.281,
          -6212.566,
          -6233.460999999999,
          -6253.960999999999,
          -6274.061,
          -6293.755,
          -6313.0380000000005,
          -6331.903,
          -6350.346,
          -6368.36,
          -6385.938,
          -6403.076,
          -6419.766,
          -6436.0019999999995,
          -6451.778,
          -6467.085999999999,
          -6481.92,
          -6496.273,
          -6510.138000000001,
          -6523.507,
          -6536.374,
          -6548.73,
          -6560.566999999999,
          -6571.878000000001,
          -6582.654,
          -6592.887,
          -6602.569,
          -6611.691,
          -6620.244000000001,
          -6628.219,
          -6635.607,
          -6642.397,
          -6648.58,
          -6654.146,
          -6659.085,
          -6663.3859999999995,
          -6667.039000000001,
          -6670.031999999999,
          -6672.354,
          -6673.993,
          -6674.938,
          -6675.175,
          -6674.693,
          -6673.478,
          -6671.517,
          -6668.797,
          -6665.303000000001,
          -6661.021,
          -6655.937,
          -6650.034000000001,
          -6643.297,
          -6635.71,
          -6627.257,
          -6617.919,
          -6607.681,
          -6596.522,
          -6584.4259999999995,
          -6571.371,
          -6557.339,
          -6542.309,
          -6526.26,
          -6509.17,
          -6491.016,
          -6471.774,
          -6451.422,
          -6429.934,
          -6407.285,
          -6383.446999999999,
          -6358.393,
          -6332.095,
          -6304.524,
          -6275.649,
          -6245.438,
          -6213.858,
          -6180.878000000001,
          -6146.459,
          -6110.566999999999,
          -6073.164000000001,
          -6034.21,
          -5993.664000000001,
          -5951.486,
          -5907.63,
          -5862.0509999999995,
          -5814.704000000001,
          -5765.536,
          -5714.499,
          -5661.539000000001,
          -5606.6,
          -5549.6269999999995,
          -5490.558000000001,
          -5429.331999999999,
          -5365.885,
          -5300.149,
          -5232.057,
          -5161.532999999999,
          -5088.505,
          -5012.893,
          -4934.6179999999995,
          -4853.596,
          -4769.738,
          -4682.957,
          -4593.157999999999,
          -4500.248,
          -4404.127,
          -4304.694,
          -4201.847,
          -4095.48,
          -3985.486,
          -3871.759,
          -3754.19,
          -3632.672,
          -3507.1,
          -3377.373,
          -3243.393,
          -3105.071,
          -2962.327,
          -2815.092,
          -2663.3140000000003,
          -2506.9610000000002,
          -2346.0229999999997,
          -2180.521,
          -2010.506,
          -1836.0739999999998,
          -1657.3629999999998,
          -1474.5610000000001,
          -1287.915,
          -1097.731,
          -904.382,
          -708.304,
          -509.999,
          -310.031,
          -109.01899999999999,
          92.37100000000001,
          293.444,
          493.481,
          691.768,
          887.6010000000001,
          1080.3110000000001,
          1269.272,
          1453.921,
          1633.763,
          1808.379,
          1977.424,
          2140.632,
          2297.81,
          2448.8320000000003,
          2593.634,
          2732.2070000000003,
          2864.586,
          2990.847,
          3111.098,
          3225.47,
          3334.115,
          3437.2,
          3534.8990000000003,
          3627.397,
          3714.877,
          3797.526,
          3875.531,
          3949.072,
          4018.328,
          4083.473,
          4144.6759999999995,
          4202.1,
          4255.899,
          4306.225,
          4353.223,
          4397.037,
          4437.772,
          4475.582,
          4510.576,
          4542.869000000001,
          4572.568,
          4599.78,
          4624.599,
          4647.122,
          4667.436,
          4685.627,
          4701.776,
          4715.959,
          4728.251,
          4738.72,
          4747.434,
          4754.456,
          4759.846,
          4763.664000000001,
          4765.963,
          4766.795999999999,
          4766.214,
          4764.264,
          4760.995,
          4756.447,
          4750.665,
          4743.688,
          4735.556,
          4726.304,
          4715.968,
          4704.584,
          4692.183,
          4678.7970000000005,
          4664.455,
          4649.188,
          4633.022,
          4615.985,
          4598.102,
          4579.398,
          4559.897,
          4539.622,
          4518.595,
          4496.838,
          4474.371,
          4451.214,
          4427.3859999999995,
          4402.906,
          4377.792,
          4352.06,
          4325.729,
          4298.814,
          4271.331,
          4243.294,
          4214.719,
          4185.619000000001,
          4156.008,
          4125.901,
          4095.309,
          4064.245,
          4032.722,
          4000.7509999999997,
          3968.344,
          3935.512,
          3902.2659999999996,
          3868.615,
          3834.57,
          3800.1420000000003,
          3765.3390000000004,
          3730.172,
          3694.6490000000003,
          3658.7790000000005,
          3622.571,
          3586.033,
          3549.1740000000004,
          3512.0009999999997,
          3474.522,
          3436.745,
          3398.678,
          3360.3259999999996,
          3321.698,
          3282.801,
          3243.64,
          3204.223,
          3164.555,
          3124.6440000000002,
          3084.495,
          3044.114,
          3003.507,
          2962.68,
          2921.639,
          2880.388,
          2838.933,
          2797.2790000000005,
          2755.4309999999996,
          2713.395,
          2671.176,
          2628.777,
          2586.2039999999997,
          2543.462,
          2500.554,
          2457.486,
          2414.261,
          2370.883,
          2327.3579999999997,
          2283.689,
          2239.88,
          2195.935,
          2151.8579999999997,
          2107.653,
          2063.323,
          2018.8729999999998,
          1974.305,
          1929.6229999999998,
          1884.832,
          1839.933,
          1794.931,
          1749.828,
          1704.629,
          1659.336,
          1613.953,
          1568.4820000000002,
          1522.9270000000001,
          1477.2910000000002,
          1431.576,
          1385.786,
          1339.9229999999998,
          1293.99,
          1247.991,
          1201.927,
          1155.802,
          1109.619,
          1063.379,
          1017.085,
          970.7410000000001,
          924.3489999999999,
          877.91,
          831.429,
          784.9060000000001,
          738.345,
          691.748,
          645.117,
          598.455,
          551.764,
          505.046,
          458.30400000000003,
          411.54,
          364.755,
          317.953,
          271.135,
          224.304,
          177.46200000000002,
          130.61,
          83.751,
          36.887,
          -9.979,
          -56.847,
          -103.713,
          -150.577,
          -197.435,
          -244.28599999999997,
          -291.128,
          -337.959,
          -384.777,
          -431.58099999999996,
          -478.36699999999996,
          -525.135,
          -571.882,
          -618.607,
          -665.307,
          -711.982,
          -758.628,
          -805.2439999999999,
          -851.829,
          -898.38,
          -944.8960000000001,
          -991.375,
          -1037.816,
          -1084.215,
          -1130.572,
          -1176.885,
          -1223.152,
          -1269.371,
          -1315.5410000000002,
          -1361.66,
          -1407.726,
          -1453.737,
          -1499.691,
          -1545.588,
          -1591.424,
          -1637.1989999999998,
          -1682.911,
          -1728.558,
          -1774.138,
          -1819.649,
          -1865.0910000000001,
          -1910.46,
          -1955.756,
          -2000.977,
          -2046.121,
          -2091.186,
          -2136.17,
          -2181.073,
          -2225.891,
          -2270.624,
          -2315.27,
          -2359.827,
          -2404.2929999999997,
          -2448.667,
          -2492.946,
          -2537.13,
          -2581.216,
          -2625.202,
          -2669.0879999999997,
          -2712.8709999999996,
          -2756.5490000000004,
          -2800.12,
          -2843.5840000000003,
          -2886.938,
          -2930.18,
          -2973.309,
          -3016.322,
          -3059.219,
          -3101.9959999999996,
          -3144.653,
          -3187.188,
          -3229.598,
          -3271.882,
          -3314.038,
          -3356.0640000000003,
          -3397.9590000000003,
          -3439.72,
          -3481.345,
          -3522.833,
          -3564.1820000000002,
          -3605.389,
          -3646.453,
          -3687.373,
          -3728.145,
          -3768.768,
          -3809.24,
          -3849.559,
          -3889.723,
          -3929.73,
          -3969.578,
          -4009.264,
          -4048.788,
          -4088.1459999999997,
          -4127.335999999999,
          -4166.357,
          -4205.206,
          -4243.880999999999,
          -4282.38,
          -4320.7,
          -4358.84,
          -4396.7970000000005,
          -4434.569,
          -4472.154,
          -4509.549,
          -4546.751,
          -4583.759,
          -4620.57,
          -4657.182,
          -4693.592000000001,
          -4729.798,
          -4765.798,
          -4801.588,
          -4837.166,
          -4872.53,
          -4907.677,
          -4942.605,
          -4977.31,
          -5011.79,
          -5046.043,
          -5080.065,
          -5113.854,
          -5147.407,
          -5180.721,
          -5213.793,
          -5246.62,
          -5279.2,
          -5311.528,
          -5343.602,
          -5375.42,
          -5406.977,
          -5438.271,
          -5469.299,
          -5500.056,
          -5530.541,
          -5560.7480000000005,
          -5590.6759999999995,
          -5620.32,
          -5649.678000000001,
          -5678.744000000001,
          -5707.517,
          -5735.991999999999,
          -5764.165,
          -5792.031999999999,
          -5819.590999999999,
          -5846.835999999999,
          -5873.764,
          -5900.37,
          -5926.651,
          -5952.603,
          -5978.221,
          -6003.501,
          -6028.438,
          -6053.028,
          -6077.267,
          -6101.149,
          -6124.670999999999,
          -6147.826,
          -6170.611999999999,
          -6193.021,
          -6215.05,
          -6236.694,
          -6257.946999999999,
          -6278.803000000001,
          -6299.258000000001,
          -6319.305,
          -6338.939,
          -6358.155,
          -6376.946,
          -6395.306,
          -6413.23,
          -6430.710999999999,
          -6447.741999999999,
          -6464.318,
          -6480.432,
          -6496.076999999999,
          -6511.245,
          -6525.931,
          -6540.126,
          -6553.823,
          -6567.016,
          -6579.695,
          -6591.855,
          -6603.486,
          -6614.58,
          -6625.128000000001,
          -6635.1230000000005,
          -6644.555,
          -6653.416,
          -6661.696,
          -6669.3859999999995,
          -6676.477,
          -6682.9580000000005,
          -6688.819,
          -6694.05,
          -6698.64,
          -6702.579000000001,
          -6705.855,
          -6708.456999999999,
          -6710.3730000000005,
          -6711.590999999999,
          -6712.099,
          -6711.883000000001,
          -6710.932,
          -6709.232,
          -6706.768,
          -6703.526999999999,
          -6699.493,
          -6694.654,
          -6688.991,
          -6682.491999999999,
          -6675.138000000001,
          -6666.9130000000005,
          -6657.8,
          -6647.78,
          -6636.8369999999995,
          -6624.951,
          -6612.102,
          -6598.271,
          -6583.436,
          -6567.576999999999,
          -6550.672,
          -6532.696999999999,
          -6513.63,
          -6493.446,
          -6472.121,
          -6449.6269999999995,
          -6425.939,
          -6401.029,
          -6374.868,
          -6347.427,
          -6318.675,
          -6288.58,
          -6257.11,
          -6224.229,
          -6189.905,
          -6154.098000000001,
          -6116.771,
          -6077.8859999999995,
          -6037.4,
          -5995.272,
          -5951.4580000000005,
          -5905.911,
          -5858.585,
          -5809.43,
          -5758.393,
          -5705.424,
          -5650.464,
          -5593.456999999999,
          -5534.343000000001,
          -5473.061,
          -5409.543000000001,
          -5343.724,
          -5275.531999999999,
          -5204.897,
          -5131.741,
          -5055.988,
          -4977.553,
          -4896.355,
          -4812.305,
          -4725.312,
          -4635.284000000001,
          -4542.124,
          -4445.732,
          -4346.008,
          -4242.847,
          -4136.142,
          -4025.7870000000003,
          -3911.672,
          -3793.688,
          -3671.7270000000003,
          -3545.683,
          -3415.452,
          -3280.935,
          -3142.042,
          -2998.6890000000003,
          -2850.8070000000002,
          -2698.343,
          -2541.26,
          -2379.5460000000003,
          -2213.219,
          -2042.33,
          -1866.97,
          -1687.275,
          -1503.4289999999999,
          -1315.6779999999999,
          -1124.325,
          -929.7389999999999,
          -732.357,
          -532.678,
          -331.26800000000003,
          -128.746,
          74.223,
          276.936,
          478.675,
          678.715,
          876.3489999999999,
          1070.897,
          1261.729,
          1448.2720000000002,
          1630.02,
          1806.546,
          1977.4979999999998,
          2142.6,
          2301.653,
          2454.524,
          2601.145,
          2741.5009999999997,
          2875.6240000000003,
          3003.587,
          3125.494,
          3241.478,
          3351.688,
          3456.289,
          3555.4570000000003,
          3649.3759999999997,
          3738.23,
          3822.208,
          3901.494,
          3976.2729999999997,
          4046.725,
          4113.023,
          4175.338,
          4233.833,
          4288.666,
          4339.988,
          4387.945,
          4432.675,
          4474.31,
          4512.979,
          4548.8,
          4581.89,
          4612.358,
          4640.307,
          4665.839,
          4689.0470000000005,
          4710.022,
          4728.848,
          4745.608,
          4760.38,
          4773.237,
          4784.252,
          4793.4890000000005,
          4801.015,
          4806.89,
          4811.1720000000005,
          4813.918,
          4815.18,
          4815.01,
          4813.456,
          4810.565,
          4806.38,
          4800.945,
          4794.302,
          4786.487,
          4777.539000000001,
          4767.495,
          4756.388,
          4744.252,
          4731.117,
          4717.015,
          4701.975,
          4686.025,
          4669.193,
          4651.503,
          4632.982,
          4613.653,
          4593.54,
          4572.666,
          4551.0509999999995,
          4528.717000000001,
          4505.683,
          4481.97,
          4457.595,
          4432.5779999999995,
          4406.935,
          4380.684,
          4353.840999999999,
          4326.420999999999,
          4298.44,
          4269.913,
          4240.855,
          4211.278,
          4181.198,
          4150.626,
          4119.575,
          4088.058,
          4056.087,
          4023.672,
          3990.827,
          3957.56,
          3923.884,
          3889.808,
          3855.343,
          3820.4970000000003,
          3785.281,
          3749.704,
          3713.7740000000003,
          3677.5009999999997,
          3640.893,
          3603.958,
          3566.704,
          3529.14,
          3491.2729999999997,
          3453.11,
          3414.659,
          3375.926,
          3336.92,
          3297.6459999999997,
          3258.111,
          3218.321,
          3178.283,
          3138.0040000000004,
          3097.488,
          3056.742,
          3015.7729999999997,
          2974.5840000000003,
          2933.1820000000002,
          2891.573,
          2849.761,
          2807.752,
          2765.55,
          2723.1620000000003,
          2680.59,
          2637.841,
          2594.919,
          2551.8289999999997,
          2508.574,
          2465.16,
          2421.591,
          2377.87,
          2334.002,
          2289.992,
          2245.842,
          2201.558,
          2157.1420000000003,
          2112.599,
          2067.931,
          2023.144,
          1978.241,
          1933.224,
          1888.098,
          1842.866,
          1797.531,
          1752.0970000000002,
          1706.566,
          1660.942,
          1615.229,
          1569.4289999999999,
          1523.545,
          1477.58,
          1431.537,
          1385.42,
          1339.23,
          1292.972,
          1246.647,
          1200.259,
          1153.809,
          1107.302,
          1060.738,
          1014.122,
          967.456,
          920.7410000000001,
          873.982,
          827.179,
          780.337,
          733.456,
          686.54,
          639.59,
          592.61,
          545.601,
          498.566,
          451.50699999999995,
          404.426,
          357.32599999999996,
          310.209,
          263.07599999999996,
          215.93099999999998,
          168.774,
          121.609,
          74.438,
          27.261999999999997,
          -19.917,
          -67.096,
          -114.273,
          -161.446,
          -208.614,
          -255.774,
          -302.925,
          -350.064,
          -397.189,
          -444.3,
          -491.392,
          -538.466,
          -585.518,
          -632.547,
          -679.552,
          -726.529,
          -773.4780000000001,
          -820.3969999999999,
          -867.283,
          -914.1360000000001,
          -960.952,
          -1007.73,
          -1054.469,
          -1101.167,
          -1147.822,
          -1194.431,
          -1240.995,
          -1287.509,
          -1333.974,
          -1380.386,
          -1426.745,
          -1473.049,
          -1519.295,
          -1565.4820000000002,
          -1611.609,
          -1657.6729999999998,
          -1703.6729999999998,
          -1749.608,
          -1795.474,
          -1841.2720000000002,
          -1886.9979999999998,
          -1932.652,
          -1978.231,
          -2023.734,
          -2069.159,
          -2114.504,
          -2159.768,
          -2204.949,
          -2250.045,
          -2295.055,
          -2339.976,
          -2384.8070000000002,
          -2429.547,
          -2474.192,
          -2518.743,
          -2563.197,
          -2607.552,
          -2651.8059999999996,
          -2695.958,
          -2740.006,
          -2783.949,
          -2827.784,
          -2871.509,
          -2915.123,
          -2958.625,
          -3002.011,
          -3045.281,
          -3088.433,
          -3131.4640000000004,
          -3174.373,
          -3217.159,
          -3259.8179999999998,
          -3302.35,
          -3344.7529999999997,
          -3387.0240000000003,
          -3429.1620000000003,
          -3471.165,
          -3513.031,
          -3554.758,
          -3596.344,
          -3637.7870000000003,
          -3679.085,
          -3720.236,
          -3761.239,
          -3802.091,
          -3842.79,
          -3883.3340000000003,
          -3923.7209999999995,
          -3963.949,
          -4004.0159999999996,
          -4043.92,
          -4083.659,
          -4123.231,
          -4162.633,
          -4201.863,
          -4240.919,
          -4279.8,
          -4318.502,
          -4357.023,
          -4395.361,
          -4433.515,
          -4471.48,
          -4509.255999999999,
          -4546.84,
          -4584.23,
          -4621.4220000000005,
          -4658.415,
          -4695.206,
          -4731.793,
          -4768.173,
          -4804.344,
          -4840.303,
          -4876.0470000000005,
          -4911.5740000000005,
          -4946.8820000000005,
          -4981.965999999999,
          -5016.826,
          -5051.458,
          -5085.859,
          -5120.027,
          -5153.958,
          -5187.65,
          -5221.099,
          -5254.304,
          -5287.26,
          -5319.965,
          -5352.415,
          -5384.608,
          -5416.541,
          -5448.21,
          -5479.611,
          -5510.743,
          -5541.6,
          -5572.181,
          -5602.481,
          -5632.496999999999,
          -5662.225,
          -5691.661999999999,
          -5720.804,
          -5749.648,
          -5778.189,
          -5806.424,
          -5834.349,
          -5861.96,
          -5889.254,
          -5916.225,
          -5942.869000000001,
          -5969.184,
          -5995.164000000001,
          -6020.805,
          -6046.103,
          -6071.052,
          -6095.649,
          -6119.888000000001,
          -6143.766,
          -6167.276999999999,
          -6190.4169999999995,
          -6213.179,
          -6235.56,
          -6257.555,
          -6279.156999999999,
          -6300.361999999999,
          -6321.164000000001,
          -6341.557,
          -6361.535,
          -6381.094,
          -6400.227,
          -6418.928000000001,
          -6437.19,
          -6455.009,
          -6472.376,
          -6489.286999999999,
          -6505.734,
          -6521.71,
          -6537.2080000000005,
          -6552.221,
          -6566.743,
          -6580.765,
          -6594.28,
          -6607.281,
          -6619.759,
          -6631.706999999999,
          -6643.116,
          -6653.978,
          -6664.283,
          -6674.025,
          -6683.191999999999,
          -6691.776,
          -6699.769,
          -6707.159000000001,
          -6713.938,
          -6720.094,
          -6725.616999999999,
          -6730.4980000000005,
          -6734.724,
          -6738.284000000001,
          -6741.168000000001,
          -6743.3640000000005,
          -6744.859,
          -6745.64,
          -6745.695,
          -6745.0109999999995,
          -6743.575,
          -6741.371999999999,
          -6738.389,
          -6734.61,
          -6730.021,
          -6724.606,
          -6718.351,
          -6711.236999999999,
          -6703.2480000000005,
          -6694.366999999999,
          -6684.576,
          -6673.857,
          -6662.191999999999,
          -6649.558000000001,
          -6635.938,
          -6621.31,
          -6605.654,
          -6588.946,
          -6571.164000000001,
          -6552.284000000001,
          -6532.281999999999,
          -6511.134,
          -6488.812,
          -6465.29,
          -6440.54,
          -6414.534000000001,
          -6387.241,
          -6358.630999999999,
          -6328.670999999999,
          -6297.33,
          -6264.571999999999,
          -6230.361999999999,
          -6194.6630000000005,
          -6157.437,
          -6118.645,
          -6078.244000000001,
          -6036.191999999999,
          -5992.446999999999,
          -5946.96,
          -5899.684,
          -5850.57,
          -5799.565,
          -5746.616999999999,
          -5691.669,
          -5634.664000000001,
          -5575.54,
          -5514.236,
          -5450.686,
          -5384.821999999999,
          -5316.573,
          -5245.866999999999,
          -5172.627,
          -5096.775,
          -5018.227,
          -4936.901,
          -4852.707,
          -4765.553,
          -4675.348,
          -4581.992,
          -4485.385,
          -4385.427,
          -4282.0109999999995,
          -4175.03,
          -4064.375,
          -3949.938,
          -3831.607,
          -3709.2729999999997,
          -3582.828,
          -3452.167,
          -3317.191,
          -3177.805,
          -3033.925,
          -2885.4809999999998,
          -2732.415,
          -2574.69,
          -2412.291,
          -2245.234,
          -2073.5660000000003,
          -1897.375,
          -1716.795,
          -1532.007,
          -1343.253,
          -1150.8339999999998,
          -955.118,
          -756.5369999999999,
          -555.591,
          -352.844,
          -148.915,
          55.528,
          259.781,
          463.119,
          664.817,
          864.1569999999999,
          1060.455,
          1253.0710000000001,
          1441.4229999999998,
          1624.9979999999998,
          1803.359,
          1976.146,
          2143.075,
          2303.94,
          2458.6020000000003,
          2606.986,
          2749.073,
          2884.89,
          3014.51,
          3138.032,
          3255.587,
          3367.324,
          3473.408,
          3574.013,
          3669.324,
          3759.526,
          3844.8059999999996,
          3925.3520000000003,
          4001.348,
          4072.974,
          4140.407,
          4203.816,
          4263.369000000001,
          4319.22,
          4371.527,
          4420.433,
          4466.0779999999995,
          4508.596,
          4548.116,
          4584.758,
          4618.64,
          4649.872,
          4678.557,
          4704.799,
          4728.691,
          4750.325,
          4769.787,
          4787.159000000001,
          4802.522,
          4815.948,
          4827.51,
          4837.275,
          4845.309,
          4851.673,
          4856.4259999999995,
          4859.624,
          4861.323,
          4861.572,
          4860.42,
          4857.916,
          4854.103,
          4849.025,
          4842.724,
          4835.238,
          4826.605,
          4816.862,
          4806.044,
          4794.184,
          4781.313,
          4767.463,
          4752.664000000001,
          4736.943,
          4720.329000000001,
          4702.847,
          4684.522,
          4665.38,
          4645.444,
          4624.737,
          4603.28,
          4581.094,
          4558.1990000000005,
          4534.616,
          4510.363,
          4485.459,
          4459.9220000000005,
          4433.768,
          4407.013,
          4379.675,
          4351.768,
          4323.307,
          4294.307,
          4264.782999999999,
          4234.747,
          4204.214,
          4173.195,
          4141.7029999999995,
          4109.75,
          4077.348,
          4044.508,
          4011.241,
          3977.559,
          3943.472,
          3908.989,
          3874.12,
          3838.875,
          3803.264,
          3767.295,
          3730.9770000000003,
          3694.3190000000004,
          3657.33,
          3620.0170000000003,
          3582.388,
          3544.4509999999996,
          3506.2140000000004,
          3467.685,
          3428.869,
          3389.775,
          3350.409,
          3310.778,
          3270.888,
          3230.745,
          3190.357,
          3149.728,
          3108.866,
          3067.776,
          3026.462,
          2984.9320000000002,
          2943.191,
          2901.243,
          2859.095,
          2816.7509999999997,
          2774.215,
          2731.494,
          2688.592,
          2645.513,
          2602.263,
          2558.845,
          2515.265,
          2471.526,
          2427.633,
          2383.589,
          2339.4,
          2295.069,
          2250.599,
          2205.996,
          2161.262,
          2116.402,
          2071.419,
          2026.317,
          1981.099,
          1935.769,
          1890.33,
          1844.786,
          1799.139,
          1753.394,
          1707.5539999999999,
          1661.621,
          1615.599,
          1569.491,
          1523.3,
          1477.029,
          1430.68,
          1384.2579999999998,
          1337.764,
          1291.201,
          1244.573,
          1197.881,
          1151.13,
          1104.32,
          1057.4560000000001,
          1010.539,
          963.573,
          916.559,
          869.5,
          822.3989999999999,
          775.258,
          728.08,
          680.867,
          633.621,
          586.345,
          539.0409999999999,
          491.711,
          444.35699999999997,
          396.983,
          349.589,
          302.17900000000003,
          254.75400000000002,
          207.317,
          159.869,
          112.413,
          64.952,
          17.486,
          -29.982,
          -77.449,
          -124.915,
          -172.37599999999998,
          -219.831,
          -267.278,
          -314.714,
          -362.139,
          -409.54900000000004,
          -456.944,
          -504.32,
          -551.677,
          -599.012,
          -646.323,
          -693.6089999999999,
          -740.868,
          -788.097,
          -835.295,
          -882.46,
          -929.591,
          -976.685,
          -1023.7410000000001,
          -1070.756,
          -1117.729,
          -1164.6589999999999,
          -1211.5430000000001,
          -1258.38,
          -1305.1680000000001,
          -1351.905,
          -1398.589,
          -1445.2179999999998,
          -1491.7920000000001,
          -1538.308,
          -1584.763,
          -1631.158,
          -1677.489,
          -1723.756,
          -1769.955,
          -1816.0870000000002,
          -1862.148,
          -1908.1370000000002,
          -1954.0529999999999,
          -1999.8929999999998,
          -2045.656,
          -2091.34,
          -2136.944,
          -2182.466,
          -2227.903,
          -2273.254,
          -2318.518,
          -2363.6929999999998,
          -2408.777,
          -2453.768,
          -2498.6639999999998,
          -2543.464,
          -2588.166,
          -2632.768,
          -2677.268,
          -2721.665,
          -2765.9570000000003,
          -2810.1420000000003,
          -2854.218,
          -2898.184,
          -2942.0370000000003,
          -2985.776,
          -3029.3990000000003,
          -3072.9040000000005,
          -3116.29,
          -3159.554,
          -3202.6940000000004,
          -3245.7090000000003,
          -3288.597,
          -3331.3559999999998,
          -3373.985,
          -3416.48,
          -3458.841,
          -3501.0640000000003,
          -3543.15,
          -3585.095,
          -3626.897,
          -3668.555,
          -3710.066,
          -3751.429,
          -3792.6409999999996,
          -3833.7009999999996,
          -3874.607,
          -3915.355,
          -3955.945,
          -3996.3740000000003,
          -4036.6409999999996,
          -4076.742,
          -4116.6759999999995,
          -4156.441,
          -4196.034000000001,
          -4235.4529999999995,
          -4274.697,
          -4313.763,
          -4352.648,
          -4391.35,
          -4429.867,
          -4468.197,
          -4506.337,
          -4544.285,
          -4582.039000000001,
          -4619.595,
          -4656.9529999999995,
          -4694.108,
          -4731.059,
          -4767.804,
          -4804.339,
          -4840.662,
          -4876.77,
          -4912.661,
          -4948.333,
          -4983.781,
          -5019.005,
          -5054,
          -5088.765,
          -5123.295999999999,
          -5157.59,
          -5191.645,
          -5225.457,
          -5259.024,
          -5292.342,
          -5325.409000000001,
          -5358.222,
          -5390.776,
          -5423.07,
          -5455.099,
          -5486.861,
          -5518.353,
          -5549.57,
          -5580.51,
          -5611.169,
          -5641.543000000001,
          -5671.63,
          -5701.425,
          -5730.924,
          -5760.124,
          -5789.022,
          -5817.611999999999,
          -5845.893,
          -5873.858,
          -5901.505,
          -5928.829000000001,
          -5955.826999999999,
          -5982.493,
          -6008.8240000000005,
          -6034.815,
          -6060.463000000001,
          -6085.7609999999995,
          -6110.706,
          -6135.294,
          -6159.519,
          -6183.375,
          -6206.86,
          -6229.967,
          -6252.691,
          -6275.026999999999,
          -6296.971,
          -6318.515,
          -6339.656,
          -6360.387,
          -6380.704000000001,
          -6400.599,
          -6420.066999999999,
          -6439.101,
          -6457.696,
          -6475.846,
          -6493.544,
          -6510.783,
          -6527.557,
          -6543.859,
          -6559.681,
          -6575.018,
          -6589.861999999999,
          -6604.205,
          -6618.039000000001,
          -6631.356,
          -6644.15,
          -6656.411999999999,
          -6668.133000000001,
          -6679.306,
          -6689.920999999999,
          -6699.969,
          -6709.441,
          -6718.329000000001,
          -6726.6230000000005,
          -6734.312,
          -6741.388000000001,
          -6747.84,
          -6753.656,
          -6758.826999999999,
          -6763.342,
          -6767.189,
          -6770.357,
          -6772.834,
          -6774.608,
          -6775.665,
          -6775.994000000001,
          -6775.581999999999,
          -6774.414000000001,
          -6772.477,
          -6769.757,
          -6766.238,
          -6761.906,
          -6756.745,
          -6750.74,
          -6743.874,
          -6736.129,
          -6727.4890000000005,
          -6717.935,
          -6707.45,
          -6696.014,
          -6683.607,
          -6670.209,
          -6655.8,
          -6640.358,
          -6623.86,
          -6606.283,
          -6587.605,
          -6567.8009999999995,
          -6546.844,
          -6524.709,
          -6501.369000000001,
          -6476.797,
          -6450.9619999999995,
          -6423.835999999999,
          -6395.387,
          -6365.5830000000005,
          -6334.391,
          -6301.776999999999,
          -6267.704000000001,
          -6232.1359999999995,
          -6195.034000000001,
          -6156.359,
          -6116.069,
          -6074.121,
          -6030.47,
          -5985.071999999999,
          -5937.876,
          -5888.834,
          -5837.893,
          -5784.999,
          -5730.097,
          -5673.1269999999995,
          -5614.03,
          -5552.741,
          -5489.196999999999,
          -5423.326999999999,
          -5355.062,
          -5284.326999999999,
          -5211.048,
          -5135.143,
          -5056.529,
          -4975.122,
          -4890.834,
          -4803.571,
          -4713.241,
          -4619.744000000001,
          -4522.981,
          -4422.846,
          -4319.236,
          -4212.042,
          -4101.154,
          -3986.461,
          -3867.8509999999997,
          -3745.216,
          -3618.4429999999998,
          -3487.428,
          -3352.07,
          -3212.2709999999997,
          -3067.948,
          -2919.028,
          -2765.448,
          -2607.172,
          -2444.181,
          -2276.489,
          -2104.14,
          -1927.2179999999998,
          -1745.855,
          -1560.229,
          -1370.578,
          -1177.201,
          -980.462,
          -780.791,
          -578.687,
          -374.712,
          -169.486,
          36.323,
          242.00900000000001,
          446.845,
          650.0980000000001,
          851.046,
          1048.998,
          1243.306,
          1433.38,
          1618.6979999999999,
          1798.815,
          1973.361,
          2142.0460000000003,
          2304.655,
          2461.044,
          2611.131,
          2754.893,
          2892.353,
          3023.579,
          3148.67,
          3267.7529999999997,
          3380.978,
          3488.506,
          3590.514,
          3687.184,
          3778.703,
          3865.258,
          3947.0370000000003,
          4024.2259999999997,
          4097.005,
          4165.552,
          4230.038,
          4290.63,
          4347.486,
          4400.762,
          4450.605,
          4497.138,
          4540.545999999999,
          4580.907999999999,
          4618.365,
          4653.031,
          4685.02,
          4714.438,
          4741.3859999999995,
          4765.96,
          4788.251,
          4808.348,
          4826.333,
          4842.287,
          4856.284000000001,
          4868.396,
          4878.692,
          4887.237,
          4894.095,
          4899.3240000000005,
          4902.981,
          4905.122,
          4905.795999999999,
          4905.055,
          4902.946,
          4899.514,
          4894.802,
          4888.852,
          4881.705,
          4873.397,
          4863.967000000001,
          4853.448,
          4841.876,
          4829.281,
          4815.696,
          4801.15,
          4785.6720000000005,
          4769.289000000001,
          4752.028,
          4733.915,
          4714.974,
          4695.23,
          4674.705,
          4653.42,
          4631.398,
          4608.659000000001,
          4585.222,
          4561.108,
          4536.334,
          4510.919,
          4484.878,
          4458.23,
          4430.991,
          4403.1759999999995,
          4374.8,
          4345.878,
          4316.424,
          4286.452,
          4255.975,
          4225.005999999999,
          4193.558,
          4161.643,
          4129.273,
          4096.46,
          4063.2140000000004,
          4029.545,
          3995.466,
          3960.986,
          3926.114,
          3890.862,
          3855.237,
          3819.25,
          3782.909,
          3746.223,
          3709.2009999999996,
          3671.849,
          3634.178,
          3596.1929999999998,
          3557.9040000000005,
          3519.3179999999998,
          3480.441,
          3441.281,
          3401.845,
          3362.14,
          3322.172,
          3281.947,
          3241.473,
          3200.7540000000004,
          3159.798,
          3118.61,
          3077.195,
          3035.56,
          2993.71,
          2951.65,
          2909.385,
          2866.921,
          2824.263,
          2781.415,
          2738.383,
          2695.172,
          2651.785,
          2608.228,
          2564.504,
          2520.619,
          2476.577,
          2432.382,
          2388.038,
          2343.548,
          2298.9179999999997,
          2254.152,
          2209.252,
          2164.222,
          2119.067,
          2073.79,
          2028.395,
          1982.885,
          1937.264,
          1891.535,
          1845.701,
          1799.767,
          1753.734,
          1707.606,
          1661.3870000000002,
          1615.08,
          1568.6860000000001,
          1522.211,
          1475.656,
          1429.025,
          1382.32,
          1335.5439999999999,
          1288.701,
          1241.792,
          1194.82,
          1147.789,
          1100.701,
          1053.559,
          1006.365,
          959.1210000000001,
          911.831,
          864.4960000000001,
          817.12,
          769.704,
          722.252,
          674.765,
          627.246,
          579.697,
          532.121,
          484.519,
          436.895,
          389.25,
          341.586,
          293.907,
          246.213,
          198.507,
          150.791,
          103.068,
          55.34,
          7.608,
          -40.126,
          -87.859,
          -135.589,
          -183.31400000000002,
          -231.033,
          -278.743,
          -326.442,
          -374.129,
          -421.801,
          -469.45599999999996,
          -517.0930000000001,
          -564.7090000000001,
          -612.303,
          -659.873,
          -707.4169999999999,
          -754.933,
          -802.419,
          -849.8739999999999,
          -897.295,
          -944.68,
          -992.029,
          -1039.338,
          -1086.607,
          -1133.833,
          -1181.014,
          -1228.149,
          -1275.237,
          -1322.274,
          -1369.26,
          -1416.192,
          -1463.07,
          -1509.89,
          -1556.652,
          -1603.3529999999998,
          -1649.993,
          -1696.568,
          -1743.0770000000002,
          -1789.52,
          -1835.892,
          -1882.194,
          -1928.4229999999998,
          -1974.578,
          -2020.6570000000002,
          -2066.657,
          -2112.578,
          -2158.417,
          -2204.173,
          -2249.845,
          -2295.429,
          -2340.925,
          -2386.33,
          -2431.644,
          -2476.863,
          -2521.987,
          -2567.014,
          -2611.942,
          -2656.7690000000002,
          -2701.493,
          -2746.112,
          -2790.625,
          -2835.03,
          -2879.3259999999996,
          -2923.509,
          -2967.579,
          -3011.533,
          -3055.3709999999996,
          -3099.0890000000004,
          -3142.6859999999997,
          -3186.16,
          -3229.51,
          -3272.7329999999997,
          -3315.827,
          -3358.792,
          -3401.6240000000003,
          -3444.321,
          -3486.883,
          -3529.3059999999996,
          -3571.5890000000004,
          -3613.7309999999998,
          -3655.728,
          -3697.579,
          -3739.282,
          -3780.835,
          -3822.236,
          -3863.4829999999997,
          -3904.574,
          -3945.506,
          -3986.278,
          -4026.887,
          -4067.3309999999997,
          -4107.609,
          -4147.717000000001,
          -4187.655,
          -4227.418,
          -4267.005999999999,
          -4306.417,
          -4345.647,
          -4384.694,
          -4423.557,
          -4462.232,
          -4500.718,
          -4539.012,
          -4577.112,
          -4615.015,
          -4652.719,
          -4690.221,
          -4727.519,
          -4764.611,
          -4801.4929999999995,
          -4838.163,
          -4874.619000000001,
          -4910.858,
          -4946.876,
          -4982.6720000000005,
          -5018.2429999999995,
          -5053.585999999999,
          -5088.698,
          -5123.576,
          -5158.217000000001,
          -5192.619000000001,
          -5226.778,
          -5260.691999999999,
          -5294.357,
          -5327.771,
          -5360.931,
          -5393.831999999999,
          -5426.472,
          -5458.848000000001,
          -5490.956,
          -5522.793000000001,
          -5554.356,
          -5585.641,
          -5616.645,
          -5647.365,
          -5677.795,
          -5707.934,
          -5737.778,
          -5767.321999999999,
          -5796.562,
          -5825.496,
          -5854.119000000001,
          -5882.427,
          -5910.416,
          -5938.081999999999,
          -5965.42,
          -5992.427,
          -6019.098000000001,
          -6045.428000000001,
          -6071.414000000001,
          -6097.0509999999995,
          -6122.334,
          -6147.258000000001,
          -6171.82,
          -6196.013000000001,
          -6219.831999999999,
          -6243.274,
          -6266.331999999999,
          -6289.001,
          -6311.276999999999,
          -6333.154,
          -6354.625,
          -6375.686,
          -6396.331,
          -6416.555,
          -6436.35,
          -6455.7119999999995,
          -6474.632,
          -6493.107,
          -6511.128000000001,
          -6528.689,
          -6545.785,
          -6562.406999999999,
          -6578.549,
          -6594.204000000001,
          -6609.365,
          -6624.023,
          -6638.172,
          -6651.803000000001,
          -6664.908,
          -6677.481,
          -6689.5109999999995,
          -6700.991,
          -6711.9130000000005,
          -6722.266,
          -6732.0419999999995,
          -6741.231,
          -6749.825,
          -6757.813,
          -6765.185,
          -6771.932,
          -6778.0419999999995,
          -6783.504,
          -6788.308000000001,
          -6792.443,
          -6795.896,
          -6798.656999999999,
          -6800.7119999999995,
          -6802.05,
          -6802.656,
          -6802.518,
          -6801.6230000000005,
          -6799.956,
          -6797.504,
          -6794.251,
          -6790.181,
          -6785.281,
          -6779.533,
          -6772.922,
          -6765.429,
          -6757.0380000000005,
          -6747.73,
          -6737.488,
          -6726.2919999999995,
          -6714.121,
          -6700.956999999999,
          -6686.776999999999,
          -6671.562,
          -6655.286,
          -6637.929,
          -6619.465,
          -6599.871999999999,
          -6579.1230000000005,
          -6557.191,
          -6534.05,
          -6509.672,
          -6484.028,
          -6457.085999999999,
          -6428.819,
          -6399.19,
          -6368.168000000001,
          -6335.719,
          -6301.807,
          -6266.393,
          -6229.44,
          -6190.906999999999,
          -6150.753000000001,
          -6108.936,
          -6065.409000000001,
          -6020.1269999999995,
          -5973.0419999999995,
          -5924.102,
          -5873.257,
          -5820.45,
          -5765.628000000001,
          -5708.73,
          -5649.696,
          -5588.460999999999,
          -5524.9619999999995,
          -5459.1269999999995,
          -5390.888000000001,
          -5320.168000000001,
          -5246.893,
          -5170.981,
          -5092.348,
          -5010.912,
          -4926.58,
          -4839.2609999999995,
          -4748.861,
          -4655.28,
          -4558.417,
          -4458.167,
          -4354.425,
          -4247.081,
          -4136.025,
          -4021.145,
          -3902.328,
          -3779.4640000000004,
          -3652.4390000000003,
          -3521.1479999999997,
          -3385.488,
          -3245.36,
          -3100.679,
          -2951.369,
          -2797.367,
          -2638.632,
          -2475.145,
          -2306.915,
          -2133.985,
          -1956.4360000000001,
          -1774.395,
          -1588.0379999999998,
          -1397.599,
          -1203.375,
          -1005.7239999999999,
          -805.076,
          -601.928,
          -396.837,
          -190.426,
          16.637999999999998,
          223.64700000000002,
          429.871,
          634.573,
          837.0269999999999,
          1036.5339999999999,
          1232.438,
          1424.141,
          1611.114,
          1792.902,
          1969.1270000000002,
          2139.493,
          2303.774,
          2461.822,
          2613.548,
          2758.925,
          2897.972,
          3030.7509999999997,
          3157.362,
          3277.927,
          3392.595,
          3501.528,
          3604.9,
          3702.8940000000002,
          3795.697,
          3883.4970000000003,
          3966.482,
          4044.837,
          4118.745,
          4188.384,
          4253.9259999999995,
          4315.539000000001,
          4373.383,
          4427.613,
          4478.378,
          4525.819,
          4570.072,
          4611.267,
          4649.528,
          4684.972,
          4717.714,
          4747.857,
          4775.5070000000005,
          4800.759,
          4823.706,
          4844.436,
          4863.034000000001,
          4879.5779999999995,
          4894.147,
          4906.811,
          4917.641,
          4926.702,
          4934.057,
          4939.767,
          4943.888,
          4946.476,
          4947.584,
          4947.26,
          4945.554,
          4942.51,
          4938.173,
          4932.584,
          4925.785,
          4917.813,
          4908.706,
          4898.499,
          4887.226,
          4874.919,
          4861.611,
          4847.331,
          4832.109,
          4815.971,
          4798.945,
          4781.058,
          4762.333,
          4742.795999999999,
          4722.468,
          4701.372,
          4679.53,
          4656.962,
          4633.689,
          4609.73,
          4585.103,
          4559.827,
          4533.919,
          4507.395,
          4480.272,
          4452.567,
          4424.295,
          4395.469,
          4366.104,
          4336.215,
          4305.815,
          4274.916,
          4243.532,
          4211.675,
          4179.357,
          4146.59,
          4113.384,
          4079.7509999999997,
          4045.7009999999996,
          4011.245,
          3976.3920000000003,
          3941.153,
          3905.5359999999996,
          3869.552,
          3833.21,
          3796.5170000000003,
          3759.4840000000004,
          3722.116,
          3684.4240000000004,
          3646.415,
          3608.0959999999995,
          3569.475,
          3530.56,
          3491.3579999999997,
          3451.875,
          3412.119,
          3372.0959999999995,
          3331.812,
          3291.275,
          3250.49,
          3209.4629999999997,
          3168.2009999999996,
          3126.708,
          3084.992,
          3043.0559999999996,
          3000.907,
          2958.551,
          2915.991,
          2873.2340000000004,
          2830.284,
          2787.147,
          2743.8259999999996,
          2700.327,
          2656.655,
          2612.814,
          2568.8070000000002,
          2524.641,
          2480.319,
          2435.844,
          2391.222,
          2346.456,
          2301.551,
          2256.509,
          2211.3360000000002,
          2166.034,
          2120.6079999999997,
          2075.06,
          2029.396,
          1983.6170000000002,
          1937.7279999999998,
          1891.7320000000002,
          1845.6329999999998,
          1799.433,
          1753.136,
          1706.745,
          1660.263,
          1613.693,
          1567.039,
          1520.3029999999999,
          1473.4879999999998,
          1426.5970000000002,
          1379.634,
          1332.6,
          1285.499,
          1238.3339999999998,
          1191.107,
          1143.82,
          1096.478,
          1049.0810000000001,
          1001.633,
          954.137,
          906.5939999999999,
          859.008,
          811.3810000000001,
          763.715,
          716.012,
          668.2760000000001,
          620.508,
          572.711,
          524.886,
          477.038,
          429.166,
          381.275,
          333.366,
          285.441,
          237.503,
          189.553,
          141.594,
          93.62700000000001,
          45.656000000000006,
          -2.318,
          -50.293,
          -98.26700000000001,
          -146.237,
          -194.202,
          -242.16,
          -290.10900000000004,
          -338.04699999999997,
          -385.971,
          -433.88,
          -481.772,
          -529.645,
          -577.497,
          -625.326,
          -673.13,
          -720.908,
          -768.6569999999999,
          -816.375,
          -864.062,
          -911.7139999999999,
          -959.331,
          -1006.909,
          -1054.448,
          -1101.9460000000001,
          -1149.4,
          -1196.809,
          -1244.171,
          -1291.485,
          -1338.7479999999998,
          -1385.9589999999998,
          -1433.115,
          -1480.2160000000001,
          -1527.26,
          -1574.244,
          -1621.1660000000002,
          -1668.026,
          -1714.8210000000001,
          -1761.55,
          -1808.211,
          -1854.8010000000002,
          -1901.32,
          -1947.765,
          -1994.135,
          -2040.4279999999999,
          -2086.6420000000003,
          -2132.776,
          -2178.827,
          -2224.794,
          -2270.675,
          -2316.469,
          -2362.173,
          -2407.786,
          -2453.306,
          -2498.731,
          -2544.0589999999997,
          -2589.29,
          -2634.42,
          -2679.448,
          -2724.3720000000003,
          -2769.191,
          -2813.903,
          -2858.505,
          -2902.9959999999996,
          -2947.375,
          -2991.638,
          -3035.785,
          -3079.8140000000003,
          -3123.722,
          -3167.509,
          -3211.171,
          -3254.7070000000003,
          -3298.115,
          -3341.3940000000002,
          -3384.5409999999997,
          -3427.554,
          -3470.4309999999996,
          -3513.171,
          -3555.772,
          -3598.2309999999998,
          -3640.546,
          -3682.716,
          -3724.739,
          -3766.612,
          -3808.333,
          -3849.901,
          -3891.312,
          -3932.566,
          -3973.66,
          -4014.592,
          -4055.36,
          -4095.96,
          -4136.393,
          -4176.654,
          -4216.7429999999995,
          -4256.656,
          -4296.391,
          -4335.947,
          -4375.321,
          -4414.51,
          -4453.512,
          -4492.325,
          -4530.946,
          -4569.374,
          -4607.605,
          -4645.637,
          -4683.467000000001,
          -4721.094,
          -4758.514,
          -4795.725,
          -4832.725,
          -4869.51,
          -4906.0779999999995,
          -4942.4259999999995,
          -4978.552,
          -5014.4529999999995,
          -5050.126,
          -5085.568,
          -5120.776,
          -5155.748,
          -5190.481,
          -5224.971,
          -5259.215999999999,
          -5293.213000000001,
          -5326.9580000000005,
          -5360.448,
          -5393.68,
          -5426.651,
          -5459.357,
          -5491.795999999999,
          -5523.965,
          -5555.858,
          -5587.474,
          -5618.809,
          -5649.859,
          -5680.62,
          -5711.09,
          -5741.264,
          -5771.138000000001,
          -5800.7080000000005,
          -5829.971,
          -5858.924,
          -5887.561,
          -5915.879,
          -5943.8730000000005,
          -5971.54,
          -5998.875,
          -6025.874,
          -6052.531999999999,
          -6078.846,
          -6104.81,
          -6130.42,
          -6155.67,
          -6180.557,
          -6205.075,
          -6229.22,
          -6252.986,
          -6276.368,
          -6299.361,
          -6321.96,
          -6344.16,
          -6365.953,
          -6387.335999999999,
          -6408.302,
          -6428.845,
          -6448.96,
          -6468.639,
          -6487.878000000001,
          -6506.670999999999,
          -6525.008000000001,
          -6542.8859999999995,
          -6560.297,
          -6577.234,
          -6593.689,
          -6609.656999999999,
          -6625.129,
          -6640.098000000001,
          -6654.556,
          -6668.496999999999,
          -6681.911,
          -6694.79,
          -6707.126,
          -6718.911,
          -6730.135,
          -6740.791,
          -6750.868,
          -6760.358,
          -6769.25,
          -6777.536,
          -6785.204000000001,
          -6792.245,
          -6798.649,
          -6804.403,
          -6809.4980000000005,
          -6813.920999999999,
          -6817.661999999999,
          -6820.7080000000005,
          -6823.047,
          -6824.6669999999995,
          -6825.554,
          -6825.695,
          -6825.076,
          -6823.684,
          -6821.505,
          -6818.523,
          -6814.722,
          -6810.088000000001,
          -6804.606,
          -6798.255999999999,
          -6791.023,
          -6782.889,
          -6773.8369999999995,
          -6763.848000000001,
          -6752.901,
          -6740.978,
          -6728.058000000001,
          -6714.121,
          -6699.143,
          -6683.104,
          -6665.98,
          -6647.746,
          -6628.379,
          -6607.852,
          -6586.14,
          -6563.215,
          -6539.049,
          -6513.6140000000005,
          -6486.878000000001,
          -6458.809,
          -6429.378000000001,
          -6398.549,
          -6366.286999999999,
          -6332.558000000001,
          -6297.323,
          -6260.543000000001,
          -6222.18,
          -6182.19,
          -6140.531,
          -6097.156999999999,
          -6052.022,
          -6005.078,
          -5956.273,
          -5905.557,
          -5852.8730000000005,
          -5798.166,
          -5741.376,
          -5682.443,
          -5621.303000000001,
          -5557.888000000001,
          -5492.132,
          -5423.960999999999,
          -5353.303000000001,
          -5280.078,
          -5204.207,
          -5125.607,
          -5044.192,
          -4959.87,
          -4872.55,
          -4782.137,
          -4688.53,
          -4591.629,
          -4491.327,
          -4387.517,
          -4280.090999999999,
          -4168.937,
          -4053.941,
          -3934.991,
          -3811.974,
          -3684.776,
          -3553.2909999999997,
          -3417.4120000000003,
          -3277.0429999999997,
          -3132.093,
          -2982.4840000000004,
          -2828.1540000000005,
          -2669.059,
          -2505.176,
          -2336.512,
          -2163.107,
          -1985.037,
          -1802.4279999999999,
          -1615.4520000000002,
          -1424.339,
          -1229.382,
          -1030.938,
          -829.431,
          -625.355,
          -419.26800000000003,
          -211.78900000000002,
          -3.5860000000000003,
          204.63099999999997,
          412.131,
          618.173,
          822.025,
          1022.9830000000001,
          1220.383,
          1413.621,
          1602.1589999999999,
          1785.531,
          1963.3529999999998,
          2135.32,
          2301.201,
          2460.8379999999997,
          2614.139,
          2761.0690000000004,
          2901.6440000000002,
          3035.9240000000004,
          3164.0040000000004,
          3286.0040000000004,
          3402.072,
          3512.368,
          3617.066,
          3716.349,
          3810.403,
          3899.4159999999997,
          3983.578,
          4063.073,
          4138.085999999999,
          4208.794,
          4275.372,
          4337.987,
          4396.8009999999995,
          4451.97,
          4503.643,
          4551.962,
          4597.066,
          4639.084,
          4678.14,
          4714.355,
          4747.840999999999,
          4778.706,
          4807.053,
          4832.98,
          4856.58,
          4877.943,
          4897.152,
          4914.289000000001,
          4929.429,
          4942.648,
          4954.014,
          4963.594,
          4971.451,
          4977.646,
          4982.237,
          4985.28,
          4986.827,
          4986.928,
          4985.633,
          4982.986,
          4979.032999999999,
          4973.816,
          4967.375,
          4959.75,
          4950.977,
          4941.093,
          4930.130999999999,
          4918.125,
          4905.107,
          4891.107,
          4876.153,
          4860.275,
          4843.499,
          4825.852,
          4807.359,
          4788.044,
          4767.929,
          4747.038,
          4725.393,
          4703.014,
          4679.920999999999,
          4656.134,
          4631.6720000000005,
          4606.553,
          4580.795,
          4554.415,
          4527.428,
          4499.852,
          4471.701,
          4442.99,
          4413.735,
          4383.9490000000005,
          4353.645,
          4322.837,
          4291.538,
          4259.76,
          4227.515,
          4194.814,
          4161.67,
          4128.093,
          4094.094,
          4059.684,
          4024.8720000000003,
          3989.6679999999997,
          3954.0820000000003,
          3918.1240000000003,
          3881.802,
          3845.125,
          3808.1020000000003,
          3770.742,
          3733.052,
          3695.0409999999997,
          3656.716,
          3618.085,
          3579.155,
          3539.934,
          3500.428,
          3460.645,
          3420.591,
          3380.2729999999997,
          3339.696,
          3298.869,
          3257.796,
          3216.4829999999997,
          3174.938,
          3133.163,
          3091.1679999999997,
          3048.9559999999997,
          3006.531,
          2963.901,
          2921.07,
          2878.0429999999997,
          2834.825,
          2791.421,
          2747.836,
          2704.074,
          2660.139,
          2616.0370000000003,
          2571.772,
          2527.348,
          2482.769,
          2438.04,
          2393.1639999999998,
          2348.145,
          2302.988,
          2257.696,
          2212.2729999999997,
          2166.723,
          2121.05,
          2075.257,
          2029.3470000000002,
          1983.3239999999998,
          1937.192,
          1890.954,
          1844.6129999999998,
          1798.172,
          1751.635,
          1705.005,
          1658.285,
          1611.4779999999998,
          1564.5870000000002,
          1517.615,
          1470.565,
          1423.44,
          1376.243,
          1328.977,
          1281.643,
          1234.246,
          1186.788,
          1139.272,
          1091.6989999999998,
          1044.0739999999998,
          996.398,
          948.673,
          900.904,
          853.091,
          805.237,
          757.346,
          709.419,
          661.4580000000001,
          613.466,
          565.446,
          517.399,
          469.32800000000003,
          421.235,
          373.12300000000005,
          324.993,
          276.848,
          228.69099999999997,
          180.52200000000002,
          132.344,
          84.16,
          35.972,
          -12.219000000000001,
          -60.41,
          -108.59899999999999,
          -156.785,
          -204.965,
          -253.137,
          -301.29900000000004,
          -349.45,
          -397.586,
          -445.707,
          -493.811,
          -541.894,
          -589.957,
          -637.995,
          -686.0089999999999,
          -733.995,
          -781.952,
          -829.878,
          -877.7719999999999,
          -925.63,
          -973.452,
          -1021.2360000000001,
          -1068.979,
          -1116.681,
          -1164.338,
          -1211.95,
          -1259.514,
          -1307.029,
          -1354.493,
          -1401.904,
          -1449.26,
          -1496.56,
          -1543.8010000000002,
          -1590.9820000000002,
          -1638.102,
          -1685.1570000000002,
          -1732.148,
          -1779.0710000000001,
          -1825.925,
          -1872.7089999999998,
          -1919.42,
          -1966.057,
          -2012.6170000000002,
          -2059.1,
          -2105.5029999999997,
          -2151.825,
          -2198.064,
          -2244.217,
          -2290.284,
          -2336.263,
          -2382.151,
          -2427.947,
          -2473.649,
          -2519.256,
          -2564.765,
          -2610.175,
          -2655.4829999999997,
          -2700.6890000000003,
          -2745.79,
          -2790.784,
          -2835.67,
          -2880.446,
          -2925.1090000000004,
          -2969.659,
          -3014.093,
          -3058.409,
          -3102.605,
          -3146.68,
          -3190.632,
          -3234.4590000000003,
          -3278.158,
          -3321.728,
          -3365.1679999999997,
          -3408.474,
          -3451.645,
          -3494.68,
          -3537.575,
          -3580.33,
          -3622.942,
          -3665.409,
          -3707.7290000000003,
          -3749.8990000000003,
          -3791.9190000000003,
          -3833.7870000000003,
          -3875.4990000000003,
          -3917.052,
          -3958.448,
          -3999.6809999999996,
          -4040.75,
          -4081.6540000000005,
          -4122.389,
          -4162.954000000001,
          -4203.347,
          -4243.565,
          -4283.605,
          -4323.465999999999,
          -4363.146,
          -4402.641,
          -4441.95,
          -4481.07,
          -4520,
          -4558.735,
          -4597.274,
          -4635.615,
          -4673.755,
          -4711.692,
          -4749.4220000000005,
          -4786.944,
          -4824.254,
          -4861.35,
          -4898.229,
          -4934.889,
          -4971.327,
          -5007.54,
          -5043.526,
          -5079.281,
          -5114.802,
          -5150.087,
          -5185.133,
          -5219.937,
          -5254.496,
          -5288.807,
          -5322.866,
          -5356.67,
          -5390.217,
          -5423.503000000001,
          -5456.525,
          -5489.279,
          -5521.762,
          -5553.971,
          -5585.903,
          -5617.553000000001,
          -5648.918000000001,
          -5679.995,
          -5710.78,
          -5741.27,
          -5771.459,
          -5801.346,
          -5830.9259999999995,
          -5860.194,
          -5889.147,
          -5917.78,
          -5946.09,
          -5974.073,
          -6001.723000000001,
          -6029.036999999999,
          -6056.0109999999995,
          -6082.64,
          -6108.919,
          -6134.843000000001,
          -6160.409000000001,
          -6185.61,
          -6210.443,
          -6234.901999999999,
          -6258.982,
          -6282.678000000001,
          -6305.984,
          -6328.896,
          -6351.408,
          -6373.515,
          -6395.21,
          -6416.486999999999,
          -6437.342,
          -6457.768,
          -6477.758000000001,
          -6497.307,
          -6516.409000000001,
          -6535.056,
          -6553.243,
          -6570.9619999999995,
          -6588.206999999999,
          -6604.97,
          -6621.244000000001,
          -6637.022,
          -6652.295999999999,
          -6667.06,
          -6681.304,
          -6695.022,
          -6708.204000000001,
          -6720.842,
          -6732.928000000001,
          -6744.453,
          -6755.408,
          -6765.784000000001,
          -6775.571999999999,
          -6784.7609999999995,
          -6793.343000000001,
          -6801.306,
          -6808.641,
          -6815.3369999999995,
          -6821.384,
          -6826.77,
          -6831.483,
          -6835.512,
          -6838.845,
          -6841.47,
          -6843.375,
          -6844.545999999999,
          -6844.969,
          -6844.630999999999,
          -6843.518,
          -6841.616999999999,
          -6838.91,
          -6835.385,
          -6831.024,
          -6825.811,
          -6819.732,
          -6812.767,
          -6804.899,
          -6796.11,
          -6786.383000000001,
          -6775.696999999999,
          -6764.031,
          -6751.366999999999,
          -6737.683000000001,
          -6722.956999999999,
          -6707.166,
          -6690.2880000000005,
          -6672.299,
          -6653.173000000001,
          -6632.885,
          -6611.409000000001,
          -6588.718000000001,
          -6564.781999999999,
          -6539.573,
          -6513.061,
          -6485.214,
          -6455.999,
          -6425.385,
          -6393.3330000000005,
          -6359.811,
          -6324.779,
          -6288.1990000000005,
          -6250.03,
          -6210.231,
          -6168.758000000001,
          -6125.566999999999,
          -6080.609,
          -6033.838000000001,
          -5985.201,
          -5934.647,
          -5882.12,
          -5827.565,
          -5770.920999999999,
          -5712.128000000001,
          -5651.121,
          -5587.834,
          -5522.198,
          -5454.14,
          -5383.588000000001,
          -5310.4619999999995,
          -5234.681,
          -5156.163,
          -5074.821,
          -4990.563,
          -4903.298,
          -4812.929,
          -4719.356,
          -4622.477,
          -4522.186,
          -4418.375,
          -4310.935,
          -4199.752,
          -4084.7140000000004,
          -3965.705,
          -3842.611,
          -3715.321,
          -3583.723,
          -3447.711,
          -3307.187,
          -3162.058,
          -3012.245,
          -2857.683,
          -2698.325,
          -2534.147,
          -2365.153,
          -2191.3779999999997,
          -2012.898,
          -1829.8329999999999,
          -1642.352,
          -1450.682,
          -1255.11,
          -1055.99,
          -853.745,
          -648.863,
          -441.901,
          -233.475,
          -24.254,
          185.053,
          393.711,
          600.977,
          806.1160000000001,
          1008.416,
          1207.208,
          1401.878,
          1591.881,
          1776.745,
          1956.0770000000002,
          2129.561,
          2296.9610000000002,
          2458.112,
          2612.916,
          2761.333,
          2903.373,
          3039.094,
          3168.586,
          3291.969,
          3409.387,
          3521,
          3626.9809999999998,
          3727.513,
          3822.78,
          3912.972,
          3998.277,
          4078.883,
          4154.971,
          4226.724,
          4294.313,
          4357.907999999999,
          4417.6720000000005,
          4473.7609999999995,
          4526.3240000000005,
          4575.4259999999995,
          4621.448,
          4664.275,
          4704.117,
          4741.092000000001,
          4775.315,
          4806.894,
          4835.932,
          4862.529,
          4886.778,
          4908.771,
          4928.589,
          4946.317,
          4962.03,
          4975.804,
          4987.707,
          4997.809,
          5006.170999999999,
          5012.855,
          5017.9220000000005,
          5021.424,
          5023.417,
          5023.9490000000005,
          5023.072,
          5020.831,
          5017.271,
          5012.434,
          5006.361,
          4999.092000000001,
          4990.665,
          4981.115,
          4970.477,
          4958.784000000001,
          4946.068,
          4932.36,
          4917.69,
          4902.085,
          4885.5740000000005,
          4868.182,
          4849.935,
          4830.857,
          4810.972,
          4790.302,
          4768.87,
          4746.696,
          4723.8009999999995,
          4700.204000000001,
          4675.925,
          4650.981,
          4625.392,
          4599.173,
          4572.340999999999,
          4544.913,
          4516.903,
          4488.3279999999995,
          4459.202,
          4429.538,
          4399.352,
          4368.655,
          4337.460999999999,
          4305.782999999999,
          4273.6320000000005,
          4241.02,
          4207.959,
          4174.46,
          4140.534000000001,
          4106.192,
          4071.4429999999998,
          4036.297,
          4000.764,
          3964.8540000000003,
          3928.5759999999996,
          3891.9390000000003,
          3854.9509999999996,
          3817.6209999999996,
          3779.9570000000003,
          3741.968,
          3703.66,
          3665.0429999999997,
          3626.1220000000003,
          3586.906,
          3547.402,
          3507.616,
          3467.555,
          3427.2270000000003,
          3386.637,
          3345.792,
          3304.698,
          3263.36,
          3221.7870000000003,
          3179.98,
          3137.949,
          3095.698,
          3053.2329999999997,
          3010.558,
          2967.678,
          2924.6,
          2881.328,
          2837.866,
          2794.22,
          2750.3940000000002,
          2706.393,
          2662.222,
          2617.884,
          2573.385,
          2528.728,
          2483.917,
          2438.9570000000003,
          2393.853,
          2348.606,
          2303.223,
          2257.706,
          2212.0589999999997,
          2166.286,
          2120.391,
          2074.377,
          2028.247,
          1982.006,
          1935.656,
          1889.201,
          1842.644,
          1795.9879999999998,
          1749.237,
          1702.394,
          1655.461,
          1608.442,
          1561.34,
          1514.1589999999999,
          1466.899,
          1419.566,
          1372.161,
          1324.6870000000001,
          1277.1480000000001,
          1229.545,
          1181.882,
          1134.162,
          1086.386,
          1038.557,
          990.678,
          942.752,
          894.7819999999999,
          846.768,
          798.715,
          750.6239999999999,
          702.498,
          654.339,
          606.15,
          557.932,
          509.689,
          461.42199999999997,
          413.134,
          364.827,
          316.503,
          268.165,
          219.81400000000002,
          171.453,
          123.083,
          74.708,
          26.328000000000003,
          -22.053,
          -70.434,
          -118.81299999999999,
          -167.188,
          -215.55599999999998,
          -263.916,
          -312.26599999999996,
          -360.603,
          -408.926,
          -457.23199999999997,
          -505.52099999999996,
          -553.789,
          -602.036,
          -650.258,
          -698.454,
          -746.623,
          -794.762,
          -842.87,
          -890.944,
          -938.982,
          -986.9839999999999,
          -1034.947,
          -1082.869,
          -1130.748,
          -1178.583,
          -1226.371,
          -1274.112,
          -1321.8020000000001,
          -1369.441,
          -1417.026,
          -1464.555,
          -1512.0279999999998,
          -1559.442,
          -1606.795,
          -1654.085,
          -1701.3110000000001,
          -1748.471,
          -1795.5629999999999,
          -1842.586,
          -1889.537,
          -1936.414,
          -1983.217,
          -2029.943,
          -2076.59,
          -2123.157,
          -2169.6420000000003,
          -2216.0429999999997,
          -2262.3579999999997,
          -2308.5860000000002,
          -2354.724,
          -2400.771,
          -2446.725,
          -2492.585,
          -2538.347,
          -2584.012,
          -2629.5759999999996,
          -2675.038,
          -2720.397,
          -2765.6490000000003,
          -2810.7940000000003,
          -2855.829,
          -2900.7540000000004,
          -2945.565,
          -2990.261,
          -3034.841,
          -3079.302,
          -3123.6420000000003,
          -3167.8590000000004,
          -3211.953,
          -3255.9190000000003,
          -3299.758,
          -3343.466,
          -3387.042,
          -3430.4840000000004,
          -3473.789,
          -3516.9570000000003,
          -3559.985,
          -3602.87,
          -3645.611,
          -3688.2059999999997,
          -3730.652,
          -3772.949,
          -3815.092,
          -3857.0820000000003,
          -3898.914,
          -3940.5879999999997,
          -3982.1,
          -4023.45,
          -4064.634,
          -4105.651,
          -4146.498,
          -4187.173,
          -4227.674,
          -4267.998,
          -4308.144,
          -4348.108,
          -4387.889,
          -4427.484,
          -4466.891,
          -4506.108,
          -4545.130999999999,
          -4583.959,
          -4622.589,
          -4661.018,
          -4699.244000000001,
          -4737.264,
          -4775.076,
          -4812.677,
          -4850.065,
          -4887.236,
          -4924.189,
          -4960.92,
          -4997.4259999999995,
          -5033.705,
          -5069.755,
          -5105.571,
          -5141.151,
          -5176.4929999999995,
          -5211.593,
          -5246.448,
          -5281.054,
          -5315.41,
          -5349.512,
          -5383.356,
          -5416.94,
          -5450.26,
          -5483.312,
          -5516.094,
          -5548.603,
          -5580.834,
          -5612.784000000001,
          -5644.4490000000005,
          -5675.826,
          -5706.911999999999,
          -5737.701,
          -5768.191999999999,
          -5798.379,
          -5828.26,
          -5857.829000000001,
          -5887.0830000000005,
          -5916.018,
          -5944.630999999999,
          -5972.915,
          -6000.868,
          -6028.485,
          -6055.7609999999995,
          -6082.691999999999,
          -6109.273,
          -6135.5,
          -6161.368,
          -6186.871999999999,
          -6212.007,
          -6236.769,
          -6261.151999999999,
          -6285.151,
          -6308.76,
          -6331.974,
          -6354.789000000001,
          -6377.196999999999,
          -6399.194,
          -6420.775,
          -6441.932,
          -6462.66,
          -6482.953,
          -6502.804,
          -6522.206999999999,
          -6541.155,
          -6559.643,
          -6577.6630000000005,
          -6595.209,
          -6612.273,
          -6628.847,
          -6644.925,
          -6660.499,
          -6675.562,
          -6690.105,
          -6704.121,
          -6717.601,
          -6730.536999999999,
          -6742.920999999999,
          -6754.743,
          -6765.994000000001,
          -6776.666,
          -6786.749,
          -6796.234,
          -6805.11,
          -6813.366999999999,
          -6820.995,
          -6827.984,
          -6834.321999999999,
          -6839.999,
          -6845.003000000001,
          -6849.321999999999,
          -6852.944,
          -6855.857,
          -6858.049,
          -6859.505999999999,
          -6860.214,
          -6860.16,
          -6859.331,
          -6857.7119999999995,
          -6855.2880000000005,
          -6852.0419999999995,
          -6847.96,
          -6843.026999999999,
          -6837.224,
          -6830.534000000001,
          -6822.94,
          -6814.425,
          -6804.969,
          -6794.553000000001,
          -6783.156,
          -6770.759,
          -6757.340999999999,
          -6742.878000000001,
          -6727.35,
          -6710.732,
          -6693.001,
          -6674.132,
          -6654.099,
          -6632.876,
          -6610.434,
          -6586.746999999999,
          -6561.785,
          -6535.517,
          -6507.911,
          -6478.936,
          -6448.557,
          -6416.741,
          -6383.4490000000005,
          -6348.645,
          -6312.291,
          -6274.344,
          -6234.764,
          -6193.507,
          -6150.528,
          -6105.779,
          -6059.213000000001,
          -6010.776999999999,
          -5960.420999999999,
          -5908.0869999999995,
          -5853.721,
          -5797.2609999999995,
          -5738.648,
          -5677.816,
          -5614.6990000000005,
          -5549.227,
          -5481.329000000001,
          -5410.929,
          -5337.95,
          -5262.311,
          -5183.927,
          -5102.712,
          -5018.575,
          -4931.4220000000005,
          -4841.157,
          -4747.679,
          -4650.8859999999995,
          -4550.673,
          -4446.929,
          -4339.544,
          -4228.406,
          -4113.399,
          -3994.409,
          -3871.321,
          -3744.02,
          -3612.395,
          -3476.3390000000004,
          -3335.75,
          -3190.5359999999996,
          -3040.616,
          -2885.921,
          -2726.403,
          -2562.035,
          -2392.82,
          -2218.7870000000003,
          -2040.01,
          -1856.605,
          -1668.7379999999998,
          -1476.631,
          -1280.567,
          -1080.896,
          -878.0369999999999,
          -672.475,
          -464.764,
          -255.518,
          -45.403999999999996,
          164.868,
          374.56300000000005,
          582.936,
          789.243,
          992.7719999999999,
          1192.846,
          1388.845,
          1580.214,
          1766.473,
          1947.2220000000002,
          2122.136,
          2290.974,
          2453.56,
          2609.7929999999997,
          2759.627,
          2903.0679999999998,
          3040.167,
          3171.015,
          3295.7259999999997,
          3414.4440000000004,
          3527.327,
          3634.547,
          3736.285,
          3832.7270000000003,
          3924.0609999999997,
          4010.4770000000003,
          4092.1609999999996,
          4169.2970000000005,
          4242.066,
          4310.642,
          4375.194,
          4435.8859999999995,
          4492.876,
          4546.314,
          4596.345,
          4643.107,
          4686.732,
          4727.347,
          4765.072,
          4800.022,
          4832.307,
          4862.031,
          4889.293,
          4914.188,
          4936.805,
          4957.232,
          4975.549,
          4991.835,
          5006.164000000001,
          5018.607,
          5029.231,
          5038.103,
          5045.281,
          5050.826,
          5054.794,
          5057.238,
          5058.21,
          5057.758,
          5055.931,
          5052.771,
          5048.3240000000005,
          5042.63,
          5035.728,
          5027.656,
          5018.452,
          5008.149,
          4996.781,
          4984.3820000000005,
          4970.98,
          4956.606,
          4941.289000000001,
          4925.057,
          4907.936,
          4889.951,
          4871.126,
          4851.486,
          4831.055,
          4809.853,
          4787.901,
          4765.221,
          4741.832,
          4717.754,
          4693.005,
          4667.602,
          4641.563,
          4614.906,
          4587.645,
          4559.798,
          4531.379,
          4502.402,
          4472.883,
          4442.834,
          4412.269,
          4381.202,
          4349.645,
          4317.61,
          4285.109,
          4252.154,
          4218.755999999999,
          4184.925,
          4150.673,
          4116.01,
          4080.945,
          4045.49,
          4009.652,
          3973.441,
          3936.867,
          3899.938,
          3862.6620000000003,
          3825.0490000000004,
          3787.105,
          3748.84,
          3710.26,
          3671.3740000000003,
          3632.1890000000003,
          3592.711,
          3552.948,
          3512.906,
          3472.593,
          3432.015,
          3391.178,
          3350.0879999999997,
          3308.752,
          3267.176,
          3225.365,
          3183.325,
          3141.062,
          3098.5809999999997,
          3055.887,
          3012.986,
          2969.883,
          2926.583,
          2883.09,
          2839.4109999999996,
          2795.548,
          2751.508,
          2707.2940000000003,
          2662.9109999999996,
          2618.363,
          2573.655,
          2528.791,
          2483.775,
          2438.611,
          2393.304,
          2347.856,
          2302.272,
          2256.556,
          2210.712,
          2164.742,
          2118.651,
          2072.4429999999998,
          2026.12,
          1979.6860000000001,
          1933.144,
          1886.499,
          1839.7520000000002,
          1792.908,
          1745.97,
          1698.94,
          1651.8220000000001,
          1604.618,
          1557.3329999999999,
          1509.9679999999998,
          1462.526,
          1415.011,
          1367.425,
          1319.7720000000002,
          1272.053,
          1224.272,
          1176.431,
          1128.5330000000001,
          1080.58,
          1032.576,
          984.5219999999999,
          936.421,
          888.2769999999999,
          840.09,
          791.8639999999999,
          743.6010000000001,
          695.303,
          646.9730000000001,
          598.614,
          550.227,
          501.814,
          453.379,
          404.92199999999997,
          356.44800000000004,
          307.957,
          259.452,
          210.935,
          162.408,
          113.874,
          65.334,
          16.791,
          -31.754,
          -80.298,
          -128.839,
          -177.375,
          -225.90400000000002,
          -274.425,
          -322.935,
          -371.43199999999996,
          -419.914,
          -468.379,
          -516.825,
          -565.251,
          -613.655,
          -662.033,
          -710.3860000000001,
          -758.71,
          -807.0039999999999,
          -855.2660000000001,
          -903.4939999999999,
          -951.686,
          -999.84,
          -1047.955,
          -1096.028,
          -1144.058,
          -1192.0439999999999,
          -1239.982,
          -1287.872,
          -1335.711,
          -1383.4979999999998,
          -1431.23,
          -1478.9070000000002,
          -1526.526,
          -1574.085,
          -1621.5829999999999,
          -1669.0179999999998,
          -1716.388,
          -1763.691,
          -1810.9260000000002,
          -1858.09,
          -1905.182,
          -1952.2,
          -1999.1429999999998,
          -2046.0079999999998,
          -2092.7929999999997,
          -2139.498,
          -2186.119,
          -2232.656,
          -2279.106,
          -2325.468,
          -2371.74,
          -2417.92,
          -2464.007,
          -2509.9970000000003,
          -2555.891,
          -2601.685,
          -2647.3779999999997,
          -2692.968,
          -2738.453,
          -2783.8320000000003,
          -2829.103,
          -2874.263,
          -2919.3109999999997,
          -2964.244,
          -3009.062,
          -3053.762,
          -3098.343,
          -3142.801,
          -3187.136,
          -3231.3459999999995,
          -3275.428,
          -3319.381,
          -3363.202,
          -3406.89,
          -3450.4429999999998,
          -3493.8579999999997,
          -3537.135,
          -3580.2690000000002,
          -3623.261,
          -3666.107,
          -3708.805,
          -3751.3540000000003,
          -3793.752,
          -3835.995,
          -3878.083,
          -3920.012,
          -3961.781,
          -4003.388,
          -4044.8309999999997,
          -4086.1059999999998,
          -4127.213,
          -4168.148,
          -4208.91,
          -4249.496,
          -4289.904,
          -4330.130999999999,
          -4370.1759999999995,
          -4410.035,
          -4449.707,
          -4489.189,
          -4528.479,
          -4567.5740000000005,
          -4606.471,
          -4645.169,
          -4683.664000000001,
          -4721.9529999999995,
          -4760.036,
          -4797.907999999999,
          -4835.567,
          -4873.01,
          -4910.235,
          -4947.2390000000005,
          -4984.02,
          -5020.573,
          -5056.897,
          -5092.9890000000005,
          -5128.845,
          -5164.463,
          -5199.84,
          -5234.973,
          -5269.858,
          -5304.491999999999,
          -5338.8730000000005,
          -5372.996999999999,
          -5406.861,
          -5440.460999999999,
          -5473.795,
          -5506.858,
          -5539.649,
          -5572.161999999999,
          -5604.395,
          -5636.343000000001,
          -5668.004,
          -5699.374,
          -5730.4490000000005,
          -5761.224,
          -5791.696999999999,
          -5821.863,
          -5851.718000000001,
          -5881.259,
          -5910.481,
          -5939.380999999999,
          -5967.953,
          -5996.194,
          -6024.099,
          -6051.664000000001,
          -6078.883000000001,
          -6105.754,
          -6132.27,
          -6158.428000000001,
          -6184.222,
          -6209.648,
          -6234.7,
          -6259.374,
          -6283.664000000001,
          -6307.564,
          -6331.07,
          -6354.1759999999995,
          -6376.8769999999995,
          -6399.166,
          -6421.0380000000005,
          -6442.488,
          -6463.509,
          -6484.094,
          -6504.238,
          -6523.934,
          -6543.1759999999995,
          -6561.956999999999,
          -6580.27,
          -6598.109,
          -6615.465999999999,
          -6632.334,
          -6648.705,
          -6664.573,
          -6679.929,
          -6694.765,
          -6709.075,
          -6722.848000000001,
          -6736.076999999999,
          -6748.754,
          -6760.869000000001,
          -6772.414000000001,
          -6783.379,
          -6793.754,
          -6803.531,
          -6812.7,
          -6821.249,
          -6829.169,
          -6836.4490000000005,
          -6843.079000000001,
          -6849.047,
          -6854.342,
          -6858.951,
          -6862.8640000000005,
          -6866.066,
          -6868.547,
          -6870.293000000001,
          -6871.291,
          -6871.525,
          -6870.984,
          -6869.651,
          -6867.514,
          -6864.554,
          -6860.758000000001,
          -6856.108,
          -6850.59,
          -6844.184,
          -6836.8730000000005,
          -6828.639,
          -6819.465,
          -6809.328,
          -6798.210999999999,
          -6786.093000000001,
          -6772.951999999999,
          -6758.766,
          -6743.513000000001,
          -6727.17,
          -6709.713000000001,
          -6691.115,
          -6671.353,
          -6650.4,
          -6628.227,
          -6604.807,
          -6580.111,
          -6554.106,
          -6526.764,
          -6498.05,
          -6467.93,
          -6436.371,
          -6403.335,
          -6368.785,
          -6332.683000000001,
          -6294.986,
          -6255.654,
          -6214.642,
          -6171.906999999999,
          -6127.399,
          -6081.07,
          -6032.871,
          -5982.746999999999,
          -5930.643,
          -5876.504,
          -5820.268,
          -5761.876,
          -5701.2609999999995,
          -5638.357,
          -5573.096,
          -5505.403,
          -5435.205,
          -5362.424,
          -5286.976,
          -5208.78,
          -5127.748,
          -5043.788,
          -4956.807,
          -4866.707,
          -4773.388,
          -4676.747,
          -4576.678,
          -4473.071,
          -4365.815,
          -4254.795,
          -4139.898,
          -4021.006,
          -3898.005,
          -3770.7790000000005,
          -3639.2140000000004,
          -3503.204,
          -3362.645,
          -3217.442,
          -3067.514,
          -2912.789,
          -2753.216,
          -2588.7670000000003,
          -2419.4410000000003,
          -2245.264,
          -2066.308,
          -1882.683,
          -1694.5510000000002,
          -1502.131,
          -1305.702,
          -1105.609,
          -902.2660000000001,
          -696.154,
          -487.825,
          -277.889,
          -67.012,
          144.09799999999998,
          354.70300000000003,
          564.056,
          771.413,
          976.054,
          1177.296,
          1374.5120000000002,
          1567.141,
          1754.695,
          1936.764,
          2113.018,
          2283.205,
          2447.146,
          2604.731,
          2755.908,
          2900.679,
          3039.093,
          3171.2340000000004,
          3297.216,
          3417.18,
          3531.282,
          3639.6929999999998,
          3742.593,
          3840.1679999999997,
          3932.6059999999998,
          4020.0959999999995,
          4102.826,
          4180.978,
          4254.735,
          4324.27,
          4389.755,
          4451.353,
          4509.223,
          4563.515,
          4614.376,
          4661.944,
          4706.352,
          4747.727,
          4786.192,
          4821.86,
          4854.842000000001,
          4885.2429999999995,
          4913.164000000001,
          4938.698,
          4961.938,
          4982.969,
          5001.874,
          5018.732,
          5033.616,
          5046.6,
          5057.75,
          5067.1320000000005,
          5074.807,
          5080.835999999999,
          5085.274,
          5088.1759999999995,
          5089.593,
          5089.5740000000005,
          5088.168,
          5085.419,
          5081.37,
          5076.064,
          5069.539000000001,
          5061.835,
          5052.988,
          5043.032,
          5032.002,
          5019.931,
          5006.849,
          4992.786,
          4977.771,
          4961.832,
          4944.997,
          4927.289000000001,
          4908.735,
          4889.357,
          4869.18,
          4848.225,
          4826.514,
          4804.067,
          4780.904,
          4757.045,
          4732.509,
          4707.313,
          4681.475,
          4655.0109999999995,
          4627.939,
          4600.274,
          4572.031,
          4543.225,
          4513.87,
          4483.98,
          4453.57,
          4422.651,
          4391.238,
          4359.340999999999,
          4326.974,
          4294.147,
          4260.872,
          4227.161,
          4193.023,
          4158.469,
          4123.51,
          4088.155,
          4052.413,
          4016.295,
          3979.808,
          3942.962,
          3905.7659999999996,
          3868.228,
          3830.3559999999998,
          3792.158,
          3753.6420000000003,
          3714.815,
          3675.6859999999997,
          3636.26,
          3596.546,
          3556.5490000000004,
          3516.278,
          3475.738,
          3434.935,
          3393.877,
          3352.5690000000004,
          3311.0170000000003,
          3269.2270000000003,
          3227.2059999999997,
          3184.9570000000003,
          3142.488,
          3099.804,
          3056.908,
          3013.808,
          2970.508,
          2927.012,
          2883.3259999999996,
          2839.455,
          2795.402,
          2751.1740000000004,
          2706.7740000000003,
          2662.2059999999997,
          2617.475,
          2572.5860000000002,
          2527.542,
          2482.348,
          2437.007,
          2391.524,
          2345.902,
          2300.145,
          2254.257,
          2208.242,
          2162.104,
          2115.845,
          2069.469,
          2022.98,
          1976.382,
          1929.6770000000001,
          1882.869,
          1835.961,
          1788.9560000000001,
          1741.858,
          1694.6689999999999,
          1647.3929999999998,
          1600.0320000000002,
          1552.5910000000001,
          1505.07,
          1457.474,
          1409.806,
          1362.067,
          1314.261,
          1266.391,
          1218.4589999999998,
          1170.468,
          1122.421,
          1074.32,
          1026.1680000000001,
          977.967,
          929.72,
          881.429,
          833.097,
          784.7260000000001,
          736.319,
          687.878,
          639.406,
          590.905,
          542.376,
          493.82199999999995,
          445.246,
          396.65,
          348.036,
          299.407,
          250.763,
          202.109,
          153.445,
          104.774,
          56.098,
          7.419,
          -41.26,
          -89.939,
          -138.614,
          -187.28400000000002,
          -235.946,
          -284.599,
          -333.241,
          -381.869,
          -430.48199999999997,
          -479.07800000000003,
          -527.655,
          -576.21,
          -624.742,
          -673.25,
          -721.73,
          -770.181,
          -818.602,
          -866.99,
          -915.3439999999999,
          -963.6619999999999,
          -1011.941,
          -1060.18,
          -1108.377,
          -1156.53,
          -1204.638,
          -1252.6989999999998,
          -1300.71,
          -1348.67,
          -1396.5770000000002,
          -1444.43,
          -1492.226,
          -1539.963,
          -1587.641,
          -1635.256,
          -1682.808,
          -1730.2939999999999,
          -1777.713,
          -1825.0620000000001,
          -1872.3410000000001,
          -1919.547,
          -1966.6779999999999,
          -2013.733,
          -2060.71,
          -2107.607,
          -2154.422,
          -2201.153,
          -2247.799,
          -2294.3579999999997,
          -2340.828,
          -2387.206,
          -2433.493,
          -2479.6839999999997,
          -2525.78,
          -2571.777,
          -2617.674,
          -2663.47,
          -2709.1609999999996,
          -2754.748,
          -2800.2259999999997,
          -2845.5959999999995,
          -2890.8540000000003,
          -2936,
          -2981.03,
          -3025.9429999999998,
          -3070.738,
          -3115.4120000000003,
          -3159.9640000000004,
          -3204.39,
          -3248.691,
          -3292.863,
          -3336.9040000000005,
          -3380.813,
          -3424.5879999999997,
          -3468.2259999999997,
          -3511.7259999999997,
          -3555.085,
          -3598.302,
          -3641.375,
          -3684.3,
          -3727.078,
          -3769.704,
          -3812.177,
          -3854.4959999999996,
          -3896.657,
          -3938.659,
          -3980.5,
          -4022.176,
          -4063.687,
          -4105.03,
          -4146.202,
          -4187.202,
          -4228.027,
          -4268.674,
          -4309.142,
          -4349.427,
          -4389.529,
          -4429.443,
          -4469.168,
          -4508.702,
          -4548.042,
          -4587.185,
          -4626.129,
          -4664.871,
          -4703.409000000001,
          -4741.74,
          -4779.862,
          -4817.771,
          -4855.465999999999,
          -4892.943,
          -4930.2,
          -4967.233,
          -5004.041,
          -5040.619000000001,
          -5076.965999999999,
          -5113.079000000001,
          -5148.9529999999995,
          -5184.587,
          -5219.978,
          -5255.121999999999,
          -5290.016,
          -5324.656999999999,
          -5359.0419999999995,
          -5393.1669999999995,
          -5427.03,
          -5460.6269999999995,
          -5493.954000000001,
          -5527.008000000001,
          -5559.786,
          -5592.284000000001,
          -5624.499,
          -5656.4259999999995,
          -5688.063,
          -5719.405,
          -5750.45,
          -5781.191999999999,
          -5811.628000000001,
          -5841.754,
          -5871.565,
          -5901.059,
          -5930.23,
          -5959.075,
          -5987.588000000001,
          -6015.767,
          -6043.606,
          -6071.1,
          -6098.246,
          -6125.039000000001,
          -6151.473000000001,
          -6177.544,
          -6203.246999999999,
          -6228.576999999999,
          -6253.528,
          -6278.097,
          -6302.276999999999,
          -6326.063,
          -6349.4490000000005,
          -6372.431,
          -6395.001,
          -6417.155,
          -6438.887,
          -6460.189,
          -6481.057,
          -6501.485,
          -6521.465,
          -6540.991,
          -6560.057,
          -6578.655,
          -6596.778,
          -6614.420999999999,
          -6631.5740000000005,
          -6648.233,
          -6664.387,
          -6680.03,
          -6695.154,
          -6709.751,
          -6723.812,
          -6737.329000000001,
          -6750.295,
          -6762.6990000000005,
          -6774.531999999999,
          -6785.786,
          -6796.451,
          -6806.518,
          -6815.976,
          -6824.816,
          -6833.026999999999,
          -6840.597,
          -6847.518,
          -6853.776,
          -6859.361999999999,
          -6864.263000000001,
          -6868.465999999999,
          -6871.96,
          -6874.732,
          -6876.77,
          -6878.058000000001,
          -6878.585,
          -6878.334,
          -6877.294,
          -6875.446999999999,
          -6872.779,
          -6869.274,
          -6864.916,
          -6859.689,
          -6853.5740000000005,
          -6846.554,
          -6838.611,
          -6829.727,
          -6819.882,
          -6809.055,
          -6797.226,
          -6784.375,
          -6770.479,
          -6755.515,
          -6739.460999999999,
          -6722.291,
          -6703.982,
          -6684.508000000001,
          -6663.840999999999,
          -6641.954000000001,
          -6618.821,
          -6594.409000000001,
          -6568.689,
          -6541.630999999999,
          -6513.2,
          -6483.363,
          -6452.085999999999,
          -6419.33,
          -6385.061,
          -6349.236999999999,
          -6311.819,
          -6272.763000000001,
          -6232.028,
          -6189.566,
          -6145.331999999999,
          -6099.276,
          -6051.347,
          -6001.491,
          -5949.656,
          -5895.781999999999,
          -5839.811,
          -5781.68,
          -5721.325,
          -5658.68,
          -5593.674,
          -5526.236,
          -5456.289000000001,
          -5383.755,
          -5308.554,
          -5230.6,
          -5149.807,
          -5066.083,
          -4979.333,
          -4889.460999999999,
          -4796.366,
          -4699.944,
          -4600.088,
          -4496.689,
          -4389.635,
          -4278.81,
          -4164.101,
          -4045.39,
          -3922.56,
          -3795.494,
          -3664.08,
          -3528.208,
          -3387.775,
          -3242.683,
          -3092.847,
          -2938.197,
          -2778.678,
          -2614.259,
          -2444.936,
          -2270.7329999999997,
          -2091.717,
          -1907.995,
          -1719.725,
          -1527.12,
          -1330.455,
          -1130.072,
          -926.378,
          -719.852,
          -511.038,
          -300.548,
          -89.042,
          122.771,
          334.156,
          544.361,
          752.64,
          958.2689999999999,
          1160.56,
          1358.88,
          1552.6589999999999,
          1741.401,
          1924.6889999999999,
          2102.186,
          2273.631,
          2438.839,
          2597.6929999999998,
          2750.135,
          2896.164,
          3035.823,
          3169.192,
          3296.384,
          3417.535,
          3532.803,
          3642.3540000000003,
          3746.369,
          3845.032,
          3938.533,
          4027.058,
          4110.795999999999,
          4189.932,
          4264.644,
          4335.111,
          4401.501,
          4463.98,
          4522.706,
          4577.832,
          4629.3240000000005,
          4677.86,
          4723.036,
          4765.157,
          4804.347,
          4840.721,
          4874.391,
          4905.462,
          4934.032999999999,
          4960.201,
          4984.058,
          5005.69,
          5025.18,
          5042.607,
          5058.0470000000005,
          5071.571,
          5083.248,
          5093.143,
          5101.319,
          5107.834,
          5112.748,
          5116.112,
          5117.98,
          5118.401,
          5117.424,
          5115.093,
          5111.451,
          5106.543,
          5100.406,
          5093.079000000001,
          5084.6,
          5075.004,
          5064.325,
          5052.595,
          5039.846,
          5026.108,
          5011.41,
          4995.78,
          4979.245,
          4961.831,
          4943.562,
          4924.463,
          4904.558,
          4883.8679999999995,
          4862.414000000001,
          4840.218,
          4817.3009999999995,
          4793.681,
          4769.376,
          4744.406,
          4718.788,
          4692.539000000001,
          4665.6759999999995,
          4638.213,
          4610.167,
          4581.553,
          4552.385,
          4522.6759999999995,
          4492.442,
          4461.695,
          4430.448,
          4398.713,
          4366.502,
          4333.827,
          4300.6990000000005,
          4267.13,
          4233.130999999999,
          4198.710999999999,
          4163.880999999999,
          4128.651,
          4093.03,
          4057.028,
          4020.6540000000005,
          3983.917,
          3946.8259999999996,
          3909.389,
          3871.615,
          3833.51,
          3795.0840000000003,
          3756.343,
          3717.296,
          3677.949,
          3638.31,
          3598.386,
          3558.183,
          3517.708,
          3476.967,
          3435.968,
          3394.716,
          3353.216,
          3311.4759999999997,
          3269.5,
          3227.2940000000003,
          3184.865,
          3142.217,
          3099.3559999999998,
          3056.2859999999996,
          3013.014,
          2969.5440000000003,
          2925.88,
          2882.028,
          2837.993,
          2793.7790000000005,
          2749.39,
          2704.8320000000003,
          2660.1079999999997,
          2615.223,
          2570.18,
          2524.984,
          2479.64,
          2434.151,
          2388.52,
          2342.752,
          2296.851,
          2250.82,
          2204.663,
          2158.383,
          2111.985,
          2065.471,
          2018.845,
          1972.11,
          1925.27,
          1878.328,
          1831.287,
          1784.15,
          1736.921,
          1689.6029999999998,
          1642.1970000000001,
          1594.7089999999998,
          1547.14,
          1499.493,
          1451.771,
          1403.9779999999998,
          1356.115,
          1308.187,
          1260.194,
          1212.141,
          1164.029,
          1115.862,
          1067.641,
          1019.3710000000001,
          971.052,
          922.687,
          874.28,
          825.832,
          777.346,
          728.824,
          680.2689999999999,
          631.683,
          583.069,
          534.427,
          485.76199999999994,
          437.075,
          388.369,
          339.645,
          290.905,
          242.153,
          193.39,
          144.618,
          95.84,
          47.056999999999995,
          -1.7280000000000002,
          -50.513999999999996,
          -99.29799999999999,
          -148.078,
          -196.852,
          -245.618,
          -294.374,
          -343.119,
          -391.85,
          -440.564,
          -489.26199999999994,
          -537.939,
          -586.595,
          -635.227,
          -683.8330000000001,
          -732.413,
          -780.9630000000001,
          -829.4810000000001,
          -878.065,
          -926.5160000000001,
          -974.93,
          -1023.305,
          -1071.639,
          -1119.931,
          -1168.1789999999999,
          -1216.381,
          -1264.535,
          -1312.639,
          -1360.691,
          -1408.69,
          -1456.634,
          -1504.52,
          -1552.348,
          -1600.115,
          -1647.819,
          -1695.46,
          -1743.0339999999999,
          -1790.54,
          -1837.976,
          -1885.3410000000001,
          -1932.632,
          -1979.849,
          -2026.9879999999998,
          -2074.048,
          -2121.028,
          -2167.926,
          -2214.739,
          -2261.466,
          -2308.105,
          -2354.655,
          -2401.113,
          -2447.478,
          -2493.7470000000003,
          -2539.92,
          -2585.993,
          -2631.966,
          -2677.836,
          -2723.6020000000003,
          -2769.262,
          -2814.813,
          -2860.2540000000004,
          -2905.5840000000003,
          -2950.7990000000004,
          -2995.8990000000003,
          -3040.881,
          -3085.743,
          -3130.4840000000004,
          -3175.1009999999997,
          -3219.593,
          -3263.9570000000003,
          -3308.192,
          -3352.296,
          -3396.2659999999996,
          -3440.1009999999997,
          -3483.798,
          -3527.3559999999998,
          -3570.7729999999997,
          -3614.046,
          -3657.173,
          -3700.153,
          -3742.9829999999997,
          -3785.6609999999996,
          -3828.185,
          -3870.553,
          -3912.762,
          -3954.8109999999997,
          -3996.698,
          -4038.4190000000003,
          -4079.973,
          -4121.358,
          -4162.571,
          -4203.61,
          -4244.472,
          -4285.156,
          -4325.659000000001,
          -4365.978,
          -4406.111,
          -4446.056,
          -4485.811,
          -4525.372,
          -4564.738,
          -4603.905,
          -4642.872,
          -4681.635,
          -4720.192,
          -4758.541,
          -4796.678,
          -4834.602,
          -4872.309,
          -4909.795999999999,
          -4947.061,
          -4984.101,
          -5020.913,
          -5057.494000000001,
          -5093.840999999999,
          -5129.952,
          -5165.823,
          -5201.451,
          -5236.833,
          -5271.965999999999,
          -5306.847,
          -5341.473000000001,
          -5375.84,
          -5409.946,
          -5443.786,
          -5477.357,
          -5510.656,
          -5543.68,
          -5576.425,
          -5608.887,
          -5641.063,
          -5672.9490000000005,
          -5704.541,
          -5735.835999999999,
          -5766.829000000001,
          -5797.518,
          -5827.897,
          -5857.963000000001,
          -5887.710999999999,
          -5917.137,
          -5946.238,
          -5975.009,
          -6003.445,
          -6031.543000000001,
          -6059.297,
          -6086.703,
          -6113.755999999999,
          -6140.451999999999,
          -6166.785,
          -6192.751,
          -6218.345,
          -6243.562,
          -6268.395,
          -6292.840999999999,
          -6316.894,
          -6340.548000000001,
          -6363.798000000001,
          -6386.638000000001,
          -6409.061,
          -6431.063,
          -6452.637,
          -6473.776999999999,
          -6494.477,
          -6514.73,
          -6534.531,
          -6553.871,
          -6572.744000000001,
          -6591.144,
          -6609.063,
          -6626.494000000001,
          -6643.43,
          -6659.8640000000005,
          -6675.786999999999,
          -6691.191,
          -6706.068,
          -6720.411,
          -6734.21,
          -6747.4580000000005,
          -6760.145,
          -6772.263000000001,
          -6783.802,
          -6794.7519999999995,
          -6805.104,
          -6814.849,
          -6823.976,
          -6832.474,
          -6840.334,
          -6847.543000000001,
          -6854.090999999999,
          -6859.965999999999,
          -6865.158,
          -6869.653,
          -6873.439,
          -6876.503000000001,
          -6878.8330000000005,
          -6880.416,
          -6881.236,
          -6881.28,
          -6880.534000000001,
          -6878.983,
          -6876.611999999999,
          -6873.403,
          -6869.342,
          -6864.411999999999,
          -6858.596,
          -6851.874,
          -6844.23,
          -6835.645,
          -6826.1,
          -6815.573,
          -6804.045,
          -6791.495,
          -6777.9,
          -6763.238,
          -6747.486,
          -6730.619000000001,
          -6712.613,
          -6693.441,
          -6673.079000000001,
          -6651.496,
          -6628.666,
          -6604.559,
          -6579.144,
          -6552.39,
          -6524.264,
          -6494.732,
          -6463.76,
          -6431.31,
          -6397.347,
          -6361.828,
          -6324.715,
          -6285.965999999999,
          -6245.536,
          -6203.38,
          -6159.451,
          -6113.701,
          -6066.076999999999,
          -6016.526999999999,
          -5964.996,
          -5911.427,
          -5855.76,
          -5797.933000000001,
          -5737.882,
          -5675.539000000001,
          -5610.835,
          -5543.698,
          -5474.052,
          -5401.816999999999,
          -5326.914000000001,
          -5249.258000000001,
          -5168.7609999999995,
          -5085.331,
          -4998.873,
          -4909.292,
          -4816.485,
          -4720.349,
          -4620.776,
          -4517.657,
          -4410.878,
          -4300.326,
          -4185.884,
          -4067.435,
          -3944.86,
          -3818.0440000000003,
          -3686.8709999999996,
          -3551.2309999999998,
          -3411.0190000000002,
          -3266.137,
          -3116.4970000000003,
          -2962.028,
          -2802.672,
          -2638.395,
          -2469.19,
          -2295.0789999999997,
          -2116.124,
          -1932.43,
          -1744.148,
          -1551.489,
          -1354.7220000000002,
          -1154.183,
          -950.275,
          -743.4730000000001,
          -534.316,
          -323.411,
          -111.416,
          100.962,
          312.987,
          523.909,
          732.9780000000001,
          939.465,
          1142.6789999999999,
          1341.98,
          1536.7920000000001,
          1726.611,
          1911.013,
          2089.651,
          2262.259,
          2428.643,
          2588.678,
          2742.304,
          2889.512,
          3030.341,
          3164.868,
          3293.203,
          3415.48,
          3531.8520000000003,
          3642.488,
          3747.565,
          3847.2670000000003,
          3941.783,
          4031.3,
          4116.005,
          4196.084,
          4271.718,
          4343.081,
          4410.346,
          4473.677,
          4533.233,
          4589.167,
          4641.626,
          4690.75,
          4736.673,
          4779.523,
          4819.423,
          4856.49,
          4890.834,
          4922.561,
          4951.773,
          4978.567,
          5003.032999999999,
          5025.259,
          5045.33,
          5063.322,
          5079.314,
          5093.376,
          5105.579000000001,
          5115.987,
          5124.664000000001,
          5131.669,
          5137.06,
          5140.891,
          5143.214,
          5144.081,
          5143.538,
          5141.6320000000005,
          5138.405,
          5133.902,
          5128.161,
          5121.222,
          5113.121,
          5103.895,
          5093.577,
          5082.2,
          5069.7970000000005,
          5056.397,
          5042.029,
          5026.721,
          5010.502,
          4993.396,
          4975.428,
          4956.624,
          4937.0070000000005,
          4916.598,
          4895.419,
          4873.492,
          4850.838,
          4827.474,
          4803.420999999999,
          4778.696,
          4753.318,
          4727.302,
          4700.667,
          4673.427,
          4645.6,
          4617.1990000000005,
          4588.238,
          4558.733,
          4528.697,
          4498.142,
          4467.083,
          4435.532,
          4403.501,
          4371.001,
          4338.044,
          4304.641,
          4270.804,
          4236.541,
          4201.865,
          4166.785,
          4131.31,
          4095.45,
          4059.2140000000004,
          4022.612,
          3985.651,
          3948.34,
          3910.6890000000003,
          3872.704,
          3834.3940000000002,
          3795.765,
          3756.827,
          3717.586,
          3678.0490000000004,
          3638.224,
          3598.116,
          3557.7340000000004,
          3517.0820000000003,
          3476.1690000000003,
          3435,
          3393.58,
          3351.917,
          3310.015,
          3267.881,
          3225.52,
          3182.937,
          3140.138,
          3097.1279999999997,
          3053.913,
          3010.4970000000003,
          2966.885,
          2923.0820000000003,
          2879.093,
          2834.922,
          2790.574,
          2746.054,
          2701.366,
          2656.514,
          2611.502,
          2566.335,
          2521.016,
          2475.551,
          2429.9410000000003,
          2384.192,
          2338.3070000000002,
          2292.291,
          2246.145,
          2199.875,
          2153.484,
          2106.976,
          2060.353,
          2013.619,
          1966.777,
          1919.832,
          1872.785,
          1825.641,
          1778.402,
          1731.0720000000001,
          1683.6529999999998,
          1636.148,
          1588.5610000000001,
          1540.894,
          1493.151,
          1445.3339999999998,
          1397.4460000000001,
          1349.489,
          1301.4669999999999,
          1253.382,
          1205.237,
          1157.035,
          1108.777,
          1060.4669999999999,
          1012.1080000000001,
          963.701,
          915.2489999999999,
          866.755,
          818.222,
          769.65,
          721.044,
          672.405,
          623.735,
          575.038,
          526.314,
          477.56800000000004,
          428.79900000000004,
          380.01199999999994,
          331.208,
          282.39,
          233.558,
          184.717,
          135.86700000000002,
          87.012,
          38.152,
          -10.709000000000001,
          -59.571000000000005,
          -108.43,
          -157.284,
          -206.13299999999998,
          -254.97299999999998,
          -303.802,
          -352.62,
          -401.423,
          -450.209,
          -498.978,
          -547.726,
          -596.452,
          -645.154,
          -693.83,
          -742.4789999999999,
          -791.097,
          -839.684,
          -888.237,
          -936.755,
          -985.235,
          -1033.6760000000002,
          -1082.076,
          -1130.434,
          -1178.746,
          -1227.012,
          -1275.23,
          -1323.3970000000002,
          -1371.5120000000002,
          -1419.5739999999998,
          -1467.579,
          -1515.527,
          -1563.4160000000002,
          -1611.243,
          -1659.007,
          -1706.707,
          -1754.34,
          -1801.904,
          -1849.398,
          -1896.82,
          -1944.168,
          -1991.44,
          -2038.635,
          -2085.751,
          -2132.785,
          -2179.736,
          -2226.603,
          -2273.382,
          -2320.074,
          -2366.675,
          -2413.1839999999997,
          -2459.599,
          -2505.9179999999997,
          -2552.139,
          -2598.261,
          -2644.281,
          -2690.198,
          -2736.01,
          -2781.715,
          -2827.3109999999997,
          -2872.797,
          -2918.1690000000003,
          -2963.427,
          -3008.5690000000004,
          -3053.592,
          -3098.494,
          -3143.275,
          -3187.9309999999996,
          -3232.46,
          -3276.862,
          -3321.133,
          -3365.272,
          -3409.276,
          -3453.145,
          -3496.875,
          -3540.4640000000004,
          -3583.9120000000003,
          -3627.215,
          -3670.3709999999996,
          -3713.3779999999997,
          -3756.235,
          -3798.9390000000003,
          -3841.487,
          -3883.8790000000004,
          -3926.111,
          -3968.1809999999996,
          -4010.087,
          -4051.828,
          -4093.4,
          -4134.8009999999995,
          -4176.03,
          -4217.083,
          -4257.958,
          -4298.654,
          -4339.167,
          -4379.495,
          -4419.6359999999995,
          -4459.587,
          -4499.347,
          -4538.911,
          -4578.279,
          -4617.446,
          -4656.412,
          -4695.1720000000005,
          -4733.725,
          -4772.068,
          -4810.198,
          -4848.112,
          -4885.808,
          -4923.282,
          -4960.532999999999,
          -4997.556,
          -5034.35,
          -5070.911,
          -5107.236,
          -5143.322,
          -5179.167,
          -5214.767,
          -5250.12,
          -5285.221,
          -5320.066999999999,
          -5354.656,
          -5388.984,
          -5423.048000000001,
          -5456.844,
          -5490.369000000001,
          -5523.62,
          -5556.593000000001,
          -5589.284000000001,
          -5621.69,
          -5653.807,
          -5685.630999999999,
          -5717.159000000001,
          -5748.3859999999995,
          -5779.31,
          -5809.924,
          -5840.227,
          -5870.213000000001,
          -5899.879,
          -5929.22,
          -5958.232,
          -5986.91,
          -6015.251,
          -6043.249,
          -6070.9,
          -6098.1990000000005,
          -6125.142,
          -6151.724,
          -6177.939,
          -6203.783,
          -6229.25,
          -6254.335999999999,
          -6279.036,
          -6303.343000000001,
          -6327.2519999999995,
          -6350.758000000001,
          -6373.854,
          -6396.536999999999,
          -6418.798000000001,
          -6440.633000000001,
          -6462.034000000001,
          -6482.996,
          -6503.512,
          -6523.576,
          -6543.182,
          -6562.321999999999,
          -6580.9890000000005,
          -6599.177,
          -6616.878000000001,
          -6634.084,
          -6650.7880000000005,
          -6666.983,
          -6682.661,
          -6697.813,
          -6712.432,
          -6726.508000000001,
          -6740.033,
          -6752.999,
          -6765.396,
          -6777.215999999999,
          -6788.448,
          -6799.0830000000005,
          -6809.111999999999,
          -6818.523,
          -6827.307,
          -6835.453,
          -6842.951,
          -6849.7880000000005,
          -6855.954000000001,
          -6861.437,
          -6866.224,
          -6870.303000000001,
          -6873.661,
          -6876.286999999999,
          -6878.166,
          -6879.284000000001,
          -6879.6269999999995,
          -6879.18,
          -6877.93,
          -6875.86,
          -6872.955,
          -6869.198,
          -6864.573,
          -6859.062,
          -6852.648,
          -6845.313,
          -6837.0380000000005,
          -6827.802,
          -6817.5869999999995,
          -6806.371999999999,
          -6794.1359999999995,
          -6780.856,
          -6766.51,
          -6751.075,
          -6734.526999999999,
          -6716.84,
          -6697.9890000000005,
          -6677.948,
          -6656.688,
          -6634.183000000001,
          -6610.401,
          -6585.312,
          -6558.885,
          -6531.089,
          -6501.887,
          -6471.245,
          -6439.128000000001,
          -6405.496999999999,
          -6370.314,
          -6333.536999999999,
          -6295.124,
          -6255.031999999999,
          -6213.215999999999,
          -6169.6269999999995,
          -6124.219,
          -6076.937,
          -6027.731,
          -5976.545999999999,
          -5923.323,
          -5868.003000000001,
          -5810.525,
          -5750.821999999999,
          -5688.83,
          -5624.478,
          -5557.694,
          -5488.4,
          -5416.521,
          -5341.973000000001,
          -5264.673000000001,
          -5184.531,
          -5101.459,
          -5015.359,
          -4926.135,
          -4833.687,
          -4737.907999999999,
          -4638.693,
          -4535.93,
          -4429.5070000000005,
          -4319.309,
          -4205.22,
          -4087.12,
          -3964.8920000000003,
          -3838.4190000000003,
          -3707.5840000000003,
          -3572.276,
          -3432.389,
          -3287.823,
          -3138.49,
          -2984.3140000000003,
          -2825.238,
          -2661.223,
          -2492.26,
          -2318.369,
          -2139.605,
          -1956.0710000000001,
          -1767.914,
          -1575.339,
          -1378.61,
          -1178.058,
          -974.081,
          -767.145,
          -557.789,
          -346.61300000000006,
          -134.274,
          78.527,
          291.05400000000003,
          502.55400000000003,
          712.2769999999999,
          919.492,
          1123.503,
          1323.6629999999998,
          1519.389,
          1710.171,
          1895.576,
          2075.251,
          2248.9210000000003,
          2416.386,
          2577.514,
          2732.24,
          2880.548,
          3022.473,
          3158.0890000000004,
          3287.502,
          3410.843,
          3528.263,
          3639.93,
          3746.0190000000002,
          3846.7140000000004,
          3942.2009999999996,
          4032.67,
          4118.305,
          4199.293,
          4275.814,
          4348.045,
          4416.156,
          4480.313,
          4540.6759999999995,
          4597.397,
          4650.625,
          4700.498,
          4747.152,
          4790.715999999999,
          4831.313,
          4869.06,
          4904.069,
          4936.445,
          4966.291,
          4993.7029999999995,
          5018.774,
          5041.592000000001,
          5062.2390000000005,
          5080.795999999999,
          5097.339,
          5111.942,
          5124.670999999999,
          5135.596,
          5144.777,
          5152.276,
          5158.15,
          5162.4529999999995,
          5165.2390000000005,
          5166.559,
          5166.459,
          5164.987,
          5162.185,
          5158.098,
          5152.765,
          5146.225,
          5138.516,
          5129.6720000000005,
          5119.729,
          5108.72,
          5096.677,
          5083.629,
          5069.607,
          5054.639,
          5038.751,
          5021.97,
          5004.322,
          4985.831,
          4966.519,
          4946.411,
          4925.526,
          4903.888,
          4881.516,
          4858.43,
          4834.648,
          4810.19,
          4785.072,
          4759.313,
          4732.928,
          4705.934,
          4678.347,
          4650.182,
          4621.4529999999995,
          4592.175,
          4562.36,
          4532.023,
          4501.177,
          4469.835,
          4438.008,
          4405.709,
          4372.948,
          4339.737,
          4306.087,
          4272.009,
          4237.513,
          4202.609,
          4167.306,
          4131.615,
          4095.545,
          4059.103,
          4022.3,
          3985.1440000000002,
          3947.6440000000002,
          3909.8059999999996,
          3871.64,
          3833.153,
          3794.3520000000003,
          3755.245,
          3715.8390000000004,
          3676.1420000000003,
          3636.159,
          3595.8979999999997,
          3555.366,
          3514.5679999999998,
          3473.511,
          3432.202,
          3390.645,
          3348.847,
          3306.8140000000003,
          3264.551,
          3222.0640000000003,
          3179.3579999999997,
          3136.4390000000003,
          3093.3109999999997,
          3049.9790000000003,
          3006.449,
          2962.7259999999997,
          2918.8140000000003,
          2874.718,
          2830.442,
          2785.992,
          2741.3709999999996,
          2696.583,
          2651.634,
          2606.526,
          2561.265,
          2515.855,
          2470.298,
          2424.6,
          2378.763,
          2332.792,
          2286.6910000000003,
          2240.4629999999997,
          2194.111,
          2147.639,
          2101.051,
          2054.351,
          2007.54,
          1960.6229999999998,
          1913.6029999999998,
          1866.484,
          1819.267,
          1771.957,
          1724.557,
          1677.069,
          1629.496,
          1581.842,
          1534.109,
          1486.3010000000002,
          1438.4189999999999,
          1390.467,
          1342.4479999999999,
          1294.365,
          1246.219,
          1198.014,
          1149.752,
          1101.4360000000001,
          1053.068,
          1004.6510000000001,
          956.188,
          907.681,
          859.132,
          810.543,
          761.918,
          713.2589999999999,
          664.567,
          615.846,
          567.097,
          518.323,
          469.526,
          420.708,
          371.87199999999996,
          323.019,
          274.153,
          225.274,
          176.386,
          127.49,
          78.58800000000001,
          29.683000000000003,
          -19.223,
          -68.128,
          -117.031,
          -165.929,
          -214.821,
          -263.703,
          -312.575,
          -361.434,
          -410.278,
          -459.105,
          -507.914,
          -556.702,
          -605.467,
          -654.2080000000001,
          -702.923,
          -751.6089999999999,
          -800.265,
          -848.8889999999999,
          -897.4789999999999,
          -946.0319999999999,
          -994.549,
          -1043.025,
          -1091.46,
          -1139.8519999999999,
          -1188.1989999999998,
          -1236.498,
          -1284.749,
          -1332.9489999999998,
          -1381.096,
          -1429.19,
          -1477.226,
          -1525.205,
          -1573.124,
          -1620.9820000000002,
          -1668.775,
          -1716.504,
          -1764.165,
          -1811.7579999999998,
          -1859.279,
          -1906.7279999999998,
          -1954.1029999999998,
          -2001.402,
          -2048.6220000000003,
          -2095.763,
          -2142.822,
          -2189.797,
          -2236.687,
          -2283.49,
          -2330.2039999999997,
          -2376.827,
          -2423.357,
          -2469.7929999999997,
          -2516.132,
          -2562.373,
          -2608.514,
          -2654.553,
          -2700.488,
          -2746.317,
          -2792.039,
          -2837.651,
          -2883.151,
          -2928.539,
          -2973.8109999999997,
          -3018.966,
          -3064.0009999999997,
          -3108.9159999999997,
          -3153.7070000000003,
          -3198.3740000000003,
          -3242.913,
          -3287.323,
          -3331.603,
          -3375.7490000000003,
          -3419.76,
          -3463.635,
          -3507.37,
          -3550.9629999999997,
          -3594.414,
          -3637.719,
          -3680.877,
          -3723.885,
          -3766.741,
          -3809.4440000000004,
          -3851.99,
          -3894.3790000000004,
          -3936.6059999999998,
          -3978.671,
          -4020.572,
          -4062.305,
          -4103.8679999999995,
          -4145.26,
          -4186.478,
          -4227.52,
          -4268.3820000000005,
          -4309.063,
          -4349.561,
          -4389.873,
          -4429.996,
          -4469.929,
          -4509.667,
          -4549.21,
          -4588.555,
          -4627.698,
          -4666.638,
          -4705.371,
          -4743.895,
          -4782.207,
          -4820.305,
          -4858.186,
          -4895.847,
          -4933.285,
          -4970.497,
          -5007.481,
          -5044.233,
          -5080.75,
          -5117.03,
          -5153.07,
          -5188.866,
          -5224.415,
          -5259.714,
          -5294.76,
          -5329.55,
          -5364.08,
          -5398.347,
          -5432.347,
          -5466.078,
          -5499.535,
          -5532.715999999999,
          -5565.616,
          -5598.232,
          -5630.561,
          -5662.598000000001,
          -5694.34,
          -5725.783,
          -5756.923000000001,
          -5787.755999999999,
          -5818.276999999999,
          -5848.484,
          -5878.371,
          -5907.934,
          -5937.17,
          -5966.0740000000005,
          -5994.641,
          -6022.866999999999,
          -6050.746999999999,
          -6078.276999999999,
          -6105.451,
          -6132.265,
          -6158.714,
          -6184.794,
          -6210.4980000000005,
          -6235.821999999999,
          -6260.76,
          -6285.308000000001,
          -6309.459,
          -6333.2080000000005,
          -6356.549,
          -6379.476,
          -6401.985,
          -6424.068,
          -6445.719,
          -6466.932,
          -6487.7,
          -6508.018,
          -6527.879,
          -6547.275,
          -6566.2,
          -6584.647,
          -6602.608,
          -6620.076,
          -6637.044,
          -6653.503000000001,
          -6669.446999999999,
          -6684.866,
          -6699.754,
          -6714.1,
          -6727.897,
          -6741.1359999999995,
          -6753.807,
          -6765.903,
          -6777.411999999999,
          -6788.326999999999,
          -6798.635,
          -6808.328,
          -6817.396,
          -6825.826999999999,
          -6833.611,
          -6840.736,
          -6847.191,
          -6852.964,
          -6858.044,
          -6862.4169999999995,
          -6866.071,
          -6868.994000000001,
          -6871.170999999999,
          -6872.59,
          -6873.235,
          -6873.092,
          -6872.147,
          -6870.384,
          -6867.786999999999,
          -6864.34,
          -6860.026999999999,
          -6854.83,
          -6848.732,
          -6841.714,
          -6833.757,
          -6824.843000000001,
          -6814.95,
          -6804.06,
          -6792.149,
          -6779.196999999999,
          -6765.181,
          -6750.079000000001,
          -6733.8640000000005,
          -6716.512,
          -6698,
          -6678.298000000001,
          -6657.38,
          -6635.218000000001,
          -6611.781999999999,
          -6587.0419999999995,
          -6560.965,
          -6533.52,
          -6504.672,
          -6474.387,
          -6442.629,
          -6409.359,
          -6374.5380000000005,
          -6338.1269999999995,
          -6300.081999999999,
          -6260.36,
          -6218.9169999999995,
          -6175.703,
          -6130.672,
          -6083.77,
          -6034.946999999999,
          -5984.146,
          -5931.311,
          -5876.382,
          -5819.295999999999,
          -5759.99,
          -5698.396,
          -5634.444,
          -5568.063,
          -5499.177,
          -5427.706999999999,
          -5353.571,
          -5276.685,
          -5196.960999999999,
          -5114.31,
          -5028.6320000000005,
          -4939.834,
          -4847.813,
          -4752.464,
          -4653.68,
          -4551.351,
          -4445.363,
          -4335.601,
          -4221.9490000000005,
          -4104.287,
          -3982.4970000000003,
          -3856.46,
          -3726.06,
          -3591.185,
          -3451.7259999999997,
          -3307.583,
          -3158.6659999999997,
          -3004.897,
          -2846.217,
          -2682.586,
          -2513.989,
          -2340.444,
          -2162.0029999999997,
          -1978.763,
          -1790.8670000000002,
          -1598.516,
          -1401.967,
          -1201.546,
          -997.6439999999999,
          -790.725,
          -581.318,
          -370.02,
          -157.484,
          55.591,
          268.472,
          480.407,
          690.6439999999999,
          898.449,
          1103.121,
          1304.008,
          1500.523,
          1692.1470000000002,
          1878.441,
          2059.042,
          2233.669,
          2402.114,
          2564.241,
          2719.975,
          2869.298,
          3012.238,
          3148.867,
          3279.285,
          3403.623,
          3522.028,
          3634.665,
          3741.71,
          3843.344,
          3939.7529999999997,
          4031.127,
          4117.648,
          4199.505,
          4276.875,
          4349.938,
          4418.863,
          4483.816,
          4544.956,
          4602.439,
          4656.359,
          4707.01,
          4754.377,
          4798.637,
          4839.914000000001,
          4878.326,
          4913.985,
          4946.999,
          4977.468,
          5005.49,
          5031.157999999999,
          5054.56,
          5075.78,
          5094.897,
          5111.99,
          5127.129,
          5140.387,
          5151.8279999999995,
          5161.514,
          5169.51,
          5175.869000000001,
          5180.65,
          5183.904,
          5185.683,
          5186.032999999999,
          5185.002,
          5182.634,
          5178.972,
          5174.057,
          5167.9259999999995,
          5160.6179999999995,
          5152.17,
          5142.615,
          5131.986,
          5120.317,
          5107.6359999999995,
          5093.975,
          5079.361,
          5063.821,
          5047.3820000000005,
          5030.07,
          5011.909000000001,
          4992.9220000000005,
          4973.130999999999,
          4952.561,
          4931.23,
          4909.16,
          4886.371,
          4862.8820000000005,
          4838.71,
          4813.875,
          4788.393,
          4762.28,
          4735.555,
          4708.232,
          4680.325,
          4651.85,
          4622.822,
          4593.253,
          4563.159000000001,
          4532.55,
          4501.441,
          4469.843,
          4437.768,
          4405.229,
          4372.236,
          4338.8009999999995,
          4304.933,
          4270.643,
          4235.942,
          4200.838,
          4165.343,
          4129.465,
          4093.212,
          4056.595,
          4019.6220000000003,
          3982.3,
          3944.638,
          3906.6440000000002,
          3868.3259999999996,
          3829.692,
          3790.748,
          3751.5029999999997,
          3711.9629999999997,
          3672.134,
          3632.025,
          3591.6409999999996,
          3550.988,
          3510.074,
          3468.9040000000005,
          3427.4840000000004,
          3385.821,
          3343.9190000000003,
          3301.7859999999996,
          3259.425,
          3216.843,
          3174.045,
          3131.035,
          3087.82,
          3044.4040000000005,
          3000.792,
          2956.988,
          2912.998,
          2868.8259999999996,
          2824.4770000000003,
          2779.954,
          2735.264,
          2690.408,
          2645.393,
          2600.221,
          2554.8979999999997,
          2509.426,
          2463.811,
          2418.055,
          2372.163,
          2326.138,
          2279.984,
          2233.705,
          2187.303,
          2140.783,
          2094.1479999999997,
          2047.402,
          2000.547,
          1953.586,
          1906.524,
          1859.3629999999998,
          1812.1070000000002,
          1764.7579999999998,
          1717.32,
          1669.795,
          1622.1870000000001,
          1574.4979999999998,
          1526.731,
          1478.89,
          1430.977,
          1382.994,
          1334.945,
          1286.8319999999999,
          1238.657,
          1190.424,
          1142.136,
          1093.7930000000001,
          1045.4,
          996.959,
          948.472,
          899.941,
          851.3689999999999,
          802.7589999999999,
          754.113,
          705.433,
          656.721,
          607.98,
          559.212,
          510.42,
          461.605,
          412.77099999999996,
          363.918,
          315.04900000000004,
          266.16700000000003,
          217.274,
          168.37099999999998,
          119.461,
          70.546,
          21.628,
          -27.291,
          -76.208,
          -125.12299999999999,
          -174.032,
          -222.93400000000003,
          -271.82599999999996,
          -320.70799999999997,
          -369.57599999999996,
          -418.42900000000003,
          -467.265,
          -516.081,
          -564.877,
          -613.65,
          -662.3969999999999,
          -711.118,
          -759.81,
          -808.472,
          -857.1010000000001,
          -905.695,
          -954.2539999999999,
          -1002.7739999999999,
          -1051.254,
          -1099.692,
          -1148.087,
          -1196.435,
          -1244.737,
          -1292.989,
          -1341.19,
          -1389.338,
          -1437.432,
          -1485.469,
          -1533.4470000000001,
          -1581.365,
          -1629.221,
          -1677.013,
          -1724.74,
          -1772.398,
          -1819.9879999999998,
          -1867.506,
          -1914.9520000000002,
          -1962.3220000000001,
          -2009.616,
          -2056.831,
          -2103.966,
          -2151.019,
          -2197.988,
          -2244.871,
          -2291.666,
          -2338.3720000000003,
          -2384.987,
          -2431.508,
          -2477.935,
          -2524.264,
          -2570.495,
          -2616.625,
          -2662.653,
          -2708.5759999999996,
          -2754.393,
          -2800.1009999999997,
          -2845.7,
          -2891.1859999999997,
          -2936.559,
          -2981.815,
          -3026.954,
          -3071.973,
          -3116.87,
          -3161.6440000000002,
          -3206.2909999999997,
          -3250.812,
          -3295.202,
          -3339.461,
          -3383.586,
          -3427.575,
          -3471.427,
          -3515.139,
          -3558.7090000000003,
          -3602.134,
          -3645.414,
          -3688.545,
          -3731.526,
          -3774.355,
          -3817.0290000000005,
          -3859.545,
          -3901.903,
          -3944.099,
          -3986.132,
          -4027.9990000000003,
          -4069.698,
          -4111.226,
          -4152.581,
          -4193.762,
          -4234.765,
          -4275.588,
          -4316.229,
          -4356.685,
          -4396.954000000001,
          -4437.034000000001,
          -4476.920999999999,
          -4516.6140000000005,
          -4556.11,
          -4595.406,
          -4634.5,
          -4673.388,
          -4712.069,
          -4750.54,
          -4788.7970000000005,
          -4826.839,
          -4864.661,
          -4902.263,
          -4939.64,
          -4976.789000000001,
          -5013.709,
          -5050.396,
          -5086.846,
          -5123.057,
          -5159.026,
          -5194.75,
          -5230.225,
          -5265.448,
          -5300.416,
          -5335.126,
          -5369.575,
          -5403.758000000001,
          -5437.673000000001,
          -5471.316999999999,
          -5504.685,
          -5537.774,
          -5570.58,
          -5603.1,
          -5635.33,
          -5667.266,
          -5698.905,
          -5730.241999999999,
          -5761.273,
          -5791.995,
          -5822.403,
          -5852.493,
          -5882.262,
          -5911.704000000001,
          -5940.815,
          -5969.592,
          -5998.028,
          -6026.12,
          -6053.863,
          -6081.253000000001,
          -6108.284000000001,
          -6134.951999999999,
          -6161.251,
          -6187.1759999999995,
          -6212.723000000001,
          -6237.8859999999995,
          -6262.659000000001,
          -6287.0380000000005,
          -6311.016,
          -6334.588000000001,
          -6357.749,
          -6380.491,
          -6402.809,
          -6424.696999999999,
          -6446.15,
          -6467.16,
          -6487.72,
          -6507.8240000000005,
          -6527.465999999999,
          -6546.639,
          -6565.334,
          -6583.545999999999,
          -6601.267,
          -6618.49,
          -6635.205,
          -6651.406999999999,
          -6667.085999999999,
          -6682.234,
          -6696.844,
          -6710.906,
          -6724.411999999999,
          -6737.353,
          -6749.718000000001,
          -6761.501,
          -6772.69,
          -6783.275,
          -6793.246,
          -6802.594,
          -6811.307,
          -6819.375,
          -6826.786,
          -6833.529,
          -6839.593000000001,
          -6844.964,
          -6849.632,
          -6853.5830000000005,
          -6856.804,
          -6859.281999999999,
          -6861.004,
          -6861.954000000001,
          -6862.119000000001,
          -6861.483,
          -6860.031999999999,
          -6857.75,
          -6854.619000000001,
          -6850.625,
          -6845.749,
          -6839.974,
          -6833.281999999999,
          -6825.654,
          -6817.07,
          -6807.5109999999995,
          -6796.956,
          -6785.385,
          -6772.774,
          -6759.102,
          -6744.345,
          -6728.48,
          -6711.481,
          -6693.323,
          -6673.978,
          -6653.422,
          -6631.6230000000005,
          -6608.553000000001,
          -6584.182,
          -6558.478,
          -6531.409000000001,
          -6502.94,
          -6473.0380000000005,
          -6441.664000000001,
          -6408.784000000001,
          -6374.355,
          -6338.34,
          -6300.694,
          -6261.376,
          -6220.338000000001,
          -6177.535,
          -6132.9169999999995,
          -6086.434,
          -6038.033,
          -5987.658,
          -5935.253000000001,
          -5880.757,
          -5824.109,
          -5765.246,
          -5704.099,
          -5640.6,
          -5574.674,
          -5506.2480000000005,
          -5435.243,
          -5361.576999999999,
          -5285.165,
          -5205.92,
          -5123.752,
          -5038.563,
          -4950.258,
          -4858.735,
          -4763.889,
          -4665.613,
          -4563.795999999999,
          -4458.325,
          -4349.084,
          -4235.955,
          -4118.821,
          -3997.5609999999997,
          -3872.0559999999996,
          -3742.191,
          -3607.85,
          -3468.925,
          -3325.3140000000003,
          -3176.926,
          -3023.6809999999996,
          -2865.5170000000003,
          -2702.39,
          -2534.2870000000003,
          -2361.217,
          -2183.2329999999997,
          -2000.425,
          -1812.93,
          -1620.9460000000001,
          -1424.723,
          -1224.5810000000001,
          -1020.905,
          -814.154,
          -604.85,
          -393.583,
          -181.00400000000002,
          32.193000000000005,
          245.27700000000002,
          457.49699999999996,
          668.1010000000001,
          876.352,
          1081.545,
          1283.025,
          1480.1970000000001,
          1672.537,
          1859.5970000000002,
          2041.0079999999998,
          2216.481,
          2385.802,
          2548.825,
          2705.473,
          2855.72,
          2999.591,
          3137.15,
          3268.498,
          3393.76,
          3513.0820000000003,
          3626.627,
          3734.567,
          3837.0840000000003,
          3934.363,
          4026.591,
          4113.9529999999995,
          4196.634,
          4274.814,
          4348.67,
          4418.373,
          4484.088,
          4545.977,
          4604.191,
          4658.88,
          4710.184,
          4758.24,
          4803.175,
          4845.1140000000005,
          4884.1759999999995,
          4920.471,
          4954.108,
          4985.189,
          5013.81,
          5040.066,
          5064.045,
          5085.831,
          5105.504,
          5123.142,
          5138.817,
          5152.6,
          5164.557,
          5174.751,
          5183.2429999999995,
          5190.093,
          5195.354,
          5199.081,
          5201.323,
          5202.13,
          5201.548,
          5199.622,
          5196.393,
          5191.905,
          5186.194,
          5179.299,
          5171.258,
          5162.102,
          5151.867,
          5140.585999999999,
          5128.286,
          5115.001,
          5100.755999999999,
          5085.58,
          5069.499,
          5052.54,
          5034.726,
          5016.081,
          4996.628,
          4976.389,
          4955.3859999999995,
          4933.638,
          4911.166,
          4887.99,
          4864.127,
          4839.595,
          4814.411,
          4788.594,
          4762.159000000001,
          4735.122,
          4707.497,
          4679.3,
          4650.545999999999,
          4621.248,
          4591.418,
          4561.073,
          4530.222,
          4498.879,
          4467.055,
          4434.763,
          4402.014,
          4368.819,
          4335.188,
          4301.1320000000005,
          4266.661,
          4231.784000000001,
          4196.512,
          4160.854,
          4124.819,
          4088.4159999999997,
          4051.653,
          4014.539,
          3977.0820000000003,
          3939.289,
          3901.17,
          3862.732,
          3823.9809999999998,
          3784.926,
          3745.573,
          3705.929,
          3666.0009999999997,
          3625.795,
          3585.3190000000004,
          3544.578,
          3503.579,
          3462.328,
          3420.83,
          3379.091,
          3337.118,
          3294.915,
          3252.489,
          3209.843,
          3166.985,
          3123.9179999999997,
          3080.647,
          3037.178,
          2993.5159999999996,
          2949.664,
          2905.6290000000004,
          2861.413,
          2817.0229999999997,
          2772.461,
          2727.7329999999997,
          2682.842,
          2637.7940000000003,
          2592.591,
          2547.238,
          2501.739,
          2456.097,
          2410.317,
          2364.402,
          2318.356,
          2272.1820000000002,
          2225.885,
          2179.466,
          2132.931,
          2086.282,
          2039.523,
          1992.656,
          1945.6860000000001,
          1898.614,
          1851.4460000000001,
          1804.183,
          1756.829,
          1709.386,
          1661.858,
          1614.247,
          1566.557,
          1518.79,
          1470.9489999999998,
          1423.0379999999998,
          1375.057,
          1327.011,
          1278.902,
          1230.733,
          1182.506,
          1134.224,
          1085.889,
          1037.504,
          989.072,
          940.5939999999999,
          892.074,
          843.513,
          794.914,
          746.28,
          697.613,
          648.915,
          600.188,
          551.436,
          502.659,
          453.86,
          405.041,
          356.20599999999996,
          307.355,
          258.491,
          209.61599999999999,
          160.732,
          111.84200000000001,
          62.946999999999996,
          14.049000000000001,
          -34.848,
          -83.745,
          -132.637,
          -181.524,
          -230.403,
          -279.27299999999997,
          -328.131,
          -376.975,
          -425.80300000000005,
          -474.61400000000003,
          -523.406,
          -572.1759999999999,
          -620.922,
          -669.6439999999999,
          -718.3380000000001,
          -767.003,
          -815.637,
          -864.238,
          -912.804,
          -961.334,
          -1009.825,
          -1058.276,
          -1106.685,
          -1155.049,
          -1203.368,
          -1251.638,
          -1299.86,
          -1348.029,
          -1396.146,
          -1444.207,
          -1492.211,
          -1540.1570000000002,
          -1588.0420000000001,
          -1635.864,
          -1683.622,
          -1731.315,
          -1778.9389999999999,
          -1826.493,
          -1873.976,
          -1921.386,
          -1968.72,
          -2015.977,
          -2063.156,
          -2110.254,
          -2157.269,
          -2204.2,
          -2251.044,
          -2297.801,
          -2344.468,
          -2391.0429999999997,
          -2437.524,
          -2483.91,
          -2530.199,
          -2576.388,
          -2622.4759999999997,
          -2668.462,
          -2714.342,
          -2760.116,
          -2805.781,
          -2851.335,
          -2896.777,
          -2942.1040000000003,
          -2987.315,
          -3032.408,
          -3077.38,
          -3122.23,
          -3166.9559999999997,
          -3211.5559999999996,
          -3256.027,
          -3300.368,
          -3344.577,
          -3388.652,
          -3432.59,
          -3476.39,
          -3520.0490000000004,
          -3563.566,
          -3606.938,
          -3650.163,
          -3693.239,
          -3736.165,
          -3778.937,
          -3821.553,
          -3864.012,
          -3906.3109999999997,
          -3948.448,
          -3990.42,
          -4032.2259999999997,
          -4073.863,
          -4115.3279999999995,
          -4156.62,
          -4197.736,
          -4238.673,
          -4279.43,
          -4320.004,
          -4360.392,
          -4400.592000000001,
          -4440.601,
          -4480.417,
          -4520.038,
          -4559.46,
          -4598.681,
          -4637.6990000000005,
          -4676.5109999999995,
          -4715.1140000000005,
          -4753.505999999999,
          -4791.682,
          -4829.642,
          -4867.3820000000005,
          -4904.899,
          -4942.19,
          -4979.253,
          -5016.084,
          -5052.681,
          -5089.04,
          -5125.157999999999,
          -5161.032,
          -5196.66,
          -5232.038,
          -5267.161999999999,
          -5302.03,
          -5336.637,
          -5370.981,
          -5405.058000000001,
          -5438.865,
          -5472.399,
          -5505.655,
          -5538.63,
          -5571.32,
          -5603.722,
          -5635.831999999999,
          -5667.647,
          -5699.161,
          -5730.371,
          -5761.274,
          -5791.8640000000005,
          -5822.138000000001,
          -5852.092,
          -5881.722,
          -5911.023,
          -5939.99,
          -5968.619000000001,
          -5996.905,
          -6024.845,
          -6052.432,
          -6079.6630000000005,
          -6106.531999999999,
          -6133.035,
          -6159.166,
          -6184.92,
          -6210.293000000001,
          -6235.276999999999,
          -6259.868,
          -6284.061,
          -6307.85,
          -6331.229,
          -6354.191999999999,
          -6376.733,
          -6398.845,
          -6420.524,
          -6441.762,
          -6462.552,
          -6482.89,
          -6502.766,
          -6522.175,
          -6541.11,
          -6559.562,
          -6577.526,
          -6594.994000000001,
          -6611.956999999999,
          -6628.406999999999,
          -6644.338000000001,
          -6659.74,
          -6674.605,
          -6688.925,
          -6702.691999999999,
          -6715.895,
          -6728.526,
          -6740.575,
          -6752.033,
          -6762.891,
          -6773.137,
          -6782.7609999999995,
          -6791.754,
          -6800.103,
          -6807.799,
          -6814.829000000001,
          -6821.182,
          -6826.845,
          -6831.807,
          -6836.056,
          -6839.576999999999,
          -6842.357,
          -6844.384,
          -6845.642,
          -6846.118,
          -6845.795999999999,
          -6844.661,
          -6842.698,
          -6839.89,
          -6836.221,
          -6831.674,
          -6826.23,
          -6819.8730000000005,
          -6812.581999999999,
          -6804.34,
          -6795.125,
          -6784.918000000001,
          -6773.696999999999,
          -6761.44,
          -6748.126,
          -6733.731,
          -6718.23,
          -6701.6,
          -6683.814,
          -6664.846,
          -6644.668000000001,
          -6623.253000000001,
          -6600.571,
          -6576.590999999999,
          -6551.283,
          -6524.6140000000005,
          -6496.549,
          -6467.055,
          -6436.095,
          -6403.630999999999,
          -6369.624,
          -6334.035,
          -6296.821,
          -6257.938,
          -6217.342,
          -6174.985,
          -6130.819,
          -6084.7919999999995,
          -6036.853,
          -5986.945,
          -5935.013000000001,
          -5880.996,
          -5824.834,
          -5766.460999999999,
          -5705.81,
          -5642.814,
          -5577.398,
          -5509.486999999999,
          -5439.005,
          -5365.866999999999,
          -5289.991,
          -5211.29,
          -5129.67,
          -5045.039000000001,
          -4957.298,
          -4866.346,
          -4772.0779999999995,
          -4674.388,
          -4573.163,
          -4468.292,
          -4359.657,
          -4247.142,
          -4130.627,
          -4009.992,
          -3885.119,
          -3755.889,
          -3622.188,
          -3483.906,
          -3340.9390000000003,
          -3193.195,
          -3040.594,
          -2883.0679999999998,
          -2720.575,
          -2553.094,
          -2380.635,
          -2203.245,
          -2021.0079999999998,
          -1834.06,
          -1642.59,
          -1446.844,
          -1247.134,
          -1043.84,
          -837.413,
          -628.369,
          -417.29400000000004,
          -204.83,
          8.331,
          221.46099999999998,
          433.81199999999995,
          644.629,
          853.177,
          1058.747,
          1260.68,
          1458.3729999999998,
          1651.2979999999998,
          1838.9979999999998,
          2021.099,
          2197.303,
          2367.388,
          2531.205,
          2688.6679999999997,
          2839.745,
          2984.458,
          3122.865,
          3255.063,
          3381.1740000000004,
          3501.342,
          3615.7270000000003,
          3724.5,
          3827.841,
          3925.935,
          4018.965,
          4107.1179999999995,
          4190.5779999999995,
          4269.525,
          4344.134,
          4414.579000000001,
          4481.022,
          4543.626,
          4602.544,
          4657.923,
          4709.906,
          4758.626,
          4804.215999999999,
          4846.798,
          4886.49,
          4923.405,
          4957.651,
          4989.331,
          5018.541,
          5045.376,
          5069.923,
          5092.268,
          5112.492,
          5130.670999999999,
          5146.878,
          5161.185,
          5173.656,
          5184.358,
          5193.35,
          5200.691,
          5206.436,
          5210.64,
          5213.352,
          5214.622,
          5214.495,
          5213.018,
          5210.233,
          5206.18,
          5200.9,
          5194.429,
          5186.806,
          5178.063,
          5168.235,
          5157.354,
          5145.45,
          5132.554,
          5118.695,
          5103.899,
          5088.193,
          5071.604,
          5054.155,
          5035.871,
          5016.773,
          4996.8859999999995,
          4976.229,
          4954.8240000000005,
          4932.689,
          4909.846,
          4886.313,
          4862.106,
          4837.245,
          4811.745,
          4785.624,
          4758.895,
          4731.576,
          4703.682,
          4675.225,
          4646.222,
          4616.684,
          4586.626,
          4556.059,
          4524.997,
          4493.451,
          4461.433,
          4428.955,
          4396.027,
          4362.66,
          4328.865,
          4294.652,
          4260.03,
          4225.01,
          4189.601,
          4153.812,
          4117.652,
          4081.1290000000004,
          4044.252,
          4007.0290000000005,
          3969.468,
          3931.578,
          3893.366,
          3854.8379999999997,
          3816.0029999999997,
          3776.868,
          3737.4390000000003,
          3697.724,
          3657.7290000000003,
          3617.46,
          3576.9240000000004,
          3536.1279999999997,
          3495.077,
          3453.777,
          3412.2329999999997,
          3370.453,
          3328.441,
          3286.202,
          3243.742,
          3201.066,
          3158.18,
          3115.0879999999997,
          3071.796,
          3028.308,
          2984.6290000000004,
          2940.763,
          2896.715,
          2852.49,
          2808.092,
          2763.525,
          2718.7940000000003,
          2673.902,
          2628.8540000000003,
          2583.653,
          2538.305,
          2492.812,
          2447.178,
          2401.407,
          2355.5029999999997,
          2309.47,
          2263.311,
          2217.029,
          2170.6279999999997,
          2124.111,
          2077.482,
          2030.744,
          1983.901,
          1936.955,
          1889.9089999999999,
          1842.767,
          1795.5320000000002,
          1748.207,
          1700.7939999999999,
          1653.297,
          1605.719,
          1558.0620000000001,
          1510.33,
          1462.524,
          1414.649,
          1366.705,
          1318.6970000000001,
          1270.627,
          1222.498,
          1174.3110000000001,
          1126.07,
          1077.777,
          1029.435,
          981.046,
          932.613,
          884.137,
          835.622,
          787.07,
          738.4830000000001,
          689.8639999999999,
          641.214,
          592.536,
          543.832,
          495.105,
          446.35699999999997,
          397.59,
          348.806,
          300.007,
          251.195,
          202.37400000000002,
          153.54399999999998,
          104.70700000000001,
          55.867,
          7.025,
          -41.818000000000005,
          -90.65799999999999,
          -139.494,
          -188.325,
          -237.14700000000002,
          -285.959,
          -334.759,
          -383.54400000000004,
          -432.314,
          -481.066,
          -529.798,
          -578.509,
          -627.195,
          -675.8560000000001,
          -724.4889999999999,
          -773.0930000000001,
          -821.666,
          -870.205,
          -918.709,
          -967.176,
          -1015.605,
          -1063.992,
          -1112.337,
          -1160.638,
          -1208.893,
          -1257.099,
          -1305.256,
          -1353.36,
          -1401.412,
          -1449.4070000000002,
          -1497.346,
          -1545.225,
          -1593.0439999999999,
          -1640.8,
          -1688.491,
          -1736.116,
          -1783.672,
          -1831.1589999999999,
          -1878.5739999999998,
          -1925.915,
          -1973.18,
          -2020.369,
          -2067.478,
          -2114.506,
          -2161.451,
          -2208.312,
          -2255.0860000000002,
          -2301.771,
          -2348.366,
          -2394.87,
          -2441.279,
          -2487.592,
          -2533.808,
          -2579.924,
          -2625.9390000000003,
          -2671.8509999999997,
          -2717.657,
          -2763.3559999999998,
          -2808.946,
          -2854.425,
          -2899.7909999999997,
          -2945.042,
          -2990.176,
          -3035.192,
          -3080.087,
          -3124.8590000000004,
          -3169.507,
          -3214.028,
          -3258.42,
          -3302.6820000000002,
          -3346.81,
          -3390.804,
          -3434.6620000000003,
          -3478.38,
          -3521.9570000000003,
          -3565.3909999999996,
          -3608.68,
          -3651.821,
          -3694.813,
          -3737.653,
          -3780.3390000000004,
          -3822.869,
          -3865.241,
          -3907.453,
          -3949.5009999999997,
          -3991.385,
          -4033.1009999999997,
          -4074.6479999999997,
          -4116.022,
          -4157.223,
          -4198.246,
          -4239.090999999999,
          -4279.753,
          -4320.232,
          -4360.524,
          -4400.628,
          -4440.54,
          -4480.258,
          -4519.779,
          -4559.101,
          -4598.221,
          -4637.137,
          -4675.845,
          -4714.344,
          -4752.63,
          -4790.701,
          -4828.554,
          -4866.185,
          -4903.593,
          -4940.773,
          -4977.724,
          -5014.442,
          -5050.924,
          -5087.167,
          -5123.168,
          -5158.924,
          -5194.432,
          -5229.688,
          -5264.689,
          -5299.432,
          -5333.914000000001,
          -5368.13,
          -5402.079000000001,
          -5435.755,
          -5469.155,
          -5502.276999999999,
          -5535.116,
          -5567.668000000001,
          -5599.931,
          -5631.899,
          -5663.57,
          -5694.938,
          -5726.001,
          -5756.753000000001,
          -5787.191,
          -5817.311,
          -5847.109,
          -5876.579000000001,
          -5905.719,
          -5934.522,
          -5962.984,
          -5991.102,
          -6018.87,
          -6046.283,
          -6073.335999999999,
          -6100.025,
          -6126.345,
          -6152.29,
          -6177.855,
          -6203.035,
          -6227.823,
          -6252.215999999999,
          -6276.206,
          -6299.789000000001,
          -6322.9580000000005,
          -6345.7080000000005,
          -6368.031,
          -6389.923000000001,
          -6411.376,
          -6432.385,
          -6452.941999999999,
          -6473.041,
          -6492.6759999999995,
          -6511.838000000001,
          -6530.52,
          -6548.715999999999,
          -6566.419,
          -6583.619000000001,
          -6600.31,
          -6616.483,
          -6632.130999999999,
          -6647.244000000001,
          -6661.815,
          -6675.834,
          -6689.294,
          -6702.183000000001,
          -6714.494000000001,
          -6726.217,
          -6737.340999999999,
          -6747.857,
          -6757.755,
          -6767.023,
          -6775.651,
          -6783.629,
          -6790.944,
          -6797.584,
          -6803.539000000001,
          -6808.795,
          -6813.340999999999,
          -6817.1630000000005,
          -6820.246999999999,
          -6822.581,
          -6824.15,
          -6824.94,
          -6824.935,
          -6824.121,
          -6822.483,
          -6820.003000000001,
          -6816.666,
          -6812.454000000001,
          -6807.35,
          -6801.335,
          -6794.391,
          -6786.5,
          -6777.64,
          -6767.7919999999995,
          -6756.935,
          -6745.045,
          -6732.103,
          -6718.0830000000005,
          -6702.963000000001,
          -6686.717,
          -6669.321,
          -6650.746999999999,
          -6630.969,
          -6609.956999999999,
          -6587.683000000001,
          -6564.116999999999,
          -6539.228,
          -6512.983,
          -6485.347,
          -6456.2880000000005,
          -6425.768,
          -6393.75,
          -6360.195,
          -6325.064,
          -6288.313,
          -6249.901,
          -6209.78,
          -6167.906,
          -6124.229,
          -6078.698,
          -6031.2609999999995,
          -5981.863,
          -5930.448,
          -5876.956,
          -5821.3240000000005,
          -5763.491,
          -5703.388000000001,
          -5640.946,
          -5576.094,
          -5508.755,
          -5438.853,
          -5366.305,
          -5291.026999999999,
          -5212.933,
          -5131.93,
          -5047.924,
          -4960.819,
          -4870.512,
          -4776.899,
          -4679.873,
          -4579.323,
          -4475.137,
          -4367.196,
          -4255.385,
          -4139.583,
          -4019.672,
          -3895.5290000000005,
          -3767.039,
          -3634.085,
          -3496.5559999999996,
          -3354.348,
          -3207.367,
          -3055.5290000000005,
          -2898.768,
          -2737.0370000000003,
          -2570.312,
          -2398.601,
          -2221.944,
          -2040.425,
          -1854.171,
          -1663.365,
          -1468.25,
          -1269.129,
          -1066.377,
          -860.435,
          -651.814,
          -441.093,
          -228.908,
          -15.946,
          197.06799999999998,
          409.389,
          620.263,
          828.954,
          1034.749,
          1236.987,
          1435.06,
          1628.432,
          1816.642,
          1999.306,
          2176.12,
          2346.856,
          2511.357,
          2669.5290000000005,
          2821.3379999999997,
          2966.798,
          3105.9640000000004,
          3238.928,
          3365.81,
          3486.7490000000003,
          3601.903,
          3711.4429999999998,
          3815.546,
          3914.3940000000002,
          4008.171,
          4097.064,
          4181.254,
          4260.9220000000005,
          4336.2429999999995,
          4407.388,
          4474.523,
          4537.807,
          4597.395,
          4653.441,
          4706.068,
          4755.43,
          4801.65,
          4844.853,
          4885.157,
          4922.675,
          4957.515,
          4989.779,
          5019.565,
          5046.967000000001,
          5072.0740000000005,
          5094.97,
          5115.737,
          5134.451,
          5151.187,
          5166.014,
          5179,
          5190.208,
          5199.7,
          5207.535,
          5213.767,
          5218.451,
          5221.637,
          5223.376,
          5223.710999999999,
          5222.691,
          5220.356,
          5216.749,
          5211.909000000001,
          5205.873,
          5198.679,
          5190.36,
          5180.952,
          5170.486,
          5158.992,
          5146.501,
          5133.042,
          5118.642,
          5103.3279999999995,
          5087.125,
          5070.06,
          5052.154,
          5033.431,
          5013.914000000001,
          4993.624,
          4972.581,
          4950.805,
          4928.317,
          4905.135,
          4881.276,
          4856.758,
          4831.598,
          4805.814,
          4779.419,
          4752.43,
          4724.862,
          4696.728,
          4668.045,
          4638.8240000000005,
          4609.079000000001,
          4578.822,
          4548.067,
          4516.825,
          4485.109,
          4452.929,
          4420.295999999999,
          4387.221,
          4353.715,
          4319.788,
          4285.45,
          4250.710999999999,
          4215.58,
          4180.066,
          4144.179,
          4107.9259999999995,
          4071.316,
          4034.3579999999997,
          3997.059,
          3959.428,
          3921.473,
          3883.2,
          3844.617,
          3805.7309999999998,
          3766.5490000000004,
          3727.079,
          3687.3259999999996,
          3647.297,
          3606.9990000000003,
          3566.437,
          3525.619,
          3484.5490000000004,
          3443.2340000000004,
          3401.68,
          3359.8909999999996,
          3317.8740000000003,
          3275.633,
          3233.175,
          3190.5029999999997,
          3147.6240000000003,
          3104.542,
          3061.262,
          3017.789,
          2974.1279999999997,
          2930.282,
          2886.257,
          2842.0570000000002,
          2797.6859999999997,
          2753.1479999999997,
          2708.448,
          2663.59,
          2618.577,
          2573.415,
          2528.105,
          2482.654,
          2437.063,
          2391.337,
          2345.481,
          2299.496,
          2253.386,
          2207.155,
          2160.8070000000002,
          2114.345,
          2067.772,
          2021.0910000000001,
          1974.305,
          1927.4189999999999,
          1880.434,
          1833.355,
          1786.183,
          1738.922,
          1691.575,
          1644.145,
          1596.635,
          1549.047,
          1501.384,
          1453.649,
          1405.845,
          1357.975,
          1310.0410000000002,
          1262.045,
          1213.991,
          1165.881,
          1117.7169999999999,
          1069.502,
          1021.2389999999999,
          972.929,
          924.576,
          876.181,
          827.748,
          779.278,
          730.773,
          682.237,
          633.6709999999999,
          585.078,
          536.46,
          487.81800000000004,
          439.157,
          390.476,
          341.779,
          293.068,
          244.345,
          195.612,
          146.872,
          98.125,
          49.375,
          0.623,
          -48.128,
          -96.87700000000001,
          -145.622,
          -194.36,
          -243.08900000000003,
          -291.808,
          -340.515,
          -389.207,
          -437.88300000000004,
          -486.541,
          -535.178,
          -583.793,
          -632.385,
          -680.95,
          -729.487,
          -777.995,
          -826.471,
          -874.913,
          -923.321,
          -971.691,
          -1020.0210000000001,
          -1068.3110000000001,
          -1116.558,
          -1164.761,
          -1212.917,
          -1261.024,
          -1309.0819999999999,
          -1357.0870000000002,
          -1405.0379999999998,
          -1452.934,
          -1500.773,
          -1548.5520000000001,
          -1596.269,
          -1643.924,
          -1691.514,
          -1739.0379999999998,
          -1786.493,
          -1833.878,
          -1881.19,
          -1928.4289999999999,
          -1975.592,
          -2022.6779999999999,
          -2069.6839999999997,
          -2116.609,
          -2163.45,
          -2210.2070000000003,
          -2256.877,
          -2303.458,
          -2349.949,
          -2396.348,
          -2442.652,
          -2488.86,
          -2534.971,
          -2580.981,
          -2626.89,
          -2672.695,
          -2718.3940000000002,
          -2763.987,
          -2809.47,
          -2854.841,
          -2900.1,
          -2945.243,
          -2990.2690000000002,
          -3035.176,
          -3079.962,
          -3124.625,
          -3169.163,
          -3213.574,
          -3257.8559999999998,
          -3302.006,
          -3346.0240000000003,
          -3389.906,
          -3433.651,
          -3477.257,
          -3520.7209999999995,
          -3564.042,
          -3607.217,
          -3650.245,
          -3693.1220000000003,
          -3735.847,
          -3778.4179999999997,
          -3820.8320000000003,
          -3863.0879999999997,
          -3905.1820000000002,
          -3947.113,
          -3988.8790000000004,
          -4030.4759999999997,
          -4071.9040000000005,
          -4113.157999999999,
          -4154.238,
          -4195.141,
          -4235.863,
          -4276.404,
          -4316.759,
          -4356.928,
          -4396.907,
          -4436.694,
          -4476.286,
          -4515.681,
          -4554.876,
          -4593.8679999999995,
          -4632.655,
          -4671.233,
          -4709.601,
          -4747.755999999999,
          -4785.694,
          -4823.413,
          -4860.91,
          -4898.182,
          -4935.226,
          -4972.039000000001,
          -5008.6179999999995,
          -5044.960999999999,
          -5081.063,
          -5116.9220000000005,
          -5152.535,
          -5187.898,
          -5223.008,
          -5257.861999999999,
          -5292.456999999999,
          -5326.789000000001,
          -5360.854,
          -5394.65,
          -5428.172,
          -5461.418000000001,
          -5494.383000000001,
          -5527.063,
          -5559.455,
          -5591.556,
          -5623.36,
          -5654.865,
          -5686.066,
          -5716.959,
          -5747.541,
          -5777.806,
          -5807.751,
          -5837.371999999999,
          -5866.6630000000005,
          -5895.62,
          -5924.24,
          -5952.517,
          -5980.446,
          -6008.023,
          -6035.243,
          -6062.1,
          -6088.590999999999,
          -6114.709,
          -6140.45,
          -6165.808000000001,
          -6190.778,
          -6215.354,
          -6239.531,
          -6263.302,
          -6286.661999999999,
          -6309.605,
          -6332.126,
          -6354.217,
          -6375.871999999999,
          -6397.085,
          -6417.849,
          -6438.159000000001,
          -6458.005,
          -6477.383000000001,
          -6496.284000000001,
          -6514.701999999999,
          -6532.629,
          -6550.056,
          -6566.977,
          -6583.384,
          -6599.268,
          -6614.62,
          -6629.433000000001,
          -6643.698,
          -6657.406,
          -6670.548000000001,
          -6683.1140000000005,
          -6695.095,
          -6706.481,
          -6717.262,
          -6727.429,
          -6736.969,
          -6745.8730000000005,
          -6754.129,
          -6761.727,
          -6768.654,
          -6774.898,
          -6780.448,
          -6785.29,
          -6789.4130000000005,
          -6792.803000000001,
          -6795.445,
          -6797.326999999999,
          -6798.434,
          -6798.75,
          -6798.2609999999995,
          -6796.951999999999,
          -6794.806,
          -6791.807,
          -6787.937,
          -6783.18,
          -6777.517,
          -6770.929,
          -6763.398,
          -6754.904,
          -6745.4259999999995,
          -6734.944,
          -6723.435,
          -6710.878000000001,
          -6697.249,
          -6682.524,
          -6666.68,
          -6649.69,
          -6631.529,
          -6612.168000000001,
          -6591.58,
          -6569.736999999999,
          -6546.607,
          -6522.16,
          -6496.361999999999,
          -6469.182,
          -6440.584,
          -6410.531999999999,
          -6378.9890000000005,
          -6345.9169999999995,
          -6311.274,
          -6275.02,
          -6237.111,
          -6197.5019999999995,
          -6156.147,
          -6112.996999999999,
          -6068.0019999999995,
          -6021.108,
          -5972.263000000001,
          -5921.409000000001,
          -5868.486999999999,
          -5813.435,
          -5756.191,
          -5696.686,
          -5634.853,
          -5570.619000000001,
          -5503.909000000001,
          -5434.646,
          -5362.749,
          -5288.133000000001,
          -5210.710999999999,
          -5130.392,
          -5047.083,
          -4960.685,
          -4871.098,
          -4778.219,
          -4681.938,
          -4582.146,
          -4478.73,
          -4371.573,
          -4260.558,
          -4145.565,
          -4026.475,
          -3903.1659999999997,
          -3775.52,
          -3643.422,
          -3506.76,
          -3365.426,
          -3219.328,
          -3068.3790000000004,
          -2912.51,
          -2751.673,
          -2585.841,
          -2415.016,
          -2239.237,
          -2058.5820000000003,
          -1873.172,
          -1683.1870000000001,
          -1488.86,
          -1290.489,
          -1088.44,
          -883.148,
          -675.118,
          -464.918,
          -253.18099999999998,
          -40.586999999999996,
          172.145,
          384.27,
          595.039,
          803.711,
          1009.577,
          1211.9669999999999,
          1410.2720000000002,
          1603.9489999999998,
          1792.529,
          1975.625,
          2152.923,
          2324.188,
          2489.257,
          2648.031,
          2800.467,
          2946.575,
          3086.406,
          3220.048,
          3347.615,
          3469.2459999999996,
          3585.0959999999995,
          3695.3309999999997,
          3800.1290000000004,
          3899.6690000000003,
          3994.135,
          4083.712,
          4168.581,
          4248.92,
          4324.906,
          4396.71,
          4464.495,
          4528.424,
          4588.648,
          4645.316,
          4698.569,
          4748.545,
          4795.37,
          4839.170999999999,
          4880.065,
          4918.167,
          4953.582,
          4986.415,
          5016.763,
          5044.721,
          5070.376,
          5093.814,
          5115.116,
          5134.36,
          5151.6179999999995,
          5166.962,
          5180.459,
          5192.173,
          5202.165,
          5210.494000000001,
          5217.215,
          5222.3820000000005,
          5226.0470000000005,
          5228.259,
          5229.063,
          5228.505,
          5226.63,
          5223.477,
          5219.085999999999,
          5213.495,
          5206.741,
          5198.86,
          5189.883,
          5179.845,
          5168.775,
          5156.704000000001,
          5143.661,
          5129.673,
          5114.766,
          5098.969,
          5082.304,
          5064.794,
          5046.465999999999,
          5027.338,
          5007.434,
          4986.774,
          4965.378,
          4943.267,
          4920.457,
          4896.968,
          4872.817,
          4848.021,
          4822.596,
          4796.559,
          4769.924,
          4742.707,
          4714.9220000000005,
          4686.584,
          4657.706,
          4628.3,
          4598.38,
          4567.96,
          4537.049,
          4505.661,
          4473.807,
          4441.497,
          4408.7429999999995,
          4375.556,
          4341.945,
          4307.92,
          4273.491,
          4238.667,
          4203.458,
          4167.873,
          4131.920999999999,
          4095.6090000000004,
          4058.947,
          4021.942,
          3984.6020000000003,
          3946.935,
          3908.948,
          3870.6490000000003,
          3832.045,
          3793.143,
          3753.95,
          3714.472,
          3674.716,
          3634.688,
          3594.395,
          3553.843,
          3513.0370000000003,
          3471.9840000000004,
          3430.6890000000003,
          3389.158,
          3347.397,
          3305.41,
          3263.203,
          3220.781,
          3178.15,
          3135.3140000000003,
          3092.277,
          3049.046,
          3005.623,
          2962.015,
          2918.225,
          2874.259,
          2830.119,
          2785.8109999999997,
          2741.3390000000004,
          2696.7070000000003,
          2651.9179999999997,
          2606.978,
          2561.889,
          2516.655,
          2471.281,
          2425.77,
          2380.125,
          2334.351,
          2288.45,
          2242.427,
          2196.284,
          2150.025,
          2103.654,
          2057.173,
          2010.586,
          1963.895,
          1917.105,
          1870.2179999999998,
          1823.2379999999998,
          1776.1660000000002,
          1729.007,
          1681.7620000000002,
          1634.4360000000001,
          1587.03,
          1539.5479999999998,
          1491.9920000000002,
          1444.365,
          1396.67,
          1348.9089999999999,
          1301.086,
          1253.202,
          1205.26,
          1157.263,
          1109.213,
          1061.113,
          1012.965,
          964.7710000000001,
          916.535,
          868.258,
          819.943,
          771.592,
          723.2080000000001,
          674.7919999999999,
          626.347,
          577.875,
          529.379,
          480.86,
          432.32099999999997,
          383.764,
          335.19199999999995,
          286.605,
          238.00799999999998,
          189.4,
          140.785,
          92.165,
          43.542,
          -5.083,
          -53.706,
          -102.32700000000001,
          -150.94299999999998,
          -199.553,
          -248.153,
          -296.743,
          -345.32,
          -393.88199999999995,
          -442.42699999999996,
          -490.954,
          -539.461,
          -587.945,
          -636.404,
          -684.8380000000001,
          -733.243,
          -781.618,
          -829.962,
          -878.2719999999999,
          -926.546,
          -974.783,
          -1022.98,
          -1071.136,
          -1119.249,
          -1167.318,
          -1215.339,
          -1263.312,
          -1311.235,
          -1359.105,
          -1406.922,
          -1454.682,
          -1502.385,
          -1550.029,
          -1597.611,
          -1645.13,
          -1692.5839999999998,
          -1739.971,
          -1787.29,
          -1834.5379999999998,
          -1881.714,
          -1928.815,
          -1975.8410000000001,
          -2022.79,
          -2069.658,
          -2116.445,
          -2163.149,
          -2209.768,
          -2256.3,
          -2302.743,
          -2349.096,
          -2395.356,
          -2441.521,
          -2487.591,
          -2533.562,
          -2579.433,
          -2625.202,
          -2670.868,
          -2716.428,
          -2761.88,
          -2807.223,
          -2852.454,
          -2897.572,
          -2942.574,
          -2987.4590000000003,
          -3032.225,
          -3076.87,
          -3121.3909999999996,
          -3165.7870000000003,
          -3210.0559999999996,
          -3254.195,
          -3298.203,
          -3342.078,
          -3385.817,
          -3429.4179999999997,
          -3472.88,
          -3516.2009999999996,
          -3559.377,
          -3602.408,
          -3645.29,
          -3688.022,
          -3730.6020000000003,
          -3773.027,
          -3815.2940000000003,
          -3857.403,
          -3899.35,
          -3941.134,
          -3982.7509999999997,
          -4024.2009999999996,
          -4065.4790000000003,
          -4106.585,
          -4147.515,
          -4188.267,
          -4228.839,
          -4269.228,
          -4309.432,
          -4349.4490000000005,
          -4389.275,
          -4428.907999999999,
          -4468.347,
          -4507.587,
          -4546.626,
          -4585.463,
          -4624.093,
          -4662.515,
          -4700.725,
          -4738.721,
          -4776.499,
          -4814.058,
          -4851.394,
          -4888.504,
          -4925.3859999999995,
          -4962.036,
          -4998.451,
          -5034.628,
          -5070.564,
          -5106.255999999999,
          -5141.7,
          -5176.894,
          -5211.834,
          -5246.517,
          -5280.939,
          -5315.097,
          -5348.988,
          -5382.607,
          -5415.951999999999,
          -5449.019,
          -5481.804,
          -5514.303000000001,
          -5546.512,
          -5578.428000000001,
          -5610.047,
          -5641.3640000000005,
          -5672.3769999999995,
          -5703.08,
          -5733.469,
          -5763.54,
          -5793.289000000001,
          -5822.7119999999995,
          -5851.803000000001,
          -5880.56,
          -5908.976,
          -5937.047,
          -5964.769,
          -5992.1359999999995,
          -6019.143,
          -6045.786999999999,
          -6072.06,
          -6097.959,
          -6123.478,
          -6148.611999999999,
          -6173.355,
          -6197.701,
          -6221.645,
          -6245.181,
          -6268.302,
          -6291.004,
          -6313.28,
          -6335.1230000000005,
          -6356.526,
          -6377.484,
          -6397.99,
          -6418.036999999999,
          -6437.618,
          -6456.726,
          -6475.353,
          -6493.493,
          -6511.137,
          -6528.278,
          -6544.908,
          -6561.018,
          -6576.601,
          -6591.648,
          -6606.15,
          -6620.099,
          -6633.485,
          -6646.3,
          -6658.533,
          -6670.175,
          -6681.215999999999,
          -6691.646,
          -6701.454000000001,
          -6710.629,
          -6719.161,
          -6727.039000000001,
          -6734.25,
          -6740.781999999999,
          -6746.625,
          -6751.764,
          -6756.188,
          -6759.884,
          -6762.835999999999,
          -6765.033,
          -6766.459,
          -6767.1,
          -6766.94,
          -6765.965,
          -6764.158,
          -6761.5019999999995,
          -6757.982,
          -6753.579000000001,
          -6748.275,
          -6742.052,
          -6734.892,
          -6726.774,
          -6717.677,
          -6707.5830000000005,
          -6696.467,
          -6684.309,
          -6671.085999999999,
          -6656.773,
          -6641.346,
          -6624.781,
          -6607.05,
          -6588.128000000001,
          -6567.984,
          -6546.592,
          -6523.92,
          -6499.939,
          -6474.615,
          -6447.915,
          -6419.806,
          -6390.25,
          -6359.210999999999,
          -6326.651999999999,
          -6292.53,
          -6256.805,
          -6219.435,
          -6180.374,
          -6139.575,
          -6096.991999999999,
          -6052.573,
          -6006.265,
          -5958.016,
          -5907.769,
          -5855.464,
          -5801.04,
          -5744.435,
          -5685.581999999999,
          -5624.411,
          -5560.852,
          -5494.83,
          -5426.267,
          -5355.081999999999,
          -5281.191999999999,
          -5204.51,
          -5124.946,
          -5042.404,
          -4956.79,
          -4868,
          -4775.933,
          -4680.48,
          -4581.532999999999,
          -4478.975,
          -4372.694,
          -4262.572,
          -4148.487,
          -4030.3190000000004,
          -3907.949,
          -3781.258,
          -3650.127,
          -3514.447,
          -3374.1079999999997,
          -3229.0159999999996,
          -3079.083,
          -2924.239,
          -2764.4309999999996,
          -2599.631,
          -2429.837,
          -2255.084,
          -2075.444,
          -1891.036,
          -1702.029,
          -1508.6529999999998,
          -1311.1970000000001,
          -1110.02,
          -905.55,
          -698.2819999999999,
          -488.777,
          -277.661,
          -65.608,
          146.66899999999998,
          358.42800000000005,
          568.922,
          777.4119999999999,
          983.185,
          1185.572,
          1383.9560000000001,
          1577.79,
          1766.601,
          1949.9920000000002,
          2127.643,
          2299.313,
          2464.8320000000003,
          2624.093,
          2777.0490000000004,
          2923.704,
          3064.103,
          3198.3309999999997,
          3326.498,
          3448.739,
          3565.2070000000003,
          3676.065,
          3781.489,
          3881.656,
          3976.7509999999997,
          4066.954,
          4152.447,
          4233.407999999999,
          4310.013,
          4382.43,
          4450.826,
          4515.359,
          4576.183,
          4633.447,
          4687.29,
          4737.849,
          4785.254,
          4829.629,
          4871.090999999999,
          4909.755999999999,
          4945.729,
          4979.1140000000005,
          5010.01,
          5038.509,
          5064.701,
          5088.6720000000005,
          5110.501,
          5130.266,
          5148.043,
          5163.9,
          5177.905,
          5190.122,
          5200.613,
          5209.437,
          5216.649,
          5222.302,
          5226.45,
          5229.139,
          5230.418,
          5230.331,
          5228.9220000000005,
          5226.232,
          5222.3,
          5217.165,
          5210.863,
          5203.429,
          5194.898,
          5185.3,
          5174.668,
          5163.031,
          5150.42,
          5136.86,
          5122.379,
          5107.003,
          5090.755999999999,
          5073.663,
          5055.747,
          5037.029,
          5017.531,
          4997.275,
          4976.281,
          4954.567,
          4932.152,
          4909.056,
          4885.295,
          4860.8859999999995,
          4835.845,
          4810.19,
          4783.935,
          4757.094,
          4729.683,
          4701.717000000001,
          4673.207,
          4644.168,
          4614.613,
          4584.553,
          4554.002,
          4522.97,
          4491.47,
          4459.513,
          4427.109,
          4394.269,
          4361.002,
          4327.32,
          4293.232,
          4258.747,
          4223.875,
          4188.624,
          4153.003,
          4117.021,
          4080.6859999999997,
          4044.006,
          4006.99,
          3969.643,
          3931.975,
          3893.993,
          3855.704,
          3817.115,
          3778.232,
          3739.063,
          3699.614,
          3659.8909999999996,
          3619.9,
          3579.6490000000003,
          3539.1409999999996,
          3498.385,
          3457.385,
          3416.147,
          3374.676,
          3332.978,
          3291.058,
          3248.921,
          3206.573,
          3164.018,
          3121.261,
          3078.3070000000002,
          3035.16,
          2991.8259999999996,
          2948.308,
          2904.612,
          2860.74,
          2816.699,
          2772.491,
          2728.1220000000003,
          2683.594,
          2638.913,
          2594.081,
          2549.103,
          2503.9829999999997,
          2458.724,
          2413.33,
          2367.804,
          2322.15,
          2276.371,
          2230.472,
          2184.4539999999997,
          2138.323,
          2092.08,
          2045.729,
          1999.273,
          1952.7160000000001,
          1906.06,
          1859.309,
          1812.465,
          1765.5320000000002,
          1718.511,
          1671.408,
          1624.223,
          1576.96,
          1529.621,
          1482.21,
          1434.729,
          1387.181,
          1339.568,
          1291.893,
          1244.1589999999999,
          1196.367,
          1148.521,
          1100.624,
          1052.6760000000002,
          1004.682,
          956.643,
          908.562,
          860.441,
          812.2819999999999,
          764.0880000000001,
          715.8610000000001,
          667.6030000000001,
          619.317,
          571.005,
          522.668,
          474.31,
          425.93199999999996,
          377.537,
          329.12699999999995,
          280.703,
          232.268,
          183.824,
          135.373,
          86.917,
          38.458,
          -10.002,
          -58.46,
          -106.916,
          -155.366,
          -203.80900000000003,
          -252.24200000000002,
          -300.665,
          -349.075,
          -397.469,
          -445.847,
          -494.20599999999996,
          -542.544,
          -590.86,
          -639.15,
          -687.415,
          -735.6510000000001,
          -783.857,
          -832.0310000000001,
          -880.171,
          -928.275,
          -976.342,
          -1024.369,
          -1072.355,
          -1120.297,
          -1168.195,
          -1216.045,
          -1263.847,
          -1311.599,
          -1359.2979999999998,
          -1406.943,
          -1454.533,
          -1502.0639999999999,
          -1549.536,
          -1596.9460000000001,
          -1644.293,
          -1691.575,
          -1738.79,
          -1785.9370000000001,
          -1833.013,
          -1880.016,
          -1926.9460000000001,
          -1973.799,
          -2020.575,
          -2067.271,
          -2113.885,
          -2160.416,
          -2206.862,
          -2253.221,
          -2299.491,
          -2345.67,
          -2391.757,
          -2437.749,
          -2483.645,
          -2529.4429999999998,
          -2575.14,
          -2620.736,
          -2666.228,
          -2711.614,
          -2756.8920000000003,
          -2802.0609999999997,
          -2847.118,
          -2892.062,
          -2936.89,
          -2981.6009999999997,
          -3026.192,
          -3070.6620000000003,
          -3115.009,
          -3159.23,
          -3203.323,
          -3247.288,
          -3291.12,
          -3334.82,
          -3378.383,
          -3421.809,
          -3465.095,
          -3508.24,
          -3551.24,
          -3594.094,
          -3636.8,
          -3679.3559999999998,
          -3721.758,
          -3764.006,
          -3806.0959999999995,
          -3848.027,
          -3889.797,
          -3931.402,
          -3972.841,
          -4014.112,
          -4055.211,
          -4096.138,
          -4136.888,
          -4177.46,
          -4217.852,
          -4258.061,
          -4298.084,
          -4337.919,
          -4377.564,
          -4417.015,
          -4456.271,
          -4495.3279999999995,
          -4534.184,
          -4572.837,
          -4611.282999999999,
          -4649.519,
          -4687.544,
          -4725.354,
          -4762.946,
          -4800.318,
          -4837.465999999999,
          -4874.388,
          -4911.08,
          -4947.541,
          -4983.765,
          -5019.751,
          -5055.495,
          -5090.994000000001,
          -5126.246,
          -5161.245,
          -5195.99,
          -5230.477,
          -5264.701999999999,
          -5298.6630000000005,
          -5332.355,
          -5365.774,
          -5398.918000000001,
          -5431.781999999999,
          -5464.3640000000005,
          -5496.658,
          -5528.6630000000005,
          -5560.371999999999,
          -5591.783,
          -5622.891,
          -5653.691999999999,
          -5684.183000000001,
          -5714.358,
          -5744.214,
          -5773.746999999999,
          -5802.951,
          -5831.823,
          -5860.358,
          -5888.5509999999995,
          -5916.397,
          -5943.891,
          -5971.03,
          -5997.806,
          -6024.217,
          -6050.255999999999,
          -6075.918000000001,
          -6101.198,
          -6126.09,
          -6150.588000000001,
          -6174.688,
          -6198.383000000001,
          -6221.6669999999995,
          -6244.534000000001,
          -6266.978,
          -6288.994000000001,
          -6310.573,
          -6331.710999999999,
          -6352.401,
          -6372.634,
          -6392.405,
          -6411.706,
          -6430.531,
          -6448.871,
          -6466.721,
          -6484.07,
          -6500.9130000000005,
          -6517.24,
          -6533.043000000001,
          -6548.315,
          -6563.045999999999,
          -6577.227,
          -6590.85,
          -6603.906,
          -6616.385,
          -6628.276,
          -6639.571,
          -6650.259,
          -6660.329000000001,
          -6669.772,
          -6678.576,
          -6686.73,
          -6694.222,
          -6701.041,
          -6707.175,
          -6712.61,
          -6717.335,
          -6721.3369999999995,
          -6724.601,
          -6727.113,
          -6728.861999999999,
          -6729.829000000001,
          -6730.0019999999995,
          -6729.365,
          -6727.901999999999,
          -6725.596,
          -6722.431,
          -6718.39,
          -6713.454000000001,
          -6707.605,
          -6700.8240000000005,
          -6693.092,
          -6684.389,
          -6674.693,
          -6663.984,
          -6652.2390000000005,
          -6639.435,
          -6625.55,
          -6610.558000000001,
          -6594.434,
          -6577.153,
          -6558.687,
          -6539.008000000001,
          -6518.089,
          -6495.898,
          -6472.406,
          -6447.58,
          -6421.387,
          -6393.793000000001,
          -6364.762,
          -6334.257,
          -6302.241,
          -6268.673000000001,
          -6233.5109999999995,
          -6196.715,
          -6158.238,
          -6118.034000000001,
          -6076.056,
          -6032.253000000001,
          -5986.575,
          -5938.965999999999,
          -5889.37,
          -5837.73,
          -5783.984,
          -5728.07,
          -5669.92,
          -5609.467,
          -5546.64,
          -5481.3640000000005,
          -5413.562,
          -5343.153,
          -5270.055,
          -5194.181,
          -5115.44,
          -5033.74,
          -4948.984,
          -4861.071,
          -4769.896,
          -4675.355,
          -4577.338,
          -4475.73,
          -4370.416,
          -4261.279,
          -4148.2,
          -4031.058,
          -3909.7309999999998,
          -3784.103,
          -3654.054,
          -3519.473,
          -3380.2509999999997,
          -3236.29,
          -3087.502,
          -2933.815,
          -2775.1740000000004,
          -2611.548,
          -2442.931,
          -2269.354,
          -2090.883,
          -1907.6329999999998,
          -1719.767,
          -1527.506,
          -1331.134,
          -1131.001,
          -927.525,
          -721.195,
          -512.563,
          -302.246,
          -90.911,
          120.73200000000001,
          331.949,
          541.994,
          750.1310000000001,
          955.6439999999999,
          1157.863,
          1356.1670000000001,
          1550.005,
          1738.8970000000002,
          1922.44,
          2100.3070000000002,
          2272.251,
          2438.094,
          2597.723,
          2751.085,
          2898.177,
          3039.0429999999997,
          3173.759,
          3302.433,
          3425.197,
          3542.199,
          3653.603,
          3759.579,
          3860.305,
          3955.962,
          4046.7290000000003,
          4132.789000000001,
          4214.317,
          4291.4890000000005,
          4364.473,
          4433.433,
          4498.53,
          4559.915,
          4617.644,
          4672.137,
          4723.249,
          4771.2029999999995,
          4816.125,
          4858.130999999999,
          4897.335999999999,
          4933.846,
          4967.765,
          4999.191,
          5028.217000000001,
          5054.933,
          5079.424,
          5101.77,
          5122.05,
          5140.335999999999,
          5156.7,
          5171.209,
          5183.928,
          5194.916,
          5204.234,
          5211.937,
          5218.079000000001,
          5222.712,
          5225.883,
          5227.642,
          5228.031,
          5227.095,
          5224.876,
          5221.412,
          5216.742,
          5210.902,
          5203.929,
          5195.854,
          5186.710999999999,
          5176.53,
          5165.343,
          5153.178,
          5140.062,
          5126.022,
          5111.085,
          5095.275,
          5078.616,
          5061.130999999999,
          5042.843,
          5023.772,
          5003.94,
          4983.3679999999995,
          4962.075,
          4940.0779999999995,
          4917.396,
          4894.048,
          4870.05,
          4845.418,
          4820.169,
          4794.318,
          4767.88,
          4740.869000000001,
          4713.3,
          4685.187,
          4656.541,
          4627.377,
          4597.707,
          4567.543,
          4536.897,
          4505.78,
          4474.204000000001,
          4442.179,
          4409.715999999999,
          4376.825,
          4343.516,
          4309.8,
          4275.684,
          4241.179,
          4206.294,
          4171.036,
          4135.416,
          4099.441,
          4063.119,
          4026.458,
          3989.466,
          3952.15,
          3914.5190000000002,
          3876.578,
          3838.335,
          3799.797,
          3760.9709999999995,
          3721.863,
          3682.4790000000003,
          3642.8259999999996,
          3602.91,
          3562.737,
          3522.313,
          3481.643,
          3440.7329999999997,
          3399.5890000000004,
          3358.216,
          3316.619,
          3274.804,
          3232.775,
          3190.538,
          3148.097,
          3105.458,
          3062.6240000000003,
          3019.6009999999997,
          2976.3920000000003,
          2933.0029999999997,
          2889.438,
          2845.7,
          2801.795,
          2757.7259999999997,
          2713.498,
          2669.113,
          2624.577,
          2579.893,
          2535.065,
          2490.097,
          2444.991,
          2399.752,
          2354.384,
          2308.89,
          2263.272,
          2217.535,
          2171.6820000000002,
          2125.716,
          2079.641,
          2033.4589999999998,
          1987.174,
          1940.7879999999998,
          1894.306,
          1847.729,
          1801.0610000000001,
          1754.305,
          1707.463,
          1660.5379999999998,
          1613.5339999999999,
          1566.453,
          1519.2979999999998,
          1472.07,
          1424.774,
          1377.412,
          1329.986,
          1282.499,
          1234.953,
          1187.351,
          1139.6960000000001,
          1091.989,
          1044.234,
          996.432,
          948.586,
          900.699,
          852.773,
          804.81,
          756.812,
          708.7819999999999,
          660.722,
          612.633,
          564.52,
          516.382,
          468.224,
          420.046,
          371.851,
          323.64099999999996,
          275.41900000000004,
          227.18599999999998,
          178.94400000000002,
          130.695,
          82.44200000000001,
          34.187,
          -14.069,
          -62.323,
          -110.574,
          -158.82,
          -207.058,
          -255.28599999999997,
          -303.503,
          -351.707,
          -399.89599999999996,
          -448.06800000000004,
          -496.22,
          -544.352,
          -592.46,
          -640.544,
          -688.602,
          -736.6310000000001,
          -784.6289999999999,
          -832.595,
          -880.528,
          -928.424,
          -976.283,
          -1024.1019999999999,
          -1071.879,
          -1119.613,
          -1167.303,
          -1214.945,
          -1262.538,
          -1310.0810000000001,
          -1357.5720000000001,
          -1405.0079999999998,
          -1452.389,
          -1499.711,
          -1546.974,
          -1594.1760000000002,
          -1641.3139999999999,
          -1688.3870000000002,
          -1735.3929999999998,
          -1782.3310000000001,
          -1829.1979999999999,
          -1875.9920000000002,
          -1922.713,
          -1969.3570000000002,
          -2015.924,
          -2062.411,
          -2108.8160000000003,
          -2155.139,
          -2201.376,
          -2247.526,
          -2293.587,
          -2339.5570000000002,
          -2385.435,
          -2431.219,
          -2476.906,
          -2522.495,
          -2567.984,
          -2613.371,
          -2658.6540000000005,
          -2703.8309999999997,
          -2748.901,
          -2793.86,
          -2838.7090000000003,
          -2883.4440000000004,
          -2928.063,
          -2972.565,
          -3016.948,
          -3061.2090000000003,
          -3105.347,
          -3149.36,
          -3193.245,
          -3237.0009999999997,
          -3280.625,
          -3324.116,
          -3367.4709999999995,
          -3410.6890000000003,
          -3453.7659999999996,
          -3496.702,
          -3539.493,
          -3582.139,
          -3624.636,
          -3666.982,
          -3709.176,
          -3751.2140000000004,
          -3793.0959999999995,
          -3834.8179999999998,
          -3876.3779999999997,
          -3917.7740000000003,
          -3959.0040000000004,
          -4000.065,
          -4040.955,
          -4081.671,
          -4122.212,
          -4162.5740000000005,
          -4202.755,
          -4242.753,
          -4282.566,
          -4322.19,
          -4361.623,
          -4400.863,
          -4439.907,
          -4478.753,
          -4517.397,
          -4555.837,
          -4594.07,
          -4632.093,
          -4669.904,
          -4707.5,
          -4744.878,
          -4782.035,
          -4818.968,
          -4855.675,
          -4892.151,
          -4928.395,
          -4964.402,
          -5000.170999999999,
          -5035.697,
          -5070.978,
          -5106.01,
          -5140.79,
          -5175.315,
          -5209.58,
          -5243.584,
          -5277.321,
          -5310.79,
          -5343.986,
          -5376.905,
          -5409.544,
          -5441.899,
          -5473.965999999999,
          -5505.741,
          -5537.221,
          -5568.401,
          -5599.278,
          -5629.847,
          -5660.104,
          -5690.045,
          -5719.665,
          -5748.96,
          -5777.925,
          -5806.557,
          -5834.85,
          -5862.8,
          -5890.401,
          -5917.65,
          -5944.54,
          -5971.066999999999,
          -5997.227,
          -6023.013000000001,
          -6048.42,
          -6073.443,
          -6098.076,
          -6122.313,
          -6146.149,
          -6169.579000000001,
          -6192.595,
          -6215.191999999999,
          -6237.365,
          -6259.105,
          -6280.406999999999,
          -6301.264,
          -6321.67,
          -6341.616999999999,
          -6361.099,
          -6380.108,
          -6398.637,
          -6416.679,
          -6434.226,
          -6451.27,
          -6467.803000000001,
          -6483.816,
          -6499.302,
          -6514.2519999999995,
          -6528.658,
          -6542.509,
          -6555.797,
          -6568.513000000001,
          -6580.647,
          -6592.189,
          -6603.13,
          -6613.4580000000005,
          -6623.1630000000005,
          -6632.235,
          -6640.661999999999,
          -6648.432,
          -6655.534000000001,
          -6661.956999999999,
          -6667.687,
          -6672.7119999999995,
          -6677.019,
          -6680.595,
          -6683.425,
          -6685.496999999999,
          -6686.795,
          -6687.303000000001,
          -6687.008000000001,
          -6685.893,
          -6683.943,
          -6681.139,
          -6677.465999999999,
          -6672.905,
          -6667.438,
          -6661.047,
          -6653.710999999999,
          -6645.411,
          -6636.1269999999995,
          -6625.835999999999,
          -6614.518,
          -6602.149,
          -6588.705,
          -6574.164000000001,
          -6558.499,
          -6541.685,
          -6523.695,
          -6504.5019999999995,
          -6484.076999999999,
          -6462.39,
          -6439.411,
          -6415.107,
          -6389.446999999999,
          -6362.395,
          -6333.918000000001,
          -6303.977,
          -6272.535,
          -6239.552,
          -6204.988,
          -6168.799,
          -6130.941999999999,
          -6091.371,
          -6050.039000000001,
          -6006.894,
          -5961.887,
          -5914.9619999999995,
          -5866.065,
          -5815.137,
          -5762.118,
          -5706.945,
          -5649.553000000001,
          -5589.874,
          -5527.835,
          -5463.365,
          -5396.3859999999995,
          -5326.818,
          -5254.578,
          -5179.58,
          -5101.735,
          -5020.9490000000005,
          -4937.127,
          -4850.167,
          -4759.969,
          -4666.424,
          -4569.424,
          -4468.855,
          -4364.603,
          -4256.55,
          -4144.5779999999995,
          -4028.565,
          -3908.3909999999996,
          -3783.937,
          -3655.085,
          -3521.722,
          -3383.739,
          -3241.0359999999996,
          -3093.525,
          -2941.131,
          -2783.796,
          -2621.487,
          -2454.196,
          -2281.946,
          -2104.802,
          -1922.871,
          -1736.31,
          -1545.3339999999998,
          -1350.2179999999998,
          -1151.3039999999999,
          -949.0010000000001,
          -743.789,
          -536.211,
          -326.876,
          -116.443,
          94.385,
          304.878,
          514.2959999999999,
          721.9,
          926.9810000000001,
          1128.862,
          1326.921,
          1520.6029999999998,
          1709.421,
          1892.967,
          2070.908,
          2242.988,
          2409.024,
          2568.895,
          2722.5440000000003,
          2869.962,
          3011.185,
          3146.2870000000003,
          3275.3720000000003,
          3398.567,
          3516.0170000000003,
          3627.883,
          3734.3340000000003,
          3835.545,
          3931.695,
          4022.9629999999997,
          4109.527,
          4191.565,
          4269.25,
          4342.749,
          4412.227,
          4477.842000000001,
          4539.746,
          4598.088,
          4653.0070000000005,
          4704.639,
          4753.112,
          4798.552,
          4841.077,
          4880.7970000000005,
          4917.822,
          4952.255,
          4984.193,
          5013.73,
          5040.955,
          5065.952,
          5088.804,
          5109.588,
          5128.376,
          5145.241,
          5160.249,
          5173.463,
          5184.948,
          5194.759,
          5202.9529999999995,
          5209.585,
          5214.705,
          5218.362,
          5220.605,
          5221.476,
          5221.02,
          5219.279,
          5216.291,
          5212.096,
          5206.729,
          5200.226,
          5192.62,
          5183.944,
          5174.229,
          5163.505999999999,
          5151.802,
          5139.146,
          5125.564,
          5111.083,
          5095.728,
          5079.521,
          5062.487,
          5044.648,
          5026.024,
          5006.639,
          4986.51,
          4965.657999999999,
          4944.101,
          4921.859,
          4898.947,
          4875.384,
          4851.185,
          4826.367,
          4800.946,
          4774.936,
          4748.351,
          4721.207,
          4693.516,
          4665.292,
          4636.548,
          4607.295,
          4577.5470000000005,
          4547.316,
          4516.612,
          4485.447,
          4453.831,
          4421.775,
          4389.291,
          4356.3859999999995,
          4323.072,
          4289.358,
          4255.252,
          4220.764,
          4185.903,
          4150.677,
          4115.094,
          4079.163,
          4042.8920000000003,
          4006.2870000000003,
          3969.3579999999997,
          3932.111,
          3894.553,
          3856.691,
          3818.533,
          3780.0840000000003,
          3741.353,
          3702.344,
          3663.0640000000003,
          3623.52,
          3583.717,
          3543.6609999999996,
          3503.3579999999997,
          3462.813,
          3422.032,
          3381.0209999999997,
          3339.785,
          3298.329,
          3256.657,
          3214.776,
          3172.6890000000003,
          3130.401,
          3087.9179999999997,
          3045.243,
          3002.382,
          2959.3390000000004,
          2916.118,
          2872.724,
          2829.16,
          2785.43,
          2741.54,
          2697.492,
          2653.29,
          2608.94,
          2564.4429999999998,
          2519.804,
          2475.027,
          2430.115,
          2385.072,
          2339.9,
          2294.605,
          2249.188,
          2203.654,
          2158.006,
          2112.246,
          2066.3779999999997,
          2020.405,
          1974.3310000000001,
          1928.1570000000002,
          1881.888,
          1835.526,
          1789.0739999999998,
          1742.535,
          1695.912,
          1649.207,
          1602.424,
          1555.565,
          1508.632,
          1461.629,
          1414.559,
          1367.422,
          1320.223,
          1272.964,
          1225.647,
          1178.275,
          1130.85,
          1083.375,
          1035.8519999999999,
          988.283,
          940.671,
          893.0189999999999,
          845.327,
          797.6,
          749.8380000000001,
          702.045,
          654.222,
          606.372,
          558.497,
          510.599,
          462.68,
          414.74199999999996,
          366.788,
          318.819,
          270.83799999999997,
          222.847,
          174.847,
          126.84100000000001,
          78.831,
          30.819000000000003,
          -17.194000000000003,
          -65.204,
          -113.211,
          -161.21200000000002,
          -209.205,
          -257.189,
          -305.161,
          -353.12,
          -401.06300000000005,
          -448.98900000000003,
          -496.89599999999996,
          -544.781,
          -592.644,
          -640.482,
          -688.293,
          -736.075,
          -783.827,
          -831.547,
          -879.232,
          -926.882,
          -974.493,
          -1022.066,
          -1069.596,
          -1117.083,
          -1164.526,
          -1211.921,
          -1259.267,
          -1306.563,
          -1353.807,
          -1400.996,
          -1448.13,
          -1495.205,
          -1542.221,
          -1589.1760000000002,
          -1636.067,
          -1682.894,
          -1729.6529999999998,
          -1776.344,
          -1822.965,
          -1869.513,
          -1915.987,
          -1962.386,
          -2008.7060000000001,
          -2054.947,
          -2101.107,
          -2147.183,
          -2193.175,
          -2239.0789999999997,
          -2284.895,
          -2330.62,
          -2376.2529999999997,
          -2421.791,
          -2467.2329999999997,
          -2512.577,
          -2557.822,
          -2602.964,
          -2648.002,
          -2692.935,
          -2737.761,
          -2782.4770000000003,
          -2827.0809999999997,
          -2871.572,
          -2915.948,
          -2960.2070000000003,
          -3004.3459999999995,
          -3048.364,
          -3092.259,
          -3136.0290000000005,
          -3179.671,
          -3223.184,
          -3266.566,
          -3309.8140000000003,
          -3352.927,
          -3395.902,
          -3438.738,
          -3481.4309999999996,
          -3523.9809999999998,
          -3566.384,
          -3608.639,
          -3650.744,
          -3692.696,
          -3734.493,
          -3776.133,
          -3817.614,
          -3858.933,
          -3900.0879999999997,
          -3941.077,
          -3981.8959999999997,
          -4022.545,
          -4063.02,
          -4103.32,
          -4143.441,
          -4183.380999999999,
          -4223.139,
          -4262.71,
          -4302.093,
          -4341.286,
          -4380.284000000001,
          -4419.087,
          -4457.691,
          -4496.094,
          -4534.292,
          -4572.282999999999,
          -4610.065,
          -4647.634,
          -4684.988,
          -4722.124,
          -4759.038,
          -4795.729,
          -4832.192,
          -4868.4259999999995,
          -4904.4259999999995,
          -4940.19,
          -4975.715,
          -5010.997,
          -5046.032999999999,
          -5080.82,
          -5115.354,
          -5149.633,
          -5183.652,
          -5217.409000000001,
          -5250.9,
          -5284.121,
          -5317.068,
          -5349.7390000000005,
          -5382.128000000001,
          -5414.233,
          -5446.049,
          -5477.573,
          -5508.8009999999995,
          -5539.728,
          -5570.351,
          -5600.666,
          -5630.6669999999995,
          -5660.352,
          -5689.714,
          -5718.751,
          -5747.456999999999,
          -5775.829000000001,
          -5803.86,
          -5831.547,
          -5858.885,
          -5885.868,
          -5912.491999999999,
          -5938.7519999999995,
          -5964.642,
          -5990.156999999999,
          -6015.291,
          -6040.04,
          -6064.397,
          -6088.357,
          -6111.914000000001,
          -6135.062,
          -6157.795,
          -6180.108,
          -6201.991999999999,
          -6223.443,
          -6244.453,
          -6265.016,
          -6285.125,
          -6304.774,
          -6323.954000000001,
          -6342.658,
          -6360.88,
          -6378.611,
          -6395.844,
          -6412.571,
          -6428.784000000001,
          -6444.474,
          -6459.633000000001,
          -6474.253000000001,
          -6488.323,
          -6501.835999999999,
          -6514.781,
          -6527.15,
          -6538.933000000001,
          -6550.12,
          -6560.6990000000005,
          -6570.661999999999,
          -6579.996,
          -6588.691999999999,
          -6596.736999999999,
          -6604.12,
          -6610.829000000001,
          -6616.852,
          -6622.1759999999995,
          -6626.789000000001,
          -6630.677,
          -6633.825,
          -6636.222,
          -6637.852,
          -6638.6990000000005,
          -6638.75,
          -6637.986999999999,
          -6636.397,
          -6633.960999999999,
          -6630.6630000000005,
          -6626.484,
          -6621.408,
          -6615.414000000001,
          -6608.485,
          -6600.6,
          -6591.738,
          -6581.879,
          -6571,
          -6559.08,
          -6546.094,
          -6532.02,
          -6516.831999999999,
          -6500.503000000001,
          -6483.01,
          -6464.321999999999,
          -6444.4130000000005,
          -6423.2519999999995,
          -6400.81,
          -6377.054,
          -6351.951999999999,
          -6325.471,
          -6297.575,
          -6268.228,
          -6237.392,
          -6205.026999999999,
          -6171.094,
          -6135.55,
          -6098.35,
          -6059.451,
          -6018.803000000001,
          -5976.358,
          -5932.065,
          -5885.871,
          -5837.718000000001,
          -5787.552,
          -5735.311,
          -5680.933000000001,
          -5624.352,
          -5565.5019999999995,
          -5504.311,
          -5440.706999999999,
          -5374.613,
          -5305.951,
          -5234.637,
          -5160.585,
          -5083.708,
          -5003.912,
          -4921.102,
          -4835.178,
          -4746.037,
          -4653.575,
          -4557.682,
          -4458.245,
          -4355.151,
          -4248.282,
          -4137.518,
          -4022.741,
          -3903.83,
          -3780.663,
          -3653.1259999999997,
          -3521.1020000000003,
          -3384.4829999999997,
          -3243.1690000000003,
          -3097.0679999999998,
          -2946.1059999999998,
          -2790.2209999999995,
          -2629.3759999999997,
          -2463.561,
          -2292.7960000000003,
          -2117.139,
          -1936.692,
          -1751.605,
          -1562.086,
          -1368.4029999999998,
          -1170.887,
          -969.939,
          -766.029,
          -559.692,
          -351.526,
          -142.184,
          67.64,
          277.224,
          485.82800000000003,
          692.72,
          897.188,
          1098.557,
          1296.201,
          1489.5620000000001,
          1678.1470000000002,
          1861.5420000000001,
          2039.408,
          2211.4829999999997,
          2377.576,
          2537.561,
          2691.373,
          2838.998,
          2980.467,
          3115.85,
          3245.244,
          3368.7740000000003,
          3486.583,
          3598.827,
          3705.672,
          3807.2909999999997,
          3903.862,
          3995.562,
          4082.567,
          4165.055,
          4243.196,
          4317.157999999999,
          4387.103,
          4453.191,
          4515.571,
          4574.392,
          4629.793,
          4681.909000000001,
          4730.869000000001,
          4776.795999999999,
          4819.81,
          4860.021,
          4897.537,
          4932.462,
          4964.893,
          4994.923,
          5022.641,
          5048.133,
          5071.478,
          5092.755,
          5112.037,
          5129.395,
          5144.895,
          5158.602,
          5170.5779999999995,
          5180.88,
          5189.565,
          5196.687,
          5202.295999999999,
          5206.443,
          5209.173,
          5210.532,
          5210.562,
          5209.306,
          5206.803,
          5203.092000000001,
          5198.207,
          5192.186,
          5185.061,
          5176.865,
          5167.629,
          5157.383,
          5146.156,
          5133.976,
          5120.869000000001,
          5106.862,
          5091.978,
          5076.2429999999995,
          5059.679,
          5042.309,
          5024.153,
          5005.234,
          4985.571,
          4965.183,
          4944.089,
          4922.308,
          4899.857,
          4876.753,
          4853.013,
          4828.652,
          4803.686,
          4778.13,
          4751.999,
          4725.306,
          4698.066,
          4670.29,
          4641.994000000001,
          4613.188,
          4583.8859999999995,
          4554.098,
          4523.835999999999,
          4493.112,
          4461.937,
          4430.32,
          4398.273,
          4365.804,
          4332.924,
          4299.643,
          4265.969,
          4231.912,
          4197.48,
          4162.681,
          4127.525,
          4092.0190000000002,
          4056.171,
          4019.989,
          3983.4809999999998,
          3946.653,
          3909.513,
          3872.0679999999998,
          3834.325,
          3796.2909999999997,
          3757.9709999999995,
          3719.373,
          3680.5029999999997,
          3641.367,
          3601.9709999999995,
          3562.32,
          3522.421,
          3482.2790000000005,
          3441.8990000000003,
          3401.288,
          3360.449,
          3319.389,
          3278.113,
          3236.625,
          3194.93,
          3153.034,
          3110.94,
          3068.6540000000005,
          3026.18,
          2983.522,
          2940.684,
          2897.672,
          2854.489,
          2811.138,
          2767.625,
          2723.954,
          2680.127,
          2636.1490000000003,
          2592.024,
          2547.756,
          2503.347,
          2458.803,
          2414.125,
          2369.3179999999998,
          2324.386,
          2279.331,
          2234.156,
          2188.866,
          2143.4629999999997,
          2097.95,
          2052.331,
          2006.608,
          1960.785,
          1914.865,
          1868.851,
          1822.745,
          1776.55,
          1730.269,
          1683.906,
          1637.4620000000002,
          1590.941,
          1544.345,
          1497.6779999999999,
          1450.94,
          1404.136,
          1357.267,
          1310.337,
          1263.347,
          1216.3,
          1169.1989999999998,
          1122.046,
          1074.844,
          1027.595,
          980.3,
          932.9630000000001,
          885.586,
          838.172,
          790.721,
          743.237,
          695.722,
          648.178,
          600.607,
          553.012,
          505.394,
          457.756,
          410.099,
          362.42699999999996,
          314.74,
          267.041,
          219.333,
          171.61599999999999,
          123.89399999999999,
          76.168,
          28.439,
          -19.289,
          -67.015,
          -114.73700000000001,
          -162.453,
          -210.16099999999997,
          -257.85900000000004,
          -305.546,
          -353.219,
          -400.876,
          -448.51599999999996,
          -496.13599999999997,
          -543.736,
          -591.312,
          -638.863,
          -686.388,
          -733.8839999999999,
          -781.3489999999999,
          -828.7819999999999,
          -876.181,
          -923.544,
          -970.8689999999999,
          -1018.155,
          -1065.399,
          -1112.599,
          -1159.755,
          -1206.864,
          -1253.924,
          -1300.934,
          -1347.891,
          -1394.795,
          -1441.642,
          -1488.432,
          -1535.162,
          -1581.8310000000001,
          -1628.4370000000001,
          -1674.9779999999998,
          -1721.453,
          -1767.859,
          -1814.194,
          -1860.4579999999999,
          -1906.6470000000002,
          -1952.761,
          -1998.7979999999998,
          -2044.755,
          -2090.631,
          -2136.423,
          -2182.131,
          -2227.7529999999997,
          -2273.286,
          -2318.728,
          -2364.078,
          -2409.335,
          -2454.495,
          -2499.5570000000002,
          -2544.52,
          -2589.381,
          -2634.139,
          -2678.7909999999997,
          -2723.337,
          -2767.772,
          -2812.097,
          -2856.308,
          -2900.405,
          -2944.384,
          -2988.245,
          -3031.9840000000004,
          -3075.6,
          -3119.092,
          -3162.4559999999997,
          -3205.692,
          -3248.796,
          -3291.7670000000003,
          -3334.603,
          -3377.302,
          -3419.861,
          -3462.2790000000005,
          -3504.553,
          -3546.6809999999996,
          -3588.6609999999996,
          -3630.491,
          -3672.1679999999997,
          -3713.69,
          -3755.0559999999996,
          -3796.263,
          -3837.308,
          -3878.1890000000003,
          -3918.9040000000005,
          -3959.45,
          -3999.8259999999996,
          -4040.0290000000005,
          -4080.0559999999996,
          -4119.904,
          -4159.573,
          -4199.058,
          -4238.358,
          -4277.469,
          -4316.39,
          -4355.117,
          -4393.649,
          -4431.982,
          -4470.113,
          -4508.04,
          -4545.7609999999995,
          -4583.272,
          -4620.57,
          -4657.654,
          -4694.519,
          -4731.163,
          -4767.583,
          -4803.776,
          -4839.7390000000005,
          -4875.468,
          -4910.962,
          -4946.215,
          -4981.226,
          -5015.991,
          -5050.5070000000005,
          -5084.771,
          -5118.778,
          -5152.526,
          -5186.0109999999995,
          -5219.229,
          -5252.178000000001,
          -5284.852,
          -5317.25,
          -5349.366,
          -5381.198,
          -5412.74,
          -5443.99,
          -5474.943,
          -5505.594,
          -5535.941,
          -5565.979,
          -5595.704000000001,
          -5625.111,
          -5654.195,
          -5682.953,
          -5711.379,
          -5739.47,
          -5767.22,
          -5794.625,
          -5821.68,
          -5848.379,
          -5874.718000000001,
          -5900.691,
          -5926.293000000001,
          -5951.52,
          -5976.365,
          -6000.823,
          -6024.888000000001,
          -6048.554,
          -6071.816,
          -6094.668000000001,
          -6117.103,
          -6139.115,
          -6160.698,
          -6181.845,
          -6202.549,
          -6222.805,
          -6242.604,
          -6261.94,
          -6280.806,
          -6299.195,
          -6317.098000000001,
          -6334.508000000001,
          -6351.4169999999995,
          -6367.816999999999,
          -6383.7,
          -6399.058000000001,
          -6413.880999999999,
          -6428.161,
          -6441.889,
          -6455.056,
          -6467.651999999999,
          -6479.668000000001,
          -6491.093000000001,
          -6501.918000000001,
          -6512.132,
          -6521.724,
          -6530.684,
          -6538.999,
          -6546.659000000001,
          -6553.651999999999,
          -6559.965999999999,
          -6565.5869999999995,
          -6570.504,
          -6574.704000000001,
          -6578.170999999999,
          -6580.894,
          -6582.857,
          -6584.045999999999,
          -6584.446,
          -6584.04,
          -6582.814,
          -6580.7519999999995,
          -6577.834,
          -6574.045999999999,
          -6569.366999999999,
          -6563.781,
          -6557.268,
          -6549.807,
          -6541.38,
          -6531.964,
          -6521.5380000000005,
          -6510.081999999999,
          -6497.569,
          -6483.978,
          -6469.283,
          -6453.459,
          -6436.48,
          -6418.319,
          -6398.946,
          -6378.334,
          -6356.453,
          -6333.269,
          -6308.753000000001,
          -6282.869000000001,
          -6255.584,
          -6226.861,
          -6196.661,
          -6164.9490000000005,
          -6131.68,
          -6096.816,
          -6060.312,
          -6022.121999999999,
          -5982.2,
          -5940.496,
          -5896.960999999999,
          -5851.5419999999995,
          -5804.182,
          -5754.826,
          -5703.4130000000005,
          -5649.882,
          -5594.168000000001,
          -5536.204000000001,
          -5475.92,
          -5413.243,
          -5348.099,
          -5280.406999999999,
          -5210.085999999999,
          -5137.052,
          -5061.215999999999,
          -4982.485,
          -4900.765,
          -4815.957,
          -4727.959,
          -4636.667,
          -4541.971,
          -4443.76,
          -4341.92,
          -4236.334,
          -4126.884,
          -4013.449,
          -3895.91,
          -3774.147,
          -3648.042,
          -3517.4809999999998,
          -3382.3540000000003,
          -3242.559,
          -3098.005,
          -2948.613,
          -2794.323,
          -2635.092,
          -2470.907,
          -2301.784,
          -2127.777,
          -1948.98,
          -1765.539,
          -1577.6529999999998,
          -1385.5810000000001,
          -1189.647,
          -990.24,
          -787.821,
          -582.9159999999999,
          -376.11199999999997,
          -168.05200000000002,
          40.576,
          249.05700000000002,
          456.659,
          662.65,
          866.321,
          1066.997,
          1264.0510000000002,
          1456.918,
          1645.104,
          1828.1879999999999,
          2005.826,
          2177.748,
          2343.755,
          2503.718,
          2657.5640000000003,
          2805.2729999999997,
          2946.8709999999996,
          3082.422,
          3212.02,
          3335.785,
          3453.857,
          3566.387,
          3673.5409999999997,
          3775.489,
          3872.405,
          3964.465,
          4051.845,
          4134.717000000001,
          4213.255,
          4287.623,
          4357.983,
          4424.4929999999995,
          4487.302,
          4546.63,
          4602.401,
          4654.963,
          4704.374,
          4750.7570000000005,
          4794.23,
          4834.903,
          4872.885,
          4908.279,
          4941.181,
          4971.685,
          4999.879,
          5025.848,
          5049.673,
          5071.432,
          5091.196,
          5109.038,
          5125.024,
          5139.218,
          5151.681,
          5162.472,
          5171.646,
          5179.2570000000005,
          5185.357,
          5189.995,
          5193.215999999999,
          5195.066,
          5195.589,
          5194.8240000000005,
          5192.814,
          5189.594,
          5185.2029999999995,
          5179.673,
          5173.041,
          5165.337,
          5156.593,
          5146.839,
          5136.103,
          5124.415,
          5111.798,
          5098.282,
          5083.888,
          5068.643,
          5052.568,
          5035.686,
          5018.019,
          4999.588,
          4980.411,
          4960.51,
          4939.902,
          4918.606,
          4896.639,
          4874.019,
          4850.762,
          4826.883,
          4802.399,
          4777.3240000000005,
          4751.6720000000005,
          4725.458,
          4698.696,
          4671.399,
          4643.579000000001,
          4615.248,
          4586.42,
          4557.107,
          4527.318,
          4497.066,
          4466.361,
          4435.214,
          4403.6359999999995,
          4371.635,
          4339.222,
          4306.407,
          4273.197,
          4239.604,
          4205.634,
          4171.298,
          4136.602,
          4101.556,
          4066.1659999999997,
          4030.441,
          3994.389,
          3958.0159999999996,
          3921.33,
          3884.3379999999997,
          3847.046,
          3809.462,
          3771.592,
          3733.441,
          3695.018,
          3656.327,
          3617.375,
          3578.1679999999997,
          3538.711,
          3499.009,
          3459.0690000000004,
          3418.895,
          3378.494,
          3337.869,
          3297.027,
          3255.972,
          3214.7090000000003,
          3173.243,
          3131.578,
          3089.72,
          3047.672,
          3005.4390000000003,
          2963.025,
          2920.435,
          2877.673,
          2834.743,
          2791.6479999999997,
          2748.393,
          2704.982,
          2661.4190000000003,
          2617.7070000000003,
          2573.85,
          2529.8520000000003,
          2485.715,
          2441.445,
          2397.044,
          2352.516,
          2307.864,
          2263.091,
          2218.201,
          2173.197,
          2128.081,
          2082.8579999999997,
          2037.53,
          1992.1,
          1946.5710000000001,
          1900.9470000000001,
          1855.229,
          1809.421,
          1763.526,
          1717.547,
          1671.486,
          1625.346,
          1579.129,
          1532.839,
          1486.4779999999998,
          1440.049,
          1393.5529999999999,
          1346.994,
          1300.375,
          1253.697,
          1206.963,
          1160.1760000000002,
          1113.337,
          1066.45,
          1019.5160000000001,
          972.539,
          925.5189999999999,
          878.46,
          831.3639999999999,
          784.2330000000001,
          737.069,
          689.8739999999999,
          642.651,
          595.4019999999999,
          548.129,
          500.833,
          453.51800000000003,
          406.185,
          358.836,
          311.473,
          264.099,
          216.715,
          169.324,
          121.927,
          74.52600000000001,
          27.124000000000002,
          -20.278,
          -67.678,
          -115.073,
          -162.46200000000002,
          -209.84400000000002,
          -257.215,
          -304.574,
          -351.92,
          -399.25,
          -446.56199999999995,
          -493.855,
          -541.127,
          -588.376,
          -635.599,
          -682.796,
          -729.965,
          -777.102,
          -824.2080000000001,
          -871.279,
          -918.315,
          -965.313,
          -1012.2710000000001,
          -1059.188,
          -1106.062,
          -1152.89,
          -1199.672,
          -1246.406,
          -1293.089,
          -1339.72,
          -1386.2979999999998,
          -1432.819,
          -1479.283,
          -1525.6879999999999,
          -1572.0320000000002,
          -1618.3120000000001,
          -1664.529,
          -1710.6779999999999,
          -1756.76,
          -1802.771,
          -1848.711,
          -1894.5770000000002,
          -1940.368,
          -1986.0810000000001,
          -2031.7160000000001,
          -2077.269,
          -2122.74,
          -2168.126,
          -2213.426,
          -2258.638,
          -2303.76,
          -2348.79,
          -2393.726,
          -2438.567,
          -2483.31,
          -2527.953,
          -2572.496,
          -2616.936,
          -2661.27,
          -2705.4970000000003,
          -2749.616,
          -2793.6240000000003,
          -2837.5190000000002,
          -2881.2990000000004,
          -2924.9629999999997,
          -2968.509,
          -3011.933,
          -3055.235,
          -3098.413,
          -3141.4640000000004,
          -3184.386,
          -3227.178,
          -3269.837,
          -3312.361,
          -3354.748,
          -3396.9970000000003,
          -3439.1040000000003,
          -3481.067,
          -3522.885,
          -3564.5559999999996,
          -3606.077,
          -3647.445,
          -3688.66,
          -3729.718,
          -3770.617,
          -3811.355,
          -3851.93,
          -3892.3390000000004,
          -3932.579,
          -3972.65,
          -4012.547,
          -4052.27,
          -4091.8140000000003,
          -4131.179,
          -4170.361,
          -4209.357,
          -4248.166,
          -4286.784000000001,
          -4325.21,
          -4363.439,
          -4401.471,
          -4439.3009999999995,
          -4476.927,
          -4514.347,
          -4551.558,
          -4588.557,
          -4625.340999999999,
          -4661.906,
          -4698.251,
          -4734.372,
          -4770.266,
          -4805.931,
          -4841.362,
          -4876.557,
          -4911.512,
          -4946.227,
          -4980.693,
          -5014.912,
          -5048.878,
          -5082.588,
          -5116.039000000001,
          -5149.226,
          -5182.148,
          -5214.8,
          -5247.177,
          -5279.278,
          -5311.096,
          -5342.63,
          -5373.875,
          -5404.826999999999,
          -5435.483,
          -5465.835999999999,
          -5495.8859999999995,
          -5525.625,
          -5555.05,
          -5584.158,
          -5612.943,
          -5641.401,
          -5669.528,
          -5697.318,
          -5724.767,
          -5751.87,
          -5778.6230000000005,
          -5805.019,
          -5831.055,
          -5856.724,
          -5882.022,
          -5906.941999999999,
          -5931.48,
          -5955.63,
          -5979.387,
          -6002.744000000001,
          -6025.694,
          -6048.235,
          -6070.356,
          -6092.054,
          -6113.321999999999,
          -6134.151,
          -6154.5380000000005,
          -6174.473000000001,
          -6193.95,
          -6212.963000000001,
          -6231.504,
          -6249.565,
          -6267.138000000001,
          -6284.215999999999,
          -6300.791,
          -6316.855,
          -6332.4,
          -6347.416,
          -6361.896,
          -6375.829000000001,
          -6389.209,
          -6402.023,
          -6414.263000000001,
          -6425.919,
          -6436.983,
          -6447.441,
          -6457.285,
          -6466.503000000001,
          -6475.084,
          -6483.017,
          -6490.29,
          -6496.891,
          -6502.808000000001,
          -6508.029,
          -6512.539000000001,
          -6516.325,
          -6519.374,
          -6521.672,
          -6523.204000000001,
          -6523.956,
          -6523.911999999999,
          -6523.055,
          -6521.37,
          -6518.84,
          -6515.448,
          -6511.175,
          -6506.004,
          -6499.915,
          -6492.89,
          -6484.908,
          -6475.946999999999,
          -6465.988,
          -6455.007,
          -6442.983,
          -6429.89,
          -6415.706,
          -6400.405,
          -6383.959,
          -6366.344,
          -6347.53,
          -6327.4890000000005,
          -6306.191999999999,
          -6283.607,
          -6259.701999999999,
          -6234.443,
          -6207.797,
          -6179.727,
          -6150.196999999999,
          -6119.1669999999995,
          -6086.598000000001,
          -6052.45,
          -6016.6759999999995,
          -5979.236,
          -5940.079000000001,
          -5899.16,
          -5856.427,
          -5811.828,
          -5765.307,
          -5716.81,
          -5666.278,
          -5613.646,
          -5558.854,
          -5501.8330000000005,
          -5442.514,
          -5380.826999999999,
          -5316.694,
          -5250.04,
          -5180.782,
          -5108.834,
          -5034.113,
          -4956.523,
          -4875.973,
          -4792.3640000000005,
          -4705.593,
          -4615.558,
          -4522.15,
          -4425.259,
          -4324.77,
          -4220.569,
          -4112.535,
          -4000.552,
          -3884.4970000000003,
          -3764.2529999999997,
          -3639.7009999999996,
          -3510.7259999999997,
          -3377.218,
          -3239.075,
          -3096.204,
          -2948.526,
          -2795.975,
          -2638.508,
          -2476.109,
          -2308.788,
          -2136.595,
          -1959.619,
          -1777.997,
          -1591.922,
          -1401.6429999999998,
          -1207.476,
          -1009.799,
          -809.064,
          -605.784,
          -400.538,
          -193.959,
          13.276,
          220.458,
          426.861,
          631.758,
          834.442,
          1034.237,
          1230.517,
          1422.714,
          1610.329,
          1792.935,
          1970.182,
          2141.797,
          2307.572,
          2467.37,
          2621.114,
          2768.778,
          2910.381,
          3045.9840000000004,
          3175.6740000000004,
          3299.5690000000004,
          3417.802,
          3530.525,
          3637.8979999999997,
          3740.0879999999997,
          3837.2690000000002,
          3929.613,
          4017.2940000000003,
          4100.486,
          4179.356,
          4254.07,
          4324.789000000001,
          4391.667,
          4454.856,
          4514.502,
          4570.742,
          4623.710999999999,
          4673.535,
          4720.338,
          4764.238,
          4805.343,
          4843.764,
          4879.602,
          4912.952,
          4943.907999999999,
          4972.558,
          4998.988,
          5023.279,
          5045.505,
          5065.74,
          5084.057,
          5100.52,
          5115.193,
          5128.137,
          5139.413,
          5149.0740000000005,
          5157.173,
          5163.764,
          5168.892,
          5172.608,
          5174.9529999999995,
          5175.973,
          5175.707,
          5174.196,
          5171.477,
          5167.585999999999,
          5162.559,
          5156.43,
          5149.23,
          5140.991,
          5131.742,
          5121.512,
          5110.33,
          5098.221,
          5085.210999999999,
          5071.326,
          5056.588,
          5041.023,
          5024.649,
          5007.49,
          4989.568,
          4970.9,
          4951.5070000000005,
          4931.407999999999,
          4910.621,
          4889.163,
          4867.0509999999995,
          4844.302,
          4820.931,
          4796.955,
          4772.388,
          4747.2429999999995,
          4721.536,
          4695.28,
          4668.488,
          4641.174,
          4613.349,
          4585.025,
          4556.215,
          4526.93,
          4497.181,
          4466.979,
          4436.333,
          4405.255999999999,
          4373.755999999999,
          4341.842000000001,
          4309.525,
          4276.815,
          4243.719,
          4210.247,
          4176.406,
          4142.206,
          4107.654,
          4072.757,
          4037.525,
          4001.965,
          3966.083,
          3929.887,
          3893.384,
          3856.5809999999997,
          3819.485,
          3782.1009999999997,
          3744.4359999999997,
          3706.4970000000003,
          3668.289,
          3629.82,
          3591.094,
          3552.117,
          3512.895,
          3473.4320000000002,
          3433.736,
          3393.8109999999997,
          3353.6620000000003,
          3313.2940000000003,
          3272.712,
          3231.921,
          3190.926,
          3149.7309999999998,
          3108.34,
          3066.76,
          3024.993,
          2983.0429999999997,
          2940.917,
          2898.617,
          2856.1479999999997,
          2813.513,
          2770.717,
          2727.763,
          2684.656,
          2641.3990000000003,
          2597.996,
          2554.45,
          2510.765,
          2466.945,
          2422.992,
          2378.91,
          2334.7039999999997,
          2290.376,
          2245.928,
          2201.366,
          2156.6910000000003,
          2111.907,
          2067.016,
          2022.023,
          1976.9279999999999,
          1931.737,
          1886.4520000000002,
          1841.075,
          1795.609,
          1750.057,
          1704.422,
          1658.707,
          1612.914,
          1567.046,
          1521.105,
          1475.094,
          1429.016,
          1382.8729999999998,
          1336.668,
          1290.403,
          1244.08,
          1197.702,
          1151.2730000000001,
          1104.7910000000002,
          1058.263,
          1011.688,
          965.072,
          918.413,
          871.716,
          824.9810000000001,
          778.212,
          731.4119999999999,
          684.581,
          637.722,
          590.837,
          543.929,
          497,
          450.05,
          403.084,
          356.102,
          309.106,
          262.1,
          215.084,
          168.06,
          121.031,
          74,
          26.965999999999998,
          -20.066,
          -67.097,
          -114.124,
          -161.144,
          -208.155,
          -255.15599999999998,
          -302.147,
          -349.12300000000005,
          -396.082,
          -443.025,
          -489.94800000000004,
          -536.851,
          -583.73,
          -630.5830000000001,
          -677.41,
          -724.21,
          -770.977,
          -817.7130000000001,
          -864.415,
          -911.082,
          -957.711,
          -1004.301,
          -1050.849,
          -1097.354,
          -1143.8139999999999,
          -1190.229,
          -1236.595,
          -1282.91,
          -1329.174,
          -1375.384,
          -1421.539,
          -1467.6370000000002,
          -1513.675,
          -1559.6529999999998,
          -1605.568,
          -1651.4189999999999,
          -1697.204,
          -1742.921,
          -1788.569,
          -1834.145,
          -1879.6470000000002,
          -1925.075,
          -1970.4260000000002,
          -2015.6979999999999,
          -2060.89,
          -2105.999,
          -2151.024,
          -2195.964,
          -2240.815,
          -2285.578,
          -2330.248,
          -2374.826,
          -2419.3089999999997,
          -2463.694,
          -2507.98,
          -2552.166,
          -2596.249,
          -2640.228,
          -2684.1009999999997,
          -2727.864,
          -2771.518,
          -2815.06,
          -2858.487,
          -2901.798,
          -2944.992,
          -2988.065,
          -3031.0159999999996,
          -3073.843,
          -3116.5440000000003,
          -3159.118,
          -3201.5609999999997,
          -3243.8720000000003,
          -3286.048,
          -3328.0879999999997,
          -3369.99,
          -3411.7509999999997,
          -3453.369,
          -3494.843,
          -3536.1690000000003,
          -3577.347,
          -3618.373,
          -3659.245,
          -3699.961,
          -3740.5190000000002,
          -3780.917,
          -3821.151,
          -3861.2209999999995,
          -3901.123,
          -3940.855,
          -3980.4159999999997,
          -4019.801,
          -4059.009,
          -4098.038,
          -4136.884,
          -4175.545999999999,
          -4214.02,
          -4252.305,
          -4290.397,
          -4328.294,
          -4365.994000000001,
          -4403.4929999999995,
          -4440.789000000001,
          -4477.878,
          -4514.759,
          -4551.428,
          -4587.883,
          -4624.121,
          -4660.138,
          -4695.931,
          -4731.498,
          -4766.835999999999,
          -4801.941,
          -4836.811,
          -4871.443,
          -4905.831,
          -4939.974,
          -4973.869000000001,
          -5007.5109999999995,
          -5040.898,
          -5074.025,
          -5106.891,
          -5139.49,
          -5171.819,
          -5203.876,
          -5235.654,
          -5267.151999999999,
          -5298.365,
          -5329.289000000001,
          -5359.920999999999,
          -5390.255999999999,
          -5420.289000000001,
          -5450.018,
          -5479.438,
          -5508.543000000001,
          -5537.331,
          -5565.795999999999,
          -5593.933000000001,
          -5621.7390000000005,
          -5649.209,
          -5676.338000000001,
          -5703.12,
          -5729.552,
          -5755.6269999999995,
          -5781.340999999999,
          -5806.689,
          -5831.664000000001,
          -5856.262,
          -5880.477,
          -5904.303000000001,
          -5927.735,
          -5950.767,
          -5973.394,
          -5995.606,
          -6017.401,
          -6038.771,
          -6059.709,
          -6080.209,
          -6100.264,
          -6119.866999999999,
          -6139.0109999999995,
          -6157.689,
          -6175.894,
          -6193.616999999999,
          -6210.851,
          -6227.588000000001,
          -6243.821999999999,
          -6259.541,
          -6274.7390000000005,
          -6289.406999999999,
          -6303.536,
          -6317.116999999999,
          -6330.14,
          -6342.596,
          -6354.476,
          -6365.77,
          -6376.465999999999,
          -6386.555,
          -6396.026,
          -6404.869000000001,
          -6413.07,
          -6420.62,
          -6427.505,
          -6433.715999999999,
          -6439.236,
          -6444.056,
          -6448.16,
          -6451.536999999999,
          -6454.170999999999,
          -6456.048000000001,
          -6457.155,
          -6457.473000000001,
          -6456.9890000000005,
          -6455.688,
          -6453.55,
          -6450.56,
          -6446.701999999999,
          -6441.954000000001,
          -6436.3,
          -6429.72,
          -6422.193,
          -6413.701,
          -6404.221,
          -6393.731,
          -6382.209,
          -6369.630999999999,
          -6355.975,
          -6341.213000000001,
          -6325.321999999999,
          -6308.273,
          -6290.039000000001,
          -6270.592,
          -6249.903,
          -6227.94,
          -6204.672,
          -6180.066,
          -6154.088000000001,
          -6126.701999999999,
          -6097.8730000000005,
          -6067.561,
          -6035.726,
          -6002.329000000001,
          -5967.326,
          -5930.674,
          -5892.325,
          -5852.231,
          -5810.345,
          -5766.611999999999,
          -5720.98,
          -5673.392,
          -5623.79,
          -5572.113,
          -5518.298000000001,
          -5462.279,
          -5403.986999999999,
          -5343.351,
          -5280.297,
          -5214.746,
          -5146.62,
          -5075.834,
          -5002.3009999999995,
          -4925.931,
          -4846.63,
          -4764.302,
          -4678.846,
          -4590.157999999999,
          -4498.1320000000005,
          -4402.657,
          -4303.619000000001,
          -4200.905,
          -4094.3959999999997,
          -3983.975,
          -3869.52,
          -3750.913,
          -3628.0359999999996,
          -3500.7740000000003,
          -3369.018,
          -3232.663,
          -3091.615,
          -2945.7940000000003,
          -2795.132,
          -2639.586,
          -2479.131,
          -2313.777,
          -2143.567,
          -1968.5839999999998,
          -1788.961,
          -1604.878,
          -1416.58,
          -1224.37,
          -1028.618,
          -829.763,
          -628.308,
          -424.82099999999997,
          -219.923,
          -14.284,
          191.39700000000002,
          396.4,
          600.005,
          801.5060000000001,
          1000.2310000000001,
          1195.5510000000002,
          1386.895,
          1573.7620000000002,
          1755.72,
          1932.415,
          2103.562,
          2268.953,
          2428.442,
          2581.945,
          2729.4320000000002,
          2870.9159999999997,
          3006.449,
          3136.118,
          3260.034,
          3378.328,
          3491.1459999999997,
          3598.645,
          3700.992,
          3798.3540000000003,
          3890.905,
          3978.815,
          4062.255,
          4141.392,
          4216.391,
          4287.41,
          4354.604,
          4418.122,
          4478.11,
          4534.7029999999995,
          4588.035,
          4638.235,
          4685.4220000000005,
          4729.714,
          4771.222,
          4810.052,
          4846.306,
          4880.081,
          4911.467000000001,
          4940.555,
          4967.428,
          4992.166,
          5014.846,
          5035.541,
          5054.319,
          5071.251,
          5086.396,
          5099.817,
          5111.572,
          5121.715999999999,
          5130.303,
          5137.383,
          5143.005999999999,
          5147.217000000001,
          5150.061,
          5151.582,
          5151.82,
          5150.815,
          5148.604,
          5145.224,
          5140.71,
          5135.094,
          5128.41,
          5120.689,
          5111.959,
          5102.25,
          5091.59,
          5080.003,
          5067.519,
          5054.157999999999,
          5039.947,
          5024.907999999999,
          5009.063,
          4992.434,
          4975.041,
          4956.904,
          4938.042,
          4918.476,
          4898.221,
          4877.295,
          4855.717000000001,
          4833.501,
          4810.665,
          4787.222,
          4763.189,
          4738.579000000001,
          4713.407,
          4687.685,
          4661.428,
          4634.649,
          4607.359,
          4579.57,
          4551.295,
          4522.544,
          4493.329000000001,
          4463.661,
          4433.55,
          4403.005999999999,
          4372.039000000001,
          4340.659000000001,
          4308.875,
          4276.697,
          4244.133,
          4211.192,
          4177.8820000000005,
          4144.212,
          4110.19,
          4075.824,
          4041.1209999999996,
          4006.0879999999997,
          3970.7340000000004,
          3935.065,
          3899.0890000000004,
          3862.8109999999997,
          3826.24,
          3789.38,
          3752.24,
          3714.823,
          3677.138,
          3639.19,
          3600.9840000000004,
          3562.527,
          3523.824,
          3484.88,
          3445.7009999999996,
          3406.292,
          3366.659,
          3326.805,
          3286.736,
          3246.458,
          3205.974,
          3165.289,
          3124.408,
          3083.336,
          3042.077,
          3000.635,
          2959.014,
          2917.218,
          2875.252,
          2833.12,
          2790.825,
          2748.3709999999996,
          2705.763,
          2663.0029999999997,
          2620.096,
          2577.0460000000003,
          2533.855,
          2490.527,
          2447.067,
          2403.476,
          2359.759,
          2315.919,
          2271.958,
          2227.881,
          2183.6910000000003,
          2139.389,
          2094.98,
          2050.467,
          2005.852,
          1961.138,
          1916.329,
          1871.4270000000001,
          1826.435,
          1781.355,
          1736.191,
          1690.945,
          1645.62,
          1600.2179999999998,
          1554.743,
          1509.1960000000001,
          1463.58,
          1417.898,
          1372.152,
          1326.345,
          1280.479,
          1234.556,
          1188.579,
          1142.55,
          1096.472,
          1050.346,
          1004.176,
          957.9630000000001,
          911.709,
          865.418,
          819.09,
          772.7280000000001,
          726.335,
          679.9119999999999,
          633.462,
          586.987,
          540.488,
          493.968,
          447.42900000000003,
          400.87300000000005,
          354.30199999999996,
          307.717,
          261.122,
          214.518,
          167.907,
          121.29,
          74.67,
          28.049,
          -18.570999999999998,
          -65.189,
          -111.802,
          -158.409,
          -205.00799999999998,
          -251.597,
          -298.173,
          -344.736,
          -391.283,
          -437.81300000000005,
          -484.32300000000004,
          -530.812,
          -577.278,
          -623.72,
          -670.135,
          -716.5210000000001,
          -762.877,
          -809.201,
          -855.492,
          -901.7460000000001,
          -947.9639999999999,
          -994.1419999999999,
          -1040.28,
          -1086.374,
          -1132.425,
          -1178.4289999999999,
          -1224.385,
          -1270.2910000000002,
          -1316.146,
          -1361.9470000000001,
          -1407.694,
          -1453.384,
          -1499.015,
          -1544.585,
          -1590.094,
          -1635.539,
          -1680.918,
          -1726.229,
          -1771.4720000000002,
          -1816.6429999999998,
          -1861.7420000000002,
          -1906.766,
          -1951.714,
          -1996.5839999999998,
          -2041.3729999999998,
          -2086.081,
          -2130.706,
          -2175.245,
          -2219.697,
          -2264.06,
          -2308.3320000000003,
          -2352.512,
          -2396.597,
          -2440.585,
          -2484.476,
          -2528.266,
          -2571.955,
          -2615.5389999999998,
          -2659.018,
          -2702.389,
          -2745.651,
          -2788.801,
          -2831.837,
          -2874.758,
          -2917.562,
          -2960.2470000000003,
          -3002.81,
          -3045.2490000000003,
          -3087.5640000000003,
          -3129.7509999999997,
          -3171.809,
          -3213.735,
          -3255.528,
          -3297.185,
          -3338.705,
          -3380.085,
          -3421.322,
          -3462.4159999999997,
          -3503.363,
          -3544.1620000000003,
          -3584.81,
          -3625.3059999999996,
          -3665.6459999999997,
          -3705.828,
          -3745.8509999999997,
          -3785.712,
          -3825.409,
          -3864.9390000000003,
          -3904.2990000000004,
          -3943.489,
          -3982.5040000000004,
          -4021.343,
          -4060.0040000000004,
          -4098.482,
          -4136.777,
          -4174.8859999999995,
          -4212.805,
          -4250.532999999999,
          -4288.066,
          -4325.403,
          -4362.539000000001,
          -4399.474,
          -4436.2029999999995,
          -4472.724,
          -4509.035,
          -4545.130999999999,
          -4581.0109999999995,
          -4616.670999999999,
          -4652.109,
          -4687.32,
          -4722.304,
          -4757.055,
          -4791.571,
          -4825.85,
          -4859.887,
          -4893.679,
          -4927.223,
          -4960.515,
          -4993.553,
          -5026.332,
          -5058.849,
          -5091.101,
          -5123.083,
          -5154.793,
          -5186.227,
          -5217.379,
          -5248.2480000000005,
          -5278.828,
          -5309.115,
          -5339.107,
          -5368.798000000001,
          -5398.185,
          -5427.262,
          -5456.026999999999,
          -5484.473000000001,
          -5512.597,
          -5540.394,
          -5567.861,
          -5594.991,
          -5621.78,
          -5648.222,
          -5674.314,
          -5700.05,
          -5725.424,
          -5750.433000000001,
          -5775.069,
          -5799.328,
          -5823.204000000001,
          -5846.691,
          -5869.783,
          -5892.475,
          -5914.7609999999995,
          -5936.634,
          -5958.088000000001,
          -5979.116,
          -5999.7119999999995,
          -6019.87,
          -6039.581999999999,
          -6058.842,
          -6077.641,
          -6095.974,
          -6113.831999999999,
          -6131.209,
          -6148.095,
          -6164.483,
          -6180.365,
          -6195.732,
          -6210.576999999999,
          -6224.89,
          -6238.661999999999,
          -6251.885,
          -6264.548000000001,
          -6276.642,
          -6288.158,
          -6299.084,
          -6309.411999999999,
          -6319.13,
          -6328.226,
          -6336.691,
          -6344.513000000001,
          -6351.68,
          -6358.179,
          -6363.999,
          -6369.1269999999995,
          -6373.548000000001,
          -6377.251,
          -6380.222,
          -6382.445,
          -6383.906999999999,
          -6384.593000000001,
          -6384.486,
          -6383.571,
          -6381.831999999999,
          -6379.251,
          -6375.812,
          -6371.496,
          -6366.285,
          -6360.159000000001,
          -6353.099,
          -6345.085999999999,
          -6336.097,
          -6326.111,
          -6315.106,
          -6303.059,
          -6289.946,
          -6275.741999999999,
          -6260.423000000001,
          -6243.96,
          -6226.328,
          -6207.496999999999,
          -6187.439,
          -6166.1230000000005,
          -6143.519,
          -6119.593000000001,
          -6094.311,
          -6067.64,
          -6039.541,
          -6009.979,
          -5978.914000000001,
          -5946.304,
          -5912.108,
          -5876.281999999999,
          -5838.781,
          -5799.557,
          -5758.561,
          -5715.74,
          -5671.044,
          -5624.415,
          -5575.795999999999,
          -5525.1269999999995,
          -5472.345,
          -5417.385,
          -5360.179,
          -5300.656,
          -5238.745,
          -5174.366,
          -5107.441,
          -5037.887,
          -4965.619000000001,
          -4890.545999999999,
          -4812.576,
          -4731.612,
          -4647.556,
          -4560.305,
          -4469.752,
          -4375.788,
          -4278.302,
          -4177.178,
          -4072.3,
          -3963.55,
          -3850.809,
          -3733.9570000000003,
          -3612.8790000000004,
          -3487.4570000000003,
          -3357.5820000000003,
          -3223.15,
          -3084.067,
          -2940.2470000000003,
          -2791.625,
          -2638.151,
          -2479.801,
          -2316.578,
          -2148.52,
          -1975.705,
          -1798.2579999999998,
          -1616.3529999999998,
          -1430.223,
          -1240.162,
          -1046.531,
          -849.755,
          -650.328,
          -448.80400000000003,
          -245.795,
          -41.958,
          162.016,
          365.414,
          567.523,
          767.64,
          965.096,
          1159.26,
          1349.5639999999999,
          1535.499,
          1716.631,
          1892.599,
          2063.115,
          2227.962,
          2386.99,
          2540.107,
          2687.276,
          2828.505,
          2963.844,
          3093.3709999999996,
          3217.1940000000004,
          3335.438,
          3448.2470000000003,
          3555.775,
          3658.185,
          3755.6409999999996,
          3848.315,
          3936.375,
          4019.989,
          4099.3240000000005,
          4174.541,
          4245.798,
          4313.249,
          4377.041,
          4437.393,
          4494.215999999999,
          4547.867,
          4598.398,
          4645.931,
          4690.579000000001,
          4732.455,
          4771.663,
          4808.305,
          4842.476,
          4874.27,
          4903.772,
          4931.068,
          4956.236,
          4979.353,
          5000.492,
          5019.722,
          5037.11,
          5052.718,
          5066.607,
          5078.835999999999,
          5089.46,
          5098.53,
          5106.099,
          5112.214,
          5116.9220000000005,
          5120.267,
          5122.292,
          5123.039000000001,
          5122.545999999999,
          5120.85,
          5117.9890000000005,
          5113.995,
          5108.905,
          5102.747,
          5095.555,
          5087.358,
          5078.183,
          5068.059,
          5057.012,
          5045.067,
          5032.25,
          5018.583,
          5004.09,
          4988.793,
          4972.713,
          4955.87,
          4938.286,
          4919.978,
          4900.965,
          4881.266,
          4860.898,
          4839.877,
          4818.221,
          4795.944,
          4773.062,
          4749.589,
          4725.542,
          4700.932,
          4675.774,
          4650.081,
          4623.866,
          4597.14,
          4569.917,
          4542.207,
          4514.022,
          4485.373,
          4456.271,
          4426.726,
          4396.749,
          4366.348,
          4335.535,
          4304.318,
          4272.706,
          4240.708,
          4208.334,
          4175.59,
          4142.486,
          4109.03,
          4075.2290000000003,
          4041.092,
          4006.625,
          3971.836,
          3936.7309999999998,
          3901.3190000000004,
          3865.605,
          3829.5959999999995,
          3793.3,
          3756.7209999999995,
          3719.867,
          3682.744,
          3645.3559999999998,
          3607.711,
          3569.813,
          3531.6679999999997,
          3493.283,
          3454.6620000000003,
          3415.81,
          3376.732,
          3337.434,
          3297.92,
          3258.196,
          3218.265,
          3178.133,
          3137.803,
          3097.282,
          3056.572,
          3015.679,
          2974.6059999999998,
          2933.357,
          2891.938,
          2850.35,
          2808.6,
          2766.69,
          2724.623,
          2682.405,
          2640.039,
          2597.527,
          2554.874,
          2512.084,
          2469.159,
          2426.103,
          2382.919,
          2339.612,
          2296.183,
          2252.636,
          2208.974,
          2165.2,
          2121.3179999999998,
          2077.33,
          2033.239,
          1989.0479999999998,
          1944.761,
          1900.379,
          1855.906,
          1811.344,
          1766.6960000000001,
          1721.965,
          1677.154,
          1632.264,
          1587.3,
          1542.2620000000002,
          1497.154,
          1451.979,
          1406.7379999999998,
          1361.435,
          1316.0710000000001,
          1270.649,
          1225.171,
          1179.64,
          1134.058,
          1088.427,
          1042.75,
          997.029,
          951.2660000000001,
          905.4630000000001,
          859.622,
          813.7460000000001,
          767.837,
          721.8960000000001,
          675.926,
          629.93,
          583.908,
          537.864,
          491.79900000000004,
          445.715,
          399.615,
          353.499,
          307.371,
          261.232,
          215.085,
          168.93,
          122.77,
          76.608,
          30.444000000000003,
          -15.719000000000001,
          -61.88,
          -108.036,
          -154.186,
          -200.327,
          -246.458,
          -292.578,
          -338.68300000000005,
          -384.773,
          -430.846,
          -476.899,
          -522.932,
          -568.941,
          -614.9259999999999,
          -660.885,
          -706.815,
          -752.715,
          -798.584,
          -844.419,
          -890.2189999999999,
          -935.982,
          -981.706,
          -1027.389,
          -1073.03,
          -1118.627,
          -1164.1789999999999,
          -1209.682,
          -1255.136,
          -1300.539,
          -1345.89,
          -1391.1860000000001,
          -1436.425,
          -1481.606,
          -1526.7279999999998,
          -1571.7879999999998,
          -1616.7839999999999,
          -1661.7160000000001,
          -1706.58,
          -1751.376,
          -1796.102,
          -1840.755,
          -1885.3339999999998,
          -1929.838,
          -1974.264,
          -2018.612,
          -2062.877,
          -2107.061,
          -2151.159,
          -2195.1710000000003,
          -2239.095,
          -2282.928,
          -2326.67,
          -2370.3179999999998,
          -2413.87,
          -2457.325,
          -2500.68,
          -2543.935,
          -2587.0860000000002,
          -2630.132,
          -2673.071,
          -2715.902,
          -2758.6220000000003,
          -2801.2290000000003,
          -2843.7209999999995,
          -2886.098,
          -2928.355,
          -2970.493,
          -3012.507,
          -3054.3979999999997,
          -3096.1620000000003,
          -3137.797,
          -3179.302,
          -3220.675,
          -3261.9120000000003,
          -3303.013,
          -3343.975,
          -3384.796,
          -3425.474,
          -3466.006,
          -3506.3909999999996,
          -3546.6259999999997,
          -3586.7090000000003,
          -3626.638,
          -3666.4109999999996,
          -3706.025,
          -3745.4770000000003,
          -3784.7670000000003,
          -3823.8909999999996,
          -3862.8459999999995,
          -3901.632,
          -3940.244,
          -3978.6809999999996,
          -4016.94,
          -4055.018,
          -4092.914,
          -4130.624,
          -4168.146,
          -4205.478,
          -4242.616,
          -4279.558,
          -4316.302,
          -4352.844,
          -4389.182,
          -4425.313,
          -4461.234,
          -4496.943,
          -4532.435,
          -4567.71,
          -4602.762,
          -4637.59,
          -4672.19,
          -4706.559,
          -4740.694,
          -4774.592000000001,
          -4808.25,
          -4841.664000000001,
          -4874.831,
          -4907.747,
          -4940.409000000001,
          -4972.814,
          -5004.958,
          -5036.837,
          -5068.447,
          -5099.786,
          -5130.85,
          -5161.633,
          -5192.134,
          -5222.347,
          -5252.268,
          -5281.894,
          -5311.22,
          -5340.241999999999,
          -5368.956,
          -5397.357,
          -5425.441999999999,
          -5453.205,
          -5480.642,
          -5507.7480000000005,
          -5534.518,
          -5560.948,
          -5587.033,
          -5612.767,
          -5638.146,
          -5663.164000000001,
          -5687.816,
          -5712.096,
          -5736,
          -5759.521,
          -5782.653,
          -5805.391,
          -5827.729,
          -5849.66,
          -5871.179,
          -5892.279,
          -5912.954000000001,
          -5933.196,
          -5953,
          -5972.358,
          -5991.263000000001,
          -6009.7080000000005,
          -6027.686,
          -6045.189,
          -6062.209,
          -6078.7390000000005,
          -6094.769,
          -6110.294,
          -6125.303000000001,
          -6139.7880000000005,
          -6153.741,
          -6167.151,
          -6180.0109999999995,
          -6192.31,
          -6204.039000000001,
          -6215.187,
          -6225.745,
          -6235.703,
          -6245.048000000001,
          -6253.77,
          -6261.859,
          -6269.302,
          -6276.0869999999995,
          -6282.201999999999,
          -6287.635,
          -6292.371999999999,
          -6296.401,
          -6299.7080000000005,
          -6302.278,
          -6304.097,
          -6305.151,
          -6305.424,
          -6304.9,
          -6303.563,
          -6301.396,
          -6298.383000000001,
          -6294.505999999999,
          -6289.745,
          -6284.0830000000005,
          -6277.5,
          -6269.976,
          -6261.491,
          -6252.022,
          -6241.548000000001,
          -6230.045999999999,
          -6217.493,
          -6203.8640000000005,
          -6189.134,
          -6173.276999999999,
          -6156.266,
          -6138.073,
          -6118.67,
          -6098.026999999999,
          -6076.111,
          -6052.892,
          -6028.335,
          -6002.406999999999,
          -5975.071999999999,
          -5946.2919999999995,
          -5916.029,
          -5884.241999999999,
          -5850.89,
          -5815.93,
          -5779.316999999999,
          -5741.004,
          -5700.941999999999,
          -5659.08,
          -5615.366999999999,
          -5569.746,
          -5522.161,
          -5472.553000000001,
          -5420.86,
          -5367.017,
          -5310.956999999999,
          -5252.611,
          -5191.906,
          -5128.766,
          -5063.112,
          -4994.863,
          -4923.933,
          -4850.234,
          -4773.675,
          -4694.16,
          -4611.590999999999,
          -4525.866,
          -4436.879,
          -4344.523,
          -4248.687,
          -4149.255999999999,
          -4046.117,
          -3939.1490000000003,
          -3828.236,
          -3713.259,
          -3594.1,
          -3470.647,
          -3342.7859999999996,
          -3210.413,
          -3073.434,
          -2931.763,
          -2785.3309999999997,
          -2634.086,
          -2478,
          -2317.073,
          -2151.339,
          -1980.868,
          -1805.777,
          -1626.234,
          -1442.463,
          -1254.747,
          -1063.434,
          -868.941,
          -671.7460000000001,
          -472.394,
          -271.483,
          -69.65899999999999,
          132.39600000000002,
          333.97900000000004,
          534.382,
          732.909,
          928.8910000000001,
          1121.702,
          1310.769,
          1495.5829999999999,
          1675.705,
          1850.7679999999998,
          2020.48,
          2184.619,
          2343.025,
          2495.604,
          2642.31,
          2783.147,
          2918.158,
          3047.4159999999997,
          3171.025,
          3289.1059999999998,
          3401.798,
          3509.252,
          3611.6259999999997,
          3709.085,
          3801.7940000000003,
          3889.921,
          3973.632,
          4053.09,
          4128.456,
          4199.885,
          4267.531,
          4331.538,
          4392.05,
          4449.202,
          4503.125,
          4553.943,
          4601.778,
          4646.744000000001,
          4688.951,
          4728.504,
          4765.502,
          4800.042,
          4832.215,
          4862.108,
          4889.804,
          4915.383,
          4938.92,
          4960.487,
          4980.154,
          4997.987,
          5014.0470000000005,
          5028.396,
          5041.090999999999,
          5052.187,
          5061.737,
          5069.792,
          5076.398,
          5081.603,
          5085.45,
          5087.983,
          5089.242,
          5089.266,
          5088.090999999999,
          5085.755,
          5082.292,
          5077.734,
          5072.115,
          5065.463,
          5057.81,
          5049.183,
          5039.61,
          5029.117,
          5017.728,
          5005.47,
          4992.366,
          4978.437,
          4963.707,
          4948.197,
          4931.925,
          4914.914000000001,
          4897.182,
          4878.747,
          4859.627,
          4839.84,
          4819.402,
          4798.329000000001,
          4776.638,
          4754.343,
          4731.459,
          4708.001,
          4683.982,
          4659.416,
          4634.315,
          4608.694,
          4582.563,
          4555.935,
          4528.821,
          4501.234,
          4473.183,
          4444.679,
          4415.733,
          4386.355,
          4356.555,
          4326.342000000001,
          4295.726,
          4264.715,
          4233.319,
          4201.545999999999,
          4169.404,
          4136.902,
          4104.049,
          4070.85,
          4037.315,
          4003.45,
          3969.263,
          3934.761,
          3899.9509999999996,
          3864.8390000000004,
          3829.433,
          3793.738,
          3757.761,
          3721.508,
          3684.985,
          3648.198,
          3611.153,
          3573.855,
          3536.3109999999997,
          3498.5240000000003,
          3460.502,
          3422.248,
          3383.768,
          3345.067,
          3306.15,
          3267.0209999999997,
          3227.6859999999997,
          3188.1479999999997,
          3148.413,
          3108.485,
          3068.368,
          3028.067,
          2987.585,
          2946.927,
          2906.097,
          2865.099,
          2823.937,
          2782.614,
          2741.134,
          2699.5009999999997,
          2657.719,
          2615.791,
          2573.721,
          2531.513,
          2489.1679999999997,
          2446.692,
          2404.087,
          2361.357,
          2318.505,
          2275.533,
          2232.446,
          2189.245,
          2145.935,
          2102.518,
          2058.998,
          2015.376,
          1971.655,
          1927.84,
          1883.932,
          1839.934,
          1795.849,
          1751.6789999999999,
          1707.4279999999999,
          1663.0970000000002,
          1618.69,
          1574.2089999999998,
          1529.656,
          1485.0339999999999,
          1440.345,
          1395.592,
          1350.777,
          1305.903,
          1260.971,
          1215.985,
          1170.947,
          1125.858,
          1080.721,
          1035.539,
          990.313,
          945.045,
          899.7389999999999,
          854.3960000000001,
          809.0169999999999,
          763.6060000000001,
          718.164,
          672.694,
          627.197,
          581.6759999999999,
          536.132,
          490.56800000000004,
          444.985,
          399.38599999999997,
          353.772,
          308.14599999999996,
          262.509,
          216.863,
          171.21099999999998,
          125.554,
          79.893,
          34.232,
          -11.427999999999999,
          -57.086000000000006,
          -102.74,
          -148.387,
          -194.02599999999998,
          -239.65400000000002,
          -285.27099999999996,
          -330.875,
          -376.463,
          -422.033,
          -467.585,
          -513.116,
          -558.624,
          -604.1080000000001,
          -649.566,
          -694.9960000000001,
          -740.3960000000001,
          -785.765,
          -831.1,
          -876.4010000000001,
          -921.665,
          -966.8910000000001,
          -1012.077,
          -1057.22,
          -1102.32,
          -1147.375,
          -1192.383,
          -1237.3410000000001,
          -1282.25,
          -1327.106,
          -1371.9070000000002,
          -1416.654,
          -1461.342,
          -1505.9720000000002,
          -1550.54,
          -1595.046,
          -1639.487,
          -1683.8629999999998,
          -1728.17,
          -1772.408,
          -1816.5739999999998,
          -1860.6670000000001,
          -1904.685,
          -1948.626,
          -1992.489,
          -2036.271,
          -2079.972,
          -2123.5879999999997,
          -2167.119,
          -2210.562,
          -2253.917,
          -2297.18,
          -2340.35,
          -2383.425,
          -2426.404,
          -2469.285,
          -2512.065,
          -2554.743,
          -2597.317,
          -2639.785,
          -2682.145,
          -2724.3959999999997,
          -2766.535,
          -2808.5609999999997,
          -2850.4709999999995,
          -2892.263,
          -2933.9359999999997,
          -2975.488,
          -3016.917,
          -3058.22,
          -3099.395,
          -3140.441,
          -3181.3559999999998,
          -3222.137,
          -3262.782,
          -3303.29,
          -3343.657,
          -3383.883,
          -3423.965,
          -3463.9,
          -3503.6859999999997,
          -3543.322,
          -3582.804,
          -3622.132,
          -3661.301,
          -3700.3109999999997,
          -3739.159,
          -3777.842,
          -3816.3579999999997,
          -3854.7059999999997,
          -3892.881,
          -3930.882,
          -3968.7070000000003,
          -4006.353,
          -4043.817,
          -4081.0959999999995,
          -4118.189,
          -4155.092000000001,
          -4191.804,
          -4228.321,
          -4264.64,
          -4300.759,
          -4336.675,
          -4372.3859999999995,
          -4407.888,
          -4443.178,
          -4478.254,
          -4513.113,
          -4547.751,
          -4582.166,
          -4616.355,
          -4650.313,
          -4684.04,
          -4717.53,
          -4750.781,
          -4783.79,
          -4816.552,
          -4849.066,
          -4881.326,
          -4913.331,
          -4945.075,
          -4976.557,
          -5007.771,
          -5038.715,
          -5069.384,
          -5099.775,
          -5129.884,
          -5159.706,
          -5189.238,
          -5218.475,
          -5247.414000000001,
          -5276.0509999999995,
          -5304.38,
          -5332.398,
          -5360.1,
          -5387.481,
          -5414.5380000000005,
          -5441.264,
          -5467.656,
          -5493.709,
          -5519.418000000001,
          -5544.776999999999,
          -5569.781,
          -5594.425,
          -5618.704000000001,
          -5642.613,
          -5666.145,
          -5689.295999999999,
          -5712.059,
          -5734.428000000001,
          -5756.398,
          -5777.9619999999995,
          -5799.1140000000005,
          -5819.847,
          -5840.156,
          -5860.034000000001,
          -5879.472,
          -5898.465999999999,
          -5917.005999999999,
          -5935.0869999999995,
          -5952.701,
          -5969.840999999999,
          -5986.496999999999,
          -6002.6630000000005,
          -6018.33,
          -6033.491,
          -6048.1359999999995,
          -6062.257,
          -6075.844,
          -6088.89,
          -6101.384,
          -6113.316,
          -6124.678000000001,
          -6135.4580000000005,
          -6145.647,
          -6155.234,
          -6164.206999999999,
          -6172.557,
          -6180.271,
          -6187.3369999999995,
          -6193.744000000001,
          -6199.48,
          -6204.531,
          -6208.883000000001,
          -6212.525,
          -6215.441999999999,
          -6217.62,
          -6219.043000000001,
          -6219.698,
          -6219.569,
          -6218.639,
          -6216.891,
          -6214.31,
          -6210.878000000001,
          -6206.576,
          -6201.3859999999995,
          -6195.289000000001,
          -6188.266,
          -6180.295,
          -6171.355,
          -6161.4259999999995,
          -6150.485,
          -6138.507,
          -6125.47,
          -6111.348000000001,
          -6096.116,
          -6079.746999999999,
          -6062.214,
          -6043.488,
          -6023.54,
          -6002.339,
          -5979.853,
          -5956.05,
          -5930.895,
          -5904.354,
          -5876.389,
          -5846.9619999999995,
          -5816.034000000001,
          -5783.564,
          -5749.509,
          -5713.825,
          -5676.465,
          -5637.380999999999,
          -5596.524,
          -5553.840999999999,
          -5509.279,
          -5462.781,
          -5414.2880000000005,
          -5363.7390000000005,
          -5311.071999999999,
          -5256.219,
          -5199.111,
          -5139.678,
          -5077.844,
          -5013.532,
          -4946.66,
          -4877.145,
          -4804.899,
          -4729.832,
          -4651.85,
          -4570.855,
          -4486.747,
          -4399.42,
          -4308.77,
          -4214.685,
          -4117.053,
          -4015.759,
          -3910.6859999999997,
          -3801.718,
          -3688.736,
          -3571.623,
          -3450.2659999999996,
          -3324.552,
          -3194.377,
          -3059.645,
          -2920.27,
          -2776.1809999999996,
          -2627.323,
          -2473.666,
          -2315.2039999999997,
          -2151.966,
          -1984.017,
          -1811.4679999999998,
          -1634.477,
          -1453.257,
          -1268.0839999999998,
          -1079.2930000000001,
          -887.2869999999999,
          -692.535,
          -495.566,
          -296.967,
          -97.37100000000001,
          102.54899999999999,
          302.10200000000003,
          500.586,
          697.312,
          891.613,
          1082.866,
          1270.496,
          1453.994,
          1632.9170000000001,
          1806.894,
          1975.6270000000002,
          2138.887,
          2296.511,
          2448.394,
          2594.489,
          2734.7909999999997,
          2869.3379999999997,
          2998.198,
          3121.47,
          3239.27,
          3351.7340000000004,
          3459.008,
          3561.248,
          3658.613,
          3751.268,
          3839.377,
          3923.103,
          4002.6090000000004,
          4078.052,
          4149.585999999999,
          4217.363,
          4281.526,
          4342.215999999999,
          4399.569,
          4453.713,
          4504.772,
          4552.866,
          4598.109,
          4640.609,
          4680.471,
          4717.794,
          4752.6720000000005,
          4785.198,
          4815.456,
          4843.53,
          4869.497,
          4893.434,
          4915.413,
          4935.501,
          4953.765,
          4970.266,
          4985.065,
          4998.218,
          5009.782,
          5019.806,
          5028.342000000001,
          5035.438,
          5041.14,
          5045.49,
          5048.532,
          5050.306,
          5050.851,
          5050.204000000001,
          5048.4,
          5045.475,
          5041.46,
          5036.388,
          5030.288,
          5023.191,
          5015.125,
          5006.116,
          4996.192,
          4985.377,
          4973.695,
          4961.17,
          4947.8240000000005,
          4933.68,
          4918.758,
          4903.079000000001,
          4886.663,
          4869.528,
          4851.693,
          4833.1759999999995,
          4813.994000000001,
          4794.163,
          4773.7,
          4752.619000000001,
          4730.938,
          4708.669,
          4685.8279999999995,
          4662.428,
          4638.482,
          4614.004,
          4589.005999999999,
          4563.5,
          4537.498,
          4511.012,
          4484.053,
          4456.6320000000005,
          4428.759,
          4400.445,
          4371.6990000000005,
          4342.532999999999,
          4312.955,
          4282.974,
          4252.599,
          4221.84,
          4190.704000000001,
          4159.201,
          4127.337,
          4095.1220000000003,
          4062.563,
          4029.667,
          3996.4429999999998,
          3962.8959999999997,
          3929.034,
          3894.865,
          3860.3940000000002,
          3825.6279999999997,
          3790.575,
          3755.239,
          3719.627,
          3683.745,
          3647.599,
          3611.195,
          3574.538,
          3537.634,
          3500.488,
          3463.105,
          3425.491,
          3387.651,
          3349.59,
          3311.3109999999997,
          3272.821,
          3234.1240000000003,
          3195.224,
          3156.1259999999997,
          3116.835,
          3077.3540000000003,
          3037.688,
          2997.842,
          2957.8179999999998,
          2917.6220000000003,
          2877.257,
          2836.7270000000003,
          2796.0359999999996,
          2755.187,
          2714.185,
          2673.032,
          2631.7329999999997,
          2590.291,
          2548.71,
          2506.992,
          2465.141,
          2423.161,
          2381.054,
          2338.824,
          2296.474,
          2254.007,
          2211.427,
          2168.735,
          2125.935,
          2083.031,
          2040.024,
          1996.918,
          1953.7160000000001,
          1910.42,
          1867.0320000000002,
          1823.557,
          1779.996,
          1736.352,
          1692.6270000000002,
          1648.8239999999998,
          1604.9460000000001,
          1560.996,
          1516.974,
          1472.885,
          1428.73,
          1384.5120000000002,
          1340.233,
          1295.896,
          1251.503,
          1207.055,
          1162.556,
          1118.007,
          1073.412,
          1028.771,
          984.087,
          939.363,
          894.6,
          849.801,
          804.967,
          760.1010000000001,
          715.205,
          670.2810000000001,
          625.331,
          580.356,
          535.359,
          490.343,
          445.30800000000005,
          400.256,
          355.191,
          310.113,
          265.024,
          219.92700000000002,
          174.824,
          129.715,
          84.604,
          39.491,
          -5.621,
          -50.73,
          -95.835,
          -140.933,
          -186.023,
          -231.104,
          -276.173,
          -321.228,
          -366.269,
          -411.292,
          -456.296,
          -501.28,
          -546.242,
          -591.18,
          -636.091,
          -680.9760000000001,
          -725.831,
          -770.655,
          -815.446,
          -860.203,
          -904.924,
          -949.607,
          -994.25,
          -1038.8519999999999,
          -1083.411,
          -1127.925,
          -1172.392,
          -1216.8110000000001,
          -1261.181,
          -1305.499,
          -1349.763,
          -1393.973,
          -1438.125,
          -1482.219,
          -1526.253,
          -1570.225,
          -1614.134,
          -1657.976,
          -1701.7520000000002,
          -1745.4589999999998,
          -1789.095,
          -1832.6589999999999,
          -1876.149,
          -1919.5629999999999,
          -1962.9,
          -2006.1570000000002,
          -2049.333,
          -2092.426,
          -2135.4339999999997,
          -2178.356,
          -2221.189,
          -2263.933,
          -2306.584,
          -2349.1420000000003,
          -2391.604,
          -2433.97,
          -2476.235,
          -2518.4,
          -2560.462,
          -2602.419,
          -2644.27,
          -2686.012,
          -2727.643,
          -2769.1620000000003,
          -2810.567,
          -2851.8559999999998,
          -2893.026,
          -2934.0759999999996,
          -2975.0040000000004,
          -3015.808,
          -3056.486,
          -3097.035,
          -3137.454,
          -3177.741,
          -3217.8940000000002,
          -3257.91,
          -3297.7870000000003,
          -3337.5240000000003,
          -3377.118,
          -3416.567,
          -3455.868,
          -3495.02,
          -3534.0209999999997,
          -3572.867,
          -3611.558,
          -3650.09,
          -3688.461,
          -3726.67,
          -3764.7129999999997,
          -3802.5879999999997,
          -3840.2929999999997,
          -3877.825,
          -3915.1820000000002,
          -3952.361,
          -3989.36,
          -4026.176,
          -4062.8070000000002,
          -4099.25,
          -4135.503,
          -4171.563,
          -4207.4259999999995,
          -4243.090999999999,
          -4278.555,
          -4313.814,
          -4348.867,
          -4383.709,
          -4418.339,
          -4452.753,
          -4486.947,
          -4520.920999999999,
          -4554.669,
          -4588.189,
          -4621.478,
          -4654.532999999999,
          -4687.35,
          -4719.927,
          -4752.258,
          -4784.343,
          -4816.1759999999995,
          -4847.754,
          -4879.0740000000005,
          -4910.133,
          -4940.9259999999995,
          -4971.45,
          -5001.701,
          -5031.675,
          -5061.369000000001,
          -5090.778,
          -5119.898,
          -5148.725,
          -5177.255,
          -5205.484,
          -5233.407999999999,
          -5261.021,
          -5288.32,
          -5315.3009999999995,
          -5341.956999999999,
          -5368.285,
          -5394.28,
          -5419.937,
          -5445.251,
          -5470.218000000001,
          -5494.831,
          -5519.085,
          -5542.975,
          -5566.496,
          -5589.642,
          -5612.408,
          -5634.786999999999,
          -5656.774,
          -5678.363,
          -5699.545999999999,
          -5720.319,
          -5740.675,
          -5760.606,
          -5780.108,
          -5799.170999999999,
          -5817.791,
          -5835.9580000000005,
          -5853.6669999999995,
          -5870.909000000001,
          -5887.677,
          -5903.963000000001,
          -5919.759,
          -5935.057,
          -5949.849,
          -5964.125,
          -5977.878000000001,
          -5991.098000000001,
          -6003.775,
          -6015.901,
          -6027.465999999999,
          -6038.459,
          -6048.871999999999,
          -6058.691999999999,
          -6067.909000000001,
          -6076.513000000001,
          -6084.493,
          -6091.835999999999,
          -6098.53,
          -6104.564,
          -6109.9259999999995,
          -6114.6,
          -6118.576,
          -6121.839,
          -6124.375,
          -6126.169,
          -6127.2080000000005,
          -6127.475,
          -6126.955,
          -6125.630999999999,
          -6123.486999999999,
          -6120.505999999999,
          -6116.67,
          -6111.96,
          -6106.359,
          -6099.845,
          -6092.4,
          -6084.003000000001,
          -6074.630999999999,
          -6064.263000000001,
          -6052.8769999999995,
          -6040.448,
          -6026.951999999999,
          -6012.363,
          -5996.656,
          -5979.803000000001,
          -5961.776999999999,
          -5942.548000000001,
          -5922.085999999999,
          -5900.36,
          -5877.338000000001,
          -5852.986,
          -5827.268,
          -5800.15,
          -5771.594,
          -5741.56,
          -5710.008000000001,
          -5676.897,
          -5642.181,
          -5605.815,
          -5567.754,
          -5527.946999999999,
          -5486.342,
          -5442.888000000001,
          -5397.526999999999,
          -5350.201999999999,
          -5300.855,
          -5249.42,
          -5195.834,
          -5140.028,
          -5081.931,
          -5021.471,
          -4958.57,
          -4893.148,
          -4825.122,
          -4754.407999999999,
          -4680.914000000001,
          -4604.548,
          -4525.214,
          -4442.813,
          -4357.241,
          -4268.393,
          -4176.16,
          -4080.43,
          -3981.09,
          -3878.0240000000003,
          -3771.116,
          -3660.2490000000003,
          -3545.3059999999996,
          -3426.1740000000004,
          -3302.741,
          -3174.902,
          -3042.5609999999997,
          -2905.631,
          -2764.0370000000003,
          -2617.724,
          -2466.658,
          -2310.83,
          -2150.262,
          -1985.016,
          -1815.192,
          -1640.942,
          -1462.47,
          -1280.038,
          -1093.973,
          -904.665,
          -712.567,
          -518.196,
          -322.126,
          -124.977,
          72.589,
          269.892,
          466.23900000000003,
          660.947,
          853.3539999999999,
          1042.838,
          1228.827,
          1410.809,
          1588.3370000000002,
          1761.039,
          1928.61,
          2090.8160000000003,
          2247.487,
          2398.514,
          2543.841,
          2683.46,
          2817.401,
          2945.728,
          3068.534,
          3185.9309999999996,
          3298.0490000000004,
          3405.033,
          3507.033,
          3604.205,
          3696.71,
          3784.712,
          3868.369,
          3947.842,
          4023.2859999999996,
          4094.8540000000003,
          4162.693,
          4226.9490000000005,
          4287.734,
          4345.255,
          4399.567,
          4450.817,
          4499.124,
          4544.601,
          4587.354,
          4627.488,
          4665.1,
          4700.284000000001,
          4733.1320000000005,
          4763.728,
          4792.154,
          4818.488,
          4842.805,
          4865.1759999999995,
          4885.668,
          4904.349,
          4921.278,
          4936.515,
          4950.117,
          4962.139,
          4972.6320000000005,
          4981.645,
          4989.227,
          4995.4220000000005,
          5000.275,
          5003.8279999999995,
          5006.119000000001,
          5007.189,
          5007.0740000000005,
          5005.808,
          5003.427,
          4999.963,
          4995.447,
          4989.911,
          4983.380999999999,
          4975.888,
          4967.457,
          4958.115,
          4947.888,
          4936.798,
          4924.87,
          4912.124,
          4898.585,
          4884.272,
          4869.204000000001,
          4853.404,
          4836.888,
          4819.675,
          4801.782999999999,
          4783.23,
          4764.03,
          4744.202,
          4723.759,
          4702.715999999999,
          4681.09,
          4658.893,
          4636.14,
          4612.843,
          4589.015,
          4564.67,
          4539.819,
          4514.474,
          4488.647,
          4462.348,
          4435.588,
          4408.379,
          4380.73,
          4352.65,
          4324.151,
          4295.241,
          4265.93,
          4236.227,
          4206.14,
          4175.677,
          4144.847,
          4113.659000000001,
          4082.119,
          4050.236,
          4018.018,
          3985.4709999999995,
          3952.603,
          3919.42,
          3885.93,
          3852.139,
          3818.054,
          3783.68,
          3749.025,
          3714.095,
          3678.8940000000002,
          3643.43,
          3607.708,
          3571.7329999999997,
          3535.511,
          3499.047,
          3462.3459999999995,
          3425.414,
          3388.256,
          3350.8759999999997,
          3313.2790000000005,
          3275.4709999999995,
          3237.455,
          3199.237,
          3160.82,
          3122.208,
          3083.408,
          3044.422,
          3005.2540000000004,
          2965.909,
          2926.3909999999996,
          2886.704,
          2846.8520000000003,
          2806.837,
          2766.665,
          2726.3379999999997,
          2685.861,
          2645.236,
          2604.468,
          2563.5589999999997,
          2522.514,
          2481.334,
          2440.025,
          2398.5879999999997,
          2357.027,
          2315.346,
          2273.5460000000003,
          2231.632,
          2189.606,
          2147.471,
          2105.23,
          2062.886,
          2020.441,
          1977.899,
          1935.2620000000002,
          1892.533,
          1849.715,
          1806.81,
          1763.8210000000001,
          1720.75,
          1677.6,
          1634.3729999999998,
          1591.0720000000001,
          1547.7,
          1504.2579999999998,
          1460.75,
          1417.1770000000001,
          1373.5420000000001,
          1329.8470000000002,
          1286.094,
          1242.286,
          1198.4260000000002,
          1154.514,
          1110.553,
          1066.546,
          1022.495,
          978.4019999999999,
          934.268,
          890.097,
          845.8889999999999,
          801.648,
          757.375,
          713.072,
          668.742,
          624.385,
          580.005,
          535.6030000000001,
          491.181,
          446.741,
          402.285,
          357.814,
          313.332,
          268.839,
          224.338,
          179.83,
          135.317,
          90.801,
          46.285,
          1.768,
          -42.745,
          -87.255,
          -131.75799999999998,
          -176.253,
          -220.739,
          -265.214,
          -309.675,
          -354.121,
          -398.551,
          -442.962,
          -487.353,
          -531.722,
          -576.067,
          -620.387,
          -664.68,
          -708.945,
          -753.178,
          -797.38,
          -841.548,
          -885.68,
          -929.775,
          -973.83,
          -1017.846,
          -1061.818,
          -1105.747,
          -1149.63,
          -1193.465,
          -1237.251,
          -1280.986,
          -1324.6689999999999,
          -1368.297,
          -1411.87,
          -1455.384,
          -1498.84,
          -1542.234,
          -1585.566,
          -1628.8329999999999,
          -1672.0339999999999,
          -1715.1660000000002,
          -1758.23,
          -1801.2220000000002,
          -1844.14,
          -1886.984,
          -1929.7520000000002,
          -1972.441,
          -2015.05,
          -2057.577,
          -2100.021,
          -2142.379,
          -2184.65,
          -2226.8320000000003,
          -2268.924,
          -2310.923,
          -2352.827,
          -2394.636,
          -2436.347,
          -2477.958,
          -2519.467,
          -2560.873,
          -2602.173,
          -2643.366,
          -2684.45,
          -2725.423,
          -2766.283,
          -2807.028,
          -2847.656,
          -2888.1659999999997,
          -2928.554,
          -2968.82,
          -3008.961,
          -3048.9759999999997,
          -3088.861,
          -3128.616,
          -3168.238,
          -3207.725,
          -3247.075,
          -3286.2859999999996,
          -3325.3559999999998,
          -3364.282,
          -3403.062,
          -3441.695,
          -3480.178,
          -3518.508,
          -3556.683,
          -3594.702,
          -3632.562,
          -3670.26,
          -3707.795,
          -3745.163,
          -3782.363,
          -3819.3920000000003,
          -3856.248,
          -3892.928,
          -3929.429,
          -3965.7490000000003,
          -4001.886,
          -4037.837,
          -4073.599,
          -4109.169,
          -4144.545999999999,
          -4179.725,
          -4214.705,
          -4249.483,
          -4284.055,
          -4318.419,
          -4352.572,
          -4386.5109999999995,
          -4420.234,
          -4453.736,
          -4487.016,
          -4520.069,
          -4552.893,
          -4585.485,
          -4617.840999999999,
          -4649.957,
          -4681.831,
          -4713.46,
          -4744.839,
          -4775.965999999999,
          -4806.837,
          -4837.447,
          -4867.795,
          -4897.875,
          -4927.683,
          -4957.217000000001,
          -4986.472,
          -5015.444,
          -5044.13,
          -5072.525,
          -5100.625,
          -5128.425,
          -5155.9220000000005,
          -5183.11,
          -5209.986,
          -5236.545,
          -5262.783,
          -5288.694,
          -5314.274,
          -5339.518,
          -5364.42,
          -5388.977,
          -5413.182,
          -5437.03,
          -5460.516,
          -5483.634,
          -5506.379,
          -5528.746,
          -5550.728,
          -5572.319,
          -5593.513000000001,
          -5614.304,
          -5634.687,
          -5654.653,
          -5674.196999999999,
          -5693.312,
          -5711.991,
          -5730.227,
          -5748.013000000001,
          -5765.342,
          -5782.205,
          -5798.596,
          -5814.505,
          -5829.9259999999995,
          -5844.85,
          -5859.269,
          -5873.173000000001,
          -5886.555,
          -5899.404,
          -5911.7119999999995,
          -5923.469,
          -5934.666,
          -5945.2919999999995,
          -5955.3369999999995,
          -5964.791,
          -5973.642,
          -5981.88,
          -5989.494000000001,
          -5996.471,
          -6002.798000000001,
          -6008.465999999999,
          -6013.46,
          -6017.767,
          -6021.375,
          -6024.268,
          -6026.434,
          -6027.857,
          -6028.522,
          -6028.415,
          -6027.518,
          -6025.816,
          -6023.291,
          -6019.927,
          -6015.705,
          -6010.606,
          -6004.611999999999,
          -5997.703,
          -5989.858,
          -5981.056,
          -5971.276,
          -5960.494000000001,
          -5948.689,
          -5935.834,
          -5921.906999999999,
          -5906.88,
          -5890.729,
          -5873.424,
          -5854.937,
          -5835.238,
          -5814.297,
          -5792.0830000000005,
          -5768.561,
          -5743.698,
          -5717.459,
          -5689.805,
          -5660.6990000000005,
          -5630.101,
          -5597.97,
          -5564.262,
          -5528.933000000001,
          -5491.937,
          -5453.224,
          -5412.744000000001,
          -5370.445,
          -5326.273,
          -5280.169,
          -5232.076,
          -5181.931,
          -5129.670999999999,
          -5075.228,
          -5018.532,
          -4959.5109999999995,
          -4898.09,
          -4834.19,
          -4767.729,
          -4698.622,
          -4626.781,
          -4552.1140000000005,
          -4474.528,
          -4393.9220000000005,
          -4310.197,
          -4223.247,
          -4132.965,
          -4039.241,
          -3941.962,
          -3841.014,
          -3736.282,
          -3627.6479999999997,
          -3514.9990000000003,
          -3398.219,
          -3277.199,
          -3151.8340000000003,
          -3022.026,
          -2887.685,
          -2748.739,
          -2605.129,
          -2456.817,
          -2303.79,
          -2146.067,
          -1983.701,
          -1816.7879999999998,
          -1645.4679999999998,
          -1469.9379999999999,
          -1290.45,
          -1107.316,
          -920.913,
          -731.682,
          -540.127,
          -346.806,
          -152.327,
          42.663000000000004,
          237.493,
          431.47900000000004,
          623.947,
          814.2410000000001,
          1001.7410000000001,
          1185.877,
          1366.135,
          1542.069,
          1713.299,
          1879.5179999999998,
          2040.486,
          2196.028,
          2346.029,
          2490.427,
          2629.2059999999997,
          2762.3920000000003,
          2890.0440000000003,
          3012.248,
          3129.112,
          3240.763,
          3347.3390000000004,
          3448.987,
          3545.861,
          3638.117,
          3725.9159999999997,
          3809.414,
          3888.7690000000002,
          3964.134,
          4035.659,
          4103.491,
          4167.77,
          4228.634,
          4286.215,
          4340.639,
          4392.028,
          4440.498,
          4486.161,
          4529.123,
          4569.487,
          4607.351,
          4642.807,
          4675.944,
          4706.847,
          4735.597,
          4762.272,
          4786.946,
          4809.688,
          4830.566,
          4849.646,
          4866.987,
          4882.65,
          4896.69,
          4909.16,
          4920.112,
          4929.597,
          4937.66,
          4944.346,
          4949.7,
          4953.762,
          4956.572,
          4958.168,
          4958.588,
          4957.866,
          4956.035,
          4953.129,
          4949.178,
          4944.213,
          4938.262,
          4931.353,
          4923.513,
          4914.768,
          4905.142,
          4894.659000000001,
          4883.343,
          4871.215999999999,
          4858.298,
          4844.612,
          4830.177,
          4815.012,
          4799.137,
          4782.568,
          4765.325,
          4747.423,
          4728.878,
          4709.708,
          4689.928,
          4669.5509999999995,
          4648.593,
          4627.067,
          4604.9890000000005,
          4582.369000000001,
          4559.221,
          4535.558,
          4511.392,
          4486.735,
          4461.597,
          4435.99,
          4409.924,
          4383.41,
          4356.458,
          4329.0779999999995,
          4301.281,
          4273.0740000000005,
          4244.467000000001,
          4215.469,
          4186.089,
          4156.335,
          4126.215,
          4095.738,
          4064.9109999999996,
          4033.742,
          4002.238,
          3970.407,
          3938.255,
          3905.79,
          3873.018,
          3839.946,
          3806.5809999999997,
          3772.928,
          3738.994,
          3704.785,
          3670.3070000000002,
          3635.565,
          3600.566,
          3565.315,
          3529.816,
          3494.0759999999996,
          3458.1,
          3421.893,
          3385.4590000000003,
          3348.804,
          3311.9320000000002,
          3274.848,
          3237.5570000000002,
          3200.063,
          3162.3709999999996,
          3124.4840000000004,
          3086.408,
          3048.1459999999997,
          3009.703,
          2971.0820000000003,
          2932.288,
          2893.324,
          2854.1940000000004,
          2814.902,
          2775.4509999999996,
          2735.8459999999995,
          2696.09,
          2656.185,
          2616.137,
          2575.947,
          2535.621,
          2495.159,
          2454.567,
          2413.847,
          2373.002,
          2332.036,
          2290.951,
          2249.751,
          2208.438,
          2167.015,
          2125.485,
          2083.8520000000003,
          2042.1170000000002,
          2000.283,
          1958.354,
          1916.332,
          1874.219,
          1832.0179999999998,
          1789.7320000000002,
          1747.364,
          1704.915,
          1662.388,
          1619.786,
          1577.111,
          1534.366,
          1491.5529999999999,
          1448.674,
          1405.731,
          1362.7279999999998,
          1319.665,
          1276.546,
          1233.372,
          1190.146,
          1146.871,
          1103.547,
          1060.177,
          1016.7639999999999,
          973.309,
          929.815,
          886.283,
          842.716,
          799.115,
          755.4839999999999,
          711.822,
          668.133,
          624.419,
          580.681,
          536.922,
          493.14300000000003,
          449.346,
          405.533,
          361.70599999999996,
          317.867,
          274.018,
          230.16,
          186.295,
          142.42600000000002,
          98.554,
          54.68,
          10.807,
          -33.064,
          -76.93,
          -120.791,
          -164.644,
          -208.488,
          -252.321,
          -296.14099999999996,
          -339.94599999999997,
          -383.735,
          -427.506,
          -471.25800000000004,
          -514.987,
          -558.694,
          -602.376,
          -646.031,
          -689.659,
          -733.2560000000001,
          -776.822,
          -820.3539999999999,
          -863.852,
          -907.313,
          -950.735,
          -994.118,
          -1037.4589999999998,
          -1080.756,
          -1124.009,
          -1167.215,
          -1210.373,
          -1253.48,
          -1296.536,
          -1339.539,
          -1382.486,
          -1425.3770000000002,
          -1468.21,
          -1510.9820000000002,
          -1553.692,
          -1596.34,
          -1638.922,
          -1681.4370000000001,
          -1723.8829999999998,
          -1766.26,
          -1808.5639999999999,
          -1850.795,
          -1892.95,
          -1935.0279999999998,
          -1977.0279999999998,
          -2018.9460000000001,
          -2060.783,
          -2102.535,
          -2144.202,
          -2185.781,
          -2227.27,
          -2268.669,
          -2309.974,
          -2351.185,
          -2392.299,
          -2433.315,
          -2474.231,
          -2515.044,
          -2555.754,
          -2596.357,
          -2636.853,
          -2677.24,
          -2717.515,
          -2757.677,
          -2797.724,
          -2837.653,
          -2877.4629999999997,
          -2917.152,
          -2956.719,
          -2996.16,
          -3035.474,
          -3074.658,
          -3113.712,
          -3152.632,
          -3191.417,
          -3230.065,
          -3268.573,
          -3306.94,
          -3345.1620000000003,
          -3383.238,
          -3421.167,
          -3458.945,
          -3496.57,
          -3534.04,
          -3571.353,
          -3608.506,
          -3645.498,
          -3682.3259999999996,
          -3718.987,
          -3755.478,
          -3791.7990000000004,
          -3827.945,
          -3863.915,
          -3899.7070000000003,
          -3935.316,
          -3970.742,
          -4005.9809999999998,
          -4041.03,
          -4075.888,
          -4110.55,
          -4145.015,
          -4179.28,
          -4213.342000000001,
          -4247.198,
          -4280.845,
          -4314.28,
          -4347.501,
          -4380.503,
          -4413.285,
          -4445.844,
          -4478.174,
          -4510.275,
          -4542.142,
          -4573.772,
          -4605.163,
          -4636.309,
          -4667.209,
          -4697.859,
          -4728.254,
          -4758.392,
          -4788.269,
          -4817.880999999999,
          -4847.223,
          -4876.294,
          -4905.088,
          -4933.601,
          -4961.831,
          -4989.771,
          -5017.419,
          -5044.77,
          -5071.819,
          -5098.563,
          -5124.996,
          -5151.115,
          -5176.915,
          -5202.391,
          -5227.537,
          -5252.35,
          -5276.8240000000005,
          -5300.954000000001,
          -5324.735,
          -5348.161,
          -5371.228,
          -5393.93,
          -5416.26,
          -5438.214,
          -5459.786,
          -5480.969,
          -5501.757,
          -5522.145,
          -5542.126,
          -5561.693,
          -5580.84,
          -5599.56,
          -5617.846,
          -5635.691,
          -5653.088000000001,
          -5670.03,
          -5686.508000000001,
          -5702.515,
          -5718.044,
          -5733.085,
          -5747.632,
          -5761.674,
          -5775.205,
          -5788.214,
          -5800.691999999999,
          -5812.630999999999,
          -5824.02,
          -5834.85,
          -5845.111,
          -5854.7919999999995,
          -5863.882,
          -5872.371999999999,
          -5880.249,
          -5887.5019999999995,
          -5894.12,
          -5900.089,
          -5905.399,
          -5910.035,
          -5913.984,
          -5917.234,
          -5919.771,
          -5921.578,
          -5922.644,
          -5922.951,
          -5922.485,
          -5921.228,
          -5919.164000000001,
          -5916.278,
          -5912.55,
          -5907.9619999999995,
          -5902.496,
          -5896.132,
          -5888.85,
          -5880.63,
          -5871.45,
          -5861.286999999999,
          -5850.121,
          -5837.925,
          -5824.6759999999995,
          -5810.349,
          -5794.918000000001,
          -5778.355,
          -5760.633000000001,
          -5741.721,
          -5721.590999999999,
          -5700.210999999999,
          -5677.548000000001,
          -5653.568,
          -5628.238,
          -5601.52,
          -5573.376,
          -5543.768,
          -5512.655,
          -5479.995,
          -5445.743,
          -5409.854,
          -5372.28,
          -5332.972,
          -5291.878000000001,
          -5248.944,
          -5204.115,
          -5157.332,
          -5108.534000000001,
          -5057.657999999999,
          -5004.64,
          -4949.409000000001,
          -4891.895,
          -4832.023,
          -4769.715999999999,
          -4704.894,
          -4637.474,
          -4567.366,
          -4494.483,
          -4418.731,
          -4340.0109999999995,
          -4258.227,
          -4173.272,
          -4085.042,
          -3993.428,
          -3898.3179999999998,
          -3799.599,
          -3697.158,
          -3590.88,
          -3480.6479999999997,
          -3366.3509999999997,
          -3247.8779999999997,
          -3125.125,
          -2997.993,
          -2866.393,
          -2730.2490000000003,
          -2589.5,
          -2444.106,
          -2294.052,
          -2139.349,
          -1980.046,
          -1816.23,
          -1648.035,
          -1475.644,
          -1299.302,
          -1119.306,
          -936.0219999999999,
          -749.8760000000001,
          -561.356,
          -371.00699999999995,
          -179.422,
          12.764000000000001,
          204.893,
          396.293,
          586.297,
          774.255,
          959.552,
          1141.619,
          1319.944,
          1494.0770000000002,
          1663.6370000000002,
          1828.3129999999999,
          1987.858,
          2142.092,
          2290.894,
          2434.197,
          2571.979,
          2704.259,
          2831.091,
          2952.5559999999996,
          3068.757,
          3179.8140000000003,
          3285.863,
          3387.047,
          3483.515,
          3575.421,
          3662.921,
          3746.1690000000003,
          3825.3190000000004,
          3900.522,
          3971.927,
          4039.677,
          4103.911,
          4164.765,
          4222.3679999999995,
          4276.846,
          4328.318,
          4376.9,
          4422.702,
          4465.829000000001,
          4506.383,
          4544.459,
          4580.149,
          4613.542,
          4644.721,
          4673.767,
          4700.7570000000005,
          4725.762,
          4748.854,
          4770.099,
          4789.56,
          4807.298,
          4823.371,
          4837.835999999999,
          4850.745,
          4862.149,
          4872.097,
          4880.635,
          4887.809,
          4893.661,
          4898.231,
          4901.56,
          4903.685,
          4904.643,
          4904.468,
          4903.193,
          4900.851,
          4897.473,
          4893.088,
          4887.726,
          4881.413,
          4874.175,
          4866.039000000001,
          4857.029,
          4847.168,
          4836.48,
          4824.987,
          4812.71,
          4799.669,
          4785.885,
          4771.376,
          4756.162,
          4740.259,
          4723.685,
          4706.458,
          4688.593,
          4670.106,
          4651.013,
          4631.327,
          4611.065,
          4590.238,
          4568.861,
          4546.947,
          4524.5070000000005,
          4501.556,
          4478.105,
          4454.165,
          4429.747,
          4404.862,
          4379.522,
          4353.736,
          4327.515,
          4300.8679999999995,
          4273.806,
          4246.335999999999,
          4218.468,
          4190.210999999999,
          4161.573,
          4132.564,
          4103.191,
          4073.462,
          4043.384,
          4012.966,
          3982.2140000000004,
          3951.136,
          3919.74,
          3888.031,
          3856.0170000000003,
          3823.703,
          3791.097,
          3758.205,
          3725.032,
          3691.585,
          3657.87,
          3623.8920000000003,
          3589.657,
          3555.171,
          3520.438,
          3485.465,
          3450.255,
          3414.815,
          3379.1490000000003,
          3343.261,
          3307.158,
          3270.842,
          3234.3190000000004,
          3197.594,
          3160.671,
          3123.553,
          3086.2459999999996,
          3048.7529999999997,
          3011.079,
          2973.2270000000003,
          2935.2009999999996,
          2897.006,
          2858.645,
          2820.1209999999996,
          2781.438,
          2742.6009999999997,
          2703.611,
          2664.474,
          2625.192,
          2585.769,
          2546.208,
          2506.512,
          2466.685,
          2426.729,
          2386.6479999999997,
          2346.444,
          2306.1220000000003,
          2265.683,
          2225.131,
          2184.468,
          2143.698,
          2102.823,
          2061.845,
          2020.769,
          1979.596,
          1938.329,
          1896.97,
          1855.523,
          1813.989,
          1772.371,
          1730.6729999999998,
          1688.895,
          1647.0410000000002,
          1605.114,
          1563.114,
          1521.045,
          1478.91,
          1436.7089999999998,
          1394.4470000000001,
          1352.124,
          1309.743,
          1267.306,
          1224.816,
          1182.274,
          1139.684,
          1097.045,
          1054.362,
          1011.6360000000001,
          968.8689999999999,
          926.063,
          883.22,
          840.342,
          797.43,
          754.488,
          711.5169999999999,
          668.5189999999999,
          625.496,
          582.4490000000001,
          539.381,
          496.293,
          453.18800000000005,
          410.06699999999995,
          366.93199999999996,
          323.785,
          280.627,
          237.46099999999998,
          194.28799999999998,
          151.11,
          107.929,
          64.747,
          21.565,
          -21.615,
          -64.791,
          -107.962,
          -151.125,
          -194.28,
          -237.423,
          -280.55400000000003,
          -323.671,
          -366.772,
          -409.856,
          -452.92,
          -495.964,
          -538.985,
          -581.982,
          -624.953,
          -667.8960000000001,
          -710.81,
          -753.694,
          -796.544,
          -839.3610000000001,
          -882.1419999999999,
          -924.885,
          -967.5889999999999,
          -1010.252,
          -1052.873,
          -1095.45,
          -1137.981,
          -1180.465,
          -1222.899,
          -1265.2830000000001,
          -1307.615,
          -1349.8929999999998,
          -1392.115,
          -1434.28,
          -1476.385,
          -1518.431,
          -1560.4129999999998,
          -1602.332,
          -1644.1860000000001,
          -1685.9720000000002,
          -1727.6889999999999,
          -1769.335,
          -1810.9089999999999,
          -1852.4089999999999,
          -1893.8329999999999,
          -1935.18,
          -1976.4470000000001,
          -2017.634,
          -2058.737,
          -2099.757,
          -2140.69,
          -2181.535,
          -2222.291,
          -2262.955,
          -2303.527,
          -2344.0029999999997,
          -2384.382,
          -2424.663,
          -2464.843,
          -2504.9210000000003,
          -2544.895,
          -2584.763,
          -2624.5229999999997,
          -2664.173,
          -2703.712,
          -2743.137,
          -2782.447,
          -2821.64,
          -2860.7129999999997,
          -2899.665,
          -2938.494,
          -2977.197,
          -3015.7729999999997,
          -3054.22,
          -3092.5359999999996,
          -3130.718,
          -3168.765,
          -3206.675,
          -3244.4440000000004,
          -3282.072,
          -3319.5559999999996,
          -3356.8940000000002,
          -3394.083,
          -3431.1220000000003,
          -3468.008,
          -3504.739,
          -3541.312,
          -3577.7259999999997,
          -3613.978,
          -3650.065,
          -3685.986,
          -3721.737,
          -3757.317,
          -3792.722,
          -3827.9509999999996,
          -3863.0009999999997,
          -3897.869,
          -3932.552,
          -3967.0490000000004,
          -4001.3559999999998,
          -4035.4709999999995,
          -4069.39,
          -4103.112,
          -4136.633,
          -4169.95,
          -4203.061,
          -4235.963,
          -4268.652,
          -4301.126,
          -4333.3820000000005,
          -4365.417,
          -4397.227,
          -4428.809,
          -4460.161,
          -4491.278,
          -4522.157999999999,
          -4552.795999999999,
          -4583.191,
          -4613.338,
          -4643.233,
          -4672.874,
          -4702.255999999999,
          -4731.376,
          -4760.229,
          -4788.813,
          -4817.123,
          -4845.156,
          -4872.906,
          -4900.371,
          -4927.545999999999,
          -4954.427,
          -4981.009,
          -5007.289000000001,
          -5033.2609999999995,
          -5058.920999999999,
          -5084.264,
          -5109.286,
          -5133.982,
          -5158.347,
          -5182.376,
          -5206.064,
          -5229.406,
          -5252.396,
          -5275.029,
          -5297.299,
          -5319.201,
          -5340.73,
          -5361.879,
          -5382.643,
          -5403.014,
          -5422.988,
          -5442.557,
          -5461.715999999999,
          -5480.456,
          -5498.773,
          -5516.658,
          -5534.106,
          -5551.108,
          -5567.656,
          -5583.744000000001,
          -5599.3640000000005,
          -5614.507,
          -5629.1669999999995,
          -5643.3330000000005,
          -5656.999,
          -5670.154,
          -5682.789000000001,
          -5694.897,
          -5706.468000000001,
          -5717.491,
          -5727.956999999999,
          -5737.855,
          -5747.177,
          -5755.91,
          -5764.043000000001,
          -5771.565,
          -5778.465999999999,
          -5784.732,
          -5790.353,
          -5795.314,
          -5799.603,
          -5803.206999999999,
          -5806.111999999999,
          -5808.305,
          -5809.77,
          -5810.493,
          -5810.4580000000005,
          -5809.65,
          -5808.052,
          -5805.647,
          -5802.419,
          -5798.349,
          -5793.418000000001,
          -5787.609,
          -5780.9,
          -5773.272,
          -5764.704000000001,
          -5755.174,
          -5744.659000000001,
          -5733.137,
          -5720.5830000000005,
          -5706.974,
          -5692.281999999999,
          -5676.481,
          -5659.545,
          -5641.443,
          -5622.148,
          -5601.6269999999995,
          -5579.85,
          -5556.781999999999,
          -5532.39,
          -5506.639,
          -5479.491,
          -5450.906999999999,
          -5420.849,
          -5389.274,
          -5356.138000000001,
          -5321.399,
          -5285.007,
          -5246.916,
          -5207.073,
          -5165.428,
          -5121.923,
          -5076.503,
          -5029.109,
          -4979.677,
          -4928.142,
          -4874.439,
          -4818.497,
          -4760.242,
          -4699.599,
          -4636.4890000000005,
          -4570.829000000001,
          -4502.534000000001,
          -4431.516,
          -4357.682,
          -4280.937,
          -4201.183,
          -4118.319,
          -4032.239,
          -3942.837,
          -3850.002,
          -3753.623,
          -3653.5879999999997,
          -3549.782,
          -3442.091,
          -3330.403,
          -3214.6090000000004,
          -3094.6040000000003,
          -2970.289,
          -2841.5759999999996,
          -2708.385,
          -2570.656,
          -2428.344,
          -2281.429,
          -2129.92,
          -1973.859,
          -1813.325,
          -1648.445,
          -1479.392,
          -1306.397,
          -1129.748,
          -949.795,
          -766.951,
          -581.688,
          -394.536,
          -206.07299999999998,
          -16.919,
          172.27900000000002,
          360.86300000000006,
          548.172,
          733.566,
          916.435,
          1096.212,
          1272.387,
          1444.507,
          1612.191,
          1775.122,
          1933.0510000000002,
          2085.79,
          2233.215,
          2375.251,
          2511.869,
          2643.085,
          2768.945,
          2889.526,
          3004.925,
          3115.258,
          3220.655,
          3321.255,
          3417.203,
          3508.651,
          3595.748,
          3678.6490000000003,
          3757.502,
          3832.4570000000003,
          3903.659,
          3971.2490000000003,
          4035.364,
          4096.157999999999,
          4153.698,
          4208.168,
          4259.666,
          4308.305,
          4354.194,
          4397.437,
          4438.135,
          4476.38,
          4512.266,
          4545.878,
          4577.3,
          4606.61,
          4633.885,
          4659.196,
          4682.613,
          4704.201,
          4724.023,
          4742.14,
          4758.608,
          4773.484,
          4786.819,
          4798.663,
          4809.065,
          4818.072,
          4825.727,
          4832.072,
          4837.149,
          4840.995,
          4843.649,
          4845.146,
          4845.521,
          4844.807,
          4843.034000000001,
          4840.235,
          4836.439,
          4831.6720000000005,
          4825.965,
          4819.340999999999,
          4811.826,
          4803.444,
          4794.22,
          4784.1759999999995,
          4773.333,
          4761.712,
          4749.334,
          4736.219,
          4722.3859999999995,
          4707.852,
          4692.6359999999995,
          4676.755,
          4660.224,
          4643.062,
          4625.282,
          4606.9,
          4587.931,
          4568.389,
          4548.287,
          4527.639,
          4506.458,
          4484.755999999999,
          4462.545,
          4439.837,
          4416.645,
          4392.978,
          4368.847,
          4344.264,
          4319.238,
          4293.78,
          4267.899,
          4241.604,
          4214.905,
          4187.811,
          4160.33,
          4132.471,
          4104.241,
          4075.65,
          4046.705,
          4017.414,
          3987.784,
          3957.823,
          3927.5370000000003,
          3896.933,
          3866.0190000000002,
          3834.801,
          3803.285,
          3771.478,
          3739.386,
          3707.015,
          3674.3709999999996,
          3641.46,
          3608.2870000000003,
          3574.857,
          3541.178,
          3507.2529999999997,
          3473.087,
          3438.687,
          3404.0559999999996,
          3369.2009999999996,
          3334.1240000000003,
          3298.8320000000003,
          3263.329,
          3227.619,
          3191.7070000000003,
          3155.597,
          3119.2929999999997,
          3082.7990000000004,
          3046.12,
          3009.26,
          2972.222,
          2935.011,
          2897.63,
          2860.083,
          2822.373,
          2784.505,
          2746.482,
          2708.3070000000002,
          2669.9829999999997,
          2631.515,
          2592.905,
          2554.157,
          2515.2729999999997,
          2476.259,
          2437.115,
          2397.845,
          2358.452,
          2318.94,
          2279.31,
          2239.567,
          2199.7129999999997,
          2159.751,
          2119.683,
          2079.512,
          2039.241,
          1998.8729999999998,
          1958.4089999999999,
          1917.854,
          1877.2089999999998,
          1836.477,
          1795.66,
          1754.761,
          1713.7820000000002,
          1672.726,
          1631.594,
          1590.39,
          1549.116,
          1507.774,
          1466.365,
          1424.8929999999998,
          1383.36,
          1341.7679999999998,
          1300.118,
          1258.414,
          1216.657,
          1174.849,
          1132.993,
          1091.09,
          1049.143,
          1007.154,
          965.123,
          923.055,
          880.95,
          838.81,
          796.638,
          754.436,
          712.204,
          669.946,
          627.6619999999999,
          585.356,
          543.028,
          500.681,
          458.316,
          415.936,
          373.542,
          331.135,
          288.718,
          246.292,
          203.86,
          161.422,
          116.477,
          74.032,
          31.588,
          -10.855,
          -53.294,
          -95.727,
          -138.154,
          -180.572,
          -222.979,
          -265.375,
          -307.757,
          -350.12300000000005,
          -392.473,
          -434.80300000000005,
          -477.11400000000003,
          -519.4019999999999,
          -561.6669999999999,
          -603.9069999999999,
          -646.119,
          -688.303,
          -730.457,
          -772.579,
          -814.668,
          -856.722,
          -898.7389999999999,
          -940.7180000000001,
          -982.6560000000001,
          -1024.5539999999999,
          -1066.4080000000001,
          -1108.2169999999999,
          -1149.98,
          -1191.695,
          -1233.361,
          -1274.975,
          -1316.536,
          -1358.0420000000001,
          -1399.493,
          -1440.885,
          -1482.2179999999998,
          -1523.49,
          -1564.7,
          -1605.845,
          -1646.9229999999998,
          -1687.935,
          -1728.876,
          -1769.747,
          -1810.545,
          -1851.269,
          -1891.9160000000002,
          -1932.486,
          -1972.977,
          -2013.386,
          -2053.712,
          -2093.9539999999997,
          -2134.109,
          -2174.176,
          -2214.154,
          -2254.0389999999998,
          -2293.8320000000003,
          -2333.529,
          -2373.13,
          -2412.631,
          -2452.032,
          -2491.331,
          -2530.525,
          -2569.614,
          -2608.594,
          -2647.465,
          -2686.225,
          -2724.87,
          -2763.4,
          -2801.813,
          -2840.107,
          -2878.2790000000005,
          -2916.328,
          -2954.252,
          -2992.0490000000004,
          -3029.716,
          -3067.252,
          -3104.655,
          -3141.922,
          -3179.052,
          -3216.042,
          -3252.89,
          -3289.595,
          -3326.153,
          -3362.562,
          -3398.822,
          -3434.928,
          -3470.8790000000004,
          -3506.6740000000004,
          -3542.308,
          -3577.78,
          -3613.0879999999997,
          -3648.2290000000003,
          -3683.2009999999996,
          -3718.0009999999997,
          -3752.627,
          -3787.0759999999996,
          -3821.3459999999995,
          -3855.434,
          -3889.3379999999997,
          -3923.055,
          -3956.5809999999997,
          -3989.9159999999997,
          -4023.055,
          -4055.9959999999996,
          -4088.736,
          -4121.272,
          -4153.602,
          -4185.722,
          -4217.63,
          -4249.323,
          -4280.7970000000005,
          -4312.049,
          -4343.076,
          -4373.874,
          -4404.443,
          -4434.775,
          -4464.87,
          -4494.724,
          -4524.333,
          -4553.693,
          -4582.802,
          -4611.654,
          -4640.248,
          -4668.579000000001,
          -4696.642,
          -4724.436,
          -4751.954000000001,
          -4779.193,
          -4806.15,
          -4832.82,
          -4859.1990000000005,
          -4885.282999999999,
          -4911.067,
          -4936.545999999999,
          -4961.717000000001,
          -4986.5740000000005,
          -5011.1140000000005,
          -5035.33,
          -5059.218,
          -5082.774,
          -5105.991,
          -5128.866,
          -5151.392,
          -5173.565,
          -5195.378,
          -5216.827,
          -5237.904,
          -5258.606,
          -5278.925,
          -5298.855,
          -5318.391,
          -5337.526,
          -5356.253000000001,
          -5374.566,
          -5392.456999999999,
          -5409.92,
          -5426.9490000000005,
          -5443.535,
          -5459.672,
          -5475.351,
          -5490.565,
          -5505.305,
          -5519.565,
          -5533.334,
          -5546.605,
          -5559.37,
          -5571.618,
          -5583.340999999999,
          -5594.529,
          -5605.173000000001,
          -5615.263000000001,
          -5624.7880000000005,
          -5633.7390000000005,
          -5642.103,
          -5649.87,
          -5657.03,
          -5663.57,
          -5669.478,
          -5674.741999999999,
          -5679.349,
          -5683.286,
          -5686.541,
          -5689.098000000001,
          -5690.944,
          -5692.065,
          -5692.445,
          -5692.069,
          -5690.92,
          -5688.982,
          -5686.2390000000005,
          -5682.673000000001,
          -5678.265,
          -5672.9980000000005,
          -5666.852,
          -5659.807,
          -5651.840999999999,
          -5642.935,
          -5633.066,
          -5622.2119999999995,
          -5610.348000000001,
          -5597.451999999999,
          -5583.496,
          -5568.456999999999,
          -5552.306,
          -5535.014,
          -5516.555,
          -5496.898,
          -5476.009,
          -5453.86,
          -5430.4130000000005,
          -5405.638000000001,
          -5379.494000000001,
          -5351.946999999999,
          -5322.956,
          -5292.48,
          -5260.477,
          -5226.904,
          -5191.715,
          -5154.861,
          -5116.293,
          -5075.960999999999,
          -5033.808,
          -4989.781,
          -4943.819,
          -4895.863,
          -4845.849,
          -4793.710999999999,
          -4739.380999999999,
          -4682.785,
          -4623.851,
          -4562.5,
          -4498.652,
          -4432.224,
          -4363.127,
          -4291.272,
          -4216.564,
          -4138.907999999999,
          -4058.203,
          -3974.3459999999995,
          -3887.2329999999997,
          -3796.7540000000004,
          -3702.8,
          -3605.258,
          -3504.018,
          -3398.966,
          -3289.99,
          -3176.9829999999997,
          -3059.8390000000004,
          -2938.46,
          -2812.756,
          -2682.6490000000003,
          -2548.074,
          -2408.984,
          -2265.3579999999997,
          -2117.197,
          -1964.5379999999998,
          -1807.455,
          -1646.0639999999999,
          -1480.53,
          -1311.0720000000001,
          -1137.965,
          -961.545,
          -782.211,
          -600.419,
          -416.684,
          -231.56900000000002,
          -45.678000000000004,
          140.357,
          325.887,
          510.265,
          692.857,
          873.06,
          1050.31,
          1224.099,
          1393.976,
          1559.556,
          1720.519,
          1876.612,
          2027.644,
          2173.4829999999997,
          2314.049,
          2449.3089999999997,
          2579.271,
          2703.9770000000003,
          2823.4959999999996,
          2937.923,
          3047.367,
          3151.953,
          3251.8179999999998,
          3347.1,
          3437.948,
          3524.509,
          3606.9309999999996,
          3685.363,
          3759.949,
          3830.8320000000003,
          3898.152,
          3962.042,
          4022.634,
          4080.053,
          4134.420999999999,
          4185.854,
          4234.464,
          4280.357,
          4323.638,
          4364.403,
          4402.746,
          4438.7570000000005,
          4472.522,
          4504.123,
          4533.637,
          4561.138,
          4586.7,
          4610.389,
          4632.27,
          4652.405,
          4670.855,
          4687.675,
          4702.92,
          4716.641,
          4728.889,
          4739.710999999999,
          4749.153,
          4757.2570000000005,
          4764.067,
          4769.621,
          4773.959,
          4777.117,
          4779.13,
          4780.034000000001,
          4779.86,
          4778.639,
          4776.402,
          4773.178,
          4768.994000000001,
          4763.879,
          4757.857,
          4750.9529999999995,
          4743.192,
          4734.596,
          4725.189,
          4714.99,
          4704.022,
          4692.304,
          4679.857,
          4666.697,
          4652.844,
          4638.315,
          4623.128,
          4607.298,
          4590.842000000001,
          4573.773,
          4556.109,
          4537.862,
          4519.048,
          4499.679,
          4479.77,
          4459.331,
          4438.376,
          4416.917,
          4394.965,
          4372.532999999999,
          4349.63,
          4326.268,
          4302.456,
          4278.207,
          4253.527,
          4228.429,
          4202.92,
          4177.01,
          4150.708,
          4124.022,
          4096.960999999999,
          4069.532,
          4041.745,
          4013.6059999999998,
          3985.1240000000003,
          3956.305,
          3927.157,
          3897.6859999999997,
          3867.901,
          3837.805,
          3807.409,
          3776.717,
          3745.736,
          3714.4709999999995,
          3682.929,
          3651.115,
          3619.0359999999996,
          3586.697,
          3554.1020000000003,
          3521.259,
          3488.171,
          3454.844,
          3421.284,
          3387.494,
          3353.48,
          3319.2470000000003,
          3284.7990000000004,
          3250.14,
          3215.276,
          3180.21,
          3144.947,
          3109.491,
          3073.8459999999995,
          3038.0159999999996,
          3002.005,
          2965.817,
          2929.455,
          2892.925,
          2856.228,
          2819.37,
          2782.3520000000003,
          2745.18,
          2707.857,
          2670.385,
          2632.768,
          2595.01,
          2557.114,
          2519.0820000000003,
          2480.9179999999997,
          2442.625,
          2404.206,
          2365.6639999999998,
          2327.002,
          2288.223,
          2249.33,
          2210.325,
          2171.212,
          2131.992,
          2092.67,
          2053.246,
          2013.725,
          1974.108,
          1934.399,
          1894.599,
          1854.711,
          1814.7379999999998,
          1774.682,
          1734.545,
          1694.33,
          1654.039,
          1613.675,
          1573.239,
          1532.734,
          1492.1629999999998,
          1451.527,
          1410.828,
          1370.07,
          1329.253,
          1288.38,
          1247.453,
          1206.474,
          1165.4460000000001,
          1124.37,
          1083.248,
          1042.083,
          1000.875,
          959.628,
          918.3430000000001,
          877.0219999999999,
          835.6669999999999,
          794.28,
          752.863,
          711.4169999999999,
          669.945,
          628.448,
          586.929,
          545.388,
          503.82800000000003,
          462.25,
          420.657,
          379.05,
          337.431,
          295.801,
          254.162,
          212.517,
          170.86599999999999,
          129.21200000000002,
          87.556,
          45.9,
          4.245,
          -37.406,
          -79.053,
          -120.693,
          -162.325,
          -203.947,
          -245.558,
          -287.155,
          -328.73800000000006,
          -370.30400000000003,
          -411.853,
          -453.38199999999995,
          -494.889,
          -536.374,
          -577.8340000000001,
          -619.268,
          -660.675,
          -702.052,
          -743.3989999999999,
          -784.7130000000001,
          -825.993,
          -867.237,
          -908.444,
          -949.613,
          -990.74,
          -1031.826,
          -1072.869,
          -1113.866,
          -1154.816,
          -1195.7169999999999,
          -1236.569,
          -1277.369,
          -1318.116,
          -1358.808,
          -1399.444,
          -1440.0220000000002,
          -1480.54,
          -1520.996,
          -1561.39,
          -1601.719,
          -1641.983,
          -1682.1779999999999,
          -1722.3039999999999,
          -1762.358,
          -1802.34,
          -1842.2479999999998,
          -1882.079,
          -1921.8329999999999,
          -1961.507,
          -2001.101,
          -2040.611,
          -2080.0370000000003,
          -2119.376,
          -2158.6279999999997,
          -2197.7889999999998,
          -2236.86,
          -2275.837,
          -2314.719,
          -2353.504,
          -2392.1910000000003,
          -2430.778,
          -2469.263,
          -2507.643,
          -2545.9179999999997,
          -2584.085,
          -2622.143,
          -2660.0890000000004,
          -2697.923,
          -2735.6409999999996,
          -2773.242,
          -2810.724,
          -2848.085,
          -2885.323,
          -2922.4359999999997,
          -2959.422,
          -2996.2790000000005,
          -3033.006,
          -3069.599,
          -3106.058,
          -3142.3790000000004,
          -3178.5609999999997,
          -3214.6009999999997,
          -3250.498,
          -3286.25,
          -3321.853,
          -3357.3059999999996,
          -3392.607,
          -3427.7529999999997,
          -3462.742,
          -3497.572,
          -3532.24,
          -3566.744,
          -3601.0820000000003,
          -3635.2509999999997,
          -3669.248,
          -3703.072,
          -3736.719,
          -3770.187,
          -3803.474,
          -3836.577,
          -3869.493,
          -3902.219,
          -3934.7529999999997,
          -3967.093,
          -3999.2340000000004,
          -4031.175,
          -4062.913,
          -4094.4440000000004,
          -4125.766,
          -4156.876,
          -4187.77,
          -4218.446,
          -4248.9,
          -4279.13,
          -4309.130999999999,
          -4338.9,
          -4368.436,
          -4397.733,
          -4426.789000000001,
          -4455.6,
          -4484.163,
          -4512.473,
          -4540.528,
          -4568.323,
          -4595.855,
          -4623.12,
          -4650.113,
          -4676.832,
          -4703.271,
          -4729.428,
          -4755.2970000000005,
          -4780.874,
          -4806.155,
          -4831.135,
          -4855.811,
          -4880.177,
          -4904.228,
          -4927.96,
          -4951.369000000001,
          -4974.4490000000005,
          -4997.194,
          -5019.6,
          -5041.662,
          -5063.374,
          -5084.73,
          -5105.726,
          -5126.354,
          -5146.611,
          -5166.4890000000005,
          -5185.982,
          -5205.085,
          -5223.79,
          -5242.092000000001,
          -5259.984,
          -5277.4580000000005,
          -5294.508000000001,
          -5311.1269999999995,
          -5327.308000000001,
          -5343.043000000001,
          -5358.325,
          -5373.145,
          -5387.496,
          -5401.37,
          -5414.758000000001,
          -5427.651999999999,
          -5440.043000000001,
          -5451.920999999999,
          -5463.278,
          -5474.104,
          -5484.39,
          -5494.125,
          -5503.3,
          -5511.903,
          -5519.924,
          -5527.351,
          -5534.174,
          -5540.380999999999,
          -5545.96,
          -5550.897,
          -5555.182,
          -5558.8,
          -5561.738,
          -5563.982,
          -5565.518,
          -5566.331,
          -5566.406,
          -5565.728,
          -5564.279,
          -5562.044,
          -5559.005999999999,
          -5555.147,
          -5550.448,
          -5544.891,
          -5538.456999999999,
          -5531.124,
          -5522.8730000000005,
          -5513.682,
          -5503.529,
          -5492.391,
          -5480.243,
          -5467.063,
          -5452.823,
          -5437.496999999999,
          -5421.058000000001,
          -5403.478,
          -5384.729,
          -5364.778,
          -5343.593000000001,
          -5321.143,
          -5297.394,
          -5272.309,
          -5245.852,
          -5217.985,
          -5188.667,
          -5157.858,
          -5125.515,
          -5091.590999999999,
          -5056.042,
          -5018.818,
          -4979.8679999999995,
          -4939.141,
          -4896.581,
          -4852.13,
          -4805.73,
          -4757.319,
          -4706.831,
          -4654.1990000000005,
          -4599.354,
          -4542.222,
          -4482.726,
          -4420.789000000001,
          -4356.3279999999995,
          -4289.2570000000005,
          -4219.487,
          -4146.927,
          -4071.4829999999997,
          -3993.055,
          -3911.5429999999997,
          -3826.843,
          -3738.849,
          -3647.452,
          -3552.542,
          -3454.007,
          -3351.738,
          -3245.623,
          -3135.5559999999996,
          -3021.4320000000002,
          -2903.152,
          -2780.625,
          -2653.7729999999997,
          -2522.53,
          -2386.845,
          -2246.694,
          -2102.074,
          -1953.016,
          -1799.586,
          -1641.892,
          -1480.089,
          -1314.385,
          -1145.042,
          -972.3810000000001,
          -796.7860000000001,
          -618.698,
          -438.61400000000003,
          -257.08099999999996,
          -74.687,
          107.949,
          290.193,
          471.408,
          650.971,
          828.285,
          1002.7919999999999,
          1173.985,
          1341.4129999999998,
          1504.693,
          1663.499,
          1817.576,
          1966.727,
          2110.815,
          2249.755,
          2383.508,
          2512.076,
          2635.495,
          2753.828,
          2867.164,
          2975.6079999999997,
          3079.28,
          3178.3109999999997,
          3272.837,
          3363,
          3448.9440000000004,
          3530.815,
          3608.755,
          3682.909,
          3753.4159999999997,
          3820.41,
          3884.026,
          3944.39,
          4001.627,
          4055.8540000000003,
          4107.189,
          4155.7390000000005,
          4201.61,
          4244.903,
          4285.714,
          4324.137,
          4360.258,
          4394.163,
          4425.932,
          4455.641,
          4483.365,
          4509.173,
          4533.1320000000005,
          4555.307,
          4575.758,
          4594.545999999999,
          4611.723,
          4627.345,
          4641.463,
          4654.126,
          4665.38,
          4675.271,
          4683.842000000001,
          4691.1320000000005,
          4697.183,
          4702.032,
          4705.715999999999,
          4708.268,
          4709.724,
          4710.1140000000005,
          4709.471,
          4707.823,
          4705.1990000000005,
          4701.627,
          4697.134,
          4691.744000000001,
          4685.483,
          4678.373,
          4670.439,
          4661.702,
          4652.183,
          4641.903,
          4630.880999999999,
          4619.137,
          4606.689,
          4593.555,
          4579.753,
          4565.299,
          4550.208,
          4534.498,
          4518.183,
          4501.277,
          4483.795,
          4465.752,
          4447.159000000001,
          4428.031,
          4408.379,
          4388.215999999999,
          4367.554,
          4346.403,
          4324.777,
          4302.685,
          4280.137,
          4257.145,
          4233.718,
          4209.866,
          4185.598,
          4160.923,
          4135.85,
          4110.389,
          4084.548,
          4058.3340000000003,
          4031.756,
          4004.822,
          3977.54,
          3949.9159999999997,
          3921.9590000000003,
          3893.675,
          3865.072,
          3836.155,
          3806.9320000000002,
          3777.41,
          3747.594,
          3717.49,
          3687.105,
          3656.4440000000004,
          3625.514,
          3594.3190000000004,
          3562.867,
          3531.1609999999996,
          3499.2070000000003,
          3467.011,
          3434.577,
          3401.91,
          3369.0159999999996,
          3335.8979999999997,
          3302.562,
          3269.012,
          3235.2529999999997,
          3201.289,
          3167.1240000000003,
          3132.762,
          3098.2090000000003,
          3063.467,
          3028.5409999999997,
          2993.434,
          2958.151,
          2922.696,
          2887.071,
          2851.281,
          2815.329,
          2779.219,
          2742.954,
          2706.538,
          2669.973,
          2633.264,
          2596.413,
          2559.424,
          2522.3,
          2485.0429999999997,
          2447.657,
          2410.146,
          2372.511,
          2334.756,
          2296.883,
          2258.896,
          2220.797,
          2182.589,
          2144.274,
          2105.855,
          2067.3360000000002,
          2028.7179999999998,
          1990.004,
          1951.1960000000001,
          1912.297,
          1873.31,
          1834.237,
          1795.08,
          1755.8410000000001,
          1716.523,
          1677.129,
          1637.66,
          1598.119,
          1558.5079999999998,
          1518.829,
          1479.0839999999998,
          1439.276,
          1399.4070000000002,
          1359.4779999999998,
          1319.4920000000002,
          1279.451,
          1239.357,
          1199.212,
          1159.018,
          1118.777,
          1078.49,
          1038.161,
          997.79,
          957.38,
          916.933,
          876.45,
          835.933,
          795.385,
          754.806,
          714.2,
          673.567,
          632.91,
          592.229,
          551.528,
          510.80800000000005,
          470.07,
          429.316,
          388.548,
          347.76800000000003,
          306.978,
          266.178,
          225.37099999999998,
          184.55900000000003,
          143.743,
          102.92399999999999,
          62.105,
          21.288,
          -19.528,
          -60.339,
          -101.14299999999999,
          -141.941,
          -182.729,
          -223.50599999999997,
          -264.27099999999996,
          -305.022,
          -345.75699999999995,
          -386.475,
          -427.17400000000004,
          -467.853,
          -508.51,
          -549.143,
          -589.752,
          -630.3330000000001,
          -670.887,
          -711.41,
          -751.9019999999999,
          -792.3610000000001,
          -832.7860000000001,
          -873.175,
          -913.5260000000001,
          -953.837,
          -994.1080000000001,
          -1034.337,
          -1074.522,
          -1114.661,
          -1154.753,
          -1194.797,
          -1234.79,
          -1274.732,
          -1314.62,
          -1354.453,
          -1394.23,
          -1433.9489999999998,
          -1473.608,
          -1513.2060000000001,
          -1552.741,
          -1592.2120000000002,
          -1631.616,
          -1670.953,
          -1710.22,
          -1749.4170000000001,
          -1788.54,
          -1827.59,
          -1866.5639999999999,
          -1905.46,
          -1944.277,
          -1983.013,
          -2021.6670000000001,
          -2060.236,
          -2098.719,
          -2137.115,
          -2175.422,
          -2213.637,
          -2251.759,
          -2289.7870000000003,
          -2327.719,
          -2365.553,
          -2403.286,
          -2440.9179999999997,
          -2478.447,
          -2515.87,
          -2553.186,
          -2590.393,
          -2627.49,
          -2664.473,
          -2701.342,
          -2738.095,
          -2774.7290000000003,
          -2811.243,
          -2847.634,
          -2883.901,
          -2920.042,
          -2956.055,
          -2991.937,
          -3027.687,
          -3063.303,
          -3098.782,
          -3134.123,
          -3169.322,
          -3204.3790000000004,
          -3239.2909999999997,
          -3274.0559999999996,
          -3308.671,
          -3343.134,
          -3377.4429999999998,
          -3411.5959999999995,
          -3445.59,
          -3479.4240000000004,
          -3513.094,
          -3546.598,
          -3579.934,
          -3613.1,
          -3646.092,
          -3678.909,
          -3711.548,
          -3744.005,
          -3776.28,
          -3808.368,
          -3840.2670000000003,
          -3871.975,
          -3903.489,
          -3934.805,
          -3965.921,
          -3996.835,
          -4027.542,
          -4058.0409999999997,
          -4088.328,
          -4118.401,
          -4148.255,
          -4177.889,
          -4207.298,
          -4236.479,
          -4265.43,
          -4294.146,
          -4322.625,
          -4350.863,
          -4378.856,
          -4406.601,
          -4434.094,
          -4461.332,
          -4488.31,
          -4515.025,
          -4541.473,
          -4567.65,
          -4593.552,
          -4619.175,
          -4644.515,
          -4669.567,
          -4694.3279999999995,
          -4718.791,
          -4742.955,
          -4766.813,
          -4790.361,
          -4813.594,
          -4836.5070000000005,
          -4859.096,
          -4881.355,
          -4903.28,
          -4924.8640000000005,
          -4946.103,
          -4966.991,
          -4987.522,
          -5007.692,
          -5027.494000000001,
          -5046.9220000000005,
          -5065.969,
          -5084.630999999999,
          -5102.9,
          -5120.77,
          -5138.234,
          -5155.286,
          -5171.918,
          -5188.125,
          -5203.897,
          -5219.228,
          -5234.111,
          -5248.536999999999,
          -5262.4980000000005,
          -5275.986999999999,
          -5288.995,
          -5301.514,
          -5313.534000000001,
          -5325.045999999999,
          -5336.041,
          -5346.5109999999995,
          -5356.445,
          -5365.8330000000005,
          -5374.664000000001,
          -5382.929,
          -5390.616,
          -5397.715,
          -5404.213000000001,
          -5410.1,
          -5415.361999999999,
          -5419.9890000000005,
          -5423.967,
          -5427.281999999999,
          -5429.920999999999,
          -5431.871,
          -5433.116,
          -5433.643,
          -5433.436,
          -5432.478,
          -5430.754,
          -5428.2480000000005,
          -5424.941999999999,
          -5420.818,
          -5415.857,
          -5410.041,
          -5403.351,
          -5395.765,
          -5387.263000000001,
          -5377.823,
          -5367.424,
          -5356.04,
          -5343.649,
          -5330.226,
          -5315.745,
          -5300.178000000001,
          -5283.5,
          -5265.679,
          -5246.689,
          -5226.495,
          -5205.068,
          -5182.374,
          -5158.377,
          -5133.042,
          -5106.331,
          -5078.207,
          -5048.628,
          -5017.5509999999995,
          -4984.935,
          -4950.731,
          -4914.894,
          -4877.374,
          -4838.119000000001,
          -4797.076,
          -4754.189,
          -4709.4,
          -4662.647,
          -4613.8679999999995,
          -4562.997,
          -4509.965,
          -4454.7,
          -4397.13,
          -4337.175,
          -4274.755,
          -4209.788,
          -4142.185,
          -4071.8579999999997,
          -3998.712,
          -3922.653,
          -3843.579,
          -3761.3909999999996,
          -3675.982,
          -3587.2470000000003,
          -3495.077,
          -3399.362,
          -3299.994,
          -3196.864,
          -3089.863,
          -2978.889,
          -2863.844,
          -2744.637,
          -2621.187,
          -2493.428,
          -2361.3070000000002,
          -2224.795,
          -2083.886,
          -1938.604,
          -1789.01,
          -1635.2020000000002,
          -1477.3239999999998,
          -1315.5739999999998,
          -1150.201,
          -981.512,
          -809.8739999999999,
          -635.7130000000001,
          -459.50699999999995,
          -281.78700000000003,
          -103.126,
          75.874,
          254.59400000000002,
          432.409,
          608.705,
          782.8939999999999,
          954.424,
          1122.79,
          1287.546,
          1448.3029999999999,
          1604.7379999999998,
          1756.59,
          1903.658,
          2045.8,
          2182.927,
          2314.991,
          2441.991,
          2563.955,
          2680.9429999999998,
          2793.0359999999996,
          2900.335,
          3002.954,
          3101.0190000000002,
          3194.6609999999996,
          3284.018,
          3369.232,
          3450.442,
          3527.789,
          3601.413,
          3671.449,
          3738.0290000000005,
          3801.2859999999996,
          3861.425,
          3918.322,
          3972.34,
          4023.508,
          4071.935,
          4117.723,
          4160.973,
          4201.779,
          4240.23,
          4276.415,
          4310.417,
          4342.312,
          4372.179,
          4400.089,
          4426.111,
          4450.311,
          4472.752,
          4493.494000000001,
          4512.594,
          4530.109,
          4546.09,
          4560.587,
          4573.649,
          4585.322,
          4595.65,
          4604.675,
          4612.439,
          4618.981,
          4624.335,
          4628.54,
          4631.63,
          4633.6359999999995,
          4634.592000000001,
          4634.527,
          4633.472,
          4631.452,
          4628.498,
          4624.633,
          4619.884,
          4614.274,
          4607.827,
          4600.566,
          4592.5109999999995,
          4583.684,
          4574.106,
          4563.795999999999,
          4552.771,
          4541.052,
          4528.655,
          4515.597,
          4501.896,
          4487.566,
          4472.623,
          4457.082,
          4440.958,
          4424.265,
          4407.016,
          4389.225,
          4370.903,
          4352.063,
          4332.719,
          4312.880999999999,
          4292.56,
          4271.768,
          4250.516,
          4228.813,
          4206.669,
          4184.096,
          4161.102,
          4137.696,
          4113.888,
          4089.6859999999997,
          4065.1,
          4040.136,
          4014.804,
          3989.112,
          3963.066,
          3936.676,
          3909.948,
          3882.889,
          3855.506,
          3827.8059999999996,
          3799.797,
          3771.4829999999997,
          3742.873,
          3713.9709999999995,
          3684.784,
          3655.3179999999998,
          3625.578,
          3595.572,
          3565.303,
          3534.778,
          3504.0009999999997,
          3472.9790000000003,
          3441.715,
          3410.215,
          3378.485,
          3346.527,
          3314.349,
          3281.953,
          3249.345,
          3216.528,
          3183.508,
          3150.289,
          3116.873,
          3083.2670000000003,
          3049.473,
          3015.4959999999996,
          2981.3390000000004,
          2947.007,
          2912.502,
          2877.829,
          2842.991,
          2807.992,
          2772.835,
          2737.5240000000003,
          2702.062,
          2666.4509999999996,
          2630.697,
          2594.801,
          2558.766,
          2522.597,
          2486.2960000000003,
          2449.865,
          2413.3089999999997,
          2376.629,
          2339.8289999999997,
          2302.911,
          2265.8779999999997,
          2228.7329999999997,
          2191.479,
          2154.118,
          2116.653,
          2079.087,
          2041.421,
          2003.6589999999999,
          1965.8029999999999,
          1927.855,
          1889.818,
          1851.694,
          1813.486,
          1775.195,
          1736.825,
          1698.378,
          1659.854,
          1621.2579999999998,
          1582.5910000000001,
          1543.855,
          1505.0529999999999,
          1466.1860000000001,
          1427.256,
          1388.267,
          1349.219,
          1310.114,
          1270.9560000000001,
          1231.745,
          1192.484,
          1153.175,
          1113.819,
          1074.4180000000001,
          1034.975,
          995.492,
          955.9689999999999,
          916.41,
          876.815,
          837.187,
          797.528,
          757.8380000000001,
          718.1210000000001,
          678.378,
          638.61,
          598.819,
          559.007,
          519.1759999999999,
          479.32800000000003,
          439.463,
          399.585,
          359.694,
          319.791,
          279.88,
          239.96099999999998,
          200.037,
          160.108,
          120.176,
          80.243,
          40.311,
          0.381,
          -39.545,
          -79.46600000000001,
          -119.38,
          -159.286,
          -199.18099999999998,
          -239.065,
          -278.935,
          -318.791,
          -358.63,
          -398.452,
          -438.254,
          -478.035,
          -517.794,
          -557.529,
          -597.238,
          -636.92,
          -676.573,
          -716.196,
          -755.7869999999999,
          -795.345,
          -834.868,
          -874.355,
          -913.804,
          -953.2139999999999,
          -992.582,
          -1031.9080000000001,
          -1071.191,
          -1110.427,
          -1149.617,
          -1188.758,
          -1227.848,
          -1266.887,
          -1305.873,
          -1344.8039999999999,
          -1383.6789999999999,
          -1422.495,
          -1461.2520000000002,
          -1499.9479999999999,
          -1538.582,
          -1577.151,
          -1615.654,
          -1654.09,
          -1692.457,
          -1730.754,
          -1768.9779999999998,
          -1807.128,
          -1845.203,
          -1883.201,
          -1921.12,
          -1958.9579999999999,
          -1996.715,
          -2034.388,
          -2071.975,
          -2109.475,
          -2146.887,
          -2184.208,
          -2221.437,
          -2258.572,
          -2295.612,
          -2332.554,
          -2369.396,
          -2406.138,
          -2442.777,
          -2479.312,
          -2515.74,
          -2552.06,
          -2588.27,
          -2624.368,
          -2660.353,
          -2696.2209999999995,
          -2731.972,
          -2767.6040000000003,
          -2803.114,
          -2838.5,
          -2873.762,
          -2908.8959999999997,
          -2943.9,
          -2978.7729999999997,
          -3013.513,
          -3048.117,
          -3082.5840000000003,
          -3116.9109999999996,
          -3151.095,
          -3185.136,
          -3219.031,
          -3252.777,
          -3286.3720000000003,
          -3319.8140000000003,
          -3353.1009999999997,
          -3386.2309999999998,
          -3419.2,
          -3452.007,
          -3484.65,
          -3517.125,
          -3549.4309999999996,
          -3581.5640000000003,
          -3613.5229999999997,
          -3645.304,
          -3676.906,
          -3708.3259999999996,
          -3739.56,
          -3770.6059999999998,
          -3801.462,
          -3832.125,
          -3862.592,
          -3892.86,
          -3922.925,
          -3952.7859999999996,
          -3982.4390000000003,
          -4011.881,
          -4041.11,
          -4070.1209999999996,
          -4098.912,
          -4127.48,
          -4155.821,
          -4183.932,
          -4211.81,
          -4239.451,
          -4266.852,
          -4294.009,
          -4320.918,
          -4347.576,
          -4373.98,
          -4400.124,
          -4426.005999999999,
          -4451.622,
          -4476.967000000001,
          -4502.038,
          -4526.83,
          -4551.34,
          -4575.562,
          -4599.4929999999995,
          -4623.128,
          -4646.462,
          -4669.491,
          -4692.209,
          -4714.613,
          -4736.698,
          -4758.458,
          -4779.888,
          -4800.983,
          -4821.738,
          -4842.147,
          -4862.205,
          -4881.905,
          -4901.2429999999995,
          -4920.212,
          -4938.806,
          -4957.02,
          -4974.846,
          -4992.279,
          -5009.311,
          -5025.937,
          -5042.148,
          -5057.938,
          -5073.3,
          -5088.226,
          -5102.709,
          -5116.741,
          -5130.314,
          -5143.42,
          -5156.0509999999995,
          -5168.197,
          -5179.85,
          -5191.001,
          -5201.642,
          -5211.762,
          -5221.351,
          -5230.4,
          -5238.898,
          -5246.835,
          -5254.201,
          -5260.983,
          -5267.17,
          -5272.751,
          -5277.714,
          -5282.045999999999,
          -5285.734,
          -5288.765,
          -5291.126,
          -5292.8009999999995,
          -5293.779,
          -5294.0419999999995,
          -5293.576999999999,
          -5292.366,
          -5290.394,
          -5287.644,
          -5284.1,
          -5279.741,
          -5274.5509999999995,
          -5268.51,
          -5261.598000000001,
          -5253.795,
          -5245.08,
          -5235.43,
          -5224.8240000000005,
          -5213.238,
          -5200.648,
          -5187.028,
          -5172.352,
          -5156.593,
          -5139.725,
          -5121.715999999999,
          -5102.537,
          -5082.157999999999,
          -5060.545,
          -5037.664000000001,
          -5013.481,
          -4987.959,
          -4961.061,
          -4932.746,
          -4902.973,
          -4871.7,
          -4838.883,
          -4804.476,
          -4768.429,
          -4730.693,
          -4691.215,
          -4649.941,
          -4606.814,
          -4561.775,
          -4514.762,
          -4465.71,
          -4414.554,
          -4361.222,
          -4305.642,
          -4247.74,
          -4187.435,
          -4124.646,
          -4059.288,
          -3991.275,
          -3920.512,
          -3846.908,
          -3770.365,
          -3690.782,
          -3608.058,
          -3522.0879999999997,
          -3432.764,
          -3339.9809999999998,
          -3243.6279999999997,
          -3143.6,
          -3039.79,
          -2932.0959999999995,
          -2820.4190000000003,
          -2704.67,
          -2584.7670000000003,
          -2460.641,
          -2332.239,
          -2199.526,
          -2062.495,
          -1921.1629999999998,
          -1775.5829999999999,
          -1625.845,
          -1472.086,
          -1314.4879999999998,
          -1153.29,
          -988.783,
          -821.318,
          -651.305,
          -479.204,
          -305.53,
          -130.836,
          44.291000000000004,
          219.247,
          393.42,
          566.2080000000001,
          737.034,
          905.3489999999999,
          1070.655,
          1232.507,
          1390.5179999999998,
          1544.361,
          1693.774,
          1838.5520000000001,
          1978.549,
          2113.667,
          2243.8579999999997,
          2369.11,
          2489.449,
          2604.926,
          2715.619,
          2821.6209999999996,
          2923.0429999999997,
          3020.0040000000004,
          3112.631,
          3201.059,
          3285.423,
          3365.86,
          3442.506,
          3515.4970000000003,
          3584.966,
          3651.042,
          3713.853,
          3773.52,
          3830.163,
          3883.8959999999997,
          3934.827,
          3983.065,
          4028.708,
          4071.855,
          4112.6,
          4151.028,
          4187.228,
          4221.279,
          4253.259,
          4283.2429999999995,
          4311.302,
          4337.503,
          4361.911,
          4384.587,
          4405.592000000001,
          4424.981,
          4442.808,
          4459.126,
          4473.983,
          4487.428,
          4499.504,
          4510.255999999999,
          4519.726,
          4527.952,
          4534.975,
          4540.829000000001,
          4545.55,
          4549.1720000000005,
          4551.728,
          4553.248,
          4553.763,
          4553.3009999999995,
          4551.89,
          4549.556,
          4546.326,
          4542.225,
          4537.274,
          4531.498,
          4524.92,
          4517.559,
          4509.438,
          4500.5740000000005,
          4490.9890000000005,
          4480.7,
          4469.725,
          4458.081,
          4445.786,
          4432.856,
          4419.306,
          4405.151,
          4390.406,
          4375.085,
          4359.2029999999995,
          4342.772,
          4325.805,
          4308.315,
          4290.314,
          4271.814,
          4252.826,
          4233.362,
          4213.433,
          4193.048,
          4172.219,
          4150.954000000001,
          4129.265,
          4107.159000000001,
          4084.647,
          4061.737,
          4038.438,
          4014.759,
          3990.7070000000003,
          3966.2909999999997,
          3941.518,
          3916.3959999999997,
          3890.9320000000002,
          3865.135,
          3839.009,
          3812.5640000000003,
          3785.805,
          3758.74,
          3731.373,
          3703.7129999999997,
          3675.764,
          3647.532,
          3619.025,
          3590.2459999999996,
          3561.203,
          3531.8990000000003,
          3502.342,
          3472.535,
          3442.4840000000004,
          3412.195,
          3381.672,
          3350.9190000000003,
          3319.942,
          3288.744,
          3257.3320000000003,
          3225.708,
          3193.8779999999997,
          3161.845,
          3129.614,
          3097.1890000000003,
          3064.574,
          3031.772,
          2998.789,
          2965.6259999999997,
          2932.289,
          2898.781,
          2865.1059999999998,
          2831.2659999999996,
          2797.2659999999996,
          2763.1079999999997,
          2728.797,
          2694.335,
          2659.7259999999997,
          2624.973,
          2590.0789999999997,
          2555.047,
          2519.88,
          2484.581,
          2449.154,
          2413.6,
          2377.923,
          2342.126,
          2306.2110000000002,
          2270.181,
          2234.04,
          2197.788,
          2161.43,
          2124.967,
          2088.402,
          2051.739,
          2014.9779999999998,
          1978.122,
          1941.175,
          1904.138,
          1867.014,
          1829.8039999999999,
          1792.5120000000002,
          1755.14,
          1717.6889999999999,
          1680.1629999999998,
          1642.5620000000001,
          1604.889,
          1567.1470000000002,
          1529.338,
          1491.4620000000002,
          1453.524,
          1415.524,
          1377.465,
          1339.348,
          1301.1760000000002,
          1262.951,
          1224.674,
          1186.348,
          1147.974,
          1109.5539999999999,
          1071.09,
          1032.5839999999998,
          994.038,
          955.454,
          916.832,
          878.176,
          839.487,
          800.7669999999999,
          762.0169999999999,
          723.2389999999999,
          684.434,
          645.606,
          606.755,
          567.882,
          528.991,
          490.08099999999996,
          451.156,
          412.216,
          373.26300000000003,
          334.29900000000004,
          295.32599999999996,
          256.344,
          217.357,
          178.364,
          139.368,
          100.37100000000001,
          61.373999999999995,
          22.378,
          -16.615,
          -55.603,
          -94.585,
          -133.559,
          -172.524,
          -211.479,
          -250.42,
          -289.349,
          -328.26099999999997,
          -367.157,
          -406.035,
          -444.892,
          -483.728,
          -522.5419999999999,
          -561.33,
          -600.0930000000001,
          -638.8290000000001,
          -677.535,
          -716.212,
          -754.8560000000001,
          -793.467,
          -832.043,
          -870.582,
          -909.084,
          -947.546,
          -985.9680000000001,
          -1024.347,
          -1062.682,
          -1100.971,
          -1139.214,
          -1177.4080000000001,
          -1215.553,
          -1253.646,
          -1291.6860000000001,
          -1329.671,
          -1367.6,
          -1405.4720000000002,
          -1443.2839999999999,
          -1481.036,
          -1518.726,
          -1556.352,
          -1593.9129999999998,
          -1631.406,
          -1668.832,
          -1706.1870000000001,
          -1743.47,
          -1780.681,
          -1817.816,
          -1854.876,
          -1891.8570000000002,
          -1928.7579999999998,
          -1965.578,
          -2002.315,
          -2038.9679999999998,
          -2075.534,
          -2112.012,
          -2148.401,
          -2184.699,
          -2220.903,
          -2257.012,
          -2293.026,
          -2328.94,
          -2364.755,
          -2400.468,
          -2436.078,
          -2471.5820000000003,
          -2506.979,
          -2542.2670000000003,
          -2577.445,
          -2612.509,
          -2647.4590000000003,
          -2682.2929999999997,
          -2717.008,
          -2751.603,
          -2786.0759999999996,
          -2820.425,
          -2854.647,
          -2888.742,
          -2922.7059999999997,
          -2956.538,
          -2990.236,
          -3023.797,
          -3057.22,
          -3090.502,
          -3123.6409999999996,
          -3156.636,
          -3189.4829999999997,
          -3222.1809999999996,
          -3254.7270000000003,
          -3287.119,
          -3319.355,
          -3351.4320000000002,
          -3383.349,
          -3415.1020000000003,
          -3446.6890000000003,
          -3478.1079999999997,
          -3509.3559999999998,
          -3540.4309999999996,
          -3571.3309999999997,
          -3602.052,
          -3632.591,
          -3662.948,
          -3693.118,
          -3723.098,
          -3752.887,
          -3782.4809999999998,
          -3811.8779999999997,
          -3841.074,
          -3870.066,
          -3898.8520000000003,
          -3927.429,
          -3955.7929999999997,
          -3983.941,
          -4011.87,
          -4039.578,
          -4067.06,
          -4094.313,
          -4121.335,
          -4148.121,
          -4174.667,
          -4200.971,
          -4227.029,
          -4252.837,
          -4278.392,
          -4303.688,
          -4328.723,
          -4353.4929999999995,
          -4377.994000000001,
          -4402.22,
          -4426.17,
          -4449.837,
          -4473.219,
          -4496.309,
          -4519.104,
          -4541.6,
          -4563.791,
          -4585.673,
          -4607.24,
          -4628.4890000000005,
          -4649.413,
          -4670.0070000000005,
          -4690.268,
          -4710.188,
          -4729.763,
          -4748.986,
          -4767.853,
          -4786.356,
          -4804.491,
          -4822.251,
          -4839.629,
          -4856.62,
          -4873.217000000001,
          -4889.412,
          -4905.2,
          -4920.573,
          -4935.524,
          -4950.045999999999,
          -4964.13,
          -4977.77,
          -4990.957,
          -5003.683,
          -5015.94,
          -5027.719,
          -5039.012,
          -5049.81,
          -5060.103,
          -5069.8820000000005,
          -5079.1359999999995,
          -5087.857,
          -5096.034000000001,
          -5103.656,
          -5110.713,
          -5117.193,
          -5123.085,
          -5128.377,
          -5133.057,
          -5137.113,
          -5140.532,
          -5143.3009999999995,
          -5145.404,
          -5146.83,
          -5147.564,
          -5147.59,
          -5146.894,
          -5145.459,
          -5143.268,
          -5140.306,
          -5136.555,
          -5131.996,
          -5126.611,
          -5120.380999999999,
          -5113.287,
          -5105.307,
          -5096.419,
          -5086.603,
          -5075.835,
          -5064.092000000001,
          -5051.349,
          -5037.581,
          -5022.762,
          -5006.865,
          -4989.86,
          -4971.719,
          -4952.412,
          -4931.906,
          -4910.169,
          -4887.167,
          -4862.863,
          -4837.223,
          -4810.206,
          -4781.773,
          -4751.883,
          -4720.491,
          -4687.553,
          -4653.023,
          -4616.85,
          -4578.985,
          -4539.373,
          -4497.96,
          -4454.688,
          -4409.497,
          -4362.323,
          -4313.103,
          -4261.767,
          -4208.245,
          -4152.463,
          -4094.343,
          -4033.808,
          -3970.7729999999997,
          -3905.152,
          -3836.857,
          -3765.796,
          -3691.8740000000003,
          -3614.991,
          -3535.0490000000004,
          -3451.945,
          -3365.574,
          -3275.83,
          -3182.607,
          -3085.8,
          -2985.303,
          -2881.0159999999996,
          -2772.841,
          -2660.687,
          -2544.473,
          -2424.1279999999997,
          -2299.598,
          -2170.846,
          -2037.858,
          -1900.6470000000002,
          -1759.259,
          -1613.7779999999998,
          -1464.3270000000002,
          -1311.079,
          -1154.259,
          -994.1439999999999,
          -831.068,
          -665.425,
          -497.656,
          -328.259,
          -157.767,
          13.249,
          184.2,
          354.491,
          523.5319999999999,
          690.752,
          855.615,
          1017.6260000000001,
          1176.343,
          1331.38,
          1482.411,
          1629.1689999999999,
          1771.4479999999999,
          1909.096,
          2042.0120000000002,
          2170.139,
          2293.4629999999997,
          2412.002,
          2525.802,
          2634.934,
          2739.488,
          2839.566,
          2935.284,
          3026.764,
          3114.135,
          3197.5290000000005,
          3277.0759999999996,
          3352.9120000000003,
          3425.1659999999997,
          3493.969,
          3559.446,
          3621.722,
          3680.915,
          3737.1420000000003,
          3790.514,
          3841.138,
          3889.117,
          3934.552,
          3977.5359999999996,
          4018.1620000000003,
          4056.514,
          4092.677,
          4126.731,
          4158.751,
          4188.811,
          4216.979,
          4243.323,
          4267.905,
          4290.786,
          4312.024,
          4331.675,
          4349.791,
          4366.423,
          4381.62,
          4395.429,
          4407.892,
          4419.054,
          4428.954000000001,
          4437.633,
          4445.127,
          4451.473,
          4456.7029999999995,
          4460.854,
          4463.956,
          4466.038,
          4467.1320000000005,
          4467.265,
          4466.464,
          4464.755,
          4462.165,
          4458.715999999999,
          4454.432,
          4449.335999999999,
          4443.4490000000005,
          4436.793,
          4429.387,
          4421.252,
          4412.405,
          4402.865,
          4392.65,
          4381.777,
          4370.262,
          4358.12,
          4345.3679999999995,
          4332.021,
          4318.092000000001,
          4303.596,
          4288.545999999999,
          4272.955,
          4256.837,
          4240.202,
          4223.064,
          4205.434,
          4187.323,
          4168.742,
          4149.7029999999995,
          4130.214,
          4110.286,
          4089.93,
          4069.153,
          4047.967,
          4026.3790000000004,
          4004.3990000000003,
          3982.034,
          3959.2940000000003,
          3936.187,
          3912.719,
          3888.8990000000003,
          3864.735,
          3840.2329999999997,
          3815.401,
          3790.245,
          3764.7740000000003,
          3738.992,
          3712.907,
          3686.5240000000003,
          3659.8509999999997,
          3632.893,
          3605.655,
          3578.1440000000002,
          3550.365,
          3522.324,
          3494.026,
          3465.4759999999997,
          3436.68,
          3407.6420000000003,
          3378.367,
          3348.861,
          3319.1279999999997,
          3289.172,
          3258.9990000000003,
          3228.611,
          3198.015,
          3167.2140000000004,
          3136.212,
          3105.013,
          3073.6220000000003,
          3042.042,
          3010.277,
          2978.3309999999997,
          2946.208,
          2913.9109999999996,
          2881.4440000000004,
          2848.8109999999997,
          2816.015,
          2783.059,
          2749.947,
          2716.6820000000002,
          2683.2670000000003,
          2649.705,
          2616,
          2582.155,
          2548.172,
          2514.055,
          2479.8070000000002,
          2445.429,
          2410.926,
          2376.301,
          2341.554,
          2306.6910000000003,
          2271.712,
          2236.6220000000003,
          2201.422,
          2166.114,
          2130.703,
          2095.189,
          2059.576,
          2023.865,
          1988.06,
          1952.162,
          1916.175,
          1880.099,
          1843.9389999999999,
          1807.695,
          1771.369,
          1734.965,
          1698.485,
          1661.9289999999999,
          1625.3020000000001,
          1588.6029999999998,
          1551.8370000000002,
          1515.004,
          1478.1070000000002,
          1441.148,
          1404.128,
          1367.05,
          1329.915,
          1292.726,
          1255.485,
          1218.193,
          1180.851,
          1143.463,
          1106.03,
          1068.553,
          1031.0339999999999,
          993.4760000000001,
          955.88,
          918.247,
          880.58,
          842.88,
          805.148,
          767.388,
          729.5989999999999,
          691.784,
          653.945,
          616.0830000000001,
          578.2,
          540.297,
          502.37699999999995,
          464.44,
          426.48800000000006,
          388.523,
          350.54699999999997,
          312.561,
          274.566,
          236.56400000000002,
          198.55700000000002,
          160.547,
          122.53399999999999,
          84.52,
          46.507,
          8.497,
          -29.51,
          -67.512,
          -105.506,
          -143.49200000000002,
          -181.46900000000002,
          -219.43400000000003,
          -257.38599999999997,
          -295.324,
          -333.246,
          -371.151,
          -409.038,
          -446.904,
          -484.74800000000005,
          -522.57,
          -560.367,
          -598.137,
          -635.881,
          -673.595,
          -711.279,
          -748.931,
          -786.549,
          -824.133,
          -861.68,
          -899.19,
          -936.6610000000001,
          -974.091,
          -1011.4780000000001,
          -1048.822,
          -1086.121,
          -1123.374,
          -1160.578,
          -1197.733,
          -1234.837,
          -1271.888,
          -1308.885,
          -1345.8270000000002,
          -1382.7120000000002,
          -1419.5379999999998,
          -1456.3039999999999,
          -1493.009,
          -1529.651,
          -1566.2279999999998,
          -1602.7379999999998,
          -1639.182,
          -1675.555,
          -1711.859,
          -1748.089,
          -1784.246,
          -1820.3270000000002,
          -1856.3310000000001,
          -1892.257,
          -1928.102,
          -1963.865,
          -1999.545,
          -2035.139,
          -2070.646,
          -2106.065,
          -2141.394,
          -2176.631,
          -2211.774,
          -2246.822,
          -2281.7729999999997,
          -2316.625,
          -2351.377,
          -2386.027,
          -2420.572,
          -2455.012,
          -2489.344,
          -2523.567,
          -2557.678,
          -2591.676,
          -2625.56,
          -2659.3259999999996,
          -2692.973,
          -2726.5,
          -2759.9040000000005,
          -2793.184,
          -2826.337,
          -2859.361,
          -2892.2540000000004,
          -2925.015,
          -2957.6409999999996,
          -2990.13,
          -3022.48,
          -3054.6890000000003,
          -3086.7540000000004,
          -3118.6740000000004,
          -3150.447,
          -3182.0690000000004,
          -3213.539,
          -3244.855,
          -3276.014,
          -3307.013,
          -3337.8509999999997,
          -3368.525,
          -3399.033,
          -3429.3709999999996,
          -3459.539,
          -3489.532,
          -3519.348,
          -3548.985,
          -3578.441,
          -3607.712,
          -3636.795,
          -3665.688,
          -3694.389,
          -3722.893,
          -3751.199,
          -3779.303,
          -3807.203,
          -3834.895,
          -3862.3759999999997,
          -3889.643,
          -3916.6940000000004,
          -3943.5240000000003,
          -3970.131,
          -3996.51,
          -4022.659,
          -4048.575,
          -4074.2529999999997,
          -4099.69,
          -4124.883,
          -4149.827,
          -4174.519,
          -4198.955,
          -4223.1320000000005,
          -4247.045,
          -4270.69,
          -4294.063,
          -4317.16,
          -4339.976,
          -4362.508,
          -4384.751,
          -4406.6990000000005,
          -4428.349,
          -4449.696,
          -4470.735,
          -4491.46,
          -4511.8679999999995,
          -4531.9529999999995,
          -4551.71,
          -4571.1320000000005,
          -4590.215999999999,
          -4608.955,
          -4627.343,
          -4645.375,
          -4663.045,
          -4680.346,
          -4697.273,
          -4713.82,
          -4729.978,
          -4745.7429999999995,
          -4761.107,
          -4776.062,
          -4790.603,
          -4804.721,
          -4818.409000000001,
          -4831.659000000001,
          -4844.464,
          -4856.816,
          -4868.705,
          -4880.125,
          -4891.065,
          -4901.517,
          -4911.472,
          -4920.919,
          -4929.851,
          -4938.255999999999,
          -4946.124,
          -4953.446,
          -4960.21,
          -4966.405,
          -4972.019,
          -4977.04,
          -4981.458,
          -4985.259,
          -4988.431,
          -4990.96,
          -4992.832,
          -4994.034000000001,
          -4994.5509999999995,
          -4994.3679999999995,
          -4993.471,
          -4991.840999999999,
          -4989.465,
          -4986.3240000000005,
          -4982.402,
          -4977.679,
          -4972.138,
          -4965.759,
          -4958.523,
          -4950.407999999999,
          -4941.392,
          -4931.455,
          -4920.573,
          -4908.723,
          -4895.879,
          -4882.016,
          -4867.108,
          -4851.128,
          -4834.045999999999,
          -4815.833,
          -4796.459,
          -4775.891,
          -4754.097,
          -4731.042,
          -4706.69,
          -4681.003,
          -4653.944,
          -4625.47,
          -4595.542,
          -4564.1140000000005,
          -4531.14,
          -4496.575,
          -4460.366,
          -4422.465,
          -4382.815,
          -4341.362,
          -4298.045,
          -4252.807,
          -4205.58,
          -4156.3009999999995,
          -4104.9,
          -4051.305,
          -3995.44,
          -3937.23,
          -3876.592,
          -3813.4429999999998,
          -3747.696,
          -3679.262,
          -3608.047,
          -3533.9559999999997,
          -3456.8909999999996,
          -3376.7509999999997,
          -3293.434,
          -3206.837,
          -3116.8540000000003,
          -3023.383,
          -2926.3190000000004,
          -2825.563,
          -2721.0170000000003,
          -2612.593,
          -2500.2070000000003,
          -2383.7889999999998,
          -2263.281,
          -2138.645,
          -2009.862,
          -1876.941,
          -1739.921,
          -1598.875,
          -1453.92,
          -1305.2169999999999,
          -1152.976,
          -997.459,
          -838.987,
          -677.932,
          -514.72,
          -349.829,
          -183.774,
          -17.107,
          149.601,
          315.767,
          480.81699999999995,
          644.191,
          805.3610000000001,
          963.8389999999999,
          1119.1860000000001,
          1271.02,
          1419.0120000000002,
          1562.8970000000002,
          1702.464,
          1837.557,
          1968.069,
          2093.9410000000003,
          2215.151,
          2331.712,
          2443.6639999999998,
          2551.072,
          2654.018,
          2752.603,
          2846.934,
          2937.13,
          3023.3140000000003,
          3105.612,
          3184.153,
          3259.0640000000003,
          3330.474,
          3398.509,
          3463.29,
          3524.938,
          3583.8340000000003,
          3639.297,
          3692.2290000000003,
          3742.4709999999995,
          3790.1220000000003,
          3835.281,
          3878.039,
          3918.485,
          3956.705,
          3992.7790000000005,
          4026.7859999999996,
          4058.7990000000004,
          4088.8909999999996,
          4117.127,
          4143.575,
          4168.295,
          4191.347,
          4212.788,
          4232.670999999999,
          4251.05,
          4267.972,
          4283.487,
          4297.638,
          4310.471,
          4322.026,
          4332.343,
          4341.46,
          4349.415,
          4356.2429999999995,
          4361.976,
          4366.649,
          4370.291,
          4372.934,
          4374.604,
          4375.331,
          4375.142,
          4374.06,
          4372.111,
          4369.32,
          4365.709,
          4361.299,
          4356.112,
          4350.169,
          4343.49,
          4336.093,
          4327.997,
          4319.22,
          4309.778,
          4299.69,
          4288.971,
          4277.6359999999995,
          4265.7,
          4253.178,
          4240.085,
          4226.432,
          4212.236,
          4197.5070000000005,
          4182.259,
          4166.503,
          4150.252,
          4133.516,
          4116.307,
          4098.635,
          4080.511,
          4061.945,
          4042.947,
          4023.526,
          4003.6929999999998,
          3983.454,
          3962.821,
          3941.8,
          3920.401,
          3898.631,
          3876.5,
          3854.013,
          3831.18,
          3808.007,
          3784.5,
          3760.6679999999997,
          3736.5170000000003,
          3712.053,
          3687.284,
          3662.215,
          3636.853,
          3611.204,
          3585.2740000000003,
          3559.067,
          3532.591,
          3505.85,
          3478.85,
          3451.5959999999995,
          3424.094,
          3396.347,
          3368.362,
          3340.1420000000003,
          3311.6940000000004,
          3283.0209999999997,
          3254.1279999999997,
          3225.0190000000002,
          3195.699,
          3166.172,
          3136.442,
          3106.513,
          3076.389,
          3046.075,
          3015.574,
          2984.889,
          2954.025,
          2922.986,
          2891.7740000000003,
          2860.393,
          2828.847,
          2797.139,
          2765.2729999999997,
          2733.2509999999997,
          2701.078,
          2668.756,
          2636.2870000000003,
          2603.677,
          2570.926,
          2538.0389999999998,
          2505.018,
          2471.866,
          2438.5860000000002,
          2405.181,
          2371.653,
          2338.006,
          2304.241,
          2270.362,
          2236.371,
          2202.27,
          2168.062,
          2133.75,
          2099.3360000000002,
          2064.822,
          2030.211,
          1995.505,
          1960.707,
          1925.818,
          1890.8410000000001,
          1855.7779999999998,
          1820.631,
          1785.4029999999998,
          1750.095,
          1714.711,
          1679.251,
          1643.7179999999998,
          1608.114,
          1572.44,
          1536.7,
          1500.895,
          1465.026,
          1429.0970000000002,
          1393.108,
          1357.0610000000001,
          1320.9589999999998,
          1284.803,
          1248.596,
          1212.338,
          1176.0330000000001,
          1139.681,
          1103.2839999999999,
          1066.844,
          1030.363,
          993.8430000000001,
          957.284,
          920.69,
          884.062,
          847.4,
          810.7080000000001,
          773.9860000000001,
          737.237,
          700.461,
          663.6610000000001,
          626.8380000000001,
          589.994,
          553.13,
          516.247,
          479.348,
          442.434,
          405.506,
          368.56699999999995,
          331.61699999999996,
          294.657,
          257.691,
          220.718,
          183.74099999999999,
          146.762,
          109.78,
          72.79899999999999,
          35.819,
          -1.158,
          -38.131,
          -75.097,
          -112.057,
          -149.007,
          -185.94799999999998,
          -222.87599999999998,
          -259.79200000000003,
          -296.693,
          -333.57800000000003,
          -370.44599999999997,
          -407.29400000000004,
          -444.12300000000005,
          -480.93,
          -517.7130000000001,
          -554.472,
          -591.206,
          -627.911,
          -664.5880000000001,
          -701.235,
          -737.85,
          -774.431,
          -810.9789999999999,
          -847.49,
          -883.9639999999999,
          -920.3989999999999,
          -956.794,
          -993.1469999999999,
          -1029.4569999999999,
          -1065.722,
          -1101.942,
          -1138.114,
          -1174.237,
          -1210.31,
          -1246.3310000000001,
          -1282.298,
          -1318.211,
          -1354.068,
          -1389.8670000000002,
          -1425.6070000000002,
          -1461.286,
          -1496.9029999999998,
          -1532.457,
          -1567.945,
          -1603.366,
          -1638.72,
          -1674.003,
          -1709.2160000000001,
          -1744.355,
          -1779.42,
          -1814.41,
          -1849.3210000000001,
          -1884.154,
          -1918.906,
          -1953.576,
          -1988.161,
          -2022.662,
          -2057.075,
          -2091.399,
          -2125.633,
          -2159.775,
          -2193.823,
          -2227.775,
          -2261.63,
          -2295.386,
          -2329.042,
          -2362.595,
          -2396.044,
          -2429.387,
          -2462.6220000000003,
          -2495.748,
          -2528.762,
          -2561.6620000000003,
          -2594.448,
          -2627.117,
          -2659.6659999999997,
          -2692.095,
          -2724.401,
          -2756.583,
          -2788.637,
          -2820.563,
          -2852.3579999999997,
          -2884.02,
          -2915.547,
          -2946.937,
          -2978.188,
          -3009.298,
          -3040.264,
          -3071.085,
          -3101.758,
          -3132.28,
          -3162.65,
          -3192.866,
          -3222.9240000000004,
          -3252.823,
          -3282.56,
          -3312.132,
          -3341.538,
          -3370.7740000000003,
          -3399.8390000000004,
          -3428.7290000000003,
          -3457.4429999999998,
          -3485.9759999999997,
          -3514.327,
          -3542.493,
          -3570.4709999999995,
          -3598.259,
          -3625.853,
          -3653.25,
          -3680.449,
          -3707.445,
          -3734.235,
          -3760.817,
          -3787.188,
          -3813.344,
          -3839.281,
          -3864.998,
          -3890.49,
          -3915.7529999999997,
          -3940.785,
          -3965.5820000000003,
          -3990.14,
          -4014.4559999999997,
          -4038.526,
          -4062.3459999999995,
          -4085.9120000000003,
          -4109.221,
          -4132.268,
          -4155.05,
          -4177.561,
          -4199.799,
          -4221.758,
          -4243.435,
          -4264.8240000000005,
          -4285.920999999999,
          -4306.721,
          -4327.22,
          -4347.414000000001,
          -4367.295999999999,
          -4386.862,
          -4406.106,
          -4425.024,
          -4443.61,
          -4461.858,
          -4479.763,
          -4497.318,
          -4514.519,
          -4531.359,
          -4547.832,
          -4563.931,
          -4579.651,
          -4594.984,
          -4609.924,
          -4624.464,
          -4638.596,
          -4652.313,
          -4665.609,
          -4678.475,
          -4690.904,
          -4702.887,
          -4714.417,
          -4725.484,
          -4736.08,
          -4746.197,
          -4755.825,
          -4764.954000000001,
          -4773.575,
          -4781.679,
          -4789.255,
          -4796.292,
          -4802.78,
          -4808.707,
          -4814.063,
          -4818.835999999999,
          -4823.013,
          -4826.583,
          -4829.531,
          -4831.846,
          -4833.513,
          -4834.519,
          -4834.849,
          -4834.4890000000005,
          -4833.4220000000005,
          -4831.6320000000005,
          -4829.105,
          -4825.822,
          -4821.767,
          -4816.92,
          -4811.264,
          -4804.778,
          -4797.444,
          -4789.24,
          -4780.145,
          -4770.1359999999995,
          -4759.192,
          -4747.287,
          -4734.397,
          -4720.495,
          -4705.558,
          -4689.555,
          -4672.458,
          -4654.2390000000005,
          -4634.865,
          -4614.305,
          -4592.524,
          -4569.49,
          -4545.164000000001,
          -4519.51,
          -4492.488,
          -4464.058,
          -4434.177,
          -4402.8009999999995,
          -4369.8820000000005,
          -4335.375,
          -4299.228,
          -4261.389,
          -4221.803,
          -4180.415,
          -4137.164000000001,
          -4091.989,
          -4044.825,
          -3995.607,
          -3944.262,
          -3890.72,
          -3834.9040000000005,
          -3776.736,
          -3716.134,
          -3653.014,
          -3587.288,
          -3518.866,
          -3447.655,
          -3373.558,
          -3296.4790000000003,
          -3216.316,
          -3132.969,
          -3046.336,
          -2956.312,
          -2862.797,
          -2765.6929999999998,
          -2664.9040000000005,
          -2560.34,
          -2451.919,
          -2339.569,
          -2223.231,
          -2102.863,
          -1978.445,
          -1849.9779999999998,
          -1717.496,
          -1581.065,
          -1440.7910000000002,
          -1296.823,
          -1149.359,
          -998.6469999999999,
          -844.988,
          -688.738,
          -530.307,
          -370.15,
          -208.764,
          -46.681999999999995,
          115.542,
          277.343,
          438.159,
          597.445,
          754.681,
          909.388,
          1061.131,
          1209.529,
          1354.257,
          1495.047,
          1631.6860000000001,
          1764.014,
          1891.9229999999998,
          2015.344,
          2134.2529999999997,
          2248.654,
          2358.583,
          2464.1,
          2565.281,
          2662.219,
          2755.018,
          2843.79,
          2928.653,
          3009.7290000000003,
          3087.1420000000003,
          3161.015,
          3231.4709999999995,
          3298.632,
          3362.617,
          3423.5440000000003,
          3481.5240000000003,
          3536.667,
          3589.078,
          3638.861,
          3686.112,
          3730.926,
          3773.3920000000003,
          3813.599,
          3851.627,
          3887.558,
          3921.465,
          3953.4240000000004,
          3983.5,
          4011.763,
          4038.2740000000003,
          4063.0959999999995,
          4086.284,
          4107.895,
          4127.981,
          4146.593,
          4163.781,
          4179.59,
          4194.063,
          4207.245,
          4219.175,
          4229.892,
          4239.435,
          4247.839,
          4255.137,
          4261.3640000000005,
          4266.5509999999995,
          4270.729,
          4273.9259999999995,
          4276.170999999999,
          4277.49,
          4277.911,
          4277.457,
          4276.154,
          4274.023,
          4271.088,
          4267.371,
          4262.892,
          4257.67,
          4251.726,
          4245.077,
          4237.7429999999995,
          4229.741,
          4221.087,
          4211.798,
          4201.888,
          4191.374,
          4180.271,
          4168.593,
          4156.353,
          4143.565,
          4130.241,
          4116.395,
          4102.038,
          4087.183,
          4071.841,
          4056.0229999999997,
          4039.74,
          4023.002,
          4005.82,
          3988.203,
          3970.1609999999996,
          3951.703,
          3932.8390000000004,
          3913.577,
          3893.927,
          3873.8959999999997,
          3853.493,
          3832.725,
          3811.6,
          3790.1259999999997,
          3768.3109999999997,
          3746.16,
          3723.6820000000002,
          3700.884,
          3677.7709999999997,
          3654.35,
          3630.6290000000004,
          3606.612,
          3582.3059999999996,
          3557.717,
          3532.85,
          3507.712,
          3482.308,
          3456.6420000000003,
          3430.7209999999995,
          3404.5490000000004,
          3378.132,
          3351.474,
          3324.5809999999997,
          3297.4559999999997,
          3270.1059999999998,
          3242.533,
          3214.743,
          3186.74,
          3158.528,
          3130.112,
          3101.495,
          3072.6809999999996,
          3043.675,
          3014.48,
          2985.1,
          2955.538,
          2925.7990000000004,
          2895.886,
          2865.802,
          2835.551,
          2805.137,
          2774.562,
          2743.829,
          2712.9429999999998,
          2681.906,
          2650.722,
          2619.3920000000003,
          2587.9210000000003,
          2556.312,
          2524.5660000000003,
          2492.688,
          2460.679,
          2428.544,
          2396.283,
          2363.9,
          2331.3979999999997,
          2298.78,
          2266.047,
          2233.202,
          2200.249,
          2167.188,
          2134.0229999999997,
          2100.757,
          2067.39,
          2033.9270000000001,
          2000.368,
          1966.717,
          1932.975,
          1899.145,
          1865.229,
          1831.229,
          1797.1470000000002,
          1762.985,
          1728.745,
          1694.43,
          1660.0410000000002,
          1625.58,
          1591.05,
          1556.4520000000002,
          1521.7879999999998,
          1487.0610000000001,
          1452.271,
          1417.421,
          1382.513,
          1347.5479999999998,
          1312.529,
          1277.4569999999999,
          1242.333,
          1207.161,
          1171.94,
          1136.674,
          1101.364,
          1066.011,
          1030.617,
          995.185,
          959.7139999999999,
          924.2080000000001,
          888.668,
          853.095,
          817.492,
          781.8589999999999,
          746.198,
          710.51,
          674.799,
          639.064,
          603.307,
          567.53,
          531.735,
          495.923,
          460.095,
          424.254,
          388.399,
          352.534,
          316.659,
          280.776,
          244.887,
          208.99200000000002,
          173.093,
          137.192,
          101.29,
          65.389,
          29.49,
          -6.406000000000001,
          -42.297,
          -78.182,
          -114.059,
          -149.928,
          -185.785,
          -221.63099999999997,
          -257.464,
          -293.282,
          -329.084,
          -364.869,
          -400.634,
          -436.38,
          -472.10400000000004,
          -507.805,
          -543.482,
          -579.133,
          -614.757,
          -650.352,
          -685.918,
          -721.452,
          -756.954,
          -792.421,
          -827.8530000000001,
          -863.2489999999999,
          -898.6060000000001,
          -933.923,
          -969.2,
          -1004.434,
          -1039.624,
          -1074.769,
          -1109.867,
          -1144.9180000000001,
          -1179.9180000000001,
          -1214.868,
          -1249.766,
          -1284.61,
          -1319.399,
          -1354.131,
          -1388.805,
          -1423.4189999999999,
          -1457.9720000000002,
          -1492.463,
          -1526.89,
          -1561.2520000000002,
          -1595.547,
          -1629.773,
          -1663.9289999999999,
          -1698.014,
          -1732.026,
          -1765.964,
          -1799.825,
          -1833.609,
          -1867.3139999999999,
          -1900.9379999999999,
          -1934.479,
          -1967.9370000000001,
          -2001.309,
          -2034.595,
          -2067.791,
          -2100.897,
          -2133.911,
          -2166.8320000000003,
          -2199.657,
          -2232.384,
          -2265.014,
          -2297.542,
          -2329.968,
          -2362.291,
          -2394.507,
          -2426.616,
          -2458.615,
          -2490.5029999999997,
          -2522.279,
          -2553.939,
          -2585.482,
          -2616.907,
          -2648.211,
          -2679.3920000000003,
          -2710.449,
          -2741.38,
          -2772.1809999999996,
          -2802.853,
          -2833.3909999999996,
          -2863.795,
          -2894.062,
          -2924.191,
          -2954.178,
          -2984.022,
          -3013.72,
          -3043.2709999999997,
          -3072.672,
          -3101.921,
          -3131.015,
          -3159.952,
          -3188.73,
          -3217.3459999999995,
          -3245.798,
          -3274.083,
          -3302.199,
          -3330.1440000000002,
          -3357.914,
          -3385.506,
          -3412.92,
          -3440.15,
          -3467.196,
          -3494.053,
          -3520.72,
          -3547.1929999999998,
          -3573.47,
          -3599.547,
          -3625.422,
          -3651.09,
          -3676.55,
          -3701.798,
          -3726.8309999999997,
          -3751.645,
          -3776.237,
          -3800.6040000000003,
          -3824.742,
          -3848.6479999999997,
          -3872.3179999999998,
          -3895.7490000000003,
          -3918.9359999999997,
          -3941.8759999999997,
          -3964.565,
          -3987,
          -4009.175,
          -4031.087,
          -4052.7329999999997,
          -4074.107,
          -4095.205,
          -4116.023,
          -4136.557,
          -4156.8009999999995,
          -4176.751,
          -4196.403,
          -4215.751,
          -4234.79,
          -4253.515,
          -4271.9220000000005,
          -4290.004,
          -4307.755999999999,
          -4325.173,
          -4342.25,
          -4358.979,
          -4375.355,
          -4391.373,
          -4407.026,
          -4422.306,
          -4437.209,
          -4451.727,
          -4465.854,
          -4479.581,
          -4492.903,
          -4505.812,
          -4518.3,
          -4530.359,
          -4541.982,
          -4553.16,
          -4563.8859999999995,
          -4574.149,
          -4583.942,
          -4593.255,
          -4602.08,
          -4610.407,
          -4618.225,
          -4625.525,
          -4632.295999999999,
          -4638.527,
          -4644.209,
          -4649.329000000001,
          -4653.875,
          -4657.835999999999,
          -4661.1990000000005,
          -4663.952,
          -4666.08,
          -4667.572,
          -4668.413,
          -4668.588,
          -4668.083,
          -4666.8820000000005,
          -4664.969,
          -4662.3279999999995,
          -4658.943,
          -4654.795,
          -4649.867,
          -4644.14,
          -4637.594,
          -4630.21,
          -4621.965999999999,
          -4612.842000000001,
          -4602.815,
          -4591.862,
          -4579.959,
          -4567.081,
          -4553.2029999999995,
          -4538.298,
          -4522.338,
          -4505.294,
          -4487.1359999999995,
          -4467.834,
          -4447.355,
          -4425.664000000001,
          -4402.728,
          -4378.51,
          -4352.972,
          -4326.0740000000005,
          -4297.776,
          -4268.032999999999,
          -4236.802,
          -4204.037,
          -4169.688,
          -4133.705,
          -4096.036,
          -4056.6240000000003,
          -4015.414,
          -3972.343,
          -3927.353,
          -3880.375,
          -3831.343,
          -3780.187,
          -3726.833,
          -3671.204,
          -3613.222,
          -3552.805,
          -3489.866,
          -3424.32,
          -3356.074,
          -3285.035,
          -3211.1090000000004,
          -3134.197,
          -3054.199,
          -2971.0170000000003,
          -2884.55,
          -2794.698,
          -2701.364,
          -2604.453,
          -2503.876,
          -2399.552,
          -2291.408,
          -2179.383,
          -2063.433,
          -1943.5339999999999,
          -1819.683,
          -1691.9070000000002,
          -1560.265,
          -1424.852,
          -1285.808,
          -1143.315,
          -997.607,
          -848.9689999999999,
          -697.74,
          -544.308,
          -389.11,
          -232.62400000000002,
          -75.362,
          82.141,
          239.33599999999998,
          395.67699999999996,
          550.633,
          703.694,
          854.39,
          1002.2919999999999,
          1147.022,
          1288.257,
          1425.729,
          1559.223,
          1688.5770000000002,
          1813.6760000000002,
          1934.45,
          2050.866,
          2162.925,
          2270.657,
          2374.113,
          2473.366,
          2568.5029999999997,
          2659.62,
          2746.8259999999996,
          2830.2329999999997,
          2909.9570000000003,
          2986.118,
          3058.8340000000003,
          3128.224,
          3194.405,
          3257.493,
          3317.6009999999997,
          3374.8379999999997,
          3429.308,
          3481.116,
          3530.361,
          3577.136,
          3621.535,
          3663.643,
          3703.546,
          3741.323,
          3777.054,
          3810.809,
          3842.6609999999996,
          3872.676,
          3900.92,
          3927.453,
          3952.336,
          3975.6240000000003,
          3997.37,
          4017.6279999999997,
          4036.445,
          4053.87,
          4069.947,
          4084.719,
          4098.229,
          4110.515,
          4121.616,
          4131.568,
          4140.406,
          4148.164000000001,
          4154.873,
          4160.566,
          4165.271,
          4169.017,
          4171.832,
          4173.74,
          4174.77,
          4174.944,
          4174.286,
          4172.819,
          4170.564,
          4167.543,
          4163.776,
          4159.282999999999,
          4154.082,
          4148.191,
          4141.629,
          4134.411,
          4126.556,
          4118.0779999999995,
          4108.9929999999995,
          4099.316,
          4089.0609999999997,
          4078.242,
          4066.8720000000003,
          4054.966,
          4042.534,
          4029.591,
          4016.1459999999997,
          4002.212,
          3987.801,
          3972.923,
          3957.5890000000004,
          3941.808,
          3925.592,
          3908.949,
          3891.889,
          3874.421,
          3856.554,
          3838.296,
          3819.657,
          3800.643,
          3781.264,
          3761.527,
          3741.44,
          3721.01,
          3700.243,
          3679.1479999999997,
          3657.7309999999998,
          3635.998,
          3613.9559999999997,
          3591.612,
          3568.9709999999995,
          3546.04,
          3522.8259999999996,
          3499.3320000000003,
          3475.565,
          3451.531,
          3427.2340000000004,
          3402.6809999999996,
          3377.8759999999997,
          3352.824,
          3327.53,
          3301.9990000000003,
          3276.235,
          3250.245,
          3224.03,
          3197.598,
          3170.95,
          3144.093,
          3117.03,
          3089.764,
          3062.301,
          3034.6440000000002,
          3006.796,
          2978.762,
          2950.545,
          2922.1490000000003,
          2893.577,
          2864.833,
          2835.921,
          2806.843,
          2777.603,
          2748.204,
          2718.651,
          2688.9429999999998,
          2659.0879999999997,
          2629.0840000000003,
          2598.939,
          2568.653,
          2538.229,
          2507.67,
          2476.979,
          2446.16,
          2415.2129999999997,
          2384.143,
          2352.952,
          2321.6420000000003,
          2290.215,
          2258.675,
          2227.024,
          2195.265,
          2163.3979999999997,
          2131.428,
          2099.356,
          2067.185,
          2034.9170000000001,
          2002.5529999999999,
          1970.0970000000002,
          1937.5510000000002,
          1904.9160000000002,
          1872.195,
          1839.389,
          1806.5020000000002,
          1773.5339999999999,
          1740.489,
          1707.3670000000002,
          1674.171,
          1640.9029999999998,
          1607.565,
          1574.1589999999999,
          1540.6860000000001,
          1507.148,
          1473.5479999999998,
          1439.886,
          1406.1660000000002,
          1372.388,
          1338.555,
          1304.6680000000001,
          1270.728,
          1236.738,
          1202.7,
          1168.614,
          1134.483,
          1100.309,
          1066.0919999999999,
          1031.835,
          997.539,
          963.206,
          928.837,
          894.435,
          859.9989999999999,
          825.533,
          791.0369999999999,
          756.513,
          721.9630000000001,
          687.388,
          652.79,
          618.17,
          583.529,
          548.87,
          514.193,
          479.5,
          444.793,
          410.07199999999995,
          375.339,
          340.597,
          305.845,
          271.086,
          236.321,
          201.55200000000002,
          166.77900000000002,
          132.004,
          97.229,
          62.455,
          27.683000000000003,
          -7.086,
          -41.849,
          -76.60600000000001,
          -111.355,
          -146.095,
          -180.825,
          -215.542,
          -250.247,
          -284.937,
          -319.611,
          -354.26800000000003,
          -388.907,
          -423.525,
          -458.12199999999996,
          -492.69699999999995,
          -527.248,
          -561.773,
          -596.2719999999999,
          -630.743,
          -665.185,
          -699.596,
          -733.975,
          -768.32,
          -802.6310000000001,
          -836.9060000000001,
          -871.143,
          -905.342,
          -939.5010000000001,
          -973.618,
          -1007.692,
          -1041.722,
          -1075.7069999999999,
          -1109.644,
          -1143.5339999999999,
          -1177.373,
          -1211.161,
          -1244.897,
          -1278.579,
          -1312.2060000000001,
          -1345.776,
          -1379.287,
          -1412.739,
          -1446.13,
          -1479.4589999999998,
          -1512.724,
          -1545.9229999999998,
          -1579.056,
          -1612.12,
          -1645.114,
          -1678.0379999999998,
          -1710.888,
          -1743.664,
          -1776.364,
          -1808.987,
          -1841.531,
          -1873.995,
          -1906.3770000000002,
          -1938.675,
          -1970.888,
          -2003.014,
          -2035.0520000000001,
          -2067,
          -2098.856,
          -2130.619,
          -2162.2870000000003,
          -2193.859,
          -2225.3320000000003,
          -2256.705,
          -2287.9770000000003,
          -2319.144,
          -2350.2070000000003,
          -2381.163,
          -2412.01,
          -2442.745,
          -2473.369,
          -2503.8779999999997,
          -2534.271,
          -2564.5460000000003,
          -2594.702,
          -2624.735,
          -2654.6440000000002,
          -2684.427,
          -2714.0820000000003,
          -2743.6079999999997,
          -2773.0009999999997,
          -2802.26,
          -2831.384,
          -2860.369,
          -2889.2129999999997,
          -2917.915,
          -2946.473,
          -2974.883,
          -3003.1440000000002,
          -3031.2529999999997,
          -3059.208,
          -3087.007,
          -3114.647,
          -3142.1259999999997,
          -3169.442,
          -3196.591,
          -3223.571,
          -3250.381,
          -3277.0159999999996,
          -3303.475,
          -3329.755,
          -3355.8520000000003,
          -3381.765,
          -3407.491,
          -3433.025,
          -3458.367,
          -3483.512,
          -3508.458,
          -3533.202,
          -3557.74,
          -3582.0690000000004,
          -3606.187,
          -3630.0890000000004,
          -3653.7729999999997,
          -3677.235,
          -3700.4709999999995,
          -3723.4790000000003,
          -3746.2540000000004,
          -3768.7929999999997,
          -3791.091,
          -3813.147,
          -3834.954,
          -3856.511,
          -3877.8109999999997,
          -3898.8520000000003,
          -3919.6290000000004,
          -3940.138,
          -3960.375,
          -3980.336,
          -4000.014,
          -4019.407,
          -4038.509,
          -4057.316,
          -4075.823,
          -4094.0229999999997,
          -4111.914000000001,
          -4129.488,
          -4146.741,
          -4163.668,
          -4180.262,
          -4196.518,
          -4212.43,
          -4227.992,
          -4243.1990000000005,
          -4258.043,
          -4272.518,
          -4286.6179999999995,
          -4300.335,
          -4313.664000000001,
          -4326.596,
          -4339.125,
          -4351.242,
          -4362.941,
          -4374.213,
          -4385.0509999999995,
          -4395.446,
          -4405.39,
          -4414.874,
          -4423.888,
          -4432.425,
          -4440.473,
          -4448.024,
          -4455.067,
          -4461.592000000001,
          -4467.589,
          -4473.0470000000005,
          -4477.954000000001,
          -4482.3,
          -4486.071,
          -4489.255,
          -4491.840999999999,
          -4493.814,
          -4495.162,
          -4495.87,
          -4495.925,
          -4495.312,
          -4494.014,
          -4492.017,
          -4489.304,
          -4485.859,
          -4481.663,
          -4476.6990000000005,
          -4470.948,
          -4464.391,
          -4457.0070000000005,
          -4448.777,
          -4439.679,
          -4429.69,
          -4418.787,
          -4406.947,
          -4394.144,
          -4380.354,
          -4365.548,
          -4349.6990000000005,
          -4332.779,
          -4314.758,
          -4295.603,
          -4275.282999999999,
          -4253.764,
          -4231.01,
          -4206.986,
          -4181.652,
          -4154.97,
          -4126.898,
          -4097.392,
          -4066.408,
          -4033.8990000000003,
          -3999.8140000000003,
          -3964.1059999999998,
          -3926.719,
          -3887.598,
          -3846.6859999999997,
          -3803.921,
          -3759.242,
          -3712.5820000000003,
          -3663.873,
          -3613.046,
          -3560.0240000000003,
          -3504.732,
          -3447.09,
          -3387.0159999999996,
          -3324.4240000000004,
          -3259.2259999999997,
          -3191.3320000000003,
          -3120.6479999999997,
          -3047.08,
          -2970.53,
          -2890.901,
          -2808.0959999999995,
          -2722.0159999999996,
          -2632.565,
          -2539.652,
          -2443.187,
          -2343.089,
          -2239.284,
          -2131.712,
          -2020.326,
          -1905.098,
          -1786.021,
          -1663.115,
          -1536.431,
          -1406.057,
          -1272.119,
          -1134.787,
          -994.2810000000001,
          -850.8689999999999,
          -704.87,
          -556.655,
          -406.639,
          -255.28,
          -103.07,
          49.475,
          201.827,
          353.454,
          503.839,
          652.485,
          798.931,
          942.7560000000001,
          1083.586,
          1221.101,
          1355.0320000000002,
          1485.164,
          1611.3310000000001,
          1733.4160000000002,
          1851.3429999999998,
          1965.075,
          2074.607,
          2179.9629999999997,
          2281.189,
          2378.351,
          2471.529,
          2560.815,
          2646.312,
          2728.125,
          2806.367,
          2881.151,
          2952.59,
          3020.8,
          3085.8940000000002,
          3147.9809999999998,
          3207.172,
          3263.705,
          3317.281,
          3368.402,
          3417.028,
          3463.252,
          3507.1620000000003,
          3548.844,
          3588.3779999999997,
          3625.844,
          3661.315,
          3694.863,
          3726.5570000000002,
          3756.462,
          3784.6409999999996,
          3811.153,
          3836.0570000000002,
          3859.406,
          3881.2529999999997,
          3901.6479999999997,
          3920.64,
          3938.2729999999997,
          3954.592,
          3969.639,
          3983.454,
          3996.077,
          4007.5409999999997,
          4017.886,
          4027.1440000000002,
          4035.348,
          4042.528,
          4048.716,
          4053.94,
          4058.228,
          4061.6059999999998,
          4064.1,
          4065.735,
          4066.535,
          4066.5229999999997,
          4065.72,
          4064.147,
          4061.8259999999996,
          4058.776,
          4055.0159999999996,
          4050.565,
          4045.44,
          4039.658,
          4033.236,
          4026.19,
          4018.535,
          4010.2870000000003,
          4001.46,
          3992.067,
          3982.123,
          3971.64,
          3960.631,
          3949.1090000000004,
          3937.086,
          3924.573,
          3911.5809999999997,
          3898.1220000000003,
          3884.205,
          3869.842,
          3855.0409999999997,
          3839.8140000000003,
          3824.1690000000003,
          3808.115,
          3791.6609999999996,
          3774.816,
          3757.5890000000004,
          3739.988,
          3722.02,
          3703.6940000000004,
          3685.0159999999996,
          3665.995,
          3646.638,
          3626.9509999999996,
          3606.941,
          3586.615,
          3565.98,
          3545.0409999999997,
          3523.805,
          3502.2790000000005,
          3480.467,
          3458.3759999999997,
          3436.012,
          3413.3790000000004,
          3390.4829999999997,
          3367.33,
          3343.9240000000004,
          3320.2709999999997,
          3296.375,
          3272.241,
          3247.8740000000003,
          3223.278,
          3198.4590000000003,
          3173.42,
          3148.165,
          3122.699,
          3097.026,
          3071.15,
          3045.0759999999996,
          3018.8059999999996,
          2992.345,
          2965.696,
          2938.863,
          2911.8509999999997,
          2884.6609999999996,
          2857.298,
          2829.7659999999996,
          2802.066,
          2774.204,
          2746.1809999999996,
          2718.0009999999997,
          2689.6679999999997,
          2661.184,
          2632.552,
          2603.775,
          2574.856,
          2545.799,
          2516.605,
          2487.278,
          2457.819,
          2428.2329999999997,
          2398.521,
          2368.687,
          2338.731,
          2308.659,
          2278.47,
          2248.169,
          2217.757,
          2187.237,
          2156.611,
          2125.882,
          2095.051,
          2064.1220000000003,
          2033.095,
          2001.974,
          1970.76,
          1939.4560000000001,
          1908.0629999999999,
          1876.585,
          1845.0220000000002,
          1813.376,
          1781.651,
          1749.8470000000002,
          1717.967,
          1686.0120000000002,
          1653.985,
          1621.8870000000002,
          1589.721,
          1557.487,
          1525.1879999999999,
          1492.826,
          1460.402,
          1427.918,
          1395.376,
          1362.7779999999998,
          1330.125,
          1297.4180000000001,
          1264.661,
          1231.854,
          1198.998,
          1166.096,
          1133.149,
          1100.1589999999999,
          1067.127,
          1034.056,
          1000.945,
          967.797,
          934.6139999999999,
          901.3969999999999,
          868.148,
          834.867,
          801.557,
          768.2189999999999,
          734.8539999999999,
          701.4639999999999,
          668.05,
          634.614,
          601.158,
          567.682,
          534.188,
          500.67699999999996,
          467.151,
          433.61199999999997,
          400.06,
          366.496,
          332.92400000000004,
          299.343,
          265.754,
          232.16099999999997,
          198.563,
          164.96200000000002,
          131.36,
          97.757,
          64.155,
          30.555999999999997,
          -3.0389999999999997,
          -36.629,
          -70.21300000000001,
          -103.79,
          -137.357,
          -170.91400000000002,
          -204.46,
          -237.99200000000002,
          -271.51,
          -305.013,
          -338.499,
          -371.967,
          -405.415,
          -438.843,
          -472.249,
          -505.631,
          -538.989,
          -572.321,
          -605.626,
          -638.9019999999999,
          -672.148,
          -705.3639999999999,
          -738.546,
          -771.696,
          -804.81,
          -837.887,
          -870.928,
          -903.929,
          -936.8889999999999,
          -969.809,
          -1002.685,
          -1035.517,
          -1068.303,
          -1101.042,
          -1133.733,
          -1166.374,
          -1198.965,
          -1231.502,
          -1263.987,
          -1296.415,
          -1328.7879999999998,
          -1361.102,
          -1393.3570000000002,
          -1425.5520000000001,
          -1457.684,
          -1489.753,
          -1521.757,
          -1553.694,
          -1585.5629999999999,
          -1617.3629999999998,
          -1649.0929999999998,
          -1680.75,
          -1712.3329999999999,
          -1743.8410000000001,
          -1775.273,
          -1806.626,
          -1837.899,
          -1869.0910000000001,
          -1900.201,
          -1931.225,
          -1962.164,
          -1993.015,
          -2023.777,
          -2054.448,
          -2085.026,
          -2115.511,
          -2145.9,
          -2176.1910000000003,
          -2206.383,
          -2236.474,
          -2266.4629999999997,
          -2296.348,
          -2326.126,
          -2355.7960000000003,
          -2385.357,
          -2414.8070000000002,
          -2444.143,
          -2473.363,
          -2502.467,
          -2531.452,
          -2560.3160000000003,
          -2589.0570000000002,
          -2617.673,
          -2646.1620000000003,
          -2674.5229999999997,
          -2702.7529999999997,
          -2730.849,
          -2758.8109999999997,
          -2786.635,
          -2814.32,
          -2841.864,
          -2869.264,
          -2896.518,
          -2923.623,
          -2950.578,
          -2977.381,
          -3004.028,
          -3030.5170000000003,
          -3056.8459999999995,
          -3083.012,
          -3109.014,
          -3134.847,
          -3160.511,
          -3186.0009999999997,
          -3211.317,
          -3236.453,
          -3261.409,
          -3286.1809999999996,
          -3310.7670000000003,
          -3335.163,
          -3359.366,
          -3383.3740000000003,
          -3407.183,
          -3430.7909999999997,
          -3454.1940000000004,
          -3477.388,
          -3500.3720000000003,
          -3523.1409999999996,
          -3545.692,
          -3568.0209999999997,
          -3590.1259999999997,
          -3612.002,
          -3633.6459999999997,
          -3655.054,
          -3676.222,
          -3697.147,
          -3717.824,
          -3738.25,
          -3758.42,
          -3778.3309999999997,
          -3797.9770000000003,
          -3817.3559999999998,
          -3836.461,
          -3855.29,
          -3873.836,
          -3892.0959999999995,
          -3910.0640000000003,
          -3927.736,
          -3945.1059999999998,
          -3962.17,
          -3978.921,
          -3995.3559999999998,
          -4011.467,
          -4027.25,
          -4042.699,
          -4057.808,
          -4072.571,
          -4086.982,
          -4101.032999999999,
          -4114.72,
          -4128.034000000001,
          -4140.97,
          -4153.521,
          -4165.678,
          -4177.435,
          -4188.784000000001,
          -4199.717000000001,
          -4210.227,
          -4220.306,
          -4229.944,
          -4239.134,
          -4247.866,
          -4256.1320000000005,
          -4263.920999999999,
          -4271.225,
          -4278.032999999999,
          -4284.335,
          -4290.121,
          -4295.38,
          -4300.101,
          -4304.273,
          -4307.883,
          -4310.919,
          -4313.369000000001,
          -4315.22,
          -4316.458,
          -4317.071,
          -4317.043,
          -4316.36,
          -4315.005999999999,
          -4312.967000000001,
          -4310.225,
          -4306.765,
          -4302.568,
          -4297.6179999999995,
          -4291.894,
          -4285.377,
          -4278.05,
          -4269.889,
          -4260.875,
          -4250.985,
          -4240.195,
          -4228.481,
          -4215.82,
          -4202.186,
          -4187.5509999999995,
          -4171.888,
          -4155.167,
          -4137.36,
          -4118.434,
          -4098.357,
          -4077.094,
          -4054.613,
          -4030.8740000000003,
          -4005.84,
          -3979.47,
          -3951.725,
          -3922.559,
          -3891.928,
          -3859.785,
          -3826.0809999999997,
          -3790.763,
          -3753.7790000000005,
          -3715.074,
          -3674.587,
          -3632.261,
          -3588.0290000000005,
          -3541.828,
          -3493.5879999999997,
          -3443.237,
          -3390.703,
          -3335.907,
          -3278.77,
          -3219.2090000000003,
          -3157.138,
          -3092.4709999999995,
          -3025.116,
          -2954.982,
          -2881.973,
          -2805.9959999999996,
          -2726.955,
          -2644.7529999999997,
          -2559.297,
          -2470.496,
          -2378.262,
          -2282.514,
          -2183.18,
          -2080.197,
          -1973.515,
          -1863.104,
          -1748.953,
          -1631.0770000000002,
          -1509.519,
          -1384.355,
          -1255.703,
          -1123.719,
          -988.6080000000001,
          -850.6210000000001,
          -710.06,
          -567.273,
          -422.658,
          -276.651,
          -129.722,
          17.634,
          164.90599999999998,
          311.58099999999996,
          457.157,
          601.15,
          743.11,
          882.623,
          1019.321,
          1152.887,
          1283.0539999999999,
          1409.606,
          1532.375,
          1651.24,
          1766.122,
          1876.977,
          1983.797,
          2086.598,
          2185.423,
          2280.328,
          2371.39,
          2458.694,
          2542.337,
          2622.4190000000003,
          2699.045,
          2772.325,
          2842.369,
          2909.284,
          2973.179,
          3034.1620000000003,
          3092.337,
          3147.804,
          3200.663,
          3251.009,
          3298.9359999999997,
          3344.53,
          3387.88,
          3429.0640000000003,
          3468.164,
          3505.255,
          3540.407,
          3573.6929999999998,
          3605.175,
          3634.92,
          3662.987,
          3689.434,
          3714.316,
          3737.688,
          3759.599,
          3780.097,
          3799.23,
          3817.0429999999997,
          3833.5759999999996,
          3848.8709999999996,
          3862.968,
          3875.9040000000005,
          3887.7140000000004,
          3898.433,
          3908.094,
          3916.7290000000003,
          3924.368,
          3931.039,
          3936.772,
          3941.593,
          3945.528,
          3948.6020000000003,
          3950.8390000000004,
          3952.261,
          3952.893,
          3952.7529999999997,
          3951.864,
          3950.245,
          3947.915,
          3944.893,
          3941.197,
          3936.844,
          3931.85,
          3926.232,
          3920.0040000000004,
          3913.183,
          3905.783,
          3897.817,
          3889.3,
          3880.245,
          3870.664,
          3860.5690000000004,
          3849.974,
          3838.888,
          3827.323,
          3815.292,
          3802.803,
          3789.868,
          3776.4959999999996,
          3762.698,
          3748.4809999999998,
          3733.857,
          3718.833,
          3703.4179999999997,
          3687.62,
          3671.449,
          3654.9109999999996,
          3638.015,
          3620.768,
          3603.177,
          3585.25,
          3566.994,
          3548.415,
          3529.52,
          3510.316,
          3490.808,
          3471.0040000000004,
          3450.908,
          3430.527,
          3409.867,
          3388.933,
          3367.73,
          3346.264,
          3324.5409999999997,
          3302.565,
          3280.341,
          3257.875,
          3235.17,
          3212.232,
          3189.065,
          3165.673,
          3142.0609999999997,
          3118.2340000000004,
          3094.195,
          3069.948,
          3045.498,
          3020.848,
          2996.0029999999997,
          2970.965,
          2945.74,
          2920.329,
          2894.738,
          2868.969,
          2843.026,
          2816.9120000000003,
          2790.631,
          2764.1859999999997,
          2737.579,
          2710.815,
          2683.8959999999997,
          2656.8259999999996,
          2629.6059999999998,
          2602.241,
          2574.732,
          2547.084,
          2519.297,
          2491.377,
          2463.324,
          2435.141,
          2406.8320000000003,
          2378.399,
          2349.844,
          2321.169,
          2292.3779999999997,
          2263.472,
          2234.455,
          2205.327,
          2176.092,
          2146.752,
          2117.3089999999997,
          2087.765,
          2058.123,
          2028.384,
          1998.5510000000002,
          1968.626,
          1938.61,
          1908.506,
          1878.316,
          1848.0420000000001,
          1817.6860000000001,
          1787.249,
          1756.734,
          1726.142,
          1695.476,
          1664.737,
          1633.9270000000001,
          1603.047,
          1572.1,
          1541.088,
          1510.011,
          1478.872,
          1447.6729999999998,
          1416.415,
          1385.1,
          1353.729,
          1322.3039999999999,
          1290.827,
          1259.299,
          1227.722,
          1196.098,
          1164.427,
          1132.712,
          1100.954,
          1069.155,
          1037.316,
          1005.438,
          973.5239999999999,
          941.574,
          909.59,
          877.574,
          845.5260000000001,
          813.449,
          781.3439999999999,
          749.211,
          717.053,
          684.872,
          652.6669999999999,
          620.441,
          588.195,
          555.931,
          523.649,
          491.352,
          459.04,
          426.715,
          394.37699999999995,
          362.03,
          329.673,
          297.308,
          264.936,
          232.55900000000003,
          200.178,
          167.794,
          135.409,
          103.024,
          70.639,
          38.257,
          5.879,
          -26.495,
          -58.861999999999995,
          -91.22200000000001,
          -123.574,
          -155.915,
          -188.245,
          -220.563,
          -252.86700000000002,
          -285.156,
          -317.42900000000003,
          -349.685,
          -381.92199999999997,
          -414.13800000000003,
          -446.334,
          -478.50699999999995,
          -510.656,
          -542.781,
          -574.879,
          -606.95,
          -638.992,
          -671.0039999999999,
          -702.9839999999999,
          -734.933,
          -766.847,
          -798.7260000000001,
          -830.569,
          -862.3739999999999,
          -894.1410000000001,
          -925.867,
          -957.552,
          -989.194,
          -1020.7919999999999,
          -1052.344,
          -1083.85,
          -1115.308,
          -1146.7160000000001,
          -1178.0739999999998,
          -1209.38,
          -1240.633,
          -1271.8310000000001,
          -1302.973,
          -1334.058,
          -1365.0829999999999,
          -1396.049,
          -1426.954,
          -1457.795,
          -1488.5729999999999,
          -1519.2839999999999,
          -1549.9289999999999,
          -1580.505,
          -1611.011,
          -1641.4460000000001,
          -1671.808,
          -1702.095,
          -1732.307,
          -1762.442,
          -1792.4979999999998,
          -1822.473,
          -1852.3670000000002,
          -1882.1770000000001,
          -1911.9029999999998,
          -1941.5420000000001,
          -1971.0929999999998,
          -2000.5539999999999,
          -2029.925,
          -2059.202,
          -2088.385,
          -2117.471,
          -2146.46,
          -2175.349,
          -2204.137,
          -2232.822,
          -2261.402,
          -2289.876,
          -2318.241,
          -2346.4970000000003,
          -2374.64,
          -2402.67,
          -2430.584,
          -2458.381,
          -2486.058,
          -2513.614,
          -2541.0460000000003,
          -2568.354,
          -2595.534,
          -2622.5840000000003,
          -2649.5029999999997,
          -2676.289,
          -2702.9390000000003,
          -2729.4509999999996,
          -2755.823,
          -2782.053,
          -2808.139,
          -2834.078,
          -2859.868,
          -2885.506,
          -2910.991,
          -2936.32,
          -2961.491,
          -2986.5,
          -3011.3459999999995,
          -3036.026,
          -3060.5370000000003,
          -3084.877,
          -3109.042,
          -3133.031,
          -3156.841,
          -3180.468,
          -3203.91,
          -3227.163,
          -3250.2259999999997,
          -3273.095,
          -3295.7659999999996,
          -3318.237,
          -3340.5040000000004,
          -3362.565,
          -3384.4159999999997,
          -3406.053,
          -3427.474,
          -3448.6740000000004,
          -3469.65,
          -3490.3979999999997,
          -3510.9159999999997,
          -3531.198,
          -3551.242,
          -3571.0429999999997,
          -3590.598,
          -3609.901,
          -3628.95,
          -3647.74,
          -3666.2659999999996,
          -3684.5240000000003,
          -3702.509,
          -3720.217,
          -3737.643,
          -3754.783,
          -3771.631,
          -3788.1820000000002,
          -3804.4320000000002,
          -3820.375,
          -3836.005,
          -3851.317,
          -3866.305,
          -3880.9640000000004,
          -3895.2870000000003,
          -3909.2690000000002,
          -3922.903,
          -3936.183,
          -3949.1020000000003,
          -3961.6540000000005,
          -3973.8320000000003,
          -3985.6279999999997,
          -3997.0359999999996,
          -4008.048,
          -4018.656,
          -4028.853,
          -4038.631,
          -4047.98,
          -4056.8940000000002,
          -4065.362,
          -4073.377,
          -4080.928,
          -4088.007,
          -4094.603,
          -4100.707,
          -4106.309,
          -4111.397,
          -4115.96,
          -4119.988,
          -4123.468,
          -4126.388,
          -4128.737,
          -4130.501,
          -4131.668,
          -4132.223,
          -4132.153,
          -4131.442,
          -4130.076,
          -4128.04,
          -4125.316,
          -4121.889,
          -4117.742,
          -4112.857,
          -4107.214,
          -4100.795999999999,
          -4093.5809999999997,
          -4085.55,
          -4076.6820000000002,
          -4066.954,
          -4056.343,
          -4044.827,
          -4032.3779999999997,
          -4018.973,
          -4004.5840000000003,
          -3989.185,
          -3972.745,
          -3955.2340000000004,
          -3936.623,
          -3916.877,
          -3895.9640000000004,
          -3873.848,
          -3850.491,
          -3825.857,
          -3799.905,
          -3772.593,
          -3743.877,
          -3713.7140000000004,
          -3682.054,
          -3648.849,
          -3614.047,
          -3577.5959999999995,
          -3539.437,
          -3499.514,
          -3457.7659999999996,
          -3414.127,
          -3368.535,
          -3320.917,
          -3271.204,
          -3219.322,
          -3165.192,
          -3108.735,
          -3049.868,
          -2988.508,
          -2924.565,
          -2857.952,
          -2788.575,
          -2716.343,
          -2641.163,
          -2562.9410000000003,
          -2481.5879999999997,
          -2397.01,
          -2309.123,
          -2217.847,
          -2123.109,
          -2024.844,
          -1923.005,
          -1817.5539999999999,
          -1708.4779999999998,
          -1595.786,
          -1479.514,
          -1359.729,
          -1236.538,
          -1110.0839999999998,
          -980.555,
          -848.189,
          -713.2669999999999,
          -576.118,
          -437.11800000000005,
          -296.681,
          -155.257,
          -13.32,
          128.64,
          270.13,
          410.661,
          549.766,
          687.0039999999999,
          821.972,
          954.309,
          1083.701,
          1209.882,
          1332.6370000000002,
          1451.797,
          1567.2379999999998,
          1678.876,
          1786.664,
          1890.5870000000002,
          1990.656,
          2086.906,
          2179.391,
          2268.179,
          2353.349,
          2434.993,
          2513.2039999999997,
          2588.083,
          2659.7340000000004,
          2728.26,
          2793.764,
          2856.3520000000003,
          2916.125,
          2973.1820000000002,
          3027.6220000000003,
          3079.539,
          3129.026,
          3176.17,
          3221.0570000000002,
          3263.77,
          3304.388,
          3342.986,
          3379.637,
          3414.4120000000003,
          3447.3759999999997,
          3478.594,
          3508.127,
          3536.033,
          3562.369,
          3587.188,
          3610.5409999999997,
          3632.4770000000003,
          3653.0440000000003,
          3672.2859999999996,
          3690.245,
          3706.9640000000004,
          3722.482,
          3736.836,
          3750.062,
          3762.195,
          3773.2690000000002,
          3783.316,
          3792.366,
          3800.448,
          3807.591,
          3813.822,
          3819.1659999999997,
          3823.65,
          3827.297,
          3830.1290000000004,
          3832.171,
          3833.4429999999998,
          3833.966,
          3833.76,
          3832.844,
          3831.236,
          3828.955,
          3826.018,
          3822.441,
          3818.242,
          3813.434,
          3808.034,
          3802.0559999999996,
          3795.514,
          3788.422,
          3780.7909999999997,
          3772.637,
          3763.9709999999995,
          3754.804,
          3745.15,
          3735.018,
          3724.4190000000003,
          3713.365,
          3701.866,
          3689.9309999999996,
          3677.57,
          3664.7929999999997,
          3651.6079999999997,
          3638.026,
          3624.053,
          3609.7,
          3594.973,
          3579.881,
          3564.4309999999996,
          3548.632,
          3532.49,
          3516.012,
          3499.2059999999997,
          3482.077,
          3464.634,
          3446.882,
          3428.827,
          3410.4759999999997,
          3391.835,
          3372.909,
          3353.705,
          3334.2270000000003,
          3314.4809999999998,
          3294.472,
          3274.2059999999997,
          3253.688,
          3232.922,
          3211.914,
          3190.667,
          3169.188,
          3147.4790000000003,
          3125.547,
          3103.3940000000002,
          3081.025,
          3058.445,
          3035.658,
          3012.6659999999997,
          2989.475,
          2966.0879999999997,
          2942.509,
          2918.741,
          2894.788,
          2870.655,
          2846.343,
          2821.857,
          2797.199,
          2772.3740000000003,
          2747.384,
          2722.2329999999997,
          2696.923,
          2671.4570000000003,
          2645.8390000000004,
          2620.072,
          2594.158,
          2568.1,
          2541.901,
          2515.563,
          2489.09,
          2462.484,
          2435.748,
          2408.884,
          2381.894,
          2354.782,
          2327.549,
          2300.199,
          2272.732,
          2245.152,
          2217.462,
          2189.6620000000003,
          2161.756,
          2133.745,
          2105.633,
          2077.42,
          2049.109,
          2020.703,
          1992.2020000000002,
          1963.61,
          1934.9279999999999,
          1906.158,
          1877.3020000000001,
          1848.3629999999998,
          1819.3410000000001,
          1790.239,
          1761.058,
          1731.8010000000002,
          1702.469,
          1673.0639999999999,
          1643.588,
          1614.0420000000001,
          1584.4289999999999,
          1554.749,
          1525.005,
          1495.1979999999999,
          1465.33,
          1435.4029999999998,
          1405.4170000000001,
          1375.376,
          1345.279,
          1315.13,
          1284.9289999999999,
          1254.678,
          1224.378,
          1194.032,
          1163.639,
          1133.203,
          1102.724,
          1072.204,
          1041.645,
          1011.047,
          980.4119999999999,
          949.742,
          919.0369999999999,
          888.3,
          857.5319999999999,
          826.7339999999999,
          795.908,
          765.054,
          734.174,
          703.27,
          672.3430000000001,
          641.394,
          610.424,
          579.435,
          548.428,
          517.404,
          486.365,
          455.31199999999995,
          424.24699999999996,
          393.16900000000004,
          362.08099999999996,
          330.985,
          299.88,
          268.769,
          237.653,
          206.532,
          175.40900000000002,
          144.284,
          113.15899999999999,
          82.03399999999999,
          50.912,
          19.793,
          -11.321,
          -42.43,
          -73.532,
          -104.626,
          -135.71,
          -166.78400000000002,
          -197.84599999999998,
          -228.895,
          -259.93,
          -290.949,
          -321.952,
          -352.93699999999995,
          -383.903,
          -414.849,
          -445.774,
          -476.676,
          -507.55400000000003,
          -538.4069999999999,
          -569.234,
          -600.033,
          -630.804,
          -661.544,
          -692.2539999999999,
          -722.931,
          -753.575,
          -784.184,
          -814.757,
          -845.293,
          -875.79,
          -906.247,
          -936.664,
          -967.038,
          -997.3689999999999,
          -1027.655,
          -1057.894,
          -1088.087,
          -1118.231,
          -1148.325,
          -1178.368,
          -1208.359,
          -1238.295,
          -1268.177,
          -1298.002,
          -1327.77,
          -1357.4779999999998,
          -1387.126,
          -1416.7120000000002,
          -1446.235,
          -1475.693,
          -1505.086,
          -1534.411,
          -1563.668,
          -1592.854,
          -1621.969,
          -1651.011,
          -1679.9779999999998,
          -1708.87,
          -1737.684,
          -1766.4189999999999,
          -1795.0739999999998,
          -1823.6470000000002,
          -1852.1370000000002,
          -1880.5420000000001,
          -1908.86,
          -1937.09,
          -1965.231,
          -1993.28,
          -2021.236,
          -2049.098,
          -2076.864,
          -2104.532,
          -2132.101,
          -2159.5679999999998,
          -2186.933,
          -2214.1929999999998,
          -2241.346,
          -2268.391,
          -2295.326,
          -2322.15,
          -2348.859,
          -2375.453,
          -2401.93,
          -2428.2870000000003,
          -2454.5229999999997,
          -2480.636,
          -2506.623,
          -2532.4829999999997,
          -2558.2129999999997,
          -2583.812,
          -2609.278,
          -2634.6079999999997,
          -2659.8,
          -2684.8520000000003,
          -2709.761,
          -2734.526,
          -2759.1440000000002,
          -2783.613,
          -2807.9309999999996,
          -2832.094,
          -2856.1009999999997,
          -2879.949,
          -2903.636,
          -2927.158,
          -2950.514,
          -2973.7009999999996,
          -2996.716,
          -3019.5559999999996,
          -3042.219,
          -3064.7009999999996,
          -3087.0009999999997,
          -3109.114,
          -3131.038,
          -3152.77,
          -3174.3070000000002,
          -3195.645,
          -3216.782,
          -3237.715,
          -3258.4390000000003,
          -3278.9509999999996,
          -3299.248,
          -3319.327,
          -3339.184,
          -3358.815,
          -3378.216,
          -3397.384,
          -3416.315,
          -3435.005,
          -3453.449,
          -3471.6440000000002,
          -3489.585,
          -3507.268,
          -3524.6890000000003,
          -3541.842,
          -3558.725,
          -3575.3309999999997,
          -3591.656,
          -3607.696,
          -3623.4440000000004,
          -3638.8959999999997,
          -3654.047,
          -3668.8909999999996,
          -3683.422,
          -3697.636,
          -3711.525,
          -3725.085,
          -3738.309,
          -3751.19,
          -3763.724,
          -3775.901,
          -3787.718,
          -3799.1659999999997,
          -3810.237,
          -3820.926,
          -3831.224,
          -3841.1240000000003,
          -3850.618,
          -3859.697,
          -3868.3540000000003,
          -3876.58,
          -3884.365,
          -3891.7009999999996,
          -3898.58,
          -3904.99,
          -3910.923,
          -3916.367,
          -3921.313,
          -3925.75,
          -3929.6659999999997,
          -3933.05,
          -3935.889,
          -3938.1740000000004,
          -3939.889,
          -3941.0229999999997,
          -3941.562,
          -3941.491,
          -3940.798,
          -3939.466,
          -3937.48,
          -3934.824,
          -3931.482,
          -3927.438,
          -3922.672,
          -3917.1679999999997,
          -3910.906,
          -3903.866,
          -3896.028,
          -3887.3720000000003,
          -3877.8740000000003,
          -3867.513,
          -3856.264,
          -3844.103,
          -3831.0040000000004,
          -3816.941,
          -3801.887,
          -3785.813,
          -3768.687,
          -3750.4809999999998,
          -3731.16,
          -3710.6929999999998,
          -3689.042,
          -3666.17,
          -3642.0409999999997,
          -3616.615,
          -3589.849,
          -3561.699,
          -3532.1220000000003,
          -3501.0690000000004,
          -3468.491,
          -3434.337,
          -3398.552,
          -3361.08,
          -3321.865,
          -3280.843,
          -3237.952,
          -3193.125,
          -3146.295,
          -3097.387,
          -3046.3309999999997,
          -2993.046,
          -2937.4559999999997,
          -2879.4759999999997,
          -2819.0240000000003,
          -2756.012,
          -2690.3520000000003,
          -2621.954,
          -2550.729,
          -2476.584,
          -2399.4320000000002,
          -2319.183,
          -2235.7529999999997,
          -2149.064,
          -2059.04,
          -1965.62,
          -1868.7520000000002,
          -1768.3970000000002,
          -1664.5379999999998,
          -1557.1789999999999,
          -1446.3470000000002,
          -1332.102,
          -1214.539,
          -1093.789,
          -970.0269999999999,
          -843.4689999999999,
          -714.3810000000001,
          -583.072,
          -449.89599999999996,
          -315.248,
          -179.549,
          -43.255,
          93.166,
          229.239,
          364.49300000000005,
          498.477,
          630.762,
          760.955,
          888.701,
          1013.694,
          1135.6680000000001,
          1254.41,
          1369.751,
          1481.5610000000001,
          1589.757,
          1694.285,
          1795.125,
          1892.2820000000002,
          1985.786,
          2075.685,
          2162.0389999999998,
          2244.924,
          2324.422,
          2400.6220000000003,
          2473.62,
          2543.512,
          2610.3979999999997,
          2674.375,
          2735.5429999999997,
          2793.9990000000003,
          2849.837,
          2903.173,
          2954.035,
          3002.574,
          3048.8520000000003,
          3092.9509999999996,
          3134.953,
          3174.93,
          3212.958,
          3249.105,
          3283.44,
          3316.0240000000003,
          3346.922,
          3376.19,
          3403.886,
          3430.063,
          3454.7740000000003,
          3478.067,
          3499.99,
          3520.586,
          3539.902,
          3557.9770000000003,
          3574.8509999999997,
          3590.5609999999997,
          3605.145,
          3618.638,
          3631.073,
          3642.4809999999998,
          3652.895,
          3662.342,
          3670.8520000000003,
          3678.452,
          3685.1679999999997,
          3691.025,
          3696.047,
          3700.259,
          3703.6809999999996,
          3706.335,
          3708.244,
          3709.426,
          3709.9,
          3709.6859999999997,
          3708.801,
          3707.263,
          3705.0879999999997,
          3702.2909999999997,
          3698.89,
          3694.8990000000003,
          3690.333,
          3685.205,
          3679.5290000000005,
          3673.3190000000004,
          3666.587,
          3659.345,
          3651.6059999999998,
          3643.381,
          3634.68,
          3625.5159999999996,
          3615.8979999999997,
          3605.837,
          3595.343,
          3584.426,
          3573.094,
          3561.3579999999997,
          3549.225,
          3536.704,
          3523.804,
          3510.533,
          3496.8979999999997,
          3482.908,
          3468.5690000000004,
          3453.889,
          3438.8759999999997,
          3423.535,
          3407.875,
          3391.901,
          3375.619,
          3359.0370000000003,
          3342.159,
          3324.993,
          3307.5429999999997,
          3289.815,
          3271.815,
          3253.5490000000004,
          3235.0209999999997,
          3216.236,
          3197.2,
          3177.9179999999997,
          3158.393,
          3138.632,
          3118.638,
          3098.4159999999997,
          3077.97,
          3057.305,
          3036.425,
          3015.333,
          2994.034,
          2972.532,
          2950.8309999999997,
          2928.934,
          2906.8459999999995,
          2884.5690000000004,
          2862.107,
          2839.4640000000004,
          2816.6440000000002,
          2793.6490000000003,
          2770.482,
          2747.1479999999997,
          2723.6490000000003,
          2699.988,
          2676.1679999999997,
          2652.1929999999998,
          2628.065,
          2603.7870000000003,
          2579.362,
          2554.792,
          2530.0820000000003,
          2505.232,
          2480.246,
          2455.126,
          2429.876,
          2404.4970000000003,
          2378.992,
          2353.363,
          2327.613,
          2301.744,
          2275.758,
          2249.659,
          2223.447,
          2197.125,
          2170.696,
          2144.161,
          2117.5229999999997,
          2090.784,
          2063.945,
          2037.009,
          2009.9779999999998,
          1982.854,
          1955.639,
          1928.3339999999998,
          1900.942,
          1873.464,
          1845.9029999999998,
          1818.259,
          1790.536,
          1762.735,
          1734.856,
          1706.904,
          1678.878,
          1650.78,
          1622.6129999999998,
          1594.378,
          1566.076,
          1537.71,
          1509.281,
          1480.79,
          1452.2379999999998,
          1423.629,
          1394.9620000000002,
          1366.24,
          1337.465,
          1308.636,
          1279.757,
          1250.829,
          1221.8519999999999,
          1192.829,
          1163.761,
          1134.649,
          1105.494,
          1076.299,
          1047.0639999999999,
          1017.791,
          988.4810000000001,
          959.1360000000001,
          929.757,
          900.345,
          870.9010000000001,
          841.427,
          811.924,
          782.3939999999999,
          752.837,
          723.2560000000001,
          693.65,
          664.023,
          634.374,
          604.705,
          575.0169999999999,
          545.311,
          515.59,
          485.853,
          456.103,
          426.34,
          396.565,
          366.781,
          336.98699999999997,
          307.185,
          277.377,
          247.56400000000002,
          217.74599999999998,
          187.925,
          158.102,
          128.278,
          98.455,
          68.634,
          38.815,
          9,
          -20.81,
          -50.613,
          -80.40899999999999,
          -110.197,
          -139.975,
          -169.74099999999999,
          -199.49599999999998,
          -229.238,
          -258.965,
          -288.677,
          -318.372,
          -348.05,
          -377.708,
          -407.346,
          -436.963,
          -466.55800000000005,
          -496.129,
          -525.675,
          -555.195,
          -584.688,
          -614.153,
          -643.589,
          -672.993,
          -702.3660000000001,
          -731.706,
          -761.012,
          -790.283,
          -819.5169999999999,
          -848.7130000000001,
          -877.87,
          -906.987,
          -936.063,
          -965.096,
          -994.085,
          -1023.029,
          -1051.927,
          -1080.778,
          -1109.579,
          -1138.3310000000001,
          -1167.031,
          -1195.6789999999999,
          -1224.2730000000001,
          -1252.812,
          -1281.2939999999999,
          -1309.719,
          -1338.085,
          -1366.39,
          -1394.6329999999998,
          -1422.8139999999999,
          -1450.93,
          -1478.981,
          -1506.964,
          -1534.879,
          -1562.724,
          -1590.4979999999998,
          -1618.1989999999998,
          -1645.826,
          -1673.3770000000002,
          -1700.852,
          -1728.2479999999998,
          -1755.5629999999999,
          -1782.7979999999998,
          -1809.9489999999998,
          -1837.016,
          -1863.997,
          -1890.891,
          -1917.695,
          -1944.408,
          -1971.029,
          -1997.556,
          -2023.9879999999998,
          -2050.322,
          -2076.558,
          -2102.692,
          -2128.725,
          -2154.653,
          -2180.475,
          -2206.19,
          -2231.795,
          -2257.2889999999998,
          -2282.67,
          -2307.936,
          -2333.084,
          -2358.114,
          -2383.024,
          -2407.81,
          -2432.472,
          -2457.007,
          -2481.413,
          -2505.688,
          -2529.8289999999997,
          -2553.8360000000002,
          -2577.705,
          -2601.435,
          -2625.0229999999997,
          -2648.466,
          -2671.763,
          -2694.9109999999996,
          -2717.908,
          -2740.7509999999997,
          -2763.438,
          -2785.967,
          -2808.3340000000003,
          -2830.5370000000003,
          -2852.573,
          -2874.441,
          -2896.136,
          -2917.657,
          -2939,
          -2960.163,
          -2981.1420000000003,
          -3001.935,
          -3022.538,
          -3042.949,
          -3063.164,
          -3083.18,
          -3102.995,
          -3122.603,
          -3142.0029999999997,
          -3161.19,
          -3180.1609999999996,
          -3198.9120000000003,
          -3217.44,
          -3235.741,
          -3253.8109999999997,
          -3271.6459999999997,
          -3289.242,
          -3306.594,
          -3323.7,
          -3340.554,
          -3357.152,
          -3373.49,
          -3389.563,
          -3405.366,
          -3420.8940000000002,
          -3436.143,
          -3451.1079999999997,
          -3465.783,
          -3480.163,
          -3494.243,
          -3508.018,
          -3521.4809999999998,
          -3534.627,
          -3547.45,
          -3559.9429999999998,
          -3572.1020000000003,
          -3583.9179999999997,
          -3595.386,
          -3606.4990000000003,
          -3617.2490000000003,
          -3627.631,
          -3637.636,
          -3647.257,
          -3656.486,
          -3665.315,
          -3673.736,
          -3681.742,
          -3689.322,
          -3696.469,
          -3703.173,
          -3709.425,
          -3715.215,
          -3720.533,
          -3725.369,
          -3729.711,
          -3733.55,
          -3736.8740000000003,
          -3739.671,
          -3741.929,
          -3743.636,
          -3744.78,
          -3745.3459999999995,
          -3745.321,
          -3744.691,
          -3743.441,
          -3741.5570000000002,
          -3739.022,
          -3735.8190000000004,
          -3731.934,
          -3727.347,
          -3722.042,
          -3715.9990000000003,
          -3709.198,
          -3701.6209999999996,
          -3693.244,
          -3684.048,
          -3674.009,
          -3663.105,
          -3651.31,
          -3638.6,
          -3624.948,
          -3610.325,
          -3594.705,
          -3578.058,
          -3560.3520000000003,
          -3541.555,
          -3521.633,
          -3500.551,
          -3478.2740000000003,
          -3454.762,
          -3429.9770000000003,
          -3403.875,
          -3376.414,
          -3347.55,
          -3317.2340000000004,
          -3285.417,
          -3252.048,
          -3217.074,
          -3180.437,
          -3142.08,
          -3101.942,
          -3059.96,
          -3016.0679999999998,
          -2970.195,
          -2922.2729999999997,
          -2872.2259999999997,
          -2819.978,
          -2765.4509999999996,
          -2708.562,
          -2649.23,
          -2587.367,
          -2522.887,
          -2455.7039999999997,
          -2385.728,
          -2312.873,
          -2237.052,
          -2158.1839999999997,
          -2076.189,
          -1990.995,
          -1902.5379999999998,
          -1810.765,
          -1715.6370000000002,
          -1617.131,
          -1515.245,
          -1410.0020000000002,
          -1301.452,
          -1189.678,
          -1074.8010000000002,
          -956.9780000000001,
          -836.413,
          -713.3480000000001,
          -588.075,
          -460.925,
          -332.26800000000003,
          -202.50799999999998,
          -72.075,
          58.583999999999996,
          189.014,
          318.764,
          447.397,
          574.501,
          699.69,
          822.6210000000001,
          942.9910000000001,
          1060.539,
          1175.055,
          1286.365,
          1394.344,
          1498.898,
          1599.974,
          1697.545,
          1791.612,
          1882.1989999999998,
          1969.344,
          2053.107,
          2133.552,
          2210.758,
          2284.8070000000002,
          2355.7889999999998,
          2423.794,
          2488.916,
          2551.248,
          2610.884,
          2667.914,
          2722.433,
          2774.526,
          2824.281,
          2871.781,
          2917.1079999999997,
          2960.34,
          3001.552,
          3040.816,
          3078.204,
          3113.781,
          3147.612,
          3179.757,
          3210.277,
          3239.228,
          3266.6620000000003,
          3292.633,
          3317.19,
          3340.38,
          3362.248,
          3382.837,
          3402.19,
          3420.3459999999995,
          3437.343,
          3453.217,
          3468.0040000000004,
          3481.737,
          3494.449,
          3506.17,
          3516.929,
          3526.755,
          3535.675,
          3543.717,
          3550.9040000000005,
          3557.261,
          3562.8109999999997,
          3567.577,
          3571.5809999999997,
          3574.841,
          3577.38,
          3579.216,
          3580.368,
          3580.8540000000003,
          3580.69,
          3579.895,
          3578.482,
          3576.469,
          3573.87,
          3570.699,
          3566.972,
          3562.7,
          3557.8979999999997,
          3552.578,
          3546.752,
          3540.433,
          3533.631,
          3526.3579999999997,
          3518.6240000000003,
          3510.441,
          3501.817,
          3492.764,
          3483.2909999999997,
          3473.407,
          3463.12,
          3452.441,
          3441.377,
          3429.937,
          3418.1279999999997,
          3405.958,
          3393.4359999999997,
          3380.5679999999998,
          3367.362,
          3353.825,
          3339.9629999999997,
          3325.783,
          3311.2909999999997,
          3296.495,
          3281.4,
          3266.011,
          3250.336,
          3234.38,
          3218.1479999999997,
          3201.645,
          3184.8779999999997,
          3167.8509999999997,
          3150.5690000000004,
          3133.0370000000003,
          3115.26,
          3097.242,
          3078.989,
          3060.505,
          3041.7940000000003,
          3022.861,
          3003.7090000000003,
          2984.343,
          2964.7670000000003,
          2944.985,
          2925.0009999999997,
          2904.8179999999998,
          2884.44,
          2863.8709999999996,
          2843.115,
          2822.1740000000004,
          2801.053,
          2779.7540000000004,
          2758.282,
          2736.638,
          2714.827,
          2692.8520000000003,
          2670.715,
          2648.4190000000003,
          2625.968,
          2603.365,
          2580.611,
          2557.7110000000002,
          2534.666,
          2511.479,
          2488.153,
          2464.6910000000003,
          2441.095,
          2417.368,
          2393.512,
          2369.529,
          2345.423,
          2321.194,
          2296.846,
          2272.381,
          2247.801,
          2223.1079999999997,
          2198.305,
          2173.393,
          2148.375,
          2123.252,
          2098.028,
          2072.703,
          2047.28,
          2021.761,
          1996.1470000000002,
          1970.442,
          1944.645,
          1918.76,
          1892.7879999999998,
          1866.731,
          1840.5910000000001,
          1814.369,
          1788.067,
          1761.6879999999999,
          1735.2320000000002,
          1708.701,
          1682.0970000000002,
          1655.422,
          1628.6770000000001,
          1601.864,
          1574.985,
          1548.04,
          1521.0320000000002,
          1493.961,
          1466.8310000000001,
          1439.641,
          1412.394,
          1385.0910000000001,
          1357.733,
          1330.3220000000001,
          1302.86,
          1275.347,
          1247.785,
          1220.1760000000002,
          1192.521,
          1164.8210000000001,
          1137.077,
          1109.292,
          1081.465,
          1053.6,
          1025.6960000000001,
          997.755,
          969.778,
          941.768,
          913.7239999999999,
          885.6489999999999,
          857.543,
          829.408,
          801.2439999999999,
          773.054,
          744.8389999999999,
          716.5980000000001,
          688.335,
          660.05,
          631.744,
          603.418,
          575.0740000000001,
          546.7130000000001,
          518.336,
          489.94300000000004,
          461.537,
          433.119,
          404.689,
          376.24800000000005,
          347.798,
          319.341,
          290.876,
          262.406,
          233.93099999999998,
          205.452,
          176.97099999999998,
          148.489,
          120.006,
          91.525,
          63.045,
          34.569,
          6.097,
          -22.37,
          -50.83,
          -79.283,
          -107.727,
          -136.162,
          -164.585,
          -192.99599999999998,
          -221.395,
          -249.77900000000002,
          -278.14799999999997,
          -306.5,
          -334.835,
          -363.152,
          -391.44800000000004,
          -419.724,
          -447.978,
          -476.209,
          -504.415,
          -532.597,
          -560.752,
          -588.879,
          -616.9780000000001,
          -645.047,
          -673.085,
          -701.091,
          -729.064,
          -757.002,
          -784.905,
          -812.7710000000001,
          -840.6,
          -868.3889999999999,
          -896.138,
          -923.846,
          -951.512,
          -979.1339999999999,
          -1006.711,
          -1034.241,
          -1061.725,
          -1089.16,
          -1116.545,
          -1143.879,
          -1171.162,
          -1198.39,
          -1225.5639999999999,
          -1252.682,
          -1279.743,
          -1306.745,
          -1333.6870000000001,
          -1360.569,
          -1387.388,
          -1414.1429999999998,
          -1440.8329999999999,
          -1467.4560000000001,
          -1494.0120000000002,
          -1520.499,
          -1546.915,
          -1573.259,
          -1599.53,
          -1625.726,
          -1651.8470000000002,
          -1677.889,
          -1703.852,
          -1729.735,
          -1755.536,
          -1781.253,
          -1806.885,
          -1832.431,
          -1857.888,
          -1883.256,
          -1908.5320000000002,
          -1933.715,
          -1958.8039999999999,
          -1983.796,
          -2008.691,
          -2033.486,
          -2058.18,
          -2082.77,
          -2107.256,
          -2131.636,
          -2155.907,
          -2180.067,
          -2204.116,
          -2228.051,
          -2251.87,
          -2275.571,
          -2299.153,
          -2322.613,
          -2345.949,
          -2369.16,
          -2392.243,
          -2415.195,
          -2438.016,
          -2460.703,
          -2483.2529999999997,
          -2505.665,
          -2527.935,
          -2550.063,
          -2572.045,
          -2593.879,
          -2615.563,
          -2637.093,
          -2658.469,
          -2679.6859999999997,
          -2700.743,
          -2721.637,
          -2742.365,
          -2762.925,
          -2783.313,
          -2803.527,
          -2823.565,
          -2843.422,
          -2863.0959999999995,
          -2882.5840000000003,
          -2901.883,
          -2920.99,
          -2939.901,
          -2958.613,
          -2977.123,
          -2995.428,
          -3013.5229999999997,
          -3031.406,
          -3049.072,
          -3066.518,
          -3083.74,
          -3100.7340000000004,
          -3117.4959999999996,
          -3134.0229999999997,
          -3150.31,
          -3166.3520000000003,
          -3182.1459999999997,
          -3197.6859999999997,
          -3212.969,
          -3227.99,
          -3242.744,
          -3257.2259999999997,
          -3271.4309999999996,
          -3285.3540000000003,
          -3298.99,
          -3312.3340000000003,
          -3325.38,
          -3338.1220000000003,
          -3350.554,
          -3362.672,
          -3374.468,
          -3385.9359999999997,
          -3397.07,
          -3407.864,
          -3418.31,
          -3428.402,
          -3438.133,
          -3447.495,
          -3456.48,
          -3465.0820000000003,
          -3473.292,
          -3481.1020000000003,
          -3488.5040000000004,
          -3495.488,
          -3502.046,
          -3508.17,
          -3513.848,
          -3519.072,
          -3523.8309999999997,
          -3528.116,
          -3531.914,
          -3535.216,
          -3538.01,
          -3540.284,
          -3542.026,
          -3543.223,
          -3543.863,
          -3543.9320000000002,
          -3543.4159999999997,
          -3542.301,
          -3540.572,
          -3538.212,
          -3535.2070000000003,
          -3531.54,
          -3527.1940000000004,
          -3522.151,
          -3516.393,
          -3509.9,
          -3502.653,
          -3494.63,
          -3485.8109999999997,
          -3476.173,
          -3465.6929999999998,
          -3454.347,
          -3442.11,
          -3428.9570000000003,
          -3414.8579999999997,
          -3399.7870000000003,
          -3383.7140000000004,
          -3366.6090000000004,
          -3348.438,
          -3329.17,
          -3308.7690000000002,
          -3287.198,
          -3264.421,
          -3240.397,
          -3215.086,
          -3188.442,
          -3160.423,
          -3130.982,
          -3100.0679999999998,
          -3067.631,
          -3033.617,
          -2997.9709999999995,
          -2960.635,
          -2921.547,
          -2880.6440000000002,
          -2837.862,
          -2793.132,
          -2746.382,
          -2697.5409999999997,
          -2646.531,
          -2593.275,
          -2537.694,
          -2479.703,
          -2419.221,
          -2356.161,
          -2290.44,
          -2221.973,
          -2150.675,
          -2076.467,
          -1999.27,
          -1919.013,
          -1835.632,
          -1749.0729999999999,
          -1659.2939999999999,
          -1566.271,
          -1469.993,
          -1370.48,
          -1267.772,
          -1161.943,
          -1053.099,
          -941.385,
          -826.9860000000001,
          -710.128,
          -591.0790000000001,
          -470.151,
          -347.69,
          -224.076,
          -99.71799999999999,
          24.962,
          149.53,
          273.553,
          396.61300000000006,
          518.31,
          638.273,
          756.1669999999999,
          871.696,
          984.6030000000001,
          1094.68,
          1201.755,
          1305.6989999999998,
          1406.4170000000001,
          1503.852,
          1597.971,
          1688.7720000000002,
          1776.2679999999998,
          1860.4979999999998,
          1941.509,
          2019.3629999999998,
          2094.131,
          2165.89,
          2234.722,
          2300.7129999999997,
          2363.948,
          2424.518,
          2482.508,
          2538.009,
          2591.103,
          2641.8759999999997,
          2690.41,
          2736.783,
          2781.075,
          2823.357,
          2863.703,
          2902.1809999999996,
          2938.8590000000004,
          2973.798,
          3007.062,
          3038.708,
          3068.7940000000003,
          3097.3720000000003,
          3124.493,
          3150.208,
          3174.565,
          3197.607,
          3219.3790000000004,
          3239.921,
          3259.275,
          3277.4770000000003,
          3294.565,
          3310.572,
          3325.533,
          3339.48,
          3352.4429999999998,
          3364.453,
          3375.5359999999996,
          3385.722,
          3395.035,
          3403.5,
          3411.143,
          3417.987,
          3424.052,
          3429.362,
          3433.9359999999997,
          3437.795,
          3440.9570000000003,
          3443.442,
          3445.2659999999996,
          3446.448,
          3447.0040000000004,
          3446.949,
          3446.3,
          3445.07,
          3443.275,
          3440.928,
          3438.042,
          3434.632,
          3430.7090000000003,
          3426.285,
          3421.373,
          3415.9840000000004,
          3410.1279999999997,
          3403.817,
          3397.06,
          3389.869,
          3382.252,
          3374.22,
          3365.781,
          3356.9429999999998,
          3347.717,
          3338.111,
          3328.132,
          3317.788,
          3307.0879999999997,
          3296.039,
          3284.647,
          3272.921,
          3260.867,
          3248.492,
          3235.802,
          3222.804,
          3209.5040000000004,
          3195.908,
          3182.022,
          3167.8520000000003,
          3153.403,
          3138.6809999999996,
          3123.691,
          3108.4390000000003,
          3092.929,
          3077.167,
          3061.157,
          3044.905,
          3028.414,
          3011.69,
          2994.736,
          2977.558,
          2960.159,
          2942.5429999999997,
          2924.715,
          2906.678,
          2888.437,
          2869.995,
          2851.355,
          2832.5229999999997,
          2813.5,
          2794.2909999999997,
          2774.8990000000003,
          2755.328,
          2735.58,
          2715.659,
          2695.5679999999998,
          2675.31,
          2654.888,
          2634.3059999999996,
          2613.565,
          2592.67,
          2571.6220000000003,
          2550.425,
          2529.0820000000003,
          2507.594,
          2485.965,
          2464.197,
          2442.2929999999997,
          2420.255,
          2398.0860000000002,
          2375.788,
          2353.364,
          2330.815,
          2308.144,
          2285.354,
          2262.446,
          2239.423,
          2216.286,
          2193.0389999999998,
          2169.683,
          2146.22,
          2122.652,
          2098.981,
          2075.21,
          2051.339,
          2027.372,
          2003.309,
          1979.1529999999998,
          1954.905,
          1930.568,
          1906.1429999999998,
          1881.632,
          1857.036,
          1832.358,
          1807.599,
          1782.76,
          1757.844,
          1732.852,
          1707.785,
          1682.645,
          1657.434,
          1632.1529999999998,
          1606.805,
          1581.389,
          1555.908,
          1530.364,
          1504.757,
          1479.089,
          1453.362,
          1427.578,
          1401.736,
          1375.84,
          1349.889,
          1323.8870000000002,
          1297.833,
          1271.729,
          1245.578,
          1219.379,
          1193.134,
          1166.845,
          1140.513,
          1114.138,
          1087.723,
          1061.269,
          1034.777,
          1008.247,
          981.682,
          955.082,
          928.449,
          901.784,
          875.0880000000001,
          848.363,
          821.6080000000001,
          794.827,
          768.0189999999999,
          741.186,
          714.329,
          687.449,
          660.548,
          633.626,
          606.685,
          579.725,
          552.748,
          525.755,
          498.74699999999996,
          471.725,
          444.69,
          417.644,
          390.587,
          363.52,
          336.445,
          309.363,
          282.274,
          255.18,
          228.082,
          200.98,
          173.877,
          146.77200000000002,
          119.66799999999999,
          92.564,
          65.46300000000001,
          38.365,
          11.270999999999999,
          -15.817,
          -42.898999999999994,
          -69.97399999999999,
          -97.04,
          -124.09700000000001,
          -151.143,
          -178.178,
          -205.2,
          -232.208,
          -259.202,
          -286.18,
          -313.14099999999996,
          -340.084,
          -367.00800000000004,
          -393.912,
          -420.79400000000004,
          -447.655,
          -474.49300000000005,
          -501.306,
          -528.094,
          -554.855,
          -581.589,
          -608.294,
          -634.97,
          -661.6139999999999,
          -688.227,
          -714.807,
          -741.3530000000001,
          -767.8639999999999,
          -794.3380000000001,
          -820.775,
          -847.173,
          -873.5319999999999,
          -899.85,
          -926.1260000000001,
          -952.3580000000001,
          -978.547,
          -1004.69,
          -1030.786,
          -1056.835,
          -1082.835,
          -1108.7839999999999,
          -1134.682,
          -1160.528,
          -1186.32,
          -1212.056,
          -1237.737,
          -1263.36,
          -1288.924,
          -1314.4279999999999,
          -1339.871,
          -1365.251,
          -1390.567,
          -1415.818,
          -1441.0020000000002,
          -1466.119,
          -1491.1660000000002,
          -1516.142,
          -1541.047,
          -1565.878,
          -1590.634,
          -1615.3139999999999,
          -1639.9160000000002,
          -1664.44,
          -1688.882,
          -1713.243,
          -1737.52,
          -1761.711,
          -1785.817,
          -1809.8339999999998,
          -1833.761,
          -1857.596,
          -1881.339,
          -1904.987,
          -1928.539,
          -1951.993,
          -1975.3470000000002,
          -1998.6,
          -2021.75,
          -2044.795,
          -2067.7329999999997,
          -2090.563,
          -2113.282,
          -2135.89,
          -2158.383,
          -2180.76,
          -2203.019,
          -2225.159,
          -2247.176,
          -2269.069,
          -2290.837,
          -2312.476,
          -2333.984,
          -2355.361,
          -2376.6020000000003,
          -2397.7070000000003,
          -2418.672,
          -2439.496,
          -2460.175,
          -2480.709,
          -2501.094,
          -2521.327,
          -2541.407,
          -2561.33,
          -2581.094,
          -2600.697,
          -2620.135,
          -2639.406,
          -2658.507,
          -2677.435,
          -2696.188,
          -2714.761,
          -2733.153,
          -2751.36,
          -2769.3790000000004,
          -2787.2059999999997,
          -2804.8379999999997,
          -2822.2729999999997,
          -2839.506,
          -2856.534,
          -2873.353,
          -2889.96,
          -2906.3520000000003,
          -2922.5229999999997,
          -2938.4709999999995,
          -2954.191,
          -2969.679,
          -2984.9309999999996,
          -2999.9429999999998,
          -3014.71,
          -3029.228,
          -3043.493,
          -3057.498,
          -3071.241,
          -3084.715,
          -3097.9159999999997,
          -3110.8390000000004,
          -3123.478,
          -3135.828,
          -3147.883,
          -3159.637,
          -3171.085,
          -3182.2209999999995,
          -3193.038,
          -3203.53,
          -3213.69,
          -3223.512,
          -3232.99,
          -3242.115,
          -3250.881,
          -3259.2790000000005,
          -3267.303,
          -3274.9440000000004,
          -3282.195,
          -3289.046,
          -3295.489,
          -3301.5159999999996,
          -3307.116,
          -3312.28,
          -3317,
          -3321.263,
          -3325.0609999999997,
          -3328.382,
          -3331.2140000000004,
          -3333.548,
          -3335.3709999999996,
          -3336.67,
          -3337.433,
          -3337.6459999999997,
          -3337.297,
          -3336.3709999999996,
          -3334.853,
          -3332.728,
          -3329.9809999999998,
          -3326.595,
          -3322.554,
          -3317.841,
          -3312.4359999999997,
          -3306.323,
          -3299.4790000000003,
          -3291.887,
          -3283.5240000000003,
          -3274.368,
          -3264.397,
          -3253.587,
          -3241.913,
          -3229.35,
          -3215.8709999999996,
          -3201.449,
          -3186.052,
          -3169.653,
          -3152.217,
          -3133.7140000000004,
          -3114.1090000000004,
          -3093.366,
          -3071.446,
          -3048.31,
          -3023.9190000000003,
          -2998.2290000000003,
          -2971.196,
          -2942.7729999999997,
          -2912.9109999999996,
          -2881.559,
          -2848.665,
          -2814.173,
          -2778.025,
          -2740.1609999999996,
          -2700.5190000000002,
          -2659.034,
          -2615.637,
          -2570.26,
          -2522.8289999999997,
          -2473.27,
          -2421.506,
          -2367.458,
          -2311.0460000000003,
          -2252.187,
          -2190.802,
          -2126.805,
          -2060.119,
          -1990.6629999999998,
          -1918.36,
          -1843.142,
          -1764.942,
          -1683.7089999999998,
          -1599.395,
          -1511.975,
          -1421.434,
          -1327.785,
          -1231.06,
          -1131.3210000000001,
          -1028.665,
          -923.2189999999999,
          -815.154,
          -704.677,
          -592.034,
          -477.515,
          -361.445,
          -244.178,
          -126.09899999999999,
          -7.608,
          110.883,
          228.96400000000003,
          346.23199999999997,
          462.30400000000003,
          576.823,
          689.462,
          799.934,
          907.9910000000001,
          1013.421,
          1116.057,
          1215.767,
          1312.4579999999999,
          1406.0639999999999,
          1496.55,
          1583.908,
          1668.146,
          1749.297,
          1827.4,
          1902.514,
          1974.6989999999998,
          2044.029,
          2110.578,
          2174.425,
          2235.653,
          2294.343,
          2350.578,
          2404.44,
          2456.008,
          2505.468,
          2552.583,
          2597.741,
          2640.91,
          2682.163,
          2721.565,
          2759.1820000000002,
          2795.079,
          2829.315,
          2861.948,
          2893.033,
          2922.625,
          2950.775,
          2977.532,
          3002.942,
          3027.05,
          3049.901,
          3071.534,
          3091.99,
          3111.3059999999996,
          3129.5190000000002,
          3146.663,
          3162.7709999999997,
          3177.877,
          3192.009,
          3205.198,
          3217.472,
          3228.8579999999997,
          3239.381,
          3249.066,
          3257.9390000000003,
          3266.0209999999997,
          3273.335,
          3279.903,
          3285.744,
          3290.8779999999997,
          3295.325,
          3299.103,
          3302.228,
          3304.719,
          3306.592,
          3307.863,
          3308.546,
          3308.658,
          3308.211,
          3307.219,
          3305.697,
          3303.657,
          3301.11,
          3298.07,
          3294.547,
          3290.555,
          3286.1020000000003,
          3281.2,
          3275.8590000000004,
          3270.0879999999997,
          3263.8990000000003,
          3257.2990000000004,
          3250.298,
          3242.9040000000005,
          3235.127,
          3226.975,
          3218.455,
          3209.5759999999996,
          3200.344,
          3190.768,
          3180.855,
          3170.611,
          3160.0429999999997,
          3149.159,
          3137.965,
          3126.466,
          3114.6690000000003,
          3102.58,
          3090.205,
          3077.55,
          3064.619,
          3051.4190000000003,
          3037.954,
          3024.23,
          3010.2509999999997,
          2996.0229999999997,
          2981.551,
          2966.8379999999997,
          2951.89,
          2936.711,
          2921.3059999999996,
          2905.678,
          2889.8320000000003,
          2873.7709999999997,
          2857.5009999999997,
          2841.0240000000003,
          2824.344,
          2807.466,
          2790.3920000000003,
          2773.127,
          2755.6740000000004,
          2738.0359999999996,
          2720.216,
          2702.219,
          2684.047,
          2665.703,
          2647.191,
          2628.513,
          2609.672,
          2590.672,
          2571.515,
          2552.2039999999997,
          2532.742,
          2513.131,
          2493.375,
          2473.475,
          2453.4339999999997,
          2433.255,
          2412.94,
          2392.492,
          2371.9139999999998,
          2351.206,
          2330.373,
          2309.415,
          2288.3360000000002,
          2267.137,
          2245.82,
          2224.389,
          2202.844,
          2181.188,
          2159.423,
          2137.551,
          2115.574,
          2093.494,
          2071.312,
          2049.031,
          2026.652,
          2004.1779999999999,
          1981.61,
          1958.95,
          1936.1989999999998,
          1913.359,
          1890.433,
          1867.421,
          1844.326,
          1821.149,
          1797.891,
          1774.555,
          1751.141,
          1727.652,
          1704.089,
          1680.453,
          1656.746,
          1632.97,
          1609.125,
          1585.214,
          1561.237,
          1537.1970000000001,
          1513.094,
          1488.931,
          1464.707,
          1440.4260000000002,
          1416.0870000000002,
          1391.693,
          1367.244,
          1342.7420000000002,
          1318.1889999999999,
          1293.585,
          1268.932,
          1244.231,
          1219.484,
          1194.691,
          1169.854,
          1144.973,
          1120.0510000000002,
          1095.089,
          1070.087,
          1045.047,
          1019.9689999999999,
          994.8560000000001,
          969.7080000000001,
          944.5260000000001,
          919.312,
          894.066,
          868.79,
          843.485,
          818.1519999999999,
          792.7919999999999,
          767.4060000000001,
          741.9960000000001,
          716.561,
          691.1039999999999,
          665.6260000000001,
          640.127,
          614.6080000000001,
          589.071,
          563.5169999999999,
          537.947,
          512.361,
          486.76099999999997,
          461.147,
          435.522,
          409.885,
          384.23900000000003,
          358.583,
          332.91900000000004,
          307.248,
          281.57099999999997,
          255.889,
          230.202,
          204.513,
          178.822,
          153.129,
          127.43700000000001,
          101.745,
          76.055,
          50.368,
          24.686,
          -0.992,
          -26.664,
          -52.33,
          -77.987,
          -103.635,
          -129.274,
          -154.901,
          -180.517,
          -206.12,
          -231.709,
          -257.283,
          -282.841,
          -308.383,
          -333.906,
          -359.411,
          -384.89599999999996,
          -410.35900000000004,
          -435.801,
          -461.22,
          -486.615,
          -511.985,
          -537.3290000000001,
          -562.646,
          -587.935,
          -613.194,
          -638.424,
          -663.622,
          -688.788,
          -713.92,
          -739.0189999999999,
          -764.081,
          -789.107,
          -814.096,
          -839.045,
          -863.955,
          -888.824,
          -913.6510000000001,
          -938.434,
          -963.174,
          -987.868,
          -1012.515,
          -1037.115,
          -1061.665,
          -1086.1660000000002,
          -1110.615,
          -1135.012,
          -1159.356,
          -1183.644,
          -1207.877,
          -1232.052,
          -1256.1689999999999,
          -1280.226,
          -1304.222,
          -1328.156,
          -1352.026,
          -1375.832,
          -1399.5710000000001,
          -1423.243,
          -1446.846,
          -1470.378,
          -1493.84,
          -1517.2279999999998,
          -1540.5420000000001,
          -1563.78,
          -1586.941,
          -1610.024,
          -1633.026,
          -1655.9470000000001,
          -1678.785,
          -1701.539,
          -1724.2060000000001,
          -1746.786,
          -1769.276,
          -1791.6760000000002,
          -1813.983,
          -1836.1970000000001,
          -1858.3139999999999,
          -1880.335,
          -1902.256,
          -1924.076,
          -1945.7939999999999,
          -1967.4070000000002,
          -1988.915,
          -2010.3139999999999,
          -2031.6029999999998,
          -2052.781,
          -2073.845,
          -2094.7929999999997,
          -2115.624,
          -2136.3360000000002,
          -2156.925,
          -2177.391,
          -2197.732,
          -2217.944,
          -2238.027,
          -2257.9770000000003,
          -2277.792,
          -2297.471,
          -2317.01,
          -2336.408,
          -2355.6620000000003,
          -2374.769,
          -2393.7270000000003,
          -2412.534,
          -2431.187,
          -2449.683,
          -2468.02,
          -2486.194,
          -2504.2039999999997,
          -2522.045,
          -2539.716,
          -2557.2129999999997,
          -2574.533,
          -2591.673,
          -2608.631,
          -2625.402,
          -2641.9829999999997,
          -2658.3720000000003,
          -2674.5640000000003,
          -2690.5559999999996,
          -2706.344,
          -2721.926,
          -2737.297,
          -2752.452,
          -2767.39,
          -2782.1040000000003,
          -2796.592,
          -2810.849,
          -2824.87,
          -2838.652,
          -2852.1890000000003,
          -2865.478,
          -2878.512,
          -2891.289,
          -2903.801,
          -2916.046,
          -2928.0159999999996,
          -2939.708,
          -2951.115,
          -2962.2309999999998,
          -2973.051,
          -2983.57,
          -2993.78,
          -3003.675,
          -3013.2490000000003,
          -3022.4959999999996,
          -3031.408,
          -3039.978,
          -3048.199,
          -3056.065,
          -3063.566,
          -3070.695,
          -3077.4440000000004,
          -3083.805,
          -3089.768,
          -3095.3259999999996,
          -3100.468,
          -3105.185,
          -3109.467,
          -3113.305,
          -3116.687,
          -3119.6040000000003,
          -3122.0440000000003,
          -3123.995,
          -3125.445,
          -3126.382,
          -3126.7929999999997,
          -3126.6659999999997,
          -3125.985,
          -3124.738,
          -3122.909,
          -3120.4829999999997,
          -3117.4440000000004,
          -3113.776,
          -3109.461,
          -3104.4829999999997,
          -3098.823,
          -3092.461,
          -3085.3779999999997,
          -3077.553,
          -3068.9640000000004,
          -3059.59,
          -3049.406,
          -3038.39,
          -3026.514,
          -3013.7529999999997,
          -3000.08,
          -2985.467,
          -2969.883,
          -2953.296,
          -2935.675,
          -2916.986,
          -2897.1929999999998,
          -2876.258,
          -2854.1440000000002,
          -2830.8109999999997,
          -2806.215,
          -2780.312,
          -2753.0570000000002,
          -2724.402,
          -2694.295,
          -2662.685,
          -2629.518,
          -2594.735,
          -2558.278,
          -2520.084,
          -2480.089,
          -2438.2270000000003,
          -2394.43,
          -2348.624,
          -2300.737,
          -2250.694,
          -2198.417,
          -2143.8289999999997,
          -2086.85,
          -2027.402,
          -1965.406,
          -1900.7839999999999,
          -1833.463,
          -1763.375,
          -1690.453,
          -1614.645,
          -1535.905,
          -1454.1979999999999,
          -1369.5120000000002,
          -1281.85,
          -1191.235,
          -1097.724,
          -1001.398,
          -902.3710000000001,
          -800.796,
          -696.863,
          -590.799,
          -482.86699999999996,
          -373.37199999999996,
          -262.644,
          -151.041,
          -38.942,
          73.267,
          185.19400000000002,
          296.45799999999997,
          406.691,
          515.5509999999999,
          622.7230000000001,
          727.928,
          830.923,
          931.502,
          1029.497,
          1124.778,
          1217.247,
          1306.836,
          1393.509,
          1477.249,
          1558.06,
          1635.9679999999998,
          1711.0079999999998,
          1783.227,
          1852.6860000000001,
          1919.4460000000001,
          1983.578,
          2045.154,
          2104.251,
          2160.9429999999998,
          2215.3089999999997,
          2267.424,
          2317.364,
          2365.202,
          2411.012,
          2454.864,
          2496.826,
          2536.965,
          2575.344,
          2612.026,
          2647.0690000000004,
          2680.532,
          2712.469,
          2742.9309999999996,
          2771.9709999999995,
          2799.636,
          2825.974,
          2851.027,
          2874.84,
          2897.452,
          2918.903,
          2939.23,
          2958.469,
          2976.655,
          2993.821,
          3009.9970000000003,
          3025.215,
          3039.5040000000004,
          3052.8909999999996,
          3065.402,
          3077.065,
          3087.903,
          3097.941,
          3107.2,
          3115.704,
          3123.472,
          3130.525,
          3136.884,
          3142.565,
          3147.5879999999997,
          3151.97,
          3155.728,
          3158.8779999999997,
          3161.435,
          3163.415,
          3164.8320000000003,
          3165.7009999999996,
          3166.034,
          3165.845,
          3165.147,
          3163.9509999999996,
          3162.27,
          3160.115,
          3157.498,
          3154.428,
          3150.9159999999997,
          3146.973,
          3142.6079999999997,
          3137.83,
          3132.65,
          3127.075,
          3121.114,
          3114.777,
          3108.07,
          3101.002,
          3093.5809999999997,
          3085.813,
          3077.7070000000003,
          3069.2690000000002,
          3060.506,
          3051.425,
          3042.033,
          3032.335,
          3022.337,
          3012.047,
          3001.469,
          2990.61,
          2979.474,
          2968.0679999999998,
          2956.3959999999997,
          2944.4640000000004,
          2932.276,
          2919.8379999999997,
          2907.1540000000005,
          2894.23,
          2881.0690000000004,
          2867.676,
          2854.0559999999996,
          2840.212,
          2826.1490000000003,
          2811.8709999999996,
          2797.382,
          2782.685,
          2767.785,
          2752.685,
          2737.389,
          2721.9,
          2706.222,
          2690.3579999999997,
          2674.312,
          2658.087,
          2641.685,
          2625.111,
          2608.367,
          2591.456,
          2574.382,
          2557.146,
          2539.7529999999997,
          2522.2039999999997,
          2504.5029999999997,
          2486.651,
          2468.653,
          2450.51,
          2432.225,
          2413.8,
          2395.238,
          2376.541,
          2357.712,
          2338.752,
          2319.665,
          2300.452,
          2281.116,
          2261.659,
          2242.083,
          2222.389,
          2202.581,
          2182.66,
          2162.6279999999997,
          2142.487,
          2122.239,
          2101.886,
          2081.429,
          2060.8720000000003,
          2040.215,
          2019.46,
          1998.609,
          1977.664,
          1956.626,
          1935.497,
          1914.28,
          1892.975,
          1871.5839999999998,
          1850.109,
          1828.5510000000002,
          1806.912,
          1785.193,
          1763.3970000000002,
          1741.523,
          1719.575,
          1697.5529999999999,
          1675.4589999999998,
          1653.295,
          1631.0610000000001,
          1608.759,
          1586.39,
          1563.9560000000001,
          1541.4589999999998,
          1518.899,
          1496.2779999999998,
          1473.5970000000002,
          1450.8570000000002,
          1428.06,
          1405.2079999999999,
          1382.3,
          1359.339,
          1336.325,
          1313.261,
          1290.146,
          1266.983,
          1243.772,
          1220.515,
          1197.213,
          1173.867,
          1150.478,
          1127.047,
          1103.576,
          1080.065,
          1056.516,
          1032.93,
          1009.307,
          985.6489999999999,
          961.957,
          938.232,
          914.4760000000001,
          890.688,
          866.8710000000001,
          843.0239999999999,
          819.15,
          795.25,
          771.323,
          747.372,
          723.398,
          699.4,
          675.3810000000001,
          651.342,
          627.283,
          603.205,
          579.109,
          554.996,
          530.868,
          506.725,
          482.569,
          458.399,
          434.218,
          410.025,
          385.82300000000004,
          361.61199999999997,
          337.392,
          313.166,
          288.933,
          264.695,
          240.453,
          216.208,
          191.96,
          167.71,
          143.461,
          119.211,
          94.963,
          70.717,
          46.475,
          22.236,
          -1.9969999999999999,
          -26.224,
          -50.443999999999996,
          -74.656,
          -98.86,
          -123.054,
          -147.236,
          -171.408,
          -195.56599999999997,
          -219.71099999999998,
          -243.84099999999998,
          -267.95599999999996,
          -292.055,
          -316.13599999999997,
          -340.199,
          -364.24199999999996,
          -388.265,
          -412.267,
          -436.24699999999996,
          -460.204,
          -484.13599999999997,
          -508.043,
          -531.925,
          -555.779,
          -579.605,
          -603.401,
          -627.168,
          -650.904,
          -674.607,
          -698.2769999999999,
          -721.913,
          -745.5139999999999,
          -769.079,
          -792.6060000000001,
          -816.095,
          -839.544,
          -862.953,
          -886.32,
          -909.645,
          -932.926,
          -956.1619999999999,
          -979.352,
          -1002.495,
          -1025.59,
          -1048.635,
          -1071.63,
          -1094.5739999999998,
          -1117.464,
          -1140.3010000000002,
          -1163.0819999999999,
          -1185.807,
          -1208.475,
          -1231.083,
          -1253.632,
          -1276.119,
          -1298.5439999999999,
          -1320.905,
          -1343.201,
          -1365.43,
          -1387.5910000000001,
          -1409.684,
          -1431.7060000000001,
          -1453.656,
          -1475.5339999999999,
          -1497.336,
          -1519.0629999999999,
          -1540.7120000000002,
          -1562.2820000000002,
          -1583.7720000000002,
          -1605.181,
          -1626.505,
          -1647.746,
          -1668.899,
          -1689.965,
          -1710.941,
          -1731.826,
          -1752.618,
          -1773.316,
          -1793.918,
          -1814.422,
          -1834.826,
          -1855.129,
          -1875.329,
          -1895.424,
          -1915.412,
          -1935.2920000000001,
          -1955.0610000000001,
          -1974.7179999999998,
          -1994.26,
          -2013.6860000000001,
          -2032.993,
          -2052.18,
          -2071.244,
          -2090.1839999999997,
          -2108.996,
          -2127.679,
          -2146.231,
          -2164.65,
          -2182.9320000000002,
          -2201.076,
          -2219.0789999999997,
          -2236.938,
          -2254.652,
          -2272.218,
          -2289.632,
          -2306.893,
          -2323.998,
          -2340.9429999999998,
          -2357.7270000000003,
          -2374.345,
          -2390.7960000000003,
          -2407.076,
          -2423.1820000000002,
          -2439.111,
          -2454.86,
          -2470.425,
          -2485.803,
          -2500.992,
          -2515.986,
          -2530.783,
          -2545.379,
          -2559.77,
          -2573.953,
          -2587.923,
          -2601.676,
          -2615.209,
          -2628.5170000000003,
          -2641.5959999999995,
          -2654.441,
          -2667.048,
          -2679.4120000000003,
          -2691.528,
          -2703.3920000000003,
          -2714.9990000000003,
          -2726.344,
          -2737.42,
          -2748.223,
          -2758.7470000000003,
          -2768.986,
          -2778.935,
          -2788.5879999999997,
          -2797.937,
          -2806.978,
          -2815.702,
          -2824.1040000000003,
          -2832.177,
          -2839.913,
          -2847.305,
          -2854.345,
          -2861.025,
          -2867.3379999999997,
          -2873.275,
          -2878.827,
          -2883.986,
          -2888.742,
          -2893.085,
          -2897.007,
          -2900.4970000000003,
          -2903.5440000000003,
          -2906.139,
          -2908.268,
          -2909.922,
          -2911.0879999999997,
          -2911.7529999999997,
          -2911.905,
          -2911.531,
          -2910.616,
          -2909.147,
          -2907.1090000000004,
          -2904.485,
          -2901.261,
          -2897.4190000000003,
          -2892.942,
          -2887.8140000000003,
          -2882.014,
          -2875.5240000000003,
          -2868.323,
          -2860.39,
          -2851.704,
          -2842.242,
          -2831.98,
          -2820.8940000000002,
          -2808.9559999999997,
          -2796.1409999999996,
          -2782.421,
          -2767.7670000000003,
          -2752.1479999999997,
          -2735.531,
          -2717.884,
          -2699.172,
          -2679.3579999999997,
          -2658.405,
          -2636.2709999999997,
          -2612.916,
          -2588.298,
          -2562.369,
          -2535.084,
          -2506.391,
          -2476.239,
          -2444.575,
          -2411.343,
          -2376.484,
          -2339.937,
          -2301.637,
          -2261.522,
          -2219.522,
          -2175.5679999999998,
          -2129.5879999999997,
          -2081.507,
          -2031.253,
          -1978.749,
          -1923.918,
          -1866.685,
          -1806.977,
          -1744.721,
          -1679.8470000000002,
          -1612.295,
          -1542.0079999999998,
          -1468.9379999999999,
          -1393.0529999999999,
          -1314.332,
          -1232.772,
          -1148.392,
          -1061.236,
          -971.375,
          -878.909,
          -783.9739999999999,
          -686.742,
          -587.418,
          -486.245,
          -383.50199999999995,
          -279.495,
          -174.558,
          -69.043,
          36.684,
          142.257,
          247.312,
          351.50199999999995,
          454.49800000000005,
          555.997,
          655.73,
          753.462,
          848.99,
          942.15,
          1032.81,
          1120.873,
          1206.267,
          1288.9489999999998,
          1368.901,
          1446.1229999999998,
          1520.628,
          1592.451,
          1661.631,
          1728.22,
          1792.275,
          1853.86,
          1913.0410000000002,
          1969.886,
          2024.4660000000001,
          2076.8520000000003,
          2127.115,
          2175.323,
          2221.548,
          2265.856,
          2308.313,
          2348.9829999999997,
          2387.927,
          2425.206,
          2460.8779999999997,
          2494.998,
          2527.62,
          2558.795,
          2588.573,
          2617.002,
          2644.127,
          2669.992,
          2694.638,
          2718.1059999999998,
          2740.4320000000002,
          2761.657,
          2781.8140000000003,
          2800.937,
          2819.059,
          2836.21,
          2852.421,
          2867.72,
          2882.134,
          2895.691,
          2908.414,
          2920.329,
          2931.458,
          2941.8259999999996,
          2951.4509999999996,
          2960.357,
          2968.562,
          2976.085,
          2982.945,
          2989.16,
          2994.7470000000003,
          2999.723,
          3004.1020000000003,
          3007.901,
          3011.135,
          3013.817,
          3015.962,
          3017.583,
          3018.692,
          3019.303,
          3019.426,
          3019.074,
          3018.258,
          3016.989,
          3015.277,
          3013.133,
          3010.566,
          3007.585,
          3004.2009999999996,
          3000.422,
          2996.257,
          2991.7140000000004,
          2986.801,
          2981.528,
          2975.9,
          2969.926,
          2963.613,
          2956.968,
          2949.9990000000003,
          2942.71,
          2935.111,
          2927.205,
          2919.0009999999997,
          2910.5029999999997,
          2901.717,
          2892.65,
          2883.3070000000002,
          2873.6929999999998,
          2863.8140000000003,
          2853.6740000000004,
          2843.278,
          2832.633,
          2821.741,
          2810.6090000000004,
          2799.24,
          2787.639,
          2775.81,
          2763.758,
          2751.486,
          2738.998,
          2726.3,
          2713.3940000000002,
          2700.284,
          2686.974,
          2673.467,
          2659.768,
          2645.8790000000004,
          2631.803,
          2617.545,
          2603.1079999999997,
          2588.494,
          2573.706,
          2558.749,
          2543.624,
          2528.334,
          2512.883,
          2497.274,
          2481.508,
          2465.589,
          2449.52,
          2433.302,
          2416.939,
          2400.433,
          2383.7870000000003,
          2367.002,
          2350.0820000000003,
          2333.028,
          2315.843,
          2298.529,
          2281.089,
          2263.524,
          2245.8360000000002,
          2228.029,
          2210.103,
          2192.061,
          2173.905,
          2155.636,
          2137.257,
          2118.77,
          2100.176,
          2081.478,
          2062.677,
          2043.774,
          2024.7720000000002,
          2005.6729999999998,
          1986.4779999999998,
          1967.1879999999999,
          1947.806,
          1928.3329999999999,
          1908.77,
          1889.12,
          1869.384,
          1849.5629999999999,
          1829.6589999999999,
          1809.6729999999998,
          1789.6070000000002,
          1769.463,
          1749.241,
          1728.944,
          1708.5720000000001,
          1688.1270000000002,
          1667.61,
          1647.024,
          1626.368,
          1605.645,
          1584.855,
          1564,
          1543.082,
          1522.101,
          1501.059,
          1479.9579999999999,
          1458.797,
          1437.579,
          1416.3039999999999,
          1394.975,
          1373.5910000000001,
          1352.155,
          1330.6670000000001,
          1309.128,
          1287.5410000000002,
          1265.905,
          1244.221,
          1222.492,
          1200.718,
          1178.9,
          1157.039,
          1135.136,
          1113.193,
          1091.21,
          1069.1889999999999,
          1047.13,
          1025.0339999999999,
          1002.903,
          980.738,
          958.539,
          936.307,
          914.044,
          891.75,
          869.427,
          847.075,
          824.696,
          802.29,
          779.8580000000001,
          757.4019999999999,
          734.921,
          712.418,
          689.893,
          667.347,
          644.781,
          622.195,
          599.591,
          576.97,
          554.3330000000001,
          531.68,
          509.01199999999994,
          486.33099999999996,
          463.63699999999994,
          440.931,
          418.214,
          395.486,
          372.75,
          350.005,
          327.253,
          304.494,
          281.73,
          258.96,
          236.187,
          213.41099999999997,
          190.632,
          167.852,
          145.072,
          122.292,
          99.514,
          76.738,
          53.965,
          31.195999999999998,
          8.431000000000001,
          -14.327,
          -37.079,
          -59.823,
          -82.559,
          -105.286,
          -128.003,
          -150.708,
          -173.40200000000002,
          -196.083,
          -218.75,
          -241.40200000000002,
          -264.039,
          -286.66,
          -309.263,
          -331.848,
          -354.414,
          -376.96,
          -399.48400000000004,
          -421.98699999999997,
          -444.467,
          -466.92400000000004,
          -489.355,
          -511.76099999999997,
          -534.14,
          -556.492,
          -578.815,
          -601.109,
          -623.372,
          -645.604,
          -667.804,
          -689.97,
          -712.102,
          -734.198,
          -756.2589999999999,
          -778.2810000000001,
          -800.265,
          -822.21,
          -844.115,
          -865.977,
          -887.798,
          -909.574,
          -931.306,
          -952.992,
          -974.6310000000001,
          -996.222,
          -1017.7639999999999,
          -1039.256,
          -1060.6960000000001,
          -1082.0839999999998,
          -1103.4180000000001,
          -1124.698,
          -1145.921,
          -1167.087,
          -1188.194,
          -1209.242,
          -1230.229,
          -1251.154,
          -1272.016,
          -1292.813,
          -1313.543,
          -1334.207,
          -1354.8020000000001,
          -1375.3270000000002,
          -1395.78,
          -1416.161,
          -1436.4679999999998,
          -1456.6989999999998,
          -1476.8529999999998,
          -1496.9289999999999,
          -1516.9260000000002,
          -1536.84,
          -1556.672,
          -1576.42,
          -1596.0810000000001,
          -1615.655,
          -1635.14,
          -1654.5339999999999,
          -1673.835,
          -1693.043,
          -1712.155,
          -1731.1689999999999,
          -1750.0839999999998,
          -1768.8970000000002,
          -1787.608,
          -1806.214,
          -1824.714,
          -1843.104,
          -1861.385,
          -1879.5529999999999,
          -1897.606,
          -1915.543,
          -1933.361,
          -1951.059,
          -1968.6329999999998,
          -1986.0829999999999,
          -2003.405,
          -2020.598,
          -2037.658,
          -2054.584,
          -2071.374,
          -2088.024,
          -2104.533,
          -2120.897,
          -2137.114,
          -2153.1820000000002,
          -2169.097,
          -2184.857,
          -2200.46,
          -2215.901,
          -2231.178,
          -2246.2889999999998,
          -2261.23,
          -2275.9970000000003,
          -2290.589,
          -2305,
          -2319.229,
          -2333.27,
          -2347.1220000000003,
          -2360.78,
          -2374.241,
          -2387.5,
          -2400.554,
          -2413.3979999999997,
          -2426.03,
          -2438.4429999999998,
          -2450.636,
          -2462.6020000000003,
          -2474.337,
          -2485.837,
          -2497.096,
          -2508.111,
          -2518.876,
          -2529.385,
          -2539.633,
          -2549.616,
          -2559.327,
          -2568.76,
          -2577.91,
          -2586.771,
          -2595.3360000000002,
          -2603.598,
          -2611.552,
          -2619.19,
          -2626.505,
          -2633.489,
          -2640.137,
          -2646.438,
          -2652.387,
          -2657.973,
          -2663.19,
          -2668.027,
          -2672.4759999999997,
          -2676.527,
          -2680.172,
          -2683.3990000000003,
          -2686.199,
          -2688.56,
          -2690.472,
          -2691.922,
          -2692.9,
          -2693.3920000000003,
          -2693.386,
          -2692.869,
          -2691.8259999999996,
          -2690.244,
          -2688.107,
          -2685.4,
          -2682.107,
          -2678.21,
          -2673.6940000000004,
          -2668.54,
          -2662.7290000000003,
          -2656.242,
          -2649.0570000000002,
          -2641.155,
          -2632.512,
          -2623.1059999999998,
          -2612.9120000000003,
          -2601.906,
          -2590.061,
          -2577.35,
          -2563.744,
          -2549.214,
          -2533.729,
          -2517.255,
          -2499.758,
          -2481.2039999999997,
          -2461.554,
          -2440.77,
          -2418.81,
          -2395.633,
          -2371.195,
          -2345.447,
          -2318.343,
          -2289.83,
          -2259.856,
          -2228.367,
          -2195.304,
          -2160.6079999999997,
          -2124.217,
          -2086.067,
          -2046.092,
          -2004.224,
          -1960.392,
          -1914.527,
          -1866.5539999999999,
          -1816.402,
          -1763.9979999999998,
          -1709.271,
          -1652.148,
          -1592.566,
          -1530.4620000000002,
          -1465.7779999999998,
          -1398.469,
          -1328.4979999999998,
          -1255.839,
          -1180.486,
          -1102.452,
          -1021.768,
          -938.4939999999999,
          -852.7189999999999,
          -764.561,
          -674.173,
          -581.74,
          -487.48400000000004,
          -391.658,
          -294.545,
          -196.452,
          -97.70700000000001,
          1.35,
          100.374,
          199.025,
          296.972,
          393.903,
          489.529,
          583.592,
          675.862,
          766.1439999999999,
          854.2769999999999,
          940.128,
          1023.5980000000001,
          1104.617,
          1183.136,
          1259.132,
          1332.595,
          1403.543,
          1471.995,
          1537.9879999999998,
          1601.566,
          1662.78,
          1721.6870000000001,
          1778.345,
          1832.817,
          1885.1689999999999,
          1935.465,
          1983.7679999999998,
          2030.144,
          2074.658,
          2117.369,
          2158.341,
          2197.632,
          2235.3,
          2271.4,
          2305.985,
          2339.11,
          2370.822,
          2401.1710000000003,
          2430.202,
          2457.959,
          2484.485,
          2509.822,
          2534.007,
          2557.08,
          2579.076,
          2600.029,
          2619.972,
          2638.937,
          2656.9559999999997,
          2674.055,
          2690.265,
          2705.611,
          2720.119,
          2733.815,
          2746.7209999999995,
          2758.862,
          2770.258,
          2780.9309999999996,
          2790.901,
          2800.187,
          2808.809,
          2816.784,
          2824.1290000000004,
          2830.862,
          2836.998,
          2842.553,
          2847.542,
          2851.98,
          2855.88,
          2859.256,
          2862.1209999999996,
          2864.487,
          2866.367,
          2867.772,
          2868.7129999999997,
          2869.202,
          2869.2490000000003,
          2868.864,
          2868.0570000000002,
          2866.8379999999997,
          2865.216,
          2863.2,
          2860.8,
          2858.022,
          2854.877,
          2851.37,
          2847.512,
          2843.308,
          2838.7659999999996,
          2833.893,
          2828.696,
          2823.183,
          2817.3579999999997,
          2811.23,
          2804.803,
          2798.0840000000003,
          2791.079,
          2783.7929999999997,
          2776.232,
          2768.401,
          2760.3059999999996,
          2751.952,
          2743.343,
          2734.4840000000004,
          2725.381,
          2716.038,
          2706.458,
          2696.6479999999997,
          2686.611,
          2676.3509999999997,
          2665.8720000000003,
          2655.178,
          2644.2740000000003,
          2633.163,
          2621.848,
          2610.334,
          2598.624,
          2586.721,
          2574.629,
          2562.3520000000003,
          2549.8920000000003,
          2537.252,
          2524.437,
          2511.448,
          2498.2889999999998,
          2484.9629999999997,
          2471.472,
          2457.82,
          2444.01,
          2430.0429999999997,
          2415.923,
          2401.652,
          2387.2329999999997,
          2372.6679999999997,
          2357.96,
          2343.111,
          2328.124,
          2313.001,
          2297.743,
          2282.354,
          2266.8360000000002,
          2251.1910000000003,
          2235.42,
          2219.527,
          2203.512,
          2187.3779999999997,
          2171.1279999999997,
          2154.762,
          2138.284,
          2121.694,
          2104.995,
          2088.188,
          2071.275,
          2054.259,
          2037.14,
          2019.921,
          2002.6029999999998,
          1985.1879999999999,
          1967.6770000000001,
          1950.0720000000001,
          1932.375,
          1914.588,
          1896.711,
          1878.746,
          1860.695,
          1842.559,
          1824.3410000000001,
          1806.04,
          1787.6589999999999,
          1769.1989999999998,
          1750.661,
          1732.047,
          1713.358,
          1694.596,
          1675.761,
          1656.856,
          1637.88,
          1618.8370000000002,
          1599.726,
          1580.549,
          1561.308,
          1542.003,
          1522.635,
          1503.207,
          1483.719,
          1464.172,
          1444.567,
          1424.906,
          1405.1889999999999,
          1385.418,
          1365.594,
          1345.7179999999998,
          1325.7910000000002,
          1305.8139999999999,
          1285.788,
          1265.714,
          1245.593,
          1225.4260000000002,
          1205.215,
          1184.96,
          1164.662,
          1144.323,
          1123.942,
          1103.522,
          1083.063,
          1062.566,
          1042.032,
          1021.462,
          1000.8580000000001,
          980.2189999999999,
          959.547,
          938.842,
          918.107,
          897.341,
          876.545,
          855.721,
          834.8689999999999,
          813.99,
          793.086,
          772.1560000000001,
          751.202,
          730.225,
          709.225,
          688.204,
          667.1619999999999,
          646.1,
          625.019,
          603.92,
          582.803,
          561.6709999999999,
          540.5219999999999,
          519.359,
          498.18199999999996,
          476.991,
          455.789,
          434.574,
          413.35,
          392.115,
          370.871,
          349.62,
          328.361,
          307.095,
          285.824,
          264.547,
          243.267,
          221.984,
          200.69799999999998,
          179.41,
          158.122,
          136.833,
          115.546,
          94.26,
          72.977,
          51.696999999999996,
          30.421,
          9.15,
          -12.115,
          -33.374,
          -54.625,
          -75.868,
          -97.102,
          -118.32600000000001,
          -139.539,
          -160.741,
          -181.93,
          -203.106,
          -224.268,
          -245.415,
          -266.546,
          -287.66,
          -308.757,
          -329.835,
          -350.895,
          -371.934,
          -392.952,
          -413.94800000000004,
          -434.921,
          -455.871,
          -476.796,
          -497.69599999999997,
          -518.569,
          -539.415,
          -560.2330000000001,
          -581.0219999999999,
          -601.781,
          -622.508,
          -643.2040000000001,
          -663.867,
          -684.4960000000001,
          -705.09,
          -725.6489999999999,
          -746.171,
          -766.655,
          -787.1,
          -807.505,
          -827.87,
          -848.193,
          -868.4730000000001,
          -888.709,
          -908.9,
          -929.046,
          -949.1439999999999,
          -969.194,
          -989.194,
          -1009.145,
          -1029.0439999999999,
          -1048.89,
          -1068.682,
          -1088.4189999999999,
          -1108.101,
          -1127.725,
          -1147.29,
          -1166.796,
          -1186.241,
          -1205.623,
          -1224.942,
          -1244.1960000000001,
          -1263.384,
          -1282.505,
          -1301.557,
          -1320.539,
          -1339.45,
          -1358.287,
          -1377.0510000000002,
          -1395.7379999999998,
          -1414.349,
          -1432.881,
          -1451.3329999999999,
          -1469.703,
          -1487.99,
          -1506.192,
          -1524.308,
          -1542.336,
          -1560.275,
          -1578.122,
          -1595.876,
          -1613.536,
          -1631.099,
          -1648.5639999999999,
          -1665.9279999999999,
          -1683.191,
          -1700.351,
          -1717.404,
          -1734.35,
          -1751.1870000000001,
          -1767.911,
          -1784.5220000000002,
          -1801.017,
          -1817.395,
          -1833.652,
          -1849.787,
          -1865.797,
          -1881.68,
          -1897.434,
          -1913.056,
          -1928.545,
          -1943.896,
          -1959.108,
          -1974.1789999999999,
          -1989.105,
          -2003.8829999999998,
          -2018.5120000000002,
          -2032.9879999999998,
          -2047.308,
          -2061.469,
          -2075.469,
          -2089.304,
          -2102.97,
          -2116.466,
          -2129.786,
          -2142.929,
          -2155.889,
          -2168.665,
          -2181.252,
          -2193.646,
          -2205.843,
          -2217.84,
          -2229.632,
          -2241.216,
          -2252.5860000000002,
          -2263.74,
          -2274.6710000000003,
          -2285.375,
          -2295.849,
          -2306.0860000000002,
          -2316.081,
          -2325.831,
          -2335.328,
          -2344.569,
          -2353.5460000000003,
          -2362.255,
          -2370.69,
          -2378.843,
          -2386.71,
          -2394.283,
          -2401.556,
          -2408.521,
          -2415.172,
          -2421.501,
          -2427.501,
          -2433.163,
          -2438.48,
          -2443.4429999999998,
          -2448.044,
          -2452.2729999999997,
          -2456.1220000000003,
          -2459.581,
          -2462.639,
          -2465.2870000000003,
          -2467.513,
          -2469.308,
          -2470.658,
          -2471.553,
          -2471.981,
          -2471.928,
          -2471.381,
          -2470.326,
          -2468.749,
          -2466.636,
          -2463.97,
          -2460.736,
          -2456.917,
          -2452.496,
          -2447.453,
          -2441.771,
          -2435.431,
          -2428.41,
          -2420.689,
          -2412.244,
          -2403.052,
          -2393.089,
          -2382.3289999999997,
          -2370.7470000000003,
          -2358.314,
          -2345,
          -2330.777,
          -2315.61,
          -2299.47,
          -2282.32,
          -2264.123,
          -2244.842,
          -2224.438,
          -2202.868,
          -2180.089,
          -2156.055,
          -2130.72,
          -2104.033,
          -2075.9429999999998,
          -2046.3970000000002,
          -2015.3370000000002,
          -1982.707,
          -1948.445,
          -1912.489,
          -1874.775,
          -1835.237,
          -1793.807,
          -1750.4170000000001,
          -1704.997,
          -1657.477,
          -1607.789,
          -1555.865,
          -1501.641,
          -1445.0529999999999,
          -1386.049,
          -1324.58,
          -1260.605,
          -1194.098,
          -1125.047,
          -1053.4560000000001,
          -979.35,
          -902.775,
          -823.81,
          -742.554,
          -659.1439999999999,
          -573.744,
          -486.551,
          -397.79699999999997,
          -307.73900000000003,
          -216.658,
          -124.85600000000001,
          -32.649,
          59.644,
          151.702,
          243.21599999999998,
          333.89099999999996,
          423.452,
          511.652,
          598.27,
          683.117,
          766.0360000000001,
          846.8960000000001,
          925.597,
          1002.065,
          1076.25,
          1148.124,
          1217.675,
          1284.9080000000001,
          1349.8410000000001,
          1412.504,
          1472.933,
          1531.172,
          1587.271,
          1641.2839999999999,
          1693.266,
          1743.275,
          1791.371,
          1837.61,
          1882.0529999999999,
          1924.7579999999998,
          1965.781,
          2005.18,
          2043.007,
          2079.3160000000003,
          2114.159,
          2147.585,
          2179.6420000000003,
          2210.376,
          2239.8320000000003,
          2268.052,
          2295.078,
          2320.948,
          2345.702,
          2369.376,
          2392.0029999999997,
          2413.619,
          2434.254,
          2453.94,
          2472.7070000000003,
          2490.581,
          2507.592,
          2523.764,
          2539.123,
          2553.6929999999998,
          2567.498,
          2580.558,
          2592.897,
          2604.533,
          2615.487,
          2625.778,
          2635.423,
          2644.441,
          2652.848,
          2660.6609999999996,
          2667.8940000000002,
          2674.5640000000003,
          2680.685,
          2686.27,
          2691.3340000000003,
          2695.889,
          2699.948,
          2703.5229999999997,
          2706.6259999999997,
          2709.2690000000002,
          2711.461,
          2713.215,
          2714.539,
          2715.445,
          2715.941,
          2716.0370000000003,
          2715.742,
          2715.065,
          2714.014,
          2712.597,
          2710.823,
          2708.699,
          2706.232,
          2703.43,
          2700.3,
          2696.849,
          2693.083,
          2689.009,
          2684.633,
          2679.962,
          2675,
          2669.755,
          2664.2309999999998,
          2658.435,
          2652.3720000000003,
          2646.045,
          2639.462,
          2632.6259999999997,
          2625.5429999999997,
          2618.217,
          2610.652,
          2602.854,
          2594.826,
          2586.573,
          2578.099,
          2569.409,
          2560.505,
          2551.391,
          2542.073,
          2532.552,
          2522.834,
          2512.9210000000003,
          2502.8160000000003,
          2492.524,
          2482.0460000000003,
          2471.388,
          2460.551,
          2449.5389999999998,
          2438.355,
          2427.002,
          2415.482,
          2403.799,
          2391.955,
          2379.953,
          2367.7960000000003,
          2355.486,
          2343.025,
          2330.417,
          2317.6639999999998,
          2304.768,
          2291.731,
          2278.556,
          2265.245,
          2251.801,
          2238.225,
          2224.519,
          2210.687,
          2196.729,
          2182.6479999999997,
          2168.446,
          2154.125,
          2139.686,
          2125.132,
          2110.465,
          2095.686,
          2080.798,
          2065.801,
          2050.698,
          2035.49,
          2020.18,
          2004.7679999999998,
          1989.257,
          1973.648,
          1957.942,
          1942.142,
          1926.2479999999998,
          1910.2620000000002,
          1894.1870000000001,
          1878.0220000000002,
          1861.77,
          1845.433,
          1829.01,
          1812.505,
          1795.918,
          1779.25,
          1762.504,
          1745.68,
          1728.779,
          1711.8029999999999,
          1694.754,
          1677.631,
          1660.4379999999999,
          1643.174,
          1625.8410000000001,
          1608.441,
          1590.974,
          1573.441,
          1555.844,
          1538.184,
          1520.4620000000002,
          1502.6789999999999,
          1484.8370000000002,
          1466.935,
          1448.976,
          1430.96,
          1412.889,
          1394.763,
          1376.5839999999998,
          1358.352,
          1340.069,
          1321.735,
          1303.3519999999999,
          1284.92,
          1266.441,
          1247.9160000000002,
          1229.344,
          1210.728,
          1192.069,
          1173.366,
          1154.622,
          1135.836,
          1117.011,
          1098.147,
          1079.244,
          1060.3039999999999,
          1041.327,
          1022.315,
          1003.268,
          984.187,
          965.073,
          945.927,
          926.75,
          907.5419999999999,
          888.304,
          869.038,
          849.743,
          830.422,
          811.074,
          791.7,
          772.302,
          752.8789999999999,
          733.434,
          713.966,
          694.477,
          674.966,
          655.436,
          635.887,
          616.319,
          596.734,
          577.132,
          557.513,
          537.879,
          518.231,
          498.569,
          478.894,
          459.207,
          439.50800000000004,
          419.798,
          400.079,
          380.35,
          360.61300000000006,
          340.86800000000005,
          321.116,
          301.358,
          281.595,
          261.827,
          242.055,
          222.27900000000002,
          202.502,
          182.722,
          162.942,
          143.162,
          123.382,
          103.604,
          83.82799999999999,
          64.055,
          44.285,
          24.52,
          4.76,
          -14.994000000000002,
          -34.741,
          -54.481,
          -74.212,
          -93.934,
          -113.647,
          -133.349,
          -153.039,
          -172.717,
          -192.38299999999998,
          -212.03400000000002,
          -231.671,
          -251.292,
          -270.89799999999997,
          -290.486,
          -310.056,
          -329.608,
          -349.14,
          -368.652,
          -388.14300000000003,
          -407.61199999999997,
          -427.05800000000005,
          -446.48,
          -465.87800000000004,
          -485.25,
          -504.596,
          -523.915,
          -543.206,
          -562.4680000000001,
          -581.7,
          -600.9019999999999,
          -620.071,
          -639.2090000000001,
          -658.312,
          -677.382,
          -696.416,
          -715.413,
          -734.3739999999999,
          -753.296,
          -772.178,
          -791.0210000000001,
          -809.822,
          -828.581,
          -847.297,
          -865.9689999999999,
          -884.595,
          -903.174,
          -921.707,
          -940.19,
          -958.6239999999999,
          -977.007,
          -995.3380000000001,
          -1013.617,
          -1031.8410000000001,
          -1050.009,
          -1068.121,
          -1086.175,
          -1104.171,
          -1122.106,
          -1139.979,
          -1157.79,
          -1175.537,
          -1193.219,
          -1210.8339999999998,
          -1228.381,
          -1245.859,
          -1263.265,
          -1280.6,
          -1297.862,
          -1315.0479999999998,
          -1332.158,
          -1349.19,
          -1366.142,
          -1383.014,
          -1399.8020000000001,
          -1416.507,
          -1433.126,
          -1449.6570000000002,
          -1466.1,
          -1482.451,
          -1498.71,
          -1514.874,
          -1530.942,
          -1546.9129999999998,
          -1562.783,
          -1578.5520000000001,
          -1594.2160000000001,
          -1609.775,
          -1625.227,
          -1640.568,
          -1655.7979999999998,
          -1670.9129999999998,
          -1685.9129999999998,
          -1700.793,
          -1715.5529999999999,
          -1730.19,
          -1744.7020000000002,
          -1759.085,
          -1773.338,
          -1787.4579999999999,
          -1801.443,
          -1815.289,
          -1828.995,
          -1842.557,
          -1855.9720000000002,
          -1869.2379999999998,
          -1882.352,
          -1895.31,
          -1908.109,
          -1920.747,
          -1933.22,
          -1945.524,
          -1957.6570000000002,
          -1969.614,
          -1981.392,
          -1992.9879999999998,
          -2004.3970000000002,
          -2015.616,
          -2026.64,
          -2037.4660000000001,
          -2048.089,
          -2058.505,
          -2068.709,
          -2078.698,
          -2088.465,
          -2098.007,
          -2107.3179999999998,
          -2116.393,
          -2125.2270000000003,
          -2133.815,
          -2142.15,
          -2150.2270000000003,
          -2158.04,
          -2165.583,
          -2172.85,
          -2179.834,
          -2186.528,
          -2192.926,
          -2199.019,
          -2204.801,
          -2210.265,
          -2215.401,
          -2220.202,
          -2224.659,
          -2228.764,
          -2232.508,
          -2235.88,
          -2238.8720000000003,
          -2241.473,
          -2243.672,
          -2245.459,
          -2246.823,
          -2247.751,
          -2248.232,
          -2248.2529999999997,
          -2247.801,
          -2246.861,
          -2245.4210000000003,
          -2243.465,
          -2240.978,
          -2237.9429999999998,
          -2234.344,
          -2230.1639999999998,
          -2225.385,
          -2219.987,
          -2213.951,
          -2207.257,
          -2199.882,
          -2191.804,
          -2183.001,
          -2173.447,
          -2163.117,
          -2151.984,
          -2140.019,
          -2127.195,
          -2113.479,
          -2098.84,
          -2083.245,
          -2066.657,
          -2049.04,
          -2030.356,
          -2010.5639999999999,
          -1989.622,
          -1967.485,
          -1944.108,
          -1919.443,
          -1893.44,
          -1866.045,
          -1837.205,
          -1806.8629999999998,
          -1774.961,
          -1741.4379999999999,
          -1706.2320000000002,
          -1669.2779999999998,
          -1630.513,
          -1589.871,
          -1547.285,
          -1502.6879999999999,
          -1456.017,
          -1407.2079999999999,
          -1356.201,
          -1302.942,
          -1247.381,
          -1189.478,
          -1129.203,
          -1066.538,
          -1001.4810000000001,
          -934.047,
          -864.2760000000001,
          -792.2280000000001,
          -717.99,
          -641.679,
          -563.44,
          -483.449,
          -401.91,
          -319.056,
          -235.144,
          -150.44899999999998,
          -65.26,
          20.127,
          105.417,
          190.31799999999998,
          274.55400000000003,
          357.86699999999996,
          440.02,
          520.805,
          600.0369999999999,
          677.564,
          753.257,
          827.0169999999999,
          898.768,
          968.456,
          1036.049,
          1101.531,
          1164.901,
          1226.172,
          1285.364,
          1342.509,
          1397.645,
          1450.8120000000001,
          1502.059,
          1551.435,
          1598.991,
          1644.78,
          1688.854,
          1731.266,
          1772.068,
          1811.3129999999999,
          1849.05,
          1885.33,
          1920.2020000000002,
          1953.711,
          1985.9029999999998,
          2016.8220000000001,
          2046.511,
          2075.009,
          2102.357,
          2128.592,
          2153.751,
          2177.868,
          2200.976,
          2223.1079999999997,
          2244.2960000000003,
          2264.5679999999998,
          2283.953,
          2302.478,
          2320.17,
          2337.053,
          2353.152,
          2368.49,
          2383.09,
          2396.971,
          2410.156,
          2422.6639999999998,
          2434.513,
          2445.723,
          2456.31,
          2466.291,
          2475.6839999999997,
          2484.5029999999997,
          2492.763,
          2500.479,
          2507.666,
          2514.3360000000002,
          2520.5029999999997,
          2526.179,
          2531.377,
          2536.107,
          2540.382,
          2544.2129999999997,
          2547.609,
          2550.581,
          2553.14,
          2555.294,
          2557.052,
          2558.425,
          2559.42,
          2560.0460000000003,
          2560.311,
          2560.222,
          2559.7889999999998,
          2559.0170000000003,
          2557.9139999999998,
          2556.488,
          2554.745,
          2552.6910000000003,
          2550.333,
          2547.677,
          2544.73,
          2541.496,
          2537.9829999999997,
          2534.194,
          2530.137,
          2525.815,
          2521.235,
          2516.401,
          2511.3179999999998,
          2505.99,
          2500.423,
          2494.621,
          2488.5879999999997,
          2482.328,
          2475.846,
          2469.146,
          2462.231,
          2455.106,
          2447.774,
          2440.239,
          2432.505,
          2424.575,
          2416.453,
          2408.141,
          2399.644,
          2390.964,
          2382.105,
          2373.07,
          2363.861,
          2354.481,
          2344.935,
          2335.223,
          2325.35,
          2315.317,
          2305.1279999999997,
          2294.785,
          2284.29,
          2273.646,
          2262.856,
          2251.9210000000003,
          2240.845,
          2229.629,
          2218.276,
          2206.788,
          2195.167,
          2183.415,
          2171.534,
          2159.527,
          2147.395,
          2135.141,
          2122.766,
          2110.272,
          2097.661,
          2084.935,
          2072.096,
          2059.146,
          2046.085,
          2032.9170000000001,
          2019.642,
          2006.263,
          1992.78,
          1979.1970000000001,
          1965.513,
          1951.731,
          1937.852,
          1923.878,
          1909.8110000000001,
          1895.651,
          1881.4,
          1867.059,
          1852.631,
          1838.116,
          1823.516,
          1808.832,
          1794.065,
          1779.217,
          1764.289,
          1749.2820000000002,
          1734.1970000000001,
          1719.036,
          1703.8,
          1688.49,
          1673.108,
          1657.654,
          1642.129,
          1626.536,
          1610.874,
          1595.145,
          1579.351,
          1563.491,
          1547.568,
          1531.582,
          1515.5339999999999,
          1499.4260000000002,
          1483.2579999999998,
          1467.0320000000002,
          1450.7479999999998,
          1434.4070000000002,
          1418.011,
          1401.56,
          1385.056,
          1368.4979999999998,
          1351.889,
          1335.229,
          1318.519,
          1301.761,
          1284.954,
          1268.099,
          1251.1989999999998,
          1234.253,
          1217.262,
          1200.228,
          1183.15,
          1166.031,
          1148.871,
          1131.67,
          1114.4289999999999,
          1097.15,
          1079.833,
          1062.479,
          1045.089,
          1027.663,
          1010.203,
          992.709,
          975.181,
          957.622,
          940.03,
          922.408,
          904.7560000000001,
          887.075,
          869.365,
          851.627,
          833.862,
          816.071,
          798.255,
          780.414,
          762.548,
          744.66,
          726.748,
          708.815,
          690.8610000000001,
          672.8860000000001,
          654.891,
          636.878,
          618.846,
          600.7959999999999,
          582.73,
          564.6469999999999,
          546.549,
          528.436,
          510.309,
          492.16900000000004,
          474.01599999999996,
          455.85,
          437.67400000000004,
          419.48699999999997,
          401.29,
          383.084,
          364.869,
          346.647,
          328.417,
          310.181,
          291.939,
          273.692,
          255.44,
          237.185,
          218.92700000000002,
          200.667,
          182.405,
          164.142,
          145.879,
          127.617,
          109.355,
          91.096,
          72.839,
          54.585,
          36.336,
          18.090999999999998,
          -0.14800000000000002,
          -18.382,
          -36.608000000000004,
          -54.827,
          -73.03699999999999,
          -91.23899999999999,
          -109.43,
          -127.611,
          -145.781,
          -163.93900000000002,
          -182.084,
          -200.21599999999998,
          -218.333,
          -236.43599999999998,
          -254.52200000000002,
          -272.593,
          -290.645,
          -308.68,
          -326.69599999999997,
          -344.69300000000004,
          -362.668,
          -380.62300000000005,
          -398.556,
          -416.465,
          -434.352,
          -452.213,
          -470.04900000000004,
          -487.86,
          -505.64300000000003,
          -523.398,
          -541.124,
          -558.821,
          -576.488,
          -594.123,
          -611.726,
          -629.295,
          -646.831,
          -664.331,
          -681.796,
          -699.2239999999999,
          -716.6139999999999,
          -733.965,
          -751.2760000000001,
          -768.547,
          -785.775,
          -802.961,
          -820.1039999999999,
          -837.201,
          -854.252,
          -871.257,
          -888.2130000000001,
          -905.1210000000001,
          -921.9780000000001,
          -938.783,
          -955.5360000000001,
          -972.2360000000001,
          -988.8810000000001,
          -1005.4689999999999,
          -1022.0010000000001,
          -1038.473,
          -1054.887,
          -1071.239,
          -1087.529,
          -1103.755,
          -1119.917,
          -1136.012,
          -1152.04,
          -1167.999,
          -1183.887,
          -1199.704,
          -1215.447,
          -1231.115,
          -1246.7069999999999,
          -1262.222,
          -1277.657,
          -1293.011,
          -1308.282,
          -1323.469,
          -1338.57,
          -1353.5839999999998,
          -1368.5079999999998,
          -1383.3410000000001,
          -1398.0810000000001,
          -1412.726,
          -1427.274,
          -1441.723,
          -1456.0720000000001,
          -1470.318,
          -1484.46,
          -1498.494,
          -1512.42,
          -1526.234,
          -1539.935,
          -1553.52,
          -1566.987,
          -1580.3339999999998,
          -1593.558,
          -1606.656,
          -1619.6270000000002,
          -1632.467,
          -1645.174,
          -1657.745,
          -1670.1770000000001,
          -1682.467,
          -1694.6129999999998,
          -1706.611,
          -1718.4579999999999,
          -1730.152,
          -1741.6879999999999,
          -1753.0639999999999,
          -1764.276,
          -1775.32,
          -1786.193,
          -1796.892,
          -1807.411,
          -1817.749,
          -1827.899,
          -1837.859,
          -1847.624,
          -1857.19,
          -1866.5510000000002,
          -1875.704,
          -1884.644,
          -1893.365,
          -1901.8629999999998,
          -1910.132,
          -1918.168,
          -1925.964,
          -1933.514,
          -1940.8129999999999,
          -1947.855,
          -1954.634,
          -1961.142,
          -1967.374,
          -1973.3210000000001,
          -1978.9779999999998,
          -1984.336,
          -1989.388,
          -1994.125,
          -1998.5410000000002,
          -2002.625,
          -2006.369,
          -2009.764,
          -2012.8010000000002,
          -2015.469,
          -2017.7579999999998,
          -2019.658,
          -2021.1570000000002,
          -2022.245,
          -2022.908,
          -2023.135,
          -2022.9129999999998,
          -2022.2279999999998,
          -2021.066,
          -2019.4129999999998,
          -2017.253,
          -2014.57,
          -2011.349,
          -2007.5710000000001,
          -2003.219,
          -1998.273,
          -1992.715,
          -1986.524,
          -1979.6779999999999,
          -1972.154,
          -1963.9289999999999,
          -1954.98,
          -1945.28,
          -1934.8010000000002,
          -1923.517,
          -1911.3970000000002,
          -1898.411,
          -1884.526,
          -1869.7079999999999,
          -1853.921,
          -1837.129,
          -1819.293,
          -1800.371,
          -1780.3220000000001,
          -1759.1,
          -1736.6589999999999,
          -1712.95,
          -1687.9229999999998,
          -1661.526,
          -1633.704,
          -1604.4,
          -1573.556,
          -1541.1129999999998,
          -1507.009,
          -1471.182,
          -1433.568,
          -1394.106,
          -1352.733,
          -1309.389,
          -1264.014,
          -1216.556,
          -1166.964,
          -1115.197,
          -1061.22,
          -1005.0139999999999,
          -946.569,
          -885.8939999999999,
          -823.015,
          -757.98,
          -690.863,
          -621.76,
          -550.799,
          -478.13199999999995,
          -403.941,
          -328.431,
          -251.833,
          -174.396,
          -96.382,
          -18.062,
          60.292,
          138.41,
          216.03599999999997,
          292.927,
          368.861,
          443.63800000000003,
          517.082,
          589.0459999999999,
          659.404,
          728.056,
          794.928,
          859.961,
          923.1210000000001,
          984.385,
          1043.748,
          1101.215,
          1156.802,
          1210.532,
          1262.437,
          1312.5520000000001,
          1360.9170000000001,
          1407.5739999999998,
          1452.569,
          1495.9470000000001,
          1537.754,
          1578.0379999999998,
          1616.899,
          1654.2220000000002,
          1690.214,
          1724.865,
          1758.22,
          1790.319,
          1821.205,
          1850.9170000000001,
          1879.493,
          1906.97,
          1933.3829999999998,
          1958.769,
          1983.158,
          2006.582,
          2029.0739999999998,
          2050.6620000000003,
          2071.373,
          2091.236,
          2110.276,
          2128.519,
          2145.987,
          2162.7039999999997,
          2178.6929999999998,
          2193.974,
          2208.569,
          2222.495,
          2235.7729999999997,
          2248.4210000000003,
          2260.456,
          2271.894,
          2282.752,
          2293.0460000000003,
          2302.79,
          2311.999,
          2320.687,
          2328.867,
          2336.551,
          2343.754,
          2350.486,
          2356.759,
          2362.585,
          2367.973,
          2372.936,
          2377.482,
          2381.621,
          2385.363,
          2388.718,
          2391.6929999999998,
          2394.297,
          2396.54,
          2398.428,
          2399.969,
          2401.172,
          2402.042,
          2402.589,
          2402.817,
          2402.734,
          2402.347,
          2401.6620000000003,
          2400.6839999999997,
          2399.42,
          2397.876,
          2396.0570000000002,
          2393.968,
          2391.615,
          2389.0029999999997,
          2386.137,
          2383.022,
          2379.663,
          2376.063,
          2372.229,
          2368.1639999999998,
          2363.8720000000003,
          2359.3579999999997,
          2354.626,
          2349.679,
          2344.521,
          2339.157,
          2333.59,
          2327.824,
          2321.861,
          2315.7070000000003,
          2309.363,
          2302.833,
          2296.12,
          2289.228,
          2282.159,
          2274.917,
          2267.504,
          2259.923,
          2252.177,
          2244.269,
          2236.202,
          2227.9770000000003,
          2219.599,
          2211.0679999999998,
          2202.388,
          2193.561,
          2184.59,
          2175.476,
          2166.222,
          2156.83,
          2147.303,
          2137.6420000000003,
          2127.85,
          2117.928,
          2107.879,
          2097.705,
          2087.407,
          2076.987,
          2066.448,
          2055.792,
          2045.019,
          2034.132,
          2023.132,
          2012.0220000000002,
          2000.8020000000001,
          1989.475,
          1978.043,
          1966.506,
          1954.866,
          1943.126,
          1931.285,
          1919.3470000000002,
          1907.3120000000001,
          1895.182,
          1882.9579999999999,
          1870.642,
          1858.235,
          1845.7379999999998,
          1833.1529999999998,
          1820.481,
          1807.724,
          1794.882,
          1781.957,
          1768.95,
          1755.8629999999998,
          1742.6960000000001,
          1729.451,
          1716.128,
          1702.73,
          1689.2579999999998,
          1675.711,
          1662.092,
          1648.402,
          1634.641,
          1620.8120000000001,
          1606.914,
          1592.9479999999999,
          1578.9170000000001,
          1564.8210000000001,
          1550.66,
          1536.4360000000001,
          1522.151,
          1507.8039999999999,
          1493.3970000000002,
          1478.93,
          1464.406,
          1449.8239999999998,
          1435.185,
          1420.491,
          1405.7420000000002,
          1390.94,
          1376.0839999999998,
          1361.1770000000001,
          1346.2179999999998,
          1331.2089999999998,
          1316.151,
          1301.0430000000001,
          1285.888,
          1270.687,
          1255.438,
          1240.145,
          1224.807,
          1209.425,
          1194,
          1178.5330000000001,
          1163.024,
          1147.475,
          1131.587,
          1115.958,
          1100.2910000000002,
          1084.586,
          1068.844,
          1053.066,
          1037.252,
          1021.404,
          1005.5210000000001,
          989.6060000000001,
          973.6569999999999,
          957.676,
          941.665,
          925.622,
          909.55,
          893.448,
          877.318,
          861.1610000000001,
          844.975,
          828.7639999999999,
          812.5260000000001,
          796.2639999999999,
          779.977,
          763.666,
          747.332,
          730.975,
          714.596,
          698.196,
          681.7760000000001,
          665.335,
          648.875,
          632.3969999999999,
          615.9,
          599.387,
          582.856,
          566.309,
          549.747,
          533.169,
          516.578,
          499.973,
          483.355,
          466.724,
          450.082,
          433.42900000000003,
          416.765,
          400.091,
          383.409,
          366.717,
          350.01800000000003,
          333.311,
          316.598,
          299.878,
          283.153,
          266.423,
          249.69,
          232.952,
          216.21200000000002,
          199.46900000000002,
          182.72400000000002,
          165.979,
          149.233,
          132.488,
          115.743,
          99,
          82.259,
          65.521,
          48.787,
          32.056,
          15.331,
          -1.389,
          -18.102999999999998,
          -34.81,
          -51.51,
          -68.20100000000001,
          -84.884,
          -101.557,
          -118.22,
          -134.872,
          -151.512,
          -168.14,
          -184.755,
          -201.356,
          -217.94299999999998,
          -234.515,
          -251.071,
          -267.61,
          -284.132,
          -300.63599999999997,
          -317.122,
          -333.587,
          -350.032,
          -366.45599999999996,
          -382.858,
          -399.23800000000006,
          -415.594,
          -431.926,
          -448.233,
          -464.51300000000003,
          -480.76800000000003,
          -496.994,
          -513.192,
          -529.362,
          -545.5,
          -561.6080000000001,
          -577.685,
          -593.7280000000001,
          -609.738,
          -625.7130000000001,
          -641.653,
          -657.557,
          -673.423,
          -689.2510000000001,
          -705.039,
          -720.7869999999999,
          -736.4939999999999,
          -752.159,
          -767.7810000000001,
          -783.3580000000001,
          -798.89,
          -814.375,
          -829.813,
          -845.202,
          -860.5419999999999,
          -875.83,
          -891.067,
          -906.25,
          -921.3789999999999,
          -936.452,
          -951.4680000000001,
          -966.426,
          -981.325,
          -996.163,
          -1010.939,
          -1025.652,
          -1040.3,
          -1054.882,
          -1069.396,
          -1083.8419999999999,
          -1098.2169999999999,
          -1112.52,
          -1126.749,
          -1140.904,
          -1154.982,
          -1168.982,
          -1182.902,
          -1196.74,
          -1210.495,
          -1224.165,
          -1237.749,
          -1251.244,
          -1264.6480000000001,
          -1277.96,
          -1291.177,
          -1304.299,
          -1317.3220000000001,
          -1330.244,
          -1343.0639999999999,
          -1355.78,
          -1368.388,
          -1380.8870000000002,
          -1393.275,
          -1405.5479999999998,
          -1417.7060000000001,
          -1429.744,
          -1441.661,
          -1453.454,
          -1465.121,
          -1476.6570000000002,
          -1488.0620000000001,
          -1499.3310000000001,
          -1510.4620000000002,
          -1521.4520000000002,
          -1532.297,
          -1542.995,
          -1553.5410000000002,
          -1563.934,
          -1574.168,
          -1584.241,
          -1594.149,
          -1603.888,
          -1613.454,
          -1622.8429999999998,
          -1632.0510000000002,
          -1641.0739999999998,
          -1649.9070000000002,
          -1658.546,
          -1666.986,
          -1675.2220000000002,
          -1683.25,
          -1691.0629999999999,
          -1698.658,
          -1706.0279999999998,
          -1713.1670000000001,
          -1720.0710000000001,
          -1726.7320000000002,
          -1733.145,
          -1739.3029999999999,
          -1745.1989999999998,
          -1750.8270000000002,
          -1756.1789999999999,
          -1761.249,
          -1766.027,
          -1770.507,
          -1774.68,
          -1778.5379999999998,
          -1782.0710000000001,
          -1785.271,
          -1788.1270000000002,
          -1790.63,
          -1792.77,
          -1794.536,
          -1795.9160000000002,
          -1796.898,
          -1797.4720000000002,
          -1797.624,
          -1797.34,
          -1796.608,
          -1795.412,
          -1793.739,
          -1791.5720000000001,
          -1788.894,
          -1785.69,
          -1781.941,
          -1777.628,
          -1772.733,
          -1767.234,
          -1761.111,
          -1754.3410000000001,
          -1746.901,
          -1738.766,
          -1729.911,
          -1720.309,
          -1709.93,
          -1698.7479999999998,
          -1686.73,
          -1673.844,
          -1660.055,
          -1645.328,
          -1629.6270000000002,
          -1612.91,
          -1595.139,
          -1576.269,
          -1556.257,
          -1535.056,
          -1512.616,
          -1488.888,
          -1463.819,
          -1437.355,
          -1409.44,
          -1380.017,
          -1349.0279999999998,
          -1316.4129999999998,
          -1282.113,
          -1246.069,
          -1208.222,
          -1168.516,
          -1126.8980000000001,
          -1083.318,
          -1037.733,
          -990.1080000000001,
          -940.416,
          -888.6439999999999,
          -834.7919999999999,
          -778.877,
          -720.935,
          -661.0239999999999,
          -599.2230000000001,
          -535.64,
          -470.405,
          -403.676,
          -335.63300000000004,
          -266.48,
          -196.43900000000002,
          -125.744,
          -54.641000000000005,
          16.621,
          87.79700000000001,
          158.65,
          228.953,
          298.5,
          367.101,
          434.591,
          500.825,
          565.683,
          629.067,
          690.8989999999999,
          751.122,
          809.694,
          866.591,
          921.801,
          975.324,
          1027.1680000000001,
          1077.351,
          1125.8980000000001,
          1172.837,
          1218.2,
          1262.0230000000001,
          1304.345,
          1345.204,
          1384.642,
          1422.6979999999999,
          1459.415,
          1494.8310000000001,
          1528.9879999999998,
          1561.925,
          1593.68,
          1624.29,
          1653.7920000000001,
          1682.223,
          1709.615,
          1736.0020000000002,
          1761.4160000000002,
          1785.888,
          1809.4470000000001,
          1832.122,
          1853.94,
          1874.9279999999999,
          1895.112,
          1914.515,
          1933.162,
          1951.0739999999998,
          1968.274,
          1984.783,
          2000.62,
          2015.8039999999999,
          2030.355,
          2044.29,
          2057.626,
          2070.38,
          2082.567,
          2094.203,
          2105.303,
          2115.88,
          2125.948,
          2135.521,
          2144.611,
          2153.23,
          2161.391,
          2169.104,
          2176.38,
          2183.231,
          2189.666,
          2195.694,
          2201.327,
          2206.572,
          2211.44,
          2215.938,
          2220.074,
          2223.8579999999997,
          2227.2960000000003,
          2230.397,
          2233.167,
          2235.615,
          2237.746,
          2239.567,
          2241.0860000000002,
          2242.3070000000002,
          2243.238,
          2243.885,
          2244.252,
          2244.346,
          2244.173,
          2243.736,
          2243.042,
          2242.096,
          2240.902,
          2239.466,
          2237.791,
          2235.882,
          2233.744,
          2231.381,
          2228.797,
          2225.996,
          2222.982,
          2219.759,
          2216.331,
          2212.7,
          2208.8720000000003,
          2204.849,
          2200.634,
          2196.232,
          2191.644,
          2186.876,
          2181.928,
          2176.805,
          2171.509,
          2166.044,
          2160.4120000000003,
          2154.616,
          2148.658,
          2142.541,
          2136.268,
          2129.842,
          2123.264,
          2116.5370000000003,
          2109.6639999999998,
          2102.647,
          2095.488,
          2088.189,
          2080.752,
          2073.181,
          2065.476,
          2057.639,
          2049.674,
          2041.5810000000001,
          2033.3629999999998,
          2025.0220000000002,
          2016.559,
          2007.976,
          1999.276,
          1990.4589999999998,
          1981.5279999999998,
          1972.484,
          1963.329,
          1954.0639999999999,
          1944.692,
          1935.214,
          1925.63,
          1915.944,
          1906.156,
          1896.267,
          1886.28,
          1876.1960000000001,
          1866.015,
          1855.74,
          1845.372,
          1834.912,
          1824.362,
          1813.7220000000002,
          1802.994,
          1792.18,
          1781.28,
          1770.296,
          1759.2279999999998,
          1748.079,
          1736.85,
          1725.54,
          1714.152,
          1702.6870000000001,
          1691.146,
          1679.529,
          1667.839,
          1656.075,
          1644.24,
          1632.3329999999999,
          1620.356,
          1608.3110000000001,
          1596.1970000000001,
          1584.017,
          1571.77,
          1559.4589999999998,
          1547.0829999999999,
          1534.644,
          1522.1429999999998,
          1509.58,
          1496.957,
          1484.274,
          1471.5320000000002,
          1458.7320000000002,
          1445.876,
          1432.963,
          1419.994,
          1406.971,
          1393.895,
          1380.765,
          1367.5829999999999,
          1354.35,
          1341.066,
          1327.733,
          1314.35,
          1300.9189999999999,
          1287.44,
          1273.915,
          1260.344,
          1246.7269999999999,
          1233.065,
          1219.36,
          1205.612,
          1191.8210000000001,
          1177.988,
          1164.114,
          1150.2,
          1136.245,
          1122.252,
          1108.221,
          1094.151,
          1080.045,
          1065.902,
          1051.723,
          1037.51,
          1023.2610000000001,
          1008.9789999999999,
          994.664,
          980.316,
          965.936,
          951.525,
          937.0830000000001,
          922.6110000000001,
          908.1089999999999,
          893.579,
          879.02,
          864.433,
          849.82,
          835.179,
          820.513,
          805.822,
          791.1060000000001,
          776.365,
          761.602,
          746.815,
          732.005,
          717.174,
          702.322,
          687.449,
          672.556,
          657.643,
          642.711,
          627.761,
          612.793,
          597.808,
          582.806,
          567.7869999999999,
          552.754,
          537.705,
          522.641,
          507.564,
          492.474,
          477.37,
          462.255,
          447.12699999999995,
          431.98900000000003,
          416.84,
          401.681,
          386.51300000000003,
          371.336,
          356.15,
          340.957,
          325.757,
          310.55,
          295.336,
          280.118,
          264.894,
          249.667,
          234.435,
          219.2,
          203.963,
          188.72400000000002,
          173.483,
          158.241,
          142.999,
          127.757,
          112.51700000000001,
          97.277,
          82.04,
          66.806,
          51.574,
          36.347,
          21.124000000000002,
          5.906000000000001,
          -9.306000000000001,
          -24.511999999999997,
          -39.71,
          -54.902,
          -70.084,
          -85.259,
          -100.42299999999999,
          -115.57799999999999,
          -130.721,
          -145.85299999999998,
          -160.97299999999998,
          -176.081,
          -191.174,
          -206.25400000000002,
          -221.31900000000002,
          -236.368,
          -251.40099999999998,
          -266.41700000000003,
          -281.416,
          -296.39599999999996,
          -311.357,
          -326.298,
          -341.219,
          -356.11800000000005,
          -370.995,
          -385.85,
          -400.68,
          -415.48699999999997,
          -430.26800000000003,
          -445.023,
          -459.751,
          -474.452,
          -489.124,
          -503.767,
          -518.38,
          -532.961,
          -547.511,
          -562.028,
          -576.511,
          -590.9590000000001,
          -605.372,
          -619.748,
          -634.087,
          -648.387,
          -662.648,
          -676.868,
          -691.047,
          -705.183,
          -719.275,
          -733.323,
          -747.325,
          -761.28,
          -775.188,
          -789.046,
          -802.8530000000001,
          -816.6089999999999,
          -830.312,
          -843.961,
          -857.555,
          -871.0930000000001,
          -884.573,
          -897.9939999999999,
          -911.3539999999999,
          -924.6519999999999,
          -937.887,
          -951.058,
          -964.1619999999999,
          -977.198,
          -990.166,
          -1003.062,
          -1015.8860000000001,
          -1028.637,
          -1041.3110000000001,
          -1053.9080000000001,
          -1066.4260000000002,
          -1078.864,
          -1091.218,
          -1103.488,
          -1115.672,
          -1127.767,
          -1139.772,
          -1151.685,
          -1163.503,
          -1175.224,
          -1186.847,
          -1198.369,
          -1209.787,
          -1221.1,
          -1232.3039999999999,
          -1243.3980000000001,
          -1254.379,
          -1265.245,
          -1275.991,
          -1286.617,
          -1297.118,
          -1307.493,
          -1317.7379999999998,
          -1327.85,
          -1337.826,
          -1347.662,
          -1357.356,
          -1366.904,
          -1376.3010000000002,
          -1385.546,
          -1394.634,
          -1403.56,
          -1412.3220000000001,
          -1420.914,
          -1429.3339999999998,
          -1437.575,
          -1445.635,
          -1453.507,
          -1461.1879999999999,
          -1468.672,
          -1475.954,
          -1483.03,
          -1489.892,
          -1496.536,
          -1502.9560000000001,
          -1509.145,
          -1515.098,
          -1520.808,
          -1526.267,
          -1531.469,
          -1536.4070000000002,
          -1541.0729999999999,
          -1545.4589999999998,
          -1549.557,
          -1553.358,
          -1556.854,
          -1560.035,
          -1562.892,
          -1565.414,
          -1567.5929999999998,
          -1569.4160000000002,
          -1570.872,
          -1571.95,
          -1572.638,
          -1572.922,
          -1572.789,
          -1572.226,
          -1571.2179999999998,
          -1569.749,
          -1567.8039999999999,
          -1565.366,
          -1562.4170000000001,
          -1558.941,
          -1554.9160000000002,
          -1550.3229999999999,
          -1545.142,
          -1539.35,
          -1532.925,
          -1525.8410000000001,
          -1518.0739999999998,
          -1509.5970000000002,
          -1500.382,
          -1490.399,
          -1479.619,
          -1468.0079999999998,
          -1455.533,
          -1442.158,
          -1427.846,
          -1412.557,
          -1396.2520000000002,
          -1378.888,
          -1360.4189999999999,
          -1340.8,
          -1319.9820000000002,
          -1297.9160000000002,
          -1274.549,
          -1249.829,
          -1223.701,
          -1196.11,
          -1166.998,
          -1136.312,
          -1103.995,
          -1069.991,
          -1034.25,
          -996.7230000000001,
          -957.365,
          -916.1389999999999,
          -873.0139999999999,
          -827.9730000000001,
          -781.007,
          -732.123,
          -681.346,
          -628.719,
          -574.305,
          -518.191,
          -460.48699999999997,
          -401.325,
          -340.86199999999997,
          -279.27299999999997,
          -216.753,
          -153.51,
          -89.762,
          -25.733,
          38.354,
          102.28399999999999,
          165.84799999999998,
          228.85299999999998,
          291.125,
          352.505,
          412.858,
          472.065,
          530.031,
          586.679,
          641.948,
          695.795,
          748.191,
          799.117,
          848.569,
          896.549,
          943.068,
          988.1419999999999,
          1031.7930000000001,
          1074.048,
          1114.935,
          1154.485,
          1192.732,
          1229.7089999999998,
          1265.45,
          1299.991,
          1333.366,
          1365.611,
          1396.7579999999998,
          1426.8410000000001,
          1455.8929999999998,
          1483.9460000000001,
          1511.031,
          1537.1789999999999,
          1562.4170000000001,
          1586.774,
          1610.2779999999998,
          1632.955,
          1654.829,
          1675.9260000000002,
          1696.269,
          1715.88,
          1734.781,
          1752.993,
          1770.537,
          1787.431,
          1803.694,
          1819.345,
          1834.399,
          1848.875,
          1862.7879999999998,
          1876.1529999999998,
          1888.985,
          1901.2979999999998,
          1913.106,
          1924.4229999999998,
          1935.261,
          1945.631,
          1955.547,
          1965.019,
          1974.059,
          1982.6770000000001,
          1990.8829999999998,
          1998.6870000000001,
          2006.1,
          2013.129,
          2019.7839999999999,
          2026.0739999999998,
          2032.007,
          2037.59,
          2042.8329999999999,
          2047.7420000000002,
          2052.325,
          2056.589,
          2060.54,
          2064.186,
          2067.532,
          2070.5860000000002,
          2073.353,
          2075.8379999999997,
          2078.049,
          2079.99,
          2081.667,
          2083.085,
          2084.248,
          2085.163,
          2085.834,
          2086.265,
          2086.4610000000002,
          2086.427,
          2086.167,
          2085.6839999999997,
          2084.984,
          2084.069,
          2082.945,
          2081.614,
          2080.081,
          2078.349,
          2076.4210000000003,
          2074.301,
          2071.992,
          2069.498,
          2066.822,
          2063.966,
          2060.9339999999997,
          2057.728,
          2054.3520000000003,
          2050.8089999999997,
          2047.101,
          2043.23,
          2039.2,
          2035.013,
          2030.672,
          2026.1779999999999,
          2021.535,
          2016.745,
          2011.81,
          2006.7320000000002,
          2001.513,
          1996.1570000000002,
          1990.664,
          1985.037,
          1979.2779999999998,
          1973.388,
          1967.371,
          1961.227,
          1954.9589999999998,
          1948.569,
          1942.058,
          1935.4270000000001,
          1928.68,
          1921.817,
          1914.84,
          1907.751,
          1900.5510000000002,
          1893.2420000000002,
          1885.826,
          1878.3039999999999,
          1870.6770000000001,
          1862.9479999999999,
          1855.1170000000002,
          1847.185,
          1839.155,
          1831.0279999999998,
          1822.8039999999999,
          1814.486,
          1806.075,
          1797.5710000000001,
          1788.977,
          1780.293,
          1771.52,
          1762.661,
          1753.715,
          1744.685,
          1735.5710000000001,
          1726.374,
          1717.096,
          1707.737,
          1698.3,
          1688.7839999999999,
          1679.191,
          1669.521,
          1659.777,
          1649.9589999999998,
          1640.067,
          1630.1029999999998,
          1620.068,
          1609.963,
          1599.789,
          1589.546,
          1579.236,
          1568.859,
          1558.4160000000002,
          1547.9089999999999,
          1537.3370000000002,
          1526.703,
          1516.006,
          1505.2479999999998,
          1494.4289999999999,
          1483.55,
          1472.6129999999998,
          1461.6170000000002,
          1450.5629999999999,
          1439.453,
          1428.2879999999998,
          1417.067,
          1405.7910000000002,
          1394.4620000000002,
          1383.08,
          1371.646,
          1360.161,
          1348.624,
          1337.0379999999998,
          1325.402,
          1313.717,
          1301.985,
          1290.205,
          1278.378,
          1266.505,
          1254.587,
          1242.624,
          1230.618,
          1218.567,
          1206.474,
          1194.339,
          1182.162,
          1169.944,
          1157.685,
          1145.387,
          1133.05,
          1120.674,
          1108.26,
          1095.809,
          1083.3210000000001,
          1070.797,
          1058.237,
          1045.642,
          1033.012,
          1020.3489999999999,
          1007.6519999999999,
          994.922,
          982.16,
          969.3660000000001,
          956.54,
          943.684,
          930.798,
          917.883,
          904.938,
          891.9639999999999,
          878.9630000000001,
          865.934,
          852.878,
          839.795,
          826.687,
          813.553,
          800.3939999999999,
          787.211,
          774.003,
          760.773,
          747.5189999999999,
          734.243,
          720.945,
          707.6260000000001,
          694.2860000000001,
          680.925,
          667.544,
          654.144,
          640.725,
          627.288,
          613.8330000000001,
          600.36,
          586.87,
          573.364,
          559.842,
          546.304,
          532.752,
          519.185,
          505.603,
          492.009,
          478.401,
          464.781,
          451.149,
          437.505,
          423.85,
          410.185,
          396.51,
          382.825,
          369.131,
          355.42800000000005,
          341.718,
          327.999,
          314.274,
          300.543,
          286.805,
          273.061,
          259.313,
          245.56,
          231.803,
          218.043,
          204.28,
          190.514,
          176.747,
          162.97799999999998,
          149.208,
          135.438,
          121.66799999999999,
          107.899,
          94.131,
          80.365,
          66.602,
          52.841,
          39.084,
          25.331999999999997,
          11.583,
          -2.16,
          -15.897,
          -29.627,
          -43.351000000000006,
          -57.067,
          -70.775,
          -84.47399999999999,
          -98.164,
          -111.844,
          -125.51299999999999,
          -139.171,
          -152.817,
          -166.45,
          -180.07,
          -193.67700000000002,
          -207.269,
          -220.845,
          -234.40599999999998,
          -247.95,
          -261.47700000000003,
          -274.986,
          -288.47700000000003,
          -301.948,
          -315.399,
          -328.829,
          -342.23699999999997,
          -355.62300000000005,
          -368.986,
          -382.325,
          -395.639,
          -408.92800000000005,
          -422.19,
          -435.425,
          -448.63199999999995,
          -461.81,
          -474.959,
          -488.07599999999996,
          -501.162,
          -514.216,
          -527.237,
          -540.2230000000001,
          -553.173,
          -566.0880000000001,
          -578.965,
          -591.804,
          -604.6030000000001,
          -617.362,
          -630.08,
          -642.755,
          -655.387,
          -667.9730000000001,
          -680.5139999999999,
          -693.008,
          -705.453,
          -717.8489999999999,
          -730.194,
          -742.488,
          -754.727,
          -766.9119999999999,
          -779.041,
          -791.113,
          -803.125,
          -815.078,
          -826.9680000000001,
          -838.796,
          -850.558,
          -862.2539999999999,
          -873.882,
          -885.441,
          -896.928,
          -908.341,
          -919.68,
          -930.942,
          -942.1260000000001,
          -953.2289999999999,
          -964.2489999999999,
          -975.185,
          -986.035,
          -996.795,
          -1007.465,
          -1018.041,
          -1028.5230000000001,
          -1038.906,
          -1049.1889999999999,
          -1059.369,
          -1069.445,
          -1079.412,
          -1089.268,
          -1099.011,
          -1108.638,
          -1118.146,
          -1127.531,
          -1136.7910000000002,
          -1145.922,
          -1154.921,
          -1163.785,
          -1172.509,
          -1181.0910000000001,
          -1189.527,
          -1197.812,
          -1205.942,
          -1213.914,
          -1221.723,
          -1229.365,
          -1236.835,
          -1244.128,
          -1251.239,
          -1258.164,
          -1264.896,
          -1271.431,
          -1277.762,
          -1283.885,
          -1289.7910000000002,
          -1295.4769999999999,
          -1300.934,
          -1306.155,
          -1311.135,
          -1315.864,
          -1320.3370000000002,
          -1324.543,
          -1328.476,
          -1332.1270000000002,
          -1335.485,
          -1338.543,
          -1341.29,
          -1343.715,
          -1345.808,
          -1347.559,
          -1348.954,
          -1349.9820000000002,
          -1350.63,
          -1350.885,
          -1350.7320000000002,
          -1350.158,
          -1349.145,
          -1347.68,
          -1345.743,
          -1343.319,
          -1340.388,
          -1336.93,
          -1332.9260000000002,
          -1328.3529999999998,
          -1323.1889999999999,
          -1317.411,
          -1310.993,
          -1303.9089999999999,
          -1296.132,
          -1287.633,
          -1278.381,
          -1268.344,
          -1257.489,
          -1245.781,
          -1233.183,
          -1219.656,
          -1205.16,
          -1189.652,
          -1173.089,
          -1155.425,
          -1136.613,
          -1116.603,
          -1095.346,
          -1072.789,
          -1048.88,
          -1023.566,
          -996.794,
          -968.513,
          -938.671,
          -907.22,
          -874.117,
          -839.32,
          -802.798,
          -764.5260000000001,
          -724.49,
          -682.687,
          -639.13,
          -593.8480000000001,
          -546.889,
          -498.319,
          -448.227,
          -396.722,
          -343.934,
          -290.012,
          -235.12400000000002,
          -179.45,
          -123.182,
          -66.516,
          -9.652000000000001,
          47.215,
          103.898,
          160.218,
          216.015,
          271.14,
          325.465,
          378.87699999999995,
          431.282,
          482.60400000000004,
          532.781,
          581.7669999999999,
          629.5269999999999,
          676.041,
          721.297,
          765.29,
          808.025,
          849.512,
          889.7660000000001,
          928.806,
          966.653,
          1003.332,
          1038.869,
          1073.292,
          1106.629,
          1138.9489999999998,
          1170.1589999999999,
          1200.41,
          1229.69,
          1258.027,
          1285.45,
          1311.984,
          1337.6570000000002,
          1362.495,
          1386.5220000000002,
          1409.763,
          1432.2420000000002,
          1453.98,
          1475,
          1495.3239999999998,
          1514.971,
          1533.961,
          1552.3139999999999,
          1570.047,
          1587.1789999999999,
          1603.725,
          1619.703,
          1635.129,
          1650.017,
          1664.382,
          1678.2379999999998,
          1691.598,
          1704.476,
          1716.885,
          1728.836,
          1740.3410000000001,
          1751.411,
          1762.058,
          1772.2910000000002,
          1782.121,
          1791.558,
          1800.61,
          1809.2879999999998,
          1817.6,
          1825.5539999999999,
          1833.1589999999999,
          1840.422,
          1847.352,
          1853.9560000000001,
          1860.24,
          1866.2120000000002,
          1871.879,
          1877.2479999999998,
          1882.3239999999998,
          1887.1129999999998,
          1891.6229999999998,
          1895.8570000000002,
          1899.8229999999999,
          1903.525,
          1906.97,
          1910.161,
          1913.1029999999998,
          1915.8029999999999,
          1918.264,
          1920.491,
          1922.489,
          1924.261,
          1925.8120000000001,
          1927.146,
          1928.2679999999998,
          1929.18,
          1929.8870000000002,
          1930.392,
          1930.6989999999998,
          1930.8120000000001,
          1930.733,
          1930.4660000000001,
          1930.015,
          1929.3829999999998,
          1928.5710000000001,
          1927.585,
          1926.4260000000002,
          1925.0970000000002,
          1923.602,
          1921.942,
          1920.121,
          1918.141,
          1916.005,
          1913.714,
          1911.273,
          1908.682,
          1905.945,
          1903.0629999999999,
          1900.039,
          1896.875,
          1893.5729999999999,
          1890.135,
          1886.5629999999999,
          1882.859,
          1879.025,
          1875.0639999999999,
          1870.976,
          1866.764,
          1862.43,
          1857.975,
          1853.401,
          1848.7089999999998,
          1843.902,
          1838.981,
          1833.9479999999999,
          1828.8039999999999,
          1823.55,
          1818.1889999999999,
          1812.7220000000002,
          1807.149,
          1801.473,
          1795.695,
          1789.817,
          1783.839,
          1777.764,
          1771.5910000000001,
          1765.3239999999998,
          1758.9620000000002,
          1752.507,
          1745.961,
          1739.3239999999998,
          1732.598,
          1725.7839999999999,
          1718.8829999999998,
          1711.896,
          1704.825,
          1697.67,
          1690.432,
          1683.112,
          1675.7120000000002,
          1668.233,
          1660.675,
          1653.04,
          1645.328,
          1637.5410000000002,
          1629.6789999999999,
          1621.743,
          1613.735,
          1605.655,
          1597.504,
          1589.283,
          1580.9920000000002,
          1572.6329999999998,
          1564.207,
          1555.714,
          1547.155,
          1538.531,
          1529.8429999999998,
          1521.0910000000001,
          1512.277,
          1503.4,
          1494.463,
          1485.465,
          1476.4070000000002,
          1467.2910000000002,
          1458.116,
          1448.884,
          1439.595,
          1430.249,
          1420.848,
          1411.3929999999998,
          1401.8829999999998,
          1392.32,
          1382.704,
          1373.036,
          1363.317,
          1353.547,
          1343.726,
          1333.856,
          1323.9370000000001,
          1313.969,
          1303.954,
          1293.891,
          1283.782,
          1273.626,
          1263.4260000000002,
          1253.18,
          1242.89,
          1232.556,
          1222.1789999999999,
          1211.76,
          1201.298,
          1190.795,
          1180.25,
          1169.6660000000002,
          1159.0410000000002,
          1148.376,
          1137.673,
          1126.931,
          1116.152,
          1105.335,
          1094.481,
          1083.59,
          1072.664,
          1061.702,
          1050.7060000000001,
          1039.674,
          1028.609,
          1017.5110000000001,
          1006.3789999999999,
          995.215,
          984.018,
          972.79,
          961.5310000000001,
          950.2410000000001,
          938.921,
          927.571,
          916.192,
          904.784,
          893.347,
          881.883,
          870.3910000000001,
          858.8710000000001,
          847.325,
          835.753,
          824.155,
          812.5319999999999,
          800.8839999999999,
          789.211,
          777.5139999999999,
          765.794,
          754.05,
          742.284,
          730.495,
          718.684,
          706.852,
          694.9989999999999,
          683.125,
          671.2310000000001,
          659.317,
          647.384,
          635.432,
          623.461,
          611.472,
          599.465,
          587.441,
          575.401,
          563.344,
          551.27,
          539.182,
          527.078,
          514.9590000000001,
          502.82599999999996,
          490.67900000000003,
          478.519,
          466.345,
          454.159,
          441.961,
          429.751,
          417.53,
          405.298,
          393.055,
          380.80300000000005,
          368.54,
          356.269,
          343.98900000000003,
          331.7,
          319.404,
          307.101,
          294.79,
          282.473,
          270.15,
          257.82099999999997,
          245.488,
          233.149,
          220.80700000000002,
          208.46099999999998,
          196.111,
          183.75900000000001,
          171.40400000000002,
          159.048,
          146.69,
          134.33100000000002,
          121.973,
          109.61399999999999,
          97.256,
          84.899,
          72.544,
          60.191,
          47.84,
          35.493,
          23.15,
          10.811,
          -1.5230000000000001,
          -13.852,
          -26.175,
          -38.491,
          -50.8,
          -63.102,
          -75.395,
          -87.679,
          -99.954,
          -112.219,
          -124.473,
          -136.716,
          -148.947,
          -161.166,
          -173.37099999999998,
          -185.562,
          -197.739,
          -209.90099999999998,
          -222.047,
          -234.176,
          -246.28799999999998,
          -258.382,
          -270.457,
          -282.513,
          -294.54900000000004,
          -306.563,
          -318.556,
          -330.526,
          -342.473,
          -354.39599999999996,
          -366.29400000000004,
          -378.165,
          -390.01,
          -401.82800000000003,
          -413.616,
          -425.376,
          -437.105,
          -448.80199999999996,
          -460.468,
          -472.1,
          -483.69800000000004,
          -495.26,
          -506.786,
          -518.275,
          -529.725,
          -541.135,
          -552.504,
          -563.832,
          -575.116,
          -586.356,
          -597.55,
          -608.697,
          -619.7959999999999,
          -630.846,
          -641.844,
          -652.79,
          -663.682,
          -674.518,
          -685.298,
          -696.02,
          -706.681,
          -717.2810000000001,
          -727.817,
          -738.289,
          -748.694,
          -759.03,
          -769.295,
          -779.488,
          -789.607,
          -799.65,
          -809.6139999999999,
          -819.497,
          -829.298,
          -839.013,
          -848.6410000000001,
          -858.179,
          -867.625,
          -876.9760000000001,
          -886.23,
          -895.383,
          -904.434,
          -913.378,
          -922.2130000000001,
          -930.937,
          -939.545,
          -948.035,
          -956.403,
          -964.6460000000001,
          -972.76,
          -980.7410000000001,
          -988.585,
          -996.289,
          -1003.847,
          -1011.257,
          -1018.512,
          -1025.61,
          -1032.5439999999999,
          -1039.31,
          -1045.903,
          -1052.316,
          -1058.546,
          -1064.585,
          -1070.427,
          -1076.067,
          -1081.497,
          -1086.712,
          -1091.703,
          -1096.463,
          -1100.985,
          -1105.26,
          -1109.28,
          -1113.036,
          -1116.519,
          -1119.719,
          -1122.626,
          -1125.23,
          -1127.519,
          -1129.482,
          -1131.106,
          -1132.38,
          -1133.289,
          -1133.8210000000001,
          -1133.9589999999998,
          -1133.688,
          -1132.993,
          -1131.857,
          -1130.261,
          -1128.187,
          -1125.614,
          -1122.5230000000001,
          -1118.891,
          -1114.695,
          -1109.911,
          -1104.513,
          -1098.474,
          -1091.767,
          -1084.361,
          -1076.225,
          -1067.327,
          -1057.631,
          -1047.101,
          -1035.7,
          -1023.387,
          -1010.122,
          -995.862,
          -980.56,
          -964.173,
          -946.65,
          -927.945,
          -908.008,
          -886.788,
          -864.2360000000001,
          -840.303,
          -814.942,
          -788.1080000000001,
          -759.76,
          -729.863,
          -698.3860000000001,
          -665.31,
          -630.623,
          -594.327,
          -556.437,
          -516.984,
          -476.01800000000003,
          -433.60400000000004,
          -389.829,
          -344.79699999999997,
          -298.632,
          -251.472,
          -203.47,
          -154.791,
          -105.604,
          -56.085,
          -6.405,
          43.266000000000005,
          92.77,
          141.957,
          190.692,
          238.852,
          286.33299999999997,
          333.043,
          378.906,
          423.86,
          467.856,
          510.85699999999997,
          552.835,
          593.774,
          633.664,
          672.503,
          710.2919999999999,
          747.0419999999999,
          782.7639999999999,
          817.472,
          851.184,
          883.919,
          915.698,
          946.543,
          976.477,
          1005.523,
          1033.703,
          1061.0410000000002,
          1087.559,
          1113.281,
          1138.229,
          1162.425,
          1185.89,
          1208.646,
          1230.711,
          1252.107,
          1272.853,
          1292.9660000000001,
          1312.465,
          1331.3670000000002,
          1349.6889999999999,
          1367.4470000000001,
          1384.656,
          1401.3329999999999,
          1417.49,
          1433.1429999999998,
          1448.305,
          1462.9879999999998,
          1477.2060000000001,
          1490.97,
          1504.293,
          1517.185,
          1529.6570000000002,
          1541.72,
          1553.384,
          1564.6589999999999,
          1575.5539999999999,
          1586.078,
          1596.241,
          1606.05,
          1615.513,
          1624.64,
          1633.4370000000001,
          1641.912,
          1650.0720000000001,
          1657.924,
          1665.475,
          1672.731,
          1679.6989999999998,
          1686.384,
          1692.793,
          1698.932,
          1704.805,
          1710.4189999999999,
          1715.7779999999998,
          1720.888,
          1725.754,
          1730.38,
          1734.771,
          1738.932,
          1742.8670000000002,
          1746.58,
          1750.075,
          1753.356,
          1756.4289999999999,
          1759.295,
          1761.9589999999998,
          1764.424,
          1766.695,
          1768.774,
          1770.665,
          1772.37,
          1773.894,
          1775.24,
          1776.4089999999999,
          1777.406,
          1778.233,
          1778.8929999999998,
          1779.388,
          1779.7220000000002,
          1779.8970000000002,
          1779.915,
          1779.779,
          1779.491,
          1779.0539999999999,
          1778.47,
          1777.741,
          1776.87,
          1775.858,
          1774.7079999999999,
          1773.422,
          1772.0020000000002,
          1770.4489999999998,
          1768.766,
          1766.955,
          1765.017,
          1762.955,
          1760.769,
          1758.463,
          1756.037,
          1753.493,
          1750.8329999999999,
          1748.058,
          1745.17,
          1742.171,
          1739.0620000000001,
          1735.844,
          1732.52,
          1729.089,
          1725.555,
          1721.918,
          1718.1789999999999,
          1714.34,
          1710.402,
          1706.3670000000002,
          1702.235,
          1698.0079999999998,
          1693.6870000000001,
          1689.274,
          1684.769,
          1680.174,
          1675.489,
          1670.7160000000001,
          1665.856,
          1660.91,
          1655.879,
          1650.765,
          1645.567,
          1640.287,
          1634.9270000000001,
          1629.486,
          1623.967,
          1618.369,
          1612.694,
          1606.943,
          1601.1170000000002,
          1595.2160000000001,
          1589.2420000000002,
          1583.195,
          1577.076,
          1570.886,
          1564.625,
          1558.296,
          1551.8970000000002,
          1545.431,
          1538.898,
          1532.2979999999998,
          1525.6329999999998,
          1518.902,
          1512.108,
          1505.25,
          1498.33,
          1491.348,
          1484.3039999999999,
          1477.1989999999998,
          1470.035,
          1462.8120000000001,
          1455.529,
          1448.1889999999999,
          1440.7910000000002,
          1433.3370000000002,
          1425.8270000000002,
          1418.261,
          1410.64,
          1402.964,
          1395.236,
          1387.454,
          1379.619,
          1371.733,
          1363.795,
          1355.806,
          1347.767,
          1339.6779999999999,
          1331.54,
          1323.3529999999998,
          1315.118,
          1306.836,
          1298.506,
          1290.13,
          1281.708,
          1273.24,
          1264.7269999999999,
          1256.1689999999999,
          1247.568,
          1238.922,
          1230.234,
          1221.502,
          1212.729,
          1203.913,
          1195.057,
          1186.1589999999999,
          1177.221,
          1168.244,
          1159.226,
          1150.17,
          1141.075,
          1131.941,
          1122.77,
          1113.5610000000001,
          1104.316,
          1095.0339999999999,
          1085.7160000000001,
          1076.362,
          1066.973,
          1057.549,
          1048.09,
          1038.598,
          1029.072,
          1019.512,
          1009.919,
          1000.294,
          990.637,
          980.948,
          971.2280000000001,
          961.477,
          951.695,
          941.883,
          932.041,
          922.17,
          912.2689999999999,
          902.34,
          892.382,
          882.3960000000001,
          872.383,
          862.342,
          852.275,
          842.181,
          832.06,
          821.914,
          811.743,
          801.546,
          791.324,
          781.078,
          770.808,
          760.5139999999999,
          750.197,
          739.857,
          729.4939999999999,
          719.1089999999999,
          708.702,
          698.273,
          687.823,
          677.352,
          666.86,
          656.3480000000001,
          645.816,
          635.265,
          624.695,
          614.105,
          603.498,
          592.872,
          582.2280000000001,
          571.567,
          560.889,
          550.194,
          539.482,
          528.755,
          518.012,
          507.25300000000004,
          496.48,
          485.69199999999995,
          474.89,
          464.074,
          453.244,
          442.401,
          431.546,
          420.67800000000005,
          409.798,
          398.906,
          388.00300000000004,
          377.089,
          366.164,
          355.22900000000004,
          344.285,
          333.33099999999996,
          322.368,
          311.39599999999996,
          300.416,
          289.428,
          278.433,
          267.431,
          256.422,
          245.407,
          234.386,
          223.36,
          212.329,
          201.293,
          190.253,
          179.209,
          168.162,
          157.113,
          146.061,
          135.007,
          123.95200000000001,
          112.895,
          101.839,
          90.78200000000001,
          79.726,
          68.67,
          57.61600000000001,
          46.56399999999999,
          35.515,
          24.468000000000004,
          13.425999999999998,
          2.387,
          -8.648,
          -19.677,
          -30.701,
          -41.718,
          -52.728,
          -63.731,
          -74.727,
          -85.713,
          -96.69,
          -107.65799999999999,
          -118.615,
          -129.561,
          -140.495,
          -151.416,
          -162.325,
          -173.21900000000002,
          -184.1,
          -194.96400000000003,
          -205.813,
          -216.646,
          -227.46,
          -238.257,
          -249.03400000000002,
          -259.791,
          -270.528,
          -281.243,
          -291.936,
          -302.605,
          -313.25,
          -323.87,
          -334.464,
          -345.031,
          -355.57,
          -366.079,
          -376.559,
          -387.00699999999995,
          -397.423,
          -407.806,
          -418.154,
          -428.467,
          -438.74199999999996,
          -448.97900000000004,
          -459.17699999999996,
          -469.335,
          -479.45,
          -489.52099999999996,
          -499.548,
          -509.529,
          -519.461,
          -529.345,
          -539.177,
          -548.957,
          -558.683,
          -568.3530000000001,
          -577.965,
          -587.518,
          -597.009,
          -606.437,
          -615.8,
          -625.095,
          -634.321,
          -643.475,
          -652.556,
          -661.56,
          -670.485,
          -679.329,
          -688.0889999999999,
          -696.763,
          -705.347,
          -713.84,
          -722.237,
          -730.5360000000001,
          -738.7339999999999,
          -746.828,
          -754.813,
          -762.687,
          -770.445,
          -778.085,
          -785.602,
          -792.9910000000001,
          -800.2489999999999,
          -807.3710000000001,
          -814.3530000000001,
          -821.189,
          -827.875,
          -834.405,
          -840.7739999999999,
          -846.977,
          -853.0060000000001,
          -858.857,
          -864.523,
          -869.9960000000001,
          -875.2710000000001,
          -880.3380000000001,
          -885.192,
          -889.823,
          -894.2230000000001,
          -898.3839999999999,
          -902.296,
          -905.948,
          -909.332,
          -912.437,
          -915.25,
          -917.76,
          -919.955,
          -921.822,
          -923.347,
          -924.515,
          -925.311,
          -925.7180000000001,
          -925.721,
          -925.301,
          -924.439,
          -923.115,
          -921.309,
          -918.998,
          -916.159,
          -912.7660000000001,
          -908.796,
          -904.2180000000001,
          -899.0060000000001,
          -893.1289999999999,
          -886.554,
          -879.247,
          -871.175,
          -862.298,
          -852.58,
          -841.9789999999999,
          -830.454,
          -817.96,
          -804.454,
          -789.8889999999999,
          -774.2180000000001,
          -757.395,
          -739.373,
          -720.105,
          -699.547,
          -677.6569999999999,
          -654.395,
          -629.73,
          -603.634,
          -576.087,
          -547.082,
          -516.619,
          -484.715,
          -451.399,
          -416.717,
          -380.733,
          -343.527,
          -305.193,
          -265.844,
          -225.604,
          -184.609,
          -143.004,
          -100.93700000000001,
          -58.556999999999995,
          -16.012999999999998,
          26.554000000000002,
          69.01,
          111.23100000000001,
          153.105,
          194.53099999999998,
          235.423,
          275.705,
          315.316,
          354.204,
          392.32800000000003,
          429.658,
          466.17,
          501.85,
          536.687,
          570.679,
          603.827,
          636.135,
          667.6110000000001,
          698.2669999999999,
          728.113,
          757.165,
          785.438,
          812.948,
          839.712,
          865.747,
          891.072,
          915.703,
          939.658,
          962.956,
          985.612,
          1007.645,
          1029.0710000000001,
          1049.905,
          1070.165,
          1089.864,
          1109.02,
          1127.645,
          1145.755,
          1163.362,
          1180.481,
          1197.124,
          1213.303,
          1229.032,
          1244.32,
          1259.18,
          1273.622,
          1287.6580000000001,
          1301.296,
          1314.547,
          1327.42,
          1339.925,
          1352.07,
          1363.864,
          1375.315,
          1386.431,
          1397.219,
          1407.6879999999999,
          1417.845,
          1427.6960000000001,
          1437.2479999999998,
          1446.5079999999998,
          1455.4820000000002,
          1464.1760000000002,
          1472.596,
          1480.7479999999998,
          1488.638,
          1496.27,
          1503.651,
          1510.785,
          1517.6770000000001,
          1524.332,
          1530.754,
          1536.9489999999998,
          1542.92,
          1548.672,
          1554.2079999999999,
          1559.5339999999999,
          1564.652,
          1569.566,
          1574.281,
          1578.8,
          1583.126,
          1587.2620000000002,
          1591.213,
          1594.981,
          1598.569,
          1601.98,
          1605.2179999999998,
          1608.285,
          1611.185,
          1613.9189999999999,
          1616.491,
          1618.902,
          1621.1570000000002,
          1623.257,
          1625.204,
          1627.0020000000002,
          1628.651,
          1630.156,
          1631.517,
          1632.737,
          1633.818,
          1634.763,
          1635.5720000000001,
          1636.249,
          1636.795,
          1637.211,
          1637.501,
          1637.665,
          1637.705,
          1637.624,
          1637.422,
          1637.102,
          1636.665,
          1636.1129999999998,
          1635.4460000000001,
          1634.668,
          1633.7779999999998,
          1632.78,
          1631.6729999999998,
          1630.46,
          1629.142,
          1627.72,
          1626.1960000000001,
          1624.57,
          1622.845,
          1621.021,
          1619.1,
          1617.0829999999999,
          1614.97,
          1612.764,
          1610.465,
          1608.075,
          1605.594,
          1603.024,
          1600.365,
          1597.619,
          1594.787,
          1591.869,
          1588.8670000000002,
          1585.7820000000002,
          1582.615,
          1579.366,
          1576.037,
          1572.628,
          1569.14,
          1565.575,
          1561.932,
          1558.214,
          1554.42,
          1550.5520000000001,
          1546.61,
          1542.595,
          1538.5079999999998,
          1534.35,
          1530.122,
          1525.8229999999999,
          1521.4560000000001,
          1517.02,
          1512.517,
          1507.9460000000001,
          1503.31,
          1498.608,
          1493.8410000000001,
          1489.01,
          1484.115,
          1479.158,
          1474.138,
          1469.056,
          1463.914,
          1458.711,
          1453.4479999999999,
          1448.1270000000002,
          1442.746,
          1437.307,
          1431.8110000000001,
          1426.2579999999998,
          1420.649,
          1414.984,
          1409.263,
          1403.4879999999998,
          1397.6589999999999,
          1391.776,
          1385.839,
          1379.85,
          1373.809,
          1367.7160000000001,
          1361.5720000000001,
          1355.3770000000002,
          1349.132,
          1342.8370000000002,
          1336.493,
          1330.099,
          1323.658,
          1317.168,
          1310.631,
          1304.047,
          1297.417,
          1290.74,
          1284.017,
          1277.249,
          1270.4360000000001,
          1263.578,
          1256.6760000000002,
          1249.731,
          1242.742,
          1235.71,
          1228.636,
          1221.519,
          1214.361,
          1207.161,
          1199.92,
          1192.639,
          1185.317,
          1177.955,
          1170.5539999999999,
          1163.113,
          1155.634,
          1148.116,
          1140.56,
          1132.9660000000001,
          1125.335,
          1117.6660000000002,
          1109.961,
          1102.219,
          1094.441,
          1086.627,
          1078.778,
          1070.893,
          1062.974,
          1055.02,
          1047.032,
          1039.01,
          1030.954,
          1022.8660000000001,
          1014.7439999999999,
          1006.5889999999999,
          998.4019999999999,
          990.183,
          981.933,
          973.65,
          965.337,
          956.993,
          948.618,
          940.2130000000001,
          931.778,
          923.313,
          914.819,
          906.295,
          897.743,
          889.1619999999999,
          880.553,
          871.916,
          863.2510000000001,
          854.558,
          845.8389999999999,
          837.092,
          828.319,
          819.52,
          810.695,
          801.8430000000001,
          792.966,
          784.064,
          775.137,
          766.186,
          757.21,
          748.209,
          739.185,
          730.137,
          721.066,
          711.972,
          702.855,
          693.715,
          684.553,
          675.37,
          666.164,
          656.937,
          647.689,
          638.42,
          629.13,
          619.82,
          610.49,
          601.14,
          591.771,
          582.382,
          572.975,
          563.548,
          554.104,
          544.641,
          535.16,
          525.6619999999999,
          516.1469999999999,
          506.61400000000003,
          497.065,
          487.5,
          477.918,
          468.32099999999997,
          458.708,
          449.079,
          439.436,
          429.779,
          420.10699999999997,
          410.421,
          400.721,
          391.00800000000004,
          381.282,
          371.543,
          361.792,
          352.029,
          342.254,
          332.468,
          322.67,
          312.862,
          303.043,
          293.215,
          283.376,
          273.528,
          263.672,
          253.80700000000002,
          243.933,
          234.05200000000002,
          224.16299999999998,
          214.267,
          204.364,
          194.456,
          184.541,
          174.62099999999998,
          164.695,
          154.765,
          144.83100000000002,
          134.893,
          124.95200000000001,
          115.008,
          105.061,
          95.113,
          85.163,
          75.212,
          65.26100000000001,
          55.31,
          45.358999999999995,
          35.409,
          25.461,
          15.515,
          5.572,
          -4.368,
          -14.304,
          -24.235,
          -34.161,
          -44.082,
          -53.997,
          -63.903999999999996,
          -73.804,
          -83.695,
          -93.57799999999999,
          -103.45,
          -113.31200000000001,
          -123.163,
          -133.002,
          -142.829,
          -152.641,
          -162.44,
          -172.22299999999998,
          -181.989,
          -191.739,
          -201.47099999999998,
          -211.18400000000003,
          -220.877,
          -230.55,
          -240.2,
          -249.828,
          -259.432,
          -269.01,
          -278.562,
          -288.087,
          -297.58299999999997,
          -307.04900000000004,
          -316.48400000000004,
          -325.88599999999997,
          -335.255,
          -344.588,
          -353.884,
          -363.142,
          -372.36,
          -381.537,
          -390.67,
          -399.759,
          -408.801,
          -417.79400000000004,
          -426.73699999999997,
          -435.62699999999995,
          -444.463,
          -453.24199999999996,
          -461.963,
          -470.62199999999996,
          -479.218,
          -487.74800000000005,
          -496.21,
          -504.6,
          -512.9169999999999,
          -521.156,
          -529.316,
          -537.393,
          -545.384,
          -553.286,
          -561.095,
          -568.807,
          -576.419,
          -583.9259999999999,
          -591.325,
          -598.611,
          -605.78,
          -612.827,
          -619.746,
          -626.534,
          -633.184,
          -639.691,
          -646.048,
          -652.251,
          -658.291,
          -664.163,
          -669.8589999999999,
          -675.372,
          -680.693,
          -685.814,
          -690.727,
          -695.423,
          -699.8910000000001,
          -704.1210000000001,
          -708.1030000000001,
          -711.826,
          -715.2760000000001,
          -718.442,
          -721.311,
          -723.867,
          -726.096,
          -727.9830000000001,
          -729.51,
          -730.66,
          -731.414,
          -731.753,
          -731.655,
          -731.0980000000001,
          -730.058,
          -728.512,
          -726.432,
          -723.791,
          -720.56,
          -716.707,
          -712.2,
          -707.005,
          -701.085,
          -694.404,
          -686.922,
          -678.5980000000001,
          -669.39,
          -659.2539999999999,
          -648.1469999999999,
          -636.024,
          -622.839,
          -608.55,
          -593.112,
          -576.485,
          -558.632,
          -539.52,
          -519.123,
          -497.42,
          -474.403,
          -450.07099999999997,
          -424.436,
          -397.524,
          -369.375,
          -340.04400000000004,
          -309.601,
          -278.129,
          -245.72400000000002,
          -212.495,
          -178.55900000000003,
          -144.037,
          -109.056,
          -73.742,
          -38.219,
          -2.603,
          32.992,
          68.465,
          103.723,
          138.683,
          173.271,
          207.426,
          241.09599999999998,
          274.235,
          306.809,
          338.79,
          370.157,
          400.894,
          430.991,
          460.44199999999995,
          489.245,
          517.401,
          544.913,
          571.7869999999999,
          598.031,
          623.653,
          648.844,
          673.072,
          696.8919999999999,
          720.135,
          742.812,
          764.937,
          786.5210000000001,
          807.578,
          828.12,
          848.158,
          867.707,
          886.7760000000001,
          905.3789999999999,
          923.5260000000001,
          941.2289999999999,
          958.4989999999999,
          975.347,
          991.7819999999999,
          1007.815,
          1023.456,
          1038.715,
          1053.6,
          1068.12,
          1082.2839999999999,
          1096.101,
          1109.578,
          1122.723,
          1135.545,
          1148.05,
          1160.246,
          1172.14,
          1183.737,
          1195.046,
          1206.0710000000001,
          1216.82,
          1227.298,
          1237.51,
          1247.463,
          1257.162,
          1266.611,
          1275.817,
          1284.7830000000001,
          1293.515,
          1302.018,
          1310.295,
          1318.351,
          1326.191,
          1333.818,
          1341.237,
          1348.45,
          1355.463,
          1362.279,
          1368.901,
          1375.332,
          1381.5770000000002,
          1387.638,
          1393.519,
          1399.2220000000002,
          1404.751,
          1410.109,
          1415.297,
          1420.3210000000001,
          1425.181,
          1429.881,
          1434.422,
          1438.809,
          1443.043,
          1447.126,
          1451.0610000000001,
          1454.85,
          1458.496,
          1462,
          1465.365,
          1468.592,
          1471.684,
          1474.6429999999998,
          1477.471,
          1480.1689999999999,
          1482.739,
          1485.184,
          1487.504,
          1489.7020000000002,
          1491.779,
          1493.7379999999998,
          1495.578,
          1497.3029999999999,
          1498.914,
          1500.412,
          1501.7979999999998,
          1503.0739999999998,
          1504.2420000000002,
          1505.3029999999999,
          1506.2579999999998,
          1507.109,
          1507.8570000000002,
          1508.503,
          1509.0479999999998,
          1509.494,
          1509.8410000000001,
          1510.092,
          1510.247,
          1510.307,
          1510.274,
          1510.148,
          1509.931,
          1509.624,
          1509.227,
          1508.7420000000002,
          1508.1689999999999,
          1507.51,
          1506.766,
          1505.9379999999999,
          1505.026,
          1504.031,
          1502.955,
          1501.797,
          1500.56,
          1499.244,
          1497.849,
          1496.3770000000002,
          1494.829,
          1493.204,
          1491.505,
          1489.731,
          1487.8829999999998,
          1485.963,
          1483.97,
          1481.906,
          1479.7720000000002,
          1477.567,
          1475.293,
          1472.951,
          1470.54,
          1468.0629999999999,
          1465.5179999999998,
          1462.9070000000002,
          1460.231,
          1457.49,
          1454.685,
          1451.817,
          1448.885,
          1445.891,
          1442.8339999999998,
          1439.717,
          1436.5379999999998,
          1433.3,
          1430.001,
          1426.644,
          1423.227,
          1419.753,
          1416.221,
          1412.631,
          1408.985,
          1405.283,
          1401.525,
          1397.7120000000002,
          1393.844,
          1389.921,
          1385.945,
          1381.915,
          1377.832,
          1373.6970000000001,
          1369.509,
          1365.27,
          1360.979,
          1356.638,
          1352.246,
          1347.8029999999999,
          1343.3120000000001,
          1338.77,
          1334.18,
          1329.5410000000002,
          1324.855,
          1320.12,
          1315.338,
          1310.508,
          1305.632,
          1300.71,
          1295.741,
          1290.7269999999999,
          1285.6680000000001,
          1280.563,
          1275.414,
          1270.22,
          1264.983,
          1259.701,
          1254.377,
          1249.009,
          1243.598,
          1238.145,
          1232.65,
          1227.113,
          1221.5339999999999,
          1215.914,
          1210.253,
          1204.5510000000002,
          1198.809,
          1193.027,
          1187.204,
          1181.343,
          1175.442,
          1169.501,
          1163.5230000000001,
          1157.505,
          1151.4489999999998,
          1145.356,
          1139.224,
          1133.055,
          1126.849,
          1120.606,
          1114.326,
          1108.009,
          1101.657,
          1095.268,
          1088.843,
          1082.383,
          1075.888,
          1069.357,
          1062.792,
          1056.192,
          1049.557,
          1042.889,
          1036.1860000000001,
          1029.45,
          1022.68,
          1015.877,
          1009.041,
          1002.172,
          995.27,
          988.336,
          981.37,
          974.3710000000001,
          967.341,
          960.279,
          953.186,
          946.062,
          938.9060000000001,
          931.72,
          924.503,
          917.2560000000001,
          909.9789999999999,
          902.671,
          895.334,
          887.967,
          880.571,
          873.145,
          865.691,
          858.2080000000001,
          850.696,
          843.155,
          835.586,
          827.99,
          820.365,
          812.712,
          805.033,
          797.325,
          789.591,
          781.83,
          774.0419999999999,
          766.227,
          758.3860000000001,
          750.5189999999999,
          742.6260000000001,
          734.707,
          726.763,
          718.793,
          710.797,
          702.7769999999999,
          694.732,
          686.6619999999999,
          678.568,
          670.449,
          662.307,
          654.14,
          645.95,
          637.736,
          629.499,
          621.238,
          612.955,
          604.649,
          596.321,
          587.97,
          579.597,
          571.202,
          562.786,
          554.347,
          545.888,
          537.408,
          528.906,
          520.384,
          511.842,
          503.279,
          494.69599999999997,
          486.093,
          477.471,
          468.83,
          460.16900000000004,
          451.49,
          442.792,
          434.075,
          425.34,
          416.588,
          407.81800000000004,
          399.03,
          390.225,
          381.404,
          372.565,
          363.711,
          354.84,
          345.95300000000003,
          337.051,
          328.134,
          319.202,
          310.255,
          301.29400000000004,
          292.319,
          283.33,
          274.328,
          265.312,
          256.285,
          247.24400000000003,
          238.192,
          229.128,
          220.053,
          210.967,
          201.87,
          192.763,
          183.64700000000002,
          174.521,
          165.386,
          156.243,
          147.092,
          137.933,
          128.768,
          119.595,
          110.417,
          101.23299999999999,
          92.044,
          82.85,
          73.653,
          64.452,
          55.248000000000005,
          46.042,
          36.834,
          27.625,
          18.416,
          9.207,
          0,
          -9.206,
          -18.409000000000002,
          -27.61,
          -36.806,
          -45.997,
          -55.181999999999995,
          -64.361,
          -73.532,
          -82.695,
          -91.84899999999999,
          -100.992,
          -110.124,
          -119.243,
          -128.349,
          -137.44,
          -146.515,
          -155.57299999999998,
          -164.613,
          -173.63299999999998,
          -182.63099999999997,
          -191.607,
          -200.55900000000003,
          -209.486,
          -218.385,
          -227.255,
          -236.095,
          -244.90200000000002,
          -253.675,
          -262.41200000000003,
          -271.11,
          -279.768,
          -288.382,
          -296.952,
          -305.475,
          -313.947,
          -322.366,
          -330.731,
          -339.036,
          -347.28,
          -355.46,
          -363.57099999999997,
          -371.611,
          -379.57599999999996,
          -387.462,
          -395.264,
          -402.98,
          -410.603,
          -418.13,
          -425.555,
          -432.874,
          -440.08099999999996,
          -447.16900000000004,
          -454.134,
          -460.968,
          -467.665,
          -474.217,
          -480.61699999999996,
          -486.85699999999997,
          -492.92900000000003,
          -498.82300000000004,
          -504.53,
          -510.041,
          -515.3430000000001,
          -520.4259999999999,
          -525.279,
          -529.887,
          -534.238,
          -538.318,
          -542.11,
          -545.599,
          -548.7669999999999,
          -551.597,
          -554.068,
          -556.159,
          -557.849,
          -559.114,
          -559.93,
          -560.268,
          -560.1030000000001,
          -559.403,
          -558.138,
          -556.273,
          -553.775,
          -550.607,
          -546.729,
          -542.1030000000001,
          -536.688,
          -530.44,
          -523.317,
          -515.275,
          -506.27099999999996,
          -496.264,
          -485.21,
          -473.07300000000004,
          -459.819,
          -445.41900000000004,
          -429.85,
          -413.098,
          -395.159,
          -376.038,
          -355.75199999999995,
          -334.333,
          -311.822,
          -288.277,
          -263.76599999999996,
          -238.36700000000002,
          -212.171,
          -185.273,
          -157.774,
          -129.78,
          -101.39200000000001,
          -72.715,
          -43.843999999999994,
          -14.873,
          14.114,
          43.038000000000004,
          71.829,
          100.427,
          128.775,
          156.829,
          184.549,
          211.90200000000002,
          238.861,
          265.405,
          291.51599999999996,
          317.183,
          342.395,
          367.147,
          391.435,
          415.25800000000004,
          438.61699999999996,
          461.514,
          483.952,
          505.93699999999995,
          527.474,
          548.569,
          569.229,
          589.46,
          609.2719999999999,
          628.67,
          647.664,
          666.262,
          684.47,
          702.298,
          719.753,
          736.8439999999999,
          753.577,
          769.961,
          786.0039999999999,
          801.712,
          817.0930000000001,
          832.154,
          846.9019999999999,
          861.3439999999999,
          875.4860000000001,
          889.335,
          902.8969999999999,
          916.178,
          929.184,
          941.921,
          954.3939999999999,
          966.6089999999999,
          978.571,
          990.2860000000001,
          1001.757,
          1012.9910000000001,
          1023.9910000000001,
          1034.763,
          1045.3110000000001,
          1055.639,
          1065.752,
          1075.653,
          1085.346,
          1094.835,
          1104.125,
          1113.218,
          1122.118,
          1130.829,
          1139.354,
          1147.6960000000001,
          1155.859,
          1163.845,
          1171.6580000000001,
          1179.3,
          1186.774,
          1194.0839999999998,
          1201.231,
          1208.219,
          1215.05,
          1221.726,
          1228.25,
          1234.624,
          1240.851,
          1246.933,
          1252.872,
          1258.67,
          1264.329,
          1269.8519999999999,
          1275.24,
          1280.495,
          1285.62,
          1290.615,
          1295.484,
          1300.2269999999999,
          1304.846,
          1309.344,
          1313.721,
          1317.98,
          1322.121,
          1326.1470000000002,
          1330.059,
          1333.858,
          1337.547,
          1341.125,
          1344.596,
          1347.9589999999998,
          1351.217,
          1354.37,
          1357.421,
          1360.37,
          1363.2179999999998,
          1365.9660000000001,
          1368.6170000000002,
          1371.171,
          1373.628,
          1375.991,
          1378.26,
          1380.4360000000001,
          1382.521,
          1384.515,
          1386.42,
          1388.235,
          1389.964,
          1391.605,
          1393.161,
          1394.631,
          1396.0179999999998,
          1397.3220000000001,
          1398.543,
          1399.683,
          1400.7420000000002,
          1401.7220000000002,
          1402.622,
          1403.444,
          1404.1889999999999,
          1404.8570000000002,
          1405.45,
          1405.967,
          1406.4089999999999,
          1406.7779999999998,
          1407.0729999999999,
          1407.297,
          1407.4479999999999,
          1407.5279999999998,
          1407.5379999999998,
          1407.479,
          1407.349,
          1407.152,
          1406.886,
          1406.5529999999999,
          1406.1529999999998,
          1405.6870000000001,
          1405.156,
          1404.559,
          1403.898,
          1403.1729999999998,
          1402.384,
          1401.5320000000002,
          1400.618,
          1399.642,
          1398.605,
          1397.506,
          1396.3470000000002,
          1395.129,
          1393.85,
          1392.513,
          1391.1170000000002,
          1389.662,
          1388.151,
          1386.5810000000001,
          1384.955,
          1383.273,
          1381.5339999999999,
          1379.74,
          1377.891,
          1375.986,
          1374.0279999999998,
          1372.015,
          1369.9489999999998,
          1367.829,
          1365.656,
          1363.431,
          1361.154,
          1358.8239999999998,
          1356.443,
          1354.011,
          1351.5279999999998,
          1348.995,
          1346.412,
          1343.7779999999998,
          1341.095,
          1338.3629999999998,
          1335.582,
          1332.7520000000002,
          1329.874,
          1326.9479999999999,
          1323.974,
          1320.953,
          1317.884,
          1314.769,
          1311.6070000000002,
          1308.3980000000001,
          1305.144,
          1301.844,
          1298.498,
          1295.107,
          1291.671,
          1288.19,
          1284.665,
          1281.095,
          1277.481,
          1273.8239999999998,
          1270.122,
          1266.378,
          1262.59,
          1258.76,
          1254.886,
          1250.971,
          1247.013,
          1243.013,
          1238.971,
          1234.887,
          1230.763,
          1226.597,
          1222.389,
          1218.142,
          1213.853,
          1209.524,
          1205.155,
          1200.746,
          1196.296,
          1191.808,
          1187.279,
          1182.712,
          1178.105,
          1173.4589999999998,
          1168.774,
          1164.0510000000002,
          1159.289,
          1154.489,
          1149.651,
          1144.774,
          1139.86,
          1134.9080000000001,
          1129.9189999999999,
          1124.892,
          1119.828,
          1114.7269999999999,
          1109.589,
          1104.414,
          1099.202,
          1093.954,
          1088.67,
          1083.349,
          1077.992,
          1072.6,
          1067.171,
          1061.7069999999999,
          1056.2069999999999,
          1050.672,
          1045.101,
          1039.495,
          1033.854,
          1028.178,
          1022.467,
          1016.722,
          1010.942,
          1005.127,
          999.278,
          993.395,
          987.4780000000001,
          981.5260000000001,
          975.541,
          969.5219999999999,
          963.4689999999999,
          957.383,
          951.263,
          945.1089999999999,
          938.923,
          932.703,
          926.45,
          920.164,
          913.846,
          907.4939999999999,
          901.11,
          894.693,
          888.2439999999999,
          881.762,
          875.248,
          868.702,
          862.1239999999999,
          855.5139999999999,
          848.8710000000001,
          842.197,
          835.492,
          828.7539999999999,
          821.985,
          815.185,
          808.3530000000001,
          801.49,
          794.596,
          787.671,
          780.7139999999999,
          773.727,
          766.709,
          759.66,
          752.581,
          745.471,
          738.33,
          731.159,
          723.9580000000001,
          716.727,
          709.465,
          702.174,
          694.8530000000001,
          687.502,
          680.1210000000001,
          672.71,
          665.27,
          657.8,
          650.302,
          642.773,
          635.216,
          627.63,
          620.015,
          612.37,
          604.697,
          596.996,
          589.266,
          581.507,
          573.721,
          565.906,
          558.062,
          550.191,
          542.293,
          534.366,
          526.4119999999999,
          518.43,
          510.421,
          502.385,
          494.32099999999997,
          486.231,
          478.11400000000003,
          469.97,
          461.8,
          453.603,
          445.38,
          437.13199999999995,
          428.85699999999997,
          420.556,
          412.231,
          403.879,
          395.50300000000004,
          387.102,
          378.676,
          370.225,
          361.75,
          353.251,
          344.72900000000004,
          336.18199999999996,
          327.612,
          319.019,
          310.403,
          301.765,
          293.10400000000004,
          284.421,
          275.717,
          266.991,
          258.244,
          249.476,
          240.688,
          231.88,
          223.05200000000002,
          214.205,
          205.33900000000003,
          196.455,
          187.553,
          178.63400000000001,
          169.697,
          160.744,
          151.775,
          142.79,
          133.791,
          124.777,
          115.75,
          106.71,
          97.65799999999999,
          88.594,
          79.51899999999999,
          70.434,
          61.34,
          52.238,
          43.128,
          34.012,
          24.89,
          15.764000000000001,
          6.6339999999999995,
          -2.498,
          -11.632,
          -20.765,
          -29.896,
          -39.025,
          -48.15,
          -57.269,
          -66.381,
          -75.483,
          -84.575,
          -93.654,
          -102.719,
          -111.766,
          -120.795,
          -129.803,
          -138.787,
          -147.745,
          -156.674,
          -165.572,
          -174.435,
          -183.25900000000001,
          -192.043,
          -200.78099999999998,
          -209.47099999999998,
          -218.108,
          -226.688,
          -235.207,
          -243.65900000000002,
          -252.04,
          -260.343,
          -268.564,
          -276.69599999999997,
          -284.733,
          -292.66700000000003,
          -300.491,
          -308.197,
          -315.777,
          -323.221,
          -330.52,
          -337.664,
          -344.64,
          -351.43800000000005,
          -358.045,
          -364.44699999999995,
          -370.629,
          -376.57599999999996,
          -382.272,
          -387.69699999999995,
          -392.834,
          -397.661,
          -402.157,
          -406.29699999999997,
          -410.05699999999996,
          -413.41,
          -416.327,
          -418.778,
          -420.73,
          -422.148,
          -422.99800000000005,
          -423.24,
          -422.835,
          -421.741,
          -419.917,
          -417.31800000000004,
          -413.901,
          -409.62199999999996,
          -404.439,
          -398.31,
          -391.19800000000004,
          -383.069,
          -373.89300000000003,
          -363.651,
          -352.327,
          -339.91900000000004,
          -326.431,
          -311.882,
          -296.3,
          -279.724,
          -262.20599999999996,
          -243.80700000000002,
          -224.59599999999998,
          -204.65,
          -184.05,
          -162.879,
          -141.22299999999998,
          -119.164,
          -96.78399999999999,
          -74.15899999999999,
          -51.363,
          -28.46,
          -5.513999999999999,
          17.423,
          40.301,
          63.077,
          85.714,
          108.179,
          130.445,
          152.488,
          174.28900000000002,
          195.831,
          217.102,
          238.092,
          258.791,
          279.194,
          299.298,
          319.098,
          338.593,
          357.783,
          376.66900000000004,
          395.251,
          413.532,
          431.514,
          449.199,
          466.592,
          483.69599999999997,
          500.514,
          517.0509999999999,
          533.311,
          549.298,
          565.016,
          580.47,
          595.665,
          610.6030000000001,
          625.2909999999999,
          639.7330000000001,
          653.932,
          667.8919999999999,
          681.6189999999999,
          695.117,
          708.3889999999999,
          721.439,
          734.2719999999999,
          746.8910000000001,
          759.3,
          771.502,
          783.502,
          795.303,
          806.909,
          818.322,
          829.546,
          840.585,
          851.441,
          862.118,
          872.618,
          882.944,
          893.1,
          903.0889999999999,
          912.9119999999999,
          922.572,
          932.073,
          941.4169999999999,
          950.605,
          959.6410000000001,
          968.5269999999999,
          977.265,
          985.8580000000001,
          994.307,
          1002.615,
          1010.784,
          1018.815,
          1026.712,
          1034.475,
          1042.107,
          1049.61,
          1056.984,
          1064.233,
          1071.358,
          1078.36,
          1085.241,
          1092.003,
          1098.647,
          1105.175,
          1111.588,
          1117.889,
          1124.077,
          1130.155,
          1136.124,
          1141.986,
          1147.741,
          1153.392,
          1158.938,
          1164.382,
          1169.725,
          1174.9669999999999,
          1180.111,
          1185.157,
          1190.105,
          1194.9589999999998,
          1199.718,
          1204.383,
          1208.9560000000001,
          1213.437,
          1217.827,
          1222.129,
          1226.3410000000001,
          1230.4660000000001,
          1234.504,
          1238.4560000000001,
          1242.323,
          1246.106,
          1249.806,
          1253.423,
          1256.958,
          1260.413,
          1263.787,
          1267.0819999999999,
          1270.299,
          1273.437,
          1276.498,
          1279.483,
          1282.393,
          1285.2269999999999,
          1287.986,
          1290.672,
          1293.285,
          1295.826,
          1298.2939999999999,
          1300.692,
          1303.018,
          1305.275,
          1307.462,
          1309.5810000000001,
          1311.631,
          1313.6129999999998,
          1315.5279999999998,
          1317.376,
          1319.1589999999999,
          1320.875,
          1322.527,
          1324.1129999999998,
          1325.636,
          1327.095,
          1328.491,
          1329.8239999999998,
          1331.094,
          1332.3029999999999,
          1333.451,
          1334.537,
          1335.5629999999999,
          1336.529,
          1337.435,
          1338.2820000000002,
          1339.07,
          1339.799,
          1340.47,
          1341.0839999999998,
          1341.64,
          1342.139,
          1342.582,
          1342.9679999999998,
          1343.2979999999998,
          1343.5729999999999,
          1343.7920000000001,
          1343.957,
          1344.067,
          1344.122,
          1344.124,
          1344.0720000000001,
          1343.967,
          1343.809,
          1343.598,
          1343.3339999999998,
          1343.019,
          1342.651,
          1342.2320000000002,
          1341.7620000000002,
          1341.241,
          1340.668,
          1340.046,
          1339.3729999999998,
          1338.65,
          1337.8770000000002,
          1337.055,
          1336.183,
          1335.2620000000002,
          1334.293,
          1333.275,
          1332.2089999999998,
          1331.094,
          1329.932,
          1328.7220000000002,
          1327.464,
          1326.1589999999999,
          1324.807,
          1323.408,
          1321.963,
          1320.471,
          1318.932,
          1317.348,
          1315.717,
          1314.0410000000002,
          1312.319,
          1310.552,
          1308.739,
          1306.882,
          1304.979,
          1303.032,
          1301.0410000000002,
          1299.004,
          1296.924,
          1294.799,
          1292.631,
          1290.4180000000001,
          1288.162,
          1285.862,
          1283.519,
          1281.133,
          1278.703,
          1276.231,
          1273.715,
          1271.157,
          1268.556,
          1265.912,
          1263.2269999999999,
          1260.498,
          1257.728,
          1254.9160000000002,
          1252.0610000000001,
          1249.165,
          1246.2269999999999,
          1243.247,
          1240.226,
          1237.163,
          1234.058,
          1230.913,
          1227.726,
          1224.498,
          1221.229,
          1217.92,
          1214.569,
          1211.177,
          1207.745,
          1204.272,
          1200.758,
          1197.204,
          1193.61,
          1189.975,
          1186.3,
          1182.585,
          1178.829,
          1175.0330000000001,
          1171.197,
          1167.3210000000001,
          1163.406,
          1159.45,
          1155.454,
          1151.4189999999999,
          1147.343,
          1143.228,
          1139.0739999999998,
          1134.879,
          1130.645,
          1126.372,
          1122.058,
          1117.7060000000001,
          1113.313,
          1108.882,
          1104.41,
          1099.9,
          1095.35,
          1090.76,
          1086.132,
          1081.464,
          1076.756,
          1072.01,
          1067.223,
          1062.3980000000001,
          1057.5339999999999,
          1052.63,
          1047.6860000000001,
          1042.704,
          1037.682,
          1032.621,
          1027.521,
          1022.382,
          1017.203,
          1011.985,
          1006.7280000000001,
          1001.431,
          996.095,
          990.72,
          985.305,
          979.8510000000001,
          974.3580000000001,
          968.825,
          963.253,
          957.6419999999999,
          951.9910000000001,
          946.301,
          940.571,
          934.802,
          928.993,
          923.1439999999999,
          917.2560000000001,
          911.329,
          905.3610000000001,
          899.3539999999999,
          893.308,
          887.221,
          881.095,
          874.929,
          868.7230000000001,
          862.477,
          856.191,
          849.865,
          843.4989999999999,
          837.0930000000001,
          830.6469999999999,
          824.16,
          817.6339999999999,
          811.067,
          804.459,
          797.812,
          791.1239999999999,
          784.395,
          777.6260000000001,
          770.816,
          763.965,
          757.074,
          750.1419999999999,
          743.169,
          736.155,
          729.1,
          722.005,
          714.868,
          707.69,
          700.471,
          693.21,
          685.909,
          678.565,
          671.181,
          663.755,
          656.2869999999999,
          648.778,
          641.227,
          633.635,
          626.001,
          618.3240000000001,
          610.606,
          602.847,
          595.045,
          587.201,
          579.315,
          571.387,
          563.4159999999999,
          555.404,
          547.349,
          539.252,
          531.113,
          522.932,
          514.7080000000001,
          506.44199999999995,
          498.13300000000004,
          489.782,
          481.389,
          472.95300000000003,
          464.475,
          455.954,
          447.39099999999996,
          438.786,
          430.139,
          421.449,
          412.717,
          403.94300000000004,
          395.12699999999995,
          386.269,
          377.369,
          368.42699999999996,
          359.444,
          350.41900000000004,
          341.353,
          332.245,
          323.097,
          313.907,
          304.677,
          295.407,
          286.097,
          276.747,
          267.357,
          257.928,
          248.46099999999998,
          238.955,
          229.41099999999997,
          219.83,
          210.21200000000002,
          200.55700000000002,
          190.86700000000002,
          181.142,
          171.382,
          161.588,
          151.762,
          141.904,
          132.014,
          122.095,
          112.147,
          102.171,
          92.169,
          82.141,
          72.09,
          62.016999999999996,
          51.923,
          41.81100000000001,
          31.683000000000003,
          21.54,
          11.385,
          1.22,
          -8.952,
          -19.127,
          -29.304000000000002,
          -39.479,
          -49.648,
          -59.806999999999995,
          -69.952,
          -80.078,
          -90.181,
          -100.256,
          -110.296,
          -120.296,
          -130.249,
          -140.14700000000002,
          -149.983,
          -159.749,
          -169.435,
          -179.03099999999998,
          -188.52599999999998,
          -197.91,
          -207.168,
          -216.28799999999998,
          -225.25400000000002,
          -234.051,
          -242.66,
          -251.063,
          -259.23900000000003,
          -267.166,
          -274.82,
          -282.17400000000004,
          -289.202,
          -295.871,
          -302.151,
          -308.006,
          -313.399,
          -318.29200000000003,
          -322.643,
          -326.408,
          -329.543,
          -332.001,
          -333.736,
          -334.70099999999996,
          -334.848,
          -334.13300000000004,
          -332.514,
          -329.954,
          -326.421,
          -321.887,
          -316.337,
          -309.762,
          -302.163,
          -293.55,
          -283.948,
          -273.389,
          -261.915,
          -249.577,
          -236.43200000000002,
          -222.544,
          -207.979,
          -192.80599999999998,
          -177.09400000000002,
          -160.91,
          -144.322,
          -127.39,
          -110.176,
          -92.734,
          -75.11399999999999,
          -57.363,
          -39.523,
          -21.631,
          -3.721,
          14.177999999999999,
          32.039,
          49.839,
          67.558,
          85.179,
          102.68700000000001,
          120.069,
          137.314,
          154.39700000000002,
          171.358,
          188.142,
          204.761,
          221.209,
          237.484,
          253.583,
          269.503,
          285.244,
          300.805,
          316.184,
          331.38300000000004,
          346.402,
          361.24,
          375.899,
          390.381,
          404.685,
          418.814,
          432.76800000000003,
          446.551,
          460.162,
          473.605,
          486.88,
          499.99,
          512.937,
          525.722,
          538.3480000000001,
          550.816,
          563.129,
          575.2869999999999,
          587.294,
          599.1519999999999,
          610.861,
          622.425,
          633.844,
          645.121,
          656.258,
          667.2560000000001,
          678.118,
          688.8439999999999,
          699.438,
          709.9,
          720.232,
          730.436,
          740.513,
          750.465,
          760.295,
          770.002,
          779.5889999999999,
          789.057,
          798.408,
          807.643,
          816.7639999999999,
          825.7710000000001,
          834.6669999999999,
          843.452,
          852.1289999999999,
          860.697,
          869.159,
          877.515,
          885.768,
          893.9169999999999,
          901.965,
          909.9119999999999,
          917.76,
          925.5089999999999,
          933.16,
          940.716,
          948.176,
          955.541,
          962.814,
          969.9939999999999,
          977.0830000000001,
          984.081,
          990.99,
          997.811,
          1004.543,
          1011.189,
          1017.7489999999999,
          1024.223,
          1030.613,
          1036.92,
          1043.144,
          1049.285,
          1055.346,
          1061.326,
          1067.226,
          1073.047,
          1078.789,
          1084.454,
          1090.042,
          1095.5539999999999,
          1100.99,
          1106.351,
          1111.638,
          1116.85,
          1121.99,
          1127.057,
          1132.052,
          1136.975,
          1141.828,
          1146.61,
          1151.322,
          1155.965,
          1160.54,
          1165.046,
          1169.485,
          1173.856,
          1178.161,
          1182.399,
          1186.572,
          1190.6789999999999,
          1194.721,
          1198.6989999999998,
          1202.613,
          1206.464,
          1210.251,
          1213.976,
          1217.638,
          1221.239,
          1224.778,
          1228.256,
          1231.673,
          1235.03,
          1238.326,
          1241.5639999999999,
          1244.742,
          1247.861,
          1250.921,
          1253.923,
          1256.867,
          1259.754,
          1262.583,
          1265.356,
          1268.072,
          1270.731,
          1273.335,
          1275.882,
          1278.374,
          1280.8110000000001,
          1283.194,
          1285.521,
          1287.7939999999999,
          1290.013,
          1292.178,
          1294.29,
          1296.348,
          1298.353,
          1300.306,
          1302.205,
          1304.052,
          1305.847,
          1307.5910000000001,
          1309.282,
          1310.922,
          1312.51,
          1314.0479999999998,
          1315.535,
          1316.97,
          1318.356,
          1319.691,
          1320.976,
          1322.211,
          1323.396,
          1324.5320000000002,
          1325.618,
          1326.655,
          1327.6429999999998,
          1328.582,
          1329.473,
          1330.3139999999999,
          1331.108,
          1331.8529999999998,
          1332.549,
          1333.1979999999999,
          1333.799,
          1334.352,
          1334.858,
          1335.316,
          1335.727,
          1336.0910000000001,
          1336.4070000000002,
          1336.6760000000002,
          1336.899,
          1337.075,
          1337.204,
          1337.287,
          1337.3229999999999,
          1337.3129999999999,
          1337.257,
          1337.155,
          1337.006,
          1336.8120000000001,
          1336.5710000000001,
          1336.285,
          1335.953,
          1335.576,
          1335.1529999999998,
          1334.685,
          1334.171,
          1333.612,
          1333.007,
          1332.358,
          1331.6629999999998,
          1330.9229999999998,
          1330.138,
          1329.308,
          1328.433,
          1327.514,
          1326.549,
          1325.54,
          1324.486,
          1323.3870000000002,
          1322.244,
          1321.056,
          1319.8229999999999,
          1318.546,
          1317.224,
          1315.858,
          1314.4470000000001,
          1312.9920000000002,
          1311.4920000000002,
          1309.947,
          1308.359,
          1306.726,
          1305.048,
          1303.326,
          1301.56,
          1299.749,
          1297.894,
          1295.994,
          1294.05,
          1292.062,
          1290.029,
          1287.951,
          1285.83,
          1283.663,
          1281.452,
          1279.197,
          1276.897,
          1274.552,
          1272.163,
          1269.729,
          1267.251,
          1264.728,
          1262.16,
          1259.547,
          1256.889,
          1254.187,
          1251.4389999999999,
          1248.647,
          1245.809,
          1242.927,
          1239.999,
          1237.026,
          1234.008,
          1230.944,
          1227.835,
          1224.681,
          1221.481,
          1218.235,
          1214.943,
          1211.606,
          1208.223,
          1204.7939999999999,
          1201.319,
          1197.798,
          1194.23,
          1190.617,
          1186.9560000000001,
          1183.25,
          1179.496,
          1175.6960000000001,
          1171.849,
          1167.955,
          1164.014,
          1160.026,
          1155.991,
          1151.9080000000001,
          1147.777,
          1143.599,
          1139.373,
          1135.099,
          1130.777,
          1126.407,
          1121.989,
          1117.522,
          1113.006,
          1108.442,
          1103.828,
          1099.1660000000002,
          1094.454,
          1089.693,
          1084.882,
          1080.021,
          1075.11,
          1070.15,
          1065.139,
          1060.077,
          1054.965,
          1049.802,
          1044.588,
          1039.323,
          1034.006,
          1028.638,
          1023.2180000000001,
          1017.7460000000001,
          1012.221,
          1006.6439999999999,
          1001.015,
          995.332,
          989.596,
          983.807,
          977.965,
          972.068,
          966.118,
          960.113,
          954.054,
          947.939,
          941.77,
          935.545,
          929.265,
          922.929,
          916.5369999999999,
          910.0880000000001,
          903.5830000000001,
          897.0210000000001,
          890.4010000000001,
          883.7239999999999,
          876.9889999999999,
          870.196,
          863.3439999999999,
          856.434,
          849.465,
          842.436,
          835.3480000000001,
          828.199,
          820.99,
          813.721,
          806.39,
          798.998,
          791.545,
          784.029,
          776.451,
          768.81,
          761.107,
          753.3389999999999,
          745.508,
          737.613,
          729.653,
          721.628,
          713.538,
          705.382,
          697.159,
          688.8710000000001,
          680.515,
          672.092,
          663.602,
          655.043,
          646.4159999999999,
          637.72,
          628.955,
          620.12,
          611.215,
          602.239,
          593.192,
          584.0740000000001,
          574.884,
          565.622,
          556.288,
          546.88,
          537.399,
          527.844,
          518.216,
          508.51199999999994,
          498.73400000000004,
          488.88,
          478.95099999999996,
          468.945,
          458.86400000000003,
          448.705,
          438.47,
          428.157,
          417.767,
          407.29900000000004,
          396.754,
          386.129,
          375.42699999999996,
          364.64599999999996,
          353.786,
          342.848,
          331.83099999999996,
          320.735,
          309.561,
          298.309,
          286.978,
          275.569,
          264.08299999999997,
          252.52,
          240.88,
          229.165,
          217.37400000000002,
          205.50900000000001,
          193.571,
          181.562,
          169.482,
          157.333,
          145.11700000000002,
          132.836,
          120.492,
          108.089,
          95.62799999999999,
          83.113,
          70.548,
          57.937,
          45.284,
          32.595,
          19.874000000000002,
          7.129,
          -5.632999999999999,
          -18.406,
          -31.18,
          -43.945,
          -56.692,
          -69.407,
          -82.08,
          -94.693,
          -107.23299999999999,
          -119.681,
          -132.018,
          -144.221,
          -156.269,
          -168.13299999999998,
          -179.787,
          -191.199,
          -202.335,
          -213.158,
          -223.628,
          -233.703,
          -243.33700000000002,
          -252.481,
          -261.085,
          -269.096,
          -276.459,
          -283.119,
          -289.022,
          -294.115,
          -298.346,
          -301.67,
          -304.045,
          -305.438,
          -305.824,
          -305.185,
          -303.517,
          -300.823,
          -297.119,
          -292.428,
          -286.786,
          -280.233,
          -272.816,
          -264.59,
          -255.61,
          -245.935,
          -235.62400000000002,
          -224.735,
          -213.325,
          -201.449,
          -189.16,
          -176.50599999999997,
          -163.534,
          -150.287,
          -136.80200000000002,
          -123.117,
          -109.264,
          -95.274,
          -81.171,
          -66.983,
          -52.729,
          -38.429,
          -24.101999999999997,
          -9.763,
          4.574,
          18.897000000000002,
          33.194,
          47.455,
          61.672,
          75.837,
          89.94200000000001,
          103.98299999999999,
          117.95299999999999,
          131.84799999999998,
          145.66299999999998,
          159.39600000000002,
          173.042,
          186.6,
          200.06599999999997,
          213.44,
          226.718,
          239.90099999999998,
          252.986,
          265.972,
          278.86,
          291.647,
          304.334,
          316.921,
          329.407,
          341.792,
          354.077,
          366.26,
          378.343,
          390.32599999999996,
          402.208,
          413.99199999999996,
          425.676,
          437.26099999999997,
          448.74800000000005,
          460.13699999999994,
          471.42900000000003,
          482.624,
          493.723,
          504.727,
          515.637,
          526.452,
          537.173,
          547.802,
          558.339,
          568.784,
          579.139,
          589.403,
          599.578,
          609.664,
          619.663,
          629.573,
          639.398,
          649.136,
          658.789,
          668.357,
          677.841,
          687.2410000000001,
          696.559,
          705.795,
          714.95,
          724.0239999999999,
          733.0169999999999,
          741.931,
          750.7660000000001,
          759.523,
          768.202,
          776.803,
          785.328,
          793.7769999999999,
          802.1510000000001,
          810.45,
          818.674,
          826.825,
          834.9019999999999,
          842.9069999999999,
          850.8389999999999,
          858.7,
          866.4889999999999,
          874.2080000000001,
          881.8560000000001,
          889.435,
          896.945,
          904.385,
          911.758,
          919.062,
          926.299,
          933.4689999999999,
          940.573,
          947.61,
          954.581,
          961.488,
          968.329,
          975.1060000000001,
          981.819,
          988.4680000000001,
          995.054,
          1001.576,
          1008.0360000000001,
          1014.434,
          1020.77,
          1027.045,
          1033.258,
          1039.41,
          1045.502,
          1051.5339999999999,
          1057.505,
          1063.4180000000001,
          1069.271,
          1075.065,
          1080.8,
          1086.4769999999999,
          1092.096,
          1097.657,
          1103.161,
          1108.607,
          1113.997,
          1119.329,
          1124.606,
          1129.826,
          1134.99,
          1140.099,
          1145.152,
          1150.15,
          1155.093,
          1159.981,
          1164.815,
          1169.594,
          1174.319,
          1178.991,
          1183.609,
          1188.173,
          1192.684,
          1197.142,
          1201.547,
          1205.9,
          1210.2,
          1214.447,
          1218.643,
          1222.787,
          1226.878,
          1230.9189999999999,
          1234.907,
          1238.845,
          1242.731,
          1246.566,
          1250.351,
          1254.085,
          1257.768,
          1261.401,
          1264.983,
          1268.515,
          1271.998,
          1275.43,
          1278.813,
          1282.146,
          1285.4289999999999,
          1288.664,
          1291.848,
          1294.984,
          1298.07,
          1301.108,
          1304.097,
          1307.036,
          1309.927,
          1312.77,
          1315.5639999999999,
          1318.309,
          1321.007,
          1323.655,
          1326.256,
          1328.809,
          1331.3129999999999,
          1333.77,
          1336.1779999999999,
          1338.539,
          1340.852,
          1343.1170000000002,
          1345.3339999999998,
          1347.504,
          1349.626,
          1351.701,
          1353.7279999999998,
          1355.7079999999999,
          1357.64,
          1359.525,
          1361.362,
          1363.152,
          1364.895,
          1366.5910000000001,
          1368.239,
          1369.84,
          1371.394,
          1372.901,
          1374.36,
          1375.773,
          1377.138,
          1378.4560000000001,
          1379.727,
          1380.95,
          1382.1270000000002,
          1383.256,
          1384.338,
          1385.374,
          1386.361,
          1387.3020000000001,
          1388.1960000000001,
          1389.0420000000001,
          1389.8410000000001,
          1390.592,
          1391.297,
          1391.954,
          1392.5629999999999,
          1393.126,
          1393.64,
          1394.108,
          1394.5279999999998,
          1394.9,
          1395.224,
          1395.501,
          1395.731,
          1395.912,
          1396.046,
          1396.131,
          1396.1689999999999,
          1396.1589999999999,
          1396.101,
          1395.994,
          1395.84,
          1395.6370000000002,
          1395.385,
          1395.085,
          1394.737,
          1394.34,
          1393.894,
          1393.4,
          1392.856,
          1392.264,
          1391.6229999999998,
          1390.932,
          1390.192,
          1389.4029999999998,
          1388.5639999999999,
          1387.675,
          1386.737,
          1385.749,
          1384.71,
          1383.622,
          1382.484,
          1381.295,
          1380.055,
          1378.765,
          1377.424,
          1376.033,
          1374.59,
          1373.096,
          1371.55,
          1369.953,
          1368.3039999999999,
          1366.604,
          1364.851,
          1363.046,
          1361.1889999999999,
          1359.279,
          1357.317,
          1355.3020000000001,
          1353.233,
          1351.112,
          1348.9360000000001,
          1346.7079999999999,
          1344.425,
          1342.088,
          1339.6970000000001,
          1337.2520000000002,
          1334.751,
          1332.1960000000001,
          1329.586,
          1326.92,
          1324.1989999999998,
          1321.421,
          1318.588,
          1315.6989999999998,
          1312.7520000000002,
          1309.749,
          1306.6889999999999,
          1303.572,
          1300.397,
          1297.164,
          1293.873,
          1290.5230000000001,
          1287.115,
          1283.6480000000001,
          1280.121,
          1276.535,
          1272.889,
          1269.182,
          1265.415,
          1261.588,
          1257.6989999999998,
          1253.748,
          1249.736,
          1245.662,
          1241.525,
          1237.325,
          1233.062,
          1228.735,
          1224.344,
          1219.889,
          1215.369,
          1210.785,
          1206.134,
          1201.4180000000001,
          1196.635,
          1191.786,
          1186.869,
          1181.885,
          1176.833,
          1171.713,
          1166.5230000000001,
          1161.264,
          1155.935,
          1150.536,
          1145.067,
          1139.525,
          1133.913,
          1128.2269999999999,
          1122.469,
          1116.638,
          1110.733,
          1104.753,
          1098.6989999999998,
          1092.568,
          1086.362,
          1080.079,
          1073.719,
          1067.281,
          1060.765,
          1054.17,
          1047.495,
          1040.739,
          1033.903,
          1026.985,
          1019.985,
          1012.9019999999999,
          1005.735,
          998.4830000000001,
          991.1469999999999,
          983.725,
          976.216,
          968.62,
          960.936,
          953.163,
          945.3,
          937.347,
          929.303,
          921.1669999999999,
          912.937,
          904.6139999999999,
          896.196,
          887.683,
          879.073,
          870.365,
          861.56,
          852.655,
          843.6489999999999,
          834.543,
          825.334,
          816.0219999999999,
          806.6060000000001,
          797.085,
          787.457,
          777.722,
          767.878,
          757.924,
          747.86,
          737.684,
          727.395,
          716.992,
          706.4730000000001,
          695.837,
          685.084,
          674.212,
          663.22,
          652.106,
          640.869,
          629.508,
          618.0219999999999,
          606.41,
          594.67,
          582.8,
          570.8,
          558.668,
          546.404,
          534.005,
          521.471,
          508.8,
          495.99,
          483.042,
          469.954,
          456.724,
          443.352,
          429.836,
          416.176,
          402.37,
          388.41900000000004,
          374.32,
          360.075,
          345.68199999999996,
          331.14099999999996,
          316.452,
          301.615,
          286.631,
          271.5,
          256.223,
          240.80200000000002,
          225.238,
          209.533,
          193.69,
          177.71200000000002,
          161.60299999999998,
          145.368,
          129.012,
          112.541,
          95.963,
          79.286,
          62.521,
          45.678000000000004,
          28.771,
          11.814,
          -5.176,
          -22.179000000000002,
          -39.175,
          -56.137,
          -73.04,
          -89.852,
          -106.538,
          -123.06200000000001,
          -139.381,
          -155.44799999999998,
          -171.215,
          -186.62599999999998,
          -201.623,
          -216.145,
          -230.12599999999998,
          -243.5,
          -256.2,
          -268.156,
          -279.302,
          -289.57599999999996,
          -298.918,
          -307.276,
          -314.607,
          -320.875,
          -326.057,
          -330.14099999999996,
          -333.12300000000005,
          -335.01300000000003,
          -335.832,
          -335.60699999999997,
          -334.376,
          -332.18,
          -329.06800000000004,
          -325.093,
          -320.306,
          -314.762,
          -308.515,
          -301.619,
          -294.126,
          -286.086,
          -277.545,
          -268.54900000000004,
          -259.139,
          -249.355,
          -239.233,
          -228.80700000000002,
          -218.108,
          -207.165,
          -196.005,
          -184.65,
          -173.12400000000002,
          -161.447,
          -149.638,
          -137.713,
          -125.68799999999999,
          -113.57700000000001,
          -101.39399999999999,
          -89.149,
          -76.855,
          -64.52,
          -52.153999999999996,
          -39.765,
          -27.36,
          -14.947000000000001,
          -2.532,
          9.881,
          22.284000000000002,
          34.674,
          47.047,
          59.397,
          71.722,
          84.01799999999999,
          96.28299999999999,
          108.512,
          120.705,
          132.858,
          144.969,
          157.037,
          169.06,
          181.035,
          192.96200000000002,
          204.83900000000003,
          216.666,
          228.44,
          240.16099999999997,
          251.829,
          263.441,
          274.998,
          286.5,
          297.944,
          309.33099999999996,
          320.661,
          331.93199999999996,
          343.145,
          354.29900000000004,
          365.394,
          376.43,
          387.407,
          398.324,
          409.181,
          419.978,
          430.715,
          441.39300000000003,
          452.01,
          462.56699999999995,
          473.064,
          483.501,
          493.87800000000004,
          504.19599999999997,
          514.453,
          524.651,
          534.788,
          544.867,
          554.885,
          564.845,
          574.745,
          584.586,
          594.368,
          604.091,
          613.755,
          623.361,
          632.909,
          642.398,
          651.8290000000001,
          661.202,
          670.518,
          679.7760000000001,
          688.9760000000001,
          698.12,
          707.206,
          716.235,
          725.2080000000001,
          734.1239999999999,
          742.9839999999999,
          751.7869999999999,
          760.535,
          769.227,
          777.863,
          786.443,
          794.9689999999999,
          803.439,
          811.8539999999999,
          820.2139999999999,
          828.52,
          836.7719999999999,
          844.9689999999999,
          853.112,
          861.201,
          869.2360000000001,
          877.2180000000001,
          885.1460000000001,
          893.02,
          900.842,
          908.6110000000001,
          916.326,
          923.9889999999999,
          931.6,
          939.158,
          946.664,
          954.117,
          961.5189999999999,
          968.8689999999999,
          976.1669999999999,
          983.413,
          990.6080000000001,
          997.752,
          1004.8439999999999,
          1011.885,
          1018.8760000000001,
          1025.815,
          1032.704,
          1039.542,
          1046.33,
          1053.067,
          1059.754,
          1066.39,
          1072.9769999999999,
          1079.514,
          1086,
          1092.437,
          1098.825,
          1105.162,
          1111.45,
          1117.6889999999999,
          1123.878,
          1130.018,
          1136.109,
          1142.151,
          1148.144,
          1154.087,
          1159.982,
          1165.828,
          1171.625,
          1177.374,
          1183.073,
          1188.725,
          1194.327,
          1199.882,
          1205.387,
          1210.845,
          1216.254,
          1221.615,
          1226.927,
          1232.191,
          1237.4080000000001,
          1242.576,
          1247.6960000000001,
          1252.767,
          1257.7910000000002,
          1262.767,
          1267.695,
          1272.575,
          1277.407,
          1282.191,
          1286.927,
          1291.615,
          1296.255,
          1300.848,
          1305.392,
          1309.889,
          1314.338,
          1318.739,
          1323.092,
          1327.3970000000002,
          1331.654,
          1335.864,
          1340.025,
          1344.139,
          1348.204,
          1352.2220000000002,
          1356.192,
          1360.114,
          1363.987,
          1367.8129999999999,
          1371.59,
          1375.32,
          1379.001,
          1382.634,
          1386.219,
          1389.756,
          1393.244,
          1396.684,
          1400.075,
          1403.418,
          1406.713,
          1409.9589999999998,
          1413.156,
          1416.305,
          1419.405,
          1422.4560000000001,
          1425.4579999999999,
          1428.412,
          1431.316,
          1434.171,
          1436.977,
          1439.734,
          1442.441,
          1445.099,
          1447.7079999999999,
          1450.267,
          1452.776,
          1455.236,
          1457.645,
          1460.005,
          1462.3139999999999,
          1464.5739999999998,
          1466.783,
          1468.942,
          1471.05,
          1473.1070000000002,
          1475.114,
          1477.07,
          1478.975,
          1480.829,
          1482.632,
          1484.3829999999998,
          1486.0829999999999,
          1487.731,
          1489.3270000000002,
          1490.872,
          1492.364,
          1493.8039999999999,
          1495.192,
          1496.527,
          1497.809,
          1499.039,
          1500.2160000000001,
          1501.339,
          1502.4089999999999,
          1503.4260000000002,
          1504.389,
          1505.2979999999998,
          1506.1529999999998,
          1506.954,
          1507.7,
          1508.391,
          1509.0279999999998,
          1509.61,
          1510.136,
          1510.608,
          1511.023,
          1511.3829999999998,
          1511.6860000000001,
          1511.933,
          1512.124,
          1512.2579999999998,
          1512.335,
          1512.354,
          1512.317,
          1512.221,
          1512.067,
          1511.856,
          1511.586,
          1511.257,
          1510.869,
          1510.421,
          1509.915,
          1509.348,
          1508.721,
          1508.0339999999999,
          1507.287,
          1506.4779999999998,
          1505.608,
          1504.6760000000002,
          1503.683,
          1502.6270000000002,
          1501.5079999999998,
          1500.3270000000002,
          1499.0829999999999,
          1497.775,
          1496.4029999999998,
          1494.967,
          1493.4660000000001,
          1491.901,
          1490.27,
          1488.5729999999999,
          1486.81,
          1484.981,
          1483.085,
          1481.122,
          1479.0910000000001,
          1476.993,
          1474.825,
          1472.589,
          1470.2839999999999,
          1467.908,
          1465.463,
          1462.9470000000001,
          1460.36,
          1457.701,
          1454.971,
          1452.168,
          1449.2920000000001,
          1446.342,
          1443.319,
          1440.22,
          1437.047,
          1433.799,
          1430.474,
          1427.0729999999999,
          1423.595,
          1420.039,
          1416.404,
          1412.691,
          1408.898,
          1405.025,
          1401.0720000000001,
          1397.037,
          1392.92,
          1388.721,
          1384.4389999999999,
          1380.0720000000001,
          1375.621,
          1371.085,
          1366.4620000000002,
          1361.753,
          1356.957,
          1352.0720000000001,
          1347.099,
          1342.036,
          1336.882,
          1331.6370000000002,
          1326.3,
          1320.87,
          1315.3470000000002,
          1309.729,
          1304.015,
          1298.205,
          1292.298,
          1286.2930000000001,
          1280.1889999999999,
          1273.985,
          1267.68,
          1261.2730000000001,
          1254.763,
          1248.149,
          1241.43,
          1234.605,
          1227.672,
          1220.632,
          1213.482,
          1206.221,
          1198.849,
          1191.364,
          1183.765,
          1176.05,
          1168.219,
          1160.27,
          1152.202,
          1144.013,
          1135.702,
          1127.268,
          1118.7089999999998,
          1110.024,
          1101.211,
          1092.269,
          1083.1960000000001,
          1073.991,
          1064.652,
          1055.177,
          1045.566,
          1035.815,
          1025.923,
          1015.8889999999999,
          1005.711,
          995.3860000000001,
          984.913,
          974.291,
          963.5160000000001,
          952.587,
          941.503,
          930.26,
          918.8560000000001,
          907.291,
          895.56,
          883.663,
          871.596,
          859.3580000000001,
          846.946,
          834.357,
          821.5889999999999,
          808.64,
          795.5060000000001,
          782.185,
          768.675,
          754.9730000000001,
          741.076,
          726.9810000000001,
          712.686,
          698.187,
          683.482,
          668.568,
          653.442,
          638.101,
          622.5419999999999,
          606.763,
          590.759,
          574.529,
          558.069,
          541.378,
          524.451,
          507.287,
          489.88300000000004,
          472.23699999999997,
          454.346,
          436.209,
          417.824,
          399.189,
          380.305,
          361.17,
          341.783,
          322.147,
          302.262,
          282.13,
          261.754,
          241.138,
          220.28799999999998,
          199.21099999999998,
          177.91299999999998,
          156.407,
          134.703,
          112.81700000000001,
          90.766,
          68.57,
          46.253,
          23.842,
          1.369,
          -21.131,
          -43.615,
          -66.039,
          -88.351,
          -110.493,
          -132.403,
          -154.012,
          -175.247,
          -196.02900000000002,
          -216.275,
          -235.90099999999998,
          -254.821,
          -272.95,
          -290.205,
          -306.508,
          -321.786,
          -335.978,
          -349.032,
          -360.905,
          -371.57,
          -381.01099999999997,
          -389.226,
          -396.222,
          -402.019,
          -406.648,
          -410.14300000000003,
          -412.548,
          -413.911,
          -414.284,
          -413.718,
          -412.27,
          -409.991,
          -406.93699999999995,
          -403.158,
          -398.705,
          -393.624,
          -387.963,
          -381.764,
          -375.066,
          -367.91,
          -360.329,
          -352.35699999999997,
          -344.024,
          -335.336,
          -326.39099999999996,
          -317.142,
          -307.63599999999997,
          -297.893,
          -287.933,
          -277.775,
          -267.435,
          -256.92900000000003,
          -246.271,
          -235.47400000000002,
          -224.55200000000002,
          -213.515,
          -202.37400000000002,
          -191.14,
          -179.82,
          -168.424,
          -156.959,
          -145.433,
          -133.85299999999998,
          -122.225,
          -110.555,
          -98.848,
          -87.11,
          -75.345,
          -63.558,
          -51.754,
          -39.935,
          -28.105,
          -16.269000000000002,
          -4.428999999999999,
          7.412000000000001,
          19.250999999999998,
          31.086,
          42.913000000000004,
          54.731,
          66.538,
          78.332,
          90.11,
          101.87100000000001,
          113.613,
          125.335,
          137.035,
          148.71200000000002,
          160.365,
          171.99200000000002,
          183.592,
          195.16400000000002,
          206.707,
          218.22099999999998,
          229.703,
          241.15400000000002,
          252.572,
          263.957,
          275.309,
          286.626,
          297.908,
          309.154,
          320.363,
          331.536,
          342.67199999999997,
          353.77,
          364.829,
          375.85,
          386.832,
          397.775,
          408.67800000000005,
          419.54,
          430.36300000000006,
          441.144,
          451.885,
          462.585,
          473.24300000000005,
          483.85900000000004,
          494.434,
          504.967,
          515.457,
          525.905,
          536.31,
          546.673,
          556.992,
          567.269,
          577.502,
          587.692,
          597.839,
          607.942,
          618.002,
          628.0169999999999,
          637.989,
          647.9169999999999,
          657.801,
          667.6410000000001,
          677.437,
          687.189,
          696.8960000000001,
          706.559,
          716.178,
          725.752,
          735.2819999999999,
          744.7669999999999,
          754.2080000000001,
          763.6039999999999,
          772.955,
          782.2610000000001,
          791.523,
          800.74,
          809.913,
          819.04,
          828.122,
          837.16,
          846.153,
          855.1,
          864.003,
          872.8610000000001,
          881.673,
          890.441,
          899.164,
          907.841,
          916.4730000000001,
          925.06,
          933.602,
          942.0989999999999,
          950.55,
          958.956,
          967.317,
          975.633,
          983.903,
          992.128,
          1000.307,
          1008.441,
          1016.53,
          1024.573,
          1032.57,
          1040.522,
          1048.4289999999999,
          1056.29,
          1064.105,
          1071.875,
          1079.599,
          1087.277,
          1094.91,
          1102.496,
          1110.037,
          1117.532,
          1124.982,
          1132.385,
          1139.742,
          1147.053,
          1154.319,
          1161.538,
          1168.711,
          1175.837,
          1182.9180000000001,
          1189.952,
          1196.94,
          1203.881,
          1210.776,
          1217.625,
          1224.427,
          1231.182,
          1237.89,
          1244.552,
          1251.167,
          1257.736,
          1264.257,
          1270.731,
          1277.1580000000001,
          1283.538,
          1289.871,
          1296.157,
          1302.395,
          1308.586,
          1314.729,
          1320.8239999999998,
          1326.872,
          1332.8729999999998,
          1338.825,
          1344.729,
          1350.586,
          1356.394,
          1362.154,
          1367.866,
          1373.529,
          1379.144,
          1384.71,
          1390.2279999999998,
          1395.6970000000001,
          1401.116,
          1406.487,
          1411.809,
          1417.0810000000001,
          1422.3039999999999,
          1427.4779999999998,
          1432.602,
          1437.6760000000002,
          1442.7,
          1447.675,
          1452.599,
          1457.473,
          1462.297,
          1467.07,
          1471.793,
          1476.465,
          1481.086,
          1485.656,
          1490.174,
          1494.642,
          1499.058,
          1503.422,
          1507.734,
          1511.995,
          1516.203,
          1520.359,
          1524.4620000000002,
          1528.513,
          1532.511,
          1536.4560000000001,
          1540.348,
          1544.1870000000001,
          1547.9720000000002,
          1551.703,
          1555.38,
          1559.004,
          1562.5729999999999,
          1566.0870000000002,
          1569.547,
          1572.9520000000002,
          1576.3020000000001,
          1579.596,
          1582.835,
          1586.0179999999998,
          1589.145,
          1592.217,
          1595.231,
          1598.1889999999999,
          1601.09,
          1603.934,
          1606.721,
          1609.45,
          1612.122,
          1614.735,
          1617.29,
          1619.786,
          1622.223,
          1624.601,
          1626.92,
          1629.1789999999999,
          1631.379,
          1633.5179999999998,
          1635.596,
          1637.614,
          1639.57,
          1641.4660000000001,
          1643.299,
          1645.0710000000001,
          1646.78,
          1648.4260000000002,
          1650.01,
          1651.53,
          1652.987,
          1654.379,
          1655.7079999999999,
          1656.971,
          1658.17,
          1659.3039999999999,
          1660.372,
          1661.3729999999998,
          1662.309,
          1663.1770000000001,
          1663.9779999999998,
          1664.7120000000002,
          1665.378,
          1665.975,
          1666.504,
          1666.963,
          1667.3529999999998,
          1667.6729999999998,
          1667.922,
          1668.1,
          1668.207,
          1668.243,
          1668.2060000000001,
          1668.096,
          1667.914,
          1667.6570000000002,
          1667.3270000000002,
          1666.921,
          1666.441,
          1665.885,
          1665.253,
          1664.5439999999999,
          1663.759,
          1662.895,
          1661.953,
          1660.932,
          1659.832,
          1658.652,
          1657.392,
          1656.05,
          1654.626,
          1653.12,
          1651.5320000000002,
          1649.859,
          1648.102,
          1646.261,
          1644.3339999999998,
          1642.32,
          1640.22,
          1638.0320000000002,
          1635.756,
          1633.391,
          1630.9360000000001,
          1628.391,
          1625.754,
          1623.025,
          1620.204,
          1617.289,
          1614.279,
          1611.175,
          1607.974,
          1604.6760000000002,
          1601.281,
          1597.787,
          1594.194,
          1590.5,
          1586.704,
          1582.807,
          1578.806,
          1574.701,
          1570.49,
          1566.174,
          1561.75,
          1557.217,
          1552.576,
          1547.8229999999999,
          1542.96,
          1537.983,
          1532.892,
          1527.6860000000001,
          1522.364,
          1516.925,
          1511.366,
          1505.6879999999999,
          1499.888,
          1493.9660000000001,
          1487.92,
          1481.7479999999998,
          1475.4489999999998,
          1469.023,
          1462.4660000000001,
          1455.779,
          1448.9579999999999,
          1442.004,
          1434.9129999999998,
          1427.685,
          1420.318,
          1412.8110000000001,
          1405.16,
          1397.366,
          1389.425,
          1381.336,
          1373.098,
          1364.707,
          1356.1629999999998,
          1347.464,
          1338.606,
          1329.589,
          1320.41,
          1311.066,
          1301.556,
          1291.877,
          1282.027,
          1272.003,
          1261.803,
          1251.425,
          1240.866,
          1230.123,
          1219.193,
          1208.075,
          1196.764,
          1185.258,
          1173.5539999999999,
          1161.649,
          1149.54,
          1137.223,
          1124.6960000000001,
          1111.955,
          1098.996,
          1085.816,
          1072.412,
          1058.78,
          1044.915,
          1030.8139999999999,
          1016.4739999999999,
          1001.8889999999999,
          987.057,
          971.972,
          956.6310000000001,
          941.028,
          925.16,
          909.0210000000001,
          892.6080000000001,
          875.915,
          858.937,
          841.669,
          824.107,
          806.2460000000001,
          788.079,
          769.6030000000001,
          750.811,
          731.698,
          712.2589999999999,
          692.4889999999999,
          672.382,
          651.934,
          631.138,
          609.991,
          588.488,
          566.623,
          544.393,
          521.794,
          498.82199999999995,
          475.475,
          451.751,
          427.647,
          403.165,
          378.30300000000005,
          353.066,
          327.455,
          301.47700000000003,
          275.14,
          248.453,
          221.429,
          194.085,
          166.43900000000002,
          138.516,
          110.344,
          81.958,
          53.396,
          24.704,
          -4.064,
          -32.85,
          -61.586999999999996,
          -90.198,
          -118.604,
          -146.713,
          -174.43200000000002,
          -201.65900000000002,
          -228.28799999999998,
          -254.21400000000003,
          -279.33,
          -303.531,
          -326.721,
          -348.80699999999996,
          -369.71,
          -389.36,
          -407.702,
          -424.69599999999997,
          -440.314,
          -454.546,
          -467.394,
          -478.871,
          -489.00300000000004,
          -497.82300000000004,
          -505.37300000000005,
          -511.70099999999996,
          -516.859,
          -520.901,
          -523.881,
          -525.857,
          -526.886,
          -527.021,
          -526.316,
          -524.8240000000001,
          -522.592,
          -519.67,
          -516.101,
          -511.92699999999996,
          -507.189,
          -501.923,
          -496.165,
          -489.94699999999995,
          -483.301,
          -476.254,
          -468.835,
          -461.06699999999995,
          -452.974,
          -444.579,
          -435.901,
          -426.958,
          -417.77,
          -408.353,
          -398.721,
          -388.89,
          -378.87199999999996,
          -368.681,
          -358.327,
          -347.824,
          -337.17900000000003,
          -326.404,
          -315.507,
          -304.497,
          -293.381,
          -282.168,
          -270.86400000000003,
          -259.476,
          -248.01,
          -236.472,
          -224.86700000000002,
          -213.201,
          -201.479,
          -189.705,
          -177.88400000000001,
          -166.02,
          -154.116,
          -142.17700000000002,
          -130.205,
          -118.205,
          -106.179,
          -94.13,
          -82.061,
          -69.975,
          -57.875,
          -45.762,
          -33.639,
          -21.508000000000003,
          -9.371,
          2.7689999999999997,
          14.912,
          27.054000000000002,
          39.195,
          51.333,
          63.466,
          75.594,
          87.713,
          99.824,
          111.92399999999999,
          124.014,
          136.09,
          148.153,
          160.202,
          172.234,
          184.25,
          196.248,
          208.22799999999998,
          220.18900000000002,
          232.12900000000002,
          244.048,
          255.945,
          267.82,
          279.672,
          291.5,
          303.30400000000003,
          315.082,
          326.835,
          338.561,
          350.26099999999997,
          361.93300000000005,
          373.57800000000003,
          385.194,
          396.781
         ],
         "y": [
          4704.321,
          4745.575,
          4784.04,
          4819.807,
          4852.978,
          4883.655,
          4911.934,
          4937.905,
          4961.654,
          4983.264,
          5002.815,
          5020.38,
          5036.032,
          5049.838,
          5061.8640000000005,
          5072.1720000000005,
          5080.821,
          5087.8679999999995,
          5093.366,
          5097.3679999999995,
          5099.923,
          5101.079000000001,
          5100.880999999999,
          5099.372,
          5096.593,
          5092.585,
          5087.3859999999995,
          5081.032999999999,
          5073.561,
          5065.003,
          5055.393,
          5044.7609999999995,
          5033.137,
          5020.55,
          5007.028,
          4992.598,
          4977.285,
          4961.115,
          4944.111,
          4926.295999999999,
          4907.693,
          4888.322,
          4868.205,
          4847.362,
          4825.811,
          4803.573,
          4780.664000000001,
          4757.102,
          4732.905,
          4708.088,
          4682.668,
          4656.659000000001,
          4630.076,
          4602.935,
          4575.248,
          4547.03,
          4518.293,
          4489.0509999999995,
          4459.315,
          4429.097,
          4398.41,
          4367.265,
          4335.673,
          4303.644,
          4271.189,
          4238.318,
          4205.041,
          4171.367,
          4137.306,
          4102.867,
          4068.058,
          4032.889,
          3997.368,
          3961.5029999999997,
          3925.301,
          3888.7709999999997,
          3851.921,
          3814.758,
          3777.288,
          3739.52,
          3701.46,
          3663.114,
          3624.489,
          3585.593,
          3546.43,
          3507.008,
          3467.3320000000003,
          3427.408,
          3387.243,
          3346.841,
          3306.2070000000003,
          3265.349,
          3224.27,
          3182.9759999999997,
          3141.472,
          3099.763,
          3057.8540000000003,
          3015.75,
          2973.455,
          2930.974,
          2888.3109999999997,
          2845.4709999999995,
          2802.4590000000003,
          2759.278,
          2715.9320000000002,
          2672.426,
          2628.764,
          2584.95,
          2540.987,
          2496.88,
          2452.632,
          2408.2470000000003,
          2363.728,
          2319.08,
          2274.305,
          2229.407,
          2184.39,
          2139.256,
          2094.01,
          2048.654,
          2003.192,
          1957.626,
          1911.96,
          1866.1970000000001,
          1820.34,
          1774.392,
          1728.356,
          1682.234,
          1636.03,
          1589.746,
          1543.385,
          1496.95,
          1450.444,
          1403.869,
          1357.2279999999998,
          1310.5230000000001,
          1263.758,
          1216.934,
          1170.0539999999999,
          1123.12,
          1076.136,
          1029.103,
          982.0239999999999,
          934.9019999999999,
          887.738,
          840.534,
          793.295,
          746.02,
          698.7130000000001,
          651.377,
          604.012,
          556.622,
          509.209,
          461.774,
          414.32099999999997,
          366.85,
          319.36400000000003,
          271.866,
          224.356,
          176.838,
          129.314,
          81.78399999999999,
          34.253,
          -13.28,
          -60.81100000000001,
          -108.339,
          -155.861,
          -203.377,
          -250.88299999999998,
          -298.378,
          -345.86,
          -393.32800000000003,
          -440.778,
          -488.21,
          -535.622,
          -583.011,
          -630.375,
          -677.7139999999999,
          -725.025,
          -772.2769999999999,
          -819.5260000000001,
          -866.742,
          -913.923,
          -961.067,
          -1008.172,
          -1055.236,
          -1102.258,
          -1149.236,
          -1196.1680000000001,
          -1243.0510000000002,
          -1289.886,
          -1336.6689999999999,
          -1383.399,
          -1430.0739999999998,
          -1476.692,
          -1523.2520000000002,
          -1569.7520000000002,
          -1616.19,
          -1662.5639999999999,
          -1708.872,
          -1755.1129999999998,
          -1801.285,
          -1847.3870000000002,
          -1893.4160000000002,
          -1939.37,
          -1985.2479999999998,
          -2031.0479999999998,
          -2076.769,
          -2122.408,
          -2167.964,
          -2213.4339999999997,
          -2258.8179999999998,
          -2304.113,
          -2349.3179999999998,
          -2394.43,
          -2439.449,
          -2484.371,
          -2529.196,
          -2573.9210000000003,
          -2618.544,
          -2663.065,
          -2707.48,
          -2751.788,
          -2795.988,
          -2840.0759999999996,
          -2884.052,
          -2927.914,
          -2971.659,
          -3015.2859999999996,
          -3058.792,
          -3102.177,
          -3145.437,
          -3188.571,
          -3231.577,
          -3274.452,
          -3317.196,
          -3359.8059999999996,
          -3402.28,
          -3444.615,
          -3486.81,
          -3528.863,
          -3570.772,
          -3612.534,
          -3654.1479999999997,
          -3695.611,
          -3736.921,
          -3778.0759999999996,
          -3819.075,
          -3859.913,
          -3900.59,
          -3941.103,
          -3981.45,
          -4021.6290000000004,
          -4061.637,
          -4101.472,
          -4141.1320000000005,
          -4180.6140000000005,
          -4219.915,
          -4259.034000000001,
          -4297.969,
          -4336.715,
          -4375.272,
          -4413.6359999999995,
          -4451.806,
          -4489.778,
          -4527.55,
          -4565.1179999999995,
          -4602.482,
          -4639.637,
          -4676.581,
          -4713.312,
          -4749.826,
          -4786.121,
          -4822.194,
          -4858.042,
          -4893.662,
          -4929.0509999999995,
          -4964.206,
          -4999.124,
          -5033.802,
          -5068.236,
          -5102.425,
          -5136.363,
          -5170.049,
          -5203.479,
          -5236.649,
          -5269.557,
          -5302.198,
          -5334.569,
          -5366.6669999999995,
          -5398.488,
          -5430.028,
          -5461.284000000001,
          -5492.251,
          -5522.927,
          -5553.306,
          -5583.3859999999995,
          -5613.161999999999,
          -5642.630999999999,
          -5671.786999999999,
          -5700.6269999999995,
          -5729.146,
          -5757.340999999999,
          -5785.206,
          -5812.738,
          -5839.931,
          -5866.781,
          -5893.283,
          -5919.433000000001,
          -5945.225,
          -5970.654,
          -5995.715999999999,
          -6020.405,
          -6044.715999999999,
          -6068.643,
          -6092.182,
          -6115.326,
          -6138.069,
          -6160.406999999999,
          -6182.331999999999,
          -6203.839,
          -6224.922,
          -6245.5740000000005,
          -6265.79,
          -6285.562,
          -6304.885,
          -6323.75,
          -6342.151,
          -6360.081,
          -6377.533,
          -6394.499,
          -6410.972,
          -6426.944,
          -6442.406999999999,
          -6457.352,
          -6471.772,
          -6485.658,
          -6499.0019999999995,
          -6511.793000000001,
          -6524.024,
          -6535.686,
          -6546.768,
          -6557.2609999999995,
          -6567.155,
          -6576.439,
          -6585.103,
          -6593.1359999999995,
          -6600.528,
          -6607.266,
          -6613.34,
          -6618.736999999999,
          -6623.445,
          -6627.45,
          -6630.741999999999,
          -6633.306,
          -6635.129,
          -6636.196,
          -6636.493,
          -6636.005999999999,
          -6634.719,
          -6632.616,
          -6629.681,
          -6625.898,
          -6621.249,
          -6615.718000000001,
          -6609.285,
          -6601.932,
          -6593.64,
          -6584.389,
          -6574.158,
          -6562.9259999999995,
          -6550.67,
          -6537.37,
          -6523.001,
          -6507.539000000001,
          -6490.959,
          -6473.236,
          -6454.342,
          -6434.251,
          -6412.932,
          -6390.359,
          -6366.4980000000005,
          -6341.32,
          -6314.79,
          -6286.876,
          -6257.541,
          -6226.746999999999,
          -6194.46,
          -6160.637,
          -6125.2390000000005,
          -6088.223000000001,
          -6049.543000000001,
          -6009.156,
          -5967.012,
          -5923.062,
          -5877.254,
          -5829.533,
          -5779.846,
          -5728.132,
          -5674.331999999999,
          -5618.38,
          -5560.214,
          -5499.763000000001,
          -5436.956,
          -5371.719,
          -5303.976,
          -5233.644,
          -5160.64,
          -5084.879,
          -5006.269,
          -4924.715,
          -4840.123,
          -4752.389,
          -4661.41,
          -4567.079000000001,
          -4469.284000000001,
          -4367.913,
          -4262.848,
          -4153.97,
          -4041.1609999999996,
          -3924.297,
          -3803.259,
          -3677.9240000000004,
          -3548.176,
          -3413.901,
          -3274.992,
          -3131.3520000000003,
          -2982.8920000000003,
          -2829.5440000000003,
          -2671.255,
          -2507.998,
          -2339.775,
          -2166.625,
          -1988.626,
          -1805.9029999999998,
          -1618.64,
          -1427.0739999999998,
          -1231.514,
          -1032.335,
          -829.982,
          -624.974,
          -417.89599999999996,
          -209.394,
          -0.162,
          209.065,
          417.533,
          624.486,
          829.18,
          1030.906,
          1229.004,
          1422.8729999999998,
          1611.9879999999998,
          1795.899,
          1974.2379999999998,
          2146.718,
          2313.125,
          2473.32,
          2627.2270000000003,
          2774.824,
          2916.139,
          3051.241,
          3180.232,
          3303.238,
          3420.409,
          3531.909,
          3637.909,
          3738.592,
          3834.1440000000002,
          3924.7470000000003,
          4010.5890000000004,
          4091.8509999999997,
          4168.713,
          4241.347,
          4309.924,
          4374.607,
          4435.553,
          4492.914000000001,
          4546.835,
          4597.454000000001,
          4644.904,
          4689.313,
          4730.8009999999995,
          4769.483,
          4805.471,
          4838.8679999999995,
          4869.773,
          4898.284000000001,
          4924.491,
          4948.479,
          4970.331,
          4990.126,
          5007.939,
          5023.84,
          5037.899,
          5050.178,
          5060.742,
          5069.649,
          5076.955,
          5082.715,
          5086.979,
          5089.799,
          5091.22,
          5091.289000000001,
          5090.048,
          5087.539000000001,
          5083.8009999999995,
          5078.873,
          5072.792,
          5065.592000000001,
          5057.308,
          5047.972,
          5037.615,
          5026.266,
          5013.955,
          5000.71,
          4986.557,
          4971.521,
          4955.629,
          4938.903,
          4921.366,
          4903.041,
          4883.9490000000005,
          4864.111,
          4843.5470000000005,
          4822.276,
          4800.316,
          4777.686,
          4754.404,
          4730.485,
          4705.948,
          4680.806,
          4655.076,
          4628.772,
          4601.909000000001,
          4574.501,
          4546.561,
          4518.102,
          4489.138,
          4459.68,
          4429.74,
          4399.33,
          4368.460999999999,
          4337.145,
          4305.392,
          4273.213,
          4240.617,
          4207.615,
          4174.215,
          4140.428,
          4106.263,
          4071.728,
          4036.8309999999997,
          4001.5820000000003,
          3965.989,
          3930.059,
          3893.8,
          3857.22,
          3820.3259999999996,
          3783.1259999999997,
          3745.6259999999997,
          3707.8340000000003,
          3669.756,
          3631.3990000000003,
          3592.768,
          3553.8720000000003,
          3514.715,
          3475.303,
          3435.6440000000002,
          3395.741,
          3355.6020000000003,
          3315.2309999999998,
          3274.634,
          3233.816,
          3192.782,
          3151.5370000000003,
          3110.087,
          3068.4359999999997,
          3026.5890000000004,
          2984.551,
          2942.3259999999996,
          2899.9190000000003,
          2857.333,
          2814.575,
          2771.647,
          2728.553,
          2685.2990000000004,
          2641.888,
          2598.324,
          2554.611,
          2510.752,
          2466.752,
          2422.614,
          2378.341,
          2333.938,
          2289.408,
          2244.754,
          2199.98,
          2155.0879999999997,
          2110.084,
          2064.968,
          2019.746,
          1974.4189999999999,
          1928.991,
          1883.465,
          1837.845,
          1792.132,
          1746.33,
          1700.442,
          1654.471,
          1608.42,
          1562.29,
          1516.086,
          1469.809,
          1423.4620000000002,
          1377.049,
          1330.5710000000001,
          1284.031,
          1237.432,
          1190.777,
          1144.066,
          1097.3039999999999,
          1050.493,
          1003.6339999999999,
          956.7310000000001,
          909.7860000000001,
          862.8,
          815.7769999999999,
          768.7180000000001,
          721.6260000000001,
          674.503,
          627.352,
          580.174,
          532.971,
          485.746,
          438.501,
          391.23900000000003,
          343.96,
          296.66700000000003,
          249.363,
          202.049,
          154.727,
          107.4,
          60.068999999999996,
          12.735999999999999,
          -34.596,
          -81.926,
          -129.252,
          -176.572,
          -223.88299999999998,
          -271.185,
          -318.474,
          -365.75,
          -413.01,
          -460.25300000000004,
          -507.476,
          -554.678,
          -601.856,
          -649.01,
          -696.137,
          -743.235,
          -790.303,
          -837.3380000000001,
          -884.3389999999999,
          -931.305,
          -978.232,
          -1025.12,
          -1071.9669999999999,
          -1118.771,
          -1165.53,
          -1212.242,
          -1258.906,
          -1305.52,
          -1352.082,
          -1398.59,
          -1445.0420000000001,
          -1491.4370000000001,
          -1537.774,
          -1584.049,
          -1630.2620000000002,
          -1676.411,
          -1722.493,
          -1768.5079999999998,
          -1814.453,
          -1860.3270000000002,
          -1906.1270000000002,
          -1951.8529999999998,
          -1997.5020000000002,
          -2043.0720000000001,
          -2088.562,
          -2133.971,
          -2179.295,
          -2224.534,
          -2269.685,
          -2314.748,
          -2359.719,
          -2404.597,
          -2449.381,
          -2494.069,
          -2538.658,
          -2583.147,
          -2627.534,
          -2671.817,
          -2715.995,
          -2760.065,
          -2804.026,
          -2847.8759999999997,
          -2891.612,
          -2935.2340000000004,
          -2978.738,
          -3022.1240000000003,
          -3065.389,
          -3108.531,
          -3151.548,
          -3194.4390000000003,
          -3237.2009999999996,
          -3279.833,
          -3322.3309999999997,
          -3364.696,
          -3406.923,
          -3449.012,
          -3490.96,
          -3532.7659999999996,
          -3574.426,
          -3615.94,
          -3657.304,
          -3698.5170000000003,
          -3739.5759999999996,
          -3780.48,
          -3821.2259999999997,
          -3861.812,
          -3902.236,
          -3942.495,
          -3982.5879999999997,
          -4022.511,
          -4062.263,
          -4101.842000000001,
          -4141.244000000001,
          -4180.467000000001,
          -4219.51,
          -4258.37,
          -4297.044,
          -4335.529,
          -4373.8240000000005,
          -4411.9259999999995,
          -4449.832,
          -4487.539000000001,
          -4525.045,
          -4562.348,
          -4599.444,
          -4636.332,
          -4673.0070000000005,
          -4709.468,
          -4745.710999999999,
          -4781.734,
          -4817.534000000001,
          -4853.108,
          -4888.4529999999995,
          -4923.566,
          -4958.444,
          -4993.083,
          -5027.482,
          -5061.6359999999995,
          -5095.542,
          -5129.198,
          -5162.599,
          -5195.744000000001,
          -5228.627,
          -5261.246,
          -5293.597,
          -5325.677,
          -5357.482,
          -5389.009,
          -5420.253000000001,
          -5451.210999999999,
          -5481.879,
          -5512.254,
          -5542.331,
          -5572.107,
          -5601.578,
          -5630.738,
          -5659.585,
          -5688.113,
          -5716.319,
          -5744.198,
          -5771.746,
          -5798.9580000000005,
          -5825.829000000001,
          -5852.354,
          -5878.53,
          -5904.351,
          -5929.811,
          -5954.906999999999,
          -5979.632,
          -6003.982,
          -6027.951,
          -6051.534000000001,
          -6074.725,
          -6097.518,
          -6119.908,
          -6141.888000000001,
          -6163.454000000001,
          -6184.598000000001,
          -6205.315,
          -6225.597,
          -6245.44,
          -6264.835,
          -6283.776,
          -6302.255999999999,
          -6320.268,
          -6337.806,
          -6354.86,
          -6371.425,
          -6387.491,
          -6403.052,
          -6418.099,
          -6432.624,
          -6446.619000000001,
          -6460.0740000000005,
          -6472.981,
          -6485.331,
          -6497.115,
          -6508.3240000000005,
          -6518.946,
          -6528.974,
          -6538.395,
          -6547.201,
          -6555.38,
          -6562.92,
          -6569.812,
          -6576.043000000001,
          -6581.601,
          -6586.475,
          -6590.65,
          -6594.116,
          -6596.859,
          -6598.865,
          -6600.12,
          -6600.609,
          -6600.319,
          -6599.233,
          -6597.3369999999995,
          -6594.6140000000005,
          -6591.047,
          -6586.62,
          -6581.315,
          -6575.1140000000005,
          -6567.999,
          -6559.9490000000005,
          -6550.946,
          -6540.969,
          -6529.996999999999,
          -6518.007,
          -6504.978,
          -6490.8859999999995,
          -6475.7080000000005,
          -6459.419,
          -6441.991999999999,
          -6423.401,
          -6403.62,
          -6382.619000000001,
          -6360.368,
          -6336.838000000001,
          -6311.9980000000005,
          -6285.814,
          -6258.2519999999995,
          -6229.276999999999,
          -6198.853,
          -6166.941999999999,
          -6133.505,
          -6098.5,
          -6061.8859999999995,
          -6023.618,
          -5983.65,
          -5941.935,
          -5898.424,
          -5853.065,
          -5805.804,
          -5756.584,
          -5705.35,
          -5652.04,
          -5596.590999999999,
          -5538.936,
          -5479.01,
          -5416.74,
          -5352.0509999999995,
          -5284.868,
          -5215.11,
          -5142.694,
          -5067.532999999999,
          -4989.537,
          -4908.613,
          -4824.662,
          -4737.587,
          -4647.281,
          -4553.639,
          -4456.549,
          -4355.898,
          -4251.57,
          -4143.447,
          -4031.408,
          -3915.3320000000003,
          -3795.098,
          -3670.586,
          -3541.678,
          -3408.259,
          -3270.224,
          -3127.472,
          -2979.9179999999997,
          -2827.488,
          -2670.131,
          -2507.8179999999998,
          -2340.551,
          -2168.362,
          -1991.33,
          -1809.578,
          -1623.283,
          -1432.682,
          -1238.077,
          -1039.839,
          -838.41,
          -634.302,
          -428.094,
          -220.429,
          -11.997,
          196.472,
          404.228,
          610.515,
          814.595,
          1015.7589999999999,
          1213.344,
          1406.753,
          1595.455,
          1779.003,
          1957.024,
          2129.228,
          2295.402,
          2455.401,
          2609.146,
          2756.615,
          2897.8320000000003,
          3032.864,
          3161.809,
          3284.796,
          3401.967,
          3513.486,
          3619.527,
          3720.265,
          3815.888,
          3906.577,
          3992.518,
          4073.8909999999996,
          4150.875,
          4223.642,
          4292.363,
          4357.198,
          4418.306,
          4475.835,
          4529.932,
          4580.735,
          4628.375,
          4672.98,
          4714.67,
          4753.559,
          4789.759,
          4823.373,
          4854.5,
          4883.237,
          4909.673,
          4933.895,
          4955.984,
          4976.019,
          4994.075,
          5010.223,
          5024.531,
          5037.062,
          5047.88,
          5057.044,
          5064.609,
          5070.63,
          5075.157999999999,
          5078.242,
          5079.93,
          5080.267,
          5079.295,
          5077.057,
          5073.592000000001,
          5068.938,
          5063.1320000000005,
          5056.209,
          5048.202,
          5039.144,
          5029.066,
          5017.998,
          5005.967000000001,
          4993.003,
          4979.1320000000005,
          4964.38,
          4948.771,
          4932.329000000001,
          4915.077,
          4897.037,
          4878.23,
          4858.678,
          4838.4,
          4817.415,
          4795.742,
          4773.398,
          4750.403,
          4726.772,
          4702.521,
          4677.667,
          4652.224,
          4626.208,
          4599.6320000000005,
          4572.5109999999995,
          4544.859,
          4516.687,
          4488.01,
          4458.838,
          4429.186,
          4399.062,
          4368.48,
          4337.45,
          4305.984,
          4274.09,
          4241.78,
          4209.063,
          4175.9490000000005,
          4142.446,
          4108.565,
          4074.3140000000003,
          4039.7009999999996,
          4004.736,
          3969.425,
          3933.778,
          3897.801,
          3861.502,
          3824.89,
          3787.9709999999995,
          3750.7509999999997,
          3713.239,
          3675.44,
          3637.362,
          3599.01,
          3560.3909999999996,
          3521.512,
          3482.377,
          3442.993,
          3403.366,
          3363.502,
          3323.406,
          3283.0820000000003,
          3242.5370000000003,
          3201.776,
          3160.804,
          3119.625,
          3078.245,
          3036.6679999999997,
          2994.8990000000003,
          2952.9429999999998,
          2910.804,
          2868.486,
          2825.994,
          2783.3320000000003,
          2740.5040000000004,
          2697.515,
          2654.368,
          2611.067,
          2567.616,
          2524.019,
          2480.28,
          2436.402,
          2392.389,
          2348.245,
          2303.973,
          2259.576,
          2215.058,
          2170.423,
          2125.673,
          2080.812,
          2035.842,
          1990.7679999999998,
          1945.592,
          1900.317,
          1854.9460000000001,
          1809.483,
          1763.93,
          1718.289,
          1672.565,
          1626.759,
          1580.874,
          1534.914,
          1488.88,
          1442.776,
          1396.604,
          1350.3670000000002,
          1304.067,
          1257.7069999999999,
          1211.289,
          1164.816,
          1118.29,
          1071.714,
          1025.089,
          978.42,
          931.706,
          884.952,
          838.16,
          791.33,
          744.467,
          697.572,
          650.6469999999999,
          603.695,
          556.717,
          509.716,
          462.694,
          415.653,
          368.595,
          321.522,
          274.437,
          227.34,
          180.236,
          133.124,
          86.008,
          38.889,
          -8.231,
          -55.349,
          -102.464,
          -149.57399999999998,
          -196.67700000000002,
          -243.77200000000002,
          -290.855,
          -337.925,
          -384.981,
          -432.02,
          -479.041,
          -526.0419999999999,
          -573.021,
          -619.976,
          -666.905,
          -713.806,
          -760.679,
          -807.52,
          -854.328,
          -901.1010000000001,
          -947.8380000000001,
          -994.5360000000001,
          -1041.194,
          -1087.81,
          -1134.383,
          -1180.91,
          -1227.39,
          -1273.8210000000001,
          -1320.201,
          -1366.5279999999998,
          -1412.8020000000001,
          -1459.019,
          -1505.1779999999999,
          -1551.2779999999998,
          -1597.317,
          -1643.2920000000001,
          -1689.203,
          -1735.047,
          -1780.8220000000001,
          -1826.5279999999998,
          -1872.161,
          -1917.721,
          -1963.2060000000001,
          -2008.6129999999998,
          -2053.942,
          -2099.189,
          -2144.354,
          -2189.435,
          -2234.43,
          -2279.337,
          -2324.154,
          -2368.88,
          -2413.513,
          -2458.05,
          -2502.491,
          -2546.833,
          -2591.074,
          -2635.2129999999997,
          -2679.248,
          -2723.176,
          -2766.9970000000003,
          -2810.7070000000003,
          -2854.3059999999996,
          -2897.792,
          -2941.1620000000003,
          -2984.414,
          -3027.547,
          -3070.559,
          -3113.448,
          -3156.212,
          -3198.848,
          -3241.355,
          -3283.7309999999998,
          -3325.974,
          -3368.0820000000003,
          -3410.053,
          -3451.884,
          -3493.575,
          -3535.1209999999996,
          -3576.5229999999997,
          -3617.777,
          -3658.881,
          -3699.833,
          -3740.631,
          -3781.2740000000003,
          -3821.757,
          -3862.08,
          -3902.241,
          -3942.236,
          -3982.0640000000003,
          -4021.722,
          -4061.208,
          -4100.519,
          -4139.654,
          -4178.61,
          -4217.384,
          -4255.974,
          -4294.378,
          -4332.593,
          -4370.616,
          -4408.445,
          -4446.0779999999995,
          -4483.512,
          -4520.744000000001,
          -4557.771,
          -4594.590999999999,
          -4631.201,
          -4667.598,
          -4703.78,
          -4739.744000000001,
          -4775.486,
          -4811.004,
          -4846.295,
          -4881.357,
          -4916.185,
          -4950.777,
          -4985.13,
          -5019.24,
          -5053.105,
          -5086.721,
          -5120.085999999999,
          -5153.195,
          -5186.045,
          -5218.633,
          -5250.956,
          -5283.009,
          -5314.79,
          -5346.294,
          -5377.519,
          -5408.46,
          -5439.113,
          -5469.475,
          -5499.5419999999995,
          -5529.309,
          -5558.774,
          -5587.931,
          -5616.776999999999,
          -5645.307,
          -5673.517,
          -5701.401999999999,
          -5728.959,
          -5756.182,
          -5783.068,
          -5809.61,
          -5835.805,
          -5861.648,
          -5887.133000000001,
          -5912.255999999999,
          -5937.0109999999995,
          -5961.394,
          -5985.399,
          -6009.02,
          -6032.2519999999995,
          -6055.089,
          -6077.526,
          -6099.557,
          -6121.175,
          -6142.376,
          -6163.151,
          -6183.496,
          -6203.404,
          -6222.866999999999,
          -6241.88,
          -6260.435,
          -6278.525,
          -6296.144,
          -6313.283,
          -6329.935,
          -6346.094,
          -6361.749,
          -6376.895,
          -6391.522,
          -6405.621999999999,
          -6419.187,
          -6432.206999999999,
          -6444.673000000001,
          -6456.578,
          -6467.91,
          -6478.661,
          -6488.82,
          -6498.378000000001,
          -6507.3240000000005,
          -6515.647,
          -6523.335999999999,
          -6530.38,
          -6536.768,
          -6542.488,
          -6547.526999999999,
          -6551.8730000000005,
          -6555.514,
          -6558.436,
          -6560.625,
          -6562.069,
          -6562.753000000001,
          -6562.661,
          -6561.779,
          -6560.092,
          -6557.581999999999,
          -6554.235,
          -6550.031999999999,
          -6544.956999999999,
          -6538.991999999999,
          -6532.116999999999,
          -6524.315,
          -6515.565,
          -6505.846,
          -6495.139,
          -6483.42,
          -6470.668000000001,
          -6456.86,
          -6441.972,
          -6425.979,
          -6408.856,
          -6390.576,
          -6371.111999999999,
          -6350.436,
          -6328.517,
          -6305.326999999999,
          -6280.834,
          -6255.005999999999,
          -6227.807,
          -6199.204000000001,
          -6169.16,
          -6137.637,
          -6104.597,
          -6069.999,
          -6033.8,
          -5995.956999999999,
          -5956.423000000001,
          -5915.153,
          -5872.097,
          -5827.201999999999,
          -5780.4169999999995,
          -5731.684,
          -5680.946999999999,
          -5628.146,
          -5573.217,
          -5516.095,
          -5456.714,
          -5395.0019999999995,
          -5330.884,
          -5264.285,
          -5195.125,
          -5123.321,
          -5048.786,
          -4971.431,
          -4891.163,
          -4807.884,
          -4721.496,
          -4631.895,
          -4538.973,
          -4442.621,
          -4342.724,
          -4239.169,
          -4131.837,
          -4020.6059999999998,
          -3905.3579999999997,
          -3785.969,
          -3662.322,
          -3534.296,
          -3401.7790000000005,
          -3264.6620000000003,
          -3122.848,
          -2976.2470000000003,
          -2824.7859999999996,
          -2668.415,
          -2507.1,
          -2340.842,
          -2169.673,
          -1993.6670000000001,
          -1812.944,
          -1627.6789999999999,
          -1438.1029999999998,
          -1244.516,
          -1047.282,
          -846.84,
          -643.695,
          -438.42199999999997,
          -231.658,
          -24.089000000000002,
          183.56099999999998,
          390.543,
          596.107,
          799.515,
          1000.059,
          1197.077,
          1389.973,
          1578.214,
          1761.35,
          1939.007,
          2110.893,
          2276.792,
          2436.556,
          2590.103,
          2737.408,
          2878.495,
          3013.425,
          3142.296,
          3265.2329999999997,
          3382.3790000000004,
          3493.8940000000002,
          3599.95,
          3700.723,
          3796.3959999999997,
          3887.152,
          3973.173,
          4054.6409999999996,
          4131.732,
          4204.6179999999995,
          4273.468,
          4338.443,
          4399.6990000000005,
          4457.387,
          4511.65,
          4562.627,
          4610.448,
          4655.349,
          4697.126,
          4736.215999999999,
          4772.622,
          4806.448,
          4837.793,
          4866.751,
          4893.414000000001,
          4917.867,
          4940.19,
          4960.464,
          4978.762,
          4995.156,
          5009.712,
          5022.495,
          5033.568,
          5042.9890000000005,
          5050.815,
          5057.098,
          5061.89,
          5065.241,
          5067.198,
          5067.806,
          5067.108,
          5065.145,
          5061.956,
          5057.58,
          5052.053,
          5045.411,
          5037.686,
          5028.911,
          5019.1179999999995,
          5008.335,
          4996.592000000001,
          4983.915,
          4970.333,
          4955.87,
          4940.5509999999995,
          4924.4,
          4907.439,
          4889.691,
          4871.178,
          4851.919,
          4831.935,
          4811.244000000001,
          4789.866,
          4767.818,
          4745.117,
          4721.782,
          4697.827,
          4673.269,
          4648.123,
          4622.403,
          4596.125,
          4569.3009999999995,
          4541.945,
          4514.07,
          4485.69,
          4456.816,
          4427.46,
          4397.634,
          4367.349,
          4336.615,
          4305.445,
          4273.848,
          4241.834,
          4209.414000000001,
          4176.595,
          4143.389,
          4109.803,
          4075.847,
          4041.53,
          4006.8590000000004,
          3971.842,
          3936.489,
          3900.8059999999996,
          3864.801,
          3828.482,
          3791.855,
          3754.928,
          3717.7070000000003,
          3680.2,
          3642.413,
          3604.3520000000003,
          3566.0229999999997,
          3527.433,
          3488.587,
          3449.492,
          3410.153,
          3370.5759999999996,
          3330.7670000000003,
          3290.73,
          3250.4709999999995,
          3209.9959999999996,
          3169.308,
          3128.414,
          3087.317,
          3046.0229999999997,
          3004.5370000000003,
          2962.862,
          2921.0040000000004,
          2878.967,
          2836.755,
          2794.3720000000003,
          2751.823,
          2709.111,
          2666.242,
          2623.217,
          2580.042,
          2536.72,
          2493.256,
          2449.652,
          2405.9120000000003,
          2362.04,
          2318.0389999999998,
          2273.913,
          2229.666,
          2185.299,
          2140.8179999999998,
          2096.224,
          2051.522,
          2006.714,
          1961.8029999999999,
          1916.793,
          1871.6860000000001,
          1826.485,
          1781.194,
          1735.815,
          1690.351,
          1644.805,
          1599.1789999999999,
          1553.477,
          1507.7,
          1461.852,
          1415.9360000000001,
          1369.953,
          1323.9070000000002,
          1277.799,
          1231.633,
          1185.411,
          1139.135,
          1092.808,
          1046.432,
          1000.0089999999999,
          953.5419999999999,
          907.033,
          860.485,
          813.8989999999999,
          767.279,
          720.625,
          673.941,
          627.2280000000001,
          580.489,
          533.726,
          486.941,
          440.135,
          393.31199999999995,
          346.473,
          299.62,
          252.75599999999997,
          205.882,
          159,
          112.11200000000001,
          65.221,
          18.328,
          -28.565,
          -75.455,
          -122.34200000000001,
          -169.22299999999998,
          -216.095,
          -262.95799999999997,
          -309.81,
          -356.647,
          -403.47,
          -450.275,
          -497.061,
          -543.826,
          -590.568,
          -637.286,
          -683.977,
          -730.64,
          -777.273,
          -823.8739999999999,
          -870.442,
          -916.9739999999999,
          -963.4689999999999,
          -1009.925,
          -1056.34,
          -1102.712,
          -1149.0410000000002,
          -1195.323,
          -1241.558,
          -1287.743,
          -1333.876,
          -1379.957,
          -1425.983,
          -1471.9520000000002,
          -1517.8629999999998,
          -1563.713,
          -1609.5020000000002,
          -1655.2279999999998,
          -1700.888,
          -1746.48,
          -1792.004,
          -1837.4579999999999,
          -1882.839,
          -1928.146,
          -1973.3770000000002,
          -2018.531,
          -2063.605,
          -2108.598,
          -2153.508,
          -2198.333,
          -2243.072,
          -2287.722,
          -2332.283,
          -2376.751,
          -2421.126,
          -2465.405,
          -2509.587,
          -2553.67,
          -2597.651,
          -2641.53,
          -2685.305,
          -2728.972,
          -2772.532,
          -2815.9809999999998,
          -2859.3179999999998,
          -2902.5409999999997,
          -2945.6479999999997,
          -2988.637,
          -3031.507,
          -3074.2540000000004,
          -3116.8779999999997,
          -3159.377,
          -3201.748,
          -3243.989,
          -3286.099,
          -3328.075,
          -3369.9159999999997,
          -3411.619,
          -3453.1820000000002,
          -3494.603,
          -3535.881,
          -3577.013,
          -3617.9970000000003,
          -3658.83,
          -3699.511,
          -3740.038,
          -3780.408,
          -3820.619,
          -3860.6690000000003,
          -3900.555,
          -3940.276,
          -3979.829,
          -4019.212,
          -4058.422,
          -4097.456,
          -4136.314,
          -4174.992,
          -4213.488,
          -4251.799,
          -4289.923,
          -4327.858,
          -4365.6,
          -4403.148,
          -4440.498,
          -4477.649,
          -4514.596,
          -4551.339,
          -4587.874,
          -4624.197,
          -4660.308,
          -4696.202,
          -4731.877,
          -4767.329000000001,
          -4802.557,
          -4837.557,
          -4872.326,
          -4906.861,
          -4941.157999999999,
          -4975.215999999999,
          -5009.03,
          -5042.598,
          -5075.916,
          -5108.98,
          -5141.789000000001,
          -5174.337,
          -5206.622,
          -5238.641,
          -5270.388000000001,
          -5301.863,
          -5333.059,
          -5363.974,
          -5394.604,
          -5424.944,
          -5454.993,
          -5484.744000000001,
          -5514.195,
          -5543.340999999999,
          -5572.178000000001,
          -5600.701999999999,
          -5628.909000000001,
          -5656.793000000001,
          -5684.351,
          -5711.579000000001,
          -5738.471,
          -5765.023,
          -5791.231,
          -5817.089,
          -5842.592,
          -5867.736,
          -5892.515,
          -5916.924,
          -5940.9580000000005,
          -5964.611,
          -5987.879,
          -6010.755,
          -6033.233,
          -6055.308000000001,
          -6076.974,
          -6098.225,
          -6119.054,
          -6139.456,
          -6159.424,
          -6178.951,
          -6198.03,
          -6216.655,
          -6234.819,
          -6252.515,
          -6269.735,
          -6286.471,
          -6302.717,
          -6318.464,
          -6333.705,
          -6348.43,
          -6362.633000000001,
          -6376.303000000001,
          -6389.433000000001,
          -6402.014,
          -6414.036,
          -6425.49,
          -6436.366999999999,
          -6446.656999999999,
          -6456.349,
          -6465.433000000001,
          -6473.899,
          -6481.735,
          -6488.931,
          -6495.475,
          -6501.355,
          -6506.56,
          -6511.075,
          -6514.891,
          -6517.991999999999,
          -6520.366,
          -6522,
          -6522.878000000001,
          -6522.986,
          -6522.309,
          -6520.831,
          -6518.5380000000005,
          -6515.411999999999,
          -6511.436,
          -6506.593000000001,
          -6500.866,
          -6494.236,
          -6486.684,
          -6478.19,
          -6468.734,
          -6458.295,
          -6446.852,
          -6434.382,
          -6420.863,
          -6406.27,
          -6390.58,
          -6373.767,
          -6355.804,
          -6336.664000000001,
          -6316.32,
          -6294.741,
          -6271.899,
          -6247.7609999999995,
          -6222.297,
          -6195.471,
          -6167.249,
          -6137.594,
          -6106.47,
          -6073.838000000001,
          -6039.656999999999,
          -6003.8859999999995,
          -5966.48,
          -5927.393,
          -5886.58,
          -5843.991999999999,
          -5799.576,
          -5753.281,
          -5705.049,
          -5654.826,
          -5602.55,
          -5548.159000000001,
          -5491.588000000001,
          -5432.77,
          -5371.634,
          -5308.108,
          -5242.112,
          -5173.572,
          -5102.401,
          -5028.515,
          -4951.8240000000005,
          -4872.237,
          -4789.655,
          -4703.981,
          -4615.11,
          -4522.936,
          -4427.351,
          -4328.2390000000005,
          -4225.488,
          -4118.978,
          -4008.5890000000004,
          -3894.202,
          -3775.6940000000004,
          -3652.948,
          -3525.842,
          -3394.2659999999996,
          -3258.1079999999997,
          -3117.2729999999997,
          -2971.6679999999997,
          -2821.223,
          -2665.882,
          -2505.612,
          -2340.413,
          -2170.313,
          -1995.385,
          -1815.745,
          -1631.5639999999999,
          -1443.07,
          -1250.558,
          -1054.387,
          -854.9910000000001,
          -652.87,
          -448.594,
          -242.792,
          -36.148,
          170.61900000000003,
          376.765,
          581.543,
          784.217,
          984.081,
          1180.474,
          1372.797,
          1560.52,
          1743.1889999999999,
          1920.4279999999999,
          2091.944,
          2257.518,
          2416.998,
          2570.302,
          2717.3990000000003,
          2858.313,
          2993.1009999999997,
          3121.86,
          3244.712,
          3361.798,
          3473.276,
          3579.317,
          3680.094,
          3775.79,
          3866.586,
          3952.664,
          4034.202,
          4111.378,
          4184.362,
          4253.322,
          4318.418,
          4379.807,
          4437.6359999999995,
          4492.0509999999995,
          4543.188,
          4591.177,
          4636.146,
          4678.215,
          4717.495,
          4754.098,
          4788.127,
          4819.68,
          4848.853,
          4875.735,
          4900.412,
          4922.965,
          4943.473,
          4962.009,
          4978.644,
          4993.446,
          5006.479,
          5017.804,
          5027.481,
          5035.565,
          5042.111,
          5047.168,
          5050.786,
          5053.013,
          5053.892,
          5053.468,
          5051.782,
          5048.872,
          5044.775,
          5039.531,
          5033.1720000000005,
          5025.733,
          5017.246,
          5007.741,
          4997.248,
          4985.795999999999,
          4973.412,
          4960.123,
          4945.955,
          4930.932,
          4915.077,
          4898.414000000001,
          4880.965,
          4862.751,
          4843.792,
          4824.108,
          4803.719,
          4782.643,
          4760.898,
          4738.5,
          4715.469,
          4691.818,
          4667.564,
          4642.723,
          4617.308,
          4591.335,
          4564.817,
          4537.767,
          4510.1990000000005,
          4482.125,
          4453.557,
          4424.5070000000005,
          4394.988,
          4365.01,
          4334.583,
          4303.719,
          4272.429,
          4240.722,
          4208.608,
          4176.096,
          4143.196,
          4109.916,
          4076.2670000000003,
          4042.255,
          4007.89,
          3973.179,
          3938.131,
          3902.7529999999997,
          3867.052,
          3831.0370000000003,
          3794.715,
          3758.092,
          3721.175,
          3683.9709999999995,
          3646.486,
          3608.7270000000003,
          3570.7009999999996,
          3532.4120000000003,
          3493.868,
          3455.074,
          3416.035,
          3376.758,
          3337.248,
          3297.51,
          3257.55,
          3217.3720000000003,
          3176.982,
          3136.385,
          3095.5840000000003,
          3054.586,
          3013.395,
          2972.015,
          2930.452,
          2888.708,
          2846.789,
          2804.698,
          2762.441,
          2720.02,
          2677.441,
          2634.7059999999997,
          2591.82,
          2548.7870000000003,
          2505.61,
          2462.2929999999997,
          2418.84,
          2375.2529999999997,
          2331.538,
          2287.696,
          2243.732,
          2199.6479999999997,
          2155.449,
          2111.137,
          2066.715,
          2022.1870000000001,
          1977.555,
          1932.8229999999999,
          1887.994,
          1843.07,
          1798.055,
          1752.951,
          1707.761,
          1662.4879999999998,
          1617.135,
          1571.704,
          1526.1989999999998,
          1480.621,
          1434.974,
          1389.259,
          1343.48,
          1297.64,
          1251.739,
          1205.782,
          1159.77,
          1113.7060000000001,
          1067.5919999999999,
          1021.431,
          975.2239999999999,
          928.975,
          882.685,
          836.357,
          789.993,
          743.595,
          697.165,
          650.706,
          604.22,
          557.7090000000001,
          511.17400000000004,
          464.619,
          418.04400000000004,
          371.45300000000003,
          324.847,
          278.22900000000004,
          231.59900000000002,
          184.96099999999998,
          138.316,
          91.667,
          45.013999999999996,
          -1.639,
          -48.291000000000004,
          -94.94,
          -141.584,
          -188.222,
          -234.851,
          -281.469,
          -328.074,
          -374.666,
          -421.241,
          -467.798,
          -514.336,
          -560.851,
          -607.344,
          -653.811,
          -700.2510000000001,
          -746.6619999999999,
          -793.0419999999999,
          -839.39,
          -885.704,
          -931.9810000000001,
          -978.221,
          -1024.422,
          -1070.58,
          -1116.6960000000001,
          -1162.767,
          -1208.792,
          -1254.768,
          -1300.694,
          -1346.568,
          -1392.389,
          -1438.154,
          -1483.8629999999998,
          -1529.5120000000002,
          -1575.101,
          -1620.628,
          -1666.09,
          -1711.487,
          -1756.816,
          -1802.076,
          -1847.265,
          -1892.381,
          -1937.4229999999998,
          -1982.388,
          -2027.275,
          -2072.083,
          -2116.808,
          -2161.451,
          -2206.008,
          -2250.479,
          -2294.86,
          -2339.152,
          -2383.351,
          -2427.456,
          -2471.465,
          -2515.376,
          -2559.188,
          -2602.8979999999997,
          -2646.505,
          -2690.008,
          -2733.403,
          -2776.6890000000003,
          -2819.865,
          -2862.929,
          -2905.8779999999997,
          -2948.71,
          -2991.425,
          -3034.0190000000002,
          -3076.491,
          -3118.8390000000004,
          -3161.0609999999997,
          -3203.156,
          -3245.12,
          -3286.952,
          -3328.65,
          -3370.2129999999997,
          -3411.637,
          -3452.921,
          -3494.063,
          -3535.0609999999997,
          -3575.9120000000003,
          -3616.615,
          -3657.167,
          -3697.567,
          -3737.8109999999997,
          -3777.8990000000003,
          -3817.827,
          -3857.593,
          -3897.196,
          -3936.632,
          -3975.9,
          -4014.9959999999996,
          -4053.92,
          -4092.6690000000003,
          -4131.2390000000005,
          -4169.63,
          -4207.837,
          -4245.86,
          -4283.694,
          -4321.339,
          -4358.791,
          -4396.0470000000005,
          -4433.105,
          -4469.963,
          -4506.6179999999995,
          -4543.066,
          -4579.306,
          -4615.335,
          -4651.149,
          -4686.746,
          -4722.123,
          -4757.278,
          -4792.206,
          -4826.906,
          -4861.374,
          -4895.607,
          -4929.602,
          -4963.356,
          -4996.865,
          -5030.127,
          -5063.138,
          -5095.895,
          -5128.395,
          -5160.633,
          -5192.607,
          -5224.313,
          -5255.7480000000005,
          -5286.906999999999,
          -5317.7880000000005,
          -5348.385,
          -5378.696999999999,
          -5408.718000000001,
          -5438.445,
          -5467.874,
          -5497.001,
          -5525.821,
          -5554.331,
          -5582.526,
          -5610.401999999999,
          -5637.954000000001,
          -5665.179,
          -5692.07,
          -5718.625,
          -5744.838000000001,
          -5770.703,
          -5796.218000000001,
          -5821.375,
          -5846.170999999999,
          -5870.6,
          -5894.656999999999,
          -5918.3369999999995,
          -5941.633000000001,
          -5964.541,
          -5987.054,
          -6009.168000000001,
          -6030.875,
          -6052.170999999999,
          -6073.049,
          -6093.5019999999995,
          -6113.525,
          -6133.11,
          -6152.2519999999995,
          -6170.941999999999,
          -6189.175,
          -6206.943,
          -6224.2390000000005,
          -6241.055,
          -6257.384,
          -6273.218000000001,
          -6288.55,
          -6303.37,
          -6317.672,
          -6331.445,
          -6344.682,
          -6357.3730000000005,
          -6369.51,
          -6381.084,
          -6392.084,
          -6402.501,
          -6412.325,
          -6421.545999999999,
          -6430.153,
          -6438.135,
          -6445.481,
          -6452.179,
          -6458.219,
          -6463.5869999999995,
          -6468.273,
          -6472.263000000001,
          -6475.544,
          -6478.102,
          -6479.925,
          -6480.9980000000005,
          -6481.306,
          -6480.835,
          -6479.57,
          -6477.493,
          -6474.59,
          -6470.843000000001,
          -6466.235,
          -6460.7480000000005,
          -6454.365,
          -6447.066,
          -6438.831999999999,
          -6429.642,
          -6419.476,
          -6408.313,
          -6396.13,
          -6382.904,
          -6368.611999999999,
          -6353.229,
          -6336.731,
          -6319.090999999999,
          -6300.283,
          -6280.276999999999,
          -6259.045999999999,
          -6236.559,
          -6212.785,
          -6187.691999999999,
          -6161.246999999999,
          -6133.415,
          -6104.16,
          -6073.445,
          -6041.232,
          -6007.479,
          -5972.145,
          -5935.188,
          -5896.561,
          -5856.219,
          -5814.111999999999,
          -5770.189,
          -5724.398,
          -5676.684,
          -5626.9890000000005,
          -5575.255,
          -5521.419,
          -5465.415,
          -5407.178000000001,
          -5346.638000000001,
          -5283.721,
          -5218.351,
          -5150.45,
          -5079.935,
          -5006.721,
          -4930.717000000001,
          -4851.834,
          -4769.975,
          -4685.041,
          -4596.927,
          -4505.53,
          -4410.7390000000005,
          -4312.442,
          -4210.525,
          -4104.869000000001,
          -3995.3559999999998,
          -3881.865,
          -3764.2729999999997,
          -3642.4640000000004,
          -3516.317,
          -3385.72,
          -3250.5640000000003,
          -3110.748,
          -2966.185,
          -2816.7990000000004,
          -2662.535,
          -2503.36,
          -2339.268,
          -2170.2889999999998,
          -1996.491,
          -1817.9879999999998,
          -1634.9470000000001,
          -1447.592,
          -1256.213,
          -1061.1660000000002,
          -862.875,
          -661.84,
          -458.62300000000005,
          -253.84799999999998,
          -48.192,
          157.629,
          362.876,
          566.806,
          768.684,
          967.805,
          1163.512,
          1355.205,
          1542.352,
          1724.4979999999998,
          1901.266,
          2072.36,
          2237.558,
          2396.7070000000003,
          2549.722,
          2696.5679999999998,
          2837.2659999999996,
          2971.8740000000003,
          3100.482,
          3223.2129999999997,
          3340.204,
          3451.614,
          3557.607,
          3658.361,
          3754.052,
          3844.862,
          3930.9709999999995,
          4012.558,
          4089.797,
          4162.859,
          4231.91,
          4297.109,
          4358.612,
          4416.568,
          4471.119000000001,
          4522.402,
          4570.548,
          4615.681,
          4657.920999999999,
          4697.3820000000005,
          4734.173,
          4768.395,
          4800.15,
          4829.531,
          4856.626,
          4881.521,
          4904.298,
          4925.035,
          4943.805,
          4960.679,
          4975.723,
          4989.003,
          5000.579000000001,
          5010.51,
          5018.852,
          5025.659000000001,
          5030.98,
          5034.866,
          5037.363,
          5038.516,
          5038.3679999999995,
          5036.959,
          5034.33,
          5030.517,
          5025.558,
          5019.486,
          5012.335999999999,
          5004.139,
          4994.927,
          4984.728,
          4973.572,
          4961.486,
          4948.496,
          4934.628,
          4919.906,
          4904.353,
          4887.994000000001,
          4870.85,
          4852.942,
          4834.29,
          4814.914000000001,
          4794.833,
          4774.067,
          4752.6320000000005,
          4730.545999999999,
          4707.826,
          4684.487,
          4660.545999999999,
          4636.018,
          4610.917,
          4585.258,
          4559.054,
          4532.319,
          4505.066,
          4477.307,
          4449.055,
          4420.322,
          4391.119000000001,
          4361.457,
          4331.348,
          4300.8009999999995,
          4269.8279999999995,
          4238.438,
          4206.641,
          4174.446,
          4141.863,
          4108.9,
          4075.5679999999998,
          4041.873,
          4007.824,
          3973.43,
          3938.698,
          3903.636,
          3868.252,
          3832.553,
          3796.546,
          3760.238,
          3723.637,
          3686.748,
          3649.578,
          3612.134,
          3574.421,
          3536.447,
          3498.216,
          3459.735,
          3421.009,
          3382.045,
          3342.847,
          3303.42,
          3263.7709999999997,
          3223.9040000000005,
          3183.824,
          3143.5359999999996,
          3103.045,
          3062.355,
          3021.472,
          2980.4,
          2939.143,
          2897.7059999999997,
          2856.093,
          2814.308,
          2772.355,
          2730.239,
          2687.9629999999997,
          2645.532,
          2602.948,
          2560.217,
          2517.341,
          2474.325,
          2431.1710000000003,
          2387.884,
          2344.467,
          2300.923,
          2257.256,
          2213.469,
          2169.565,
          2125.548,
          2081.4210000000003,
          2037.1860000000001,
          1992.8470000000002,
          1948.4070000000002,
          1903.869,
          1859.236,
          1814.51,
          1769.695,
          1724.7939999999999,
          1679.808,
          1634.7420000000002,
          1589.5970000000002,
          1544.376,
          1499.082,
          1453.7179999999998,
          1408.286,
          1362.789,
          1317.229,
          1271.608,
          1225.93,
          1180.1960000000001,
          1134.4089999999999,
          1088.5710000000001,
          1042.685,
          996.753,
          950.7769999999999,
          904.76,
          858.703,
          812.61,
          766.482,
          720.321,
          674.13,
          627.91,
          581.665,
          535.395,
          489.10400000000004,
          442.792,
          396.463,
          350.11800000000005,
          303.759,
          257.389,
          211.00900000000001,
          164.62099999999998,
          118.227,
          71.829,
          25.43,
          -20.97,
          -67.368,
          -113.76100000000001,
          -160.149,
          -206.53,
          -252.90099999999998,
          -299.26,
          -345.60699999999997,
          -391.93800000000005,
          -438.25199999999995,
          -484.548,
          -530.823,
          -577.076,
          -623.305,
          -669.508,
          -715.683,
          -761.829,
          -807.943,
          -854.025,
          -900.071,
          -946.081,
          -992.053,
          -1037.984,
          -1083.874,
          -1129.72,
          -1175.52,
          -1221.274,
          -1266.979,
          -1312.6329999999998,
          -1358.235,
          -1403.7820000000002,
          -1449.274,
          -1494.7089999999998,
          -1540.0839999999998,
          -1585.398,
          -1630.65,
          -1675.8370000000002,
          -1720.9579999999999,
          -1766.011,
          -1810.994,
          -1855.906,
          -1900.745,
          -1945.5079999999998,
          -1990.195,
          -2034.8039999999999,
          -2079.3320000000003,
          -2123.779,
          -2168.1420000000003,
          -2212.419,
          -2256.609,
          -2300.71,
          -2344.72,
          -2388.638,
          -2432.4610000000002,
          -2476.188,
          -2519.8160000000003,
          -2563.345,
          -2606.7729999999997,
          -2650.0959999999995,
          -2693.315,
          -2736.426,
          -2779.428,
          -2822.3190000000004,
          -2865.097,
          -2907.761,
          -2950.308,
          -2992.736,
          -3035.0440000000003,
          -3077.2290000000003,
          -3119.29,
          -3161.225,
          -3203.031,
          -3244.7070000000003,
          -3286.2509999999997,
          -3327.6609999999996,
          -3368.934,
          -3410.0679999999998,
          -3451.063,
          -3491.914,
          -3532.6220000000003,
          -3573.1820000000002,
          -3613.594,
          -3653.8540000000003,
          -3693.961,
          -3733.913,
          -3773.708,
          -3813.342,
          -3852.815,
          -3892.123,
          -3931.265,
          -3970.238,
          -4009.04,
          -4047.6679999999997,
          -4086.12,
          -4124.393,
          -4162.486,
          -4200.396,
          -4238.12,
          -4275.656,
          -4313.001,
          -4350.153,
          -4387.108,
          -4423.866,
          -4460.4220000000005,
          -4496.774,
          -4532.92,
          -4568.856,
          -4604.58,
          -4640.089,
          -4675.38,
          -4710.451,
          -4745.298,
          -4779.918,
          -4814.309,
          -4848.468,
          -4882.39,
          -4916.0740000000005,
          -4949.516,
          -4982.713,
          -5015.661,
          -5048.358,
          -5080.799,
          -5112.982,
          -5144.903,
          -5176.558,
          -5207.945,
          -5239.058,
          -5269.896,
          -5300.453,
          -5330.727,
          -5360.713000000001,
          -5390.406999999999,
          -5419.806,
          -5448.905,
          -5477.701,
          -5506.189,
          -5534.365,
          -5562.224,
          -5589.763000000001,
          -5616.977,
          -5643.861,
          -5670.41,
          -5696.621,
          -5722.486999999999,
          -5748.005,
          -5773.17,
          -5797.976,
          -5822.418000000001,
          -5846.491999999999,
          -5870.191,
          -5893.51,
          -5916.444,
          -5938.986999999999,
          -5961.133000000001,
          -5982.8769999999995,
          -6004.213000000001,
          -6025.133000000001,
          -6045.633000000001,
          -6065.705,
          -6085.344,
          -6104.5419999999995,
          -6123.293000000001,
          -6141.590999999999,
          -6159.427,
          -6176.794,
          -6193.686,
          -6210.095,
          -6226.012,
          -6241.431,
          -6256.342,
          -6270.7390000000005,
          -6284.611999999999,
          -6297.953,
          -6310.753000000001,
          -6323.003000000001,
          -6334.693,
          -6345.815,
          -6356.357,
          -6366.312,
          -6375.6669999999995,
          -6384.4130000000005,
          -6392.539000000001,
          -6400.035,
          -6406.887,
          -6413.085999999999,
          -6418.618,
          -6423.473000000001,
          -6427.637,
          -6431.098000000001,
          -6433.840999999999,
          -6435.855,
          -6437.124,
          -6437.634,
          -6437.37,
          -6436.316999999999,
          -6434.46,
          -6431.781999999999,
          -6428.266,
          -6423.896,
          -6418.653,
          -6412.52,
          -6405.478,
          -6397.508000000001,
          -6388.588000000001,
          -6378.7,
          -6367.821,
          -6355.93,
          -6343.003000000001,
          -6329.018,
          -6313.9490000000005,
          -6297.774,
          -6280.464,
          -6261.993,
          -6242.335,
          -6221.4580000000005,
          -6199.335,
          -6175.934,
          -6151.223000000001,
          -6125.169,
          -6097.736999999999,
          -6068.893,
          -6038.598000000001,
          -6006.815,
          -5973.503000000001,
          -5938.62,
          -5902.125,
          -5863.972,
          -5824.115,
          -5782.504,
          -5739.09,
          -5693.82,
          -5646.639,
          -5597.491,
          -5546.316999999999,
          -5493.054,
          -5437.638000000001,
          -5380.003000000001,
          -5320.08,
          -5257.795,
          -5193.073,
          -5125.835,
          -5056,
          -4983.483,
          -4908.193,
          -4830.043,
          -4748.934,
          -4664.768,
          -4577.443,
          -4486.854,
          -4392.891,
          -4295.443,
          -4194.395,
          -4089.631,
          -3981.0290000000005,
          -3868.472,
          -3751.8379999999997,
          -3631.008,
          -3505.864,
          -3376.2909999999997,
          -3242.1820000000002,
          -3103.434,
          -2959.961,
          -2811.685,
          -2658.551,
          -2500.5229999999997,
          -2337.596,
          -2169.794,
          -1997.185,
          -1819.878,
          -1638.0379999999998,
          -1451.885,
          -1261.702,
          -1067.8419999999999,
          -870.7230000000001,
          -670.8380000000001,
          -468.744,
          -265.061,
          -60.458,
          144.35299999999998,
          348.639,
          551.658,
          752.68,
          951.0010000000001,
          1145.9660000000001,
          1336.974,
          1523.4920000000002,
          1705.066,
          1881.315,
          2051.9410000000003,
          2216.721,
          2375.4970000000003,
          2528.1820000000002,
          2674.741,
          2815.188,
          2949.5809999999997,
          3078.008,
          3200.587,
          3317.4559999999997,
          3428.77,
          3534.692,
          3635.397,
          3731.062,
          3821.866,
          3907.986,
          3989.603,
          4066.887,
          4140.0109999999995,
          4209.137,
          4274.425,
          4336.031,
          4394.101,
          4448.776,
          4500.195,
          4548.487,
          4593.713,
          4636.179,
          4675.813,
          4712.784000000001,
          4747.195,
          4779.145,
          4808.728,
          4836.032,
          4861.142,
          4884.14,
          4905.103,
          4924.104,
          4941.215,
          4956.5,
          4970.025,
          4981.852,
          4992.038,
          5000.638,
          5007.707,
          5013.293,
          5017.448,
          5020.218,
          5021.646,
          5021.776,
          5020.649,
          5018.303,
          5014.777,
          5010.106,
          5004.325,
          4997.469,
          4989.567,
          4980.653,
          4970.753,
          4959.899,
          4948.115,
          4935.43,
          4921.8679999999995,
          4907.454000000001,
          4892.210999999999,
          4876.162,
          4859.329000000001,
          4841.734,
          4823.396,
          4804.335999999999,
          4784.572,
          4764.122,
          4743.005,
          4721.2390000000005,
          4698.838,
          4675.82,
          4652.201,
          4627.995,
          4603.217000000001,
          4577.88,
          4552,
          4525.59,
          4498.661,
          4471.228,
          4443.302,
          4414.895,
          4386.018,
          4356.683,
          4326.901,
          4296.681,
          4266.035,
          4234.973,
          4203.503,
          4171.6359999999995,
          4139.380999999999,
          4106.746,
          4073.742,
          4040.375,
          4006.6540000000005,
          3972.5879999999997,
          3938.184,
          3903.4509999999996,
          3868.3940000000002,
          3833.0229999999997,
          3797.343,
          3761.363,
          3725.0879999999997,
          3688.526,
          3651.683,
          3614.565,
          3577.179,
          3539.53,
          3501.6259999999997,
          3463.47,
          3425.07,
          3386.43,
          3347.5559999999996,
          3308.454,
          3269.1279999999997,
          3229.5840000000003,
          3189.827,
          3149.862,
          3109.6929999999998,
          3069.325,
          3028.763,
          2988.012,
          2947.075,
          2905.9570000000003,
          2864.663,
          2823.197,
          2781.562,
          2739.764,
          2697.805,
          2655.69,
          2613.422,
          2571.006,
          2528.445,
          2485.742,
          2442.902,
          2399.928,
          2356.823,
          2313.59,
          2270.234,
          2226.757,
          2183.163,
          2139.4539999999997,
          2095.635,
          2051.7070000000003,
          2007.675,
          1963.5410000000002,
          1919.308,
          1874.979,
          1830.557,
          1786.045,
          1741.445,
          1696.761,
          1651.995,
          1607.15,
          1562.2279999999998,
          1517.233,
          1472.1660000000002,
          1427.03,
          1381.828,
          1336.5629999999999,
          1291.236,
          1245.851,
          1200.4089999999999,
          1154.913,
          1109.366,
          1063.769,
          1018.1260000000001,
          972.438,
          926.707,
          880.936,
          835.128,
          789.284,
          743.4060000000001,
          697.497,
          651.558,
          605.5930000000001,
          559.602,
          513.589,
          467.55400000000003,
          421.501,
          375.431,
          329.346,
          283.249,
          237.141,
          191.024,
          144.9,
          98.771,
          52.638999999999996,
          6.507000000000001,
          -39.625,
          -85.75399999999999,
          -131.879,
          -177.997,
          -224.107,
          -270.20599999999996,
          -316.293,
          -362.36699999999996,
          -408.42400000000004,
          -454.465,
          -500.485,
          -546.485,
          -592.462,
          -638.413,
          -684.3389999999999,
          -730.2360000000001,
          -776.1030000000001,
          -821.938,
          -867.7389999999999,
          -913.505,
          -959.2339999999999,
          -1004.924,
          -1050.5739999999998,
          -1096.181,
          -1141.744,
          -1187.261,
          -1232.731,
          -1278.151,
          -1323.521,
          -1368.8370000000002,
          -1414.1,
          -1459.305,
          -1504.453,
          -1549.5420000000001,
          -1594.569,
          -1639.533,
          -1684.432,
          -1729.264,
          -1774.0279999999998,
          -1818.7220000000002,
          -1863.344,
          -1907.8929999999998,
          -1952.366,
          -1996.763,
          -2041.0810000000001,
          -2085.3179999999998,
          -2129.473,
          -2173.544,
          -2217.529,
          -2261.426,
          -2305.234,
          -2348.951,
          -2392.575,
          -2436.105,
          -2479.538,
          -2522.8720000000003,
          -2566.107,
          -2609.239,
          -2652.2670000000003,
          -2695.19,
          -2738.006,
          -2780.712,
          -2823.3070000000002,
          -2865.788,
          -2908.155,
          -2950.405,
          -2992.535,
          -3034.546,
          -3076.433,
          -3118.196,
          -3159.8320000000003,
          -3201.3390000000004,
          -3242.716,
          -3283.961,
          -3325.07,
          -3366.0440000000003,
          -3406.8779999999997,
          -3447.572,
          -3488.123,
          -3528.528,
          -3568.7870000000003,
          -3608.897,
          -3648.855,
          -3688.66,
          -3728.309,
          -3767.8,
          -3807.132,
          -3846.3,
          -3885.304,
          -3924.1409999999996,
          -3962.809,
          -4001.305,
          -4039.6279999999997,
          -4077.7729999999997,
          -4115.74,
          -4153.526,
          -4191.129,
          -4228.545,
          -4265.772,
          -4302.808,
          -4339.65,
          -4376.295999999999,
          -4412.7429999999995,
          -4448.988,
          -4485.029,
          -4520.862,
          -4556.486,
          -4591.897,
          -4627.092000000001,
          -4662.069,
          -4696.8240000000005,
          -4731.356,
          -4765.66,
          -4799.734,
          -4833.5740000000005,
          -4867.179,
          -4900.543,
          -4933.665,
          -4966.541,
          -4999.167,
          -5031.541,
          -5063.659000000001,
          -5095.517,
          -5127.113,
          -5158.442,
          -5189.501,
          -5220.286,
          -5250.794,
          -5281.021,
          -5310.963000000001,
          -5340.616,
          -5369.976,
          -5399.04,
          -5427.803000000001,
          -5456.26,
          -5484.409000000001,
          -5512.244000000001,
          -5539.762,
          -5566.956999999999,
          -5593.825,
          -5620.363,
          -5646.564,
          -5672.424,
          -5697.939,
          -5723.103,
          -5747.9130000000005,
          -5772.361,
          -5796.444,
          -5820.156,
          -5843.491999999999,
          -5866.445,
          -5889.0109999999995,
          -5911.184,
          -5932.9580000000005,
          -5954.326,
          -5975.284000000001,
          -5995.8240000000005,
          -6015.941,
          -6035.6269999999995,
          -6054.8769999999995,
          -6073.684,
          -6092.04,
          -6109.94,
          -6127.374,
          -6144.3369999999995,
          -6160.821,
          -6176.818,
          -6192.319,
          -6207.318,
          -6221.806,
          -6235.776,
          -6249.217,
          -6262.121,
          -6274.48,
          -6286.284000000001,
          -6297.524,
          -6308.19,
          -6318.272,
          -6327.76,
          -6336.643,
          -6344.911999999999,
          -6352.554,
          -6359.56,
          -6365.916,
          -6371.611,
          -6376.634,
          -6380.971,
          -6384.611,
          -6387.539000000001,
          -6389.743,
          -6391.2080000000005,
          -6391.92,
          -6391.8640000000005,
          -6391.026,
          -6389.388000000001,
          -6386.937,
          -6383.654,
          -6379.523,
          -6374.526,
          -6368.646,
          -6361.863,
          -6354.159000000001,
          -6345.513000000001,
          -6335.906,
          -6325.315,
          -6313.72,
          -6301.097,
          -6287.423000000001,
          -6272.673000000001,
          -6256.825,
          -6239.851,
          -6221.724,
          -6202.418000000001,
          -6181.904,
          -6160.151999999999,
          -6137.130999999999,
          -6112.809,
          -6087.154,
          -6060.130999999999,
          -6031.706,
          -6001.840999999999,
          -5970.4980000000005,
          -5937.637,
          -5903.215999999999,
          -5867.194,
          -5829.526,
          -5790.166,
          -5749.064,
          -5706.172,
          -5661.437,
          -5614.803000000001,
          -5566.215999999999,
          -5515.616999999999,
          -5462.944,
          -5408.132,
          -5351.116,
          -5291.826999999999,
          -5230.193,
          -5166.138,
          -5099.582,
          -5030.448,
          -4958.649,
          -4884.097,
          -4806.7,
          -4726.365,
          -4642.9929999999995,
          -4556.482,
          -4466.727,
          -4373.62,
          -4277.048,
          -4176.899,
          -4073.0559999999996,
          -3965.3979999999997,
          -3853.809,
          -3738.165,
          -3618.349,
          -3494.243,
          -3365.7309999999998,
          -3232.708,
          -3095.0690000000004,
          -2952.7270000000003,
          -2805.6040000000003,
          -2653.6440000000002,
          -2496.8089999999997,
          -2335.093,
          -2168.518,
          -1997.148,
          -1821.09,
          -1640.505,
          -1455.608,
          -1266.678,
          -1074.062,
          -878.175,
          -679.5010000000001,
          -478.593,
          -276.064,
          -72.578,
          131.16,
          334.41900000000004,
          536.4630000000001,
          736.564,
          934.0219999999999,
          1128.181,
          1318.441,
          1504.27,
          1685.211,
          1860.884,
          2030.986,
          2195.292,
          2353.643,
          2505.948,
          2652.17,
          2792.32,
          2926.453,
          3054.656,
          3177.0440000000003,
          3293.7509999999997,
          3404.9320000000002,
          3510.748,
          3611.373,
          3706.9790000000003,
          3797.7459999999996,
          3883.8509999999997,
          3965.4709999999995,
          4042.776,
          4115.936,
          4185.116,
          4250.472,
          4312.16,
          4370.325,
          4425.108,
          4476.646,
          4525.068,
          4570.497,
          4613.052,
          4652.846,
          4689.986,
          4724.5740000000005,
          4756.71,
          4786.486,
          4813.99,
          4839.307,
          4862.519,
          4883.701,
          4902.929,
          4920.271,
          4935.793,
          4949.56,
          4961.634,
          4972.071,
          4980.927,
          4988.255999999999,
          4994.107,
          4998.53,
          5001.571,
          5003.275,
          5003.684,
          5002.838,
          5000.778,
          4997.539000000001,
          4993.159000000001,
          4987.6720000000005,
          4981.111,
          4973.508,
          4964.894,
          4955.298,
          4944.748,
          4933.272,
          4920.896,
          4907.645,
          4893.543,
          4878.6140000000005,
          4862.880999999999,
          4846.366,
          4829.09,
          4811.072,
          4792.334,
          4772.892,
          4752.767,
          4731.976,
          4710.535,
          4688.462,
          4665.772,
          4642.482,
          4618.606,
          4594.159000000001,
          4569.155,
          4543.607,
          4517.529,
          4490.934,
          4463.835,
          4436.244000000001,
          4408.1720000000005,
          4379.630999999999,
          4350.6320000000005,
          4321.187,
          4291.304,
          4260.995,
          4230.27,
          4199.139,
          4167.61,
          4135.693,
          4103.397,
          4070.7309999999998,
          4037.703,
          4004.322,
          3970.594,
          3936.53,
          3902.135,
          3867.4179999999997,
          3832.385,
          3797.045,
          3761.403,
          3725.467,
          3689.244,
          3652.739,
          3615.96,
          3578.9120000000003,
          3541.6020000000003,
          3504.035,
          3466.217,
          3428.1540000000005,
          3389.8509999999997,
          3351.3140000000003,
          3312.548,
          3273.559,
          3234.3509999999997,
          3194.929,
          3155.2990000000004,
          3115.465,
          3075.4320000000002,
          3035.204,
          2994.7859999999996,
          2954.1820000000002,
          2913.397,
          2872.4359999999997,
          2831.301,
          2789.998,
          2748.53,
          2706.901,
          2665.116,
          2623.177,
          2581.09,
          2538.857,
          2496.482,
          2453.969,
          2411.321,
          2368.541,
          2325.634,
          2282.6020000000003,
          2239.449,
          2196.178,
          2152.792,
          2109.294,
          2065.688,
          2021.976,
          1978.162,
          1934.2479999999998,
          1890.237,
          1846.1329999999998,
          1801.9370000000001,
          1757.654,
          1713.285,
          1668.8339999999998,
          1624.3020000000001,
          1579.693,
          1535.01,
          1490.254,
          1445.4289999999999,
          1400.537,
          1355.5810000000001,
          1310.562,
          1265.484,
          1220.348,
          1175.1580000000001,
          1129.915,
          1084.623,
          1039.282,
          993.8960000000001,
          948.466,
          902.9960000000001,
          857.4860000000001,
          811.94,
          766.36,
          720.747,
          675.1039999999999,
          629.433,
          583.735,
          538.014,
          492.27099999999996,
          446.509,
          400.728,
          354.93199999999996,
          309.122,
          263.3,
          217.468,
          171.62900000000002,
          125.78299999999999,
          79.934,
          34.082,
          -11.77,
          -57.62,
          -103.46700000000001,
          -149.308,
          -195.142,
          -240.967,
          -286.781,
          -332.582,
          -378.369,
          -424.139,
          -469.89099999999996,
          -515.623,
          -561.3330000000001,
          -607.02,
          -652.681,
          -698.315,
          -743.921,
          -789.495,
          -835.038,
          -880.546,
          -926.018,
          -971.453,
          -1016.8480000000001,
          -1062.202,
          -1107.514,
          -1152.78,
          -1198.001,
          -1243.174,
          -1288.296,
          -1333.368,
          -1378.386,
          -1423.35,
          -1468.256,
          -1513.105,
          -1557.8929999999998,
          -1602.62,
          -1647.283,
          -1691.881,
          -1736.412,
          -1780.875,
          -1825.267,
          -1869.5870000000002,
          -1913.8329999999999,
          -1958.004,
          -2002.0970000000002,
          -2046.111,
          -2090.045,
          -2133.896,
          -2177.663,
          -2221.343,
          -2264.936,
          -2308.439,
          -2351.851,
          -2395.169,
          -2438.393,
          -2481.52,
          -2524.548,
          -2567.476,
          -2610.301,
          -2653.0229999999997,
          -2695.638,
          -2738.1459999999997,
          -2780.545,
          -2822.8309999999997,
          -2865.005,
          -2907.063,
          -2949.0040000000004,
          -2990.8259999999996,
          -3032.527,
          -3074.105,
          -3115.558,
          -3156.885,
          -3198.0820000000003,
          -3239.1490000000003,
          -3280.083,
          -3320.882,
          -3361.5440000000003,
          -3402.067,
          -3442.45,
          -3482.6890000000003,
          -3522.783,
          -3562.7290000000003,
          -3602.526,
          -3642.172,
          -3681.664,
          -3720.9990000000003,
          -3760.177,
          -3799.1940000000004,
          -3838.0490000000004,
          -3876.738,
          -3915.261,
          -3953.613,
          -3991.7940000000003,
          -4029.8,
          -4067.63,
          -4105.281,
          -4142.75,
          -4180.035,
          -4217.133,
          -4254.043,
          -4290.76,
          -4327.284000000001,
          -4363.61,
          -4399.737,
          -4435.662,
          -4471.3820000000005,
          -4506.895,
          -4542.196,
          -4577.285,
          -4612.157999999999,
          -4646.811,
          -4681.2429999999995,
          -4715.45,
          -4749.43,
          -4783.178,
          -4816.692,
          -4849.97,
          -4883.0070000000005,
          -4915.8,
          -4948.347,
          -4980.643,
          -5012.687,
          -5044.473,
          -5075.999,
          -5107.262,
          -5138.2570000000005,
          -5168.981,
          -5199.43,
          -5229.601,
          -5259.49,
          -5289.093000000001,
          -5318.406,
          -5347.4259999999995,
          -5376.147,
          -5404.566,
          -5432.679,
          -5460.482,
          -5487.97,
          -5515.139,
          -5541.984,
          -5568.501,
          -5594.685,
          -5620.531,
          -5646.035,
          -5671.191999999999,
          -5695.9980000000005,
          -5720.445,
          -5744.531,
          -5768.249,
          -5791.594,
          -5814.56,
          -5837.143,
          -5859.335999999999,
          -5881.133000000001,
          -5902.529,
          -5923.517,
          -5944.092,
          -5964.246999999999,
          -5983.976,
          -6003.272,
          -6022.129,
          -6040.54,
          -6058.496999999999,
          -6075.994000000001,
          -6093.023,
          -6109.576999999999,
          -6125.648,
          -6141.229,
          -6156.311,
          -6170.887,
          -6184.948,
          -6198.486,
          -6211.491999999999,
          -6223.956999999999,
          -6235.871,
          -6247.226,
          -6258.012,
          -6268.219,
          -6277.838000000001,
          -6286.856,
          -6295.265,
          -6303.053000000001,
          -6310.209,
          -6316.721,
          -6322.578,
          -6327.768,
          -6332.278,
          -6336.096,
          -6339.209,
          -6341.603,
          -6343.264,
          -6344.178000000001,
          -6344.331,
          -6343.706999999999,
          -6342.291,
          -6340.066999999999,
          -6337.019,
          -6333.129,
          -6328.38,
          -6322.754,
          -6316.234,
          -6308.799,
          -6300.43,
          -6291.107,
          -6280.808000000001,
          -6269.513000000001,
          -6257.196999999999,
          -6243.84,
          -6229.415,
          -6213.899,
          -6197.266,
          -6179.49,
          -6160.544,
          -6140.398,
          -6119.024,
          -6096.39,
          -6072.465999999999,
          -6047.218000000001,
          -6020.6140000000005,
          -5992.616999999999,
          -5963.191,
          -5932.298000000001,
          -5899.898,
          -5865.951999999999,
          -5830.414000000001,
          -5793.243,
          -5754.392,
          -5713.813,
          -5671.456,
          -5627.269,
          -5581.198,
          -5533.188,
          -5483.18,
          -5431.113,
          -5376.923000000001,
          -5320.544,
          -5261.908,
          -5200.943,
          -5137.575,
          -5071.724,
          -5003.312,
          -4932.253,
          -4858.460999999999,
          -4781.843,
          -4702.307,
          -4619.755,
          -4534.084,
          -4445.191,
          -4352.968,
          -4257.303,
          -4158.084,
          -4055.1940000000004,
          -3948.513,
          -3837.926,
          -3723.309,
          -3604.5440000000003,
          -3481.514,
          -3354.1040000000003,
          -3222.2070000000003,
          -3085.719,
          -2944.552,
          -2798.6279999999997,
          -2647.889,
          -2492.297,
          -2331.842,
          -2166.545,
          -1996.467,
          -1821.714,
          -1642.4389999999999,
          -1458.856,
          -1271.239,
          -1079.9289999999999,
          -885.335,
          -687.936,
          -488.277,
          -286.965,
          -84.661,
          117.93799999999999,
          320.106,
          521.11,
          720.2260000000001,
          916.757,
          1110.048,
          1299.5,
          1484.5810000000001,
          1664.8310000000001,
          1839.871,
          2009.395,
          2173.175,
          2331.052,
          2482.93,
          2628.768,
          2768.578,
          2902.4109999999996,
          3030.349,
          3152.508,
          3269.018,
          3380.033,
          3485.71,
          3586.223,
          3681.742,
          3772.446,
          3858.509,
          3940.107,
          4017.41,
          4090.586,
          4159.799,
          4225.204000000001,
          4286.956,
          4345.1990000000005,
          4400.0740000000005,
          4451.717000000001,
          4500.255,
          4545.812,
          4588.505999999999,
          4628.4490000000005,
          4665.748,
          4700.504,
          4732.816,
          4762.777,
          4790.474,
          4815.992,
          4839.411,
          4860.809,
          4880.2570000000005,
          4897.826,
          4913.582,
          4927.588,
          4939.906,
          4950.592000000001,
          4959.7029999999995,
          4967.291,
          4973.406,
          4978.097,
          4981.41,
          4983.39,
          4984.0779999999995,
          4983.516,
          4981.742,
          4978.794,
          4974.707,
          4969.516,
          4963.254,
          4955.9529999999995,
          4947.643,
          4938.354,
          4928.1140000000005,
          4916.9490000000005,
          4904.887,
          4891.952,
          4878.169,
          4863.56,
          4848.149,
          4831.957,
          4815.005999999999,
          4797.316,
          4778.905,
          4759.794,
          4740,
          4719.541,
          4698.434,
          4676.696,
          4654.343,
          4631.39,
          4607.852,
          4583.745,
          4559.081,
          4533.874,
          4508.138,
          4481.8859999999995,
          4455.130999999999,
          4427.883,
          4400.156,
          4371.960999999999,
          4343.308,
          4314.209,
          4284.673,
          4254.712,
          4224.335,
          4193.552,
          4162.372,
          4130.804,
          4098.857,
          4066.5409999999997,
          4033.862,
          4000.8309999999997,
          3967.454,
          3933.739,
          3899.695,
          3865.328,
          3830.647,
          3795.657,
          3760.366,
          3724.78,
          3688.907,
          3652.7529999999997,
          3616.324,
          3579.627,
          3542.667,
          3505.45,
          3467.982,
          3430.268,
          3392.315,
          3354.1279999999997,
          3315.711,
          3277.071,
          3238.211,
          3199.138,
          3159.8559999999998,
          3120.369,
          3080.683,
          3040.802,
          3000.7309999999998,
          2960.474,
          2920.035,
          2879.4190000000003,
          2838.6290000000004,
          2797.67,
          2756.546,
          2715.261,
          2673.8190000000004,
          2632.223,
          2590.478,
          2548.587,
          2506.553,
          2464.38,
          2422.072,
          2379.632,
          2337.064,
          2294.37,
          2251.554,
          2208.62,
          2165.571,
          2122.409,
          2079.137,
          2035.76,
          1992.279,
          1948.6979999999999,
          1905.02,
          1861.247,
          1817.3829999999998,
          1773.43,
          1729.39,
          1685.267,
          1641.0639999999999,
          1596.7820000000002,
          1552.425,
          1507.995,
          1463.495,
          1418.9270000000001,
          1374.293,
          1329.5970000000002,
          1284.84,
          1240.025,
          1195.155,
          1150.231,
          1105.256,
          1060.232,
          1015.1619999999999,
          970.048,
          924.8919999999999,
          879.696,
          834.4630000000001,
          789.194,
          743.8919999999999,
          698.558,
          653.196,
          607.807,
          562.393,
          516.956,
          471.49800000000005,
          426.02099999999996,
          380.528,
          335.019,
          289.499,
          243.967,
          198.426,
          152.878,
          107.325,
          61.769,
          16.211,
          -29.345,
          -74.9,
          -120.45,
          -165.99400000000003,
          -211.53,
          -257.057,
          -302.57099999999997,
          -348.07300000000004,
          -393.559,
          -439.028,
          -484.478,
          -529.9069999999999,
          -575.314,
          -620.697,
          -666.054,
          -711.3839999999999,
          -756.684,
          -801.953,
          -847.189,
          -892.39,
          -937.555,
          -982.682,
          -1027.769,
          -1072.815,
          -1117.817,
          -1162.775,
          -1207.685,
          -1252.548,
          -1297.36,
          -1342.12,
          -1386.8270000000002,
          -1431.479,
          -1476.0739999999998,
          -1520.61,
          -1565.086,
          -1609.499,
          -1653.849,
          -1698.134,
          -1742.351,
          -1786.499,
          -1830.5770000000002,
          -1874.582,
          -1918.513,
          -1962.369,
          -2006.146,
          -2049.845,
          -2093.462,
          -2136.9970000000003,
          -2180.447,
          -2223.811,
          -2267.087,
          -2310.2729999999997,
          -2353.367,
          -2396.368,
          -2439.274,
          -2482.083,
          -2524.7929999999997,
          -2567.402,
          -2609.909,
          -2652.312,
          -2694.6090000000004,
          -2736.797,
          -2778.8759999999997,
          -2820.844,
          -2862.698,
          -2904.4359999999997,
          -2946.0570000000002,
          -2987.559,
          -3028.94,
          -3070.197,
          -3111.33,
          -3152.335,
          -3193.212,
          -3233.9570000000003,
          -3274.5690000000004,
          -3315.047,
          -3355.387,
          -3395.5890000000004,
          -3435.6490000000003,
          -3475.565,
          -3515.337,
          -3554.961,
          -3594.435,
          -3633.757,
          -3672.926,
          -3711.938,
          -3750.792,
          -3789.485,
          -3828.015,
          -3866.38,
          -3904.578,
          -3942.605,
          -3980.46,
          -4018.1409999999996,
          -4055.645,
          -4092.969,
          -4130.112,
          -4167.07,
          -4203.842000000001,
          -4240.424,
          -4276.814,
          -4313.009,
          -4349.008,
          -4384.806,
          -4420.402,
          -4455.792,
          -4490.975,
          -4525.947,
          -4560.705,
          -4595.246,
          -4629.568,
          -4663.668,
          -4697.542,
          -4731.188,
          -4764.603,
          -4797.782999999999,
          -4830.725,
          -4863.427,
          -4895.884,
          -4928.094,
          -4960.053,
          -4991.758,
          -5023.206,
          -5054.392,
          -5085.314,
          -5115.968,
          -5146.35,
          -5176.456,
          -5206.284000000001,
          -5235.8279999999995,
          -5265.085,
          -5294.0509999999995,
          -5322.723000000001,
          -5351.095,
          -5379.165,
          -5406.927,
          -5434.3769999999995,
          -5461.5109999999995,
          -5488.325,
          -5514.815,
          -5540.974,
          -5566.799,
          -5592.286,
          -5617.429,
          -5642.222,
          -5666.6630000000005,
          -5690.744000000001,
          -5714.460999999999,
          -5737.809,
          -5760.781999999999,
          -5783.374,
          -5805.58,
          -5827.395,
          -5848.812,
          -5869.826,
          -5890.43,
          -5910.618,
          -5930.383000000001,
          -5949.721,
          -5968.621999999999,
          -5987.081999999999,
          -6005.092,
          -6022.646,
          -6039.736999999999,
          -6056.357,
          -6072.499,
          -6088.155,
          -6103.316999999999,
          -6117.977,
          -6132.1269999999995,
          -6145.758000000001,
          -6158.861999999999,
          -6171.43,
          -6183.451999999999,
          -6194.92,
          -6205.8240000000005,
          -6216.154,
          -6225.9,
          -6235.052,
          -6243.599,
          -6251.531,
          -6258.835999999999,
          -6265.503000000001,
          -6271.521,
          -6276.878000000001,
          -6281.561,
          -6285.557,
          -6288.854,
          -6291.439,
          -6293.297,
          -6294.414000000001,
          -6294.776,
          -6294.369000000001,
          -6293.175,
          -6291.181,
          -6288.369000000001,
          -6284.723000000001,
          -6280.225,
          -6274.858,
          -6268.603,
          -6261.441,
          -6253.352,
          -6244.318,
          -6234.316,
          -6223.325,
          -6211.323,
          -6198.286999999999,
          -6184.193,
          -6169.017,
          -6152.732,
          -6135.314,
          -6116.734,
          -6096.965,
          -6075.977,
          -6053.7390000000005,
          -6030.222,
          -6005.392,
          -5979.215,
          -5951.656999999999,
          -5922.682,
          -5892.25,
          -5860.325,
          -5826.8640000000005,
          -5791.825,
          -5755.165,
          -5716.8369999999995,
          -5676.795,
          -5634.9890000000005,
          -5591.366999999999,
          -5545.876,
          -5498.46,
          -5449.062,
          -5397.619000000001,
          -5344.07,
          -5288.349,
          -5230.387,
          -5170.1140000000005,
          -5107.455,
          -5042.333,
          -4974.666,
          -4904.374,
          -4831.3679999999995,
          -4755.557,
          -4676.849,
          -4595.144,
          -4510.345,
          -4422.346,
          -4331.039000000001,
          -4236.316,
          -4138.061,
          -4036.1609999999996,
          -3930.4970000000003,
          -3820.95,
          -3707.3990000000003,
          -3589.728,
          -3467.8179999999998,
          -3341.555,
          -3210.83,
          -3075.5429999999997,
          -2935.6,
          -2790.927,
          -2641.462,
          -2487.167,
          -2328.029,
          -2164.0679999999998,
          -1995.3429999999998,
          -1821.953,
          -1644.0520000000001,
          -1461.8470000000002,
          -1275.607,
          -1085.6680000000001,
          -892.433,
          -696.3739999999999,
          -498.032,
          -298.006,
          -96.949,
          104.445,
          305.457,
          505.358,
          703.428,
          898.972,
          1091.337,
          1279.923,
          1464.201,
          1643.71,
          1818.066,
          1986.965,
          2150.175,
          2307.533,
          2458.942,
          2604.359,
          2743.792,
          2877.288,
          3004.929,
          3126.827,
          3243.112,
          3353.93,
          3459.4440000000004,
          3559.8190000000004,
          3655.228,
          3745.8459999999995,
          3831.847,
          3913.402,
          3990.685,
          4063.861,
          4133.089,
          4198.528,
          4260.33,
          4318.638,
          4373.593,
          4425.3279999999995,
          4473.972,
          4519.673,
          4562.471,
          4602.554,
          4640.003,
          4674.920999999999,
          4707.404,
          4737.544,
          4765.429,
          4791.143,
          4814.766,
          4836.374,
          4856.041,
          4873.835,
          4889.822,
          4904.066,
          4916.627,
          4927.563,
          4936.928,
          4944.774,
          4951.154,
          4956.1140000000005,
          4959.701,
          4961.958,
          4962.928,
          4962.652,
          4961.167,
          4958.512,
          4954.722,
          4949.831,
          4943.873,
          4936.877,
          4928.876,
          4919.899,
          4909.973,
          4899.125,
          4887.383,
          4874.77,
          4861.31,
          4847.028,
          4831.946,
          4816.085,
          4799.465,
          4782.109,
          4764.034000000001,
          4745.26,
          4725.805,
          4705.687,
          4684.9220000000005,
          4663.527,
          4641.518,
          4618.91,
          4595.719,
          4571.96,
          4547.645,
          4522.789000000001,
          4497.405,
          4471.505,
          4445.103,
          4418.209,
          4390.837,
          4362.997,
          4334.7,
          4305.957,
          4276.779,
          4247.1759999999995,
          4217.157,
          4186.733,
          4155.912,
          4124.704000000001,
          4093.118,
          4061.1620000000003,
          4028.844,
          3996.1740000000004,
          3963.158,
          3929.8059999999996,
          3896.123,
          3862.119,
          3827.7990000000004,
          3793.172,
          3758.244,
          3723.0209999999997,
          3687.511,
          3651.72,
          3615.653,
          3579.3179999999998,
          3542.7209999999995,
          3505.866,
          3468.761,
          3431.409,
          3393.8179999999998,
          3355.992,
          3317.937,
          3279.658,
          3241.16,
          3202.448,
          3163.527,
          3124.401,
          3085.075,
          3045.555,
          3005.843,
          2965.945,
          2925.865,
          2885.6079999999997,
          2845.176,
          2804.5759999999996,
          2763.809,
          2722.881,
          2681.796,
          2640.5559999999996,
          2599.167,
          2557.63,
          2515.951,
          2474.133,
          2432.178,
          2390.092,
          2347.876,
          2305.534,
          2263.07,
          2220.487,
          2177.7870000000003,
          2134.975,
          2092.053,
          2049.024,
          2005.891,
          1962.6570000000002,
          1919.325,
          1875.898,
          1832.378,
          1788.769,
          1745.0729999999999,
          1701.293,
          1657.432,
          1613.4920000000002,
          1569.475,
          1525.385,
          1481.223,
          1436.994,
          1392.6979999999999,
          1348.338,
          1303.917,
          1259.437,
          1214.9,
          1170.31,
          1125.667,
          1080.975,
          1036.236,
          991.451,
          946.6239999999999,
          901.7560000000001,
          856.85,
          811.9069999999999,
          766.93,
          721.921,
          676.8810000000001,
          631.814,
          586.721,
          541.605,
          496.466,
          451.30800000000005,
          406.131,
          360.939,
          315.733,
          270.51599999999996,
          225.28799999999998,
          180.05200000000002,
          134.81,
          89.56299999999999,
          44.315,
          -0.935,
          -46.183,
          -91.427,
          -136.667,
          -181.9,
          -227.12400000000002,
          -272.33799999999997,
          -317.54,
          -362.727,
          -407.899,
          -453.05199999999996,
          -498.18699999999995,
          -543.3,
          -588.391,
          -633.456,
          -678.4960000000001,
          -723.507,
          -768.488,
          -813.438,
          -858.3539999999999,
          -903.235,
          -948.08,
          -992.885,
          -1037.651,
          -1082.375,
          -1127.055,
          -1171.69,
          -1216.277,
          -1260.816,
          -1305.305,
          -1349.741,
          -1394.124,
          -1438.451,
          -1482.721,
          -1526.932,
          -1571.082,
          -1615.17,
          -1659.194,
          -1703.152,
          -1747.0420000000001,
          -1790.864,
          -1834.614,
          -1878.2920000000001,
          -1921.896,
          -1965.424,
          -2008.8729999999998,
          -2052.244,
          -2095.533,
          -2138.739,
          -2181.86,
          -2224.895,
          -2267.842,
          -2310.699,
          -2353.464,
          -2396.135,
          -2438.7110000000002,
          -2481.19,
          -2523.57,
          -2565.85,
          -2608.026,
          -2650.099,
          -2692.065,
          -2733.923,
          -2775.671,
          -2817.308,
          -2858.83,
          -2900.238,
          -2941.527,
          -2982.698,
          -3023.7470000000003,
          -3064.673,
          -3105.473,
          -3146.147,
          -3186.691,
          -3227.105,
          -3267.385,
          -3307.53,
          -3347.538,
          -3387.406,
          -3427.134,
          -3466.717,
          -3506.156,
          -3545.446,
          -3584.587,
          -3623.5759999999996,
          -3662.4109999999996,
          -3701.09,
          -3739.6090000000004,
          -3777.968,
          -3816.164,
          -3854.195,
          -3892.0570000000002,
          -3929.75,
          -3967.27,
          -4004.616,
          -4041.785,
          -4078.7729999999997,
          -4115.58,
          -4152.202,
          -4188.637,
          -4224.883,
          -4260.936,
          -4296.794,
          -4332.455,
          -4367.916,
          -4403.174,
          -4438.226,
          -4473.07,
          -4507.7029999999995,
          -4542.121,
          -4576.323,
          -4610.305,
          -4644.064,
          -4677.597,
          -4710.902,
          -4743.974,
          -4776.812,
          -4809.411,
          -4841.769,
          -4873.8820000000005,
          -4905.748,
          -4937.362,
          -4968.721,
          -4999.822,
          -5030.661,
          -5061.235,
          -5091.541,
          -5121.573,
          -5151.33,
          -5180.806,
          -5209.999,
          -5238.904,
          -5267.516,
          -5295.8330000000005,
          -5323.851,
          -5351.563,
          -5378.968000000001,
          -5406.06,
          -5432.835,
          -5459.2880000000005,
          -5485.415,
          -5511.210999999999,
          -5536.672,
          -5561.7919999999995,
          -5586.566999999999,
          -5610.991999999999,
          -5635.062,
          -5658.772,
          -5682.115,
          -5705.088000000001,
          -5727.683000000001,
          -5749.896,
          -5771.722,
          -5793.154,
          -5814.187,
          -5834.813,
          -5855.028,
          -5874.825,
          -5894.196999999999,
          -5913.138000000001,
          -5931.641,
          -5949.7,
          -5967.306,
          -5984.454000000001,
          -6001.135,
          -6017.343000000001,
          -6033.069,
          -6048.306,
          -6063.045999999999,
          -6077.28,
          -6091,
          -6104.198,
          -6116.865,
          -6128.991999999999,
          -6140.569,
          -6151.588000000001,
          -6162.036999999999,
          -6171.909000000001,
          -6181.191,
          -6189.875,
          -6197.948,
          -6205.401,
          -6212.222,
          -6218.399,
          -6223.920999999999,
          -6228.775,
          -6232.9490000000005,
          -6236.429,
          -6239.204000000001,
          -6241.258000000001,
          -6242.578,
          -6243.15,
          -6242.959,
          -6241.9890000000005,
          -6240.225,
          -6237.651,
          -6234.25,
          -6230.004,
          -6224.897,
          -6218.91,
          -6212.023,
          -6204.218000000001,
          -6195.475,
          -6185.773,
          -6175.09,
          -6163.405,
          -6150.695,
          -6136.936,
          -6122.103,
          -6106.173000000001,
          -6089.116999999999,
          -6070.91,
          -6051.524,
          -6030.928000000001,
          -6009.094,
          -5985.991,
          -5961.585999999999,
          -5935.845,
          -5908.735,
          -5880.218000000001,
          -5850.258000000001,
          -5818.816,
          -5785.851,
          -5751.321,
          -5715.183000000001,
          -5677.39,
          -5637.898,
          -5596.655,
          -5553.611999999999,
          -5508.714,
          -5461.906999999999,
          -5413.132,
          -5362.33,
          -5309.437,
          -5254.39,
          -5197.12,
          -5137.557,
          -5075.626,
          -5011.251,
          -4944.352,
          -4874.846,
          -4802.647,
          -4727.666,
          -4649.808,
          -4568.977,
          -4485.073,
          -4397.994000000001,
          -4307.6320000000005,
          -4213.877,
          -4116.616,
          -4015.735,
          -3911.117,
          -3802.6440000000002,
          -3690.1929999999998,
          -3573.65,
          -3452.8959999999997,
          -3327.817,
          -3198.303,
          -3064.2540000000004,
          -2925.579,
          -2782.197,
          -2634.051,
          -2481.098,
          -2323.324,
          -2160.749,
          -1993.4260000000002,
          -1821.453,
          -1644.979,
          -1464.207,
          -1279.402,
          -1090.891,
          -899.075,
          -704.419,
          -507.45599999999996,
          -308.779,
          -109.035,
          91.089,
          290.878,
          489.61,
          686.566,
          881.057,
          1072.43,
          1260.086,
          1443.497,
          1622.201,
          1795.8129999999999,
          1964.027,
          2126.609,
          2283.393,
          2434.28,
          2579.224,
          2718.2290000000003,
          2851.342,
          2978.6409999999996,
          3100.235,
          3216.252,
          3326.836,
          3432.1479999999997,
          3532.35,
          3627.615,
          3718.115,
          3804.0229999999997,
          3885.509,
          3962.744,
          4035.8920000000003,
          4105.113,
          4170.563,
          4232.392,
          4290.745,
          4345.7609999999995,
          4397.57,
          4446.303,
          4492.081,
          4535.019,
          4575.23,
          4612.817,
          4647.884,
          4680.526,
          4710.835,
          4738.898,
          4764.8,
          4788.619000000001,
          4810.43,
          4830.308,
          4848.321,
          4864.534000000001,
          4879.0109999999995,
          4891.811,
          4902.992,
          4912.608,
          4920.710999999999,
          4927.353,
          4932.58,
          4936.439,
          4938.974,
          4940.226,
          4940.235,
          4939.041,
          4936.68,
          4933.188,
          4928.599,
          4922.945,
          4916.259,
          4908.569,
          4899.906,
          4890.298,
          4879.772,
          4868.353,
          4856.066,
          4842.935,
          4828.984,
          4814.235,
          4798.709,
          4782.428,
          4765.411,
          4747.679,
          4729.248,
          4710.139,
          4690.3679999999995,
          4669.952,
          4648.907,
          4627.25,
          4604.996,
          4582.16,
          4558.755999999999,
          4534.799,
          4510.302,
          4485.277,
          4459.738,
          4433.698,
          4407.167,
          4380.159000000001,
          4352.683,
          4324.752,
          4296.376,
          4267.565,
          4238.329000000001,
          4208.679,
          4178.624,
          4148.173,
          4117.335,
          4086.119,
          4054.534,
          4022.5890000000004,
          3990.29,
          3957.647,
          3924.667,
          3891.3579999999997,
          3857.7270000000003,
          3823.781,
          3789.528,
          3754.973,
          3720.125,
          3684.989,
          3649.572,
          3613.881,
          3577.92,
          3541.697,
          3505.217,
          3468.486,
          3431.51,
          3394.2929999999997,
          3356.842,
          3319.1609999999996,
          3281.257,
          3243.132,
          3204.7940000000003,
          3166.2470000000003,
          3127.494,
          3088.542,
          3049.395,
          3010.0559999999996,
          2970.531,
          2930.823,
          2890.937,
          2850.8779999999997,
          2810.6479999999997,
          2770.2529999999997,
          2729.695,
          2688.98,
          2648.11,
          2607.089,
          2565.922,
          2524.611,
          2483.161,
          2441.574,
          2399.854,
          2358.005,
          2316.029,
          2273.93,
          2231.712,
          2189.376,
          2146.928,
          2104.369,
          2061.702,
          2018.931,
          1976.058,
          1933.0870000000002,
          1890.019,
          1846.859,
          1803.609,
          1760.27,
          1716.848,
          1673.342,
          1629.7579999999998,
          1586.096,
          1542.36,
          1498.5520000000001,
          1454.675,
          1410.731,
          1366.7220000000002,
          1322.651,
          1278.521,
          1234.333,
          1190.09,
          1145.795,
          1101.4489999999998,
          1057.0539999999999,
          1012.6139999999999,
          968.13,
          923.605,
          879.04,
          834.438,
          789.8,
          745.13,
          700.428,
          655.698,
          610.941,
          566.159,
          521.355,
          476.529,
          431.685,
          386.824,
          341.94800000000004,
          297.058,
          252.158,
          207.24900000000002,
          162.333,
          117.411,
          72.485,
          27.558000000000003,
          -17.368,
          -62.293,
          -107.214,
          -152.129,
          -197.03599999999997,
          -241.935,
          -286.822,
          -331.69599999999997,
          -376.555,
          -421.398,
          -466.223,
          -511.028,
          -555.811,
          -600.571,
          -645.306,
          -690.0139999999999,
          -734.693,
          -779.341,
          -823.9580000000001,
          -868.541,
          -913.0880000000001,
          -957.5989999999999,
          -1002.07,
          -1046.501,
          -1090.889,
          -1135.234,
          -1179.532,
          -1223.7839999999999,
          -1267.986,
          -1312.138,
          -1356.237,
          -1400.2820000000002,
          -1444.271,
          -1488.203,
          -1532.075,
          -1575.8870000000002,
          -1619.636,
          -1663.3210000000001,
          -1706.94,
          -1750.491,
          -1793.973,
          -1837.3829999999998,
          -1880.721,
          -1923.985,
          -1967.172,
          -2010.281,
          -2053.311,
          -2096.259,
          -2139.125,
          -2181.905,
          -2224.599,
          -2267.2039999999997,
          -2309.719,
          -2352.143,
          -2394.472,
          -2436.7070000000003,
          -2478.844,
          -2520.882,
          -2562.819,
          -2604.653,
          -2646.384,
          -2688.007,
          -2729.5229999999997,
          -2770.929,
          -2812.223,
          -2853.403,
          -2894.467,
          -2935.414,
          -2976.242,
          -3016.948,
          -3057.531,
          -3097.988,
          -3138.3190000000004,
          -3178.52,
          -3218.59,
          -3258.527,
          -3298.329,
          -3337.993,
          -3377.518,
          -3416.902,
          -3456.1420000000003,
          -3495.237,
          -3534.184,
          -3572.9809999999998,
          -3611.6259999999997,
          -3650.116,
          -3688.4509999999996,
          -3726.6259999999997,
          -3764.6409999999996,
          -3802.492,
          -3840.178,
          -3877.696,
          -3915.0440000000003,
          -3952.22,
          -3989.2209999999995,
          -4026.0440000000003,
          -4062.688,
          -4099.149,
          -4135.4259999999995,
          -4171.515,
          -4207.414000000001,
          -4243.121,
          -4278.633,
          -4313.948,
          -4349.062,
          -4383.972,
          -4418.677,
          -4453.174,
          -4487.459,
          -4521.529,
          -4555.383,
          -4589.016,
          -4622.4259999999995,
          -4655.61,
          -4688.564,
          -4721.287,
          -4753.774,
          -4786.022,
          -4818.029,
          -4849.79,
          -4881.303,
          -4912.564,
          -4943.57,
          -4974.317,
          -5004.802,
          -5035.021,
          -5064.971,
          -5094.647,
          -5124.0470000000005,
          -5153.165,
          -5181.999,
          -5210.544,
          -5238.7970000000005,
          -5266.753000000001,
          -5294.408,
          -5321.759,
          -5348.799,
          -5375.526999999999,
          -5401.936,
          -5428.022,
          -5453.781,
          -5479.2080000000005,
          -5504.299,
          -5529.047,
          -5553.45,
          -5577.5,
          -5601.195,
          -5624.526999999999,
          -5647.491999999999,
          -5670.0830000000005,
          -5692.297,
          -5714.1269999999995,
          -5735.566999999999,
          -5756.611999999999,
          -5777.255,
          -5797.491,
          -5817.313,
          -5836.714,
          -5855.688,
          -5874.229,
          -5892.33,
          -5909.984,
          -5927.183000000001,
          -5943.92,
          -5960.189,
          -5975.98,
          -5991.2880000000005,
          -6006.103,
          -6020.4169999999995,
          -6034.223000000001,
          -6047.5109999999995,
          -6060.274,
          -6072.501,
          -6084.184,
          -6095.314,
          -6105.880999999999,
          -6115.874,
          -6125.285,
          -6134.102,
          -6142.315,
          -6149.9130000000005,
          -6156.885,
          -6163.22,
          -6168.906,
          -6173.93,
          -6178.28,
          -6181.943,
          -6184.906999999999,
          -6187.156999999999,
          -6188.68,
          -6189.4619999999995,
          -6189.488,
          -6188.741999999999,
          -6187.209,
          -6184.874,
          -6181.719,
          -6177.727,
          -6172.882,
          -6167.164000000001,
          -6160.556,
          -6153.036999999999,
          -6144.588000000001,
          -6135.189,
          -6124.819,
          -6113.455,
          -6101.075,
          -6087.655,
          -6073.172,
          -6057.6,
          -6040.9130000000005,
          -6023.085,
          -6004.0869999999995,
          -5983.892,
          -5962.469,
          -5939.786,
          -5915.814,
          -5890.518,
          -5863.8640000000005,
          -5835.816,
          -5806.3369999999995,
          -5775.388000000001,
          -5742.93,
          -5708.92,
          -5673.316,
          -5636.071,
          -5597.14,
          -5556.474,
          -5514.023,
          -5469.733,
          -5423.549,
          -5375.414000000001,
          -5325.269,
          -5273.05,
          -5218.695,
          -5162.135,
          -5103.3,
          -5042.117,
          -4978.51,
          -4912.399,
          -4843.702,
          -4772.334,
          -4698.204000000001,
          -4621.222,
          -4541.29,
          -4458.309,
          -4372.1759999999995,
          -4282.787,
          -4190.03,
          -4093.7940000000003,
          -3993.965,
          -3890.426,
          -3783.059,
          -3671.745,
          -3556.366,
          -3436.8059999999996,
          -3312.949,
          -3184.687,
          -3051.92,
          -2914.555,
          -2772.512,
          -2625.73,
          -2474.169,
          -2317.81,
          -2156.6710000000003,
          -1990.8039999999999,
          -1820.3029999999999,
          -1645.3129999999999,
          -1466.0320000000002,
          -1282.72,
          -1095.701,
          -905.367,
          -712.177,
          -516.658,
          -319.39599999999996,
          -121.031,
          77.756,
          276.256,
          473.75,
          669.528,
          862.8989999999999,
          1053.215,
          1239.879,
          1422.361,
          1600.1989999999998,
          1773.009,
          1940.481,
          2102.38,
          2258.5370000000003,
          2408.851,
          2553.2729999999997,
          2691.805,
          2824.49,
          2951.4040000000005,
          3072.6540000000005,
          3188.364,
          3298.679,
          3403.7529999999997,
          3503.7509999999997,
          3598.84,
          3689.1929999999998,
          3774.98,
          3856.37,
          3933.532,
          4006.63,
          4075.821,
          4141.2609999999995,
          4203.099,
          4261.478,
          4316.536,
          4368.405,
          4417.212,
          4463.0779999999995,
          4506.1179999999995,
          4546.442,
          4584.156,
          4619.361,
          4652.153,
          4682.622,
          4710.855,
          4736.937,
          4760.944,
          4782.9529999999995,
          4803.037,
          4821.264,
          4837.6990000000005,
          4852.405,
          4865.441,
          4876.8640000000005,
          4886.729,
          4895.087,
          4901.99,
          4907.484,
          4911.615,
          4914.4259999999995,
          4915.96,
          4916.255999999999,
          4915.354,
          4913.288,
          4910.096,
          4905.811,
          4900.465,
          4894.090999999999,
          4886.715999999999,
          4878.372,
          4869.085999999999,
          4858.884,
          4847.793,
          4835.837,
          4823.04,
          4809.4259999999995,
          4795.016,
          4779.832,
          4763.894,
          4747.224,
          4729.839,
          4711.76,
          4693.002,
          4673.585999999999,
          4653.526,
          4632.84,
          4611.543,
          4589.65,
          4567.177,
          4544.138,
          4520.545999999999,
          4496.416,
          4471.76,
          4446.590999999999,
          4420.920999999999,
          4394.763,
          4368.128,
          4341.027,
          4313.471,
          4285.471,
          4257.037,
          4228.179,
          4198.907999999999,
          4169.232,
          4139.161,
          4108.704000000001,
          4077.87,
          4046.667,
          4015.1040000000003,
          3983.1890000000003,
          3950.929,
          3918.333,
          3885.409,
          3852.1620000000003,
          3818.6020000000003,
          3784.7340000000004,
          3750.565,
          3716.103,
          3681.353,
          3646.323,
          3611.018,
          3575.4440000000004,
          3539.6079999999997,
          3503.515,
          3467.171,
          3430.5820000000003,
          3393.7529999999997,
          3356.6890000000003,
          3319.395,
          3281.877,
          3244.14,
          3206.1890000000003,
          3168.028,
          3129.6620000000003,
          3091.0959999999995,
          3052.335,
          3013.382,
          2974.243,
          2934.921,
          2895.42,
          2855.7459999999996,
          2815.901,
          2775.89,
          2735.717,
          2695.385,
          2654.8979999999997,
          2614.261,
          2573.476,
          2532.548,
          2491.479,
          2450.2729999999997,
          2408.9339999999997,
          2367.465,
          2325.869,
          2284.15,
          2242.31,
          2200.353,
          2158.282,
          2116.1,
          2073.81,
          2031.415,
          1988.918,
          1946.3210000000001,
          1903.628,
          1860.8410000000001,
          1817.964,
          1774.9979999999998,
          1731.9460000000001,
          1688.8120000000001,
          1645.5970000000002,
          1602.305,
          1558.9379999999999,
          1515.4979999999998,
          1471.9879999999998,
          1428.41,
          1384.767,
          1341.06,
          1297.2939999999999,
          1253.469,
          1209.589,
          1165.655,
          1121.6689999999999,
          1077.635,
          1033.5539999999999,
          989.428,
          945.2589999999999,
          901.051,
          856.804,
          812.5210000000001,
          768.204,
          723.855,
          679.4760000000001,
          635.07,
          590.638,
          546.182,
          501.704,
          457.20599999999996,
          412.69,
          368.159,
          323.613,
          279.056,
          234.488,
          189.912,
          145.329,
          100.742,
          56.152,
          11.561,
          -33.029,
          -77.616,
          -122.199,
          -166.775,
          -211.343,
          -255.90099999999998,
          -300.447,
          -344.98,
          -389.49800000000005,
          -433.99800000000005,
          -478.48,
          -522.942,
          -567.381,
          -611.7959999999999,
          -656.186,
          -700.548,
          -744.882,
          -789.184,
          -833.454,
          -877.69,
          -921.89,
          -966.053,
          -1010.176,
          -1054.258,
          -1098.298,
          -1142.2930000000001,
          -1186.243,
          -1230.145,
          -1273.997,
          -1317.799,
          -1361.547,
          -1405.2420000000002,
          -1448.88,
          -1492.461,
          -1535.9820000000002,
          -1579.442,
          -1622.84,
          -1666.172,
          -1709.4389999999999,
          -1752.638,
          -1795.7679999999998,
          -1838.826,
          -1881.8110000000001,
          -1924.7220000000002,
          -1967.556,
          -2010.3129999999999,
          -2052.989,
          -2095.584,
          -2138.096,
          -2180.5229999999997,
          -2222.863,
          -2265.115,
          -2307.277,
          -2349.346,
          -2391.322,
          -2433.203,
          -2474.986,
          -2516.67,
          -2558.254,
          -2599.734,
          -2641.11,
          -2682.38,
          -2723.542,
          -2764.594,
          -2805.533,
          -2846.3590000000004,
          -2887.07,
          -2927.663,
          -2968.136,
          -3008.488,
          -3048.717,
          -3088.82,
          -3128.797,
          -3168.6440000000002,
          -3208.36,
          -3247.9429999999998,
          -3287.39,
          -3326.7,
          -3365.8709999999996,
          -3404.901,
          -3443.7870000000003,
          -3482.528,
          -3521.12,
          -3559.563,
          -3597.8540000000003,
          -3635.99,
          -3673.97,
          -3711.792,
          -3749.452,
          -3786.949,
          -3824.281,
          -3861.445,
          -3898.438,
          -3935.26,
          -3971.906,
          -4008.3740000000003,
          -4044.663,
          -4080.77,
          -4116.692,
          -4152.4259999999995,
          -4187.971,
          -4223.323,
          -4258.479,
          -4293.438,
          -4328.197,
          -4362.752,
          -4397.101,
          -4431.241,
          -4465.17,
          -4498.884,
          -4532.380999999999,
          -4565.657,
          -4598.71,
          -4631.536,
          -4664.133,
          -4696.498,
          -4728.627,
          -4760.517,
          -4792.164000000001,
          -4823.566,
          -4854.719,
          -4885.62,
          -4916.266,
          -4946.652,
          -4976.775,
          -5006.6320000000005,
          -5036.219,
          -5065.532999999999,
          -5094.568,
          -5123.323,
          -5151.792,
          -5179.971,
          -5207.858,
          -5235.447,
          -5262.734,
          -5289.715999999999,
          -5316.387,
          -5342.744000000001,
          -5368.781,
          -5394.495,
          -5419.880999999999,
          -5444.934,
          -5469.649,
          -5494.021,
          -5518.045999999999,
          -5541.717,
          -5565.031,
          -5587.981,
          -5610.563,
          -5632.77,
          -5654.597,
          -5676.04,
          -5697.090999999999,
          -5717.744000000001,
          -5737.995,
          -5757.835999999999,
          -5777.26,
          -5796.263000000001,
          -5814.835999999999,
          -5832.974,
          -5850.67,
          -5867.915,
          -5884.704000000001,
          -5901.029,
          -5916.880999999999,
          -5932.255,
          -5947.141,
          -5961.531999999999,
          -5975.419,
          -5988.794,
          -6001.648,
          -6013.973000000001,
          -6025.759,
          -6036.9980000000005,
          -6047.679,
          -6057.7919999999995,
          -6067.329000000001,
          -6076.278,
          -6084.629,
          -6092.37,
          -6099.491999999999,
          -6105.984,
          -6111.831999999999,
          -6117.025,
          -6121.5509999999995,
          -6125.397,
          -6128.55,
          -6130.996999999999,
          -6132.723000000001,
          -6133.715,
          -6133.959,
          -6133.438,
          -6132.138000000001,
          -6130.044,
          -6127.137,
          -6123.401999999999,
          -6118.821,
          -6113.376,
          -6107.049,
          -6099.82,
          -6091.67,
          -6082.578,
          -6072.525,
          -6061.486999999999,
          -6049.441999999999,
          -6036.366999999999,
          -6022.2390000000005,
          -6007.031999999999,
          -5990.721,
          -5973.279,
          -5954.678000000001,
          -5934.89,
          -5913.8859999999995,
          -5891.634,
          -5868.104,
          -5843.263000000001,
          -5817.075,
          -5789.507,
          -5760.52,
          -5730.076,
          -5698.137,
          -5664.66,
          -5629.603,
          -5592.92,
          -5554.565,
          -5514.491999999999,
          -5472.648,
          -5428.982,
          -5383.438,
          -5335.960999999999,
          -5286.491,
          -5234.965999999999,
          -5181.322,
          -5125.4929999999995,
          -5067.407999999999,
          -5006.996,
          -4944.18,
          -4878.880999999999,
          -4811.018,
          -4740.505999999999,
          -4667.2570000000005,
          -4591.178,
          -4512.174,
          -4430.145,
          -4344.992,
          -4256.607,
          -4164.8820000000005,
          -4069.7059999999997,
          -3970.9640000000004,
          -3868.542,
          -3762.322,
          -3652.184,
          -3538.011,
          -3419.688,
          -3297.099,
          -3170.137,
          -3038.698,
          -2902.6929999999998,
          -2762.04,
          -2616.676,
          -2466.56,
          -2311.673,
          -2152.028,
          -1987.6770000000001,
          -1818.7089999999998,
          -1645.265,
          -1467.539,
          -1285.787,
          -1100.325,
          -911.54,
          -719.883,
          -525.876,
          -330.097,
          -133.179,
          64.203,
          261.347,
          457.539,
          652.073,
          844.26,
          1033.458,
          1219.0710000000001,
          1400.567,
          1577.484,
          1749.4389999999999,
          1916.119,
          2077.286,
          2232.771,
          2382.468,
          2526.326,
          2664.345,
          2796.5640000000003,
          2923.058,
          3043.929,
          3159.301,
          3269.315,
          3374.1240000000003,
          3473.889,
          3568.778,
          3658.9590000000003,
          3744.6009999999997,
          3825.8740000000003,
          3902.9429999999998,
          3975.9709999999995,
          4045.114,
          4110.528,
          4172.359,
          4230.749,
          4285.835999999999,
          4337.751,
          4386.62,
          4432.460999999999,
          4475.694,
          4516.123,
          4553.955,
          4589.29,
          4622.224,
          4652.846,
          4681.244000000001,
          4707.499,
          4731.69,
          4753.893,
          4774.18,
          4792.617,
          4809.271,
          4824.2029999999995,
          4837.473,
          4849.138,
          4859.251,
          4867.8640000000005,
          4875.027,
          4880.788,
          4885.192,
          4888.282,
          4890.099,
          4890.684,
          4890.075,
          4888.309,
          4885.419,
          4881.441,
          4876.407,
          4870.348,
          4863.293,
          4855.272,
          4846.312,
          4836.441,
          4825.683,
          4814.063,
          4801.606,
          4788.334,
          4774.269,
          4759.433,
          4743.846,
          4727.529,
          4710.5,
          4692.778,
          4674.38,
          4655.326,
          4635.63,
          4615.31,
          4594.380999999999,
          4572.859,
          4550.7570000000005,
          4528.090999999999,
          4504.874,
          4481.12,
          4456.842000000001,
          4432.052,
          4406.763,
          4380.986,
          4354.734,
          4328.017,
          4300.846,
          4273.232,
          4245.186,
          4216.717000000001,
          4187.834,
          4158.549,
          4128.869000000001,
          4098.804,
          4068.362,
          4037.552,
          4006.383,
          3974.862,
          3942.998,
          3910.797,
          3878.2690000000002,
          3845.4190000000003,
          3812.255,
          3778.785,
          3745.014,
          3710.95,
          3676.599,
          3641.967,
          3607.0609999999997,
          3571.886,
          3536.45,
          3500.756,
          3464.812,
          3428.623,
          3392.1929999999998,
          3355.5290000000005,
          3318.636,
          3281.518,
          3244.1809999999996,
          3206.6290000000004,
          3168.868,
          3130.902,
          3092.735,
          3054.373,
          3015.82,
          2977.08,
          2938.157,
          2899.055,
          2859.7790000000005,
          2820.3320000000003,
          2780.72,
          2740.9440000000004,
          2701.01,
          2660.92,
          2620.68,
          2580.291,
          2539.759,
          2499.0860000000002,
          2458.275,
          2417.331,
          2376.256,
          2335.054,
          2293.728,
          2252.282,
          2210.717,
          2169.038,
          2127.248,
          2085.348,
          2043.3429999999998,
          2001.236,
          1959.0279999999998,
          1916.724,
          1874.325,
          1831.8339999999998,
          1789.255,
          1746.589,
          1703.84,
          1661.01,
          1618.102,
          1575.118,
          1532.06,
          1488.932,
          1445.735,
          1402.4720000000002,
          1359.145,
          1315.757,
          1272.31,
          1228.807,
          1185.249,
          1141.639,
          1097.979,
          1054.271,
          1010.518,
          966.721,
          922.8839999999999,
          879.007,
          835.0930000000001,
          791.1439999999999,
          747.163,
          703.15,
          659.1089999999999,
          615.0409999999999,
          570.9490000000001,
          526.8330000000001,
          482.69699999999995,
          438.541,
          394.369,
          350.18199999999996,
          305.982,
          261.77,
          217.549,
          173.32,
          129.086,
          84.848,
          40.608000000000004,
          -3.633,
          -47.871,
          -92.10700000000001,
          -136.33700000000002,
          -180.56,
          -224.774,
          -268.978,
          -313.16900000000004,
          -357.347,
          -401.509,
          -445.653,
          -489.778,
          -533.882,
          -577.964,
          -622.021,
          -666.052,
          -710.055,
          -754.029,
          -797.971,
          -841.8810000000001,
          -885.757,
          -929.596,
          -973.3969999999999,
          -1017.159,
          -1060.879,
          -1104.557,
          -1148.19,
          -1191.777,
          -1235.315,
          -1278.805,
          -1322.243,
          -1365.628,
          -1408.9589999999998,
          -1452.233,
          -1495.45,
          -1538.6070000000002,
          -1581.7020000000002,
          -1624.735,
          -1667.704,
          -1710.606,
          -1753.44,
          -1796.204,
          -1838.8970000000002,
          -1881.517,
          -1924.0629999999999,
          -1966.5320000000002,
          -2008.922,
          -2051.2329999999997,
          -2093.4629999999997,
          -2135.609,
          -2177.6710000000003,
          -2219.645,
          -2261.531,
          -2303.327,
          -2345.031,
          -2386.641,
          -2428.156,
          -2469.574,
          -2510.8920000000003,
          -2552.11,
          -2593.225,
          -2634.235,
          -2675.139,
          -2715.9359999999997,
          -2756.6220000000003,
          -2797.196,
          -2837.656,
          -2878.0009999999997,
          -2918.2290000000003,
          -2958.337,
          -2998.324,
          -3038.187,
          -3077.926,
          -3117.5370000000003,
          -3157.0190000000002,
          -3196.37,
          -3235.5879999999997,
          -3274.671,
          -3313.616,
          -3352.422,
          -3391.087,
          -3429.6090000000004,
          -3467.985,
          -3506.2129999999997,
          -3544.2909999999997,
          -3582.217,
          -3619.99,
          -3657.605,
          -3695.062,
          -3732.3590000000004,
          -3769.492,
          -3806.4590000000003,
          -3843.259,
          -3879.889,
          -3916.3459999999995,
          -3952.6279999999997,
          -3988.7329999999997,
          -4024.658,
          -4060.4,
          -4095.958,
          -4131.329000000001,
          -4166.509,
          -4201.497,
          -4236.289000000001,
          -4270.884,
          -4305.278,
          -4339.469,
          -4373.454000000001,
          -4407.23,
          -4440.794,
          -4474.143,
          -4507.275,
          -4540.186,
          -4572.874,
          -4605.335,
          -4637.567,
          -4669.565,
          -4701.3279999999995,
          -4732.852,
          -4764.133,
          -4795.168,
          -4825.954000000001,
          -4856.488,
          -4886.766,
          -4916.784000000001,
          -4946.539000000001,
          -4976.027,
          -5005.245,
          -5034.188,
          -5062.854,
          -5091.237,
          -5119.335,
          -5147.143,
          -5174.657,
          -5201.872,
          -5228.786,
          -5255.393,
          -5281.689,
          -5307.67,
          -5333.33,
          -5358.6669999999995,
          -5383.674,
          -5408.347,
          -5432.681,
          -5456.672,
          -5480.313,
          -5503.601,
          -5526.529,
          -5549.093000000001,
          -5571.286999999999,
          -5593.106,
          -5614.543000000001,
          -5635.594,
          -5656.251,
          -5676.51,
          -5696.3640000000005,
          -5715.806,
          -5734.83,
          -5753.431,
          -5771.6,
          -5789.331,
          -5806.618,
          -5823.453,
          -5839.829000000001,
          -5855.738,
          -5871.172,
          -5886.125,
          -5900.588000000001,
          -5914.552,
          -5928.009,
          -5940.951999999999,
          -5953.37,
          -5965.255999999999,
          -5976.599,
          -5987.391,
          -5997.621999999999,
          -6007.281,
          -6016.359,
          -6024.845,
          -6032.728,
          -6039.9980000000005,
          -6046.644,
          -6052.653,
          -6058.014,
          -6062.714,
          -6066.741,
          -6070.0830000000005,
          -6072.725,
          -6074.655,
          -6075.857,
          -6076.319,
          -6076.024,
          -6074.956999999999,
          -6073.104,
          -6070.446999999999,
          -6066.969,
          -6062.654,
          -6057.484,
          -6051.44,
          -6044.504,
          -6036.655,
          -6027.874,
          -6018.14,
          -6007.432,
          -5995.727,
          -5983.001,
          -5969.233,
          -5954.396,
          -5938.465,
          -5921.415,
          -5903.217,
          -5883.843000000001,
          -5863.265,
          -5841.451999999999,
          -5818.371,
          -5793.991,
          -5768.279,
          -5741.198,
          -5712.7119999999995,
          -5682.784000000001,
          -5651.374,
          -5618.44,
          -5583.941,
          -5547.831999999999,
          -5510.066,
          -5470.597,
          -5429.374,
          -5386.346,
          -5341.456999999999,
          -5294.653,
          -5245.8730000000005,
          -5195.058,
          -5142.142,
          -5087.061,
          -5029.744000000001,
          -4970.121,
          -4908.116,
          -4843.65,
          -4776.643,
          -4707.008,
          -4634.661,
          -4559.509,
          -4481.457,
          -4400.407999999999,
          -4316.258,
          -4228.905,
          -4138.24,
          -4044.153,
          -3946.53,
          -3845.256,
          -3740.2140000000004,
          -3631.2859999999996,
          -3518.355,
          -3401.304,
          -3280.0209999999997,
          -3154.397,
          -3024.328,
          -2889.724,
          -2750.5040000000004,
          -2606.603,
          -2457.979,
          -2304.611,
          -2146.511,
          -1983.726,
          -1816.345,
          -1644.5020000000002,
          -1468.388,
          -1288.253,
          -1104.4080000000001,
          -917.2330000000001,
          -727.174,
          -534.742,
          -340.51199999999994,
          -145.108,
          50.802,
          246.52200000000002,
          441.344,
          634.564,
          825.502,
          1013.5139999999999,
          1198.008,
          1378.451,
          1554.384,
          1725.42,
          1891.247,
          2051.6220000000003,
          2206.377,
          2355.402,
          2498.643,
          2636.097,
          2767.801,
          2893.828,
          3014.276,
          3129.2659999999996,
          3238.938,
          3343.4429999999998,
          3442.9390000000003,
          3537.591,
          3627.567,
          3713.034,
          3794.159,
          3871.107,
          3944.039,
          4013.1090000000004,
          4078.4709999999995,
          4140.272,
          4198.653,
          4253.749,
          4305.691,
          4354.604,
          4400.606,
          4443.813,
          4484.333,
          4522.269,
          4557.722,
          4590.786,
          4621.55,
          4650.101,
          4676.522,
          4700.888,
          4723.276,
          4743.758,
          4762.399,
          4779.266,
          4794.419,
          4807.919,
          4819.821,
          4830.179,
          4839.044,
          4846.465,
          4852.491,
          4857.166,
          4860.532999999999,
          4862.634,
          4863.508,
          4863.192,
          4861.725,
          4859.139,
          4855.47,
          4850.749,
          4845.008,
          4838.275,
          4830.579000000001,
          4821.9490000000005,
          4812.412,
          4801.991,
          4790.712,
          4778.599,
          4765.674,
          4751.959,
          4737.476,
          4722.246,
          4706.287,
          4689.619000000001,
          4672.2609999999995,
          4654.231,
          4635.545,
          4616.22,
          4596.274,
          4575.72,
          4554.575,
          4532.853,
          4510.568,
          4487.734,
          4464.3640000000005,
          4440.472,
          4416.07,
          4391.17,
          4365.785,
          4339.924,
          4313.601,
          4286.825,
          4259.607,
          4231.958,
          4203.887,
          4175.404,
          4146.519,
          4117.24,
          4087.577,
          4057.539,
          4027.133,
          3996.368,
          3965.2529999999997,
          3933.795,
          3902.0009999999997,
          3869.88,
          3837.438,
          3804.683,
          3771.6209999999996,
          3738.26,
          3704.605,
          3670.665,
          3636.4440000000004,
          3601.949,
          3567.185,
          3532.16,
          3496.8790000000004,
          3461.347,
          3425.5690000000004,
          3389.552,
          3353.301,
          3316.82,
          3280.115,
          3243.191,
          3206.052,
          3168.704,
          3131.151,
          3093.397,
          3055.448,
          3017.3070000000002,
          2978.9790000000003,
          2940.468,
          2901.7790000000005,
          2862.915,
          2823.88,
          2784.679,
          2745.315,
          2705.792,
          2666.113,
          2626.283,
          2586.305,
          2546.183,
          2505.919,
          2465.518,
          2424.982,
          2384.3160000000003,
          2343.522,
          2302.604,
          2261.564,
          2220.407,
          2179.134,
          2137.749,
          2096.255,
          2054.655,
          2012.951,
          1971.1470000000002,
          1929.245,
          1887.249,
          1845.16,
          1802.9820000000002,
          1760.717,
          1718.368,
          1675.9370000000001,
          1633.4270000000001,
          1590.8410000000001,
          1548.18,
          1505.4479999999999,
          1462.6470000000002,
          1419.779,
          1376.846,
          1333.852,
          1290.798,
          1247.6860000000001,
          1204.519,
          1161.299,
          1118.029,
          1074.7089999999998,
          1031.344,
          987.934,
          944.482,
          900.99,
          857.461,
          813.895,
          770.296,
          726.665,
          683.0039999999999,
          639.315,
          595.601,
          551.863,
          508.103,
          464.32300000000004,
          420.525,
          376.711,
          332.88300000000004,
          289.04200000000003,
          245.19099999999997,
          201.332,
          157.465,
          113.594,
          69.72,
          25.844,
          -18.031,
          -61.903999999999996,
          -105.773,
          -149.636,
          -193.49200000000002,
          -237.338,
          -281.17400000000004,
          -324.996,
          -368.80400000000003,
          -412.595,
          -456.369,
          -500.12300000000005,
          -543.856,
          -587.565,
          -631.25,
          -674.908,
          -718.539,
          -762.1389999999999,
          -805.7080000000001,
          -849.2439999999999,
          -892.745,
          -936.209,
          -979.635,
          -1023.0219999999999,
          -1066.367,
          -1109.6689999999999,
          -1152.9260000000002,
          -1196.137,
          -1239.299,
          -1282.412,
          -1325.473,
          -1368.4820000000002,
          -1411.435,
          -1454.3329999999999,
          -1497.172,
          -1539.951,
          -1582.67,
          -1625.325,
          -1667.915,
          -1710.4389999999999,
          -1752.896,
          -1795.2820000000002,
          -1837.5970000000002,
          -1879.839,
          -1922.007,
          -1964.098,
          -2006.11,
          -2048.0429999999997,
          -2089.895,
          -2131.663,
          -2173.346,
          -2214.9429999999998,
          -2256.451,
          -2297.869,
          -2339.195,
          -2380.427,
          -2421.564,
          -2462.604,
          -2503.545,
          -2544.385,
          -2585.1220000000003,
          -2625.755,
          -2666.282,
          -2706.7009999999996,
          -2747.009,
          -2787.2070000000003,
          -2827.29,
          -2867.258,
          -2907.1090000000004,
          -2946.84,
          -2986.4509999999996,
          -3025.938,
          -3065.3,
          -3104.535,
          -3143.6409999999996,
          -3182.616,
          -3221.458,
          -3260.165,
          -3298.735,
          -3337.1659999999997,
          -3375.455,
          -3413.6009999999997,
          -3451.6020000000003,
          -3489.455,
          -3527.159,
          -3564.71,
          -3602.1079999999997,
          -3639.349,
          -3676.4320000000002,
          -3713.3540000000003,
          -3750.113,
          -3786.7070000000003,
          -3823.133,
          -3859.389,
          -3895.472,
          -3931.381,
          -3967.112,
          -4002.664,
          -4038.033,
          -4073.218,
          -4108.215,
          -4143.022,
          -4177.637,
          -4212.056,
          -4246.278,
          -4280.299,
          -4314.117,
          -4347.729,
          -4381.1320000000005,
          -4414.323,
          -4447.299,
          -4480.058,
          -4512.596,
          -4544.911,
          -4576.999,
          -4608.857,
          -4640.482,
          -4671.871,
          -4703.021,
          -4733.928,
          -4764.589,
          -4795.001,
          -4825.16,
          -4855.063,
          -4884.706,
          -4914.085999999999,
          -4943.198,
          -4972.04,
          -5000.607,
          -5028.896,
          -5056.902,
          -5084.623,
          -5112.052,
          -5139.188,
          -5166.025,
          -5192.558,
          -5218.785,
          -5244.7,
          -5270.3,
          -5295.578,
          -5320.531,
          -5345.155,
          -5369.443,
          -5393.392,
          -5416.996,
          -5440.25,
          -5463.149,
          -5485.688,
          -5507.861999999999,
          -5529.664000000001,
          -5551.089,
          -5572.132,
          -5592.786999999999,
          -5613.047,
          -5632.906999999999,
          -5652.361,
          -5671.401,
          -5690.022,
          -5708.217,
          -5725.979,
          -5743.3009999999995,
          -5760.177,
          -5776.598000000001,
          -5792.558000000001,
          -5808.049,
          -5823.064,
          -5837.593000000001,
          -5851.63,
          -5865.166,
          -5878.193,
          -5890.701,
          -5902.682,
          -5914.1269999999995,
          -5925.026,
          -5935.37,
          -5945.15,
          -5954.354,
          -5962.973000000001,
          -5970.995,
          -5978.41,
          -5985.2080000000005,
          -5991.376,
          -5996.903,
          -6001.776999999999,
          -6005.985,
          -6009.514,
          -6012.351,
          -6014.483,
          -6015.896,
          -6016.575,
          -6016.505999999999,
          -6015.674,
          -6014.062,
          -6011.656,
          -6008.438,
          -6004.39,
          -5999.496999999999,
          -5993.7390000000005,
          -5987.097,
          -5979.552,
          -5971.085,
          -5961.675,
          -5951.3,
          -5939.938,
          -5927.566999999999,
          -5914.161999999999,
          -5899.701,
          -5884.156,
          -5867.503000000001,
          -5849.714,
          -5830.762,
          -5810.616,
          -5789.2480000000005,
          -5766.625,
          -5742.715999999999,
          -5717.486999999999,
          -5690.904,
          -5662.929,
          -5633.526,
          -5602.655,
          -5570.276,
          -5536.347,
          -5500.823,
          -5463.659000000001,
          -5424.807,
          -5384.219,
          -5341.843000000001,
          -5297.624,
          -5251.508000000001,
          -5203.435,
          -5153.346,
          -5101.1759999999995,
          -5046.861,
          -4990.332,
          -4931.518,
          -4870.343,
          -4806.731,
          -4740.602,
          -4671.869000000001,
          -4600.448,
          -4526.248,
          -4449.174,
          -4369.129,
          -4286.012,
          -4199.719,
          -4110.145,
          -4017.177,
          -3920.705,
          -3820.611,
          -3716.783,
          -3609.1009999999997,
          -3497.448,
          -3381.7090000000003,
          -3261.7709999999997,
          -3137.526,
          -3008.869,
          -2875.711,
          -2737.97,
          -2595.58,
          -2448.4970000000003,
          -2296.7,
          -2140.197,
          -1979.033,
          -1813.293,
          -1643.109,
          -1468.6660000000002,
          -1290.2089999999998,
          -1108.0439999999999,
          -922.544,
          -734.1469999999999,
          -543.3580000000001,
          -350.74300000000005,
          -156.921,
          37.448,
          231.675,
          425.05699999999996,
          616.896,
          806.5160000000001,
          993.2760000000001,
          1176.5839999999998,
          1355.912,
          1530.797,
          1700.854,
          1865.7679999999998,
          2025.295,
          2179.265,
          2327.564,
          2470.138,
          2606.979,
          2738.1220000000003,
          2863.637,
          2983.619,
          3098.188,
          3207.4809999999998,
          3311.645,
          3410.836,
          3505.22,
          3594.961,
          3680.222,
          3761.172,
          3837.973,
          3910.783,
          3979.756,
          4045.046,
          4106.7970000000005,
          4165.148,
          4220.235,
          4272.186,
          4321.127,
          4367.175,
          4410.443,
          4451.04,
          4489.068,
          4524.627,
          4557.81,
          4588.707,
          4617.403,
          4643.98,
          4668.514,
          4691.081,
          4711.751,
          4730.590999999999,
          4747.666,
          4763.037,
          4776.762,
          4788.897,
          4799.497,
          4808.612,
          4816.29,
          4822.58,
          4827.525,
          4831.169,
          4833.553,
          4834.715999999999,
          4834.696,
          4833.528,
          4831.249,
          4827.891,
          4823.485,
          4818.064,
          4811.657,
          4804.29,
          4795.994000000001,
          4786.794,
          4776.714,
          4765.781,
          4754.016,
          4741.444,
          4728.085,
          4713.960999999999,
          4699.092000000001,
          4683.499,
          4667.1990000000005,
          4650.212,
          4632.554,
          4614.244000000001,
          4595.298,
          4575.732,
          4555.562,
          4534.802,
          4513.467000000001,
          4491.572,
          4469.13,
          4446.153,
          4422.656,
          4398.651,
          4374.149,
          4349.164000000001,
          4323.705,
          4297.785,
          4271.414000000001,
          4244.602,
          4217.36,
          4189.697,
          4161.624,
          4133.149,
          4104.282999999999,
          4075.032,
          4045.408,
          4015.417,
          3985.0679999999998,
          3954.369,
          3923.328,
          3891.953,
          3860.25,
          3828.228,
          3795.893,
          3763.252,
          3730.312,
          3697.08,
          3663.562,
          3629.763,
          3595.692,
          3561.3520000000003,
          3526.7509999999997,
          3491.8940000000002,
          3456.7870000000003,
          3421.434,
          3385.842,
          3350.0159999999996,
          3313.961,
          3277.6820000000002,
          3241.183,
          3204.4709999999995,
          3167.548,
          3130.421,
          3093.094,
          3055.571,
          3017.8559999999998,
          2979.954,
          2941.869,
          2903.605,
          2865.167,
          2826.558,
          2787.782,
          2748.843,
          2709.745,
          2670.491,
          2631.086,
          2591.532,
          2551.833,
          2511.994,
          2472.016,
          2431.903,
          2391.66,
          2351.288,
          2310.792,
          2270.174,
          2229.437,
          2188.585,
          2147.62,
          2106.545,
          2065.364,
          2024.079,
          1982.693,
          1941.2089999999998,
          1899.63,
          1857.9579999999999,
          1816.195,
          1774.345,
          1732.411,
          1690.394,
          1648.297,
          1606.1229999999998,
          1563.875,
          1521.5539999999999,
          1479.1629999999998,
          1436.705,
          1394.181,
          1351.595,
          1308.948,
          1266.243,
          1223.482,
          1180.6680000000001,
          1137.8010000000002,
          1094.886,
          1051.923,
          1008.915,
          965.8639999999999,
          922.7719999999999,
          879.6410000000001,
          836.4739999999999,
          793.2719999999999,
          750.0369999999999,
          706.7710000000001,
          663.477,
          620.156,
          576.811,
          533.442,
          490.05300000000005,
          446.644,
          403.219,
          359.778,
          316.323,
          272.858,
          229.382,
          185.899,
          142.409,
          98.916,
          55.419,
          11.923,
          -31.573,
          -75.066,
          -118.554,
          -162.036,
          -205.50900000000001,
          -248.97299999999998,
          -292.426,
          -335.865,
          -379.289,
          -422.69599999999997,
          -466.085,
          -509.454,
          -552.8009999999999,
          -596.124,
          -639.423,
          -682.695,
          -725.938,
          -769.1510000000001,
          -812.332,
          -855.48,
          -898.5930000000001,
          -941.669,
          -984.707,
          -1027.704,
          -1070.66,
          -1113.573,
          -1156.441,
          -1199.262,
          -1242.035,
          -1284.758,
          -1327.4289999999999,
          -1370.047,
          -1412.611,
          -1455.118,
          -1497.566,
          -1539.955,
          -1582.283,
          -1624.5479999999998,
          -1666.7479999999998,
          -1708.881,
          -1750.9470000000001,
          -1792.942,
          -1834.8670000000002,
          -1876.7179999999998,
          -1918.495,
          -1960.195,
          -2001.817,
          -2043.36,
          -2084.821,
          -2126.198,
          -2167.491,
          -2208.697,
          -2249.815,
          -2290.843,
          -2331.779,
          -2372.6220000000003,
          -2413.369,
          -2454.019,
          -2494.57,
          -2535.021,
          -2575.369,
          -2615.613,
          -2655.75,
          -2695.78,
          -2735.7009999999996,
          -2775.509,
          -2815.204,
          -2854.784,
          -2894.2470000000003,
          -2933.591,
          -2972.813,
          -3011.913,
          -3050.888,
          -3089.735,
          -3128.455,
          -3167.0429999999997,
          -3205.498,
          -3243.8190000000004,
          -3282.0029999999997,
          -3320.047,
          -3357.9509999999996,
          -3395.712,
          -3433.327,
          -3470.795,
          -3508.114,
          -3545.281,
          -3582.2940000000003,
          -3619.151,
          -3655.85,
          -3692.388,
          -3728.763,
          -3764.973,
          -3801.0159999999996,
          -3836.889,
          -3872.5890000000004,
          -3908.115,
          -3943.4629999999997,
          -3978.633,
          -4013.619,
          -4048.422,
          -4083.0370000000003,
          -4117.462,
          -4151.695,
          -4185.733,
          -4219.573,
          -4253.213,
          -4286.65,
          -4319.88,
          -4352.902,
          -4385.712,
          -4418.307,
          -4450.685,
          -4482.842000000001,
          -4514.776,
          -4546.483,
          -4577.96,
          -4609.205,
          -4640.213,
          -4670.982,
          -4701.508,
          -4731.788,
          -4761.819,
          -4791.597,
          -4821.1179999999995,
          -4850.379,
          -4879.377,
          -4908.108,
          -4936.567,
          -4964.752,
          -4992.657999999999,
          -5020.281,
          -5047.6179999999995,
          -5074.664000000001,
          -5101.415,
          -5127.8679999999995,
          -5154.017,
          -5179.858,
          -5205.387,
          -5230.6,
          -5255.491,
          -5280.057,
          -5304.2919999999995,
          -5328.191,
          -5351.749,
          -5374.963000000001,
          -5397.825,
          -5420.331999999999,
          -5442.478,
          -5464.257,
          -5485.664000000001,
          -5506.693,
          -5527.338000000001,
          -5547.594,
          -5567.454000000001,
          -5586.911999999999,
          -5605.963000000001,
          -5624.599,
          -5642.813,
          -5660.601,
          -5677.953,
          -5694.8640000000005,
          -5711.326,
          -5727.3330000000005,
          -5742.875,
          -5757.946999999999,
          -5772.539000000001,
          -5786.645,
          -5800.255,
          -5813.361999999999,
          -5825.956,
          -5838.03,
          -5849.573,
          -5860.576999999999,
          -5871.031999999999,
          -5880.928000000001,
          -5890.255999999999,
          -5899.005,
          -5907.165,
          -5914.724,
          -5921.673000000001,
          -5927.999,
          -5933.691,
          -5938.736999999999,
          -5943.124,
          -5946.840999999999,
          -5949.8730000000005,
          -5952.206999999999,
          -5953.831,
          -5954.729,
          -5954.887,
          -5954.289000000001,
          -5952.922,
          -5950.767,
          -5947.81,
          -5944.033,
          -5939.419,
          -5933.9490000000005,
          -5927.606,
          -5920.369000000001,
          -5912.219,
          -5903.1359999999995,
          -5893.099,
          -5882.085999999999,
          -5870.0740000000005,
          -5857.04,
          -5842.96,
          -5827.808000000001,
          -5811.559,
          -5794.187,
          -5775.661999999999,
          -5755.9580000000005,
          -5735.043000000001,
          -5712.888000000001,
          -5689.4580000000005,
          -5664.723000000001,
          -5638.647,
          -5611.194,
          -5582.328,
          -5552.009,
          -5520.196999999999,
          -5486.851,
          -5451.9259999999995,
          -5415.378000000001,
          -5377.159000000001,
          -5337.221,
          -5295.513000000001,
          -5251.981,
          -5206.57,
          -5159.223,
          -5109.879,
          -5058.475,
          -5004.947,
          -4949.227,
          -4891.2429999999995,
          -4830.923,
          -4768.189,
          -4702.960999999999,
          -4635.156,
          -4564.688,
          -4491.467000000001,
          -4415.4,
          -4336.39,
          -4254.337,
          -4169.137,
          -4080.6859999999997,
          -3988.873,
          -3893.587,
          -3794.712,
          -3692.136,
          -3585.74,
          -3475.408,
          -3361.0229999999997,
          -3242.4759999999997,
          -3119.656,
          -2992.461,
          -2860.797,
          -2724.586,
          -2583.76,
          -2438.272,
          -2288.1020000000003,
          -2133.255,
          -1973.7720000000002,
          -1809.736,
          -1641.274,
          -1468.568,
          -1291.854,
          -1111.435,
          -927.677,
          -741.0110000000001,
          -551.935,
          -361.006,
          -168.835,
          23.924,
          216.588,
          408.463,
          598.855,
          787.091,
          972.534,
          1154.596,
          1332.747,
          1506.527,
          1675.5479999999998,
          1839.495,
          1998.1229999999998,
          2151.258,
          2298.785,
          2440.647,
          2576.8320000000003,
          2707.3740000000003,
          2832.3379999999997,
          2951.8179999999998,
          3065.9309999999996,
          3174.8109999999997,
          3278.603,
          3377.462,
          3471.5490000000004,
          3561.027,
          3646.059,
          3726.8109999999997,
          3803.441,
          3876.1090000000004,
          3944.967,
          4010.165,
          4071.848,
          4130.153,
          4185.215999999999,
          4237.162,
          4286.1179999999995,
          4332.415,
          4375.517,
          4416.18,
          4454.29,
          4489.946,
          4523.241,
          4554.262,
          4583.096,
          4609.823,
          4634.52,
          4657.26,
          4678.1140000000005,
          4697.149,
          4714.429,
          4730.014,
          4743.962,
          4756.33,
          4767.17,
          4776.534000000001,
          4784.468,
          4791.022,
          4796.238,
          4800.16,
          4802.8279999999995,
          4804.282,
          4804.558,
          4803.694,
          4801.723,
          4798.678,
          4794.592000000001,
          4789.495,
          4783.416,
          4776.384,
          4768.425,
          4759.568,
          4749.835,
          4739.252,
          4727.842000000001,
          4715.628,
          4702.630999999999,
          4688.872,
          4674.372,
          4659.15,
          4643.225,
          4626.616,
          4609.34,
          4591.413,
          4572.853,
          4553.6759999999995,
          4533.897,
          4513.531,
          4492.592000000001,
          4471.095,
          4449.053,
          4426.479,
          4403.3859999999995,
          4379.787,
          4355.694,
          4331.1179999999995,
          4306.071,
          4280.564,
          4254.607,
          4228.212,
          4201.387,
          4174.144,
          4146.491,
          4118.438,
          4089.994,
          4061.1679999999997,
          4031.968,
          4002.403,
          3972.4809999999998,
          3942.211,
          3911.599,
          3880.653,
          3849.381,
          3817.79,
          3785.888,
          3753.68,
          3721.173,
          3688.375,
          3655.292,
          3621.929,
          3588.2929999999997,
          3554.39,
          3520.225,
          3485.805,
          3451.135,
          3416.2209999999995,
          3381.067,
          3345.679,
          3310.062,
          3274.222,
          3238.163,
          3201.889,
          3165.407,
          3128.719,
          3091.8309999999997,
          3054.748,
          3017.473,
          2980.011,
          2942.365,
          2904.5409999999997,
          2866.542,
          2828.373,
          2790.0359999999996,
          2751.5359999999996,
          2712.877,
          2674.062,
          2635.095,
          2595.98,
          2556.72,
          2517.3179999999998,
          2477.778,
          2438.103,
          2398.2960000000003,
          2358.361,
          2318.301,
          2278.119,
          2237.8179999999998,
          2197.4,
          2156.87,
          2116.23,
          2075.4829999999997,
          2034.631,
          1993.6779999999999,
          1952.626,
          1911.4779999999998,
          1870.237,
          1828.905,
          1787.486,
          1745.98,
          1704.392,
          1662.724,
          1620.9779999999998,
          1579.156,
          1537.261,
          1495.296,
          1453.2620000000002,
          1411.1629999999998,
          1369,
          1326.776,
          1284.493,
          1242.153,
          1199.758,
          1157.3110000000001,
          1114.8139999999999,
          1072.269,
          1029.678,
          987.044,
          944.367,
          901.65,
          858.8960000000001,
          816.107,
          773.283,
          730.428,
          687.544,
          644.631,
          601.693,
          558.731,
          515.748,
          472.744,
          429.722,
          386.68300000000005,
          343.63,
          300.565,
          257.48900000000003,
          214.40400000000002,
          171.31099999999998,
          128.213,
          85.11200000000001,
          42.00899999999999,
          -1.094,
          -44.196000000000005,
          -87.294,
          -130.387,
          -173.47299999999998,
          -216.55,
          -259.617,
          -302.672,
          -345.713,
          -388.73900000000003,
          -431.74800000000005,
          -474.73800000000006,
          -517.707,
          -560.655,
          -603.578,
          -646.476,
          -689.3480000000001,
          -732.19,
          -775.002,
          -817.7819999999999,
          -860.528,
          -903.2389999999999,
          -945.913,
          -988.548,
          -1031.143,
          -1073.697,
          -1116.2069999999999,
          -1158.671,
          -1201.089,
          -1243.4589999999998,
          -1285.779,
          -1328.047,
          -1370.2620000000002,
          -1412.421,
          -1454.525,
          -1496.57,
          -1538.556,
          -1580.48,
          -1622.3410000000001,
          -1664.1370000000002,
          -1705.8670000000002,
          -1747.529,
          -1789.121,
          -1830.642,
          -1872.09,
          -1913.464,
          -1954.761,
          -1995.98,
          -2037.119,
          -2078.177,
          -2119.152,
          -2160.042,
          -2200.846,
          -2241.562,
          -2282.187,
          -2322.721,
          -2363.1620000000003,
          -2403.507,
          -2443.756,
          -2483.905,
          -2523.955,
          -2563.902,
          -2603.745,
          -2643.482,
          -2683.112,
          -2722.632,
          -2762.04,
          -2801.336,
          -2840.5159999999996,
          -2879.58,
          -2918.5240000000003,
          -2957.348,
          -2996.0490000000004,
          -3034.6259999999997,
          -3073.0759999999996,
          -3111.397,
          -3149.5879999999997,
          -3187.6459999999997,
          -3225.57,
          -3263.357,
          -3301.006,
          -3338.513,
          -3375.8779999999997,
          -3413.098,
          -3450.171,
          -3487.095,
          -3523.867,
          -3560.486,
          -3596.949,
          -3633.2540000000004,
          -3669.3979999999997,
          -3705.38,
          -3741.197,
          -3776.847,
          -3812.327,
          -3847.635,
          -3882.7690000000002,
          -3917.7259999999997,
          -3952.5029999999997,
          -3987.099,
          -4021.51,
          -4055.7340000000004,
          -4089.7690000000002,
          -4123.612,
          -4157.259,
          -4190.71,
          -4223.96,
          -4257.0070000000005,
          -4289.848,
          -4322.48,
          -4354.901,
          -4387.108,
          -4419.097,
          -4450.866,
          -4482.411,
          -4513.73,
          -4544.819,
          -4575.675,
          -4606.295,
          -4636.675,
          -4666.813,
          -4696.706,
          -4726.348,
          -4755.738,
          -4784.872,
          -4813.745,
          -4842.355,
          -4870.697,
          -4898.768,
          -4926.565,
          -4954.082,
          -4981.317,
          -5008.264,
          -5034.920999999999,
          -5061.282999999999,
          -5087.345,
          -5113.104,
          -5138.555,
          -5163.693,
          -5188.515,
          -5213.014,
          -5237.188,
          -5261.03,
          -5284.536,
          -5307.701,
          -5330.519,
          -5352.986999999999,
          -5375.098000000001,
          -5396.846,
          -5418.228,
          -5439.236,
          -5459.865,
          -5480.109,
          -5499.963000000001,
          -5519.42,
          -5538.474,
          -5557.119000000001,
          -5575.348000000001,
          -5593.155,
          -5610.531999999999,
          -5627.473000000001,
          -5643.971,
          -5660.018,
          -5675.608,
          -5690.732,
          -5705.382,
          -5719.552,
          -5733.232,
          -5746.415,
          -5759.092,
          -5771.254,
          -5782.892,
          -5793.996999999999,
          -5804.559,
          -5814.57,
          -5824.018,
          -5832.895,
          -5841.19,
          -5848.892,
          -5855.9890000000005,
          -5862.472,
          -5868.326999999999,
          -5873.544,
          -5878.11,
          -5882.013000000001,
          -5885.24,
          -5887.776999999999,
          -5889.611,
          -5890.727,
          -5891.111999999999,
          -5890.751,
          -5889.628000000001,
          -5887.727,
          -5885.033,
          -5881.528,
          -5877.195,
          -5872.016,
          -5865.974,
          -5859.048000000001,
          -5851.219,
          -5842.468000000001,
          -5832.773,
          -5822.111999999999,
          -5810.464,
          -5797.805,
          -5784.111,
          -5769.358,
          -5753.52,
          -5736.57,
          -5718.481,
          -5699.225,
          -5678.771,
          -5657.090999999999,
          -5634.151,
          -5609.918000000001,
          -5584.359,
          -5557.439,
          -5529.119000000001,
          -5499.363,
          -5468.129,
          -5435.3769999999995,
          -5401.064,
          -5365.145,
          -5327.573,
          -5288.299,
          -5247.274,
          -5204.444,
          -5159.755,
          -5113.15,
          -5064.568,
          -5013.948,
          -4961.226,
          -4906.334,
          -4849.202,
          -4789.7570000000005,
          -4727.923,
          -4663.62,
          -4596.766,
          -4527.276,
          -4455.059,
          -4380.024,
          -4302.076,
          -4221.115,
          -4137.039000000001,
          -4049.742,
          -3959.114,
          -3865.047,
          -3767.426,
          -3666.137,
          -3561.063,
          -3452.0890000000004,
          -3339.098,
          -3221.9809999999998,
          -3100.6290000000004,
          -2974.938,
          -2844.816,
          -2710.1809999999996,
          -2570.967,
          -2427.126,
          -2278.634,
          -2125.494,
          -1967.7479999999998,
          -1805.4720000000002,
          -1638.7910000000002,
          -1467.88,
          -1292.973,
          -1114.364,
          -932.413,
          -747.544,
          -560.247,
          -371.07300000000004,
          -180.623,
          10.457,
          201.49,
          391.788,
          580.663,
          767.447,
          951.505,
          1132.253,
          1309.162,
          1481.7720000000002,
          1649.6960000000001,
          1812.616,
          1970.287,
          2122.53,
          2269.231,
          2410.328,
          2545.808,
          2675.699,
          2800.067,
          2919.002,
          3032.617,
          3141.045,
          3244.428,
          3342.9179999999997,
          3436.6740000000004,
          3525.857,
          3610.63,
          3691.153,
          3767.587,
          3840.086,
          3908.803,
          3973.887,
          4035.48,
          4093.72,
          4148.738,
          4200.662,
          4249.615,
          4295.712,
          4339.065,
          4379.781,
          4417.960999999999,
          4453.702,
          4487.096,
          4518.231,
          4547.193,
          4574.062,
          4598.912,
          4621.819,
          4642.851,
          4662.0740000000005,
          4679.553,
          4695.347,
          4709.514,
          4722.11,
          4733.187,
          4742.795999999999,
          4750.986,
          4757.8009999999995,
          4763.288,
          4767.487,
          4770.439,
          4772.183,
          4772.7570000000005,
          4772.196,
          4770.535,
          4767.806,
          4764.041,
          4759.27,
          4753.523,
          4746.8279999999995,
          4739.212,
          4730.7,
          4721.318,
          4711.089,
          4700.038,
          4688.187,
          4675.557,
          4662.169,
          4648.043,
          4633.1990000000005,
          4617.656,
          4601.431,
          4584.542,
          4567.005999999999,
          4548.84,
          4530.059,
          4510.678,
          4490.713,
          4470.179,
          4449.088,
          4427.455,
          4405.292,
          4382.613,
          4359.429,
          4335.753,
          4311.596,
          4286.97,
          4261.8859999999995,
          4236.354,
          4210.384,
          4183.987,
          4157.173,
          4129.95,
          4102.329000000001,
          4074.3190000000004,
          4045.927,
          4017.163,
          3988.0359999999996,
          3958.552,
          3928.72,
          3898.548,
          3868.0440000000003,
          3837.2140000000004,
          3806.066,
          3774.607,
          3742.844,
          3710.783,
          3678.4309999999996,
          3645.7940000000003,
          3612.8790000000004,
          3579.691,
          3546.237,
          3512.5209999999997,
          3478.551,
          3444.3309999999997,
          3409.867,
          3375.164,
          3340.228,
          3305.063,
          3269.675,
          3234.0679999999998,
          3198.2470000000003,
          3162.217,
          3125.982,
          3089.547,
          3052.917,
          3016.095,
          2979.086,
          2941.8940000000002,
          2904.5240000000003,
          2866.978,
          2829.262,
          2791.3790000000004,
          2753.3320000000003,
          2715.1259999999997,
          2676.764,
          2638.25,
          2599.587,
          2560.779,
          2521.83,
          2482.741,
          2443.518,
          2404.163,
          2364.679,
          2325.07,
          2285.3379999999997,
          2245.487,
          2205.519,
          2165.439,
          2125.2470000000003,
          2084.948,
          2044.545,
          2004.039,
          1963.434,
          1922.733,
          1881.9379999999999,
          1841.0520000000001,
          1800.0770000000002,
          1759.016,
          1717.871,
          1676.646,
          1635.342,
          1593.9620000000002,
          1552.509,
          1510.984,
          1469.39,
          1427.73,
          1386.006,
          1344.219,
          1302.373,
          1260.469,
          1218.51,
          1176.497,
          1134.434,
          1092.322,
          1050.163,
          1007.959,
          965.7130000000001,
          923.426,
          881.1,
          838.738,
          796.342,
          753.913,
          711.453,
          668.965,
          626.4490000000001,
          583.909,
          541.347,
          498.76300000000003,
          456.159,
          413.539,
          370.903,
          328.25300000000004,
          285.592,
          242.92,
          200.24,
          157.554,
          114.86200000000001,
          72.168,
          29.473000000000003,
          -13.222000000000001,
          -55.915,
          -98.603,
          -141.286,
          -183.96200000000002,
          -226.628,
          -269.284,
          -311.927,
          -354.556,
          -397.16900000000004,
          -439.765,
          -482.342,
          -524.898,
          -567.431,
          -609.941,
          -652.424,
          -694.8810000000001,
          -737.308,
          -779.705,
          -822.069,
          -864.4,
          -906.695,
          -948.953,
          -991.172,
          -1033.351,
          -1075.488,
          -1117.5810000000001,
          -1159.63,
          -1201.631,
          -1243.5839999999998,
          -1285.487,
          -1327.338,
          -1369.136,
          -1410.879,
          -1452.566,
          -1494.194,
          -1535.763,
          -1577.27,
          -1618.715,
          -1660.094,
          -1701.408,
          -1742.6529999999998,
          -1783.829,
          -1824.934,
          -1865.9660000000001,
          -1906.9229999999998,
          -1947.8039999999999,
          -1988.608,
          -2029.332,
          -2069.974,
          -2110.534,
          -2151.009,
          -2191.3979999999997,
          -2231.699,
          -2271.91,
          -2312.029,
          -2352.056,
          -2391.987,
          -2431.822,
          -2471.5589999999997,
          -2511.195,
          -2550.729,
          -2590.16,
          -2629.485,
          -2668.702,
          -2707.8109999999997,
          -2746.808,
          -2785.692,
          -2824.462,
          -2863.115,
          -2901.6490000000003,
          -2940.063,
          -2978.355,
          -3016.522,
          -3054.563,
          -3092.4759999999997,
          -3130.258,
          -3167.909,
          -3205.425,
          -3242.805,
          -3280.046,
          -3317.1479999999997,
          -3354.1059999999998,
          -3390.92,
          -3427.5879999999997,
          -3464.1059999999998,
          -3500.474,
          -3536.688,
          -3572.7470000000003,
          -3608.6479999999997,
          -3644.389,
          -3679.968,
          -3715.382,
          -3750.63,
          -3785.708,
          -3820.614,
          -3855.347,
          -3889.903,
          -3924.28,
          -3958.475,
          -3992.486,
          -4026.3109999999997,
          -4059.946,
          -4093.39,
          -4126.639,
          -4159.691,
          -4192.543,
          -4225.192,
          -4257.6359999999995,
          -4289.871,
          -4321.895,
          -4353.705,
          -4385.298,
          -4416.67,
          -4447.819,
          -4478.742,
          -4509.436,
          -4539.896,
          -4570.121,
          -4600.107,
          -4629.85,
          -4659.348,
          -4688.596,
          -4717.590999999999,
          -4746.33,
          -4774.809,
          -4803.025,
          -4830.973,
          -4858.649,
          -4886.0509999999995,
          -4913.174,
          -4940.015,
          -4966.568,
          -4992.83,
          -5018.7970000000005,
          -5044.464,
          -5069.8279999999995,
          -5094.884,
          -5119.626,
          -5144.052,
          -5168.155,
          -5191.931,
          -5215.376,
          -5238.485,
          -5261.2519999999995,
          -5283.672,
          -5305.74,
          -5327.451,
          -5348.799,
          -5369.779,
          -5390.385,
          -5410.611999999999,
          -5430.453,
          -5449.901999999999,
          -5468.953,
          -5487.601,
          -5505.8369999999995,
          -5523.656999999999,
          -5541.053000000001,
          -5558.019,
          -5574.545999999999,
          -5590.63,
          -5606.2609999999995,
          -5621.432,
          -5636.1359999999995,
          -5650.365,
          -5664.111,
          -5677.365,
          -5690.12,
          -5702.366,
          -5714.095,
          -5725.298000000001,
          -5735.965,
          -5746.085999999999,
          -5755.653,
          -5764.655,
          -5773.081,
          -5780.922,
          -5788.166,
          -5794.803000000001,
          -5800.82,
          -5806.206999999999,
          -5810.95,
          -5815.0380000000005,
          -5818.4580000000005,
          -5821.196999999999,
          -5823.241,
          -5824.576,
          -5825.189,
          -5825.064,
          -5824.186,
          -5822.54,
          -5820.109,
          -5816.8769999999995,
          -5812.826999999999,
          -5807.941999999999,
          -5802.201999999999,
          -5795.59,
          -5788.085999999999,
          -5779.669,
          -5770.319,
          -5760.015,
          -5748.735,
          -5736.456,
          -5723.154,
          -5708.804,
          -5693.382,
          -5676.861,
          -5659.214,
          -5640.4130000000005,
          -5620.429,
          -5599.23,
          -5576.786999999999,
          -5553.066,
          -5528.034000000001,
          -5501.654,
          -5473.892,
          -5444.709,
          -5414.064,
          -5381.919,
          -5348.229,
          -5312.951,
          -5276.039000000001,
          -5237.444,
          -5197.116,
          -5155.003,
          -5111.0509999999995,
          -5065.204000000001,
          -5017.402,
          -4967.584,
          -4915.685,
          -4861.64,
          -4805.38,
          -4746.83,
          -4685.917,
          -4622.561,
          -4556.681,
          -4488.192,
          -4417.005,
          -4343.03,
          -4266.170999999999,
          -4186.33,
          -4103.405,
          -4017.2909999999997,
          -3927.882,
          -3835.065,
          -3738.7309999999998,
          -3638.764,
          -3535.048,
          -3427.47,
          -3315.9120000000003,
          -3200.2659999999996,
          -3080.423,
          -2956.28,
          -2827.744,
          -2694.7309999999998,
          -2557.178,
          -2415.033,
          -2268.271,
          -2116.893,
          -1960.9379999999999,
          -1800.48,
          -1635.638,
          -1466.5839999999998,
          -1293.5439999999999,
          -1116.809,
          -936.73,
          -753.725,
          -568.276,
          -380.92400000000004,
          -192.265,
          -2.9360000000000004,
          186.395,
          375.045,
          562.332,
          747.5939999999999,
          930.199,
          1109.5639999999999,
          1285.165,
          1456.54,
          1623.3029999999999,
          1785.134,
          1941.7879999999998,
          2093.083,
          2238.902,
          2379.181,
          2513.904,
          2643.099,
          2766.824,
          2885.1690000000003,
          2998.244,
          3106.179,
          3209.114,
          3307.2,
          3400.59,
          3489.446,
          3573.928,
          3654.1940000000004,
          3730.403,
          3802.7070000000003,
          3871.26,
          3936.2059999999997,
          3997.687,
          4055.84,
          4110.795,
          4162.678,
          4211.61,
          4257.708,
          4301.081,
          4341.835,
          4380.07,
          4415.884,
          4449.367,
          4480.606,
          4509.686,
          4536.686,
          4561.683,
          4584.748,
          4605.95,
          4625.356,
          4643.028,
          4659.026,
          4673.407999999999,
          4686.229,
          4697.54,
          4707.392,
          4715.833,
          4722.909000000001,
          4728.664000000001,
          4733.139,
          4736.375,
          4738.411,
          4739.282999999999,
          4739.026,
          4737.6759999999995,
          4735.264,
          4731.822,
          4727.380999999999,
          4721.968,
          4715.613,
          4708.342000000001,
          4700.18,
          4691.153,
          4681.284000000001,
          4670.596,
          4659.113,
          4646.855,
          4633.844,
          4620.098,
          4605.638,
          4590.482,
          4574.648,
          4558.153,
          4541.015,
          4523.249,
          4504.872,
          4485.898,
          4466.342000000001,
          4446.219,
          4425.543,
          4404.327,
          4382.584,
          4360.326,
          4337.567,
          4314.317,
          4290.589,
          4266.393,
          4241.741,
          4216.643,
          4191.109,
          4165.15,
          4138.775,
          4111.994000000001,
          4084.815,
          4057.2490000000003,
          4029.303,
          4000.986,
          3972.3059999999996,
          3943.272,
          3913.8909999999996,
          3884.171,
          3854.119,
          3823.743,
          3793.05,
          3762.046,
          3730.739,
          3699.136,
          3667.242,
          3635.065,
          3602.6090000000004,
          3569.882,
          3536.889,
          3503.635,
          3470.127,
          3436.37,
          3402.37,
          3368.131,
          3333.659,
          3298.9590000000003,
          3264.0359999999996,
          3228.8940000000002,
          3193.539,
          3157.975,
          3122.2059999999997,
          3086.238,
          3050.074,
          3013.719,
          2977.178,
          2940.453,
          2903.5490000000004,
          2866.4709999999995,
          2829.222,
          2791.8059999999996,
          2754.2270000000003,
          2716.488,
          2678.593,
          2640.546,
          2602.35,
          2564.009,
          2525.525,
          2486.903,
          2448.146,
          2409.257,
          2370.239,
          2331.095,
          2291.828,
          2252.442,
          2212.939,
          2173.322,
          2133.594,
          2093.758,
          2053.8179999999998,
          2013.774,
          1973.631,
          1933.391,
          1893.057,
          1852.631,
          1812.116,
          1771.515,
          1730.829,
          1690.0620000000001,
          1649.2160000000001,
          1608.293,
          1567.296,
          1526.227,
          1485.088,
          1443.882,
          1402.611,
          1361.2779999999998,
          1319.8829999999998,
          1278.431,
          1236.923,
          1195.36,
          1153.746,
          1112.0819999999999,
          1070.37,
          1028.613,
          986.813,
          944.971,
          903.0889999999999,
          861.17,
          819.216,
          777.2280000000001,
          735.209,
          693.16,
          651.0830000000001,
          608.98,
          566.854,
          524.705,
          482.537,
          440.349,
          398.14599999999996,
          355.92699999999996,
          313.69599999999997,
          271.453,
          229.201,
          186.94099999999997,
          144.67600000000002,
          102.406,
          60.13399999999999,
          17.861,
          -24.41,
          -66.679,
          -108.944,
          -151.202,
          -193.453,
          -235.69400000000002,
          -277.923,
          -320.14,
          -362.343,
          -404.529,
          -446.69699999999995,
          -488.847,
          -530.975,
          -573.08,
          -615.161,
          -657.216,
          -699.243,
          -741.2410000000001,
          -783.209,
          -825.1439999999999,
          -867.045,
          -908.91,
          -950.7389999999999,
          -992.528,
          -1034.277,
          -1075.984,
          -1117.647,
          -1159.265,
          -1200.836,
          -1242.359,
          -1283.8319999999999,
          -1325.253,
          -1366.621,
          -1407.934,
          -1449.19,
          -1490.389,
          -1531.5279999999998,
          -1572.605,
          -1613.62,
          -1654.57,
          -1695.454,
          -1736.27,
          -1777.017,
          -1817.692,
          -1858.295,
          -1898.8239999999998,
          -1939.277,
          -1979.652,
          -2019.9470000000001,
          -2060.1620000000003,
          -2100.294,
          -2140.342,
          -2180.304,
          -2220.178,
          -2259.962,
          -2299.655,
          -2339.256,
          -2378.762,
          -2418.1710000000003,
          -2457.482,
          -2496.694,
          -2535.804,
          -2574.81,
          -2613.7110000000002,
          -2652.505,
          -2691.19,
          -2729.765,
          -2768.2270000000003,
          -2806.574,
          -2844.8059999999996,
          -2882.9190000000003,
          -2920.9120000000003,
          -2958.783,
          -2996.53,
          -3034.151,
          -3071.645,
          -3109.008,
          -3146.24,
          -3183.3379999999997,
          -3220.3,
          -3257.125,
          -3293.809,
          -3330.3509999999997,
          -3366.75,
          -3403.0009999999997,
          -3439.105,
          -3475.058,
          -3510.8579999999997,
          -3546.5029999999997,
          -3581.991,
          -3617.3190000000004,
          -3652.485,
          -3687.487,
          -3722.323,
          -3756.99,
          -3791.486,
          -3825.808,
          -3859.954,
          -3893.922,
          -3927.708,
          -3961.3109999999997,
          -3994.7270000000003,
          -4027.955,
          -4060.991,
          -4093.8340000000003,
          -4126.479,
          -4158.925,
          -4191.168,
          -4223.207,
          -4255.037,
          -4286.656,
          -4318.062,
          -4349.251,
          -4380.22,
          -4410.965,
          -4441.485,
          -4471.776,
          -4501.835,
          -4531.657999999999,
          -4561.242,
          -4590.584,
          -4619.68,
          -4648.527,
          -4677.122,
          -4705.46,
          -4733.539000000001,
          -4761.354,
          -4788.902,
          -4816.179,
          -4843.181,
          -4869.905,
          -4896.345,
          -4922.499,
          -4948.361,
          -4973.929,
          -4999.197,
          -5024.161,
          -5048.816,
          -5073.159000000001,
          -5097.184,
          -5120.887,
          -5144.263,
          -5167.307,
          -5190.014,
          -5212.38,
          -5234.398,
          -5256.064,
          -5277.371999999999,
          -5298.316999999999,
          -5318.893,
          -5339.095,
          -5358.916,
          -5378.351,
          -5397.393,
          -5416.036999999999,
          -5434.275,
          -5452.103,
          -5469.512,
          -5486.496,
          -5503.049,
          -5519.161999999999,
          -5534.83,
          -5550.044,
          -5564.797,
          -5579.081,
          -5592.888000000001,
          -5606.21,
          -5619.039000000001,
          -5631.365,
          -5643.182,
          -5654.479,
          -5665.246999999999,
          -5675.476,
          -5685.158,
          -5694.281999999999,
          -5702.839,
          -5710.816999999999,
          -5718.206,
          -5724.995,
          -5731.173000000001,
          -5736.728,
          -5741.648,
          -5745.92,
          -5749.533,
          -5752.474,
          -5754.728,
          -5756.281999999999,
          -5757.1230000000005,
          -5757.235,
          -5756.604,
          -5755.214,
          -5753.048000000001,
          -5750.092,
          -5746.328,
          -5741.738,
          -5736.305,
          -5730.009,
          -5722.8330000000005,
          -5714.755,
          -5705.755,
          -5695.813,
          -5684.906,
          -5673.012,
          -5660.107,
          -5646.168000000001,
          -5631.169,
          -5615.084,
          -5597.887,
          -5579.549,
          -5560.0419999999995,
          -5539.335,
          -5517.398,
          -5494.198,
          -5469.701999999999,
          -5443.875,
          -5416.682,
          -5388.084,
          -5358.041,
          -5326.515,
          -5293.463000000001,
          -5258.840999999999,
          -5222.603,
          -5184.702,
          -5145.088,
          -5103.709,
          -5060.512,
          -5015.442,
          -4968.438,
          -4919.442,
          -4868.388,
          -4815.212,
          -4759.845,
          -4702.215,
          -4642.247,
          -4579.863,
          -4514.984,
          -4447.524,
          -4377.395,
          -4304.508,
          -4228.768,
          -4150.079000000001,
          -4068.3379999999997,
          -3983.4429999999998,
          -3895.2859999999996,
          -3803.758,
          -3708.748,
          -3610.1420000000003,
          -3507.827,
          -3401.6859999999997,
          -3291.607,
          -3177.4770000000003,
          -3059.191,
          -2936.6440000000002,
          -2809.745,
          -2678.409,
          -2542.57,
          -2402.177,
          -2257.203,
          -2107.649,
          -1953.546,
          -1794.9679999999998,
          -1632.03,
          -1464.899,
          -1293.796,
          -1119.003,
          -940.867,
          -759.796,
          -576.266,
          -390.809,
          -204.012,
          -16.505,
          171.05200000000002,
          357.98400000000004,
          543.614,
          727.285,
          908.3710000000001,
          1086.29,
          1260.519,
          1430.6,
          1596.144,
          1756.832,
          1912.415,
          2062.7110000000002,
          2207.6,
          2347.016,
          2480.938,
          2609.393,
          2732.4359999999997,
          2850.1540000000005,
          2962.653,
          3070.062,
          3172.5170000000003,
          3270.167,
          3363.164,
          3451.6659999999997,
          3535.8309999999997,
          3615.816,
          3691.777,
          3763.865,
          3832.232,
          3897.022,
          3958.373,
          4016.422,
          4071.297,
          4123.124,
          4172.024,
          4218.262,
          4261.49,
          4302.271,
          4340.5509999999995,
          4376.428,
          4409.99,
          4441.325,
          4470.516,
          4497.642,
          4522.778,
          4545.996,
          4567.3640000000005,
          4586.947,
          4604.809,
          4621.009,
          4635.603,
          4648.646,
          4660.19,
          4670.284000000001,
          4678.976,
          4686.313,
          4692.335999999999,
          4697.088,
          4700.609,
          4702.937,
          4704.108,
          4704.159000000001,
          4703.122,
          4701.03,
          4697.915,
          4693.806,
          4688.732,
          4682.72,
          4675.798,
          4667.991,
          4659.3240000000005,
          4649.82,
          4639.501,
          4628.392,
          4616.513,
          4603.884,
          4590.525,
          4576.455,
          4561.693,
          4546.2570000000005,
          4530.164000000001,
          4513.431,
          4496.0740000000005,
          4478.108,
          4459.549,
          4440.411,
          4420.709,
          4400.456,
          4379.666,
          4358.351,
          4336.525,
          4314.1990000000005,
          4291.385,
          4268.095,
          4244.339,
          4220.13,
          4195.476,
          4170.389,
          4144.878,
          4118.9529999999995,
          4092.623,
          4065.8979999999997,
          4038.7859999999996,
          4011.297,
          3983.437,
          3955.217,
          3926.6440000000002,
          3897.725,
          3868.468,
          3838.881,
          3808.9709999999995,
          3778.744,
          3748.2090000000003,
          3717.3709999999996,
          3686.237,
          3654.8140000000003,
          3623.1079999999997,
          3591.125,
          3558.8709999999996,
          3526.3509999999997,
          3493.572,
          3460.54,
          3427.259,
          3393.735,
          3359.973,
          3325.978,
          3291.756,
          3257.3109999999997,
          3222.6490000000003,
          3187.7729999999997,
          3152.688,
          3117.4,
          3081.9120000000003,
          3046.228,
          3010.3540000000003,
          2974.2929999999997,
          2938.0490000000004,
          2901.627,
          2865.03,
          2828.262,
          2791.328,
          2754.23,
          2716.972,
          2679.559,
          2641.993,
          2604.278,
          2566.4179999999997,
          2528.416,
          2490.275,
          2451.998,
          2413.589,
          2375.051,
          2336.387,
          2297.6,
          2258.6929999999998,
          2219.669,
          2180.531,
          2141.282,
          2101.924,
          2062.4610000000002,
          2022.895,
          1983.229,
          1943.4660000000001,
          1903.608,
          1863.6570000000002,
          1823.6170000000002,
          1783.49,
          1743.2779999999998,
          1702.985,
          1662.611,
          1622.16,
          1581.635,
          1541.037,
          1500.368,
          1459.632,
          1418.83,
          1377.964,
          1337.0379999999998,
          1296.052,
          1255.01,
          1213.913,
          1172.763,
          1131.563,
          1090.3139999999999,
          1049.019,
          1007.679,
          966.298,
          924.8760000000001,
          883.416,
          841.919,
          800.388,
          758.824,
          717.23,
          675.607,
          633.9580000000001,
          592.283,
          550.585,
          508.866,
          467.12800000000004,
          425.37199999999996,
          383.6,
          341.814,
          300.01599999999996,
          258.20799999999997,
          216.39,
          174.56599999999997,
          132.736,
          90.90299999999999,
          49.068000000000005,
          7.232,
          -34.601,
          -76.432,
          -118.257,
          -160.076,
          -201.887,
          -243.688,
          -285.47700000000003,
          -327.253,
          -369.015,
          -410.76,
          -452.486,
          -494.194,
          -535.879,
          -577.5419999999999,
          -619.18,
          -660.793,
          -702.377,
          -743.932,
          -785.456,
          -826.948,
          -868.4060000000001,
          -909.827,
          -951.212,
          -992.557,
          -1033.863,
          -1075.126,
          -1116.345,
          -1157.519,
          -1198.647,
          -1239.726,
          -1280.755,
          -1321.7320000000002,
          -1362.6570000000002,
          -1403.526,
          -1444.339,
          -1485.095,
          -1525.79,
          -1566.425,
          -1606.997,
          -1647.504,
          -1687.9460000000001,
          -1728.319,
          -1768.624,
          -1808.858,
          -1849.019,
          -1889.1070000000002,
          -1929.118,
          -1969.0520000000001,
          -2008.908,
          -2048.6820000000002,
          -2088.374,
          -2127.982,
          -2167.504,
          -2206.939,
          -2246.285,
          -2285.54,
          -2324.702,
          -2363.77,
          -2402.742,
          -2441.617,
          -2480.3920000000003,
          -2519.065,
          -2557.636,
          -2596.1020000000003,
          -2634.461,
          -2672.711,
          -2710.8520000000003,
          -2748.88,
          -2786.7940000000003,
          -2824.592,
          -2862.2729999999997,
          -2899.8340000000003,
          -2937.2740000000003,
          -2974.59,
          -3011.781,
          -3048.844,
          -3085.778,
          -3122.5809999999997,
          -3159.2509999999997,
          -3195.785,
          -3232.1809999999996,
          -3268.4390000000003,
          -3304.555,
          -3340.527,
          -3376.353,
          -3412.031,
          -3447.56,
          -3482.9359999999997,
          -3518.157,
          -3553.222,
          -3588.1279999999997,
          -3622.873,
          -3657.454,
          -3691.869,
          -3726.115,
          -3760.191,
          -3794.094,
          -3827.821,
          -3861.3709999999996,
          -3894.739,
          -3927.925,
          -3960.925,
          -3993.737,
          -4026.357,
          -4058.784,
          -4091.015,
          -4123.0470000000005,
          -4154.876,
          -4186.501,
          -4217.919,
          -4249.126,
          -4280.12,
          -4310.897,
          -4341.456,
          -4371.791,
          -4401.901,
          -4431.782999999999,
          -4461.432,
          -4490.846,
          -4520.022,
          -4548.956,
          -4577.645,
          -4606.085,
          -4634.273,
          -4662.205,
          -4689.877,
          -4717.286,
          -4744.429,
          -4771.3,
          -4797.897,
          -4824.215999999999,
          -4850.251,
          -4876,
          -4901.459,
          -4926.622,
          -4951.485,
          -4976.045,
          -5000.295999999999,
          -5024.235,
          -5047.856,
          -5071.155,
          -5094.126,
          -5116.766,
          -5139.068,
          -5161.029,
          -5182.642,
          -5203.903,
          -5224.805,
          -5245.344,
          -5265.514,
          -5285.308000000001,
          -5304.722,
          -5323.749,
          -5342.382,
          -5360.616,
          -5378.445,
          -5395.861,
          -5412.858,
          -5429.43,
          -5445.568,
          -5461.267,
          -5476.518,
          -5491.315,
          -5505.648,
          -5519.512,
          -5532.897,
          -5545.795999999999,
          -5558.1990000000005,
          -5570.099,
          -5581.486,
          -5592.352,
          -5602.686,
          -5612.48,
          -5621.724,
          -5630.408,
          -5638.521,
          -5646.052,
          -5652.991999999999,
          -5659.328,
          -5665.049,
          -5670.144,
          -5674.6,
          -5678.405,
          -5681.545999999999,
          -5684.01,
          -5685.783,
          -5686.852,
          -5687.201,
          -5686.816999999999,
          -5685.683000000001,
          -5683.785,
          -5681.106,
          -5677.629,
          -5673.335999999999,
          -5668.210999999999,
          -5662.235,
          -5655.389,
          -5647.653,
          -5639.007,
          -5629.43,
          -5618.901,
          -5607.397,
          -5594.895,
          -5581.371999999999,
          -5566.8009999999995,
          -5551.159000000001,
          -5534.4169999999995,
          -5516.549,
          -5497.526,
          -5477.319,
          -5455.896,
          -5433.226,
          -5409.276,
          -5384.0109999999995,
          -5357.395,
          -5329.393,
          -5299.963000000001,
          -5269.068,
          -5236.666,
          -5202.712,
          -5167.161,
          -5129.968,
          -5091.081,
          -5050.452,
          -5008.026,
          -4963.747,
          -4917.56,
          -4869.402,
          -4819.212,
          -4766.924,
          -4712.47,
          -4655.78,
          -4596.778,
          -4535.389,
          -4471.532999999999,
          -4405.125,
          -4336.08,
          -4264.307,
          -4189.714,
          -4112.2029999999995,
          -4031.676,
          -3948.0290000000005,
          -3861.156,
          -3770.947,
          -3677.296,
          -3580.086,
          -3479.2059999999997,
          -3374.5409999999997,
          -3265.9770000000003,
          -3153.405,
          -3036.716,
          -2915.81,
          -2790.591,
          -2660.978,
          -2526.901,
          -2388.31,
          -2245.175,
          -2097.495,
          -1945.3,
          -1788.6589999999999,
          -1627.684,
          -1462.535,
          -1293.43,
          -1120.644,
          -944.515,
          -765.447,
          -583.904,
          -400.411,
          -215.547,
          -29.933000000000003,
          155.779,
          340.92,
          524.822,
          706.831,
          886.325,
          1062.728,
          1235.518,
          1404.237,
          1568.495,
          1727.974,
          1882.425,
          2031.661,
          2175.562,
          2314.0570000000002,
          2447.125,
          2574.788,
          2697.099,
          2814.1420000000003,
          2926.0209999999997,
          3032.86,
          3134.7940000000003,
          3231.969,
          3324.535,
          3412.647,
          3496.461,
          3576.133,
          3651.815,
          3723.66,
          3791.8140000000003,
          3856.421,
          3917.618,
          3975.54,
          4030.3140000000003,
          4082.066,
          4130.912,
          4176.967000000001,
          4220.338,
          4261.13,
          4299.441,
          4335.366,
          4368.995,
          4400.413,
          4429.7029999999995,
          4456.944,
          4482.21,
          4505.572,
          4527.097,
          4546.851,
          4564.896,
          4581.291,
          4596.090999999999,
          4609.352,
          4621.124,
          4631.456,
          4640.397,
          4647.991,
          4654.281,
          4659.308,
          4663.112,
          4665.732,
          4667.2029999999995,
          4667.56,
          4666.837,
          4665.067,
          4662.279,
          4658.504,
          4653.77,
          4648.105,
          4641.535,
          4634.085999999999,
          4625.782,
          4616.646,
          4606.702,
          4595.971,
          4584.475,
          4572.233,
          4559.267,
          4545.593,
          4531.232,
          4516.2,
          4500.515,
          4484.193,
          4467.251,
          4449.704000000001,
          4431.567,
          4412.854,
          4393.58,
          4373.759,
          4353.403,
          4332.525,
          4311.138,
          4289.254,
          4266.885,
          4244.042,
          4220.736,
          4196.978,
          4172.779,
          4148.148,
          4123.095,
          4097.63,
          4071.762,
          4045.5,
          4018.8540000000003,
          3991.8320000000003,
          3964.441,
          3936.691,
          3908.59,
          3880.1440000000002,
          3851.362,
          3822.2509999999997,
          3792.8179999999998,
          3763.07,
          3733.014,
          3702.657,
          3672.005,
          3641.0640000000003,
          3609.842,
          3578.344,
          3546.575,
          3514.542,
          3482.25,
          3449.7059999999997,
          3416.913,
          3383.8790000000004,
          3350.607,
          3317.103,
          3283.3720000000003,
          3249.4190000000003,
          3215.248,
          3180.865,
          3146.2740000000003,
          3111.4790000000003,
          3076.4840000000004,
          3041.295,
          3005.915,
          2970.349,
          2934.6,
          2898.673,
          2862.571,
          2826.2990000000004,
          2789.8590000000004,
          2753.257,
          2716.495,
          2679.577,
          2642.507,
          2605.288,
          2567.923,
          2530.416,
          2492.771,
          2454.99,
          2417.076,
          2379.033,
          2340.864,
          2302.571,
          2264.158,
          2225.629,
          2186.984,
          2148.228,
          2109.364,
          2070.394,
          2031.32,
          1992.146,
          1952.874,
          1913.507,
          1874.047,
          1834.497,
          1794.86,
          1755.138,
          1715.332,
          1675.4470000000001,
          1635.484,
          1595.445,
          1555.3329999999999,
          1515.151,
          1474.9,
          1434.582,
          1394.2,
          1353.757,
          1313.254,
          1272.693,
          1232.076,
          1191.407,
          1150.6860000000001,
          1109.9160000000002,
          1069.098,
          1028.236,
          987.33,
          946.3839999999999,
          905.398,
          864.3739999999999,
          823.316,
          782.2239999999999,
          741.1,
          699.947,
          658.7660000000001,
          617.559,
          576.328,
          535.075,
          493.801,
          452.509,
          411.199,
          369.875,
          328.537,
          287.188,
          245.829,
          204.46099999999998,
          163.08700000000002,
          121.709,
          80.327,
          38.944,
          -2.439,
          -43.818999999999996,
          -85.196,
          -126.568,
          -167.933,
          -209.28900000000002,
          -250.635,
          -291.969,
          -333.29,
          -374.595,
          -415.884,
          -457.154,
          -498.405,
          -539.634,
          -580.84,
          -622.021,
          -663.176,
          -704.303,
          -745.4010000000001,
          -786.467,
          -827.5010000000001,
          -868.5010000000001,
          -909.465,
          -950.3919999999999,
          -991.28,
          -1032.127,
          -1072.933,
          -1113.694,
          -1154.411,
          -1195.0810000000001,
          -1235.702,
          -1276.274,
          -1316.7939999999999,
          -1357.261,
          -1397.674,
          -1438.03,
          -1478.329,
          -1518.568,
          -1558.746,
          -1598.862,
          -1638.914,
          -1678.9,
          -1718.818,
          -1758.668,
          -1798.4470000000001,
          -1838.154,
          -1877.787,
          -1917.344,
          -1956.825,
          -1996.227,
          -2035.5479999999998,
          -2074.788,
          -2113.944,
          -2153.014,
          -2191.9970000000003,
          -2230.8920000000003,
          -2269.696,
          -2308.409,
          -2347.027,
          -2385.55,
          -2423.975,
          -2462.301,
          -2500.527,
          -2538.65,
          -2576.6679999999997,
          -2614.581,
          -2652.385,
          -2690.08,
          -2727.663,
          -2765.133,
          -2802.487,
          -2839.724,
          -2876.842,
          -2913.8390000000004,
          -2950.7129999999997,
          -2987.4629999999997,
          -3024.085,
          -3060.579,
          -3096.942,
          -3133.172,
          -3169.268,
          -3205.2270000000003,
          -3241.047,
          -3276.7259999999997,
          -3312.261,
          -3347.652,
          -3382.895,
          -3417.989,
          -3452.9320000000002,
          -3487.72,
          -3522.3520000000003,
          -3556.8259999999996,
          -3591.139,
          -3625.289,
          -3659.2740000000003,
          -3693.092,
          -3726.739,
          -3760.2129999999997,
          -3793.513,
          -3826.635,
          -3859.577,
          -3892.337,
          -3924.9120000000003,
          -3957.2990000000004,
          -3989.4959999999996,
          -4021.5,
          -4053.308,
          -4084.917,
          -4116.326,
          -4147.53,
          -4178.527,
          -4209.315,
          -4239.89,
          -4270.248,
          -4300.389,
          -4330.306,
          -4359.999,
          -4389.465,
          -4418.698,
          -4447.697,
          -4476.458,
          -4504.978,
          -4533.253,
          -4561.28,
          -4589.054,
          -4616.5740000000005,
          -4643.834,
          -4670.832,
          -4697.563,
          -4724.024,
          -4750.21,
          -4776.119000000001,
          -4801.745,
          -4827.084,
          -4852.133,
          -4876.887,
          -4901.342000000001,
          -4925.4929999999995,
          -4949.335999999999,
          -4972.867,
          -4996.079000000001,
          -5018.97,
          -5041.534000000001,
          -5063.766,
          -5085.66,
          -5107.213,
          -5128.418,
          -5149.27,
          -5169.764,
          -5189.895,
          -5209.655,
          -5229.041,
          -5248.045,
          -5266.661,
          -5284.885,
          -5302.7080000000005,
          -5320.125,
          -5337.129,
          -5353.713000000001,
          -5369.871,
          -5385.595,
          -5400.878000000001,
          -5415.7119999999995,
          -5430.090999999999,
          -5444.005999999999,
          -5457.4490000000005,
          -5470.4130000000005,
          -5482.888000000001,
          -5494.866999999999,
          -5506.340999999999,
          -5517.3,
          -5527.735,
          -5537.638000000001,
          -5546.9980000000005,
          -5555.805,
          -5564.05,
          -5571.721,
          -5578.808000000001,
          -5585.3,
          -5591.186,
          -5596.454000000001,
          -5601.092,
          -5605.088000000001,
          -5608.429,
          -5611.102,
          -5613.093000000001,
          -5614.389,
          -5614.976,
          -5614.839,
          -5613.963000000001,
          -5612.331999999999,
          -5609.931,
          -5606.741999999999,
          -5602.749,
          -5597.935,
          -5592.28,
          -5585.767,
          -5578.376,
          -5570.0869999999995,
          -5560.879,
          -5550.732,
          -5539.621999999999,
          -5527.526999999999,
          -5514.424,
          -5500.286999999999,
          -5485.093000000001,
          -5468.813,
          -5451.422,
          -5432.89,
          -5413.19,
          -5392.289000000001,
          -5370.156999999999,
          -5346.7609999999995,
          -5322.068,
          -5296.041,
          -5268.644,
          -5239.839,
          -5209.585999999999,
          -5177.844,
          -5144.571,
          -5109.722,
          -5073.249,
          -5035.105,
          -4995.2390000000005,
          -4953.599,
          -4910.13,
          -4864.774,
          -4817.473,
          -4768.165,
          -4716.784000000001,
          -4663.263,
          -4607.532999999999,
          -4549.52,
          -4489.148,
          -4426.337,
          -4361.005999999999,
          -4293.069,
          -4222.437,
          -4149.017,
          -4072.7140000000004,
          -3993.428,
          -3911.059,
          -3825.502,
          -3736.647,
          -3644.386,
          -3548.6090000000004,
          -3449.2,
          -3346.048,
          -3239.04,
          -3128.066,
          -3013.018,
          -2893.795,
          -2770.303,
          -2642.4590000000003,
          -2510.194,
          -2373.455,
          -2232.212,
          -2086.462,
          -1936.23,
          -1781.5839999999998,
          -1622.631,
          -1459.527,
          -1292.484,
          -1121.769,
          -947.716,
          -770.717,
          -591.231,
          -409.773,
          -226.91400000000002,
          -43.266000000000005,
          140.528,
          323.806,
          505.906,
          686.18,
          864.013,
          1038.829,
          1210.109,
          1377.398,
          1540.305,
          1698.5120000000002,
          1851.7679999999998,
          1999.885,
          2142.739,
          2280.259,
          2412.4210000000003,
          2539.241,
          2660.772,
          2777.093,
          2888.3070000000002,
          2994.534,
          3095.908,
          3192.5690000000004,
          3284.6679999999997,
          3372.3559999999998,
          3455.7870000000003,
          3535.114,
          3610.49,
          3682.062,
          3749.9770000000003,
          3814.3759999999997,
          3875.3959999999997,
          3933.1690000000003,
          3987.822,
          4039.4770000000003,
          4088.252,
          4134.259,
          4177.605,
          4218.392,
          4256.72,
          4292.68,
          4326.363,
          4357.854,
          4387.232,
          4414.5779999999995,
          4439.965,
          4463.462,
          4485.138,
          4505.055,
          4523.277,
          4539.861,
          4554.862,
          4568.335999999999,
          4580.332,
          4590.9,
          4600.085999999999,
          4607.934,
          4614.4890000000005,
          4619.79,
          4623.877,
          4626.788,
          4628.558,
          4629.223,
          4628.815,
          4627.367,
          4624.909000000001,
          4621.47,
          4617.079000000001,
          4611.764,
          4605.549,
          4598.460999999999,
          4590.524,
          4581.7609999999995,
          4572.195,
          4561.847,
          4550.7390000000005,
          4538.89,
          4526.321,
          4513.049,
          4499.094,
          4484.473,
          4469.202,
          4453.299,
          4436.779,
          4419.657999999999,
          4401.95,
          4383.670999999999,
          4364.833,
          4345.451,
          4325.537,
          4305.105,
          4284.167,
          4262.734,
          4240.819,
          4218.432,
          4195.585,
          4172.288,
          4148.552,
          4124.387,
          4099.802,
          4074.808,
          4049.4120000000003,
          4023.625,
          3997.455,
          3970.91,
          3943.9990000000003,
          3916.7309999999998,
          3889.112,
          3861.151,
          3832.855,
          3804.2309999999998,
          3775.2870000000003,
          3746.03,
          3716.465,
          3686.6009999999997,
          3656.4429999999998,
          3625.9970000000003,
          3595.2709999999997,
          3564.27,
          3532.9990000000003,
          3501.465,
          3469.6740000000004,
          3437.63,
          3405.3390000000004,
          3372.8059999999996,
          3340.038,
          3307.038,
          3273.8109999999997,
          3240.363,
          3206.698,
          3172.821,
          3138.736,
          3104.448,
          3069.961,
          3035.2790000000005,
          3000.408,
          2965.35,
          2930.11,
          2894.692,
          2859.099,
          2823.336,
          2787.407,
          2751.3140000000003,
          2715.062,
          2678.6540000000005,
          2642.094,
          2605.385,
          2568.531,
          2531.534,
          2494.3979999999997,
          2457.127,
          2419.723,
          2382.19,
          2344.53,
          2306.7470000000003,
          2268.844,
          2230.823,
          2192.687,
          2154.44,
          2116.083,
          2077.621,
          2039.055,
          2000.388,
          1961.6229999999998,
          1922.7620000000002,
          1883.808,
          1844.764,
          1805.631,
          1766.4129999999998,
          1727.112,
          1687.731,
          1648.27,
          1608.734,
          1569.124,
          1529.443,
          1489.692,
          1449.875,
          1409.9920000000002,
          1370.047,
          1330.0420000000001,
          1289.978,
          1249.859,
          1209.685,
          1169.4589999999998,
          1129.183,
          1088.859,
          1048.489,
          1008.075,
          967.6189999999999,
          927.123,
          886.5889999999999,
          846.0189999999999,
          805.414,
          764.7769999999999,
          724.1089999999999,
          683.413,
          642.69,
          601.941,
          561.169,
          520.376,
          479.56300000000005,
          438.73199999999997,
          397.885,
          357.023,
          316.149,
          275.264,
          234.36900000000003,
          193.467,
          152.559,
          111.646,
          70.73100000000001,
          29.816,
          -11.099,
          -52.012,
          -92.921,
          -133.82399999999998,
          -174.71900000000002,
          -215.606,
          -256.482,
          -297.346,
          -338.19699999999995,
          -379.032,
          -419.85,
          -460.649,
          -501.42900000000003,
          -542.187,
          -582.9209999999999,
          -623.631,
          -664.314,
          -704.97,
          -745.596,
          -786.19,
          -826.753,
          -867.2810000000001,
          -907.773,
          -948.2280000000001,
          -988.6439999999999,
          -1029.02,
          -1069.354,
          -1109.644,
          -1149.889,
          -1190.088,
          -1230.238,
          -1270.339,
          -1310.388,
          -1350.385,
          -1390.3270000000002,
          -1430.213,
          -1470.0420000000001,
          -1509.8110000000001,
          -1549.52,
          -1589.1670000000001,
          -1628.749,
          -1668.267,
          -1707.717,
          -1747.098,
          -1786.41,
          -1825.649,
          -1864.816,
          -1903.9070000000002,
          -1942.921,
          -1981.8570000000002,
          -2020.713,
          -2059.488,
          -2098.179,
          -2136.785,
          -2175.305,
          -2213.736,
          -2252.078,
          -2290.327,
          -2328.484,
          -2366.545,
          -2404.51,
          -2442.376,
          -2480.1420000000003,
          -2517.806,
          -2555.365,
          -2592.82,
          -2630.167,
          -2667.4040000000005,
          -2704.531,
          -2741.545,
          -2778.4440000000004,
          -2815.2259999999997,
          -2851.89,
          -2888.434,
          -2924.855,
          -2961.153,
          -2997.324,
          -3033.367,
          -3069.2790000000005,
          -3105.06,
          -3140.7070000000003,
          -3176.217,
          -3211.59,
          -3246.822,
          -3281.9109999999996,
          -3316.857,
          -3351.655,
          -3386.305,
          -3420.804,
          -3455.1490000000003,
          -3489.34,
          -3523.3720000000003,
          -3557.245,
          -3590.955,
          -3624.5009999999997,
          -3657.8790000000004,
          -3691.0890000000004,
          -3724.1259999999997,
          -3756.99,
          -3789.676,
          -3822.184,
          -3854.51,
          -3886.651,
          -3918.605,
          -3950.37,
          -3981.9429999999998,
          -4013.32,
          -4044.5,
          -4075.4790000000003,
          -4106.255,
          -4136.8240000000005,
          -4167.185,
          -4197.333,
          -4227.266,
          -4256.981,
          -4286.476,
          -4315.745,
          -4344.787,
          -4373.599,
          -4402.1759999999995,
          -4430.516,
          -4458.615,
          -4486.471,
          -4514.0779999999995,
          -4541.434,
          -4568.536,
          -4595.379,
          -4621.96,
          -4648.275,
          -4674.32,
          -4700.090999999999,
          -4725.584,
          -4750.795999999999,
          -4775.721,
          -4800.357,
          -4824.698,
          -4848.74,
          -4872.479,
          -4895.91,
          -4919.028,
          -4941.83,
          -4964.309,
          -4986.462,
          -5008.282999999999,
          -5029.767,
          -5050.909000000001,
          -5071.704000000001,
          -5092.146,
          -5112.229,
          -5131.9490000000005,
          -5151.299,
          -5170.274,
          -5188.867,
          -5207.072,
          -5224.884,
          -5242.295,
          -5259.3,
          -5275.891,
          -5292.062,
          -5307.806,
          -5323.115,
          -5337.983,
          -5352.401,
          -5366.363,
          -5379.86,
          -5392.884,
          -5405.427,
          -5417.481,
          -5429.036999999999,
          -5440.085999999999,
          -5450.619000000001,
          -5460.6269999999995,
          -5470.1,
          -5479.028,
          -5487.401999999999,
          -5495.210999999999,
          -5502.444,
          -5509.09,
          -5515.139,
          -5520.579000000001,
          -5525.398,
          -5529.5830000000005,
          -5533.1230000000005,
          -5536.005,
          -5538.214,
          -5539.738,
          -5540.563,
          -5540.674,
          -5540.056,
          -5538.694,
          -5536.571999999999,
          -5533.674,
          -5529.983,
          -5525.481,
          -5520.151,
          -5513.975,
          -5506.932,
          -5499.004,
          -5490.169,
          -5480.408,
          -5469.696999999999,
          -5458.015,
          -5445.338000000001,
          -5431.642,
          -5416.901999999999,
          -5401.092,
          -5384.185,
          -5366.153,
          -5346.967,
          -5326.598000000001,
          -5305.014,
          -5282.183000000001,
          -5258.071,
          -5232.643,
          -5205.8640000000005,
          -5177.695,
          -5148.096,
          -5117.03,
          -5084.451,
          -5050.317,
          -5014.581,
          -4977.195,
          -4938.109,
          -4897.273,
          -4854.63,
          -4810.126,
          -4763.701,
          -4715.294,
          -4664.840999999999,
          -4612.276,
          -4557.529,
          -4500.528,
          -4441.197,
          -4379.459,
          -4315.232,
          -4248.431,
          -4178.967000000001,
          -4106.751,
          -4031.6859999999997,
          -3953.676,
          -3872.619,
          -3788.4109999999996,
          -3700.947,
          -3610.115,
          -3515.808,
          -3417.913,
          -3316.316,
          -3210.907,
          -3101.5759999999996,
          -2988.216,
          -2870.725,
          -2749.011,
          -2622.989,
          -2492.589,
          -2357.759,
          -2218.466,
          -2074.705,
          -1926.499,
          -1773.912,
          -1617.046,
          -1456.0539999999999,
          -1291.14,
          -1122.567,
          -950.659,
          -775.803,
          -598.446,
          -419.098,
          -238.317,
          -56.708,
          125.094,
          306.435,
          486.662,
          665.1310000000001,
          841.232,
          1014.393,
          1184.099,
          1349.894,
          1511.389,
          1668.265,
          1820.2679999999998,
          1967.2120000000002,
          2108.968,
          2245.4629999999997,
          2376.669,
          2502.6020000000003,
          2623.309,
          2738.868,
          2849.3779999999997,
          2954.9570000000003,
          3055.7340000000004,
          3151.849,
          3243.448,
          3330.6820000000002,
          3413.702,
          3492.658,
          3567.7009999999996,
          3638.978,
          3706.631,
          3770.801,
          3831.623,
          3889.228,
          3943.741,
          3995.284,
          4043.972,
          4089.842,
          4133.223,
          4173.9929999999995,
          4212.325,
          4248.31,
          4282.036,
          4313.589,
          4343.048,
          4370.491,
          4395.991,
          4419.617,
          4441.436,
          4461.512,
          4479.906,
          4496.674,
          4511.874,
          4525.557,
          4537.775,
          4548.576,
          4558.005,
          4566.108,
          4572.9259999999995,
          4578.501,
          4582.871,
          4586.0740000000005,
          4588.145,
          4589.1179999999995,
          4589.027,
          4587.903,
          4585.777,
          4582.678,
          4578.633,
          4573.67,
          4567.815,
          4561.092000000001,
          4553.526,
          4545.141,
          4535.957,
          4525.998,
          4515.282999999999,
          4503.833,
          4491.667,
          4478.804,
          4465.262,
          4451.058,
          4436.209,
          4420.732,
          4404.641,
          4387.954000000001,
          4370.683,
          4352.845,
          4334.452,
          4315.517,
          4296.055,
          4276.077,
          4255.596,
          4234.624,
          4213.1720000000005,
          4191.251,
          4168.873,
          4146.0470000000005,
          4122.785,
          4099.096,
          4074.989,
          4050.475,
          4025.563,
          4000.26,
          3974.577,
          3948.522,
          3922.1020000000003,
          3895.3259999999996,
          3868.2009999999996,
          3840.736,
          3812.938,
          3784.8140000000003,
          3756.37,
          3727.615,
          3698.554,
          3669.195,
          3639.5429999999997,
          3609.6040000000003,
          3579.387,
          3548.8959999999997,
          3518.135,
          3487.113,
          3455.835,
          3424.304,
          3392.528,
          3360.511,
          3328.259,
          3295.776,
          3263.067,
          3230.137,
          3196.991,
          3163.634,
          3130.0690000000004,
          3096.302,
          3062.336,
          3028.177,
          2993.827,
          2959.292,
          2924.575,
          2889.68,
          2854.611,
          2819.3709999999996,
          2783.966,
          2748.397,
          2712.67,
          2676.7859999999996,
          2640.7509999999997,
          2604.567,
          2568.237,
          2531.765,
          2495.154,
          2458.407,
          2421.528,
          2384.519,
          2347.384,
          2310.125,
          2272.746,
          2235.249,
          2197.637,
          2159.913,
          2122.08,
          2084.141,
          2046.0970000000002,
          2007.953,
          1969.71,
          1931.371,
          1892.9379999999999,
          1854.415,
          1815.8029999999999,
          1777.105,
          1738.3229999999999,
          1699.46,
          1660.519,
          1621.5,
          1582.408,
          1543.243,
          1504.009,
          1464.707,
          1425.34,
          1385.9089999999999,
          1346.4170000000001,
          1306.867,
          1267.259,
          1227.597,
          1187.881,
          1148.116,
          1108.3010000000002,
          1068.4389999999999,
          1028.5330000000001,
          988.584,
          948.5939999999999,
          908.565,
          868.4989999999999,
          828.3969999999999,
          788.262,
          748.096,
          707.9,
          667.676,
          627.4259999999999,
          587.1519999999999,
          546.855,
          506.537,
          466.20099999999996,
          425.847,
          385.477,
          345.094,
          304.698,
          264.29200000000003,
          223.878,
          183.456,
          143.029,
          102.598,
          62.165,
          21.730999999999998,
          -18.701,
          -59.131,
          -99.602,
          -140.02100000000002,
          -180.433,
          -220.835,
          -261.22700000000003,
          -301.606,
          -341.971,
          -382.32099999999997,
          -422.654,
          -462.968,
          -503.26099999999997,
          -543.533,
          -583.7819999999999,
          -624.006,
          -664.203,
          -704.372,
          -744.512,
          -784.6210000000001,
          -824.697,
          -864.7389999999999,
          -904.7460000000001,
          -944.715,
          -984.645,
          -1024.535,
          -1064.383,
          -1104.188,
          -1143.948,
          -1183.662,
          -1223.327,
          -1262.943,
          -1302.508,
          -1342.021,
          -1381.479,
          -1420.881,
          -1460.226,
          -1499.513,
          -1538.739,
          -1577.9029999999998,
          -1617.003,
          -1656.039,
          -1695.0079999999998,
          -1733.908,
          -1772.739,
          -1811.4979999999998,
          -1850.184,
          -1888.796,
          -1927.3310000000001,
          -1965.789,
          -2004.1670000000001,
          -2042.464,
          -2080.678,
          -2118.808,
          -2156.851,
          -2194.8070000000002,
          -2232.674,
          -2270.449,
          -2308.132,
          -2345.72,
          -2383.2110000000002,
          -2420.605,
          -2457.899,
          -2495.092,
          -2532.1820000000002,
          -2569.166,
          -2606.044,
          -2642.813,
          -2679.472,
          -2716.0190000000002,
          -2752.4509999999996,
          -2788.768,
          -2824.967,
          -2861.046,
          -2897.0040000000004,
          -2932.8379999999997,
          -2968.547,
          -3004.1279999999997,
          -3039.58,
          -3074.901,
          -3110.0879999999997,
          -3145.14,
          -3180.054,
          -3214.829,
          -3249.4629999999997,
          -3283.952,
          -3318.296,
          -3352.492,
          -3386.5370000000003,
          -3420.4309999999996,
          -3454.1690000000003,
          -3487.7509999999997,
          -3521.173,
          -3554.435,
          -3587.532,
          -3620.4629999999997,
          -3653.2259999999997,
          -3685.817,
          -3718.235,
          -3750.478,
          -3782.542,
          -3814.425,
          -3846.1240000000003,
          -3877.638,
          -3908.962,
          -3940.095,
          -3971.034,
          -4001.776,
          -4032.3190000000004,
          -4062.659,
          -4092.7929999999997,
          -4122.718,
          -4152.434,
          -4181.934,
          -4211.217000000001,
          -4240.28,
          -4269.119000000001,
          -4297.731,
          -4326.1140000000005,
          -4354.263,
          -4382.1759999999995,
          -4409.849,
          -4437.278,
          -4464.460999999999,
          -4491.393,
          -4518.07,
          -4544.49,
          -4570.649,
          -4596.542,
          -4622.166,
          -4647.517,
          -4672.590999999999,
          -4697.383,
          -4721.89,
          -4746.108,
          -4770.032,
          -4793.657,
          -4816.979,
          -4839.995,
          -4862.698,
          -4885.084,
          -4907.149,
          -4928.888,
          -4950.295,
          -4971.366,
          -4992.094,
          -5012.476,
          -5032.505,
          -5052.1759999999995,
          -5071.483,
          -5090.420999999999,
          -5108.983,
          -5127.163,
          -5144.956,
          -5162.355,
          -5179.354,
          -5195.946,
          -5212.124,
          -5227.880999999999,
          -5243.21,
          -5258.105,
          -5272.557,
          -5286.56,
          -5300.105,
          -5313.185,
          -5325.791,
          -5337.915,
          -5349.548000000001,
          -5360.683000000001,
          -5371.309,
          -5381.418000000001,
          -5391,
          -5400.045999999999,
          -5408.545,
          -5416.488,
          -5423.8640000000005,
          -5430.661999999999,
          -5436.871,
          -5442.48,
          -5447.477,
          -5451.851,
          -5455.588000000001,
          -5458.677,
          -5461.103,
          -5462.854,
          -5463.916,
          -5464.275,
          -5463.915,
          -5462.821999999999,
          -5460.98,
          -5458.3730000000005,
          -5454.985,
          -5450.797,
          -5445.794,
          -5439.956,
          -5433.264,
          -5425.6990000000005,
          -5417.241,
          -5407.869000000001,
          -5397.561,
          -5386.295999999999,
          -5374.05,
          -5360.799,
          -5346.519,
          -5331.183000000001,
          -5314.766,
          -5297.24,
          -5278.576999999999,
          -5258.746,
          -5237.717000000001,
          -5215.458,
          -5191.937,
          -5167.1179999999995,
          -5140.965,
          -5113.443,
          -5084.5109999999995,
          -5054.13,
          -5022.258,
          -4988.851,
          -4953.8640000000005,
          -4917.25,
          -4878.959,
          -4838.94,
          -4797.14,
          -4753.503,
          -4707.971,
          -4660.483,
          -4610.977,
          -4559.3859999999995,
          -4505.642,
          -4449.673,
          -4391.406,
          -4330.762,
          -4267.662,
          -4202.02,
          -4133.751,
          -4062.764,
          -3988.965,
          -3912.258,
          -3832.542,
          -3749.715,
          -3663.671,
          -3574.303,
          -3481.5009999999997,
          -3385.153,
          -3285.1490000000003,
          -3181.377,
          -3073.728,
          -2962.0959999999995,
          -2846.381,
          -2726.487,
          -2602.333,
          -2473.846,
          -2340.973,
          -2203.681,
          -2061.96,
          -1915.835,
          -1765.362,
          -1610.642,
          -1451.8210000000001,
          -1289.098,
          -1122.73,
          -953.033,
          -780.385,
          -605.227,
          -428.05699999999996,
          -249.426,
          -69.928,
          109.809,
          289.14099999999996,
          467.41900000000004,
          644.009,
          818.304,
          989.737,
          1157.795,
          1322.025,
          1482.0379999999998,
          1637.514,
          1788.2,
          1933.906,
          2074.502,
          2209.91,
          2340.103,
          2465.091,
          2584.9210000000003,
          2699.665,
          2809.421,
          2914.302,
          3014.437,
          3109.962,
          3201.0209999999997,
          3287.761,
          3370.3309999999997,
          3448.88,
          3523.555,
          3594.5009999999997,
          3661.861,
          3725.772,
          3786.368,
          3843.778,
          3898.1259999999997,
          3949.531,
          3998.1090000000004,
          4043.968,
          4087.2140000000004,
          4127.948,
          4166.264,
          4202.255999999999,
          4236.01,
          4267.61,
          4297.135,
          4324.661,
          4350.2609999999995,
          4374.003,
          4395.955,
          4416.178,
          4434.734,
          4451.678,
          4467.067,
          4480.952,
          4493.385,
          4504.411,
          4514.0779999999995,
          4522.43,
          4529.5070000000005,
          4535.352,
          4540.001,
          4543.492,
          4545.861,
          4547.141,
          4547.365,
          4546.564,
          4544.769,
          4542.008,
          4538.309,
          4533.6990000000005,
          4528.204000000001,
          4521.848,
          4514.655,
          4506.648,
          4497.85,
          4488.281,
          4477.963,
          4466.915,
          4455.156,
          4442.705,
          4429.579000000001,
          4415.7970000000005,
          4401.374,
          4386.327,
          4370.6720000000005,
          4354.424,
          4337.596,
          4320.204000000001,
          4302.262,
          4283.782,
          4264.777,
          4245.26,
          4225.244000000001,
          4204.7390000000005,
          4183.758,
          4162.311,
          4140.409000000001,
          4118.063,
          4095.282,
          4072.078,
          4048.458,
          4024.434,
          4000.013,
          3975.205,
          3950.018,
          3924.461,
          3898.542,
          3872.268,
          3845.6479999999997,
          3818.6890000000003,
          3791.3990000000003,
          3763.784,
          3735.8520000000003,
          3707.6090000000004,
          3679.063,
          3650.219,
          3621.085,
          3591.6659999999997,
          3561.968,
          3531.9970000000003,
          3501.76,
          3471.261,
          3440.507,
          3409.5029999999997,
          3378.2529999999997,
          3346.764,
          3315.04,
          3283.086,
          3250.907,
          3218.508,
          3185.8940000000002,
          3153.0690000000004,
          3120.0370000000003,
          3086.804,
          3053.3720000000003,
          3019.7470000000003,
          2985.933,
          2951.934,
          2917.7529999999997,
          2883.3940000000002,
          2848.862,
          2814.16,
          2779.292,
          2744.262,
          2709.072,
          2673.7270000000003,
          2638.23,
          2602.584,
          2566.7929999999997,
          2530.86,
          2494.788,
          2458.581,
          2422.24,
          2385.77,
          2349.174,
          2312.4539999999997,
          2275.613,
          2238.655,
          2201.5820000000003,
          2164.396,
          2127.101,
          2089.699,
          2052.1929999999998,
          2014.586,
          1976.88,
          1939.0770000000002,
          1901.181,
          1863.194,
          1825.1170000000002,
          1786.954,
          1748.7079999999999,
          1710.379,
          1671.971,
          1633.486,
          1594.9260000000002,
          1556.2939999999999,
          1517.5910000000001,
          1478.82,
          1439.983,
          1401.082,
          1362.12,
          1323.098,
          1284.018,
          1244.883,
          1205.694,
          1166.454,
          1127.164,
          1087.826,
          1048.444,
          1009.0169999999999,
          969.549,
          930.04,
          890.4939999999999,
          850.9119999999999,
          811.295,
          771.6460000000001,
          731.966,
          692.258,
          652.5219999999999,
          612.761,
          572.977,
          533.17,
          493.344,
          453.499,
          413.63800000000003,
          373.76199999999994,
          333.87199999999996,
          293.971,
          254.06,
          214.141,
          174.215,
          134.284,
          94.35,
          54.413999999999994,
          14.478,
          -25.456,
          -65.387,
          -105.314,
          -145.234,
          -185.14700000000002,
          -225.05,
          -264.942,
          -304.822,
          -344.68699999999995,
          -384.537,
          -424.369,
          -464.18300000000005,
          -503.976,
          -543.748,
          -583.496,
          -623.219,
          -662.916,
          -702.585,
          -742.2239999999999,
          -781.8330000000001,
          -821.409,
          -860.95,
          -900.457,
          -939.926,
          -979.3560000000001,
          -1018.7460000000001,
          -1058.095,
          -1097.401,
          -1136.662,
          -1175.876,
          -1215.0430000000001,
          -1254.161,
          -1293.2269999999999,
          -1332.2420000000002,
          -1371.2020000000002,
          -1410.108,
          -1448.9560000000001,
          -1487.746,
          -1526.476,
          -1565.144,
          -1603.749,
          -1642.289,
          -1680.764,
          -1719.17,
          -1757.507,
          -1795.773,
          -1833.9660000000001,
          -1872.086,
          -1910.129,
          -1948.096,
          -1985.983,
          -2023.789,
          -2061.514,
          -2099.154,
          -2136.71,
          -2174.177,
          -2211.5570000000002,
          -2248.845,
          -2286.042,
          -2323.144,
          -2360.151,
          -2397.061,
          -2433.8720000000003,
          -2470.581,
          -2507.189,
          -2543.692,
          -2580.089,
          -2616.3779999999997,
          -2652.558,
          -2688.6259999999997,
          -2724.58,
          -2760.42,
          -2796.143,
          -2831.7459999999996,
          -2867.2290000000003,
          -2902.5890000000004,
          -2937.825,
          -2972.934,
          -3007.914,
          -3042.764,
          -3077.482,
          -3112.0640000000003,
          -3146.511,
          -3180.8179999999998,
          -3214.985,
          -3249.009,
          -3282.888,
          -3316.62,
          -3350.202,
          -3383.633,
          -3416.91,
          -3450.032,
          -3482.995,
          -3515.797,
          -3548.437,
          -3580.9109999999996,
          -3613.218,
          -3645.355,
          -3677.3190000000004,
          -3709.1079999999997,
          -3740.72,
          -3772.152,
          -3803.401,
          -3834.465,
          -3865.341,
          -3896.027,
          -3926.5190000000002,
          -3956.816,
          -3986.913,
          -4016.809,
          -4046.5009999999997,
          -4075.985,
          -4105.259,
          -4134.319,
          -4163.164000000001,
          -4191.788,
          -4220.19,
          -4248.366,
          -4276.313,
          -4304.028,
          -4331.5070000000005,
          -4358.747,
          -4385.744000000001,
          -4412.496,
          -4438.997,
          -4465.246,
          -4491.237,
          -4516.968,
          -4542.434,
          -4567.6320000000005,
          -4592.558,
          -4617.207,
          -4641.576,
          -4665.66,
          -4689.455,
          -4712.957,
          -4736.161,
          -4759.064,
          -4781.659000000001,
          -4803.943,
          -4825.911,
          -4847.558,
          -4868.88,
          -4889.87,
          -4910.524,
          -4930.837,
          -4950.803,
          -4970.417,
          -4989.673,
          -5008.565,
          -5027.089,
          -5045.237,
          -5063.003,
          -5080.383,
          -5097.3679999999995,
          -5113.9529999999995,
          -5130.13,
          -5145.894,
          -5161.238,
          -5176.153,
          -5190.633,
          -5204.67,
          -5218.258,
          -5231.387,
          -5244.05,
          -5256.2390000000005,
          -5267.945,
          -5279.159000000001,
          -5289.874,
          -5300.079000000001,
          -5309.766,
          -5318.925,
          -5327.545999999999,
          -5335.619000000001,
          -5343.134,
          -5350.08,
          -5356.446999999999,
          -5362.222,
          -5367.395,
          -5371.954000000001,
          -5375.8859999999995,
          -5379.18,
          -5381.821999999999,
          -5383.798000000001,
          -5385.096,
          -5385.701,
          -5385.599,
          -5384.775,
          -5383.2119999999995,
          -5380.897,
          -5377.812,
          -5373.939,
          -5369.263000000001,
          -5363.764,
          -5357.425,
          -5350.225,
          -5342.146,
          -5333.166,
          -5323.265,
          -5312.419,
          -5300.608,
          -5287.806,
          -5273.99,
          -5259.135,
          -5243.213000000001,
          -5226.1990000000005,
          -5208.063,
          -5188.778,
          -5168.311,
          -5146.633,
          -5123.709,
          -5099.5070000000005,
          -5073.991,
          -5047.124,
          -5018.8679999999995,
          -4989.183,
          -4958.028,
          -4925.361,
          -4891.135,
          -4855.306,
          -4817.823,
          -4778.6359999999995,
          -4737.693,
          -4694.939,
          -4650.316,
          -4603.764,
          -4555.222,
          -4504.624,
          -4451.902,
          -4396.986,
          -4339.803,
          -4280.276,
          -4218.3240000000005,
          -4153.867,
          -4086.817,
          -4017.085,
          -3944.578,
          -3869.202,
          -3790.8559999999998,
          -3709.44,
          -3624.849,
          -3536.9759999999997,
          -3445.7129999999997,
          -3350.948,
          -3252.573,
          -3150.4770000000003,
          -3044.55,
          -2934.6890000000003,
          -2820.7909999999997,
          -2702.764,
          -2580.524,
          -2453.998,
          -2323.133,
          -2187.894,
          -2048.27,
          -1904.28,
          -1755.981,
          -1603.467,
          -1446.88,
          -1286.413,
          -1122.317,
          -954.8989999999999,
          -784.5310000000001,
          -611.643,
          -436.724,
          -260.317,
          -83.007,
          94.589,
          271.835,
          448.089,
          622.725,
          795.1389999999999,
          964.7710000000001,
          1131.109,
          1293.703,
          1452.165,
          1606.174,
          1755.477,
          1899.881,
          2039.256,
          2173.52,
          2302.644,
          2426.634,
          2545.535,
          2659.4159999999997,
          2768.3709999999996,
          2872.512,
          2971.9629999999997,
          3066.857,
          3157.337,
          3243.547,
          3325.633,
          3403.742,
          3478.018,
          3548.607,
          3615.6459999999997,
          3679.272,
          3739.617,
          3796.809,
          3850.969,
          3902.217,
          3950.664,
          3996.421,
          4039.59,
          4080.27,
          4118.557,
          4154.542,
          4188.31,
          4219.944,
          4249.523,
          4277.121,
          4302.812,
          4326.662,
          4348.738,
          4369.101,
          4387.812,
          4404.9259999999995,
          4420.498,
          4434.581,
          4447.223,
          4458.472,
          4468.373,
          4476.971,
          4484.306,
          4490.417,
          4495.345,
          4499.124,
          4501.79,
          4503.376,
          4503.916,
          4503.439,
          4501.977,
          4499.556,
          4496.205,
          4491.951,
          4486.819,
          4480.832,
          4474.016,
          4466.392,
          4457.983,
          4448.81,
          4438.893,
          4428.252,
          4416.905,
          4404.872,
          4392.169,
          4378.815,
          4364.825,
          4350.215,
          4335.002,
          4319.1990000000005,
          4302.822,
          4285.885,
          4268.401,
          4250.383,
          4231.845,
          4212.7970000000005,
          4193.254,
          4173.226,
          4152.724,
          4131.76,
          4110.344,
          4088.487,
          4066.198,
          4043.488,
          4020.366,
          3996.841,
          3972.922,
          3948.619,
          3923.9390000000003,
          3898.8909999999996,
          3873.4829999999997,
          3847.723,
          3821.618,
          3795.177,
          3768.406,
          3741.312,
          3713.903,
          3686.1859999999997,
          3658.1659999999997,
          3629.85,
          3601.245,
          3572.357,
          3543.191,
          3513.7540000000004,
          3484.052,
          3454.0890000000004,
          3423.8720000000003,
          3393.406,
          3362.696,
          3331.748,
          3300.565,
          3269.1540000000005,
          3237.5190000000002,
          3205.664,
          3173.595,
          3141.316,
          3108.8309999999997,
          3076.145,
          3043.262,
          3010.185,
          2976.92,
          2943.4709999999995,
          2909.84,
          2876.032,
          2842.052,
          2807.901,
          2773.585,
          2739.107,
          2704.47,
          2669.678,
          2634.7340000000004,
          2599.641,
          2564.404,
          2529.024,
          2493.506,
          2457.8520000000003,
          2422.0660000000003,
          2386.15,
          2350.107,
          2313.9410000000003,
          2277.654,
          2241.25,
          2204.73,
          2168.098,
          2131.356,
          2094.507,
          2057.554,
          2020.5,
          1983.346,
          1946.095,
          1908.751,
          1871.315,
          1833.79,
          1796.1770000000001,
          1758.481,
          1720.7020000000002,
          1682.844,
          1644.9070000000002,
          1606.896,
          1568.8120000000001,
          1530.656,
          1492.432,
          1454.141,
          1415.786,
          1377.369,
          1338.891,
          1300.355,
          1261.763,
          1223.117,
          1184.4180000000001,
          1145.6689999999999,
          1106.872,
          1068.028,
          1029.14,
          990.21,
          951.238,
          912.2280000000001,
          873.181,
          834.0989999999999,
          794.9830000000001,
          755.835,
          716.658,
          677.453,
          638.222,
          598.966,
          559.687,
          520.387,
          481.06800000000004,
          441.731,
          402.37800000000004,
          363.01,
          323.63,
          284.23900000000003,
          244.83900000000003,
          205.43,
          166.016,
          126.59700000000001,
          87.175,
          47.751000000000005,
          8.328,
          -31.093000000000004,
          -70.51100000000001,
          -109.92399999999999,
          -149.33100000000002,
          -188.729,
          -228.118,
          -267.495,
          -306.86,
          -346.211,
          -385.546,
          -424.86300000000006,
          -464.162,
          -503.44,
          -542.697,
          -581.93,
          -621.138,
          -660.32,
          -699.4739999999999,
          -738.5980000000001,
          -777.692,
          -816.753,
          -855.7810000000001,
          -894.7719999999999,
          -933.727,
          -972.6439999999999,
          -1011.52,
          -1050.355,
          -1089.1480000000001,
          -1127.895,
          -1166.597,
          -1205.252,
          -1243.857,
          -1282.412,
          -1320.915,
          -1359.365,
          -1397.759,
          -1436.0970000000002,
          -1474.3770000000002,
          -1512.5970000000002,
          -1550.756,
          -1588.8529999999998,
          -1626.885,
          -1664.851,
          -1702.751,
          -1740.5810000000001,
          -1778.3410000000001,
          -1816.029,
          -1853.6429999999998,
          -1891.182,
          -1928.644,
          -1966.0279999999998,
          -2003.332,
          -2040.5539999999999,
          -2077.694,
          -2114.748,
          -2151.716,
          -2188.595,
          -2225.385,
          -2262.083,
          -2298.688,
          -2335.199,
          -2371.612,
          -2407.928,
          -2444.143,
          -2480.257,
          -2516.2670000000003,
          -2552.172,
          -2587.97,
          -2623.659,
          -2659.237,
          -2694.703,
          -2730.054,
          -2765.289,
          -2800.407,
          -2835.4040000000005,
          -2870.28,
          -2905.031,
          -2939.657,
          -2974.156,
          -3008.525,
          -3042.762,
          -3076.865,
          -3110.833,
          -3144.664,
          -3178.3540000000003,
          -3211.902,
          -3245.3070000000002,
          -3278.565,
          -3311.675,
          -3344.635,
          -3377.441,
          -3410.093,
          -3442.587,
          -3474.922,
          -3507.095,
          -3539.1040000000003,
          -3570.946,
          -3602.62,
          -3634.1209999999996,
          -3665.449,
          -3696.6009999999997,
          -3727.573,
          -3758.364,
          -3788.9709999999995,
          -3819.3909999999996,
          -3849.6209999999996,
          -3879.659,
          -3909.5029999999997,
          -3939.1479999999997,
          -3968.594,
          -3997.835,
          -4026.8709999999996,
          -4055.697,
          -4084.31,
          -4112.709,
          -4140.889,
          -4168.847,
          -4196.581,
          -4224.085999999999,
          -4251.36,
          -4278.4,
          -4305.201,
          -4331.7609999999995,
          -4358.076,
          -4384.143,
          -4409.957,
          -4435.515,
          -4460.813,
          -4485.848,
          -4510.615,
          -4535.111,
          -4559.332,
          -4583.273,
          -4606.93,
          -4630.299,
          -4653.376,
          -4676.156,
          -4698.635,
          -4720.808,
          -4742.67,
          -4764.217000000001,
          -4785.444,
          -4806.345,
          -4826.917,
          -4847.152,
          -4867.048,
          -4886.597,
          -4905.794,
          -4924.634,
          -4943.111,
          -4961.219,
          -4978.9529999999995,
          -4996.305,
          -5013.27,
          -5029.842000000001,
          -5046.013,
          -5061.777,
          -5077.128,
          -5092.058,
          -5106.56,
          -5120.627,
          -5134.251,
          -5147.425,
          -5160.14,
          -5172.388,
          -5184.162,
          -5195.4529999999995,
          -5206.252,
          -5216.55,
          -5226.338,
          -5235.606,
          -5244.345,
          -5252.545,
          -5260.196999999999,
          -5267.2880000000005,
          -5273.809,
          -5279.749,
          -5285.096,
          -5289.838000000001,
          -5293.965,
          -5297.4619999999995,
          -5300.318,
          -5302.519,
          -5304.053000000001,
          -5304.905,
          -5305.06,
          -5304.505,
          -5303.224,
          -5301.201,
          -5298.42,
          -5294.8640000000005,
          -5290.517,
          -5285.361,
          -5279.3769999999995,
          -5272.545999999999,
          -5264.849,
          -5256.265,
          -5246.774,
          -5236.353,
          -5224.981,
          -5212.634,
          -5199.288,
          -5184.919,
          -5169.5,
          -5153.004,
          -5135.404,
          -5116.6720000000005,
          -5096.776,
          -5075.687,
          -5053.372,
          -5029.795999999999,
          -5004.927,
          -4978.727,
          -4951.157999999999,
          -4922.182,
          -4891.758,
          -4859.843,
          -4826.394,
          -4791.363,
          -4754.704000000001,
          -4716.366,
          -4676.2970000000005,
          -4634.443,
          -4590.748,
          -4545.152,
          -4497.593,
          -4448.009,
          -4396.331,
          -4342.491,
          -4286.416,
          -4228.029,
          -4167.253,
          -4104.005999999999,
          -4038.203,
          -3969.755,
          -3898.571,
          -3824.5570000000002,
          -3747.614,
          -3667.643,
          -3584.54,
          -3498.198,
          -3408.511,
          -3315.37,
          -3218.665,
          -3118.2870000000003,
          -3014.127,
          -2906.0820000000003,
          -2794.05,
          -2677.938,
          -2557.663,
          -2433.153,
          -2304.35,
          -2171.221,
          -2033.751,
          -1891.9589999999998,
          -1745.895,
          -1595.652,
          -1441.365,
          -1283.223,
          -1121.4669999999999,
          -956.4010000000001,
          -788.3839999999999,
          -617.84,
          -445.24800000000005,
          -271.14099999999996,
          -96.09299999999999,
          79.28699999999999,
          254.37099999999998,
          428.527,
          601.133,
          771.595,
          939.3530000000001,
          1103.902,
          1264.792,
          1421.6370000000002,
          1574.116,
          1721.973,
          1865.017,
          2003.1129999999998,
          2136.18,
          2264.1820000000002,
          2387.125,
          2505.048,
          2618.021,
          2726.132,
          2829.491,
          2928.218,
          3022.445,
          3112.31,
          3197.9559999999997,
          3279.526,
          3357.164,
          3431.014,
          3501.217,
          3567.909,
          3631.2259999999997,
          3691.297,
          3748.248,
          3802.2009999999996,
          3853.2709999999997,
          3901.571,
          3947.296,
          3990.283,
          4030.895,
          4069.138,
          4105.102,
          4138.871,
          4170.528,
          4200.15,
          4227.812,
          4253.583,
          4277.532999999999,
          4299.725,
          4320.221,
          4339.08,
          4356.358,
          4372.109,
          4386.384,
          4399.232,
          4410.7,
          4420.833,
          4429.674,
          4437.264,
          4443.642,
          4448.846,
          4452.912,
          4455.876,
          4457.769,
          4458.625,
          4458.474,
          4457.345,
          4455.267,
          4452.266,
          4448.37,
          4443.603,
          4437.99,
          4431.554,
          4424.317,
          4416.302,
          4407.528,
          4398.017,
          4387.788,
          4376.859,
          4365.249,
          4352.975,
          4340.055,
          4326.504,
          4312.338,
          4297.5740000000005,
          4282.224,
          4266.305,
          4249.83,
          4232.812,
          4215.265,
          4197.2,
          4178.630999999999,
          4159.569,
          4140.026,
          4120.013,
          4099.541,
          4078.62,
          4057.261,
          4035.474,
          4013.268,
          3990.653,
          3967.638,
          3944.232,
          3920.4440000000004,
          3896.281,
          3871.7529999999997,
          3846.868,
          3821.632,
          3796.054,
          3770.1420000000003,
          3743.902,
          3717.341,
          3690.467,
          3663.285,
          3635.804,
          3608.028,
          3579.9640000000004,
          3551.619,
          3522.998,
          3494.1079999999997,
          3464.953,
          3435.539,
          3405.8720000000003,
          3375.958,
          3345.8,
          3315.405,
          3284.778,
          3253.922,
          3222.844,
          3191.547,
          3160.0370000000003,
          3128.317,
          3096.393,
          3064.2670000000003,
          3031.946,
          2999.4320000000002,
          2966.7309999999998,
          2933.845,
          2900.778,
          2867.5359999999996,
          2834.12,
          2800.5359999999996,
          2766.7859999999996,
          2732.875,
          2698.805,
          2664.58,
          2630.204,
          2595.68,
          2561.01,
          2526.199,
          2491.249,
          2456.1639999999998,
          2420.947,
          2385.599,
          2350.126,
          2314.529,
          2278.811,
          2242.975,
          2207.024,
          2170.9610000000002,
          2134.7870000000003,
          2098.507,
          2062.123,
          2025.636,
          1989.05,
          1952.3670000000002,
          1915.59,
          1878.721,
          1841.763,
          1804.717,
          1767.586,
          1730.3729999999998,
          1693.08,
          1655.7079999999999,
          1618.261,
          1580.741,
          1543.148,
          1505.487,
          1467.759,
          1429.965,
          1392.109,
          1354.191,
          1316.215,
          1278.182,
          1240.094,
          1201.953,
          1163.761,
          1125.52,
          1087.232,
          1048.899,
          1010.5219999999999,
          972.1039999999999,
          933.6460000000001,
          895.15,
          856.618,
          818.052,
          779.454,
          740.824,
          702.166,
          663.48,
          624.769,
          586.034,
          547.2769999999999,
          508.499,
          469.70300000000003,
          430.889,
          392.06,
          353.218,
          314.363,
          275.497,
          236.623,
          197.74099999999999,
          158.85299999999998,
          119.961,
          81.067,
          42.17100000000001,
          3.2760000000000002,
          -35.617,
          -74.506,
          -113.39,
          -152.267,
          -191.136,
          -229.99599999999998,
          -268.844,
          -307.67900000000003,
          -346.5,
          -385.305,
          -424.093,
          -462.86199999999997,
          -501.61,
          -540.337,
          -579.04,
          -617.719,
          -656.3710000000001,
          -694.9960000000001,
          -733.591,
          -772.155,
          -810.687,
          -849.186,
          -887.6489999999999,
          -926.076,
          -964.4639999999999,
          -1002.813,
          -1041.12,
          -1079.385,
          -1117.606,
          -1155.781,
          -1193.9089999999999,
          -1231.988,
          -1270.018,
          -1307.996,
          -1345.92,
          -1383.7910000000002,
          -1421.605,
          -1459.361,
          -1497.059,
          -1534.695,
          -1572.27,
          -1609.781,
          -1647.227,
          -1684.605,
          -1721.9160000000002,
          -1759.1570000000002,
          -1796.326,
          -1833.4229999999998,
          -1870.444,
          -1907.39,
          -1944.2579999999998,
          -1981.047,
          -2017.754,
          -2054.38,
          -2090.9210000000003,
          -2127.376,
          -2163.744,
          -2200.0229999999997,
          -2236.2110000000002,
          -2272.3070000000002,
          -2308.308,
          -2344.214,
          -2380.0229999999997,
          -2415.732,
          -2451.34,
          -2486.846,
          -2522.2470000000003,
          -2557.542,
          -2592.729,
          -2627.8070000000002,
          -2662.772,
          -2697.625,
          -2732.362,
          -2766.982,
          -2801.4829999999997,
          -2835.863,
          -2870.1209999999996,
          -2904.2529999999997,
          -2938.259,
          -2972.137,
          -3005.883,
          -3039.498,
          -3072.9770000000003,
          -3106.32,
          -3139.5240000000003,
          -3172.587,
          -3205.508,
          -3238.283,
          -3270.9109999999996,
          -3303.389,
          -3335.716,
          -3367.889,
          -3399.906,
          -3431.764,
          -3463.462,
          -3494.9959999999996,
          -3526.366,
          -3557.567,
          -3588.598,
          -3619.4559999999997,
          -3650.138,
          -3680.643,
          -3710.968,
          -3741.11,
          -3771.066,
          -3800.833,
          -3830.41,
          -3859.7929999999997,
          -3888.9790000000003,
          -3917.966,
          -3946.7509999999997,
          -3975.3309999999997,
          -4003.702,
          -4031.863,
          -4059.809,
          -4087.538,
          -4115.0470000000005,
          -4142.331,
          -4169.39,
          -4196.218,
          -4222.812,
          -4249.17,
          -4275.287,
          -4301.16,
          -4326.786,
          -4352.161,
          -4377.281,
          -4402.142,
          -4426.741,
          -4451.073,
          -4475.1359999999995,
          -4498.924,
          -4522.433,
          -4545.66,
          -4568.599,
          -4591.248,
          -4613.6,
          -4635.653,
          -4657.4,
          -4678.838,
          -4699.962,
          -4720.766,
          -4741.246,
          -4761.396,
          -4781.212,
          -4800.688,
          -4819.818,
          -4838.598,
          -4857.021,
          -4875.082,
          -4892.774,
          -4910.093,
          -4927.031,
          -4943.582,
          -4959.74,
          -4975.498,
          -4990.85,
          -5005.788,
          -5020.306,
          -5034.396,
          -5048.0509999999995,
          -5061.264,
          -5074.026,
          -5086.329000000001,
          -5098.166,
          -5109.528,
          -5120.406,
          -5130.792,
          -5140.6759999999995,
          -5150.05,
          -5158.904,
          -5167.228,
          -5175.012,
          -5182.246,
          -5188.919,
          -5195.02,
          -5200.538,
          -5205.462,
          -5209.78,
          -5213.48,
          -5216.549,
          -5218.974,
          -5220.742,
          -5221.84,
          -5222.253,
          -5221.967000000001,
          -5220.965999999999,
          -5219.236,
          -5216.7609999999995,
          -5213.524,
          -5209.5070000000005,
          -5204.695,
          -5199.068,
          -5192.608,
          -5185.295999999999,
          -5177.111,
          -5168.034000000001,
          -5158.042,
          -5147.1140000000005,
          -5135.226,
          -5122.356,
          -5108.478,
          -5093.567,
          -5077.596,
          -5060.539000000001,
          -5042.367,
          -5023.05,
          -5002.558,
          -4980.859,
          -4957.92,
          -4933.707,
          -4908.184,
          -4881.314,
          -4853.058,
          -4823.376,
          -4792.226,
          -4759.565,
          -4725.348,
          -4689.526,
          -4652.052,
          -4612.873,
          -4571.936,
          -4529.185,
          -4484.562,
          -4438.005999999999,
          -4389.455,
          -4338.842000000001,
          -4286.098,
          -4231.152,
          -4173.929,
          -4114.352,
          -4052.341,
          -3987.81,
          -3920.673,
          -3850.84,
          -3778.216,
          -3702.7070000000003,
          -3624.211,
          -3542.6279999999997,
          -3457.8520000000003,
          -3369.777,
          -3278.296,
          -3183.298,
          -3084.677,
          -2982.325,
          -2876.138,
          -2766.015,
          -2651.865,
          -2533.6020000000003,
          -2411.155,
          -2284.467,
          -2153.5,
          -2018.24,
          -1878.701,
          -1734.932,
          -1587.02,
          -1435.096,
          -1279.343,
          -1119.995,
          -957.347,
          -791.752,
          -623.624,
          -453.43199999999996,
          -281.698,
          -108.988,
          64.09899999999999,
          236.94400000000002,
          408.925,
          579.4259999999999,
          747.8580000000001,
          913.669,
          1076.354,
          1235.4669999999999,
          1390.6229999999998,
          1541.503,
          1687.848,
          1829.4660000000001,
          1966.22,
          2098.026,
          2224.848,
          2346.687,
          2463.58,
          2575.592,
          2682.809,
          2785.3379999999997,
          2883.296,
          2976.812,
          3066.0229999999997,
          3151.065,
          3232.0820000000003,
          3309.2140000000004,
          3382.603,
          3452.388,
          3518.703,
          3581.6809999999996,
          3641.4509999999996,
          3698.136,
          3751.8559999999998,
          3802.7259999999997,
          3850.8559999999998,
          3896.3509999999997,
          3939.313,
          3979.8390000000004,
          4018.0209999999997,
          4053.947,
          4087.703,
          4119.3679999999995,
          4149.021,
          4176.732,
          4202.573,
          4226.611,
          4248.909000000001,
          4269.529,
          4288.528,
          4305.960999999999,
          4321.883,
          4336.344,
          4349.392,
          4361.0740000000005,
          4371.433,
          4380.513,
          4388.355,
          4394.996,
          4400.474,
          4404.826,
          4408.085,
          4410.284000000001,
          4411.456,
          4411.63,
          4410.835,
          4409.1,
          4406.451,
          4402.914000000001,
          4398.515,
          4393.277,
          4387.223,
          4380.376,
          4372.7570000000005,
          4364.387,
          4355.286,
          4345.473,
          4334.967000000001,
          4323.785,
          4311.945,
          4299.464,
          4286.357,
          4272.642,
          4258.332,
          4243.443,
          4227.988,
          4211.982,
          4195.437,
          4178.367,
          4160.785,
          4142.702,
          4124.129,
          4105.08,
          4085.5640000000003,
          4065.592,
          4045.176,
          4024.324,
          4003.048,
          3981.355,
          3959.257,
          3936.762,
          3913.8779999999997,
          3890.615,
          3866.98,
          3842.9829999999997,
          3818.63,
          3793.93,
          3768.89,
          3743.5170000000003,
          3717.8190000000004,
          3691.802,
          3665.474,
          3638.84,
          3611.909,
          3584.685,
          3557.175,
          3529.385,
          3501.321,
          3472.988,
          3444.393,
          3415.5409999999997,
          3386.437,
          3357.086,
          3327.495,
          3297.667,
          3267.607,
          3237.321,
          3206.812,
          3176.087,
          3145.1490000000003,
          3114.002,
          3082.652,
          3051.1009999999997,
          3019.3559999999998,
          2987.4179999999997,
          2955.2940000000003,
          2922.986,
          2890.498,
          2857.8340000000003,
          2824.9990000000003,
          2791.995,
          2758.8259999999996,
          2725.495,
          2692.007,
          2658.364,
          2624.57,
          2590.629,
          2556.542,
          2522.314,
          2487.948,
          2453.447,
          2418.813,
          2384.05,
          2349.16,
          2314.147,
          2279.013,
          2243.762,
          2208.395,
          2172.916,
          2137.326,
          2101.63,
          2065.8289999999997,
          2029.9260000000002,
          1993.924,
          1957.8239999999998,
          1921.63,
          1885.344,
          1848.9679999999998,
          1812.504,
          1775.955,
          1739.3239999999998,
          1702.612,
          1665.8210000000001,
          1628.954,
          1592.013,
          1555,
          1517.918,
          1480.767,
          1443.5520000000001,
          1406.2720000000002,
          1368.932,
          1331.531,
          1294.0739999999998,
          1256.56,
          1218.993,
          1181.375,
          1143.7060000000001,
          1105.99,
          1068.228,
          1030.421,
          992.572,
          954.683,
          916.755,
          878.79,
          840.79,
          802.757,
          764.691,
          726.596,
          688.4730000000001,
          650.323,
          612.148,
          573.951,
          535.731,
          497.49199999999996,
          459.235,
          420.961,
          382.67199999999997,
          344.37,
          306.056,
          267.731,
          229.399,
          191.05900000000003,
          152.714,
          114.365,
          76.014,
          37.662,
          -0.69,
          -39.038000000000004,
          -77.384,
          -115.723,
          -154.056,
          -192.38099999999997,
          -230.695,
          -268.999,
          -307.289,
          -345.565,
          -383.825,
          -422.06800000000004,
          -460.292,
          -498.496,
          -536.678,
          -574.837,
          -612.971,
          -651.0790000000001,
          -689.159,
          -727.21,
          -765.2310000000001,
          -803.22,
          -841.175,
          -879.095,
          -916.9789999999999,
          -954.825,
          -992.6310000000001,
          -1030.397,
          -1068.12,
          -1105.8,
          -1143.434,
          -1181.022,
          -1218.562,
          -1256.052,
          -1293.49,
          -1330.8770000000002,
          -1368.2089999999998,
          -1405.485,
          -1442.705,
          -1479.866,
          -1516.967,
          -1554.006,
          -1590.9820000000002,
          -1627.894,
          -1664.739,
          -1701.517,
          -1738.226,
          -1774.8629999999998,
          -1811.4289999999999,
          -1847.921,
          -1884.3370000000002,
          -1920.6760000000002,
          -1956.9370000000001,
          -1993.118,
          -2029.2160000000001,
          -2065.232,
          -2101.1620000000003,
          -2137.006,
          -2172.762,
          -2208.428,
          -2244.002,
          -2279.4829999999997,
          -2314.869,
          -2350.159,
          -2385.35,
          -2420.4410000000003,
          -2455.431,
          -2490.317,
          -2525.098,
          -2559.772,
          -2594.337,
          -2628.7909999999997,
          -2663.133,
          -2697.361,
          -2731.473,
          -2765.467,
          -2799.341,
          -2833.093,
          -2866.722,
          -2900.225,
          -2933.6009999999997,
          -2966.847,
          -2999.961,
          -3032.9429999999998,
          -3065.788,
          -3098.4959999999996,
          -3131.0640000000003,
          -3163.491,
          -3195.7729999999997,
          -3227.909,
          -3259.8979999999997,
          -3291.735,
          -3323.42,
          -3354.95,
          -3386.323,
          -3417.5370000000003,
          -3448.5879999999997,
          -3479.4759999999997,
          -3510.196,
          -3540.7470000000003,
          -3571.1279999999997,
          -3601.3340000000003,
          -3631.363,
          -3661.2140000000004,
          -3690.882,
          -3720.367,
          -3749.664,
          -3778.772,
          -3807.688,
          -3836.408,
          -3864.929,
          -3893.25,
          -3921.368,
          -3949.278,
          -3976.978,
          -4004.466,
          -4031.738,
          -4058.79,
          -4085.6209999999996,
          -4112.226,
          -4138.602,
          -4164.746,
          -4190.654,
          -4216.323,
          -4241.75,
          -4266.93,
          -4291.861,
          -4316.538,
          -4340.958,
          -4365.116,
          -4389.01,
          -4412.634,
          -4435.986,
          -4459.06,
          -4481.853,
          -4504.36,
          -4526.577,
          -4548.499,
          -4570.122,
          -4591.442,
          -4612.4529999999995,
          -4633.15,
          -4653.53,
          -4673.585999999999,
          -4693.314,
          -4712.708,
          -4731.764,
          -4750.475,
          -4768.835999999999,
          -4786.840999999999,
          -4804.485,
          -4821.762,
          -4838.665,
          -4855.189,
          -4871.327,
          -4887.072,
          -4902.418,
          -4917.358,
          -4931.885,
          -4945.9929999999995,
          -4959.673,
          -4972.918,
          -4985.721,
          -4998.073,
          -5009.968,
          -5021.396,
          -5032.348,
          -5042.818,
          -5052.795,
          -5062.27,
          -5071.234,
          -5079.677,
          -5087.590999999999,
          -5094.963,
          -5101.785,
          -5108.045,
          -5113.732,
          -5118.835,
          -5123.343,
          -5127.2429999999995,
          -5130.523,
          -5133.17,
          -5135.1720000000005,
          -5136.515,
          -5137.184,
          -5137.167,
          -5136.447,
          -5135.0109999999995,
          -5132.840999999999,
          -5129.923,
          -5126.2390000000005,
          -5121.772,
          -5116.504,
          -5110.417,
          -5103.4929999999995,
          -5095.71,
          -5087.049,
          -5077.49,
          -5067.009,
          -5055.585999999999,
          -5043.195,
          -5029.814,
          -5015.417,
          -4999.977,
          -4983.469,
          -4965.8640000000005,
          -4947.133,
          -4927.247,
          -4906.1720000000005,
          -4883.878,
          -4860.331,
          -4835.494000000001,
          -4809.333,
          -4781.808,
          -4752.88,
          -4722.508,
          -4690.649,
          -4657.258,
          -4622.288,
          -4585.692,
          -4547.418,
          -4507.413,
          -4465.624,
          -4421.992,
          -4376.457,
          -4328.958,
          -4279.429,
          -4227.802,
          -4174.008,
          -4117.971,
          -4059.617,
          -3998.864,
          -3935.631,
          -3869.8309999999997,
          -3801.3759999999997,
          -3730.172,
          -3656.125,
          -3579.136,
          -3499.105,
          -3415.928,
          -3329.4990000000003,
          -3239.7140000000004,
          -3146.462,
          -3049.637,
          -2949.133,
          -2844.847,
          -2736.678,
          -2624.535,
          -2508.3320000000003,
          -2387.998,
          -2263.475,
          -2134.723,
          -2001.727,
          -1864.499,
          -1723.0839999999998,
          -1577.5639999999999,
          -1428.067,
          -1274.767,
          -1117.895,
          -957.735,
          -794.633,
          -628.993,
          -461.274,
          -291.99,
          -121.695,
          49.023,
          219.553,
          389.28,
          557.5980000000001,
          723.924,
          887.71,
          1048.4569999999999,
          1205.719,
          1359.115,
          1508.3239999999998,
          1653.089,
          1793.215,
          1928.5639999999999,
          2059.049,
          2184.631,
          2305.3089999999997,
          2421.117,
          2532.116,
          2638.39,
          2740.042,
          2837.1859999999997,
          2929.948,
          3018.462,
          3102.862,
          3183.2870000000003,
          3259.8779999999997,
          3332.7729999999997,
          3402.107,
          3468.015,
          3530.627,
          3590.0679999999998,
          3646.461,
          3699.9240000000004,
          3750.57,
          3798.508,
          3843.841,
          3886.671,
          3927.092,
          3965.195,
          4001.0679999999998,
          4034.795,
          4066.454,
          4096.123,
          4123.871,
          4149.77,
          4173.8859999999995,
          4196.28,
          4217.014,
          4236.144,
          4253.726,
          4269.812,
          4284.452,
          4297.694,
          4309.584,
          4320.166,
          4329.481,
          4337.57,
          4344.471,
          4350.221,
          4354.856,
          4358.41,
          4360.914000000001,
          4362.401,
          4362.899,
          4362.439,
          4361.0470000000005,
          4358.751,
          4355.576,
          4351.545999999999,
          4346.685,
          4341.017,
          4334.563,
          4327.344,
          4319.380999999999,
          4310.694,
          4301.3009999999995,
          4291.222,
          4280.473,
          4269.072,
          4257.036,
          4244.38,
          4231.12,
          4217.272,
          4202.848,
          4187.865,
          4172.335,
          4156.271,
          4139.686,
          4122.593,
          4105.004,
          4086.929,
          4068.382,
          4049.3709999999996,
          4029.909,
          4010.006,
          3989.671,
          3968.914,
          3947.745,
          3926.173,
          3904.2070000000003,
          3881.8559999999998,
          3859.1279999999997,
          3836.032,
          3812.575,
          3788.7659999999996,
          3764.612,
          3740.12,
          3715.298,
          3690.153,
          3664.692,
          3638.921,
          3612.848,
          3586.478,
          3559.817,
          3532.873,
          3505.65,
          3478.155,
          3450.3940000000002,
          3422.3709999999996,
          3394.093,
          3365.5640000000003,
          3336.7909999999997,
          3307.777,
          3278.528,
          3249.05,
          3219.345,
          3189.421,
          3159.28,
          3128.927,
          3098.367,
          3067.6040000000003,
          3036.643,
          3005.486,
          2974.14,
          2942.6059999999998,
          2910.89,
          2878.995,
          2846.9240000000004,
          2814.683,
          2782.2729999999997,
          2749.699,
          2716.965,
          2684.073,
          2651.027,
          2617.83,
          2584.486,
          2550.9970000000003,
          2517.367,
          2483.599,
          2449.696,
          2415.661,
          2381.4970000000003,
          2347.2070000000003,
          2312.7929999999997,
          2278.259,
          2243.607,
          2208.84,
          2173.96,
          2138.97,
          2103.873,
          2068.672,
          2033.368,
          1997.965,
          1962.464,
          1926.869,
          1891.181,
          1855.4029999999998,
          1819.5379999999998,
          1783.586,
          1747.5520000000001,
          1711.4370000000001,
          1675.243,
          1638.9720000000002,
          1602.6270000000002,
          1566.21,
          1529.7220000000002,
          1493.1660000000002,
          1456.5439999999999,
          1419.858,
          1383.11,
          1346.3020000000001,
          1309.4360000000001,
          1272.513,
          1235.537,
          1198.508,
          1161.428,
          1124.3,
          1087.125,
          1049.906,
          1012.643,
          975.3380000000001,
          937.995,
          900.613,
          863.196,
          825.7439999999999,
          788.2589999999999,
          750.7439999999999,
          713.199,
          675.627,
          638.03,
          600.408,
          562.763,
          525.0980000000001,
          487.413,
          449.71,
          411.99199999999996,
          374.259,
          336.51300000000003,
          298.756,
          260.98900000000003,
          223.21400000000003,
          185.433,
          147.64600000000002,
          109.855,
          72.063,
          34.27,
          -3.522,
          -41.312,
          -79.097,
          -116.87700000000001,
          -154.65,
          -192.415,
          -230.17,
          -267.913,
          -305.643,
          -343.36,
          -381.06,
          -418.74300000000005,
          -456.407,
          -494.051,
          -531.674,
          -569.273,
          -606.8480000000001,
          -644.3969999999999,
          -681.918,
          -719.4110000000001,
          -756.873,
          -794.304,
          -831.701,
          -869.064,
          -906.3910000000001,
          -943.68,
          -980.93,
          -1018.14,
          -1055.307,
          -1092.432,
          -1129.512,
          -1166.545,
          -1203.531,
          -1240.468,
          -1277.354,
          -1314.1879999999999,
          -1350.9679999999998,
          -1387.694,
          -1424.3629999999998,
          -1460.974,
          -1497.526,
          -1534.016,
          -1570.445,
          -1606.809,
          -1643.108,
          -1679.34,
          -1715.503,
          -1751.5970000000002,
          -1787.618,
          -1823.567,
          -1859.441,
          -1895.239,
          -1930.96,
          -1966.601,
          -2002.161,
          -2037.638,
          -2073.031,
          -2108.339,
          -2143.56,
          -2178.6910000000003,
          -2213.732,
          -2248.68,
          -2283.535,
          -2318.294,
          -2352.956,
          -2387.518,
          -2421.98,
          -2456.34,
          -2490.595,
          -2524.745,
          -2558.7870000000003,
          -2592.719,
          -2626.54,
          -2660.248,
          -2693.84,
          -2727.316,
          -2760.6740000000004,
          -2793.9109999999996,
          -2827.025,
          -2860.015,
          -2892.8779999999997,
          -2925.614,
          -2958.219,
          -2990.691,
          -3023.03,
          -3055.232,
          -3087.295,
          -3119.218,
          -3150.9990000000003,
          -3182.634,
          -3214.123,
          -3245.462,
          -3276.65,
          -3307.685,
          -3338.5640000000003,
          -3369.284,
          -3399.844,
          -3430.242,
          -3460.474,
          -3490.5370000000003,
          -3520.4309999999996,
          -3550.152,
          -3579.699,
          -3609.0679999999998,
          -3638.256,
          -3667.261,
          -3696.0809999999997,
          -3724.712,
          -3753.153,
          -3781.4,
          -3809.45,
          -3837.3,
          -3864.948,
          -3892.3909999999996,
          -3919.6259999999997,
          -3946.6490000000003,
          -3973.4570000000003,
          -4000.048,
          -4026.4179999999997,
          -4052.5640000000003,
          -4078.4829999999997,
          -4104.170999999999,
          -4129.625,
          -4154.842000000001,
          -4179.817,
          -4204.5470000000005,
          -4229.03,
          -4253.26,
          -4277.234,
          -4300.948,
          -4324.399,
          -4347.583,
          -4370.494000000001,
          -4393.13,
          -4415.486,
          -4437.558,
          -4459.34,
          -4480.83,
          -4502.022,
          -4522.911,
          -4543.4929999999995,
          -4563.764,
          -4583.717000000001,
          -4603.348,
          -4622.653,
          -4641.625,
          -4660.259,
          -4678.55,
          -4696.4929999999995,
          -4714.081,
          -4731.308,
          -4748.169,
          -4764.657999999999,
          -4780.769,
          -4796.494000000001,
          -4811.8279999999995,
          -4826.763,
          -4841.293,
          -4855.412,
          -4869.111,
          -4882.383,
          -4895.221,
          -4907.6179999999995,
          -4919.564,
          -4931.053,
          -4942.076,
          -4952.624,
          -4962.689,
          -4972.2609999999995,
          -4981.332,
          -4989.891,
          -4997.93,
          -5005.438,
          -5012.406,
          -5018.821,
          -5024.675,
          -5029.955,
          -5034.65,
          -5038.749,
          -5042.238,
          -5045.107,
          -5047.340999999999,
          -5048.928,
          -5049.854,
          -5050.106,
          -5049.667,
          -5048.525,
          -5046.662,
          -5044.064,
          -5040.713,
          -5036.594,
          -5031.687,
          -5025.976,
          -5019.442,
          -5012.065,
          -5003.825,
          -4994.702,
          -4984.674,
          -4973.719,
          -4961.814,
          -4948.935,
          -4935.057,
          -4920.156,
          -4904.204000000001,
          -4887.174,
          -4869.037,
          -4849.764,
          -4829.3240000000005,
          -4807.684,
          -4784.813,
          -4760.674,
          -4735.232,
          -4708.45,
          -4680.288,
          -4650.707,
          -4619.663,
          -4587.113,
          -4553.01,
          -4517.307,
          -4479.955,
          -4440.901,
          -4400.090999999999,
          -4357.468,
          -4312.974,
          -4266.548,
          -4218.124,
          -4167.637,
          -4115.017,
          -4060.191,
          -4003.085,
          -3943.618,
          -3881.71,
          -3817.276,
          -3750.228,
          -3680.475,
          -3607.923,
          -3532.475,
          -3454.031,
          -3372.489,
          -3287.745,
          -3199.6929999999998,
          -3108.2290000000003,
          -3013.243,
          -2914.631,
          -2812.2909999999997,
          -2706.123,
          -2596.036,
          -2481.945,
          -2363.777,
          -2241.474,
          -2114.995,
          -1984.3220000000001,
          -1849.4660000000001,
          -1710.467,
          -1567.404,
          -1420.4,
          -1269.624,
          -1115.297,
          -957.697,
          -797.1619999999999,
          -634.085,
          -468.917,
          -302.159,
          -134.356,
          33.914,
          202.05,
          369.44699999999995,
          535.506,
          699.65,
          861.337,
          1020.072,
          1175.413,
          1326.979,
          1474.451,
          1617.57,
          1756.142,
          1890.025,
          2019.132,
          2143.419,
          2262.883,
          2377.555,
          2487.492,
          2592.777,
          2693.507,
          2789.795,
          2881.764,
          2969.5409999999997,
          3053.263,
          3133.063,
          3209.08,
          3281.449,
          3350.304,
          3415.776,
          3477.994,
          3537.0820000000003,
          3593.159,
          3646.343,
          3696.744,
          3744.469,
          3789.816,
          3832.301,
          3872.6,
          3910.6090000000004,
          3946.414,
          3980.098,
          4011.738,
          4041.4109999999996,
          4069.1859999999997,
          4095.132,
          4119.315,
          4141.7970000000005,
          4162.6359999999995,
          4181.89,
          4199.6140000000005,
          4215.857,
          4230.670999999999,
          4244.102,
          4256.196,
          4266.996,
          4276.543,
          4284.877,
          4292.036,
          4298.056,
          4302.973,
          4306.82,
          4309.629,
          4311.43,
          4312.254,
          4312.129,
          4311.083,
          4309.14,
          4306.3279999999995,
          4302.67,
          4298.19,
          4292.91,
          4286.852,
          4280.037,
          4272.485,
          4264.215999999999,
          4255.249,
          4245.601,
          4235.291,
          4224.334,
          4212.749,
          4200.549,
          4187.752,
          4174.371,
          4160.420999999999,
          4145.916,
          4130.869000000001,
          4115.293,
          4099.202,
          4082.6059999999998,
          4065.518,
          4047.95,
          4029.913,
          4011.417,
          3992.473,
          3973.092,
          3953.283,
          3933.055,
          3912.4190000000003,
          3891.384,
          3869.9570000000003,
          3848.1490000000003,
          3825.967,
          3803.4190000000003,
          3780.514,
          3757.259,
          3733.6620000000003,
          3709.73,
          3685.47,
          3660.89,
          3635.995,
          3610.7940000000003,
          3585.292,
          3559.495,
          3533.41,
          3507.0440000000003,
          3480.401,
          3453.487,
          3426.309,
          3398.8709999999996,
          3371.179,
          3343.239,
          3315.055,
          3286.633,
          3257.9770000000003,
          3229.093,
          3199.9840000000004,
          3170.656,
          3141.113,
          3111.36,
          3081.3990000000003,
          3051.238,
          3020.88,
          2990.327,
          2959.5840000000003,
          2928.656,
          2897.546,
          2866.257,
          2834.795,
          2803.1620000000003,
          2771.361,
          2739.397,
          2707.2729999999997,
          2674.991,
          2642.5570000000002,
          2609.972,
          2577.24,
          2544.364,
          2511.347,
          2478.1929999999998,
          2444.904,
          2411.4829999999997,
          2377.933,
          2344.257,
          2310.458,
          2276.5389999999998,
          2242.501,
          2208.349,
          2174.084,
          2139.71,
          2105.228,
          2070.6420000000003,
          2035.953,
          2001.164,
          1966.279,
          1931.2979999999998,
          1896.224,
          1861.0610000000001,
          1825.809,
          1790.4720000000002,
          1755.0510000000002,
          1719.5479999999998,
          1683.967,
          1648.309,
          1612.576,
          1576.77,
          1540.8929999999998,
          1504.9479999999999,
          1468.9360000000001,
          1432.86,
          1396.721,
          1360.5220000000002,
          1324.263,
          1287.948,
          1251.578,
          1215.155,
          1178.681,
          1142.1580000000001,
          1105.587,
          1068.97,
          1032.31,
          995.607,
          958.8639999999999,
          922.0830000000001,
          885.2639999999999,
          848.4110000000001,
          811.5239999999999,
          774.605,
          737.6560000000001,
          700.678,
          663.674,
          626.645,
          589.592,
          552.5169999999999,
          515.4209999999999,
          478.30699999999996,
          441.176,
          404.029,
          366.869,
          329.695,
          292.51099999999997,
          255.317,
          218.11599999999999,
          180.908,
          143.695,
          106.479,
          69.26100000000001,
          32.043,
          -5.1739999999999995,
          -42.388999999999996,
          -79.59899999999999,
          -116.804,
          -154.002,
          -191.192,
          -228.37099999999998,
          -265.539,
          -302.694,
          -339.835,
          -376.961,
          -414.069,
          -451.158,
          -488.228,
          -525.276,
          -562.3009999999999,
          -599.302,
          -636.2769999999999,
          -673.225,
          -710.1439999999999,
          -747.033,
          -783.8910000000001,
          -820.716,
          -857.507,
          -894.262,
          -930.98,
          -967.66,
          -1004.299,
          -1040.897,
          -1077.453,
          -1113.964,
          -1150.4289999999999,
          -1186.847,
          -1223.2169999999999,
          -1259.536,
          -1295.8039999999999,
          -1332.02,
          -1368.18,
          -1404.285,
          -1440.3329999999999,
          -1476.3220000000001,
          -1512.251,
          -1548.118,
          -1583.922,
          -1619.661,
          -1655.3339999999998,
          -1690.9389999999999,
          -1726.475,
          -1761.94,
          -1797.3339999999998,
          -1832.6529999999998,
          -1867.8970000000002,
          -1903.0639999999999,
          -1938.1529999999998,
          -1973.162,
          -2008.089,
          -2042.933,
          -2077.692,
          -2112.365,
          -2146.95,
          -2181.445,
          -2215.85,
          -2250.161,
          -2284.3779999999997,
          -2318.498,
          -2352.521,
          -2386.444,
          -2420.265,
          -2453.984,
          -2487.598,
          -2521.105,
          -2554.504,
          -2587.7929999999997,
          -2620.97,
          -2654.033,
          -2686.98,
          -2719.81,
          -2752.5209999999997,
          -2785.111,
          -2817.577,
          -2849.9179999999997,
          -2882.133,
          -2914.218,
          -2946.173,
          -2977.994,
          -3009.68,
          -3041.23,
          -3072.64,
          -3103.909,
          -3135.034,
          -3166.014,
          -3196.847,
          -3227.5290000000005,
          -3258.059,
          -3288.4359999999997,
          -3318.655,
          -3348.715,
          -3378.612,
          -3408.347,
          -3437.9159999999997,
          -3467.316,
          -3496.545,
          -3525.6,
          -3554.4790000000003,
          -3583.18,
          -3611.699,
          -3640.034,
          -3668.1820000000002,
          -3696.1409999999996,
          -3723.907,
          -3751.4790000000003,
          -3778.8520000000003,
          -3806.025,
          -3832.994,
          -3859.756,
          -3886.309,
          -3912.6490000000003,
          -3938.772,
          -3964.677,
          -3990.3590000000004,
          -4015.815,
          -4041.0429999999997,
          -4066.0370000000003,
          -4090.796,
          -4115.316,
          -4139.592000000001,
          -4163.621,
          -4187.401,
          -4210.925,
          -4234.192,
          -4257.197,
          -4279.936,
          -4302.405,
          -4324.599,
          -4346.515,
          -4368.149,
          -4389.495,
          -4410.55,
          -4431.308,
          -4451.766,
          -4471.918,
          -4491.759,
          -4511.285,
          -4530.491,
          -4549.371,
          -4567.92,
          -4586.133,
          -4604.004,
          -4621.528,
          -4638.6990000000005,
          -4655.51,
          -4671.957,
          -4688.032,
          -4703.731,
          -4719.045,
          -4733.969,
          -4748.496,
          -4762.619000000001,
          -4776.33,
          -4789.624,
          -4802.492,
          -4814.9259999999995,
          -4826.92,
          -4838.464,
          -4849.552,
          -4860.174,
          -4870.322,
          -4879.987,
          -4889.159000000001,
          -4897.831,
          -4905.992,
          -4913.6320000000005,
          -4920.742,
          -4927.31,
          -4933.327,
          -4938.781,
          -4943.662,
          -4947.957,
          -4951.654,
          -4954.742,
          -4957.208,
          -4959.039000000001,
          -4960.221,
          -4960.74,
          -4960.583,
          -4959.734,
          -4958.179,
          -4955.902,
          -4952.8859999999995,
          -4949.115,
          -4944.572,
          -4939.2390000000005,
          -4933.098,
          -4926.129,
          -4918.313,
          -4909.63,
          -4900.058,
          -4889.576,
          -4878.161,
          -4865.79,
          -4852.438,
          -4838.08,
          -4822.691,
          -4806.2429999999995,
          -4788.708,
          -4770.056,
          -4750.259,
          -4729.282999999999,
          -4707.096,
          -4683.665,
          -4658.954000000001,
          -4632.925,
          -4605.542,
          -4576.763,
          -4546.548,
          -4514.852,
          -4481.63,
          -4446.837,
          -4410.4220000000005,
          -4372.334,
          -4332.52,
          -4290.925,
          -4247.491,
          -4202.157,
          -4154.86,
          -4105.534000000001,
          -4054.111,
          -4000.518,
          -3944.683,
          -3886.528,
          -3825.9709999999995,
          -3762.93,
          -3697.3179999999998,
          -3629.045,
          -3558.018,
          -3484.1420000000003,
          -3407.3190000000004,
          -3327.447,
          -3244.423,
          -3158.143,
          -3068.5029999999997,
          -2975.395,
          -2878.718,
          -2778.367,
          -2674.2459999999996,
          -2566.263,
          -2454.3320000000003,
          -2338.38,
          -2218.349,
          -2094.197,
          -1965.904,
          -1833.4779999999998,
          -1696.957,
          -1556.414,
          -1411.9660000000001,
          -1263.779,
          -1112.066,
          -957.097,
          -799.201,
          -638.761,
          -476.218,
          -312.062,
          -146.829,
          18.914,
          184.578,
          349.566,
          513.286,
          675.17,
          834.681,
          991.328,
          1144.673,
          1294.336,
          1439.9979999999998,
          1581.4029999999998,
          1718.3529999999998,
          1850.7060000000001,
          1978.371,
          2101.302,
          2219.495,
          2332.975,
          2441.799,
          2546.0429999999997,
          2645.802,
          2741.187,
          2832.317,
          2919.317,
          3002.3190000000004,
          3081.4559999999997,
          3156.863,
          3228.671,
          3297.014,
          3362.0190000000002,
          3423.813,
          3482.5190000000002,
          3538.2540000000004,
          3591.132,
          3641.264,
          3688.755,
          3733.7059999999997,
          3776.2140000000004,
          3816.3720000000003,
          3854.2690000000002,
          3889.989,
          3923.613,
          3955.219,
          3984.881,
          4012.6690000000003,
          4038.65,
          4062.889,
          4085.447,
          4106.3820000000005,
          4125.751,
          4143.607,
          4160.001,
          4174.982,
          4188.596,
          4200.888,
          4211.9,
          4221.675,
          4230.25,
          4237.663,
          4243.951,
          4249.147,
          4253.285,
          4256.397,
          4258.512,
          4259.661,
          4259.871,
          4259.17,
          4257.583,
          4255.135,
          4251.85,
          4247.752,
          4242.863,
          4237.204000000001,
          4230.795,
          4223.657999999999,
          4215.811,
          4207.273,
          4198.061,
          4188.194,
          4177.687,
          4166.557,
          4154.82,
          4142.49,
          4129.583,
          4116.113,
          4102.092000000001,
          4087.5359999999996,
          4072.4559999999997,
          4056.865,
          4040.7740000000003,
          4024.196,
          4007.1420000000003,
          3989.6240000000003,
          3971.651,
          3953.2340000000004,
          3934.383,
          3915.1090000000004,
          3895.42,
          3875.327,
          3854.837,
          3833.96,
          3812.704,
          3791.077,
          3769.0890000000004,
          3746.745,
          3724.055,
          3701.026,
          3677.664,
          3653.978,
          3629.973,
          3605.657,
          3581.0370000000003,
          3556.118,
          3530.906,
          3505.409,
          3479.632,
          3453.5809999999997,
          3427.261,
          3400.678,
          3373.8379999999997,
          3346.7459999999996,
          3319.407,
          3291.825,
          3264.007,
          3235.9570000000003,
          3207.68,
          3179.18,
          3150.462,
          3121.531,
          3092.39,
          3063.0440000000003,
          3033.498,
          3003.755,
          2973.8190000000004,
          2943.695,
          2913.386,
          2882.8959999999997,
          2852.2290000000003,
          2821.389,
          2790.3779999999997,
          2759.2009999999996,
          2727.861,
          2696.362,
          2664.7059999999997,
          2632.8979999999997,
          2600.94,
          2568.835,
          2536.587,
          2504.198,
          2471.673,
          2439.012,
          2406.221,
          2373.301,
          2340.255,
          2307.0860000000002,
          2273.7960000000003,
          2240.39,
          2206.868,
          2173.234,
          2139.49,
          2105.639,
          2071.683,
          2037.625,
          2003.4679999999998,
          1969.2120000000002,
          1934.862,
          1900.4189999999999,
          1865.886,
          1831.264,
          1796.556,
          1761.765,
          1726.892,
          1691.94,
          1656.91,
          1621.805,
          1586.6270000000002,
          1551.378,
          1516.06,
          1480.675,
          1445.225,
          1409.711,
          1374.1370000000002,
          1338.503,
          1302.812,
          1267.065,
          1231.265,
          1195.413,
          1159.511,
          1123.5610000000001,
          1087.5639999999999,
          1051.5230000000001,
          1015.438,
          979.313,
          943.148,
          906.946,
          870.707,
          834.434,
          798.1289999999999,
          761.7919999999999,
          725.426,
          689.0319999999999,
          652.612,
          616.168,
          579.7,
          543.211,
          506.702,
          470.175,
          433.63199999999995,
          397.07300000000004,
          360.5,
          323.916,
          287.32,
          250.71599999999998,
          214.104,
          177.486,
          140.863,
          104.23700000000001,
          67.609,
          30.982,
          -5.645,
          -42.269,
          -78.888,
          -115.50299999999999,
          -152.11,
          -188.708,
          -225.297,
          -261.874,
          -298.439,
          -334.99,
          -371.525,
          -408.042,
          -444.542,
          -481.022,
          -517.48,
          -553.9159999999999,
          -590.328,
          -626.714,
          -663.074,
          -699.405,
          -735.707,
          -771.9780000000001,
          -808.216,
          -844.42,
          -880.5889999999999,
          -916.722,
          -952.816,
          -988.8710000000001,
          -1024.885,
          -1060.857,
          -1096.785,
          -1132.6680000000001,
          -1168.504,
          -1204.2930000000001,
          -1240.032,
          -1275.72,
          -1311.3570000000002,
          -1346.9389999999999,
          -1382.4660000000001,
          -1417.9370000000001,
          -1453.35,
          -1488.703,
          -1523.996,
          -1559.226,
          -1594.392,
          -1629.493,
          -1664.527,
          -1699.4920000000002,
          -1734.388,
          -1769.213,
          -1803.964,
          -1838.642,
          -1873.243,
          -1907.767,
          -1942.2120000000002,
          -1976.576,
          -2010.859,
          -2045.057,
          -2079.1710000000003,
          -2113.197,
          -2147.135,
          -2180.9829999999997,
          -2214.739,
          -2248.402,
          -2281.969,
          -2315.44,
          -2348.813,
          -2382.085,
          -2415.255,
          -2448.322,
          -2481.284,
          -2514.138,
          -2546.884,
          -2579.519,
          -2612.042,
          -2644.45,
          -2676.742,
          -2708.917,
          -2740.9709999999995,
          -2772.9040000000005,
          -2804.7129999999997,
          -2836.3959999999997,
          -2867.952,
          -2899.3779999999997,
          -2930.673,
          -2961.8340000000003,
          -2992.86,
          -3023.748,
          -3054.4959999999996,
          -3085.1020000000003,
          -3115.5640000000003,
          -3145.88,
          -3176.048,
          -3206.065,
          -3235.929,
          -3265.638,
          -3295.19,
          -3324.5809999999997,
          -3353.8109999999997,
          -3382.8759999999997,
          -3411.7740000000003,
          -3440.502,
          -3469.059,
          -3497.441,
          -3525.6459999999997,
          -3553.671,
          -3581.514,
          -3609.172,
          -3636.643,
          -3663.923,
          -3691.009,
          -3717.8990000000003,
          -3744.591,
          -3771.08,
          -3797.364,
          -3823.44,
          -3849.3059999999996,
          -3874.9570000000003,
          -3900.39,
          -3925.603,
          -3950.592,
          -3975.3540000000003,
          -3999.885,
          -4024.1820000000002,
          -4048.241,
          -4072.059,
          -4095.632,
          -4118.956,
          -4142.028,
          -4164.844,
          -4187.399,
          -4209.69,
          -4231.713,
          -4253.464,
          -4274.938,
          -4296.130999999999,
          -4317.038,
          -4337.656,
          -4357.98,
          -4378.004,
          -4397.724,
          -4417.1359999999995,
          -4436.234,
          -4455.013,
          -4473.469,
          -4491.595,
          -4509.3859999999995,
          -4526.838,
          -4543.943,
          -4560.698,
          -4577.094,
          -4593.128,
          -4608.791,
          -4624.079000000001,
          -4638.985,
          -4653.502,
          -4667.622,
          -4681.34,
          -4694.649,
          -4707.54,
          -4720.0070000000005,
          -4732.041,
          -4743.6359999999995,
          -4754.782999999999,
          -4765.474,
          -4775.7,
          -4785.452,
          -4794.723,
          -4803.502,
          -4811.781,
          -4819.55,
          -4826.798,
          -4833.516,
          -4839.693,
          -4845.319,
          -4850.3820000000005,
          -4854.871,
          -4858.774,
          -4862.08,
          -4864.776,
          -4866.848,
          -4868.285,
          -4869.072,
          -4869.195,
          -4868.641,
          -4867.393,
          -4865.437,
          -4862.7570000000005,
          -4859.335999999999,
          -4855.157999999999,
          -4850.205,
          -4844.459,
          -4837.901,
          -4830.512,
          -4822.272,
          -4813.16,
          -4803.155,
          -4792.235,
          -4780.376,
          -4767.556,
          -4753.748,
          -4738.928,
          -4723.069,
          -4706.143,
          -4688.121,
          -4668.973,
          -4648.67,
          -4627.178,
          -4604.464,
          -4580.494000000001,
          -4555.23,
          -4528.6359999999995,
          -4500.6720000000005,
          -4471.2970000000005,
          -4440.469,
          -4408.143,
          -4374.273,
          -4338.811,
          -4301.706,
          -4262.905,
          -4222.356,
          -4179.999,
          -4135.776,
          -4089.6259999999997,
          -4041.482,
          -3991.277,
          -3938.941,
          -3884.401,
          -3827.5820000000003,
          -3768.402,
          -3706.781,
          -3642.633,
          -3575.869,
          -3506.3990000000003,
          -3434.1259999999997,
          -3358.9570000000003,
          -3280.788,
          -3199.52,
          -3115.05,
          -3027.272,
          -2936.0840000000003,
          -2841.382,
          -2743.065,
          -2641.035,
          -2535.202,
          -2425.48,
          -2311.795,
          -2194.089,
          -2072.3179999999998,
          -1946.4620000000002,
          -1816.524,
          -1682.54,
          -1544.58,
          -1402.756,
          -1257.224,
          -1108.194,
          -955.927,
          -800.743,
          -643.014,
          -483.17199999999997,
          -321.697,
          -159.112,
          4.026,
          167.138,
          329.63599999999997,
          490.939,
          650.4830000000001,
          807.74,
          962.222,
          1113.495,
          1261.181,
          1404.963,
          1544.5829999999999,
          1679.844,
          1810.6,
          1936.76,
          2058.276,
          2175.138,
          2287.37,
          2395.026,
          2498.177,
          2596.917,
          2691.3520000000003,
          2781.598,
          2867.778,
          2950.02,
          3028.455,
          3103.2140000000004,
          3174.427,
          3242.224,
          3306.73,
          3368.071,
          3426.366,
          3481.7309999999998,
          3534.278,
          3584.117,
          3631.35,
          3676.077,
          3718.3940000000002,
          3758.3909999999996,
          3796.157,
          3831.7740000000003,
          3865.323,
          3896.88,
          3926.5170000000003,
          3954.305,
          3980.308,
          4004.592,
          4027.215,
          4048.236,
          4067.711,
          4085.69,
          4102.226,
          4117.367,
          4131.156,
          4143.64,
          4154.86,
          4164.857,
          4173.669,
          4181.333,
          4187.885,
          4193.358,
          4197.785,
          4201.198,
          4203.627,
          4205.1,
          4205.645,
          4205.289000000001,
          4204.058,
          4201.975,
          4199.065,
          4195.351,
          4190.855,
          4185.597,
          4179.599,
          4172.879,
          4165.458,
          4157.352,
          4148.581,
          4139.161,
          4129.109,
          4118.44,
          4107.17,
          4095.315,
          4082.887,
          4069.902,
          4056.373,
          4042.313,
          4027.736,
          4012.652,
          3997.074,
          3981.014,
          3964.482,
          3947.49,
          3930.048,
          3912.167,
          3893.8559999999998,
          3875.1259999999997,
          3855.985,
          3836.4429999999998,
          3816.508,
          3796.19,
          3775.4970000000003,
          3754.4359999999997,
          3733.0170000000003,
          3711.2459999999996,
          3689.131,
          3666.68,
          3643.9,
          3620.798,
          3597.38,
          3573.6540000000005,
          3549.625,
          3525.301,
          3500.687,
          3475.789,
          3450.614,
          3425.1659999999997,
          3399.453,
          3373.478,
          3347.248,
          3320.7670000000003,
          3294.042,
          3267.0759999999996,
          3239.875,
          3212.4440000000004,
          3184.788,
          3156.91,
          3128.815,
          3100.509,
          3071.994,
          3043.276,
          3014.3590000000004,
          2985.2459999999996,
          2955.941,
          2926.45,
          2896.7740000000003,
          2866.9190000000003,
          2836.887,
          2806.683,
          2776.31,
          2745.7709999999997,
          2715.07,
          2684.21,
          2653.195,
          2622.027,
          2590.7110000000002,
          2559.248,
          2527.643,
          2495.8979999999997,
          2464.016,
          2432,
          2399.853,
          2367.577,
          2335.177,
          2302.653,
          2270.01,
          2237.249,
          2204.373,
          2171.386,
          2138.288,
          2105.084,
          2071.775,
          2038.364,
          2004.8529999999998,
          1971.244,
          1937.54,
          1903.744,
          1869.856,
          1835.881,
          1801.819,
          1767.674,
          1733.4460000000001,
          1699.139,
          1664.754,
          1630.2939999999999,
          1595.76,
          1561.155,
          1526.481,
          1491.739,
          1456.931,
          1422.06,
          1387.1270000000002,
          1352.134,
          1317.0839999999998,
          1281.9769999999999,
          1246.816,
          1211.603,
          1176.339,
          1141.026,
          1105.6660000000002,
          1070.26,
          1034.8110000000001,
          999.32,
          963.789,
          928.22,
          892.613,
          856.971,
          821.296,
          785.5880000000001,
          749.8510000000001,
          714.084,
          678.291,
          642.472,
          606.628,
          570.763,
          534.876,
          498.971,
          463.04699999999997,
          427.10699999999997,
          391.152,
          355.184,
          319.204,
          283.214,
          247.215,
          211.209,
          175.196,
          139.179,
          103.16,
          67.138,
          31.116999999999997,
          -4.9030000000000005,
          -40.921,
          -76.934,
          -112.94200000000001,
          -148.94299999999998,
          -184.935,
          -220.917,
          -256.889,
          -292.847,
          -328.792,
          -364.722,
          -400.634,
          -436.528,
          -472.403,
          -508.25699999999995,
          -544.089,
          -579.8969999999999,
          -615.68,
          -651.436,
          -687.164,
          -722.8639999999999,
          -758.5319999999999,
          -794.169,
          -829.7719999999999,
          -865.341,
          -900.8739999999999,
          -936.3689999999999,
          -971.825,
          -1007.24,
          -1042.615,
          -1077.9460000000001,
          -1113.232,
          -1148.473,
          -1183.6660000000002,
          -1218.8110000000001,
          -1253.906,
          -1288.9489999999998,
          -1323.94,
          -1358.876,
          -1393.756,
          -1428.579,
          -1463.3429999999998,
          -1498.0479999999998,
          -1532.691,
          -1567.271,
          -1601.786,
          -1636.236,
          -1670.618,
          -1704.932,
          -1739.175,
          -1773.346,
          -1807.444,
          -1841.467,
          -1875.414,
          -1909.283,
          -1943.0720000000001,
          -1976.78,
          -2010.406,
          -2043.9479999999999,
          -2077.404,
          -2110.772,
          -2144.052,
          -2177.241,
          -2210.3379999999997,
          -2243.341,
          -2276.248,
          -2309.0589999999997,
          -2341.771,
          -2374.382,
          -2406.891,
          -2439.295,
          -2471.595,
          -2503.786,
          -2535.869,
          -2567.84,
          -2599.699,
          -2631.4429999999998,
          -2663.07,
          -2694.579,
          -2725.968,
          -2757.2340000000004,
          -2788.377,
          -2819.393,
          -2850.282,
          -2881.04,
          -2911.667,
          -2942.159,
          -2972.515,
          -3002.7340000000004,
          -3032.8109999999997,
          -3062.7470000000003,
          -3092.538,
          -3122.1820000000002,
          -3151.677,
          -3181.022,
          -3210.212,
          -3239.2470000000003,
          -3268.1240000000003,
          -3296.84,
          -3325.3940000000002,
          -3353.783,
          -3382.0029999999997,
          -3410.054,
          -3437.9320000000002,
          -3465.634,
          -3493.159,
          -3520.5029999999997,
          -3547.664,
          -3574.64,
          -3601.426,
          -3628.0209999999997,
          -3654.422,
          -3680.6259999999997,
          -3706.63,
          -3732.43,
          -3758.025,
          -3783.41,
          -3808.583,
          -3833.5409999999997,
          -3858.28,
          -3882.797,
          -3907.0879999999997,
          -3931.151,
          -3954.982,
          -3978.577,
          -4001.933,
          -4025.045,
          -4047.9120000000003,
          -4070.527,
          -4092.889,
          -4114.992,
          -4136.833,
          -4158.407999999999,
          -4179.712,
          -4200.742,
          -4221.4929999999995,
          -4241.96,
          -4262.14,
          -4282.027,
          -4301.617,
          -4320.905,
          -4339.8859999999995,
          -4358.556,
          -4376.907999999999,
          -4394.939,
          -4412.643,
          -4430.013,
          -4447.045999999999,
          -4463.734,
          -4480.073,
          -4496.057,
          -4511.679,
          -4526.933,
          -4541.813,
          -4556.312,
          -4570.424,
          -4584.141,
          -4597.458,
          -4610.366,
          -4622.859,
          -4634.929,
          -4646.569,
          -4657.769,
          -4668.523,
          -4678.823,
          -4688.659000000001,
          -4698.023,
          -4706.905,
          -4715.298,
          -4723.191,
          -4730.5740000000005,
          -4737.438,
          -4743.772,
          -4749.566,
          -4754.809,
          -4759.49,
          -4763.597,
          -4767.119000000001,
          -4770.043,
          -4772.357,
          -4774.0470000000005,
          -4775.101,
          -4775.504,
          -4775.244000000001,
          -4774.304,
          -4772.67,
          -4770.326,
          -4767.2570000000005,
          -4763.445,
          -4758.874,
          -4753.525,
          -4747.380999999999,
          -4740.4220000000005,
          -4732.628,
          -4723.981,
          -4714.457,
          -4704.036,
          -4692.695,
          -4680.411,
          -4667.159000000001,
          -4652.914000000001,
          -4637.651,
          -4621.340999999999,
          -4603.956,
          -4585.468,
          -4565.846,
          -4545.058,
          -4523.072,
          -4499.853,
          -4475.365,
          -4449.572,
          -4422.436,
          -4393.915,
          -4363.968,
          -4332.552,
          -4299.62,
          -4265.127,
          -4229.021,
          -4191.252,
          -4151.765,
          -4110.505,
          -4067.414,
          -4022.43,
          -3975.49,
          -3926.526,
          -3875.47,
          -3822.2509999999997,
          -3766.792,
          -3709.0170000000003,
          -3648.843,
          -3586.188,
          -3520.9640000000004,
          -3453.08,
          -3382.445,
          -3308.961,
          -3232.533,
          -3153.0570000000002,
          -3070.434,
          -2984.56,
          -2895.333,
          -2802.65,
          -2706.4109999999996,
          -2606.519,
          -2502.883,
          -2395.42,
          -2284.055,
          -2168.728,
          -2049.396,
          -1926.0339999999999,
          -1798.645,
          -1667.261,
          -1531.9479999999999,
          -1392.8129999999999,
          -1250.007,
          -1103.73,
          -954.238,
          -801.8389999999999,
          -646.898,
          -489.835,
          -331.119,
          -171.261,
          -10.808,
          149.672,
          309.601,
          468.406,
          625.5319999999999,
          780.457,
          932.698,
          1081.8239999999998,
          1227.46,
          1369.289,
          1507.056,
          1640.56,
          1769.655,
          1894.249,
          2014.2879999999998,
          2129.762,
          2240.692,
          2347.127,
          2449.136,
          2546.8089999999997,
          2640.248,
          2729.566,
          2814.885,
          2896.327,
          2974.022,
          3048.097,
          3118.68,
          3185.8979999999997,
          3249.875,
          3310.7329999999997,
          3368.5890000000004,
          3423.558,
          3475.75,
          3525.2709999999997,
          3572.225,
          3616.823,
          3658.8109999999997,
          3698.6290000000004,
          3736.2459999999996,
          3771.745,
          3805.203,
          3836.695,
          3866.2940000000003,
          3894.0679999999998,
          3920.0820000000003,
          3944.3990000000003,
          3967.077,
          3988.1740000000004,
          4007.745,
          4025.84,
          4042.51,
          4057.803,
          4071.763,
          4084.433,
          4095.8559999999998,
          4106.071,
          4115.115,
          4123.027,
          4129.839,
          4135.587,
          4140.302,
          4144.015,
          4146.755999999999,
          4148.553,
          4149.433,
          4149.423,
          4148.548,
          4146.832,
          4144.298,
          4140.97,
          4136.869000000001,
          4132.015,
          4126.43,
          4120.1320000000005,
          4113.14,
          4105.472,
          4097.145,
          4088.177,
          4078.5840000000003,
          4068.382,
          4057.585,
          4046.2090000000003,
          4034.268,
          4021.775,
          4008.744,
          3995.188,
          3981.119,
          3966.55,
          3951.492,
          3935.9570000000003,
          3919.9559999999997,
          3903.4990000000003,
          3886.5959999999995,
          3869.259,
          3851.4970000000003,
          3833.32,
          3814.736,
          3795.755,
          3776.385,
          3756.636,
          3736.515,
          3716.031,
          3695.191,
          3674.0029999999997,
          3652.474,
          3630.613,
          3608.425,
          3585.9179999999997,
          3563.099,
          3539.973,
          3516.5490000000004,
          3492.8309999999997,
          3468.825,
          3444.539,
          3419.9770000000003,
          3395.1459999999997,
          3370.051,
          3344.696,
          3319.0890000000004,
          3293.2329999999997,
          3267.134,
          3240.797,
          3214.2270000000003,
          3187.427,
          3160.4040000000005,
          3133.1620000000003,
          3105.704,
          3078.0359999999996,
          3050.1620000000003,
          3022.085,
          2993.81,
          2965.342,
          2936.683,
          2907.837,
          2878.81,
          2849.603,
          2820.2209999999995,
          2790.6679999999997,
          2760.946,
          2731.06,
          2701.013,
          2670.8070000000002,
          2640.447,
          2609.936,
          2579.276,
          2548.471,
          2517.5229999999997,
          2486.436,
          2455.2129999999997,
          2423.857,
          2392.37,
          2360.755,
          2329.015,
          2297.152,
          2265.17,
          2233.071,
          2200.857,
          2168.532,
          2136.097,
          2103.555,
          2070.908,
          2038.1589999999999,
          2005.3110000000001,
          1972.365,
          1939.3239999999998,
          1906.19,
          1872.965,
          1839.652,
          1806.253,
          1772.769,
          1739.203,
          1705.558,
          1671.835,
          1638.035,
          1604.1629999999998,
          1570.2179999999998,
          1536.203,
          1502.121,
          1467.9720000000002,
          1433.76,
          1399.485,
          1365.151,
          1330.757,
          1296.307,
          1261.802,
          1227.245,
          1192.635,
          1157.9769999999999,
          1123.27,
          1088.518,
          1053.721,
          1018.8810000000001,
          984.0010000000001,
          949.081,
          914.123,
          879.13,
          844.1010000000001,
          809.041,
          773.948,
          738.826,
          703.676,
          668.5,
          633.298,
          598.073,
          562.826,
          527.558,
          492.272,
          456.968,
          421.648,
          386.314,
          350.967,
          315.608,
          280.23900000000003,
          244.862,
          209.477,
          174.08599999999998,
          138.692,
          103.294,
          67.895,
          32.495,
          -2.903,
          -38.298,
          -73.689,
          -109.075,
          -144.453,
          -179.824,
          -215.185,
          -250.53400000000002,
          -285.872,
          -321.195,
          -356.504,
          -391.796,
          -427.07,
          -462.324,
          -497.559,
          -532.771,
          -567.96,
          -603.124,
          -638.262,
          -673.373,
          -708.455,
          -743.507,
          -778.528,
          -813.5160000000001,
          -848.4689999999999,
          -883.387,
          -918.268,
          -953.1110000000001,
          -987.914,
          -1022.677,
          -1057.396,
          -1092.072,
          -1126.703,
          -1161.288,
          -1195.825,
          -1230.312,
          -1264.748,
          -1299.133,
          -1333.464,
          -1367.74,
          -1401.96,
          -1436.1229999999998,
          -1470.226,
          -1504.2679999999998,
          -1538.249,
          -1572.1660000000002,
          -1606.0179999999998,
          -1639.8039999999999,
          -1673.5220000000002,
          -1707.171,
          -1740.749,
          -1774.255,
          -1807.6870000000001,
          -1841.0439999999999,
          -1874.3239999999998,
          -1907.526,
          -1940.648,
          -1973.6889999999999,
          -2006.646,
          -2039.52,
          -2072.3070000000002,
          -2105.007,
          -2137.617,
          -2170.136,
          -2202.563,
          -2234.896,
          -2267.133,
          -2299.2729999999997,
          -2331.314,
          -2363.2529999999997,
          -2395.09,
          -2426.823,
          -2458.45,
          -2489.969,
          -2521.379,
          -2552.677,
          -2583.862,
          -2614.933,
          -2645.886,
          -2676.7209999999995,
          -2707.435,
          -2738.026,
          -2768.494,
          -2798.835,
          -2829.047,
          -2859.1290000000004,
          -2889.079,
          -2918.895,
          -2948.574,
          -2978.115,
          -3007.515,
          -3036.772,
          -3065.884,
          -3094.849,
          -3123.665,
          -3152.329,
          -3180.8390000000004,
          -3209.1929999999998,
          -3237.389,
          -3265.4240000000004,
          -3293.295,
          -3321,
          -3348.538,
          -3375.9040000000005,
          -3403.097,
          -3430.115,
          -3456.953,
          -3483.611,
          -3510.085,
          -3536.3720000000003,
          -3562.47,
          -3588.375,
          -3614.086,
          -3639.598,
          -3664.909,
          -3690.0170000000003,
          -3714.917,
          -3739.607,
          -3764.0840000000003,
          -3788.345,
          -3812.385,
          -3836.202,
          -3859.7929999999997,
          -3883.1540000000005,
          -3906.281,
          -3929.171,
          -3951.82,
          -3974.225,
          -3996.381,
          -4018.2859999999996,
          -4039.934,
          -4061.323,
          -4082.447,
          -4103.303,
          -4123.887,
          -4144.194,
          -4164.22,
          -4183.96,
          -4203.41,
          -4222.565,
          -4241.42,
          -4259.971,
          -4278.212,
          -4296.139,
          -4313.745,
          -4331.027,
          -4347.978,
          -4364.593,
          -4380.866,
          -4396.791,
          -4412.363,
          -4427.576,
          -4442.423,
          -4456.897,
          -4470.9929999999995,
          -4484.7029999999995,
          -4498.022,
          -4510.941,
          -4523.452,
          -4535.552,
          -4547.23,
          -4558.479,
          -4569.291,
          -4579.659000000001,
          -4589.573,
          -4599.025,
          -4608.0070000000005,
          -4616.509,
          -4624.522,
          -4632.036,
          -4639.042,
          -4645.53,
          -4651.49,
          -4656.91,
          -4661.78,
          -4666.088,
          -4669.823,
          -4672.974,
          -4675.527,
          -4677.469,
          -4678.789000000001,
          -4679.472,
          -4679.505,
          -4678.873,
          -4677.561,
          -4675.555,
          -4672.837,
          -4669.393,
          -4665.205,
          -4660.255999999999,
          -4654.527,
          -4648.001,
          -4640.657,
          -4632.477,
          -4623.439,
          -4613.522,
          -4602.704000000001,
          -4590.960999999999,
          -4578.27,
          -4564.607,
          -4549.945,
          -4534.258,
          -4517.518,
          -4499.696,
          -4480.764,
          -4460.689,
          -4439.44,
          -4416.982,
          -4393.281,
          -4368.3009999999995,
          -4342.004,
          -4314.349,
          -4285.298,
          -4254.805,
          -4222.827,
          -4189.317,
          -4154.226,
          -4117.504,
          -4079.098,
          -4038.953,
          -3997.012,
          -3953.2140000000004,
          -3907.498,
          -3859.797,
          -3810.045,
          -3758.1679999999997,
          -3704.0959999999995,
          -3647.75,
          -3589.051,
          -3527.9159999999997,
          -3464.26,
          -3397.994,
          -3329.027,
          -3257.263,
          -3182.607,
          -3104.96,
          -3024.2209999999995,
          -2940.288,
          -2853.0609999999997,
          -2762.4390000000003,
          -2668.321,
          -2570.612,
          -2469.221,
          -2364.065,
          -2255.071,
          -2142.175,
          -2025.3339999999998,
          -1904.523,
          -1779.7420000000002,
          -1651.019,
          -1518.4160000000002,
          -1382.0339999999999,
          -1242.02,
          -1098.566,
          -951.92,
          -802.3810000000001,
          -650.303,
          -496.095,
          -340.215,
          -183.16400000000002,
          -25.476,
          132.29,
          289.568,
          445.79400000000004,
          600.4209999999999,
          752.933,
          902.8539999999999,
          1049.755,
          1193.265,
          1333.067,
          1468.9070000000002,
          1600.5839999999998,
          1727.951,
          1850.911,
          1969.411,
          2083.436,
          2193.005,
          2298.161,
          2398.973,
          2495.527,
          2587.9210000000003,
          2676.2659999999996,
          2760.677,
          2841.277,
          2918.19,
          2991.542,
          3061.4590000000003,
          3128.063,
          3191.4770000000003,
          3251.82,
          3309.208,
          3363.7509999999997,
          3415.56,
          3464.739,
          3511.387,
          3555.6,
          3597.4709999999995,
          3637.0890000000004,
          3674.538,
          3709.8979999999997,
          3743.2470000000003,
          3774.66,
          3804.2059999999997,
          3831.952,
          3857.962,
          3882.2990000000004,
          3905.0209999999997,
          3926.183,
          3945.8390000000004,
          3964.0409999999997,
          3980.836,
          3996.2729999999997,
          4010.395,
          4023.245,
          4034.864,
          4045.292,
          4054.565,
          4062.719,
          4069.789,
          4075.808,
          4080.808,
          4084.8190000000004,
          4087.87,
          4089.989,
          4091.204,
          4091.539,
          4091.0209999999997,
          4089.672,
          4087.5159999999996,
          4084.5759999999996,
          4080.8709999999996,
          4076.4240000000004,
          4071.2540000000004,
          4065.38,
          4058.82,
          4051.593,
          4043.716,
          4035.204,
          4026.075,
          4016.344,
          4006.026,
          3995.135,
          3983.685,
          3971.69,
          3959.164,
          3946.118,
          3932.565,
          3918.518,
          3903.987,
          3888.985,
          3873.5209999999997,
          3857.607,
          3841.2529999999997,
          3824.468,
          3807.264,
          3789.6479999999997,
          3771.63,
          3753.219,
          3734.4240000000004,
          3715.2529999999997,
          3695.715,
          3675.816,
          3655.566,
          3634.9709999999995,
          3614.04,
          3592.778,
          3571.1929999999998,
          3549.2929999999997,
          3527.083,
          3504.57,
          3481.76,
          3458.66,
          3435.276,
          3411.613,
          3387.677,
          3363.474,
          3339.009,
          3314.288,
          3289.315,
          3264.097,
          3238.637,
          3212.941,
          3187.014,
          3160.86,
          3134.4840000000004,
          3107.89,
          3081.083,
          3054.067,
          3026.847,
          2999.425,
          2971.8070000000002,
          2943.9959999999996,
          2915.9959999999996,
          2887.812,
          2859.446,
          2830.902,
          2802.185,
          2773.297,
          2744.242,
          2715.0229999999997,
          2685.6440000000002,
          2656.1079999999997,
          2626.4179999999997,
          2596.577,
          2566.5879999999997,
          2536.456,
          2506.181,
          2475.768,
          2445.22,
          2414.538,
          2383.726,
          2352.7870000000003,
          2321.724,
          2290.538,
          2259.2329999999997,
          2227.811,
          2196.275,
          2164.6279999999997,
          2132.871,
          2101.007,
          2069.0389999999998,
          2036.969,
          2004.8,
          1972.5320000000002,
          1940.17,
          1907.715,
          1875.1689999999999,
          1842.535,
          1809.8139999999999,
          1777.009,
          1744.121,
          1711.154,
          1678.109,
          1644.987,
          1611.7920000000001,
          1578.524,
          1545.1860000000001,
          1511.78,
          1478.308,
          1444.771,
          1411.171,
          1377.511,
          1343.7920000000001,
          1310.016,
          1276.184,
          1242.299,
          1208.361,
          1174.374,
          1140.338,
          1106.255,
          1072.128,
          1037.9569999999999,
          1003.7439999999999,
          969.4910000000001,
          935.199,
          900.8710000000001,
          866.507,
          832.11,
          797.68,
          763.22,
          728.7310000000001,
          694.2139999999999,
          659.671,
          625.104,
          590.514,
          555.9019999999999,
          521.27,
          486.62,
          451.952,
          417.269,
          382.57199999999995,
          347.86199999999997,
          313.14,
          278.409,
          243.669,
          208.923,
          174.17,
          139.414,
          104.654,
          69.893,
          35.132,
          0.37200000000000005,
          -34.385,
          -69.138,
          -103.88600000000001,
          -138.627,
          -173.36,
          -208.083,
          -242.796,
          -277.496,
          -312.183,
          -346.855,
          -381.51099999999997,
          -416.149,
          -450.769,
          -485.36800000000005,
          -519.946,
          -554.501,
          -589.0319999999999,
          -623.5369999999999,
          -658.015,
          -692.465,
          -726.8860000000001,
          -761.275,
          -795.633,
          -829.957,
          -864.2460000000001,
          -898.498,
          -932.7130000000001,
          -966.89,
          -1001.0260000000001,
          -1035.12,
          -1069.171,
          -1103.1789999999999,
          -1137.14,
          -1171.0539999999999,
          -1204.92,
          -1238.736,
          -1272.501,
          -1306.214,
          -1339.872,
          -1373.476,
          -1407.0220000000002,
          -1440.511,
          -1473.9389999999999,
          -1507.307,
          -1540.6129999999998,
          -1573.855,
          -1607.031,
          -1640.141,
          -1673.183,
          -1706.155,
          -1739.056,
          -1771.884,
          -1804.639,
          -1837.318,
          -1869.92,
          -1902.443,
          -1934.8870000000002,
          -1967.2479999999998,
          -1999.527,
          -2031.721,
          -2063.8289999999997,
          -2095.849,
          -2127.779,
          -2159.618,
          -2191.365,
          -2223.0170000000003,
          -2254.574,
          -2286.032,
          -2317.3920000000003,
          -2348.65,
          -2379.806,
          -2410.857,
          -2441.803,
          -2472.64,
          -2503.367,
          -2533.984,
          -2564.486,
          -2594.874,
          -2625.145,
          -2655.296,
          -2685.328,
          -2715.236,
          -2745.02,
          -2774.677,
          -2804.2059999999997,
          -2833.6040000000003,
          -2862.869,
          -2892,
          -2920.995,
          -2949.8509999999997,
          -2978.565,
          -3007.137,
          -3035.5640000000003,
          -3063.843,
          -3091.972,
          -3119.95,
          -3147.7729999999997,
          -3175.44,
          -3202.948,
          -3230.295,
          -3257.478,
          -3284.494,
          -3311.343,
          -3338.0190000000002,
          -3364.5229999999997,
          -3390.849,
          -3416.9970000000003,
          -3442.9629999999997,
          -3468.745,
          -3494.3390000000004,
          -3519.744,
          -3544.955,
          -3569.9709999999995,
          -3594.788,
          -3619.403,
          -3643.8140000000003,
          -3668.0159999999996,
          -3692.008,
          -3715.785,
          -3739.345,
          -3762.683,
          -3785.798,
          -3808.685,
          -3831.341,
          -3853.762,
          -3875.9440000000004,
          -3897.885,
          -3919.58,
          -3941.025,
          -3962.216,
          -3983.15,
          -4003.822,
          -4024.2290000000003,
          -4044.365,
          -4064.2270000000003,
          -4083.81,
          -4103.11,
          -4122.122,
          -4140.842000000001,
          -4159.264,
          -4177.385,
          -4195.198,
          -4212.6990000000005,
          -4229.8820000000005,
          -4246.7429999999995,
          -4263.276,
          -4279.475,
          -4295.334,
          -4310.848,
          -4326.0109999999995,
          -4340.817,
          -4355.259,
          -4369.332,
          -4383.028,
          -4396.340999999999,
          -4409.264,
          -4421.79,
          -4433.912,
          -4445.622,
          -4456.914000000001,
          -4467.778,
          -4478.208,
          -4488.196,
          -4497.731,
          -4506.806,
          -4515.413,
          -4523.542,
          -4531.183,
          -4538.3279999999995,
          -4544.965999999999,
          -4551.087,
          -4556.681,
          -4561.737,
          -4566.244000000001,
          -4570.191,
          -4573.565,
          -4576.356,
          -4578.55,
          -4580.134,
          -4581.096,
          -4581.420999999999,
          -4581.097,
          -4580.107,
          -4578.438,
          -4576.073,
          -4572.998,
          -4569.194,
          -4564.646,
          -4559.335,
          -4553.244000000001,
          -4546.353,
          -4538.643,
          -4530.094,
          -4520.684,
          -4510.394,
          -4499.197,
          -4487.073,
          -4473.996,
          -4459.943,
          -4444.885,
          -4428.7970000000005,
          -4411.651,
          -4393.416,
          -4374.063,
          -4353.56,
          -4331.873,
          -4308.97,
          -4284.813,
          -4259.366,
          -4232.590999999999,
          -4204.446,
          -4174.891,
          -4143.88,
          -4111.3679999999995,
          -4077.308,
          -4041.65,
          -4004.343,
          -3965.3309999999997,
          -3924.559,
          -3881.967,
          -3837.495,
          -3791.078,
          -3742.65,
          -3692.1420000000003,
          -3639.48,
          -3584.5879999999997,
          -3527.39,
          -3467.804,
          -3405.745,
          -3341.1259999999997,
          -3273.857,
          -3203.847,
          -3130.998,
          -3055.2140000000004,
          -2976.395,
          -2894.4429999999998,
          -2809.256,
          -2720.736,
          -2628.782,
          -2533.3,
          -2434.201,
          -2331.4,
          -2224.825,
          -2114.4139999999998,
          -2000.119,
          -1881.9160000000002,
          -1759.8,
          -1633.7979999999998,
          -1503.969,
          -1370.406,
          -1233.251,
          -1092.69,
          -948.96,
          -802.3530000000001,
          -653.214,
          -501.939,
          -348.974,
          -194.81,
          -39.969,
          115.00200000000001,
          269.548,
          423.11199999999997,
          575.159,
          725.178,
          872.697,
          1017.294,
          1158.6,
          1296.3,
          1430.139,
          1559.918,
          1685.486,
          1806.747,
          1923.6429999999998,
          2036.1570000000002,
          2144.305,
          2248.127,
          2347.688,
          2443.07,
          2534.369,
          2621.691,
          2705.15,
          2784.863,
          2860.954,
          2933.5429999999997,
          3002.756,
          3068.71,
          3131.527,
          3191.322,
          3248.21,
          3302.3,
          3353.698,
          3402.507,
          3448.825,
          3492.7459999999996,
          3534.361,
          3573.757,
          3611.018,
          3646.2209999999995,
          3679.4440000000004,
          3710.759,
          3740.236,
          3767.938,
          3793.9320000000002,
          3818.276,
          3841.028,
          3862.244,
          3881.9759999999997,
          3900.2740000000003,
          3917.1859999999997,
          3932.759,
          3947.035,
          3960.058,
          3971.867,
          3982.502,
          3991.998,
          4000.3909999999996,
          4007.7140000000004,
          4014.002,
          4019.283,
          4023.59,
          4026.949,
          4029.39,
          4030.938,
          4031.618,
          4031.4559999999997,
          4030.475,
          4028.698,
          4026.1459999999997,
          4022.84,
          4018.802,
          4014.0490000000004,
          4008.6020000000003,
          4002.478,
          3995.695,
          3988.27,
          3980.22,
          3971.559,
          3962.304,
          3952.469,
          3942.0679999999998,
          3931.116,
          3919.625,
          3907.6090000000004,
          3895.08,
          3882.05,
          3868.532,
          3854.5359999999996,
          3840.073,
          3825.155,
          3809.792,
          3793.994,
          3777.7709999999997,
          3761.132,
          3744.087,
          3726.6440000000002,
          3708.813,
          3690.6020000000003,
          3672.0190000000002,
          3653.072,
          3633.77,
          3614.119,
          3594.1279999999997,
          3573.804,
          3553.153,
          3532.1820000000002,
          3510.8990000000003,
          3489.309,
          3467.42,
          3445.237,
          3422.7670000000003,
          3400.015,
          3376.987,
          3353.6890000000003,
          3330.1259999999997,
          3306.304,
          3282.228,
          3257.903,
          3233.335,
          3208.527,
          3183.486,
          3158.215,
          3132.72,
          3107.0040000000004,
          3081.072,
          3054.929,
          3028.579,
          3002.025,
          2975.2729999999997,
          2948.325,
          2921.1859999999997,
          2893.86,
          2866.35,
          2838.66,
          2810.7940000000003,
          2782.755,
          2754.547,
          2726.173,
          2697.636,
          2668.94,
          2640.0879999999997,
          2611.083,
          2581.928,
          2552.626,
          2523.181,
          2493.595,
          2463.871,
          2434.012,
          2404.02,
          2373.899,
          2343.652,
          2313.28,
          2282.7870000000003,
          2252.175,
          2221.447,
          2190.604,
          2159.651,
          2128.5879999999997,
          2097.419,
          2066.145,
          2034.77,
          2003.295,
          1971.723,
          1940.056,
          1908.296,
          1876.445,
          1844.506,
          1812.48,
          1780.37,
          1748.1779999999999,
          1715.905,
          1683.5539999999999,
          1651.1270000000002,
          1618.626,
          1586.0520000000001,
          1553.408,
          1520.695,
          1487.915,
          1455.0710000000001,
          1422.164,
          1389.195,
          1356.1670000000001,
          1323.0810000000001,
          1289.94,
          1256.744,
          1223.495,
          1190.1960000000001,
          1156.848,
          1123.453,
          1090.012,
          1056.526,
          1022.998,
          989.43,
          955.821,
          922.176,
          888.4939999999999,
          854.7769999999999,
          821.028,
          787.2460000000001,
          753.435,
          719.596,
          685.7289999999999,
          651.837,
          617.9209999999999,
          583.982,
          550.0219999999999,
          516.043,
          482.045,
          448.031,
          414.001,
          379.957,
          345.901,
          311.83299999999997,
          277.756,
          243.671,
          209.578,
          175.48,
          141.378,
          107.272,
          73.166,
          39.059,
          4.953,
          -29.15,
          -63.248999999999995,
          -97.34299999999999,
          -131.431,
          -165.51,
          -199.58,
          -233.64,
          -267.688,
          -301.723,
          -335.74300000000005,
          -369.74800000000005,
          -403.735,
          -437.704,
          -471.653,
          -505.58099999999996,
          -539.487,
          -573.369,
          -607.226,
          -641.057,
          -674.86,
          -708.6339999999999,
          -742.378,
          -776.09,
          -809.77,
          -843.415,
          -877.025,
          -910.5980000000001,
          -944.133,
          -977.628,
          -1011.0830000000001,
          -1044.496,
          -1077.865,
          -1111.1889999999999,
          -1144.4669999999999,
          -1177.698,
          -1210.88,
          -1244.011,
          -1277.0919999999999,
          -1310.119,
          -1343.092,
          -1376.009,
          -1408.869,
          -1441.671,
          -1474.4129999999998,
          -1507.094,
          -1539.7120000000002,
          -1572.266,
          -1604.755,
          -1637.1760000000002,
          -1669.53,
          -1701.8129999999999,
          -1734.026,
          -1766.165,
          -1798.231,
          -1830.22,
          -1862.1329999999998,
          -1893.967,
          -1925.721,
          -1957.3929999999998,
          -1988.9820000000002,
          -2020.485,
          -2051.903,
          -2083.2329999999997,
          -2114.473,
          -2145.6220000000003,
          -2176.678,
          -2207.64,
          -2238.506,
          -2269.274,
          -2299.9429999999998,
          -2330.511,
          -2360.976,
          -2391.3360000000002,
          -2421.591,
          -2451.736,
          -2481.774,
          -2511.698,
          -2541.511,
          -2571.2070000000003,
          -2600.7870000000003,
          -2630.2470000000003,
          -2659.587,
          -2688.804,
          -2717.897,
          -2746.863,
          -2775.7,
          -2804.407,
          -2832.9809999999998,
          -2861.42,
          -2889.723,
          -2917.887,
          -2945.91,
          -2973.79,
          -3001.5240000000003,
          -3029.111,
          -3056.548,
          -3083.833,
          -3110.9640000000004,
          -3137.938,
          -3164.752,
          -3191.406,
          -3217.895,
          -3244.218,
          -3270.3720000000003,
          -3296.355,
          -3322.163,
          -3347.795,
          -3373.2470000000003,
          -3398.518,
          -3423.603,
          -3448.5009999999997,
          -3473.208,
          -3497.722,
          -3522.04,
          -3546.158,
          -3570.074,
          -3593.784,
          -3617.2859999999996,
          -3640.5759999999996,
          -3663.651,
          -3686.508,
          -3709.143,
          -3731.553,
          -3753.7340000000004,
          -3775.684,
          -3797.397,
          -3818.8709999999996,
          -3840.1009999999997,
          -3861.085,
          -3881.817,
          -3902.295,
          -3922.513,
          -3942.469,
          -3962.157,
          -3981.573,
          -4000.7129999999997,
          -4019.573,
          -4038.147,
          -4056.4320000000002,
          -4074.422,
          -4092.113,
          -4109.499,
          -4126.575,
          -4143.337,
          -4159.779,
          -4175.895,
          -4191.68,
          -4207.129,
          -4222.234,
          -4236.992,
          -4251.394,
          -4265.436,
          -4279.111,
          -4292.412,
          -4305.332,
          -4317.865,
          -4330.003,
          -4341.74,
          -4353.067,
          -4363.978,
          -4374.465,
          -4384.52,
          -4394.133,
          -4403.298,
          -4412.005,
          -4420.245,
          -4428.009,
          -4435.288,
          -4442.072,
          -4448.352,
          -4454.116,
          -4459.356,
          -4464.059,
          -4468.214,
          -4471.811,
          -4474.837,
          -4477.28,
          -4479.128,
          -4480.367,
          -4480.985,
          -4480.967000000001,
          -4480.3,
          -4478.968,
          -4476.957,
          -4474.251,
          -4470.834,
          -4466.688,
          -4461.798,
          -4456.144,
          -4449.709,
          -4442.472,
          -4434.416,
          -4425.518,
          -4415.758,
          -4405.113,
          -4393.561,
          -4381.077,
          -4367.638,
          -4353.217000000001,
          -4337.789000000001,
          -4321.325,
          -4303.795999999999,
          -4285.174,
          -4265.4259999999995,
          -4244.521,
          -4222.425,
          -4199.103,
          -4174.519,
          -4148.635,
          -4121.411,
          -4092.805,
          -4062.777,
          -4031.28,
          -3998.2659999999996,
          -3963.6890000000003,
          -3927.4959999999996,
          -3889.636,
          -3850.052,
          -3808.687,
          -3765.4809999999998,
          -3720.37,
          -3673.29,
          -3624.172,
          -3572.945,
          -3519.535,
          -3463.865,
          -3405.855,
          -3345.423,
          -3282.482,
          -3216.9440000000004,
          -3148.718,
          -3077.712,
          -3003.827,
          -2926.968,
          -2847.034,
          -2763.928,
          -2677.551,
          -2587.806,
          -2494.598,
          -2397.8379999999997,
          -2297.4429999999998,
          -2193.339,
          -2085.465,
          -1973.773,
          -1858.234,
          -1738.845,
          -1615.626,
          -1488.6329999999998,
          -1357.957,
          -1223.73,
          -1086.132,
          -945.3919999999999,
          -801.7919999999999,
          -655.6669999999999,
          -507.402,
          -357.434,
          -206.238,
          -54.325,
          97.76899999999999,
          249.49900000000002,
          400.32,
          549.705,
          697.148,
          842.186,
          984.4010000000001,
          1123.425,
          1258.9489999999998,
          1390.715,
          1518.524,
          1642.225,
          1761.719,
          1876.9479999999999,
          1987.89,
          2094.5570000000002,
          2196.988,
          2295.244,
          2389.402,
          2479.5570000000002,
          2565.8089999999997,
          2648.27,
          2727.054,
          2802.281,
          2874.07,
          2942.54,
          3007.809,
          3069.995,
          3129.211,
          3185.5679999999998,
          3239.1740000000004,
          3290.135,
          3338.548,
          3384.511,
          3428.1440000000002,
          3469.454,
          3508.607,
          3545.659,
          3580.688,
          3613.7659999999996,
          3644.968,
          3674.3590000000004,
          3702.0040000000004,
          3727.966,
          3752.305,
          3775.0759999999996,
          3796.335,
          3816.132,
          3834.5159999999996,
          3851.5359999999996,
          3867.237,
          3881.66,
          3894.849,
          3906.842,
          3917.677,
          3927.3920000000003,
          3936.018,
          3943.592,
          3950.1440000000002,
          3955.705,
          3960.304,
          3963.9709999999995,
          3966.7309999999998,
          3968.612,
          3969.637,
          3969.8320000000003,
          3969.219,
          3967.821,
          3965.659,
          3962.7540000000004,
          3959.1259999999997,
          3954.7940000000003,
          3949.776,
          3944.091,
          3937.756,
          3930.788,
          3923.202,
          3915.014,
          3906.239,
          3896.893,
          3886.988,
          3876.539,
          3865.558,
          3854.059,
          3842.053,
          3829.553,
          3816.57,
          3803.116,
          3789.202,
          3774.837,
          3760.033,
          3744.7990000000004,
          3729.145,
          3713.0809999999997,
          3696.615,
          3679.757,
          3662.514,
          3644.8959999999997,
          3626.9109999999996,
          3608.567,
          3589.87,
          3570.83,
          3551.453,
          3531.7459999999996,
          3511.716,
          3491.3709999999996,
          3470.716,
          3449.758,
          3428.5040000000004,
          3406.9590000000003,
          3385.13,
          3363.022,
          3340.6409999999996,
          3317.993,
          3295.083,
          3271.9159999999997,
          3248.498,
          3224.8340000000003,
          3200.928,
          3176.7859999999996,
          3152.4109999999996,
          3127.81,
          3102.986,
          3077.9440000000004,
          3052.688,
          3027.222,
          3001.551,
          2975.679,
          2949.6090000000004,
          2923.3459999999995,
          2896.893,
          2870.2540000000004,
          2843.434,
          2816.434,
          2789.26,
          2761.915,
          2734.401,
          2706.722,
          2678.882,
          2650.884,
          2622.7309999999998,
          2594.426,
          2565.972,
          2537.373,
          2508.63,
          2479.7470000000003,
          2450.728,
          2421.574,
          2392.288,
          2362.874,
          2333.333,
          2303.669,
          2273.884,
          2243.98,
          2213.9610000000002,
          2183.8289999999997,
          2153.585,
          2123.2329999999997,
          2092.774,
          2062.2110000000002,
          2031.5479999999998,
          2000.7839999999999,
          1969.9229999999998,
          1938.9679999999998,
          1907.9189999999999,
          1876.78,
          1845.5529999999999,
          1814.239,
          1782.84,
          1751.36,
          1719.7979999999998,
          1688.1589999999999,
          1656.443,
          1624.652,
          1592.789,
          1560.855,
          1528.8529999999998,
          1496.783,
          1464.648,
          1432.45,
          1400.19,
          1367.87,
          1335.4920000000002,
          1303.058,
          1270.569,
          1238.027,
          1205.433,
          1172.79,
          1140.099,
          1107.362,
          1074.579,
          1041.754,
          1008.887,
          975.9789999999999,
          943.034,
          910.051,
          877.033,
          843.9810000000001,
          810.8960000000001,
          777.7810000000001,
          744.6360000000001,
          711.4630000000001,
          678.2639999999999,
          645.039,
          611.7909999999999,
          578.521,
          545.23,
          511.92,
          478.592,
          445.24699999999996,
          411.88699999999994,
          378.514,
          345.12800000000004,
          311.731,
          278.324,
          244.90900000000002,
          211.487,
          178.06,
          144.628,
          111.194,
          77.757,
          44.321000000000005,
          10.886,
          -22.546999999999997,
          -55.977,
          -89.40100000000001,
          -122.819,
          -156.22899999999998,
          -189.63099999999997,
          -223.02200000000002,
          -256.402,
          -289.769,
          -323.122,
          -356.459,
          -389.78,
          -423.083,
          -456.36699999999996,
          -489.63,
          -522.871,
          -556.089,
          -589.283,
          -622.451,
          -655.592,
          -688.705,
          -721.789,
          -754.841,
          -787.862,
          -820.8489999999999,
          -853.801,
          -886.7180000000001,
          -919.597,
          -952.437,
          -985.238,
          -1017.997,
          -1050.714,
          -1083.387,
          -1116.015,
          -1148.597,
          -1181.13,
          -1213.615,
          -1246.049,
          -1278.431,
          -1310.76,
          -1343.035,
          -1375.253,
          -1407.415,
          -1439.517,
          -1471.56,
          -1503.5410000000002,
          -1535.46,
          -1567.3139999999999,
          -1599.1029999999998,
          -1630.825,
          -1662.479,
          -1694.0620000000001,
          -1725.5739999999998,
          -1757.014,
          -1788.379,
          -1819.668,
          -1850.881,
          -1882.014,
          -1913.067,
          -1944.039,
          -1974.9279999999999,
          -2005.731,
          -2036.4479999999999,
          -2067.078,
          -2097.618,
          -2128.0660000000003,
          -2158.423,
          -2188.6839999999997,
          -2218.85,
          -2248.9179999999997,
          -2278.887,
          -2308.755,
          -2338.52,
          -2368.181,
          -2397.736,
          -2427.183,
          -2456.52,
          -2485.746,
          -2514.8579999999997,
          -2543.856,
          -2572.736,
          -2601.498,
          -2630.139,
          -2658.658,
          -2687.052,
          -2715.3190000000004,
          -2743.458,
          -2771.466,
          -2799.342,
          -2827.083,
          -2854.688,
          -2882.1540000000005,
          -2909.4790000000003,
          -2936.66,
          -2963.697,
          -2990.586,
          -3017.325,
          -3043.9120000000003,
          -3070.345,
          -3096.62,
          -3122.737,
          -3148.692,
          -3174.4840000000004,
          -3200.1079999999997,
          -3225.5640000000003,
          -3250.848,
          -3275.958,
          -3300.89,
          -3325.6440000000002,
          -3350.215,
          -3374.6,
          -3398.798,
          -3422.805,
          -3446.619,
          -3470.235,
          -3493.652,
          -3516.867,
          -3539.875,
          -3562.6740000000004,
          -3585.261,
          -3607.632,
          -3629.785,
          -3651.715,
          -3673.4190000000003,
          -3694.8940000000002,
          -3716.135,
          -3737.14,
          -3757.9040000000005,
          -3778.425,
          -3798.697,
          -3818.716,
          -3838.48,
          -3857.9840000000004,
          -3877.223,
          -3896.1929999999998,
          -3914.89,
          -3933.309,
          -3951.446,
          -3969.297,
          -3986.855,
          -4004.117,
          -4021.078,
          -4037.732,
          -4054.074,
          -4070.099,
          -4085.801,
          -4101.175,
          -4116.215999999999,
          -4130.917,
          -4145.272,
          -4159.275,
          -4172.920999999999,
          -4186.202,
          -4199.113,
          -4211.645,
          -4223.793,
          -4235.55,
          -4246.907999999999,
          -4257.859,
          -4268.397,
          -4278.513,
          -4288.1990000000005,
          -4297.447,
          -4306.249,
          -4314.596,
          -4322.479,
          -4329.888,
          -4336.815,
          -4343.249,
          -4349.181,
          -4354.6,
          -4359.496,
          -4363.858,
          -4367.674,
          -4370.934,
          -4373.624,
          -4375.734,
          -4377.25,
          -4378.159000000001,
          -4378.448,
          -4378.102,
          -4377.108,
          -4375.451,
          -4373.115,
          -4370.085,
          -4366.344,
          -4361.875,
          -4356.661,
          -4350.684,
          -4343.924,
          -4336.3640000000005,
          -4327.982,
          -4318.7570000000005,
          -4308.668,
          -4297.693,
          -4285.808,
          -4272.9890000000005,
          -4259.212,
          -4244.4490000000005,
          -4228.675,
          -4211.861,
          -4193.977,
          -4174.995,
          -4154.880999999999,
          -4133.603,
          -4111.127,
          -4087.417,
          -4062.4359999999997,
          -4036.145,
          -4008.5040000000004,
          -3979.4709999999995,
          -3949.002,
          -3917.051,
          -3883.571,
          -3848.511,
          -3811.82,
          -3773.4429999999998,
          -3733.324,
          -3691.4040000000005,
          -3647.6209999999996,
          -3601.9109999999996,
          -3554.2059999999997,
          -3504.4390000000003,
          -3452.535,
          -3398.42,
          -3342.014,
          -3283.236,
          -3222.0029999999997,
          -3158.228,
          -3091.821,
          -3022.6890000000003,
          -2950.739,
          -2875.8740000000003,
          -2797.998,
          -2717.013,
          -2632.821,
          -2545.327,
          -2454.437,
          -2360.062,
          -2262.121,
          -2160.5389999999998,
          -2055.254,
          -1946.217,
          -1833.401,
          -1716.796,
          -1596.421,
          -1472.328,
          -1344.602,
          -1213.37,
          -1078.805,
          -941.127,
          -800.6089999999999,
          -657.574,
          -512.398,
          -365.50300000000004,
          -217.355,
          -68.453,
          80.681,
          229.512,
          377.50699999999995,
          524.143,
          668.929,
          811.404,
          951.1560000000001,
          1087.82,
          1221.087,
          1350.704,
          1476.469,
          1598.2320000000002,
          1715.89,
          1829.385,
          1938.6889999999999,
          2043.8139999999999,
          2144.794,
          2241.687,
          2334.567,
          2423.5229999999997,
          2508.656,
          2590.071,
          2667.88,
          2742.199,
          2813.1440000000002,
          2880.8320000000003,
          2945.3779999999997,
          3006.897,
          3065.4990000000003,
          3121.2929999999997,
          3174.386,
          3224.8779999999997,
          3272.867,
          3318.448,
          3361.7129999999997,
          3402.748,
          3441.637,
          3478.46,
          3513.292,
          3546.2070000000003,
          3577.276,
          3606.5640000000003,
          3634.136,
          3660.052,
          3684.3709999999996,
          3707.1479999999997,
          3728.437,
          3748.2870000000003,
          3766.748,
          3783.865,
          3799.684,
          3814.2459999999996,
          3827.593,
          3839.762,
          3850.792,
          3860.718,
          3869.573,
          3877.393,
          3884.205,
          3890.042,
          3894.9320000000002,
          3898.902,
          3901.9809999999998,
          3904.192,
          3905.5609999999997,
          3906.112,
          3905.867,
          3904.849,
          3903.078,
          3900.574,
          3897.3579999999997,
          3893.448,
          3888.863,
          3883.619,
          3877.735,
          3871.2259999999997,
          3864.1090000000004,
          3856.3990000000003,
          3848.11,
          3839.256,
          3829.8520000000003,
          3819.9109999999996,
          3809.446,
          3798.469,
          3786.993,
          3775.0290000000005,
          3762.5890000000004,
          3749.683,
          3736.324,
          3722.52,
          3708.283,
          3693.6209999999996,
          3678.545,
          3663.063,
          3647.1859999999997,
          3630.92,
          3614.276,
          3597.26,
          3579.882,
          3562.1490000000003,
          3544.0690000000004,
          3525.6490000000003,
          3506.8959999999997,
          3487.817,
          3468.4190000000003,
          3448.7090000000003,
          3428.6940000000004,
          3408.3790000000004,
          3387.7709999999997,
          3366.8759999999997,
          3345.699,
          3324.2470000000003,
          3302.526,
          3280.54,
          3258.295,
          3235.796,
          3213.048,
          3190.0570000000002,
          3166.8259999999996,
          3143.362,
          3119.6679999999997,
          3095.7490000000003,
          3071.6090000000004,
          3047.2540000000004,
          3022.687,
          2997.913,
          2972.934,
          2947.757,
          2922.384,
          2896.8190000000004,
          2871.066,
          2845.13,
          2819.012,
          2792.718,
          2766.25,
          2739.612,
          2712.808,
          2685.8390000000004,
          2658.711,
          2631.426,
          2603.987,
          2576.397,
          2548.659,
          2520.777,
          2492.752,
          2464.5879999999997,
          2436.2889999999998,
          2407.855,
          2379.291,
          2350.599,
          2321.781,
          2292.84,
          2263.779,
          2234.601,
          2205.306,
          2175.899,
          2146.381,
          2116.756,
          2087.024,
          2057.188,
          2027.251,
          1997.2160000000001,
          1967.0829999999999,
          1936.855,
          1906.535,
          1876.124,
          1845.625,
          1815.039,
          1784.369,
          1753.6170000000002,
          1722.7839999999999,
          1691.8729999999998,
          1660.885,
          1629.8220000000001,
          1598.6870000000001,
          1567.481,
          1536.205,
          1504.862,
          1473.454,
          1441.9820000000002,
          1410.4479999999999,
          1378.854,
          1347.201,
          1315.491,
          1283.726,
          1251.9080000000001,
          1220.038,
          1188.117,
          1156.1480000000001,
          1124.131,
          1092.07,
          1059.964,
          1027.816,
          995.627,
          963.3989999999999,
          931.133,
          898.831,
          866.4939999999999,
          834.1239999999999,
          801.722,
          769.29,
          736.828,
          704.3389999999999,
          671.825,
          639.285,
          606.722,
          574.138,
          541.533,
          508.909,
          476.267,
          443.60900000000004,
          410.936,
          378.249,
          345.55,
          312.84,
          280.121,
          247.393,
          214.65900000000002,
          181.918,
          149.174,
          116.426,
          83.677,
          50.927,
          18.178,
          -14.569,
          -47.312,
          -80.051,
          -112.78299999999999,
          -145.50799999999998,
          -178.225,
          -210.93200000000002,
          -243.628,
          -276.311,
          -308.981,
          -341.63599999999997,
          -374.275,
          -406.89599999999996,
          -439.499,
          -472.082,
          -504.64300000000003,
          -537.182,
          -569.698,
          -602.188,
          -634.6519999999999,
          -667.0889999999999,
          -699.497,
          -731.875,
          -764.222,
          -796.5360000000001,
          -828.816,
          -861.061,
          -893.27,
          -925.441,
          -957.573,
          -989.665,
          -1021.716,
          -1053.723,
          -1085.687,
          -1117.605,
          -1149.4769999999999,
          -1181.3,
          -1213.0739999999998,
          -1244.798,
          -1276.469,
          -1308.087,
          -1339.651,
          -1371.158,
          -1402.609,
          -1434,
          -1465.332,
          -1496.602,
          -1527.809,
          -1558.9520000000002,
          -1590.029,
          -1621.04,
          -1651.9820000000002,
          -1682.854,
          -1713.655,
          -1744.3829999999998,
          -1775.037,
          -1805.616,
          -1836.1170000000002,
          -1866.54,
          -1896.8829999999998,
          -1927.144,
          -1957.3220000000001,
          -1987.415,
          -2017.422,
          -2047.3410000000001,
          -2077.1710000000003,
          -2106.911,
          -2136.5570000000002,
          -2166.11,
          -2195.5660000000003,
          -2224.926,
          -2254.186,
          -2283.346,
          -2312.403,
          -2341.355,
          -2370.202,
          -2398.942,
          -2427.572,
          -2456.091,
          -2484.496,
          -2512.7870000000003,
          -2540.9610000000002,
          -2569.0170000000003,
          -2596.952,
          -2624.765,
          -2652.454,
          -2680.0159999999996,
          -2707.45,
          -2734.7529999999997,
          -2761.925,
          -2788.962,
          -2815.862,
          -2842.6240000000003,
          -2869.2459999999996,
          -2895.724,
          -2922.0570000000002,
          -2948.243,
          -2974.2790000000005,
          -3000.164,
          -3025.8940000000002,
          -3051.467,
          -3076.881,
          -3102.134,
          -3127.223,
          -3152.1459999999997,
          -3176.8990000000003,
          -3201.4809999999998,
          -3225.889,
          -3250.12,
          -3274.171,
          -3298.04,
          -3321.723,
          -3345.219,
          -3368.5240000000003,
          -3391.634,
          -3414.548,
          -3437.262,
          -3459.7729999999997,
          -3482.078,
          -3504.173,
          -3526.0559999999996,
          -3547.723,
          -3569.17,
          -3590.3940000000002,
          -3611.3920000000003,
          -3632.159,
          -3652.6929999999998,
          -3672.99,
          -3693.045,
          -3712.8559999999998,
          -3732.417,
          -3751.725,
          -3770.777,
          -3789.566,
          -3808.091,
          -3826.345,
          -3844.324,
          -3862.025,
          -3879.442,
          -3896.57,
          -3913.405,
          -3929.942,
          -3946.175,
          -3962.1,
          -3977.711,
          -3993.0029999999997,
          -4007.969,
          -4022.605,
          -4036.905,
          -4050.863,
          -4064.472,
          -4077.7259999999997,
          -4090.619,
          -4103.144,
          -4115.295,
          -4127.065,
          -4138.446,
          -4149.432,
          -4160.014,
          -4170.186,
          -4179.939,
          -4189.266,
          -4198.157,
          -4206.606,
          -4214.602,
          -4222.138,
          -4229.202,
          -4235.787,
          -4241.883,
          -4247.478,
          -4252.564,
          -4257.129,
          -4261.162,
          -4264.653,
          -4267.589,
          -4269.958,
          -4271.749,
          -4272.948,
          -4273.543,
          -4273.519,
          -4272.862,
          -4271.559,
          -4269.594,
          -4266.951,
          -4263.615,
          -4259.57,
          -4254.7970000000005,
          -4249.28,
          -4243,
          -4235.938,
          -4228.075,
          -4219.39,
          -4209.861,
          -4199.468,
          -4188.186,
          -4175.994000000001,
          -4162.865,
          -4148.775,
          -4133.698,
          -4117.606,
          -4100.469,
          -4082.26,
          -4062.946,
          -4042.4959999999996,
          -4020.8759999999997,
          -3998.051,
          -3973.985,
          -3948.639,
          -3921.975,
          -3893.9509999999996,
          -3864.525,
          -3833.651,
          -3801.283,
          -3767.3720000000003,
          -3731.867,
          -3694.715,
          -3655.861,
          -3615.2470000000003,
          -3572.8109999999997,
          -3528.493,
          -3482.225,
          -3433.94,
          -3383.566,
          -3331.031,
          -3276.256,
          -3219.1609999999996,
          -3159.665,
          -3097.6820000000002,
          -3033.1240000000003,
          -2965.901,
          -2895.9190000000003,
          -2823.085,
          -2747.303,
          -2668.4759999999997,
          -2586.51,
          -2501.3089999999997,
          -2412.78,
          -2320.8360000000002,
          -2225.395,
          -2126.385,
          -2023.74,
          -1917.4129999999998,
          -1807.372,
          -1693.609,
          -1576.139,
          -1455.007,
          -1330.295,
          -1202.126,
          -1070.663,
          -936.118,
          -798.7539999999999,
          -658.885,
          -516.876,
          -373.135,
          -228.11700000000002,
          -82.307,
          63.783,
          209.63099999999997,
          354.713,
          498.519,
          640.562,
          780.3910000000001,
          917.595,
          1051.818,
          1182.75,
          1310.141,
          1433.786,
          1553.537,
          1669.2879999999998,
          1780.979,
          1888.58,
          1992.099,
          2091.567,
          2187.038,
          2278.584,
          2366.2889999999998,
          2450.25,
          2530.57,
          2607.357,
          2680.723,
          2750.782,
          2817.6479999999997,
          2881.4320000000002,
          2942.2459999999996,
          3000.199,
          3055.397,
          3107.9440000000004,
          3157.938,
          3205.474,
          3250.6479999999997,
          3293.546,
          3334.2540000000004,
          3372.855,
          3409.426,
          3444.0409999999997,
          3476.7740000000003,
          3507.692,
          3536.86,
          3564.342,
          3590.197,
          3614.4809999999998,
          3637.2509999999997,
          3658.5570000000002,
          3678.449,
          3696.975,
          3714.18,
          3730.107,
          3744.8,
          3758.296,
          3770.635,
          3781.853,
          3791.985,
          3801.0640000000003,
          3809.123,
          3816.192,
          3822.301,
          3827.478,
          3831.75,
          3835.145,
          3837.6859999999997,
          3839.3979999999997,
          3840.304,
          3840.427,
          3839.789,
          3838.409,
          3836.308,
          3833.506,
          3830.02,
          3825.869,
          3821.07,
          3815.64,
          3809.594,
          3802.949,
          3795.72,
          3787.921,
          3779.565,
          3770.667,
          3761.239,
          3751.295,
          3740.847,
          3729.907,
          3718.486,
          3706.595,
          3694.2459999999996,
          3681.448,
          3668.2129999999997,
          3654.55,
          3640.469,
          3625.978,
          3611.0879999999997,
          3595.8070000000002,
          3580.1440000000002,
          3564.1059999999998,
          3547.703,
          3530.942,
          3513.83,
          3496.375,
          3478.585,
          3460.467,
          3442.027,
          3423.2709999999997,
          3404.208,
          3384.843,
          3365.1820000000002,
          3345.232,
          3324.9970000000003,
          3304.486,
          3283.7009999999996,
          3262.65,
          3241.3379999999997,
          3219.77,
          3197.9509999999996,
          3175.886,
          3153.58,
          3131.038,
          3108.264,
          3085.264,
          3062.04,
          3038.599,
          3014.9440000000004,
          2991.08,
          2967.01,
          2942.738,
          2918.2690000000002,
          2893.607,
          2868.755,
          2843.716,
          2818.495,
          2793.0959999999995,
          2767.5209999999997,
          2741.7740000000003,
          2715.8579999999997,
          2689.777,
          2663.535,
          2637.133,
          2610.575,
          2583.865,
          2557.006,
          2529.999,
          2502.849,
          2475.558,
          2448.129,
          2420.564,
          2392.867,
          2365.04,
          2337.0860000000002,
          2309.007,
          2280.805,
          2252.484,
          2224.0460000000003,
          2195.493,
          2166.828,
          2138.052,
          2109.169,
          2080.18,
          2051.0879999999997,
          2021.895,
          1992.604,
          1963.215,
          1933.7320000000002,
          1904.1570000000002,
          1874.491,
          1844.737,
          1814.896,
          1784.9720000000002,
          1754.964,
          1724.8770000000002,
          1694.711,
          1664.4679999999998,
          1634.15,
          1603.76,
          1573.2979999999998,
          1542.767,
          1512.168,
          1481.504,
          1450.775,
          1419.984,
          1389.1329999999998,
          1358.2220000000002,
          1327.255,
          1296.231,
          1265.154,
          1234.024,
          1202.843,
          1171.613,
          1140.336,
          1109.012,
          1077.644,
          1046.233,
          1014.78,
          983.2869999999999,
          951.7560000000001,
          920.187,
          888.5830000000001,
          856.945,
          825.2739999999999,
          793.572,
          761.84,
          730.079,
          698.2919999999999,
          666.4789999999999,
          634.641,
          602.781,
          570.899,
          538.997,
          507.07599999999996,
          475.13699999999994,
          443.18300000000005,
          411.213,
          379.23,
          347.235,
          315.22900000000004,
          283.21299999999997,
          251.18900000000002,
          219.158,
          187.12099999999998,
          155.08,
          123.036,
          90.99,
          58.943000000000005,
          26.897,
          -5.148,
          -37.189,
          -69.226,
          -101.257,
          -133.281,
          -165.298,
          -197.304,
          -229.301,
          -261.285,
          -293.256,
          -325.21299999999997,
          -357.154,
          -389.079,
          -420.985,
          -452.87199999999996,
          -484.73900000000003,
          -516.5840000000001,
          -548.406,
          -580.203,
          -611.976,
          -643.721,
          -675.439,
          -707.128,
          -738.7860000000001,
          -770.4119999999999,
          -802.0060000000001,
          -833.565,
          -865.0889999999999,
          -896.577,
          -928.0260000000001,
          -959.436,
          -990.806,
          -1022.1339999999999,
          -1053.42,
          -1084.661,
          -1115.856,
          -1147.005,
          -1178.105,
          -1209.157,
          -1240.157,
          -1271.105,
          -1302.001,
          -1332.8410000000001,
          -1363.626,
          -1394.3529999999998,
          -1425.021,
          -1455.63,
          -1486.1770000000001,
          -1516.662,
          -1547.082,
          -1577.4370000000001,
          -1607.725,
          -1637.945,
          -1668.095,
          -1698.174,
          -1728.181,
          -1758.1129999999998,
          -1787.971,
          -1817.751,
          -1847.453,
          -1877.075,
          -1906.616,
          -1936.0739999999998,
          -1965.4470000000001,
          -1994.735,
          -2023.935,
          -2053.047,
          -2082.067,
          -2110.996,
          -2139.83,
          -2168.57,
          -2197.212,
          -2225.755,
          -2254.198,
          -2282.5389999999998,
          -2310.776,
          -2338.908,
          -2366.933,
          -2394.848,
          -2422.652,
          -2450.344,
          -2477.922,
          -2505.383,
          -2532.726,
          -2559.949,
          -2587.05,
          -2614.027,
          -2640.8779999999997,
          -2667.6020000000003,
          -2694.195,
          -2720.656,
          -2746.9840000000004,
          -2773.175,
          -2799.2290000000003,
          -2825.1409999999996,
          -2850.9120000000003,
          -2876.5370000000003,
          -2902.0159999999996,
          -2927.345,
          -2952.522,
          -2977.546,
          -3002.413,
          -3027.1220000000003,
          -3051.67,
          -3076.053,
          -3100.2709999999997,
          -3124.32,
          -3148.197,
          -3171.9,
          -3195.427,
          -3218.7740000000003,
          -3241.9390000000003,
          -3264.9179999999997,
          -3287.71,
          -3310.3109999999997,
          -3332.719,
          -3354.929,
          -3376.9390000000003,
          -3398.7459999999996,
          -3420.347,
          -3441.738,
          -3462.917,
          -3483.8790000000004,
          -3504.6209999999996,
          -3525.14,
          -3545.4320000000002,
          -3565.494,
          -3585.322,
          -3604.9120000000003,
          -3624.26,
          -3643.363,
          -3662.215,
          -3680.8140000000003,
          -3699.155,
          -3717.2340000000004,
          -3735.046,
          -3752.587,
          -3769.853,
          -3786.8379999999997,
          -3803.538,
          -3819.949,
          -3836.0640000000003,
          -3851.88,
          -3867.3909999999996,
          -3882.591,
          -3897.4759999999997,
          -3912.039,
          -3926.275,
          -3940.179,
          -3953.744,
          -3966.9629999999997,
          -3979.8320000000003,
          -3992.343,
          -4004.49,
          -4016.2659999999996,
          -4027.664,
          -4038.678,
          -4049.2990000000004,
          -4059.5209999999997,
          -4069.336,
          -4078.735,
          -4087.712,
          -4096.2570000000005,
          -4104.362,
          -4112.019,
          -4119.217000000001,
          -4125.9490000000005,
          -4132.204000000001,
          -4137.973,
          -4143.245,
          -4148.01,
          -4152.258,
          -4155.978,
          -4159.157,
          -4161.785,
          -4163.849,
          -4165.337,
          -4166.236,
          -4166.532999999999,
          -4166.214,
          -4165.265,
          -4163.670999999999,
          -4161.417,
          -4158.488,
          -4154.867,
          -4150.538,
          -4145.484,
          -4139.686,
          -4133.126,
          -4125.785,
          -4117.644,
          -4108.68,
          -4098.873,
          -4088.2009999999996,
          -4076.64,
          -4064.167,
          -4050.757,
          -4036.384,
          -4021.0209999999997,
          -4004.64,
          -3987.2129999999997,
          -3968.7090000000003,
          -3949.0959999999995,
          -3928.343,
          -3906.415,
          -3883.275,
          -3858.888,
          -3833.2140000000004,
          -3806.2140000000004,
          -3777.845,
          -3748.0640000000003,
          -3716.824,
          -3684.079,
          -3649.778,
          -3613.87,
          -3576.301,
          -3537.012,
          -3495.947,
          -3453.042,
          -3408.2340000000004,
          -3361.4559999999997,
          -3312.639,
          -3261.7090000000003,
          -3208.593,
          -3153.21,
          -3095.4809999999998,
          -3035.322,
          -2972.645,
          -2907.364,
          -2839.387,
          -2768.6209999999996,
          -2694.9709999999995,
          -2618.344,
          -2538.644,
          -2455.78,
          -2369.658,
          -2280.1929999999998,
          -2187.302,
          -2090.913,
          -1990.961,
          -1887.399,
          -1780.192,
          -1669.3310000000001,
          -1554.825,
          -1436.719,
          -1315.089,
          -1190.05,
          -1061.76,
          -930.421,
          -796.2869999999999,
          -659.6610000000001,
          -520.896,
          -380.39,
          -238.585,
          -95.95200000000001,
          47.011,
          189.791,
          331.87699999999995,
          472.767,
          611.9830000000001,
          749.081,
          883.658,
          1015.3580000000001,
          1143.878,
          1268.964,
          1390.415,
          1508.082,
          1621.8570000000002,
          1731.6760000000002,
          1837.509,
          1939.359,
          2037.255,
          2131.2470000000003,
          2221.403,
          2307.804,
          2390.544,
          2469.72,
          2545.439,
          2617.8089999999997,
          2686.94,
          2752.9429999999998,
          2815.927,
          2876.0009999999997,
          2933.2709999999997,
          2987.84,
          3039.809,
          3089.275,
          3136.3320000000003,
          3181.0690000000004,
          3223.322,
          3263.933,
          3302.224,
          3338.5209999999997,
          3372.9,
          3405.4309999999996,
          3436.18,
          3465.212,
          3492.5879999999997,
          3518.366,
          3542.6020000000003,
          3565.3509999999997,
          3586.6609999999996,
          3606.583,
          3625.163,
          3642.446,
          3658.474,
          3673.288,
          3686.926,
          3699.428,
          3710.827,
          3721.159,
          3730.4559999999997,
          3738.7509999999997,
          3746.073,
          3752.45,
          3757.9109999999996,
          3762.4829999999997,
          3766.191,
          3769.0609999999997,
          3771.115,
          3772.3759999999997,
          3772.867,
          3772.6090000000004,
          3771.6209999999996,
          3769.925,
          3767.538,
          3764.478,
          3760.764,
          3756.4120000000003,
          3751.4390000000003,
          3745.861,
          3739.692,
          3732.947,
          3725.6420000000003,
          3717.79,
          3709.403,
          3700.494,
          3691.078,
          3681.164,
          3670.7659999999996,
          3659.8940000000002,
          3648.559,
          3636.7729999999997,
          3624.545,
          3611.886,
          3598.805,
          3585.312,
          3571.4159999999997,
          3557.1259999999997,
          3542.4509999999996,
          3527.3979999999997,
          3511.9770000000003,
          3496.195,
          3480.06,
          3463.579,
          3446.761,
          3429.611,
          3412.137,
          3394.3459999999995,
          3376.244,
          3357.8390000000004,
          3339.135,
          3320.139,
          3300.8590000000004,
          3281.297,
          3261.461,
          3241.357,
          3220.989,
          3200.363,
          3179.4840000000004,
          3158.357,
          3136.987,
          3115.3790000000004,
          3093.538,
          3071.468,
          3049.173,
          3026.659,
          3003.929,
          2980.988,
          2957.8390000000004,
          2934.488,
          2910.937,
          2887.191,
          2863.2529999999997,
          2839.127,
          2814.817,
          2790.327,
          2765.659,
          2740.8179999999998,
          2715.8070000000002,
          2690.6279999999997,
          2665.2859999999996,
          2639.783,
          2614.123,
          2588.3089999999997,
          2562.343,
          2536.229,
          2509.969,
          2483.567,
          2457.025,
          2430.346,
          2403.532,
          2376.587,
          2349.513,
          2322.312,
          2294.988,
          2267.542,
          2239.9770000000003,
          2212.295,
          2184.5,
          2156.592,
          2128.575,
          2100.451,
          2072.222,
          2043.89,
          2015.4579999999999,
          1986.9270000000001,
          1958.299,
          1929.578,
          1900.764,
          1871.86,
          1842.868,
          1813.789,
          1784.6270000000002,
          1755.382,
          1726.056,
          1696.652,
          1667.172,
          1637.616,
          1607.987,
          1578.2879999999998,
          1548.5179999999998,
          1518.681,
          1488.7779999999998,
          1458.81,
          1428.78,
          1398.6889999999999,
          1368.5379999999998,
          1338.33,
          1308.066,
          1277.747,
          1247.375,
          1216.952,
          1186.48,
          1155.9589999999998,
          1125.391,
          1094.778,
          1064.121,
          1033.422,
          1002.683,
          971.904,
          941.087,
          910.2330000000001,
          879.345,
          848.423,
          817.4689999999999,
          786.485,
          755.47,
          724.428,
          693.3589999999999,
          662.265,
          631.1469999999999,
          600.006,
          568.8430000000001,
          537.6619999999999,
          506.461,
          475.24300000000005,
          444.009,
          412.76,
          381.49800000000005,
          350.223,
          318.937,
          287.642,
          256.339,
          225.028,
          193.71099999999998,
          162.39,
          131.065,
          99.73899999999999,
          68.411,
          37.084,
          5.757999999999999,
          -25.565,
          -56.88399999999999,
          -88.198,
          -119.505,
          -150.805,
          -182.095,
          -213.37599999999998,
          -244.645,
          -275.902,
          -307.145,
          -338.374,
          -369.586,
          -400.78,
          -431.957,
          -463.11300000000006,
          -494.24800000000005,
          -525.362,
          -556.452,
          -587.5169999999999,
          -618.556,
          -649.569,
          -680.553,
          -711.508,
          -742.432,
          -773.324,
          -804.183,
          -835.008,
          -865.798,
          -896.55,
          -927.2639999999999,
          -957.94,
          -988.574,
          -1019.1669999999999,
          -1049.7169999999999,
          -1080.223,
          -1110.683,
          -1141.096,
          -1171.461,
          -1201.777,
          -1232.0430000000001,
          -1262.256,
          -1292.4160000000002,
          -1322.5220000000002,
          -1352.5720000000001,
          -1382.5639999999999,
          -1412.4979999999998,
          -1442.3729999999998,
          -1472.1860000000001,
          -1501.9370000000001,
          -1531.6229999999998,
          -1561.245,
          -1590.8,
          -1620.287,
          -1649.705,
          -1679.0520000000001,
          -1708.3270000000002,
          -1737.5279999999998,
          -1766.654,
          -1795.703,
          -1824.675,
          -1853.567,
          -1882.378,
          -1911.1070000000002,
          -1939.7520000000002,
          -1968.3110000000001,
          -1996.7839999999999,
          -2025.1670000000001,
          -2053.4610000000002,
          -2081.663,
          -2109.772,
          -2137.785,
          -2165.703,
          -2193.522,
          -2221.241,
          -2248.8579999999997,
          -2276.3720000000003,
          -2303.782,
          -2331.084,
          -2358.278,
          -2385.362,
          -2412.333,
          -2439.1910000000003,
          -2465.933,
          -2492.558,
          -2519.062,
          -2545.446,
          -2571.706,
          -2597.841,
          -2623.848,
          -2649.7259999999997,
          -2675.473,
          -2701.086,
          -2726.5640000000003,
          -2751.9040000000005,
          -2777.105,
          -2802.163,
          -2827.077,
          -2851.844,
          -2876.4629999999997,
          -2900.9309999999996,
          -2925.245,
          -2949.403,
          -2973.4040000000005,
          -2997.243,
          -3020.9190000000003,
          -3044.429,
          -3067.7709999999997,
          -3090.9429999999998,
          -3113.94,
          -3136.761,
          -3159.403,
          -3181.863,
          -3204.138,
          -3226.225,
          -3248.1220000000003,
          -3269.825,
          -3291.3320000000003,
          -3312.639,
          -3333.742,
          -3354.64,
          -3375.328,
          -3395.803,
          -3416.062,
          -3436.1009999999997,
          -3455.9159999999997,
          -3475.505,
          -3494.864,
          -3513.988,
          -3532.8740000000003,
          -3551.518,
          -3569.915,
          -3588.063,
          -3605.9559999999997,
          -3623.59,
          -3640.962,
          -3658.066,
          -3674.8990000000003,
          -3691.455,
          -3707.7290000000003,
          -3723.718,
          -3739.4159999999997,
          -3754.817,
          -3769.9179999999997,
          -3784.712,
          -3799.1940000000004,
          -3813.3579999999997,
          -3827.2,
          -3840.7129999999997,
          -3853.89,
          -3866.7270000000003,
          -3879.216,
          -3891.3520000000003,
          -3903.1279999999997,
          -3914.5370000000003,
          -3925.572,
          -3936.2259999999997,
          -3946.492,
          -3956.362,
          -3965.829,
          -3974.885,
          -3983.522,
          -3991.7309999999998,
          -3999.5040000000004,
          -4006.8320000000003,
          -4013.7059999999997,
          -4020.118,
          -4026.0559999999996,
          -4031.511,
          -4036.474,
          -4040.934,
          -4044.88,
          -4048.3,
          -4051.185,
          -4053.5209999999997,
          -4055.297,
          -4056.5,
          -4057.117,
          -4057.135,
          -4056.54,
          -4055.317,
          -4053.453,
          -4050.9320000000002,
          -4047.738,
          -4043.8540000000003,
          -4039.265,
          -4033.952,
          -4027.897,
          -4021.083,
          -4013.488,
          -4005.093,
          -3995.8779999999997,
          -3985.82,
          -3974.897,
          -3963.086,
          -3950.362,
          -3936.7009999999996,
          -3922.075,
          -3906.4590000000003,
          -3889.823,
          -3872.138,
          -3853.3740000000003,
          -3833.498,
          -3812.4759999999997,
          -3790.275,
          -3766.8590000000004,
          -3742.188,
          -3716.225,
          -3688.929,
          -3660.255,
          -3630.1609999999996,
          -3598.599,
          -3565.52,
          -3530.8740000000003,
          -3494.6079999999997,
          -3456.6659999999997,
          -3416.991,
          -3375.5229999999997,
          -3332.198,
          -3286.952,
          -3239.716,
          -3190.4190000000003,
          -3138.987,
          -3085.3459999999995,
          -3029.414,
          -2971.1090000000004,
          -2910.348,
          -2847.042,
          -2781.1040000000003,
          -2712.442,
          -2640.9640000000004,
          -2566.575,
          -2489.1839999999997,
          -2408.7,
          -2325.029,
          -2238.0879999999997,
          -2147.7960000000003,
          -2054.0789999999997,
          -1956.8729999999998,
          -1856.13,
          -1751.815,
          -1643.912,
          -1532.433,
          -1417.418,
          -1298.935,
          -1177.094,
          -1052.045,
          -923.9860000000001,
          -793.1569999999999,
          -659.852,
          -524.411,
          -387.221,
          -248.708,
          -109.335,
          30.415,
          170.042,
          309.045,
          446.93300000000005,
          583.238,
          717.5210000000001,
          849.3860000000001,
          978.4830000000001,
          1104.508,
          1227.211,
          1346.3929999999998,
          1461.901,
          1573.6270000000002,
          1681.505,
          1785.504,
          1885.62,
          1981.882,
          2074.3360000000002,
          2163.045,
          2248.087,
          2329.552,
          2407.536,
          2482.138,
          2553.466,
          2621.627,
          2686.7259999999997,
          2748.87,
          2808.1659999999997,
          2864.717,
          2918.623,
          2969.982,
          3018.889,
          3065.4359999999997,
          3109.711,
          3151.8,
          3191.782,
          3229.737,
          3265.739,
          3299.86,
          3332.1679999999997,
          3362.7309999999998,
          3391.6079999999997,
          3418.861,
          3444.546,
          3468.719,
          3491.4320000000002,
          3512.735,
          3532.675,
          3551.298,
          3568.6479999999997,
          3584.7659999999996,
          3599.692,
          3613.465,
          3626.1209999999996,
          3637.695,
          3648.2209999999995,
          3657.73,
          3666.255,
          3673.824,
          3680.467,
          3686.2090000000003,
          3691.078,
          3695.098,
          3698.2929999999997,
          3700.688,
          3702.304,
          3703.1620000000003,
          3703.284,
          3702.69,
          3701.3979999999997,
          3699.428,
          3696.797,
          3693.522,
          3689.62,
          3685.107,
          3679.998,
          3674.309,
          3668.055,
          3661.248,
          3653.903,
          3646.032,
          3637.6479999999997,
          3628.763,
          3619.39,
          3609.54,
          3599.224,
          3588.453,
          3577.236,
          3565.586,
          3553.51,
          3541.0190000000002,
          3528.123,
          3514.829,
          3501.1479999999997,
          3487.086,
          3472.6540000000005,
          3457.8579999999997,
          3442.7070000000003,
          3427.2070000000003,
          3411.368,
          3395.195,
          3378.695,
          3361.877,
          3344.7459999999996,
          3327.308,
          3309.57,
          3291.539,
          3273.22,
          3254.619,
          3235.742,
          3216.594,
          3197.1809999999996,
          3177.508,
          3157.58,
          3137.403,
          3116.9809999999998,
          3096.3190000000004,
          3075.422,
          3054.295,
          3032.941,
          3011.367,
          2989.574,
          2967.5690000000004,
          2945.355,
          2922.937,
          2900.317,
          2877.5,
          2854.491,
          2831.292,
          2807.907,
          2784.34,
          2760.594,
          2736.673,
          2712.5809999999997,
          2688.3190000000004,
          2663.893,
          2639.304,
          2614.5570000000002,
          2589.653,
          2564.597,
          2539.39,
          2514.0370000000003,
          2488.54,
          2462.901,
          2437.123,
          2411.21,
          2385.163,
          2358.986,
          2332.68,
          2306.249,
          2279.696,
          2253.021,
          2226.228,
          2199.32,
          2172.298,
          2145.165,
          2117.923,
          2090.574,
          2063.121,
          2035.566,
          2007.911,
          1980.1570000000002,
          1952.308,
          1924.364,
          1896.329,
          1868.203,
          1839.99,
          1811.691,
          1783.307,
          1754.842,
          1726.296,
          1697.671,
          1668.97,
          1640.194,
          1611.345,
          1582.424,
          1553.434,
          1524.376,
          1495.251,
          1466.0620000000001,
          1436.81,
          1407.497,
          1378.124,
          1348.693,
          1319.205,
          1289.662,
          1260.067,
          1230.4189999999999,
          1200.721,
          1170.974,
          1141.18,
          1111.34,
          1081.4560000000001,
          1051.529,
          1021.56,
          991.551,
          961.5039999999999,
          931.42,
          901.299,
          871.145,
          840.957,
          810.737,
          780.488,
          750.209,
          719.9019999999999,
          689.57,
          659.212,
          628.83,
          598.4259999999999,
          568.001,
          537.557,
          507.093,
          476.61300000000006,
          446.116,
          415.60400000000004,
          385.08,
          354.542,
          323.994,
          293.436,
          262.87,
          232.296,
          201.71599999999998,
          171.132,
          140.543,
          109.95299999999999,
          79.361,
          48.769,
          18.178,
          -12.411,
          -42.996,
          -73.57600000000001,
          -104.15,
          -134.717,
          -165.27599999999998,
          -195.825,
          -226.364,
          -256.89099999999996,
          -287.405,
          -317.904,
          -348.38800000000003,
          -378.856,
          -409.305,
          -439.736,
          -470.147,
          -500.536,
          -530.903,
          -561.246,
          -591.565,
          -621.857,
          -652.122,
          -682.3589999999999,
          -712.566,
          -742.742,
          -772.8860000000001,
          -802.997,
          -833.074,
          -863.115,
          -893.1189999999999,
          -923.086,
          -953.013,
          -982.8989999999999,
          -1012.7439999999999,
          -1042.546,
          -1072.303,
          -1102.016,
          -1131.681,
          -1161.299,
          -1190.867,
          -1220.386,
          -1249.8519999999999,
          -1279.265,
          -1308.625,
          -1337.9279999999999,
          -1367.175,
          -1396.364,
          -1425.493,
          -1454.5610000000001,
          -1483.567,
          -1512.51,
          -1541.388,
          -1570.2,
          -1598.944,
          -1627.619,
          -1656.224,
          -1684.757,
          -1713.2179999999998,
          -1741.6029999999998,
          -1769.9129999999998,
          -1798.145,
          -1826.2979999999998,
          -1854.371,
          -1882.361,
          -1910.269,
          -1938.092,
          -1965.828,
          -1993.476,
          -2021.035,
          -2048.502,
          -2075.877,
          -2103.158,
          -2130.343,
          -2157.43,
          -2184.4179999999997,
          -2211.305,
          -2238.09,
          -2264.77,
          -2291.344,
          -2317.811,
          -2344.1679999999997,
          -2370.413,
          -2396.545,
          -2422.563,
          -2448.4629999999997,
          -2474.245,
          -2499.906,
          -2525.444,
          -2550.8579999999997,
          -2576.145,
          -2601.303,
          -2626.3309999999997,
          -2651.2259999999997,
          -2675.987,
          -2700.61,
          -2725.095,
          -2749.438,
          -2773.637,
          -2797.691,
          -2821.597,
          -2845.3520000000003,
          -2868.954,
          -2892.402,
          -2915.691,
          -2938.821,
          -2961.788,
          -2984.59,
          -3007.225,
          -3029.688,
          -3051.9790000000003,
          -3074.094,
          -3096.031,
          -3117.7859999999996,
          -3139.3559999999998,
          -3160.74,
          -3181.933,
          -3202.934,
          -3223.738,
          -3244.342,
          -3264.744,
          -3284.94,
          -3304.927,
          -3324.7009999999996,
          -3344.259,
          -3363.597,
          -3382.7129999999997,
          -3401.6020000000003,
          -3420.26,
          -3438.684,
          -3456.869,
          -3474.812,
          -3492.509,
          -3509.9559999999997,
          -3527.1479999999997,
          -3544.0809999999997,
          -3560.75,
          -3577.152,
          -3593.282,
          -3609.134,
          -3624.704,
          -3639.988,
          -3654.98,
          -3669.6740000000004,
          -3684.066,
          -3698.151,
          -3711.922,
          -3725.375,
          -3738.5029999999997,
          -3751.3,
          -3763.76,
          -3775.8779999999997,
          -3787.6459999999997,
          -3799.059,
          -3810.1090000000004,
          -3820.789,
          -3831.093,
          -3841.013,
          -3850.542,
          -3859.672,
          -3868.395,
          -3876.703,
          -3884.587,
          -3892.04,
          -3899.053,
          -3905.617,
          -3911.7209999999995,
          -3917.3559999999998,
          -3922.513,
          -3927.1820000000002,
          -3931.3509999999997,
          -3935.011,
          -3938.1490000000003,
          -3940.756,
          -3942.8179999999998,
          -3944.323,
          -3945.26,
          -3945.615,
          -3945.3740000000003,
          -3944.5229999999997,
          -3943.0490000000004,
          -3940.937,
          -3938.17,
          -3934.7340000000004,
          -3930.611,
          -3925.785,
          -3920.239,
          -3913.954,
          -3906.91,
          -3899.0890000000004,
          -3890.469,
          -3881.031,
          -3870.7509999999997,
          -3859.6079999999997,
          -3847.577,
          -3834.634,
          -3820.7540000000004,
          -3805.909,
          -3790.073,
          -3773.216,
          -3755.309,
          -3736.321,
          -3716.218,
          -3694.968,
          -3672.534,
          -3648.88,
          -3623.968,
          -3597.758,
          -3570.2070000000003,
          -3541.2729999999997,
          -3510.9109999999996,
          -3479.071,
          -3445.7059999999997,
          -3410.762,
          -3374.1859999999997,
          -3335.923,
          -3295.9120000000003,
          -3254.094,
          -3210.403,
          -3164.772,
          -3117.134,
          -3067.415,
          -3015.542,
          -2961.4359999999997,
          -2905.0170000000003,
          -2846.202,
          -2784.906,
          -2721.042,
          -2654.52,
          -2585.25,
          -2513.139,
          -2438.098,
          -2360.034,
          -2278.86,
          -2194.49,
          -2106.843,
          -2015.849,
          -1921.441,
          -1823.57,
          -1722.201,
          -1617.318,
          -1508.9260000000002,
          -1397.0610000000001,
          -1281.7910000000002,
          -1163.2160000000001,
          -1041.481,
          -916.7710000000001,
          -789.322,
          -659.415,
          -527.377,
          -393.583,
          -258.448,
          -122.41799999999999,
          14.034,
          150.422,
          286.256,
          421.056,
          554.362,
          685.7460000000001,
          814.816,
          941.2239999999999,
          1064.672,
          1184.913,
          1301.748,
          1415.021,
          1524.625,
          1630.491,
          1732.585,
          1830.9029999999998,
          1925.467,
          2016.3220000000001,
          2103.525,
          2187.153,
          2267.29,
          2344.029,
          2417.467,
          2487.706,
          2554.851,
          2619.0029999999997,
          2680.268,
          2738.7470000000003,
          2794.542,
          2847.75,
          2898.465,
          2946.782,
          2992.789,
          3036.573,
          3078.216,
          3117.797,
          3155.3920000000003,
          3191.0759999999996,
          3224.917,
          3256.982,
          3287.3379999999997,
          3316.042,
          3343.155,
          3368.7309999999998,
          3392.8259999999996,
          3415.489,
          3436.77,
          3456.715,
          3475.37,
          3492.775,
          3508.973,
          3524.002,
          3537.9,
          3550.703,
          3562.4440000000004,
          3573.158,
          3582.8740000000003,
          3591.6240000000003,
          3599.4359999999997,
          3606.3390000000004,
          3612.3590000000004,
          3617.5209999999997,
          3621.85,
          3625.37,
          3628.1040000000003,
          3630.073,
          3631.298,
          3631.801,
          3631.6,
          3630.7140000000004,
          3629.1620000000003,
          3626.96,
          3624.1259999999997,
          3620.676,
          3616.6259999999997,
          3611.991,
          3606.7859999999996,
          3601.0240000000003,
          3594.72,
          3587.887,
          3580.5370000000003,
          3572.6820000000002,
          3564.336,
          3555.509,
          3546.2140000000004,
          3536.4590000000003,
          3526.258,
          3515.618,
          3504.552,
          3493.067,
          3481.1740000000004,
          3468.882,
          3456.199,
          3443.134,
          3429.696,
          3415.8920000000003,
          3401.7309999999998,
          3387.219,
          3372.366,
          3357.176,
          3341.659,
          3325.821,
          3309.6679999999997,
          3293.2059999999997,
          3276.4429999999998,
          3259.385,
          3242.0370000000003,
          3224.406,
          3206.4959999999996,
          3188.315,
          3169.867,
          3151.157,
          3132.191,
          3112.974,
          3093.511,
          3073.8059999999996,
          3053.865,
          3033.692,
          3013.2909999999997,
          2992.667,
          2971.825,
          2950.768,
          2929.5009999999997,
          2908.028,
          2886.353,
          2864.4790000000003,
          2842.4109999999996,
          2820.152,
          2797.7059999999997,
          2775.0759999999996,
          2752.2659999999996,
          2729.28,
          2706.12,
          2682.79,
          2659.2940000000003,
          2635.634,
          2611.814,
          2587.837,
          2563.705,
          2539.422,
          2514.991,
          2490.413,
          2465.694,
          2440.834,
          2415.8360000000002,
          2390.7039999999997,
          2365.44,
          2340.047,
          2314.526,
          2288.881,
          2263.114,
          2237.2270000000003,
          2211.223,
          2185.103,
          2158.8720000000003,
          2132.529,
          2106.0789999999997,
          2079.5229999999997,
          2052.862,
          2026.1,
          1999.2379999999998,
          1972.279,
          1945.224,
          1918.076,
          1890.836,
          1863.506,
          1836.089,
          1808.586,
          1780.999,
          1753.33,
          1725.5810000000001,
          1697.753,
          1669.849,
          1641.869,
          1613.817,
          1585.693,
          1557.499,
          1529.237,
          1500.9089999999999,
          1472.516,
          1444.06,
          1415.5420000000001,
          1386.965,
          1358.328,
          1329.635,
          1300.887,
          1272.085,
          1243.231,
          1214.325,
          1185.371,
          1156.368,
          1127.32,
          1098.226,
          1069.089,
          1039.9089999999999,
          1010.689,
          981.429,
          952.132,
          922.797,
          893.428,
          864.025,
          834.5889999999999,
          805.1210000000001,
          775.6239999999999,
          746.0980000000001,
          716.545,
          686.966,
          657.362,
          627.735,
          598.085,
          568.414,
          538.724,
          509.015,
          479.289,
          449.54699999999997,
          419.79,
          390.02,
          360.23699999999997,
          330.444,
          300.64,
          270.827,
          241.007,
          211.18099999999998,
          181.34900000000002,
          151.514,
          121.675,
          91.836,
          61.995,
          32.155,
          2.318,
          -27.517,
          -57.348,
          -87.17299999999999,
          -116.991,
          -146.80200000000002,
          -176.604,
          -206.396,
          -236.17700000000002,
          -265.94599999999997,
          -295.70099999999996,
          -325.441,
          -355.166,
          -384.874,
          -414.564,
          -444.235,
          -473.885,
          -503.514,
          -533.12,
          -562.702,
          -592.259,
          -621.79,
          -651.294,
          -680.7689999999999,
          -710.215,
          -739.6289999999999,
          -769.012,
          -798.362,
          -827.677,
          -856.957,
          -886.2,
          -915.405,
          -944.571,
          -973.697,
          -1002.7810000000001,
          -1031.823,
          -1060.82,
          -1089.7730000000001,
          -1118.6789999999999,
          -1147.537,
          -1176.347,
          -1205.106,
          -1233.815,
          -1262.47,
          -1291.072,
          -1319.619,
          -1348.109,
          -1376.5410000000002,
          -1404.915,
          -1433.2279999999998,
          -1461.479,
          -1489.668,
          -1517.7920000000001,
          -1545.851,
          -1573.842,
          -1601.766,
          -1629.619,
          -1657.402,
          -1685.112,
          -1712.7479999999998,
          -1740.308,
          -1767.7920000000001,
          -1795.1979999999999,
          -1822.524,
          -1849.769,
          -1876.931,
          -1904.009,
          -1931.001,
          -1957.906,
          -1984.723,
          -2011.4489999999998,
          -2038.0829999999999,
          -2064.624,
          -2091.07,
          -2117.419,
          -2143.669,
          -2169.82,
          -2195.869,
          -2221.814,
          -2247.654,
          -2273.388,
          -2299.012,
          -2324.526,
          -2349.928,
          -2375.216,
          -2400.388,
          -2425.4410000000003,
          -2450.376,
          -2475.188,
          -2499.877,
          -2524.44,
          -2548.875,
          -2573.181,
          -2597.355,
          -2621.395,
          -2645.2990000000004,
          -2669.065,
          -2692.69,
          -2716.173,
          -2739.511,
          -2762.702,
          -2785.743,
          -2808.633,
          -2831.368,
          -2853.947,
          -2876.366,
          -2898.623,
          -2920.717,
          -2942.643,
          -2964.4,
          -2985.985,
          -3007.3940000000002,
          -3028.6259999999997,
          -3049.677,
          -3070.545,
          -3091.2259999999997,
          -3111.718,
          -3132.0170000000003,
          -3152.1209999999996,
          -3172.025,
          -3191.728,
          -3211.225,
          -3230.514,
          -3249.591,
          -3268.452,
          -3287.094,
          -3305.513,
          -3323.7059999999997,
          -3341.6690000000003,
          -3359.397,
          -3376.887,
          -3394.135,
          -3411.137,
          -3427.889,
          -3444.386,
          -3460.6240000000003,
          -3476.598,
          -3492.305,
          -3507.738,
          -3522.8940000000002,
          -3537.768,
          -3552.355,
          -3566.6490000000003,
          -3580.645,
          -3594.3379999999997,
          -3607.722,
          -3620.792,
          -3633.542,
          -3645.966,
          -3658.058,
          -3669.812,
          -3681.2209999999995,
          -3692.2790000000005,
          -3702.9790000000003,
          -3713.315,
          -3723.2790000000005,
          -3732.863,
          -3742.0609999999997,
          -3750.865,
          -3759.2670000000003,
          -3767.259,
          -3774.833,
          -3781.9790000000003,
          -3788.69,
          -3794.9559999999997,
          -3800.768,
          -3806.116,
          -3810.991,
          -3815.381,
          -3819.277,
          -3822.6679999999997,
          -3825.5429999999997,
          -3827.89,
          -3829.697,
          -3830.952,
          -3831.643,
          -3831.756,
          -3831.277,
          -3830.1940000000004,
          -3828.491,
          -3826.153,
          -3823.1659999999997,
          -3819.512,
          -3815.176,
          -3810.1409999999996,
          -3804.388,
          -3797.8990000000003,
          -3790.655,
          -3782.636,
          -3773.822,
          -3764.191,
          -3753.7209999999995,
          -3742.39,
          -3730.172,
          -3717.0440000000003,
          -3702.98,
          -3687.953,
          -3671.933,
          -3654.8940000000002,
          -3636.803,
          -3617.6290000000004,
          -3597.34,
          -3575.902,
          -3553.277,
          -3529.43,
          -3504.321,
          -3477.908,
          -3450.151,
          -3421.0029999999997,
          -3390.42,
          -3358.353,
          -3324.7509999999997,
          -3289.563,
          -3252.732,
          -3214.2009999999996,
          -3173.91,
          -3131.798,
          -3087.7990000000004,
          -3041.8459999999995,
          -2993.867,
          -2943.79,
          -2891.539,
          -2837.0370000000003,
          -2780.2,
          -2720.947,
          -2659.191,
          -2594.846,
          -2527.822,
          -2458.029,
          -2385.377,
          -2309.779,
          -2231.144,
          -2149.391,
          -2064.44,
          -1976.2160000000001,
          -1884.658,
          -1789.7160000000001,
          -1691.349,
          -1589.5420000000001,
          -1484.299,
          -1375.65,
          -1263.657,
          -1148.417,
          -1030.0639999999999,
          -908.779,
          -784.784,
          -658.3510000000001,
          -529.7959999999999,
          -399.48,
          -267.80400000000003,
          -135.203,
          -2.134,
          130.92700000000002,
          263.505,
          395.13,
          525.352,
          653.749,
          779.937,
          903.574,
          1024.364,
          1142.062,
          1256.47,
          1367.432,
          1474.84,
          1578.624,
          1678.745,
          1775.1979999999999,
          1868.001,
          1957.194,
          2042.8339999999998,
          2124.99,
          2203.745,
          2279.189,
          2351.413,
          2420.516,
          2486.6,
          2549.763,
          2610.107,
          2667.7309999999998,
          2722.7329999999997,
          2775.2070000000003,
          2825.2459999999996,
          2872.941,
          2918.3790000000004,
          2961.6420000000003,
          3003.012,
          3041.965,
          3079.177,
          3114.5190000000002,
          3148.058,
          3179.86,
          3209.988,
          3238.5,
          3265.455,
          3290.907,
          3314.908,
          3337.507,
          3358.7529999999997,
          3378.69,
          3397.363,
          3414.8140000000003,
          3431.0809999999997,
          3446.204,
          3460.219,
          3473.16,
          3485.062,
          3495.955,
          3505.8720000000003,
          3514.842,
          3522.893,
          3530.052,
          3536.345,
          3541.798,
          3546.434,
          3550.276,
          3553.347,
          3555.6690000000003,
          3557.261,
          3558.1440000000002,
          3558.336,
          3557.857,
          3556.724,
          3554.953,
          3552.563,
          3549.567,
          3545.9829999999997,
          3541.824,
          3537.1059999999998,
          3531.842,
          3526.045,
          3519.7270000000003,
          3512.903,
          3505.5840000000003,
          3497.781,
          3489.507,
          3480.7709999999997,
          3471.585,
          3461.96,
          3451.905,
          3441.429,
          3430.5429999999997,
          3419.256,
          3407.5759999999996,
          3395.512,
          3383.072,
          3370.265,
          3357.099,
          3343.5809999999997,
          3329.719,
          3315.52,
          3300.992,
          3286.1409999999996,
          3270.973,
          3255.4959999999996,
          3239.716,
          3223.638,
          3207.27,
          3190.617,
          3173.684,
          3156.478,
          3139.0040000000004,
          3121.2670000000003,
          3103.272,
          3085.025,
          3066.531,
          3047.7940000000003,
          3028.8190000000004,
          3009.611,
          2990.1740000000004,
          2970.513,
          2950.632,
          2930.5359999999996,
          2910.228,
          2889.7129999999997,
          2868.994,
          2848.0759999999996,
          2826.962,
          2805.656,
          2784.1609999999996,
          2762.482,
          2740.6220000000003,
          2718.5840000000003,
          2696.3709999999996,
          2673.987,
          2651.4359999999997,
          2628.719,
          2605.841,
          2582.805,
          2559.612,
          2536.268,
          2512.7729999999997,
          2489.132,
          2465.347,
          2441.42,
          2417.355,
          2393.153,
          2368.819,
          2344.353,
          2319.759,
          2295.04,
          2270.196,
          2245.232,
          2220.149,
          2194.95,
          2169.637,
          2144.212,
          2118.677,
          2093.034,
          2067.2870000000003,
          2041.4360000000001,
          2015.484,
          1989.433,
          1963.285,
          1937.0420000000001,
          1910.705,
          1884.2779999999998,
          1857.761,
          1831.1570000000002,
          1804.467,
          1777.694,
          1750.839,
          1723.904,
          1696.89,
          1669.8,
          1642.635,
          1615.3970000000002,
          1588.0870000000002,
          1560.7079999999999,
          1533.26,
          1505.746,
          1478.1670000000001,
          1450.524,
          1422.82,
          1395.055,
          1367.2320000000002,
          1339.352,
          1311.415,
          1283.425,
          1255.382,
          1227.287,
          1199.143,
          1170.951,
          1142.711,
          1114.4260000000002,
          1086.096,
          1057.724,
          1029.3110000000001,
          1000.857,
          972.365,
          943.835,
          915.2689999999999,
          886.668,
          858.034,
          829.368,
          800.671,
          771.944,
          743.189,
          714.4069999999999,
          685.5989999999999,
          656.7669999999999,
          627.911,
          599.033,
          570.134,
          541.216,
          512.279,
          483.325,
          454.35400000000004,
          425.369,
          396.37,
          367.35900000000004,
          338.337,
          309.30400000000003,
          280.262,
          251.213,
          222.15599999999998,
          193.095,
          164.02900000000002,
          134.959,
          105.88799999999999,
          76.816,
          47.744,
          18.673,
          -10.395,
          -39.46,
          -68.52,
          -97.574,
          -126.62100000000001,
          -155.66,
          -184.68900000000002,
          -213.708,
          -242.71599999999998,
          -271.711,
          -300.693,
          -329.659,
          -358.61,
          -387.543,
          -416.459,
          -445.35400000000004,
          -474.23,
          -503.084,
          -531.915,
          -560.722,
          -589.504,
          -618.26,
          -646.989,
          -675.689,
          -704.36,
          -733,
          -761.6080000000001,
          -790.183,
          -818.7239999999999,
          -847.23,
          -875.699,
          -904.1310000000001,
          -932.5239999999999,
          -960.877,
          -989.188,
          -1017.4580000000001,
          -1045.683,
          -1073.864,
          -1101.999,
          -1130.087,
          -1158.127,
          -1186.116,
          -1214.055,
          -1241.942,
          -1269.776,
          -1297.555,
          -1325.2779999999998,
          -1352.944,
          -1380.5520000000001,
          -1408.1,
          -1435.586,
          -1463.011,
          -1490.372,
          -1517.668,
          -1544.898,
          -1572.06,
          -1599.154,
          -1626.1770000000001,
          -1653.128,
          -1680.006,
          -1706.809,
          -1733.537,
          -1760.1870000000001,
          -1786.759,
          -1813.25,
          -1839.6589999999999,
          -1865.985,
          -1892.227,
          -1918.382,
          -1944.4489999999998,
          -1970.4270000000001,
          -1996.3139999999999,
          -2022.109,
          -2047.809,
          -2073.4139999999998,
          -2098.9210000000003,
          -2124.33,
          -2149.637,
          -2174.843,
          -2199.944,
          -2224.939,
          -2249.827,
          -2274.605,
          -2299.2729999999997,
          -2323.827,
          -2348.266,
          -2372.589,
          -2396.792,
          -2420.876,
          -2444.8360000000002,
          -2468.672,
          -2492.382,
          -2515.9629999999997,
          -2539.413,
          -2562.731,
          -2585.9139999999998,
          -2608.959,
          -2631.866,
          -2654.631,
          -2677.252,
          -2699.7270000000003,
          -2722.054,
          -2744.23,
          -2766.2529999999997,
          -2788.12,
          -2809.829,
          -2831.3779999999997,
          -2852.763,
          -2873.9829999999997,
          -2895.034,
          -2915.914,
          -2936.62,
          -2957.1490000000003,
          -2977.498,
          -2997.665,
          -3017.647,
          -3037.44,
          -3057.0409999999997,
          -3076.448,
          -3095.656,
          -3114.664,
          -3133.467,
          -3152.062,
          -3170.446,
          -3188.615,
          -3206.565,
          -3224.2929999999997,
          -3241.796,
          -3259.0690000000004,
          -3276.1079999999997,
          -3292.909,
          -3309.469,
          -3325.784,
          -3341.848,
          -3357.658,
          -3373.2090000000003,
          -3388.4970000000003,
          -3403.5170000000003,
          -3418.264,
          -3432.7329999999997,
          -3446.92,
          -3460.8190000000004,
          -3474.425,
          -3487.7329999999997,
          -3500.737,
          -3513.4320000000002,
          -3525.812,
          -3537.8709999999996,
          -3549.603,
          -3561.002,
          -3572.062,
          -3582.775,
          -3593.136,
          -3603.138,
          -3612.772,
          -3622.033,
          -3630.913,
          -3639.4040000000005,
          -3647.498,
          -3655.187,
          -3662.4629999999997,
          -3669.3179999999998,
          -3675.741,
          -3681.7259999999997,
          -3687.262,
          -3692.3390000000004,
          -3696.948,
          -3701.078,
          -3704.719,
          -3707.861,
          -3710.491,
          -3712.598,
          -3714.171,
          -3715.197,
          -3715.664,
          -3715.558,
          -3714.866,
          -3713.573,
          -3711.6659999999997,
          -3709.1290000000004,
          -3705.946,
          -3702.1020000000003,
          -3697.58,
          -3692.363,
          -3686.433,
          -3679.7709999999997,
          -3672.357,
          -3664.172,
          -3655.196,
          -3645.406,
          -3634.78,
          -3623.295,
          -3610.927,
          -3597.651,
          -3583.44,
          -3568.2690000000002,
          -3552.1059999999998,
          -3534.923,
          -3516.691,
          -3497.375,
          -3476.9440000000004,
          -3455.362,
          -3432.592,
          -3408.599,
          -3383.34,
          -3356.775,
          -3328.86,
          -3299.551,
          -3268.801,
          -3236.56,
          -3202.778,
          -3167.401,
          -3130.3720000000003,
          -3091.633,
          -3051.1240000000003,
          -3008.781,
          -2964.538,
          -2918.327,
          -2870.0759999999996,
          -2819.71,
          -2767.155,
          -2712.33,
          -2655.153,
          -2595.541,
          -2533.409,
          -2468.67,
          -2401.234,
          -2331.014,
          -2257.923,
          -2181.874,
          -2102.784,
          -2020.575,
          -1935.1760000000002,
          -1846.521,
          -1754.559,
          -1659.253,
          -1560.582,
          -1458.549,
          -1353.18,
          -1244.53,
          -1132.692,
          -1017.795,
          -900.007,
          -779.5419999999999,
          -656.6610000000001,
          -531.669,
          -404.913,
          -276.78,
          -147.692,
          -18.093,
          111.556,
          240.79,
          369.153,
          496.202,
          621.5269999999999,
          744.747,
          865.528,
          983.577,
          1098.652,
          1210.553,
          1319.128,
          1424.267,
          1525.895,
          1623.974,
          1718.495,
          1809.4720000000002,
          1896.942,
          1980.9589999999998,
          2061.5879999999997,
          2138.907,
          2213.002,
          2283.962,
          2351.882,
          2416.86,
          2478.99,
          2538.3720000000003,
          2595.101,
          2649.2729999999997,
          2700.9770000000003,
          2750.3059999999996,
          2797.347,
          2842.184,
          2884.897,
          2925.566,
          2964.2659999999996,
          3001.07,
          3036.047,
          3069.261,
          3100.7790000000005,
          3130.659,
          3158.961,
          3185.74,
          3211.05,
          3234.941,
          3257.462,
          3278.658,
          3298.575,
          3317.255,
          3334.739,
          3351.066,
          3366.2729999999997,
          3380.395,
          3393.466,
          3405.52,
          3416.5879999999997,
          3426.699,
          3435.883,
          3444.167,
          3451.578,
          3458.1409999999996,
          3463.881,
          3468.821,
          3472.9829999999997,
          3476.39,
          3479.063,
          3481.0209999999997,
          3482.284,
          3482.87,
          3482.798,
          3482.085,
          3480.748,
          3478.802,
          3476.264,
          3473.1479999999997,
          3469.468,
          3465.24,
          3460.4759999999997,
          3455.191,
          3449.395,
          3443.1009999999997,
          3436.322,
          3429.0679999999998,
          3421.3509999999997,
          3413.1820000000002,
          3404.572,
          3395.5290000000005,
          3386.0640000000003,
          3376.187,
          3365.907,
          3355.2329999999997,
          3344.173,
          3332.736,
          3320.9309999999996,
          3308.764,
          3296.244,
          3283.3790000000004,
          3270.176,
          3256.6409999999996,
          3242.783,
          3228.607,
          3214.12,
          3199.329,
          3184.241,
          3168.86,
          3153.192,
          3137.245,
          3121.022,
          3104.531,
          3087.776,
          3070.762,
          3053.494,
          3035.9790000000003,
          3018.219,
          3000.2209999999995,
          2981.988,
          2963.526,
          2944.8390000000004,
          2925.9309999999996,
          2906.8059999999996,
          2887.469,
          2867.923,
          2848.173,
          2828.222,
          2808.075,
          2787.735,
          2767.205,
          2746.489,
          2725.592,
          2704.515,
          2683.263,
          2661.8390000000004,
          2640.245,
          2618.486,
          2596.565,
          2574.4829999999997,
          2552.245,
          2529.854,
          2507.311,
          2484.621,
          2461.785,
          2438.8070000000002,
          2415.689,
          2392.4339999999997,
          2369.045,
          2345.5229999999997,
          2321.8720000000003,
          2298.094,
          2274.1910000000003,
          2250.166,
          2226.021,
          2201.758,
          2177.38,
          2152.889,
          2128.2870000000003,
          2103.576,
          2078.759,
          2053.837,
          2028.8129999999999,
          2003.6879999999999,
          1978.464,
          1953.144,
          1927.73,
          1902.223,
          1876.625,
          1850.9379999999999,
          1825.165,
          1799.306,
          1773.364,
          1747.34,
          1721.236,
          1695.0539999999999,
          1668.796,
          1642.463,
          1616.057,
          1589.579,
          1563.0320000000002,
          1536.4160000000002,
          1509.733,
          1482.986,
          1456.175,
          1429.3020000000001,
          1402.369,
          1375.376,
          1348.326,
          1321.22,
          1294.06,
          1266.846,
          1239.5810000000001,
          1212.265,
          1184.9,
          1157.488,
          1130.03,
          1102.527,
          1074.98,
          1047.392,
          1019.762,
          992.0939999999999,
          964.387,
          936.643,
          908.863,
          881.049,
          853.203,
          825.324,
          797.415,
          769.477,
          741.51,
          713.5169999999999,
          685.498,
          657.454,
          629.388,
          601.299,
          573.19,
          545.061,
          516.913,
          488.74800000000005,
          460.56699999999995,
          432.371,
          404.161,
          375.93800000000005,
          347.704,
          319.459,
          291.205,
          262.943,
          234.673,
          206.398,
          178.118,
          149.835,
          121.54899999999999,
          93.26100000000001,
          64.973,
          36.686,
          8.4,
          -19.882,
          -48.161,
          -76.434,
          -104.70100000000001,
          -132.961,
          -161.21200000000002,
          -189.454,
          -217.685,
          -245.90400000000002,
          -274.111,
          -302.30400000000003,
          -330.48199999999997,
          -358.64300000000003,
          -386.788,
          -414.914,
          -443.02099999999996,
          -471.10699999999997,
          -499.17199999999997,
          -527.214,
          -555.232,
          -583.226,
          -611.193,
          -639.134,
          -667.046,
          -694.929,
          -722.7810000000001,
          -750.602,
          -778.39,
          -806.145,
          -833.8639999999999,
          -861.547,
          -889.193,
          -916.801,
          -944.3689999999999,
          -971.8960000000001,
          -999.382,
          -1026.8239999999998,
          -1054.222,
          -1081.575,
          -1108.881,
          -1136.139,
          -1163.349,
          -1190.508,
          -1217.616,
          -1244.671,
          -1271.672,
          -1298.618,
          -1325.5079999999998,
          -1352.34,
          -1379.1129999999998,
          -1405.826,
          -1432.4779999999998,
          -1459.067,
          -1485.5910000000001,
          -1512.0510000000002,
          -1538.443,
          -1564.7679999999998,
          -1591.023,
          -1617.207,
          -1643.32,
          -1669.358,
          -1695.3220000000001,
          -1721.2089999999998,
          -1747.019,
          -1772.749,
          -1798.399,
          -1823.9660000000001,
          -1849.45,
          -1874.849,
          -1900.161,
          -1925.384,
          -1950.519,
          -1975.5610000000001,
          -2000.511,
          -2025.366,
          -2050.125,
          -2074.7870000000003,
          -2099.349,
          -2123.8089999999997,
          -2148.167,
          -2172.42,
          -2196.567,
          -2220.606,
          -2244.534,
          -2268.351,
          -2292.055,
          -2315.643,
          -2339.113,
          -2362.465,
          -2385.695,
          -2408.802,
          -2431.784,
          -2454.638,
          -2477.363,
          -2499.9570000000003,
          -2522.417,
          -2544.742,
          -2566.929,
          -2588.975,
          -2610.879,
          -2632.639,
          -2654.252,
          -2675.715,
          -2697.026,
          -2718.183,
          -2739.184,
          -2760.025,
          -2780.704,
          -2801.219,
          -2821.566,
          -2841.744,
          -2861.7490000000003,
          -2881.578,
          -2901.2290000000003,
          -2920.699,
          -2939.985,
          -2959.083,
          -2977.991,
          -2996.705,
          -3015.222,
          -3033.54,
          -3051.6540000000005,
          -3069.5609999999997,
          -3087.258,
          -3104.741,
          -3122.007,
          -3139.051,
          -3155.8709999999996,
          -3172.461,
          -3188.8190000000004,
          -3204.941,
          -3220.821,
          -3236.4559999999997,
          -3251.842,
          -3266.974,
          -3281.848,
          -3296.4590000000003,
          -3310.802,
          -3324.8720000000003,
          -3338.6659999999997,
          -3352.176,
          -3365.4,
          -3378.33,
          -3390.962,
          -3403.29,
          -3415.308,
          -3427.011,
          -3438.393,
          -3449.447,
          -3460.167,
          -3470.547,
          -3480.579,
          -3490.258,
          -3499.5759999999996,
          -3508.525,
          -3517.1,
          -3525.2909999999997,
          -3533.091,
          -3540.492,
          -3547.485,
          -3554.063,
          -3560.216,
          -3565.9359999999997,
          -3571.2129999999997,
          -3576.0370000000003,
          -3580.3990000000003,
          -3584.288,
          -3587.6929999999998,
          -3590.605,
          -3593.011,
          -3594.901,
          -3596.262,
          -3597.0820000000003,
          -3597.348,
          -3597.047,
          -3596.165,
          -3594.6890000000003,
          -3592.6040000000003,
          -3589.8940000000002,
          -3586.5440000000003,
          -3582.539,
          -3577.86,
          -3572.492,
          -3566.415,
          -3559.611,
          -3552.06,
          -3543.743,
          -3534.639,
          -3524.725,
          -3513.9790000000003,
          -3502.3790000000004,
          -3489.8979999999997,
          -3476.513,
          -3462.196,
          -3446.92,
          -3430.656,
          -3413.375,
          -3395.0440000000003,
          -3375.632,
          -3355.105,
          -3333.427,
          -3310.562,
          -3286.472,
          -3261.115,
          -3234.449,
          -3206.4309999999996,
          -3177.0159999999996,
          -3146.155,
          -3113.7990000000004,
          -3079.895,
          -3044.39,
          -3007.225,
          -2968.342,
          -2927.68,
          -2885.173,
          -2840.757,
          -2794.3590000000004,
          -2745.908,
          -2695.329,
          -2642.546,
          -2587.48,
          -2530.0460000000003,
          -2470.1620000000003,
          -2407.744,
          -2342.705,
          -2274.9570000000003,
          -2204.415,
          -2130.995,
          -2054.615,
          -1975.1970000000001,
          -1892.668,
          -1806.9679999999998,
          -1718.0420000000001,
          -1625.851,
          -1530.375,
          -1431.611,
          -1329.5829999999999,
          -1224.344,
          -1115.976,
          -1004.602,
          -890.3839999999999,
          -773.525,
          -654.273,
          -532.922,
          -409.80699999999996,
          -285.301,
          -159.812,
          -33.77,
          92.37899999999999,
          218.18200000000002,
          343.19300000000004,
          466.98199999999997,
          589.144,
          709.31,
          827.148,
          942.372,
          1054.74,
          1164.0539999999999,
          1270.164,
          1372.954,
          1472.3529999999998,
          1568.319,
          1660.8370000000002,
          1749.922,
          1835.606,
          1917.9370000000001,
          1996.979,
          2072.806,
          2145.498,
          2215.143,
          2281.831,
          2345.655,
          2406.708,
          2465.084,
          2520.8779999999997,
          2574.179,
          2625.078,
          2673.6609999999996,
          2720.013,
          2764.217,
          2806.3509999999997,
          2846.491,
          2884.71,
          2921.079,
          2955.665,
          2988.532,
          3019.742,
          3049.355,
          3077.427,
          3104.012,
          3129.1620000000003,
          3152.926,
          3175.3520000000003,
          3196.485,
          3216.367,
          3235.042,
          3252.547,
          3268.922,
          3284.202,
          3298.422,
          3311.615,
          3323.813,
          3335.047,
          3345.3459999999995,
          3354.738,
          3363.25,
          3370.908,
          3377.736,
          3383.759,
          3389.0009999999997,
          3393.4809999999998,
          3397.2209999999995,
          3400.243,
          3402.566,
          3404.208,
          3405.1890000000003,
          3405.5240000000003,
          3405.232,
          3404.329,
          3402.83,
          3400.7509999999997,
          3398.1059999999998,
          3394.909,
          3391.1740000000004,
          3386.915,
          3382.143,
          3376.873,
          3371.115,
          3364.881,
          3358.1809999999996,
          3351.028,
          3343.4309999999996,
          3335.401,
          3326.948,
          3318.0809999999997,
          3308.81,
          3299.143,
          3289.0890000000004,
          3278.657,
          3267.8559999999998,
          3256.692,
          3245.1740000000004,
          3233.31,
          3221.107,
          3208.571,
          3195.711,
          3182.532,
          3169.0409999999997,
          3155.2459999999996,
          3141.151,
          3126.764,
          3112.09,
          3097.135,
          3081.9040000000005,
          3066.403,
          3050.638,
          3034.613,
          3018.3340000000003,
          3001.8059999999996,
          2985.034,
          2968.0209999999997,
          2950.7740000000003,
          2933.297,
          2915.594,
          2897.6679999999997,
          2879.526,
          2861.17,
          2842.6059999999998,
          2823.836,
          2804.864,
          2785.695,
          2766.333,
          2746.78,
          2727.0409999999997,
          2707.118,
          2687.0159999999996,
          2666.738,
          2646.2859999999996,
          2625.665,
          2604.877,
          2583.925,
          2562.813,
          2541.544,
          2520.12,
          2498.544,
          2476.819,
          2454.948,
          2432.933,
          2410.778,
          2388.485,
          2366.056,
          2343.494,
          2320.802,
          2297.981,
          2275.035,
          2251.966,
          2228.775,
          2205.466,
          2182.04,
          2158.5,
          2134.847,
          2111.085,
          2087.215,
          2063.239,
          2039.1589999999999,
          2014.9779999999998,
          1990.6970000000001,
          1966.318,
          1941.8429999999998,
          1917.275,
          1892.614,
          1867.8629999999998,
          1843.024,
          1818.098,
          1793.088,
          1767.994,
          1742.819,
          1717.5639999999999,
          1692.2320000000002,
          1666.8229999999999,
          1641.34,
          1615.783,
          1590.155,
          1564.4579999999999,
          1538.692,
          1512.859,
          1486.9620000000002,
          1461,
          1434.977,
          1408.892,
          1382.749,
          1356.5479999999998,
          1330.29,
          1303.978,
          1277.612,
          1251.193,
          1224.724,
          1198.2060000000001,
          1171.64,
          1145.027,
          1118.369,
          1091.6660000000002,
          1064.921,
          1038.134,
          1011.308,
          984.442,
          957.539,
          930.5989999999999,
          903.6239999999999,
          876.6160000000001,
          849.574,
          822.5010000000001,
          795.398,
          768.2660000000001,
          741.1060000000001,
          713.919,
          686.707,
          659.47,
          632.211,
          604.929,
          577.626,
          550.304,
          522.9630000000001,
          495.60400000000004,
          468.23,
          440.84,
          413.436,
          386.019,
          358.59,
          331.15,
          303.70099999999996,
          276.243,
          248.77700000000002,
          221.305,
          193.828,
          166.347,
          138.862,
          111.376,
          83.88799999999999,
          56.401,
          28.914,
          1.43,
          -26.05,
          -53.527,
          -80.998,
          -108.463,
          -135.92,
          -163.368,
          -190.80700000000002,
          -218.235,
          -245.65099999999998,
          -273.055,
          -300.444,
          -327.81800000000004,
          -355.17699999999996,
          -382.51800000000003,
          -409.841,
          -437.145,
          -464.42900000000003,
          -491.691,
          -518.931,
          -546.1469999999999,
          -573.3380000000001,
          -600.504,
          -627.643,
          -654.755,
          -681.837,
          -708.8889999999999,
          -735.91,
          -762.8989999999999,
          -789.8539999999999,
          -816.775,
          -843.66,
          -870.5089999999999,
          -897.32,
          -924.092,
          -950.823,
          -977.5139999999999,
          -1004.1619999999999,
          -1030.766,
          -1057.326,
          -1083.84,
          -1110.307,
          -1136.726,
          -1163.095,
          -1189.414,
          -1215.681,
          -1241.895,
          -1268.0539999999999,
          -1294.1589999999999,
          -1320.2060000000001,
          -1346.195,
          -1372.126,
          -1397.996,
          -1423.8039999999999,
          -1449.549,
          -1475.229,
          -1500.844,
          -1526.392,
          -1551.872,
          -1577.2820000000002,
          -1602.621,
          -1627.8870000000002,
          -1653.08,
          -1678.1979999999999,
          -1703.239,
          -1728.2020000000002,
          -1753.086,
          -1777.888,
          -1802.609,
          -1827.245,
          -1851.796,
          -1876.26,
          -1900.636,
          -1924.922,
          -1949.116,
          -1973.217,
          -1997.224,
          -2021.1329999999998,
          -2044.945,
          -2068.657,
          -2092.268,
          -2115.776,
          -2139.178,
          -2162.474,
          -2185.6620000000003,
          -2208.739,
          -2231.705,
          -2254.556,
          -2277.292,
          -2299.91,
          -2322.408,
          -2344.784,
          -2367.0370000000003,
          -2389.165,
          -2411.1639999999998,
          -2433.034,
          -2454.772,
          -2476.375,
          -2497.843,
          -2519.172,
          -2540.36,
          -2561.406,
          -2582.305,
          -2603.0570000000002,
          -2623.659,
          -2644.1090000000004,
          -2664.402,
          -2684.539,
          -2704.515,
          -2724.328,
          -2743.975,
          -2763.454,
          -2782.762,
          -2801.897,
          -2820.8540000000003,
          -2839.631,
          -2858.2259999999997,
          -2876.635,
          -2894.855,
          -2912.883,
          -2930.716,
          -2948.35,
          -2965.782,
          -2983.009,
          -3000.026,
          -3016.8320000000003,
          -3033.421,
          -3049.79,
          -3065.935,
          -3081.853,
          -3097.539,
          -3112.989,
          -3128.2,
          -3143.1659999999997,
          -3157.884,
          -3172.349,
          -3186.5570000000002,
          -3200.5029999999997,
          -3214.1809999999996,
          -3227.5879999999997,
          -3240.718,
          -3253.567,
          -3266.1279999999997,
          -3278.3959999999997,
          -3290.367,
          -3302.033,
          -3313.39,
          -3324.4309999999996,
          -3335.151,
          -3345.5429999999997,
          -3355.6,
          -3365.317,
          -3374.6859999999997,
          -3383.7,
          -3392.3520000000003,
          -3400.635,
          -3408.5409999999997,
          -3416.062,
          -3423.191,
          -3429.9179999999997,
          -3436.237,
          -3442.136,
          -3447.6090000000004,
          -3452.645,
          -3457.236,
          -3461.37,
          -3465.039,
          -3468.23,
          -3470.934,
          -3473.139,
          -3474.8340000000003,
          -3476.006,
          -3476.6440000000002,
          -3476.735,
          -3476.265,
          -3475.2209999999995,
          -3473.5890000000004,
          -3471.353,
          -3468.5,
          -3465.013,
          -3460.877,
          -3456.074,
          -3450.586,
          -3444.395,
          -3437.4840000000004,
          -3429.8309999999997,
          -3421.4179999999997,
          -3412.222,
          -3402.223,
          -3391.397,
          -3379.72,
          -3367.1690000000003,
          -3353.717,
          -3339.336,
          -3324.0009999999997,
          -3307.6809999999996,
          -3290.347,
          -3271.966,
          -3252.507,
          -3231.934,
          -3210.2129999999997,
          -3187.304,
          -3163.17,
          -3137.77,
          -3111.0609999999997,
          -3082.9990000000003,
          -3053.5370000000003,
          -3022.627,
          -2990.218,
          -2956.257,
          -2920.6890000000003,
          -2883.4559999999997,
          -2844.5,
          -2803.755,
          -2761.159,
          -2716.6420000000003,
          -2670.135,
          -2621.565,
          -2570.856,
          -2517.931,
          -2462.7110000000002,
          -2405.113,
          -2345.053,
          -2282.448,
          -2217.214,
          -2149.265,
          -2078.518,
          -2004.8929999999998,
          -1928.3129999999999,
          -1848.7079999999999,
          -1766.013,
          -1680.1760000000002,
          -1591.158,
          -1498.934,
          -1403.501,
          -1304.879,
          -1203.114,
          -1098.2839999999999,
          -990.5060000000001,
          -879.93,
          -766.7510000000001,
          -651.207,
          -533.578,
          -414.186,
          -293.392,
          -171.58599999999998,
          -49.187,
          73.373,
          195.655,
          317.226,
          437.664,
          556.577,
          673.6010000000001,
          788.4110000000001,
          900.7239999999999,
          1010.302,
          1116.9489999999998,
          1220.513,
          1320.881,
          1417.976,
          1511.755,
          1602.204,
          1689.33,
          1773.162,
          1853.7479999999998,
          1931.145,
          2005.4229999999998,
          2076.66,
          2144.937,
          2210.344,
          2272.967,
          2332.8979999999997,
          2390.2270000000003,
          2445.044,
          2497.437,
          2547.492,
          2595.295,
          2640.926,
          2684.465,
          2725.988,
          2765.4590000000003,
          2803.281,
          2839.19,
          2873.36,
          2905.8559999999998,
          2936.739,
          2966.063,
          2993.885,
          3020.257,
          3045.2290000000003,
          3068.85,
          3091.1659999999997,
          3112.2209999999995,
          3132.0559999999996,
          3150.712,
          3168.2270000000003,
          3184.639,
          3199.982,
          3214.29,
          3227.5959999999995,
          3239.9309999999996,
          3251.324,
          3261.804,
          3271.3979999999997,
          3280.132,
          3288.033,
          3295.1220000000003,
          3301.425,
          3306.9640000000004,
          3311.759,
          3315.833,
          3319.203,
          3321.889,
          3323.9109999999996,
          3325.285,
          3326.028,
          3326.158,
          3325.69,
          3324.64,
          3323.022,
          3320.85,
          3318.138,
          3314.901,
          3311.15,
          3306.8979999999997,
          3302.157,
          3296.938,
          3291.2540000000004,
          3285.114,
          3278.53,
          3271.512,
          3264.0690000000004,
          3256.212,
          3247.949,
          3239.29,
          3230.244,
          3220.8190000000004,
          3211.0229999999997,
          3200.864,
          3190.3509999999997,
          3179.491,
          3168.2909999999997,
          3156.758,
          3144.9,
          3132.723,
          3120.2340000000004,
          3107.44,
          3094.345,
          3080.958,
          3067.283,
          3053.3259999999996,
          3039.093,
          3024.59,
          3009.822,
          2994.795,
          2979.512,
          2963.98,
          2948.203,
          2932.1859999999997,
          2915.933,
          2899.45,
          2882.74,
          2865.808,
          2848.658,
          2831.295,
          2813.7209999999995,
          2795.942,
          2777.961,
          2759.782,
          2741.409,
          2722.845,
          2704.094,
          2685.159,
          2666.0440000000003,
          2646.752,
          2627.2859999999996,
          2607.649,
          2587.846,
          2567.8779999999997,
          2547.749,
          2527.462,
          2507.019,
          2486.424,
          2465.679,
          2444.788,
          2423.752,
          2402.574,
          2381.258,
          2359.805,
          2338.218,
          2316.5,
          2294.652,
          2272.678,
          2250.58,
          2228.36,
          2206.02,
          2183.562,
          2160.99,
          2138.304,
          2115.507,
          2092.601,
          2069.5879999999997,
          2046.471,
          2023.251,
          1999.9289999999999,
          1976.509,
          1952.9920000000002,
          1929.38,
          1905.675,
          1881.878,
          1857.991,
          1834.017,
          1809.9560000000001,
          1785.8110000000001,
          1761.5839999999998,
          1737.275,
          1712.8870000000002,
          1688.422,
          1663.88,
          1639.264,
          1614.576,
          1589.815,
          1564.986,
          1540.088,
          1515.1229999999998,
          1490.0929999999998,
          1464.999,
          1439.8429999999998,
          1414.626,
          1389.35,
          1364.015,
          1338.624,
          1313.1779999999999,
          1287.678,
          1262.126,
          1236.522,
          1210.868,
          1185.1660000000002,
          1159.417,
          1133.622,
          1107.782,
          1081.899,
          1055.974,
          1030.008,
          1004.002,
          977.9580000000001,
          951.877,
          925.7589999999999,
          899.607,
          873.422,
          847.204,
          820.955,
          794.676,
          768.368,
          742.0319999999999,
          715.67,
          689.2819999999999,
          662.87,
          636.434,
          609.987,
          583.508,
          557.01,
          530.493,
          503.958,
          477.407,
          450.84,
          424.259,
          397.665,
          371.05800000000005,
          344.44,
          317.812,
          291.175,
          264.53,
          237.878,
          211.22099999999998,
          184.558,
          157.892,
          131.222,
          104.552,
          77.88,
          51.208999999999996,
          24.539,
          -2.128,
          -28.791999999999998,
          -55.451,
          -82.105,
          -108.75200000000001,
          -135.391,
          -162.02200000000002,
          -188.643,
          -215.25400000000002,
          -241.852,
          -268.438,
          -295.01099999999997,
          -321.568,
          -348.10900000000004,
          -374.634,
          -401.14,
          -427.62800000000004,
          -454.095,
          -480.542,
          -506.966,
          -533.367,
          -559.744,
          -586.096,
          -612.4209999999999,
          -638.719,
          -664.9889999999999,
          -691.2289999999999,
          -717.438,
          -743.6160000000001,
          -769.7610000000001,
          -795.872,
          -821.948,
          -847.988,
          -873.9910000000001,
          -899.956,
          -925.8810000000001,
          -951.7660000000001,
          -977.61,
          -1003.4110000000001,
          -1029.167,
          -1054.879,
          -1080.545,
          -1106.164,
          -1131.734,
          -1157.254,
          -1182.724,
          -1208.141,
          -1233.506,
          -1258.816,
          -1284.07,
          -1309.267,
          -1334.4070000000002,
          -1359.487,
          -1384.506,
          -1409.464,
          -1434.359,
          -1459.1889999999999,
          -1483.953,
          -1508.65,
          -1533.279,
          -1557.839,
          -1582.3270000000002,
          -1606.743,
          -1631.0839999999998,
          -1655.351,
          -1679.5410000000002,
          -1703.654,
          -1727.6860000000001,
          -1751.638,
          -1775.5079999999998,
          -1799.293,
          -1822.993,
          -1846.6070000000002,
          -1870.131,
          -1893.566,
          -1916.9089999999999,
          -1940.16,
          -1963.315,
          -1986.374,
          -2009.335,
          -2032.1960000000001,
          -2054.955,
          -2077.612,
          -2100.163,
          -2122.6079999999997,
          -2144.944,
          -2167.17,
          -2189.284,
          -2211.284,
          -2233.1679999999997,
          -2254.9339999999997,
          -2276.58,
          -2298.104,
          -2319.505,
          -2340.779,
          -2361.926,
          -2382.9429999999998,
          -2403.827,
          -2424.577,
          -2445.19,
          -2465.6639999999998,
          -2485.9970000000003,
          -2506.187,
          -2526.231,
          -2546.126,
          -2565.87,
          -2585.462,
          -2604.897,
          -2624.1740000000004,
          -2643.29,
          -2662.243,
          -2681.0290000000005,
          -2699.645,
          -2718.09,
          -2736.3590000000004,
          -2754.4509999999996,
          -2772.362,
          -2790.0879999999997,
          -2807.6279999999997,
          -2824.9770000000003,
          -2842.133,
          -2859.092,
          -2875.8509999999997,
          -2892.406,
          -2908.7529999999997,
          -2924.89,
          -2940.812,
          -2956.5159999999996,
          -2971.998,
          -2987.2540000000004,
          -3002.2790000000005,
          -3017.071,
          -3031.623,
          -3045.934,
          -3059.9970000000003,
          -3073.808,
          -3087.363,
          -3100.657,
          -3113.6859999999997,
          -3126.4440000000004,
          -3138.926,
          -3151.127,
          -3163.0409999999997,
          -3174.663,
          -3185.988,
          -3197.01,
          -3207.723,
          -3218.12,
          -3228.196,
          -3237.9440000000004,
          -3247.3579999999997,
          -3256.4309999999996,
          -3265.155,
          -3273.525,
          -3281.532,
          -3289.1690000000003,
          -3296.428,
          -3303.301,
          -3309.78,
          -3315.857,
          -3321.522,
          -3326.768,
          -3331.5840000000003,
          -3335.961,
          -3339.89,
          -3343.3590000000004,
          -3346.3579999999997,
          -3348.8779999999997,
          -3350.905,
          -3352.43,
          -3353.44,
          -3353.922,
          -3353.865,
          -3353.2540000000004,
          -3352.0759999999996,
          -3350.317,
          -3347.962,
          -3344.9959999999996,
          -3341.4040000000005,
          -3337.1690000000003,
          -3332.275,
          -3326.702,
          -3320.434,
          -3313.452,
          -3305.735,
          -3297.264,
          -3288.0170000000003,
          -3277.972,
          -3267.107,
          -3255.397,
          -3242.8179999999998,
          -3229.343,
          -3214.946,
          -3199.599,
          -3183.272,
          -3165.934,
          -3147.555,
          -3128.1,
          -3107.5359999999996,
          -3085.825,
          -3062.93,
          -3038.8109999999997,
          -3013.427,
          -2986.736,
          -2958.691,
          -2929.2459999999996,
          -2898.3520000000003,
          -2865.9570000000003,
          -2832.008,
          -2796.449,
          -2759.2209999999995,
          -2720.265,
          -2679.5159999999996,
          -2636.908,
          -2592.373,
          -2545.841,
          -2497.239,
          -2446.489,
          -2393.515,
          -2338.237,
          -2280.574,
          -2220.442,
          -2157.76,
          -2092.445,
          -2024.415,
          -1953.59,
          -1879.8970000000002,
          -1803.2620000000002,
          -1723.625,
          -1640.931,
          -1555.14,
          -1466.227,
          -1374.1860000000001,
          -1279.031,
          -1180.806,
          -1079.583,
          -975.4689999999999,
          -868.61,
          -759.187,
          -647.429,
          -533.6030000000001,
          -418.01800000000003,
          -301.019,
          -182.984,
          -64.316,
          54.567,
          173.239,
          291.279,
          408.278,
          523.852,
          637.645,
          749.3389999999999,
          858.655,
          965.36,
          1069.258,
          1170.197,
          1268.065,
          1362.7820000000002,
          1454.305,
          1542.614,
          1627.714,
          1709.6329999999998,
          1788.411,
          1864.1029999999998,
          1936.777,
          2006.503,
          2073.362,
          2137.438,
          2198.814,
          2257.577,
          2313.817,
          2367.616,
          2419.062,
          2468.237,
          2515.224,
          2560.1,
          2602.9429999999998,
          2643.8259999999996,
          2682.822,
          2719.9970000000003,
          2755.4190000000003,
          2789.151,
          2821.2529999999997,
          2851.785,
          2880.8,
          2908.353,
          2934.494,
          2959.272,
          2982.7340000000004,
          3004.925,
          3025.888,
          3045.6620000000003,
          3064.2870000000003,
          3081.8,
          3098.238,
          3113.635,
          3128.022,
          3141.433,
          3153.897,
          3165.442,
          3176.097,
          3185.887,
          3194.84,
          3202.978,
          3210.3259999999996,
          3216.905,
          3222.739,
          3227.847,
          3232.2509999999997,
          3235.969,
          3239.0190000000002,
          3241.4190000000003,
          3243.188,
          3244.34,
          3244.8940000000002,
          3244.863,
          3244.263,
          3243.1090000000004,
          3241.414,
          3239.191,
          3236.454,
          3233.215,
          3229.486,
          3225.28,
          3220.607,
          3215.478,
          3209.9040000000005,
          3203.895,
          3197.462,
          3190.613,
          3183.3590000000004,
          3175.708,
          3167.6690000000003,
          3159.2509999999997,
          3150.4629999999997,
          3141.3109999999997,
          3131.805,
          3121.9509999999996,
          3111.757,
          3101.2309999999998,
          3090.3779999999997,
          3079.2070000000003,
          3067.724,
          3055.934,
          3043.8459999999995,
          3031.4629999999997,
          3018.7940000000003,
          3005.842,
          2992.615,
          2979.117,
          2965.353,
          2951.33,
          2937.051,
          2922.5229999999997,
          2907.75,
          2892.737,
          2877.488,
          2862.007,
          2846.301,
          2830.3720000000003,
          2814.224,
          2797.863,
          2781.292,
          2764.514,
          2747.535,
          2730.357,
          2712.985,
          2695.421,
          2677.67,
          2659.735,
          2641.619,
          2623.325,
          2604.8579999999997,
          2586.22,
          2567.413,
          2548.4429999999998,
          2529.31,
          2510.019,
          2490.572,
          2470.971,
          2451.221,
          2431.323,
          2411.28,
          2391.095,
          2370.77,
          2350.308,
          2329.712,
          2308.9829999999997,
          2288.125,
          2267.139,
          2246.028,
          2224.795,
          2203.44,
          2181.968,
          2160.379,
          2138.677,
          2116.862,
          2094.938,
          2072.905,
          2050.7670000000003,
          2028.525,
          2006.182,
          1983.7379999999998,
          1961.1960000000001,
          1938.558,
          1915.826,
          1893.001,
          1870.085,
          1847.0810000000001,
          1823.989,
          1800.8110000000001,
          1777.55,
          1754.2060000000001,
          1730.7820000000002,
          1707.279,
          1683.6979999999999,
          1660.0420000000001,
          1636.3120000000001,
          1612.509,
          1588.634,
          1564.69,
          1540.6779999999999,
          1516.599,
          1492.455,
          1468.247,
          1443.977,
          1419.646,
          1395.255,
          1370.806,
          1346.3,
          1321.739,
          1297.123,
          1272.455,
          1247.735,
          1222.965,
          1198.146,
          1173.279,
          1148.366,
          1123.407,
          1098.405,
          1073.36,
          1048.2730000000001,
          1023.1460000000001,
          997.98,
          972.7760000000001,
          947.535,
          922.2589999999999,
          896.948,
          871.6039999999999,
          846.227,
          820.82,
          795.383,
          769.9169999999999,
          744.424,
          718.904,
          693.3580000000001,
          667.788,
          642.195,
          616.58,
          590.944,
          565.2869999999999,
          539.612,
          513.919,
          488.209,
          462.483,
          436.74199999999996,
          410.98800000000006,
          385.221,
          359.44199999999995,
          333.653,
          307.85400000000004,
          282.047,
          256.232,
          230.41,
          204.583,
          178.752,
          152.917,
          127.079,
          101.241,
          75.40100000000001,
          49.562,
          23.725,
          -2.11,
          -27.941,
          -53.766999999999996,
          -79.58800000000001,
          -105.40299999999999,
          -131.21,
          -157.00799999999998,
          -182.797,
          -208.575,
          -234.342,
          -260.096,
          -285.837,
          -311.563,
          -337.274,
          -362.968,
          -388.644,
          -414.30199999999996,
          -439.94,
          -465.55800000000005,
          -491.154,
          -516.727,
          -542.2769999999999,
          -567.802,
          -593.3009999999999,
          -618.774,
          -644.2180000000001,
          -669.6339999999999,
          -695.02,
          -720.375,
          -745.698,
          -770.988,
          -796.2439999999999,
          -821.465,
          -846.6489999999999,
          -871.797,
          -896.905,
          -921.975,
          -947.003,
          -971.99,
          -996.934,
          -1021.835,
          -1046.69,
          -1071.499,
          -1096.26,
          -1120.973,
          -1145.637,
          -1170.25,
          -1194.81,
          -1219.318,
          -1243.771,
          -1268.1680000000001,
          -1292.509,
          -1316.7920000000001,
          -1341.016,
          -1365.1789999999999,
          -1389.28,
          -1413.319,
          -1437.293,
          -1461.201,
          -1485.043,
          -1508.816,
          -1532.52,
          -1556.1529999999998,
          -1579.714,
          -1603.2020000000002,
          -1626.614,
          -1649.95,
          -1673.2079999999999,
          -1696.3870000000002,
          -1719.485,
          -1742.501,
          -1765.433,
          -1788.28,
          -1811.0410000000002,
          -1833.713,
          -1856.296,
          -1878.787,
          -1901.185,
          -1923.489,
          -1945.6960000000001,
          -1967.806,
          -1989.816,
          -2011.725,
          -2033.531,
          -2055.232,
          -2076.827,
          -2098.313,
          -2119.689,
          -2140.953,
          -2162.104,
          -2183.138,
          -2204.055,
          -2224.8520000000003,
          -2245.527,
          -2266.078,
          -2286.504,
          -2306.801,
          -2326.968,
          -2347.0029999999997,
          -2366.904,
          -2386.667,
          -2406.292,
          -2425.775,
          -2445.115,
          -2464.308,
          -2483.353,
          -2502.2470000000003,
          -2520.986,
          -2539.57,
          -2557.996,
          -2576.259,
          -2594.359,
          -2612.291,
          -2630.053,
          -2647.643,
          -2665.0570000000002,
          -2682.292,
          -2699.345,
          -2716.2129999999997,
          -2732.893,
          -2749.382,
          -2765.675,
          -2781.7709999999997,
          -2797.665,
          -2813.3540000000003,
          -2828.8340000000003,
          -2844.1009999999997,
          -2859.152,
          -2873.9829999999997,
          -2888.59,
          -2902.968,
          -2917.114,
          -2931.0240000000003,
          -2944.692,
          -2958.115,
          -2971.288,
          -2984.2070000000003,
          -2996.866,
          -3009.261,
          -3021.386,
          -3033.237,
          -3044.809,
          -3056.095,
          -3067.09,
          -3077.789,
          -3088.1859999999997,
          -3098.275,
          -3108.0490000000004,
          -3117.502,
          -3126.6279999999997,
          -3135.42,
          -3143.8709999999996,
          -3151.974,
          -3159.722,
          -3167.1079999999997,
          -3174.123,
          -3180.76,
          -3187.01,
          -3192.866,
          -3198.3179999999998,
          -3203.357,
          -3207.975,
          -3212.1620000000003,
          -3215.908,
          -3219.202,
          -3222.035,
          -3224.395,
          -3226.272,
          -3227.6540000000005,
          -3228.5290000000005,
          -3228.885,
          -3228.708,
          -3227.986,
          -3226.7059999999997,
          -3224.8520000000003,
          -3222.4109999999996,
          -3219.367,
          -3215.704,
          -3211.407,
          -3206.458,
          -3200.8379999999997,
          -3194.531,
          -3187.518,
          -3179.778,
          -3171.2909999999997,
          -3162.0359999999996,
          -3151.99,
          -3141.131,
          -3129.435,
          -3116.8759999999997,
          -3103.428,
          -3089.0640000000003,
          -3073.757,
          -3057.475,
          -3040.1890000000003,
          -3021.867,
          -3002.475,
          -2981.9770000000003,
          -2960.337,
          -2937.5159999999996,
          -2913.4759999999997,
          -2888.173,
          -2861.566,
          -2833.607,
          -2804.2490000000003,
          -2773.4429999999998,
          -2741.136,
          -2707.276,
          -2671.803,
          -2634.66,
          -2595.786,
          -2555.116,
          -2512.585,
          -2468.1220000000003,
          -2421.657,
          -2373.117,
          -2322.425,
          -2269.504,
          -2214.275,
          -2156.658,
          -2096.57,
          -2033.932,
          -1968.664,
          -1900.6870000000001,
          -1829.9270000000001,
          -1756.315,
          -1679.787,
          -1600.2920000000001,
          -1517.785,
          -1432.2420000000002,
          -1343.6529999999998,
          -1252.029,
          -1157.411,
          -1059.862,
          -959.4839999999999,
          -856.413,
          -750.822,
          -642.927,
          -532.9830000000001,
          -421.286,
          -308.166,
          -193.987,
          -79.137,
          35.98,
          150.953,
          265.372,
          378.842,
          490.986,
          601.46,
          709.95,
          816.183,
          919.929,
          1020.993,
          1119.226,
          1214.514,
          1306.777,
          1395.969,
          1482.066,
          1565.0710000000001,
          1645.009,
          1721.9160000000002,
          1795.8429999999998,
          1866.852,
          1935.0120000000002,
          2000.4,
          2063.092,
          2123.172,
          2180.723,
          2235.827,
          2288.5660000000003,
          2339.025,
          2387.282,
          2433.415,
          2477.501,
          2519.615,
          2559.826,
          2598.2039999999997,
          2634.816,
          2669.7259999999997,
          2702.993,
          2734.677,
          2764.8340000000003,
          2793.518,
          2820.782,
          2846.673,
          2871.238,
          2894.5240000000003,
          2916.573,
          2937.428,
          2957.1259999999997,
          2975.708,
          2993.2070000000003,
          3009.66,
          3025.099,
          3039.5559999999996,
          3053.0609999999997,
          3065.645,
          3077.335,
          3088.158,
          3098.139,
          3107.303,
          3115.6740000000004,
          3123.275,
          3130.1279999999997,
          3136.2529999999997,
          3141.672,
          3146.4040000000005,
          3150.467,
          3153.8790000000004,
          3156.658,
          3158.82,
          3160.383,
          3161.36,
          3161.768,
          3161.62,
          3160.9309999999996,
          3159.715,
          3157.9840000000004,
          3155.75,
          3153.027,
          3149.8259999999996,
          3146.158,
          3142.035,
          3137.467,
          3132.4629999999997,
          3127.0359999999996,
          3121.1929999999998,
          3114.9440000000004,
          3108.3,
          3101.2670000000003,
          3093.8559999999998,
          3086.074,
          3077.929,
          3069.43,
          3060.5840000000003,
          3051.3979999999997,
          3041.8790000000004,
          3032.035,
          3021.873,
          3011.3979999999997,
          3000.618,
          2989.538,
          2978.165,
          2966.505,
          2954.5640000000003,
          2942.3459999999995,
          2929.8579999999997,
          2917.105,
          2904.093,
          2890.825,
          2877.308,
          2863.546,
          2849.5440000000003,
          2835.3059999999996,
          2820.8379999999997,
          2806.1420000000003,
          2791.225,
          2776.0890000000004,
          2760.74,
          2745.18,
          2729.414,
          2713.446,
          2697.28,
          2680.9190000000003,
          2664.367,
          2647.627,
          2630.702,
          2613.597,
          2596.315,
          2578.8579999999997,
          2561.23,
          2543.433,
          2525.472,
          2507.349,
          2489.067,
          2470.629,
          2452.0370000000003,
          2433.295,
          2414.404,
          2395.369,
          2376.19,
          2356.8720000000003,
          2337.416,
          2317.824,
          2298.1,
          2278.246,
          2258.264,
          2238.156,
          2217.924,
          2197.571,
          2177.1,
          2156.511,
          2135.808,
          2114.992,
          2094.0660000000003,
          2073.031,
          2051.889,
          2030.642,
          2009.293,
          1987.8429999999998,
          1966.2939999999999,
          1944.648,
          1922.9070000000002,
          1901.0720000000001,
          1879.145,
          1857.128,
          1835.023,
          1812.8310000000001,
          1790.555,
          1768.195,
          1745.753,
          1723.231,
          1700.63,
          1677.953,
          1655.2,
          1632.3729999999998,
          1609.473,
          1586.503,
          1563.463,
          1540.355,
          1517.181,
          1493.941,
          1470.638,
          1447.2720000000002,
          1423.845,
          1400.358,
          1376.8129999999999,
          1353.211,
          1329.5529999999999,
          1305.84,
          1282.075,
          1258.257,
          1234.389,
          1210.472,
          1186.506,
          1162.494,
          1138.435,
          1114.3319999999999,
          1090.1860000000001,
          1065.998,
          1041.768,
          1017.4989999999999,
          993.191,
          968.846,
          944.4639999999999,
          920.047,
          895.596,
          871.112,
          846.595,
          822.048,
          797.471,
          772.8660000000001,
          748.2330000000001,
          723.573,
          698.888,
          674.178,
          649.445,
          624.69,
          599.913,
          575.116,
          550.3,
          525.466,
          500.61400000000003,
          475.746,
          450.86300000000006,
          425.966,
          401.056,
          376.13300000000004,
          351.2,
          326.256,
          301.303,
          276.341,
          251.373,
          226.398,
          201.418,
          176.43400000000003,
          151.446,
          126.456,
          101.465,
          76.473,
          51.482,
          26.491999999999997,
          1.505,
          -23.479,
          -48.458,
          -73.432,
          -98.399,
          -123.359,
          -148.311,
          -173.25400000000002,
          -198.18599999999998,
          -223.107,
          -248.016,
          -272.91200000000003,
          -297.793,
          -322.66,
          -347.51,
          -372.344,
          -397.159,
          -421.95599999999996,
          -446.73199999999997,
          -471.48699999999997,
          -496.221,
          -520.931,
          -545.618,
          -570.279,
          -594.915,
          -619.523,
          -644.104,
          -668.655,
          -693.177,
          -717.6669999999999,
          -742.1260000000001,
          -766.551,
          -790.942,
          -815.298,
          -839.618,
          -863.9,
          -888.1439999999999,
          -912.3480000000001,
          -936.512,
          -960.6339999999999,
          -984.7139999999999,
          -1008.7489999999999,
          -1032.74,
          -1056.685,
          -1080.583,
          -1104.432,
          -1128.232,
          -1151.981,
          -1175.6789999999999,
          -1199.323,
          -1222.914,
          -1246.4489999999998,
          -1269.928,
          -1293.349,
          -1316.711,
          -1340.013,
          -1363.254,
          -1386.432,
          -1409.546,
          -1432.595,
          -1455.5770000000002,
          -1478.4920000000002,
          -1501.3370000000002,
          -1524.112,
          -1546.816,
          -1569.4460000000001,
          -1592.001,
          -1614.481,
          -1636.8829999999998,
          -1659.207,
          -1681.45,
          -1703.612,
          -1725.69,
          -1747.684,
          -1769.5910000000001,
          -1791.411,
          -1813.142,
          -1834.781,
          -1856.328,
          -1877.7820000000002,
          -1899.139,
          -1920.399,
          -1941.56,
          -1962.62,
          -1983.5770000000002,
          -2004.431,
          -2025.1779999999999,
          -2045.817,
          -2066.347,
          -2086.765,
          -2107.069,
          -2127.258,
          -2147.3289999999997,
          -2167.281,
          -2187.112,
          -2206.819,
          -2226.401,
          -2245.855,
          -2265.179,
          -2284.371,
          -2303.429,
          -2322.35,
          -2341.132,
          -2359.7729999999997,
          -2378.27,
          -2396.6220000000003,
          -2414.824,
          -2432.876,
          -2450.774,
          -2468.515,
          -2486.098,
          -2503.518,
          -2520.774,
          -2537.863,
          -2554.782,
          -2571.527,
          -2588.096,
          -2604.485,
          -2620.6929999999998,
          -2636.7140000000004,
          -2652.547,
          -2668.187,
          -2683.632,
          -2698.877,
          -2713.92,
          -2728.756,
          -2743.382,
          -2757.7940000000003,
          -2771.988,
          -2785.961,
          -2799.7070000000003,
          -2813.223,
          -2826.505,
          -2839.5490000000004,
          -2852.348,
          -2864.9,
          -2877.2,
          -2889.242,
          -2901.022,
          -2912.535,
          -2923.7740000000003,
          -2934.736,
          -2945.415,
          -2955.804,
          -2965.8979999999997,
          -2975.691,
          -2985.178,
          -2994.3509999999997,
          -3003.205,
          -3011.7329999999997,
          -3019.927,
          -3027.782,
          -3035.289,
          -3042.442,
          -3049.232,
          -3055.652,
          -3061.6940000000004,
          -3067.349,
          -3072.6090000000004,
          -3077.465,
          -3081.908,
          -3085.928,
          -3089.5159999999996,
          -3092.6609999999996,
          -3095.353,
          -3097.5809999999997,
          -3099.335,
          -3100.6020000000003,
          -3101.3720000000003,
          -3101.63,
          -3101.366,
          -3100.565,
          -3099.215,
          -3097.3,
          -3094.8070000000002,
          -3091.72,
          -3088.0229999999997,
          -3083.7009999999996,
          -3078.736,
          -3073.1090000000004,
          -3066.804,
          -3059.801,
          -3052.0809999999997,
          -3043.6220000000003,
          -3034.4040000000005,
          -3024.4040000000005,
          -3013.599,
          -3001.965,
          -2989.4759999999997,
          -2976.107,
          -2961.83,
          -2946.616,
          -2930.4359999999997,
          -2913.259,
          -2895.052,
          -2875.782,
          -2855.4120000000003,
          -2833.906,
          -2811.2259999999997,
          -2787.3309999999997,
          -2762.178,
          -2735.725,
          -2707.925,
          -2678.728,
          -2648.086,
          -2615.946,
          -2582.2529999999997,
          -2546.95,
          -2509.9770000000003,
          -2471.2729999999997,
          -2430.772,
          -2388.41,
          -2344.115,
          -2297.8160000000003,
          -2249.44,
          -2198.913,
          -2146.155,
          -2091.089,
          -2033.6370000000002,
          -1973.7179999999998,
          -1911.255,
          -1846.172,
          -1778.3929999999998,
          -1707.852,
          -1634.486,
          -1558.241,
          -1479.076,
          -1396.9589999999998,
          -1311.882,
          -1223.853,
          -1132.905,
          -1039.098,
          -942.5269999999999,
          -843.316,
          -741.632,
          -637.678,
          -531.696,
          -423.969,
          -314.813,
          -204.576,
          -93.633,
          17.63,
          128.813,
          239.523,
          349.37199999999996,
          457.99800000000005,
          565.062,
          670.2589999999999,
          773.323,
          874.0219999999999,
          972.17,
          1067.616,
          1160.244,
          1249.976,
          1336.761,
          1420.575,
          1501.418,
          1579.307,
          1654.2779999999998,
          1726.379,
          1795.6660000000002,
          1862.204,
          1926.065,
          1987.3239999999998,
          2046.059,
          2102.349,
          2156.272,
          2207.91,
          2257.34,
          2304.639,
          2349.883,
          2393.145,
          2434.495,
          2474.002,
          2511.739,
          2547.7529999999997,
          2582.1220000000003,
          2614.899,
          2646.14,
          2675.9,
          2704.2309999999998,
          2731.184,
          2756.805,
          2781.139,
          2804.2309999999998,
          2826.123,
          2846.8540000000003,
          2866.4629999999997,
          2884.987,
          2902.4590000000003,
          2918.915,
          2934.385,
          2948.901,
          2962.493,
          2975.188,
          2987.014,
          2997.998,
          3008.1620000000003,
          3017.532,
          3026.131,
          3033.9809999999998,
          3041.1020000000003,
          3047.5159999999996,
          3053.242,
          3058.3,
          3062.7059999999997,
          3066.48,
          3069.636,
          3072.192,
          3074.164,
          3075.566,
          3076.413,
          3076.719,
          3076.4970000000003,
          3075.762,
          3074.525,
          3072.7990000000004,
          3070.595,
          3067.925,
          3064.8,
          3061.23,
          3057.2270000000003,
          3052.8,
          3047.9590000000003,
          3042.7129999999997,
          3037.071,
          3031.042,
          3024.635,
          3017.8579999999997,
          3010.719,
          3003.2259999999997,
          2995.387,
          2987.208,
          2978.698,
          2969.864,
          2960.711,
          2951.2470000000003,
          2941.478,
          2931.41,
          2921.05,
          2910.403,
          2899.475,
          2888.272,
          2876.8,
          2865.062,
          2853.066,
          2840.815,
          2828.315,
          2815.57,
          2802.586,
          2789.367,
          2775.917,
          2762.241,
          2748.343,
          2734.2270000000003,
          2719.8979999999997,
          2705.3579999999997,
          2690.613,
          2675.6659999999997,
          2660.5209999999997,
          2645.1809999999996,
          2629.651,
          2613.9320000000002,
          2598.03,
          2581.946,
          2565.686,
          2549.25,
          2532.644,
          2515.87,
          2498.931,
          2481.8289999999997,
          2464.5679999999998,
          2447.151,
          2429.581,
          2411.86,
          2393.99,
          2375.975,
          2357.817,
          2339.519,
          2321.083,
          2302.511,
          2283.806,
          2264.971,
          2246.007,
          2226.917,
          2207.703,
          2188.367,
          2168.9120000000003,
          2149.339,
          2129.651,
          2109.85,
          2089.938,
          2069.916,
          2049.7870000000003,
          2029.5529999999999,
          2009.215,
          1988.776,
          1968.237,
          1947.6,
          1926.8670000000002,
          1906.039,
          1885.119,
          1864.108,
          1843.007,
          1821.819,
          1800.545,
          1779.1870000000001,
          1757.746,
          1736.223,
          1714.621,
          1692.941,
          1671.185,
          1649.3529999999998,
          1627.4479999999999,
          1605.47,
          1583.422,
          1561.3039999999999,
          1539.119,
          1516.8670000000002,
          1494.55,
          1472.1689999999999,
          1449.726,
          1427.221,
          1404.6570000000002,
          1382.0339999999999,
          1359.354,
          1336.618,
          1313.828,
          1290.984,
          1268.087,
          1245.14,
          1222.143,
          1199.097,
          1176.004,
          1152.864,
          1129.68,
          1106.451,
          1083.18,
          1059.867,
          1036.514,
          1013.1210000000001,
          989.69,
          966.222,
          942.717,
          919.178,
          895.605,
          871.998,
          848.36,
          824.692,
          800.993,
          777.2660000000001,
          753.5110000000001,
          729.7289999999999,
          705.922,
          682.091,
          658.235,
          634.3580000000001,
          610.4580000000001,
          586.538,
          562.599,
          538.641,
          514.665,
          490.67199999999997,
          466.664,
          442.64099999999996,
          418.605,
          394.555,
          370.494,
          346.42199999999997,
          322.34,
          298.25,
          274.151,
          250.045,
          225.933,
          201.815,
          177.69400000000002,
          153.569,
          129.442,
          105.314,
          81.185,
          57.056000000000004,
          32.929,
          8.804,
          -15.318,
          -39.435,
          -63.548,
          -87.654,
          -111.75299999999999,
          -135.845,
          -159.92700000000002,
          -184,
          -208.062,
          -232.112,
          -256.15,
          -280.17400000000004,
          -304.184,
          -328.17800000000005,
          -352.156,
          -376.11699999999996,
          -400.059,
          -423.98199999999997,
          -447.885,
          -471.767,
          -495.62699999999995,
          -519.4630000000001,
          -543.276,
          -567.063,
          -590.825,
          -614.559,
          -638.266,
          -661.943,
          -685.591,
          -709.207,
          -732.7919999999999,
          -756.3439999999999,
          -779.8610000000001,
          -803.3439999999999,
          -826.79,
          -850.2,
          -873.571,
          -896.903,
          -920.195,
          -943.445,
          -966.653,
          -989.818,
          -1012.938,
          -1036.012,
          -1059.04,
          -1082.02,
          -1104.95,
          -1127.8310000000001,
          -1150.66,
          -1173.437,
          -1196.16,
          -1218.829,
          -1241.441,
          -1263.997,
          -1286.494,
          -1308.931,
          -1331.308,
          -1353.6229999999998,
          -1375.874,
          -1398.0610000000001,
          -1420.182,
          -1442.236,
          -1464.221,
          -1486.1370000000002,
          -1507.981,
          -1529.753,
          -1551.451,
          -1573.0739999999998,
          -1594.62,
          -1616.088,
          -1637.477,
          -1658.785,
          -1680.01,
          -1701.151,
          -1722.207,
          -1743.1760000000002,
          -1764.056,
          -1784.846,
          -1805.545,
          -1826.15,
          -1846.66,
          -1867.0739999999998,
          -1887.389,
          -1907.604,
          -1927.717,
          -1947.727,
          -1967.631,
          -1987.4279999999999,
          -2007.116,
          -2026.693,
          -2046.158,
          -2065.507,
          -2084.74,
          -2103.854,
          -2122.847,
          -2141.718,
          -2160.4629999999997,
          -2179.081,
          -2197.57,
          -2215.928,
          -2234.151,
          -2252.239,
          -2270.188,
          -2287.996,
          -2305.661,
          -2323.18,
          -2340.551,
          -2357.771,
          -2374.837,
          -2391.748,
          -2408.499,
          -2425.089,
          -2441.514,
          -2457.772,
          -2473.86,
          -2489.774,
          -2505.512,
          -2521.07,
          -2536.446,
          -2551.635,
          -2566.635,
          -2581.4429999999998,
          -2596.053,
          -2610.464,
          -2624.672,
          -2638.672,
          -2652.461,
          -2666.035,
          -2679.39,
          -2692.5209999999997,
          -2705.425,
          -2718.098,
          -2730.534,
          -2742.73,
          -2754.6809999999996,
          -2766.381,
          -2777.827,
          -2789.013,
          -2799.934,
          -2810.5840000000003,
          -2820.958,
          -2831.052,
          -2840.8579999999997,
          -2850.3720000000003,
          -2859.587,
          -2868.4959999999996,
          -2877.095,
          -2885.375,
          -2893.3309999999997,
          -2900.955,
          -2908.241,
          -2915.18,
          -2921.7659999999996,
          -2927.991,
          -2933.8459999999995,
          -2939.323,
          -2944.415,
          -2949.111,
          -2953.4040000000005,
          -2957.283,
          -2960.738,
          -2963.761,
          -2966.34,
          -2968.465,
          -2970.1240000000003,
          -2971.308,
          -2972.002,
          -2972.196,
          -2971.877,
          -2971.031,
          -2969.6459999999997,
          -2967.7059999999997,
          -2965.197,
          -2962.105,
          -2958.413,
          -2954.1059999999998,
          -2949.165,
          -2943.574,
          -2937.3140000000003,
          -2930.367,
          -2922.711,
          -2914.328,
          -2905.1940000000004,
          -2895.289,
          -2884.5890000000004,
          -2873.07,
          -2860.705,
          -2847.469,
          -2833.335,
          -2818.2729999999997,
          -2802.2540000000004,
          -2785.2459999999996,
          -2767.218,
          -2748.135,
          -2727.96,
          -2706.656,
          -2684.1859999999997,
          -2660.507,
          -2635.578,
          -2609.355,
          -2581.79,
          -2552.835,
          -2522.439,
          -2490.549,
          -2457.111,
          -2422.0660000000003,
          -2385.355,
          -2346.9139999999998,
          -2306.68,
          -2264.587,
          -2220.563,
          -2174.5370000000003,
          -2126.437,
          -2076.189,
          -2023.713,
          -1968.935,
          -1911.7779999999998,
          -1852.1629999999998,
          -1790.017,
          -1725.2679999999998,
          -1657.8470000000002,
          -1587.693,
          -1514.753,
          -1438.9820000000002,
          -1360.352,
          -1278.847,
          -1194.474,
          -1107.262,
          -1017.265,
          -924.568,
          -829.2919999999999,
          -731.5889999999999,
          -631.653,
          -529.7130000000001,
          -426.039,
          -320.931,
          -214.72299999999998,
          -107.773,
          -0.45399999999999996,
          106.85,
          213.757,
          319.89599999999996,
          424.911,
          528.476,
          630.2909999999999,
          730.095,
          827.663,
          922.81,
          1015.385,
          1105.274,
          1192.396,
          1276.6989999999998,
          1358.156,
          1436.765,
          1512.539,
          1585.511,
          1655.721,
          1723.225,
          1788.0839999999998,
          1850.364,
          1910.136,
          1967.476,
          2022.4560000000001,
          2075.154,
          2125.646,
          2174.006,
          2220.308,
          2264.623,
          2307.024,
          2347.577,
          2386.348,
          2423.401,
          2458.798,
          2492.598,
          2524.857,
          2555.631,
          2584.971,
          2612.926,
          2639.546,
          2664.8759999999997,
          2688.96,
          2711.841,
          2733.558,
          2754.15,
          2773.6540000000005,
          2792.105,
          2809.5370000000003,
          2825.9840000000004,
          2841.474,
          2856.039,
          2869.7059999999997,
          2882.5040000000004,
          2894.458,
          2905.593,
          2915.935,
          2925.505,
          2934.3259999999996,
          2942.4190000000003,
          2949.805,
          2956.5029999999997,
          2962.534,
          2967.914,
          2972.6609999999996,
          2976.7929999999997,
          2980.3259999999996,
          2983.276,
          2985.656,
          2987.4829999999997,
          2988.77,
          2989.531,
          2989.7790000000005,
          2989.527,
          2988.7859999999996,
          2987.5690000000004,
          2985.888,
          2983.7529999999997,
          2981.175,
          2978.164,
          2974.7309999999998,
          2970.884,
          2966.635,
          2961.99,
          2956.96,
          2951.554,
          2945.778,
          2939.6420000000003,
          2933.1540000000005,
          2926.32,
          2919.1479999999997,
          2911.6459999999997,
          2903.821,
          2895.678,
          2887.225,
          2878.469,
          2869.414,
          2860.0690000000004,
          2850.438,
          2840.527,
          2830.341,
          2819.887,
          2809.1690000000003,
          2798.1929999999998,
          2786.9640000000004,
          2775.486,
          2763.764,
          2751.804,
          2739.6090000000004,
          2727.185,
          2714.535,
          2701.663,
          2688.575,
          2675.2729999999997,
          2661.762,
          2648.046,
          2634.1290000000004,
          2620.014,
          2605.7039999999997,
          2591.2039999999997,
          2576.5170000000003,
          2561.647,
          2546.595,
          2531.367,
          2515.964,
          2500.391,
          2484.65,
          2468.744,
          2452.676,
          2436.449,
          2420.0660000000003,
          2403.529,
          2386.842,
          2370.006,
          2353.025,
          2335.901,
          2318.636,
          2301.2329999999997,
          2283.695,
          2266.0229999999997,
          2248.22,
          2230.2889999999998,
          2212.232,
          2194.05,
          2175.746,
          2157.323,
          2138.781,
          2120.124,
          2101.353,
          2082.471,
          2063.479,
          2044.379,
          2025.1729999999998,
          2005.8629999999998,
          1986.451,
          1966.9379999999999,
          1947.3270000000002,
          1927.619,
          1907.816,
          1887.92,
          1867.932,
          1847.854,
          1827.6870000000001,
          1807.434,
          1787.095,
          1766.6729999999998,
          1746.1689999999999,
          1725.5839999999998,
          1704.92,
          1684.1779999999999,
          1663.36,
          1642.4679999999998,
          1621.5020000000002,
          1600.465,
          1579.3570000000002,
          1558.18,
          1536.935,
          1515.624,
          1494.2479999999998,
          1472.808,
          1451.306,
          1429.743,
          1408.119,
          1386.4370000000001,
          1364.6979999999999,
          1342.9029999999998,
          1321.0529999999999,
          1299.149,
          1277.192,
          1255.184,
          1233.126,
          1211.019,
          1188.864,
          1166.662,
          1144.415,
          1122.123,
          1099.788,
          1077.411,
          1054.992,
          1032.5339999999999,
          1010.0360000000001,
          987.5,
          964.928,
          942.319,
          919.676,
          896.9989999999999,
          874.289,
          851.548,
          828.775,
          805.9730000000001,
          783.1419999999999,
          760.284,
          737.398,
          714.487,
          691.551,
          668.592,
          645.609,
          622.605,
          599.5790000000001,
          576.534,
          553.469,
          530.387,
          507.287,
          484.171,
          461.04,
          437.894,
          414.735,
          391.56300000000005,
          368.38,
          345.186,
          321.982,
          298.77,
          275.54900000000004,
          252.322,
          229.088,
          205.84900000000002,
          182.606,
          159.359,
          136.11,
          112.859,
          89.60799999999999,
          66.35600000000001,
          43.106,
          19.858,
          -3.388,
          -26.629,
          -49.86600000000001,
          -73.097,
          -96.322,
          -119.54,
          -142.749,
          -165.949,
          -189.139,
          -212.31799999999998,
          -235.485,
          -258.64,
          -281.78,
          -304.906,
          -328.017,
          -351.11,
          -374.18699999999995,
          -397.245,
          -420.284,
          -443.30300000000005,
          -466.301,
          -489.277,
          -512.229,
          -535.158,
          -558.062,
          -580.94,
          -603.7919999999999,
          -626.615,
          -649.41,
          -672.175,
          -694.91,
          -717.613,
          -740.283,
          -762.919,
          -785.5210000000001,
          -808.0880000000001,
          -830.617,
          -853.1089999999999,
          -875.563,
          -897.9760000000001,
          -920.3489999999999,
          -942.68,
          -964.9680000000001,
          -987.212,
          -1009.4110000000001,
          -1031.5639999999999,
          -1053.67,
          -1075.7269999999999,
          -1097.735,
          -1119.692,
          -1141.598,
          -1163.451,
          -1185.249,
          -1206.993,
          -1228.68,
          -1250.31,
          -1271.881,
          -1293.392,
          -1314.8410000000001,
          -1336.229,
          -1357.5520000000001,
          -1378.8110000000001,
          -1400.004,
          -1421.129,
          -1442.185,
          -1463.17,
          -1484.085,
          -1504.9260000000002,
          -1525.693,
          -1546.385,
          -1566.999,
          -1587.535,
          -1607.991,
          -1628.366,
          -1648.6570000000002,
          -1668.865,
          -1688.986,
          -1709.02,
          -1728.964,
          -1748.818,
          -1768.58,
          -1788.247,
          -1807.819,
          -1827.2939999999999,
          -1846.67,
          -1865.945,
          -1885.1170000000002,
          -1904.185,
          -1923.1470000000002,
          -1942.001,
          -1960.745,
          -1979.3770000000002,
          -1997.895,
          -2016.2979999999998,
          -2034.582,
          -2052.7470000000003,
          -2070.79,
          -2088.709,
          -2106.501,
          -2124.165,
          -2141.699,
          -2159.099,
          -2176.364,
          -2193.492,
          -2210.479,
          -2227.324,
          -2244.024,
          -2260.576,
          -2276.978,
          -2293.2270000000003,
          -2309.321,
          -2325.256,
          -2341.03,
          -2356.64,
          -2372.0820000000003,
          -2387.355,
          -2402.455,
          -2417.3779999999997,
          -2432.1220000000003,
          -2446.683,
          -2461.058,
          -2475.244,
          -2489.236,
          -2503.032,
          -2516.6279999999997,
          -2530.019,
          -2543.203,
          -2556.175,
          -2568.931,
          -2581.467,
          -2593.779,
          -2605.862,
          -2617.7129999999997,
          -2629.3259999999996,
          -2640.697,
          -2651.821,
          -2662.6929999999998,
          -2673.308,
          -2683.6609999999996,
          -2693.7470000000003,
          -2703.56,
          -2713.094,
          -2722.344,
          -2731.304,
          -2739.967,
          -2748.328,
          -2756.38,
          -2764.116,
          -2771.53,
          -2778.615,
          -2785.362,
          -2791.7659999999996,
          -2797.817,
          -2803.509,
          -2808.833,
          -2813.78,
          -2818.342,
          -2822.51,
          -2826.275,
          -2829.627,
          -2832.5559999999996,
          -2835.051,
          -2837.103,
          -2838.7,
          -2839.8309999999997,
          -2840.4840000000004,
          -2840.647,
          -2840.308,
          -2839.453,
          -2838.07,
          -2836.143,
          -2833.658,
          -2830.6009999999997,
          -2826.9559999999997,
          -2822.705,
          -2817.833,
          -2812.322,
          -2806.153,
          -2799.308,
          -2791.7659999999996,
          -2783.507,
          -2774.511,
          -2764.7529999999997,
          -2754.212,
          -2742.862,
          -2730.679,
          -2717.635,
          -2703.703,
          -2688.855,
          -2673.0609999999997,
          -2656.289,
          -2638.505,
          -2619.676,
          -2599.766,
          -2578.738,
          -2556.551,
          -2533.167,
          -2508.54,
          -2482.627,
          -2455.38,
          -2426.751,
          -2396.689,
          -2365.14,
          -2332.049,
          -2297.3579999999997,
          -2261.007,
          -2222.9320000000002,
          -2183.069,
          -2141.3520000000003,
          -2097.7110000000002,
          -2052.074,
          -2004.369,
          -1954.523,
          -1902.4589999999998,
          -1848.1029999999998,
          -1791.381,
          -1732.217,
          -1670.5439999999999,
          -1606.2920000000001,
          -1539.401,
          -1469.818,
          -1397.497,
          -1322.4089999999999,
          -1244.536,
          -1163.881,
          -1080.469,
          -994.3480000000001,
          -905.597,
          -814.327,
          -720.68,
          -624.84,
          -527.0219999999999,
          -427.48199999999997,
          -326.506,
          -224.41299999999998,
          -121.544,
          -18.259,
          85.075,
          188.08900000000003,
          290.425,
          391.73900000000003,
          491.713,
          590.055,
          686.513,
          780.863,
          872.922,
          962.544,
          1049.612,
          1134.046,
          1215.7910000000002,
          1294.819,
          1371.1229999999998,
          1444.713,
          1515.619,
          1583.8770000000002,
          1649.5379999999998,
          1712.66,
          1773.3029999999999,
          1831.536,
          1887.4289999999999,
          1941.0529999999999,
          1992.479,
          2041.781,
          2089.028,
          2134.292,
          2177.643,
          2219.146,
          2258.866,
          2296.868,
          2333.2129999999997,
          2367.958,
          2401.161,
          2432.876,
          2463.157,
          2492.051,
          2519.6079999999997,
          2545.874,
          2570.893,
          2594.709,
          2617.359,
          2638.884,
          2659.32,
          2678.704,
          2697.0690000000004,
          2714.448,
          2730.8720000000003,
          2746.3709999999996,
          2760.974,
          2774.7070000000003,
          2787.598,
          2799.672,
          2810.952,
          2821.4629999999997,
          2831.2259999999997,
          2840.263,
          2848.595,
          2856.241,
          2863.22,
          2869.551,
          2875.2509999999997,
          2880.3379999999997,
          2884.827,
          2888.735,
          2892.077,
          2894.867,
          2897.119,
          2898.8459999999995,
          2900.063,
          2900.782,
          2901.014,
          2900.7729999999997,
          2900.0679999999998,
          2898.9120000000003,
          2897.315,
          2895.288,
          2892.84,
          2889.9809999999998,
          2886.7209999999995,
          2883.0679999999998,
          2879.031,
          2874.62,
          2869.841,
          2864.704,
          2859.216,
          2853.385,
          2847.217,
          2840.7209999999995,
          2833.903,
          2826.77,
          2819.328,
          2811.5840000000003,
          2803.5440000000003,
          2795.2129999999997,
          2786.599,
          2777.7059999999997,
          2768.5409999999997,
          2759.1079999999997,
          2749.413,
          2739.46,
          2729.256,
          2718.805,
          2708.111,
          2697.18,
          2686.015,
          2674.6209999999996,
          2663.0029999999997,
          2651.165,
          2639.11,
          2626.843,
          2614.368,
          2601.689,
          2588.8089999999997,
          2575.732,
          2562.462,
          2549.002,
          2535.355,
          2521.526,
          2507.516,
          2493.33,
          2478.97,
          2464.44,
          2449.743,
          2434.881,
          2419.8579999999997,
          2404.676,
          2389.3379999999997,
          2373.846,
          2358.205,
          2342.415,
          2326.48,
          2310.403,
          2294.185,
          2277.8289999999997,
          2261.337,
          2244.712,
          2227.9570000000003,
          2211.072,
          2194.062,
          2176.926,
          2159.669,
          2142.292,
          2124.797,
          2107.186,
          2089.46,
          2071.623,
          2053.676,
          2035.621,
          2017.4589999999998,
          1999.194,
          1980.825,
          1962.356,
          1943.787,
          1925.121,
          1906.36,
          1887.504,
          1868.556,
          1849.5179999999998,
          1830.39,
          1811.175,
          1791.874,
          1772.4879999999998,
          1753.02,
          1733.47,
          1713.84,
          1694.132,
          1674.3470000000002,
          1654.486,
          1634.5510000000002,
          1614.543,
          1594.464,
          1574.3139999999999,
          1554.096,
          1533.81,
          1513.4579999999999,
          1493.0420000000001,
          1472.5610000000001,
          1452.019,
          1431.415,
          1410.751,
          1390.029,
          1369.249,
          1348.412,
          1327.521,
          1306.576,
          1285.578,
          1264.528,
          1243.428,
          1222.279,
          1201.0810000000001,
          1179.836,
          1158.545,
          1137.2089999999998,
          1115.829,
          1094.406,
          1072.941,
          1051.435,
          1029.89,
          1008.306,
          986.684,
          965.0260000000001,
          943.332,
          921.6030000000001,
          899.84,
          878.045,
          856.2180000000001,
          834.36,
          812.472,
          790.556,
          768.612,
          746.64,
          724.643,
          702.6210000000001,
          680.574,
          658.5039999999999,
          636.4119999999999,
          614.299,
          592.165,
          570.011,
          547.839,
          525.649,
          503.44199999999995,
          481.219,
          458.98199999999997,
          436.72900000000004,
          414.464,
          392.186,
          369.897,
          347.597,
          325.28700000000003,
          302.969,
          280.642,
          258.308,
          235.968,
          213.623,
          191.273,
          168.919,
          146.562,
          124.204,
          101.844,
          79.484,
          57.125,
          34.766999999999996,
          12.411,
          -9.941,
          -32.289,
          -54.632,
          -76.97,
          -99.3,
          -121.62299999999999,
          -143.938,
          -166.24400000000003,
          -188.53900000000002,
          -210.82299999999998,
          -233.09599999999998,
          -255.355,
          -277.601,
          -299.832,
          -322.048,
          -344.24800000000005,
          -366.43,
          -388.594,
          -410.74,
          -432.865,
          -454.969,
          -477.05199999999996,
          -499.11199999999997,
          -521.149,
          -543.161,
          -565.1469999999999,
          -587.1080000000001,
          -609.0409999999999,
          -630.946,
          -652.821,
          -674.6669999999999,
          -696.4810000000001,
          -718.2639999999999,
          -740.013,
          -761.7280000000001,
          -783.409,
          -805.053,
          -826.6610000000001,
          -848.23,
          -869.7610000000001,
          -891.2510000000001,
          -912.701,
          -934.1080000000001,
          -955.4730000000001,
          -976.793,
          -998.068,
          -1019.296,
          -1040.4769999999999,
          -1061.61,
          -1082.693,
          -1103.725,
          -1124.7060000000001,
          -1145.633,
          -1166.507,
          -1187.325,
          -1208.086,
          -1228.79,
          -1249.435,
          -1270.02,
          -1290.5439999999999,
          -1311.005,
          -1331.402,
          -1351.735,
          -1372.001,
          -1392.1989999999998,
          -1412.328,
          -1432.3870000000002,
          -1452.375,
          -1472.289,
          -1492.129,
          -1511.8929999999998,
          -1531.58,
          -1551.1889999999999,
          -1570.717,
          -1590.164,
          -1609.527,
          -1628.806,
          -1647.999,
          -1667.104,
          -1686.119,
          -1705.0439999999999,
          -1723.876,
          -1742.614,
          -1761.256,
          -1779.8,
          -1798.245,
          -1816.588,
          -1834.829,
          -1852.964,
          -1870.993,
          -1888.914,
          -1906.724,
          -1924.421,
          -1942.004,
          -1959.471,
          -1976.819,
          -1994.046,
          -2011.151,
          -2028.13,
          -2044.9820000000002,
          -2061.705,
          -2078.2960000000003,
          -2094.7529999999997,
          -2111.074,
          -2127.255,
          -2143.2960000000003,
          -2159.192,
          -2174.9410000000003,
          -2190.541,
          -2205.99,
          -2221.283,
          -2236.419,
          -2251.395,
          -2266.208,
          -2280.854,
          -2295.331,
          -2309.635,
          -2323.763,
          -2337.7129999999997,
          -2351.481,
          -2365.062,
          -2378.455,
          -2391.654,
          -2404.657,
          -2417.46,
          -2430.0589999999997,
          -2442.45,
          -2454.629,
          -2466.591,
          -2478.334,
          -2489.851,
          -2501.139,
          -2512.1929999999998,
          -2523.009,
          -2533.5820000000003,
          -2543.907,
          -2553.978,
          -2563.79,
          -2573.339,
          -2582.618,
          -2591.621,
          -2600.344,
          -2608.78,
          -2616.923,
          -2624.7670000000003,
          -2632.304,
          -2639.5290000000005,
          -2646.435,
          -2653.013,
          -2659.258,
          -2665.16,
          -2670.7140000000004,
          -2675.909,
          -2680.739,
          -2685.1940000000004,
          -2689.2659999999996,
          -2692.946,
          -2696.224,
          -2699.0890000000004,
          -2701.533,
          -2703.5440000000003,
          -2705.112,
          -2706.225,
          -2706.8720000000003,
          -2707.0409999999997,
          -2706.72,
          -2705.8940000000002,
          -2704.552,
          -2702.678,
          -2700.26,
          -2697.281,
          -2693.725,
          -2689.578,
          -2684.821,
          -2679.437,
          -2673.409,
          -2666.717,
          -2659.341,
          -2651.261,
          -2642.455,
          -2632.902,
          -2622.577,
          -2611.4570000000003,
          -2599.515,
          -2586.7270000000003,
          -2573.063,
          -2558.495,
          -2542.993,
          -2526.525,
          -2509.0589999999997,
          -2490.5589999999997,
          -2470.99,
          -2450.315,
          -2428.492,
          -2405.484,
          -2381.244,
          -2355.728,
          -2328.889,
          -2300.678,
          -2271.045,
          -2239.9339999999997,
          -2207.291,
          -2173.0570000000002,
          -2137.172,
          -2099.573,
          -2060.194,
          -2018.971,
          -1975.8339999999998,
          -1930.711,
          -1883.531,
          -1834.223,
          -1782.711,
          -1728.9229999999998,
          -1672.789,
          -1614.2379999999998,
          -1553.205,
          -1489.629,
          -1423.4560000000001,
          -1354.642,
          -1283.155,
          -1208.974,
          -1132.1019999999999,
          -1052.555,
          -970.378,
          -885.643,
          -798.451,
          -708.937,
          -617.27,
          -523.654,
          -428.33099999999996,
          -331.574,
          -233.68200000000002,
          -134.984,
          -35.821,
          63.452,
          162.483,
          260.925,
          358.44699999999995,
          454.74,
          549.521,
          642.5419999999999,
          733.587,
          822.475,
          909.06,
          993.2280000000001,
          1074.896,
          1154.007,
          1230.5330000000001,
          1304.461,
          1375.8020000000001,
          1444.576,
          1510.819,
          1574.578,
          1635.904,
          1694.8570000000002,
          1751.499,
          1805.895,
          1858.1129999999998,
          1908.223,
          1956.29,
          2002.384,
          2046.5720000000001,
          2088.919,
          2129.488,
          2168.342,
          2205.5429999999997,
          2241.105,
          2275.2110000000002,
          2307.7889999999998,
          2338.9339999999997,
          2368.695,
          2397.121,
          2424.257,
          2450.1479999999997,
          2474.8360000000002,
          2498.362,
          2520.764,
          2542.08,
          2562.345,
          2581.594,
          2599.859,
          2617.1710000000003,
          2633.5609999999997,
          2649.0570000000002,
          2663.687,
          2677.4759999999997,
          2690.4509999999996,
          2702.636,
          2714.053,
          2724.7270000000003,
          2734.677,
          2743.925,
          2752.49,
          2760.3909999999996,
          2767.647,
          2774.275,
          2780.2929999999997,
          2785.717,
          2790.562,
          2794.843,
          2798.5759999999996,
          2801.775,
          2804.453,
          2806.6220000000003,
          2808.296,
          2809.487,
          2810.2059999999997,
          2810.466,
          2810.277,
          2809.65,
          2808.595,
          2807.1220000000003,
          2805.241,
          2802.961,
          2800.2909999999997,
          2797.241,
          2793.8179999999998,
          2790.03,
          2785.886,
          2781.3940000000002,
          2776.56,
          2771.393,
          2765.9,
          2760.087,
          2753.96,
          2747.528,
          2740.795,
          2733.768,
          2726.453,
          2718.8559999999998,
          2710.9829999999997,
          2702.8379999999997,
          2694.428,
          2685.757,
          2676.8309999999997,
          2667.655,
          2658.2329999999997,
          2648.571,
          2638.672,
          2628.542,
          2618.1839999999997,
          2607.603,
          2596.803,
          2585.7889999999998,
          2574.563,
          2563.131,
          2551.495,
          2539.66,
          2527.629,
          2515.405,
          2502.993,
          2490.395,
          2477.615,
          2464.657,
          2451.522,
          2438.215,
          2424.738,
          2411.094,
          2397.2870000000003,
          2383.319,
          2369.1929999999998,
          2354.911,
          2340.4770000000003,
          2325.893,
          2311.161,
          2296.285,
          2281.266,
          2266.106,
          2250.81,
          2235.3779999999997,
          2219.813,
          2204.118,
          2188.294,
          2172.343,
          2156.269,
          2140.073,
          2123.756,
          2107.322,
          2090.771,
          2074.107,
          2057.33,
          2040.443,
          2023.4479999999999,
          2006.3470000000002,
          1989.141,
          1971.8310000000001,
          1954.421,
          1936.911,
          1919.3039999999999,
          1901.6,
          1883.8029999999999,
          1865.912,
          1847.93,
          1829.858,
          1811.6989999999998,
          1793.453,
          1775.122,
          1756.707,
          1738.21,
          1719.6329999999998,
          1700.976,
          1682.241,
          1663.431,
          1644.545,
          1625.585,
          1606.5529999999999,
          1587.45,
          1568.277,
          1549.036,
          1529.727,
          1510.3529999999998,
          1490.914,
          1471.412,
          1451.8470000000002,
          1432.221,
          1412.535,
          1392.7910000000002,
          1372.989,
          1353.131,
          1333.217,
          1313.249,
          1293.229,
          1273.156,
          1253.0330000000001,
          1232.859,
          1212.638,
          1192.368,
          1172.052,
          1151.691,
          1131.285,
          1110.835,
          1090.343,
          1069.81,
          1049.236,
          1028.623,
          1007.971,
          987.2819999999999,
          966.556,
          945.794,
          924.998,
          904.169,
          883.306,
          862.4119999999999,
          841.487,
          820.5319999999999,
          799.548,
          778.5360000000001,
          757.4960000000001,
          736.43,
          715.3389999999999,
          694.2230000000001,
          673.084,
          651.922,
          630.738,
          609.533,
          588.307,
          567.063,
          545.8,
          524.519,
          503.222,
          481.909,
          460.58099999999996,
          439.23900000000003,
          417.884,
          396.51599999999996,
          375.13599999999997,
          353.746,
          332.345,
          310.936,
          289.518,
          268.093,
          246.66099999999997,
          225.22400000000002,
          203.78099999999998,
          182.335,
          160.885,
          139.433,
          117.979,
          96.524,
          75.069,
          53.615,
          32.163000000000004,
          10.713,
          -10.732999999999999,
          -32.175,
          -53.611999999999995,
          -75.044,
          -96.469,
          -117.88600000000001,
          -139.295,
          -160.694,
          -182.084,
          -203.463,
          -224.83,
          -246.185,
          -267.526,
          -288.853,
          -310.165,
          -331.461,
          -352.74,
          -374.001,
          -395.244,
          -416.468,
          -437.671,
          -458.853,
          -480.01300000000003,
          -501.15,
          -522.263,
          -543.351,
          -564.414,
          -585.45,
          -606.4580000000001,
          -627.439,
          -648.389,
          -669.31,
          -690.199,
          -711.057,
          -731.8810000000001,
          -752.671,
          -773.426,
          -794.145,
          -814.827,
          -835.471,
          -856.076,
          -876.6419999999999,
          -897.166,
          -917.648,
          -938.087,
          -958.482,
          -978.832,
          -999.135,
          -1019.3919999999999,
          -1039.6,
          -1059.758,
          -1079.866,
          -1099.922,
          -1119.9260000000002,
          -1139.875,
          -1159.769,
          -1179.607,
          -1199.388,
          -1219.11,
          -1238.772,
          -1258.373,
          -1277.912,
          -1297.387,
          -1316.797,
          -1336.141,
          -1355.418,
          -1374.626,
          -1393.763,
          -1412.83,
          -1431.8229999999999,
          -1450.743,
          -1469.586,
          -1488.3529999999998,
          -1507.0410000000002,
          -1525.65,
          -1544.1760000000002,
          -1562.62,
          -1580.98,
          -1599.253,
          -1617.4379999999999,
          -1635.535,
          -1653.54,
          -1671.453,
          -1689.2720000000002,
          -1706.994,
          -1724.619,
          -1742.145,
          -1759.569,
          -1776.89,
          -1794.106,
          -1811.215,
          -1828.2160000000001,
          -1845.106,
          -1861.882,
          -1878.545,
          -1895.09,
          -1911.516,
          -1927.8210000000001,
          -1944.003,
          -1960.059,
          -1975.987,
          -1991.785,
          -2007.451,
          -2022.9820000000002,
          -2038.375,
          -2053.629,
          -2068.74,
          -2083.705,
          -2098.5229999999997,
          -2113.1910000000003,
          -2127.705,
          -2142.063,
          -2156.261,
          -2170.298,
          -2184.17,
          -2197.873,
          -2211.405,
          -2224.762,
          -2237.942,
          -2250.939,
          -2263.752,
          -2276.377,
          -2288.8089999999997,
          -2301.0460000000003,
          -2313.0820000000003,
          -2324.915,
          -2336.541,
          -2347.9539999999997,
          -2359.152,
          -2370.129,
          -2380.881,
          -2391.403,
          -2401.692,
          -2411.741,
          -2421.5460000000003,
          -2431.1020000000003,
          -2440.404,
          -2449.446,
          -2458.223,
          -2466.729,
          -2474.958,
          -2482.903,
          -2490.56,
          -2497.9210000000003,
          -2504.98,
          -2511.729,
          -2518.163,
          -2524.274,
          -2530.054,
          -2535.495,
          -2540.59,
          -2545.331,
          -2549.708,
          -2553.714,
          -2557.339,
          -2560.574,
          -2563.41,
          -2565.835,
          -2567.84,
          -2569.415,
          -2570.547,
          -2571.226,
          -2571.439,
          -2571.174,
          -2570.419,
          -2569.16,
          -2567.384,
          -2565.075,
          -2562.22,
          -2558.802,
          -2554.805,
          -2550.2129999999997,
          -2545.008,
          -2539.173,
          -2532.687,
          -2525.533,
          -2517.688,
          -2509.132,
          -2499.843,
          -2489.797,
          -2478.969,
          -2467.335,
          -2454.868,
          -2441.54,
          -2427.323,
          -2412.187,
          -2396.099,
          -2379.026,
          -2360.9339999999997,
          -2341.788,
          -2321.548,
          -2300.177,
          -2277.631,
          -2253.868,
          -2228.843,
          -2202.509,
          -2174.8160000000003,
          -2145.712,
          -2115.144,
          -2083.056,
          -2049.391,
          -2014.086,
          -1977.08,
          -1938.31,
          -1897.7060000000001,
          -1855.2020000000002,
          -1810.73,
          -1764.215,
          -1715.59,
          -1664.783,
          -1611.7220000000002,
          -1556.342,
          -1498.5770000000002,
          -1438.3670000000002,
          -1375.6589999999999,
          -1310.407,
          -1242.578,
          -1172.151,
          -1099.122,
          -1023.507,
          -945.342,
          -864.694,
          -781.653,
          -696.346,
          -608.931,
          -519.599,
          -428.575,
          -336.119,
          -242.517,
          -148.077,
          -53.126999999999995,
          41.996,
          136.952,
          231.408,
          325.046,
          417.56699999999995,
          508.69699999999995,
          598.194,
          685.847,
          771.4780000000001,
          854.943,
          936.13,
          1014.953,
          1091.356,
          1165.305,
          1236.787,
          1305.809,
          1372.386,
          1436.5520000000001,
          1498.348,
          1557.8220000000001,
          1615.0279999999998,
          1670.025,
          1722.874,
          1773.64,
          1822.385,
          1869.174,
          1914.0729999999999,
          1957.1429999999998,
          1998.4479999999999,
          2038.0479999999998,
          2076.002,
          2112.367,
          2147.199,
          2180.552,
          2212.4770000000003,
          2243.024,
          2272.241,
          2300.173,
          2326.866,
          2352.36,
          2376.696,
          2399.913,
          2422.049,
          2443.139,
          2463.217,
          2482.315,
          2500.465,
          2517.697,
          2534.04,
          2549.521,
          2564.167,
          2578.0029999999997,
          2591.052,
          2603.339,
          2614.886,
          2625.715,
          2635.845,
          2645.298,
          2654.091,
          2662.243,
          2669.772,
          2676.6940000000004,
          2683.026,
          2688.784,
          2693.9829999999997,
          2698.637,
          2702.761,
          2706.368,
          2709.4709999999995,
          2712.0820000000003,
          2714.2140000000004,
          2715.8790000000004,
          2717.087,
          2717.85,
          2718.179,
          2718.083,
          2717.574,
          2716.659,
          2715.349,
          2713.652,
          2711.578,
          2709.135,
          2706.3309999999997,
          2703.173,
          2699.67,
          2695.829,
          2691.657,
          2687.1609999999996,
          2682.349,
          2677.2259999999997,
          2671.8,
          2666.075,
          2660.06,
          2653.759,
          2647.178,
          2640.323,
          2633.2,
          2625.813,
          2618.1679999999997,
          2610.27,
          2602.123,
          2593.7329999999997,
          2585.105,
          2576.242,
          2567.15,
          2557.831,
          2548.292,
          2538.535,
          2528.565,
          2518.386,
          2508.002,
          2497.416,
          2486.632,
          2475.653,
          2464.4829999999997,
          2453.126,
          2441.585,
          2429.863,
          2417.9629999999997,
          2405.889,
          2393.643,
          2381.228,
          2368.6479999999997,
          2355.905,
          2343.002,
          2329.942,
          2316.7270000000003,
          2303.361,
          2289.845,
          2276.183,
          2262.376,
          2248.427,
          2234.339,
          2220.114,
          2205.755,
          2191.262,
          2176.64,
          2161.889,
          2147.013,
          2132.013,
          2116.89,
          2101.6479999999997,
          2086.2889999999998,
          2070.813,
          2055.224,
          2039.5220000000002,
          2023.711,
          2007.7910000000002,
          1991.764,
          1975.6329999999998,
          1959.399,
          1943.0629999999999,
          1926.628,
          1910.095,
          1893.4660000000001,
          1876.7420000000002,
          1859.925,
          1843.017,
          1826.0179999999998,
          1808.931,
          1791.757,
          1774.497,
          1757.154,
          1739.727,
          1722.22,
          1704.6329999999998,
          1686.967,
          1669.224,
          1651.405,
          1633.5120000000002,
          1615.546,
          1597.5079999999998,
          1579.4,
          1561.2220000000002,
          1542.976,
          1524.6629999999998,
          1506.2839999999999,
          1487.842,
          1469.335,
          1450.767,
          1432.138,
          1413.4489999999998,
          1394.701,
          1375.896,
          1357.0339999999999,
          1338.1170000000002,
          1319.145,
          1300.121,
          1281.0439999999999,
          1261.9160000000002,
          1242.738,
          1223.511,
          1204.236,
          1184.914,
          1165.546,
          1146.133,
          1126.6760000000002,
          1107.1760000000002,
          1087.634,
          1068.05,
          1048.427,
          1028.764,
          1009.063,
          989.325,
          969.55,
          949.74,
          929.895,
          910.0160000000001,
          890.105,
          870.1610000000001,
          850.187,
          830.182,
          810.148,
          790.086,
          769.9960000000001,
          749.88,
          729.737,
          709.57,
          689.378,
          669.164,
          648.9259999999999,
          628.6669999999999,
          608.388,
          588.0880000000001,
          567.769,
          547.432,
          527.077,
          506.70599999999996,
          486.31800000000004,
          465.916,
          445.499,
          425.069,
          404.62699999999995,
          384.17199999999997,
          363.707,
          343.231,
          322.745,
          302.251,
          281.749,
          261.24,
          240.725,
          220.204,
          199.679,
          179.15,
          158.61700000000002,
          138.082,
          117.546,
          97.009,
          76.472,
          55.93600000000001,
          35.400999999999996,
          14.869000000000002,
          -5.66,
          -26.185,
          -46.705,
          -67.219,
          -87.727,
          -108.228,
          -128.721,
          -149.205,
          -169.68,
          -190.144,
          -210.59599999999998,
          -231.037,
          -251.465,
          -271.879,
          -292.278,
          -312.663,
          -333.031,
          -353.38199999999995,
          -373.715,
          -394.029,
          -414.324,
          -434.599,
          -454.852,
          -475.083,
          -495.291,
          -515.475,
          -535.635,
          -555.769,
          -575.876,
          -595.956,
          -616.008,
          -636.031,
          -656.023,
          -675.985,
          -695.914,
          -715.811,
          -735.674,
          -755.502,
          -775.294,
          -795.05,
          -814.768,
          -834.447,
          -854.086,
          -873.685,
          -893.243,
          -912.758,
          -932.2289999999999,
          -951.655,
          -971.035,
          -990.3689999999999,
          -1009.655,
          -1028.891,
          -1048.078,
          -1067.213,
          -1086.296,
          -1105.326,
          -1124.3010000000002,
          -1143.22,
          -1162.083,
          -1180.887,
          -1199.632,
          -1218.316,
          -1236.938,
          -1255.498,
          -1273.993,
          -1292.423,
          -1310.785,
          -1329.08,
          -1347.305,
          -1365.4589999999998,
          -1383.5410000000002,
          -1401.549,
          -1419.4820000000002,
          -1437.339,
          -1455.1170000000002,
          -1472.816,
          -1490.435,
          -1507.97,
          -1525.422,
          -1542.7879999999998,
          -1560.067,
          -1577.257,
          -1594.3570000000002,
          -1611.364,
          -1628.2779999999998,
          -1645.096,
          -1661.816,
          -1678.4379999999999,
          -1694.9579999999999,
          -1711.376,
          -1727.6889999999999,
          -1743.895,
          -1759.9920000000002,
          -1775.979,
          -1791.8529999999998,
          -1807.612,
          -1823.255,
          -1838.7779999999998,
          -1854.181,
          -1869.4589999999998,
          -1884.612,
          -1899.6370000000002,
          -1914.5320000000002,
          -1929.293,
          -1943.9189999999999,
          -1958.4070000000002,
          -1972.754,
          -1986.9589999999998,
          -2001.017,
          -2014.9260000000002,
          -2028.684,
          -2042.2879999999998,
          -2055.735,
          -2069.021,
          -2082.143,
          -2095.099,
          -2107.885,
          -2120.498,
          -2132.935,
          -2145.1910000000003,
          -2157.264,
          -2169.15,
          -2180.844,
          -2192.344,
          -2203.646,
          -2214.744,
          -2225.636,
          -2236.3160000000003,
          -2246.781,
          -2257.026,
          -2267.047,
          -2276.8379999999997,
          -2286.395,
          -2295.7129999999997,
          -2304.7870000000003,
          -2313.612,
          -2322.1820000000002,
          -2330.491,
          -2338.533,
          -2346.304,
          -2353.7960000000003,
          -2361.004,
          -2367.9210000000003,
          -2374.541,
          -2380.855,
          -2386.859,
          -2392.5429999999997,
          -2397.901,
          -2402.924,
          -2407.606,
          -2411.936,
          -2415.908,
          -2419.511,
          -2422.738,
          -2425.577,
          -2428.02,
          -2430.056,
          -2431.674,
          -2432.864,
          -2433.614,
          -2433.913,
          -2433.748,
          -2433.106,
          -2431.976,
          -2430.341,
          -2428.19,
          -2425.507,
          -2422.276,
          -2418.482,
          -2414.107,
          -2409.135,
          -2403.548,
          -2397.327,
          -2390.452,
          -2382.903,
          -2374.659,
          -2365.697,
          -2355.995,
          -2345.528,
          -2334.27,
          -2322.196,
          -2309.278,
          -2295.487,
          -2280.7929999999997,
          -2265.1639999999998,
          -2248.567,
          -2230.967,
          -2212.3289999999997,
          -2192.614,
          -2171.785,
          -2149.797,
          -2126.6079999999997,
          -2102.173,
          -2076.445,
          -2049.375,
          -2020.91,
          -1990.997,
          -1959.579,
          -1926.601,
          -1892,
          -1855.715,
          -1817.681,
          -1777.8339999999998,
          -1736.104,
          -1692.425,
          -1646.7279999999998,
          -1598.943,
          -1549.0020000000002,
          -1496.84,
          -1442.391,
          -1385.599,
          -1326.408,
          -1264.774,
          -1200.661,
          -1134.047,
          -1064.925,
          -993.305,
          -919.221,
          -842.7280000000001,
          -763.9119999999999,
          -682.8889999999999,
          -599.802,
          -514.8330000000001,
          -428.19300000000004,
          -340.12300000000005,
          -250.895,
          -160.80200000000002,
          -70.154,
          20.726,
          111.516,
          201.895,
          291.557,
          380.215,
          467.603,
          553.487,
          637.66,
          719.948,
          800.211,
          878.3330000000001,
          954.2330000000001,
          1027.85,
          1099.149,
          1168.115,
          1234.747,
          1299.062,
          1361.0870000000002,
          1420.859,
          1478.422,
          1533.825,
          1587.124,
          1638.376,
          1687.638,
          1734.9720000000002,
          1780.44,
          1824.1,
          1866.0120000000002,
          1906.236,
          1944.83,
          1981.8470000000002,
          2017.3429999999998,
          2051.3720000000003,
          2083.984,
          2115.2270000000003,
          2145.149,
          2173.795,
          2201.21,
          2227.435,
          2252.51,
          2276.473,
          2299.362,
          2321.2129999999997,
          2342.0589999999997,
          2361.9320000000002,
          2380.864,
          2398.885,
          2416.0229999999997,
          2432.306,
          2447.761,
          2462.411,
          2476.282,
          2489.397,
          2501.778,
          2513.446,
          2524.422,
          2534.726,
          2544.377,
          2553.3920000000003,
          2561.79,
          2569.5879999999997,
          2576.8,
          2583.444,
          2589.534,
          2595.084,
          2600.109,
          2604.6220000000003,
          2608.637,
          2612.165,
          2615.218,
          2617.81,
          2619.949,
          2621.6479999999997,
          2622.917,
          2623.7659999999996,
          2624.205,
          2624.243,
          2623.8909999999996,
          2623.156,
          2622.047,
          2620.573,
          2618.742,
          2616.561,
          2614.0389999999998,
          2611.183,
          2607.999,
          2604.495,
          2600.678,
          2596.554,
          2592.129,
          2587.409,
          2582.402,
          2577.112,
          2571.545,
          2565.7070000000003,
          2559.604,
          2553.239,
          2546.619,
          2539.749,
          2532.633,
          2525.276,
          2517.683,
          2509.8579999999997,
          2501.805,
          2493.529,
          2485.034,
          2476.325,
          2467.404,
          2458.276,
          2448.944,
          2439.413,
          2429.685,
          2419.765,
          2409.655,
          2399.36,
          2388.882,
          2378.225,
          2367.3920000000003,
          2356.385,
          2345.208,
          2333.864,
          2322.356,
          2310.686,
          2298.8579999999997,
          2286.873,
          2274.736,
          2262.447,
          2250.01,
          2237.427,
          2224.701,
          2211.834,
          2198.8289999999997,
          2185.687,
          2172.411,
          2159.0029999999997,
          2145.466,
          2131.801,
          2118.011,
          2104.097,
          2090.063,
          2075.909,
          2061.637,
          2047.25,
          2032.75,
          2018.138,
          2003.415,
          1988.585,
          1973.649,
          1958.608,
          1943.464,
          1928.2179999999998,
          1912.874,
          1897.431,
          1881.892,
          1866.257,
          1850.53,
          1834.711,
          1818.8020000000001,
          1802.8039999999999,
          1786.719,
          1770.5479999999998,
          1754.2920000000001,
          1737.954,
          1721.5339999999999,
          1705.033,
          1688.454,
          1671.797,
          1655.0629999999999,
          1638.255,
          1621.3729999999998,
          1604.418,
          1587.392,
          1570.296,
          1553.131,
          1535.899,
          1518.6,
          1501.236,
          1483.807,
          1466.316,
          1448.7620000000002,
          1431.148,
          1413.474,
          1395.741,
          1377.951,
          1360.105,
          1342.203,
          1324.246,
          1306.236,
          1288.174,
          1270.0610000000001,
          1251.897,
          1233.684,
          1215.422,
          1197.113,
          1178.757,
          1160.356,
          1141.911,
          1123.422,
          1104.89,
          1086.316,
          1067.702,
          1049.047,
          1030.354,
          1011.622,
          992.8530000000001,
          974.047,
          955.206,
          936.331,
          917.421,
          898.4789999999999,
          879.505,
          860.4989999999999,
          841.462,
          822.3969999999999,
          803.302,
          784.179,
          765.03,
          745.8539999999999,
          726.6519999999999,
          707.426,
          688.176,
          668.903,
          649.607,
          630.29,
          610.952,
          591.594,
          572.217,
          552.822,
          533.409,
          513.979,
          494.533,
          475.07199999999995,
          455.596,
          436.10699999999997,
          416.60400000000004,
          397.09,
          377.56300000000005,
          358.027,
          338.48,
          318.923,
          299.35900000000004,
          279.78700000000003,
          260.207,
          240.622,
          221.03099999999998,
          201.435,
          181.83599999999998,
          162.233,
          142.628,
          123.021,
          103.413,
          83.806,
          64.19800000000001,
          44.592,
          24.989,
          5.388,
          -14.21,
          -33.803000000000004,
          -53.39,
          -72.972,
          -92.54700000000001,
          -112.115,
          -131.675,
          -151.225,
          -170.766,
          -190.296,
          -209.815,
          -229.322,
          -248.81599999999997,
          -268.296,
          -287.762,
          -307.212,
          -326.64599999999996,
          -346.064,
          -365.463,
          -384.844,
          -404.20599999999996,
          -423.548,
          -442.86800000000005,
          -462.167,
          -481.44300000000004,
          -500.69599999999997,
          -519.924,
          -539.127,
          -558.303,
          -577.453,
          -596.575,
          -615.668,
          -634.732,
          -653.765,
          -672.7660000000001,
          -691.7360000000001,
          -710.672,
          -729.573,
          -748.44,
          -767.2710000000001,
          -786.064,
          -804.82,
          -823.5360000000001,
          -842.2130000000001,
          -860.8489999999999,
          -879.443,
          -897.993,
          -916.5,
          -934.962,
          -953.378,
          -971.7460000000001,
          -990.067,
          -1008.3380000000001,
          -1026.559,
          -1044.728,
          -1062.845,
          -1080.9080000000001,
          -1098.9160000000002,
          -1116.868,
          -1134.763,
          -1152.599,
          -1170.376,
          -1188.0910000000001,
          -1205.745,
          -1223.335,
          -1240.861,
          -1258.3210000000001,
          -1275.713,
          -1293.037,
          -1310.2910000000002,
          -1327.473,
          -1344.5829999999999,
          -1361.619,
          -1378.579,
          -1395.4620000000002,
          -1412.266,
          -1428.99,
          -1445.6329999999998,
          -1462.193,
          -1478.668,
          -1495.056,
          -1511.3570000000002,
          -1527.568,
          -1543.6870000000001,
          -1559.713,
          -1575.645,
          -1591.48,
          -1607.217,
          -1622.8529999999998,
          -1638.3870000000002,
          -1653.817,
          -1669.14,
          -1684.356,
          -1699.4620000000002,
          -1714.455,
          -1729.3339999999998,
          -1744.0970000000002,
          -1758.741,
          -1773.264,
          -1787.6629999999998,
          -1801.9370000000001,
          -1816.0839999999998,
          -1830.099,
          -1843.9820000000002,
          -1857.73,
          -1871.339,
          -1884.808,
          -1898.1329999999998,
          -1911.3110000000001,
          -1924.3410000000001,
          -1937.2179999999998,
          -1949.941,
          -1962.505,
          -1974.908,
          -1987.1470000000002,
          -1999.2179999999998,
          -2011.118,
          -2022.844,
          -2034.391,
          -2045.757,
          -2056.937,
          -2067.928,
          -2078.7270000000003,
          -2089.327,
          -2099.7270000000003,
          -2109.922,
          -2119.906,
          -2129.676,
          -2139.228,
          -2148.555,
          -2157.655,
          -2166.521,
          -2175.1479999999997,
          -2183.532,
          -2191.667,
          -2199.547,
          -2207.166,
          -2214.519,
          -2221.599,
          -2228.4,
          -2234.915,
          -2241.138,
          -2247.063,
          -2252.68,
          -2257.985,
          -2262.968,
          -2267.6220000000003,
          -2271.938,
          -2275.909,
          -2279.525,
          -2282.779,
          -2285.659,
          -2288.157,
          -2290.262,
          -2291.964,
          -2293.2529999999997,
          -2294.117,
          -2294.544,
          -2294.5229999999997,
          -2294.041,
          -2293.0860000000002,
          -2291.643,
          -2289.698,
          -2287.239,
          -2284.248,
          -2280.71,
          -2276.609,
          -2271.927,
          -2266.647,
          -2260.75,
          -2254.217,
          -2247.028,
          -2239.1620000000003,
          -2230.596,
          -2221.3070000000002,
          -2211.271,
          -2200.464,
          -2188.8579999999997,
          -2176.427,
          -2163.1420000000003,
          -2148.973,
          -2133.888,
          -2117.853,
          -2100.835,
          -2082.797,
          -2063.703,
          -2043.5120000000002,
          -2022.182,
          -1999.671,
          -1975.933,
          -1950.921,
          -1924.586,
          -1896.875,
          -1867.736,
          -1837.115,
          -1804.95,
          -1771.184,
          -1735.754,
          -1698.599,
          -1659.652,
          -1618.848,
          -1576.119,
          -1531.399,
          -1484.6229999999998,
          -1435.724,
          -1384.641,
          -1331.317,
          -1275.6960000000001,
          -1217.735,
          -1157.396,
          -1094.654,
          -1029.501,
          -961.941,
          -892.003,
          -819.7360000000001,
          -745.2180000000001,
          -668.551,
          -589.871,
          -509.345,
          -427.16900000000004,
          -343.57,
          -258.80400000000003,
          -173.146,
          -86.891,
          -0.34299999999999997,
          86.18799999999999,
          172.399,
          257.994,
          342.69699999999995,
          426.25300000000004,
          508.43300000000005,
          589.039,
          667.8989999999999,
          744.873,
          819.8510000000001,
          892.747,
          963.5010000000001,
          1032.076,
          1098.451,
          1162.627,
          1224.613,
          1284.432,
          1342.119,
          1397.711,
          1451.257,
          1502.8029999999999,
          1552.404,
          1600.115,
          1645.9920000000002,
          1690.0910000000001,
          1732.47,
          1773.184,
          1812.2879999999998,
          1849.836,
          1885.8829999999998,
          1920.477,
          1953.7320000000002,
          1985.5079999999998,
          2016.0410000000002,
          2045.31,
          2073.36,
          2100.231,
          2125.964,
          2150.598,
          2174.1679999999997,
          2196.709,
          2218.255,
          2238.8379999999997,
          2258.491,
          2277.241,
          2295.117,
          2312.147,
          2328.357,
          2343.772,
          2358.416,
          2372.312,
          2385.482,
          2397.947,
          2409.728,
          2420.844,
          2431.315,
          2441.157,
          2450.389,
          2459.028,
          2467.089,
          2474.5879999999997,
          2481.54,
          2487.959,
          2493.8579999999997,
          2499.2529999999997,
          2504.154,
          2508.575,
          2512.528,
          2516.024,
          2519.074,
          2521.69,
          2523.881,
          2525.657,
          2527.028,
          2528.005,
          2528.595,
          2528.8070000000002,
          2528.651,
          2528.134,
          2527.265,
          2526.051,
          2524.5,
          2522.618,
          2520.4139999999998,
          2517.894,
          2515.064,
          2511.9320000000002,
          2508.5029999999997,
          2504.783,
          2500.779,
          2496.495,
          2491.939,
          2487.115,
          2482.028,
          2476.6839999999997,
          2471.0879999999997,
          2465.245,
          2459.158,
          2452.834,
          2446.277,
          2439.49,
          2432.479,
          2425.2470000000003,
          2417.799,
          2410.139,
          2402.269,
          2394.195,
          2385.92,
          2377.448,
          2368.781,
          2359.924,
          2350.88,
          2341.652,
          2332.243,
          2322.657,
          2312.897,
          2302.965,
          2292.865,
          2282.599,
          2272.1710000000003,
          2261.5820000000003,
          2250.837,
          2239.937,
          2228.885,
          2217.683,
          2206.334,
          2194.841,
          2183.206,
          2171.431,
          2159.518,
          2147.471,
          2135.29,
          2122.978,
          2110.538,
          2097.971,
          2085.279,
          2072.465,
          2059.53,
          2046.477,
          2033.307,
          2020.0220000000002,
          2006.6229999999998,
          1993.114,
          1979.495,
          1965.769,
          1951.9360000000001,
          1938,
          1923.96,
          1909.82,
          1895.58,
          1881.243,
          1866.809,
          1852.28,
          1837.658,
          1822.944,
          1808.141,
          1793.2479999999998,
          1778.2679999999998,
          1763.2020000000002,
          1748.0510000000002,
          1732.817,
          1717.501,
          1702.105,
          1686.629,
          1671.075,
          1655.445,
          1639.7379999999998,
          1623.9579999999999,
          1608.105,
          1592.18,
          1576.184,
          1560.118,
          1543.985,
          1527.7839999999999,
          1511.517,
          1495.185,
          1478.789,
          1462.3310000000001,
          1445.8110000000001,
          1429.23,
          1412.59,
          1395.891,
          1379.135,
          1362.3220000000001,
          1345.453,
          1328.53,
          1311.5539999999999,
          1294.525,
          1277.445,
          1260.3139999999999,
          1243.133,
          1225.904,
          1208.627,
          1191.302,
          1173.932,
          1156.517,
          1139.058,
          1121.555,
          1104.01,
          1086.424,
          1068.797,
          1051.13,
          1033.424,
          1015.68,
          997.898,
          980.081,
          962.227,
          944.3389999999999,
          926.4169999999999,
          908.462,
          890.4739999999999,
          872.455,
          854.405,
          836.324,
          818.215,
          800.078,
          781.9119999999999,
          763.72,
          745.502,
          727.258,
          708.99,
          690.698,
          672.383,
          654.045,
          635.686,
          617.306,
          598.9069999999999,
          580.487,
          562.049,
          543.594,
          525.121,
          506.631,
          488.126,
          469.606,
          451.07199999999995,
          432.524,
          413.964,
          395.39099999999996,
          376.80699999999996,
          358.212,
          339.608,
          320.994,
          302.372,
          283.742,
          265.105,
          246.46099999999998,
          227.812,
          209.158,
          190.5,
          171.838,
          153.174,
          134.507,
          115.84,
          97.171,
          78.503,
          59.835,
          41.169,
          22.506,
          3.845,
          -14.812000000000001,
          -33.465,
          -52.111999999999995,
          -70.75399999999999,
          -89.389,
          -108.016,
          -126.635,
          -145.246,
          -163.847,
          -182.437,
          -201.017,
          -219.584,
          -238.139,
          -256.681,
          -275.20799999999997,
          -293.721,
          -312.218,
          -330.69800000000004,
          -349.161,
          -367.606,
          -386.032,
          -404.439,
          -422.825,
          -441.19,
          -459.532,
          -477.852,
          -496.149,
          -514.42,
          -532.6659999999999,
          -550.886,
          -569.0790000000001,
          -587.244,
          -605.381,
          -623.487,
          -641.563,
          -659.6080000000001,
          -677.62,
          -695.5989999999999,
          -713.543,
          -731.453,
          -749.326,
          -767.163,
          -784.962,
          -802.721,
          -820.441,
          -838.12,
          -855.757,
          -873.3510000000001,
          -890.9019999999999,
          -908.4069999999999,
          -925.867,
          -943.279,
          -960.6439999999999,
          -977.959,
          -995.2239999999999,
          -1012.438,
          -1029.599,
          -1046.7060000000001,
          -1063.759,
          -1080.756,
          -1097.695,
          -1114.576,
          -1131.3980000000001,
          -1148.1589999999999,
          -1164.858,
          -1181.493,
          -1198.0639999999999,
          -1214.569,
          -1231.007,
          -1247.376,
          -1263.675,
          -1279.902,
          -1296.057,
          -1312.138,
          -1328.142,
          -1344.07,
          -1359.9189999999999,
          -1375.6870000000001,
          -1391.374,
          -1406.9779999999998,
          -1422.496,
          -1437.9270000000001,
          -1453.271,
          -1468.524,
          -1483.685,
          -1498.7520000000002,
          -1513.725,
          -1528.6,
          -1543.375,
          -1558.05,
          -1572.622,
          -1587.088,
          -1601.4479999999999,
          -1615.6979999999999,
          -1629.838,
          -1643.864,
          -1657.774,
          -1671.566,
          -1685.239,
          -1698.7879999999998,
          -1712.213,
          -1725.511,
          -1738.6779999999999,
          -1751.714,
          -1764.614,
          -1777.376,
          -1789.9979999999998,
          -1802.476,
          -1814.809,
          -1826.9920000000002,
          -1839.023,
          -1850.899,
          -1862.6170000000002,
          -1874.1729999999998,
          -1885.5639999999999,
          -1896.786,
          -1907.8370000000002,
          -1918.7120000000002,
          -1929.4089999999999,
          -1939.922,
          -1950.249,
          -1960.384,
          -1970.325,
          -1980.067,
          -1989.606,
          -1998.9370000000001,
          -2008.055,
          -2016.957,
          -2025.636,
          -2034.089,
          -2042.31,
          -2050.2929999999997,
          -2058.034,
          -2065.527,
          -2072.765,
          -2079.744,
          -2086.456,
          -2092.896,
          -2099.056,
          -2104.931,
          -2110.514,
          -2115.7960000000003,
          -2120.771,
          -2125.431,
          -2129.768,
          -2133.774,
          -2137.44,
          -2140.757,
          -2143.717,
          -2146.31,
          -2148.526,
          -2150.354,
          -2151.785,
          -2152.8070000000002,
          -2153.409,
          -2153.58,
          -2153.306,
          -2152.576,
          -2151.375,
          -2149.6910000000003,
          -2147.508,
          -2144.813,
          -2141.589,
          -2137.82,
          -2133.489,
          -2128.5789999999997,
          -2123.071,
          -2116.946,
          -2110.1839999999997,
          -2102.765,
          -2094.666,
          -2085.865,
          -2076.337,
          -2066.0570000000002,
          -2055.001,
          -2043.139,
          -2030.445,
          -2016.888,
          -2002.4360000000001,
          -1987.056,
          -1970.715,
          -1953.376,
          -1935.0020000000002,
          -1915.5539999999999,
          -1894.989,
          -1873.265,
          -1850.3370000000002,
          -1826.158,
          -1800.6779999999999,
          -1773.8470000000002,
          -1745.61,
          -1715.914,
          -1684.7,
          -1651.9089999999999,
          -1617.481,
          -1581.354,
          -1543.4620000000002,
          -1503.743,
          -1462.132,
          -1418.5629999999999,
          -1372.974,
          -1325.305,
          -1275.498,
          -1223.5,
          -1169.265,
          -1112.756,
          -1053.9460000000001,
          -992.822,
          -929.387,
          -863.6619999999999,
          -795.69,
          -725.539,
          -653.304,
          -579.1080000000001,
          -503.10400000000004,
          -425.474,
          -346.43,
          -266.211,
          -185.077,
          -103.303,
          -21.179000000000002,
          61.001999999999995,
          142.951,
          224.387,
          305.04400000000004,
          384.676,
          463.064,
          540.012,
          615.357,
          688.959,
          760.7080000000001,
          830.52,
          898.3330000000001,
          964.107,
          1027.8210000000001,
          1089.468,
          1149.057,
          1206.607,
          1262.145,
          1315.7079999999999,
          1367.336,
          1417.0739999999998,
          1464.973,
          1511.082,
          1555.453,
          1598.138,
          1639.192,
          1678.664,
          1716.608,
          1753.075,
          1788.1129999999998,
          1821.77,
          1854.094,
          1885.129,
          1914.92,
          1943.5079999999998,
          1970.934,
          1997.237,
          2022.455,
          2046.6229999999998,
          2069.777,
          2091.949,
          2113.1710000000003,
          2133.474,
          2152.888,
          2171.439,
          2189.155,
          2206.063,
          2222.186,
          2237.548,
          2252.174,
          2266.083,
          2279.298,
          2291.8379999999997,
          2303.722,
          2314.97,
          2325.599,
          2335.627,
          2345.07,
          2353.9429999999998,
          2362.263,
          2370.044,
          2377.3,
          2384.045,
          2390.291,
          2396.052,
          2401.34,
          2406.167,
          2410.544,
          2414.482,
          2417.992,
          2421.084,
          2423.768,
          2426.053,
          2427.949,
          2429.465,
          2430.609,
          2431.39,
          2431.8160000000003,
          2431.895,
          2431.635,
          2431.042,
          2430.125,
          2428.889,
          2427.343,
          2425.492,
          2423.342,
          2420.901,
          2418.174,
          2415.166,
          2411.884,
          2408.333,
          2404.518,
          2400.444,
          2396.117,
          2391.541,
          2386.722,
          2381.6639999999998,
          2376.371,
          2370.849,
          2365.1,
          2359.13,
          2352.9429999999998,
          2346.542,
          2339.9320000000002,
          2333.116,
          2326.099,
          2318.883,
          2311.472,
          2303.87,
          2296.08,
          2288.105,
          2279.95,
          2271.615,
          2263.106,
          2254.424,
          2245.573,
          2236.556,
          2227.375,
          2218.033,
          2208.534,
          2198.879,
          2189.071,
          2179.113,
          2169.007,
          2158.755,
          2148.361,
          2137.826,
          2127.153,
          2116.343,
          2105.4,
          2094.324,
          2083.119,
          2071.7870000000003,
          2060.3289999999997,
          2048.7470000000003,
          2037.0439999999999,
          2025.221,
          2013.28,
          2001.224,
          1989.0529999999999,
          1976.77,
          1964.3770000000002,
          1951.875,
          1939.265,
          1926.55,
          1913.7320000000002,
          1900.8110000000001,
          1887.79,
          1874.6689999999999,
          1861.4520000000002,
          1848.138,
          1834.73,
          1821.2279999999998,
          1807.636,
          1793.953,
          1780.181,
          1766.3220000000001,
          1752.3770000000002,
          1738.348,
          1724.235,
          1710.04,
          1695.764,
          1681.4089999999999,
          1666.975,
          1652.464,
          1637.878,
          1623.217,
          1608.483,
          1593.6760000000002,
          1578.7979999999998,
          1563.85,
          1548.8339999999998,
          1533.749,
          1518.598,
          1503.382,
          1488.1,
          1472.756,
          1457.349,
          1441.88,
          1426.351,
          1410.763,
          1395.116,
          1379.412,
          1363.651,
          1347.835,
          1331.965,
          1316.0410000000002,
          1300.0639999999999,
          1284.035,
          1267.9560000000001,
          1251.827,
          1235.6480000000001,
          1219.422,
          1203.1480000000001,
          1186.828,
          1170.462,
          1154.052,
          1137.597,
          1121.1,
          1104.5610000000001,
          1087.98,
          1071.359,
          1054.697,
          1037.997,
          1021.2589999999999,
          1004.4839999999999,
          987.672,
          970.824,
          953.942,
          937.025,
          920.074,
          903.091,
          886.076,
          869.03,
          851.953,
          834.847,
          817.712,
          800.548,
          783.357,
          766.1389999999999,
          748.8960000000001,
          731.6260000000001,
          714.3330000000001,
          697.015,
          679.674,
          662.311,
          644.9259999999999,
          627.52,
          610.0930000000001,
          592.6469999999999,
          575.181,
          557.698,
          540.197,
          522.679,
          505.144,
          487.594,
          470.029,
          452.45,
          434.858,
          417.25300000000004,
          399.635,
          382.006,
          364.36699999999996,
          346.717,
          329.05699999999996,
          311.389,
          293.71299999999997,
          276.03,
          258.339,
          240.643,
          222.94099999999997,
          205.235,
          187.524,
          169.81,
          152.094,
          134.375,
          116.655,
          98.935,
          81.214,
          63.494,
          45.776,
          28.06,
          10.345999999999998,
          -7.364,
          -25.07,
          -42.771,
          -60.466,
          -78.155,
          -95.837,
          -113.512,
          -131.178,
          -148.835,
          -166.482,
          -184.118,
          -201.74400000000003,
          -219.357,
          -236.958,
          -254.545,
          -272.117,
          -289.675,
          -307.218,
          -324.743,
          -342.25199999999995,
          -359.74300000000005,
          -377.214,
          -394.667,
          -412.099,
          -429.51,
          -446.899,
          -464.265,
          -481.608,
          -498.926,
          -516.22,
          -533.487,
          -550.7280000000001,
          -567.941,
          -585.125,
          -602.28,
          -619.405,
          -636.499,
          -653.561,
          -670.59,
          -687.586,
          -704.546,
          -721.471,
          -738.36,
          -755.211,
          -772.0239999999999,
          -788.797,
          -805.53,
          -822.221,
          -838.87,
          -855.4760000000001,
          -872.038,
          -888.554,
          -905.023,
          -921.445,
          -937.818,
          -954.1419999999999,
          -970.415,
          -986.6360000000001,
          -1002.803,
          -1018.9169999999999,
          -1034.975,
          -1050.976,
          -1066.92,
          -1082.805,
          -1098.629,
          -1114.392,
          -1130.0910000000001,
          -1145.7269999999999,
          -1161.297,
          -1176.8010000000002,
          -1192.236,
          -1207.6019999999999,
          -1222.896,
          -1238.118,
          -1253.267,
          -1268.339,
          -1283.335,
          -1298.253,
          -1313.09,
          -1327.846,
          -1342.5179999999998,
          -1357.106,
          -1371.6070000000002,
          -1386.02,
          -1400.342,
          -1414.5729999999999,
          -1428.71,
          -1442.751,
          -1456.695,
          -1470.539,
          -1484.2820000000002,
          -1497.922,
          -1511.4560000000001,
          -1524.882,
          -1538.1989999999998,
          -1551.404,
          -1564.495,
          -1577.469,
          -1590.3239999999998,
          -1603.059,
          -1615.6689999999999,
          -1628.154,
          -1640.509,
          -1652.733,
          -1664.8229999999999,
          -1676.777,
          -1688.59,
          -1700.261,
          -1711.787,
          -1723.164,
          -1734.389,
          -1745.46,
          -1756.372,
          -1767.1229999999998,
          -1777.7089999999998,
          -1788.126,
          -1798.372,
          -1808.441,
          -1818.3310000000001,
          -1828.037,
          -1837.556,
          -1846.8829999999998,
          -1856.014,
          -1864.944,
          -1873.67,
          -1882.185,
          -1890.486,
          -1898.568,
          -1906.4260000000002,
          -1914.0529999999999,
          -1921.4460000000001,
          -1928.5970000000002,
          -1935.5020000000002,
          -1942.155,
          -1948.549,
          -1954.6779999999999,
          -1960.535,
          -1966.114,
          -1971.408,
          -1976.41,
          -1981.111,
          -1985.505,
          -1989.5829999999999,
          -1993.3370000000002,
          -1996.759,
          -1999.84,
          -2002.57,
          -2004.9389999999999,
          -2006.9389999999999,
          -2008.557,
          -2009.785,
          -2010.61,
          -2011.0220000000002,
          -2011.007,
          -2010.555,
          -2009.651,
          -2008.2820000000002,
          -2006.434,
          -2004.0929999999998,
          -2001.244,
          -1997.87,
          -1993.954,
          -1989.479,
          -1984.4270000000001,
          -1978.78,
          -1972.5179999999998,
          -1965.619,
          -1958.0639999999999,
          -1949.828,
          -1940.888,
          -1931.219,
          -1920.796,
          -1909.592,
          -1897.579,
          -1884.727,
          -1871.003,
          -1856.3770000000002,
          -1840.8129999999999,
          -1824.277,
          -1806.7320000000002,
          -1788.136,
          -1768.4489999999998,
          -1747.63,
          -1725.6329999999998,
          -1702.411,
          -1677.914,
          -1652.094,
          -1624.8970000000002,
          -1596.267,
          -1566.148,
          -1534.4820000000002,
          -1501.211,
          -1466.27,
          -1429.6,
          -1391.138,
          -1350.82,
          -1308.588,
          -1264.379,
          -1218.138,
          -1169.8139999999999,
          -1119.359,
          -1066.736,
          -1011.915,
          -954.882,
          -895.633,
          -834.186,
          -770.578,
          -704.865,
          -637.136,
          -567.499,
          -496.095,
          -423.094,
          -348.689,
          -273.103,
          -196.579,
          -119.37700000000001,
          -41.766999999999996,
          35.973,
          113.569,
          190.753,
          267.27099999999996,
          342.889,
          417.39300000000003,
          490.597,
          562.3380000000001,
          632.482,
          700.921,
          767.568,
          832.3610000000001,
          895.26,
          956.237,
          1015.2860000000001,
          1072.41,
          1127.623,
          1180.951,
          1232.423,
          1282.077,
          1329.953,
          1376.096,
          1420.5520000000001,
          1463.369,
          1504.594,
          1544.277,
          1582.4679999999998,
          1619.2120000000002,
          1654.557,
          1688.55,
          1721.236,
          1752.6570000000002,
          1782.856,
          1811.876,
          1839.754,
          1866.529,
          1892.2379999999998,
          1916.915,
          1940.595,
          1963.31,
          1985.092,
          2005.971,
          2025.974,
          2045.131,
          2063.466,
          2081.008,
          2097.778,
          2113.8,
          2129.098,
          2143.692,
          2157.603,
          2170.8520000000003,
          2183.4570000000003,
          2195.436,
          2206.8070000000002,
          2217.5879999999997,
          2227.7929999999997,
          2237.44,
          2246.5429999999997,
          2255.116,
          2263.175,
          2270.731,
          2277.798,
          2284.388,
          2290.513,
          2296.186,
          2301.417,
          2306.217,
          2310.597,
          2314.5660000000003,
          2318.135,
          2321.313,
          2324.109,
          2326.531,
          2328.5879999999997,
          2330.2889999999998,
          2331.6420000000003,
          2332.653,
          2333.331,
          2333.6839999999997,
          2333.717,
          2333.438,
          2332.854,
          2331.971,
          2330.794,
          2329.331,
          2327.587,
          2325.5679999999998,
          2323.279,
          2320.726,
          2317.9139999999998,
          2314.848,
          2311.533,
          2307.974,
          2304.175,
          2300.141,
          2295.877,
          2291.387,
          2286.675,
          2281.745,
          2276.6020000000003,
          2271.248,
          2265.689,
          2259.927,
          2253.967,
          2247.811,
          2241.464,
          2234.929,
          2228.209,
          2221.3070000000002,
          2214.226,
          2206.97,
          2199.541,
          2191.9429999999998,
          2184.178,
          2176.249,
          2168.159,
          2159.91,
          2151.506,
          2142.948,
          2134.24,
          2125.383,
          2116.38,
          2107.234,
          2097.947,
          2088.521,
          2078.958,
          2069.26,
          2059.431,
          2049.471,
          2039.382,
          2029.168,
          2018.829,
          2008.368,
          1997.787,
          1987.0870000000002,
          1976.271,
          1965.34,
          1954.296,
          1943.14,
          1931.875,
          1920.5020000000002,
          1909.023,
          1897.4379999999999,
          1885.751,
          1873.963,
          1862.0739999999998,
          1850.0870000000002,
          1838.003,
          1825.8239999999998,
          1813.5510000000002,
          1801.185,
          1788.7279999999998,
          1776.181,
          1763.545,
          1750.8229999999999,
          1738.014,
          1725.121,
          1712.145,
          1699.0870000000002,
          1685.9479999999999,
          1672.73,
          1659.433,
          1646.059,
          1632.609,
          1619.0839999999998,
          1605.486,
          1591.815,
          1578.0729999999999,
          1564.26,
          1550.378,
          1536.4279999999999,
          1522.411,
          1508.3270000000002,
          1494.1789999999999,
          1479.9660000000001,
          1465.691,
          1451.3529999999998,
          1436.954,
          1422.496,
          1407.9779999999998,
          1393.401,
          1378.7679999999998,
          1364.078,
          1349.3329999999999,
          1334.533,
          1319.68,
          1304.7730000000001,
          1289.815,
          1274.806,
          1259.747,
          1244.638,
          1229.481,
          1214.276,
          1199.025,
          1183.7269999999999,
          1168.384,
          1152.997,
          1137.567,
          1122.093,
          1106.578,
          1091.021,
          1075.424,
          1059.787,
          1044.111,
          1028.397,
          1012.645,
          996.857,
          981.033,
          965.174,
          949.28,
          933.352,
          917.3910000000001,
          901.398,
          885.373,
          869.317,
          853.2310000000001,
          837.1160000000001,
          820.971,
          804.799,
          788.5980000000001,
          772.3710000000001,
          756.118,
          739.84,
          723.5360000000001,
          707.209,
          690.857,
          674.4839999999999,
          658.0880000000001,
          641.67,
          625.232,
          608.773,
          592.295,
          575.798,
          559.283,
          542.75,
          526.2,
          509.634,
          493.05300000000005,
          476.45599999999996,
          459.845,
          443.22,
          426.582,
          409.931,
          393.269,
          376.595,
          359.911,
          343.217,
          326.514,
          309.802,
          293.082,
          276.355,
          259.62,
          242.88,
          226.13400000000001,
          209.38400000000001,
          192.62900000000002,
          175.87099999999998,
          159.109,
          142.346,
          125.58,
          108.814,
          92.04799999999999,
          75.281,
          58.516000000000005,
          41.751999999999995,
          24.991,
          8.232000000000001,
          -8.523,
          -25.273000000000003,
          -42.019,
          -58.76,
          -75.494,
          -92.221,
          -108.94,
          -125.652,
          -142.35399999999998,
          -159.047,
          -175.729,
          -192.4,
          -209.06,
          -225.707,
          -242.34099999999998,
          -258.961,
          -275.567,
          -292.157,
          -308.731,
          -325.289,
          -341.829,
          -358.35,
          -374.853,
          -391.336,
          -407.79900000000004,
          -424.24,
          -440.659,
          -457.055,
          -473.42800000000005,
          -489.776,
          -506.099,
          -522.396,
          -538.665,
          -554.908,
          -571.121,
          -587.306,
          -603.46,
          -619.582,
          -635.673,
          -651.731,
          -667.755,
          -683.745,
          -699.698,
          -715.6160000000001,
          -731.495,
          -747.337,
          -763.1389999999999,
          -778.9,
          -794.62,
          -810.298,
          -825.932,
          -841.5219999999999,
          -857.066,
          -872.564,
          -888.0139999999999,
          -903.416,
          -918.768,
          -934.068,
          -949.317,
          -964.513,
          -979.654,
          -994.7389999999999,
          -1009.768,
          -1024.738,
          -1039.649,
          -1054.5,
          -1069.289,
          -1084.015,
          -1098.6760000000002,
          -1113.271,
          -1127.799,
          -1142.258,
          -1156.647,
          -1170.965,
          -1185.2089999999998,
          -1199.379,
          -1213.473,
          -1227.489,
          -1241.4260000000002,
          -1255.282,
          -1269.055,
          -1282.744,
          -1296.347,
          -1309.862,
          -1323.2879999999998,
          -1336.622,
          -1349.8629999999998,
          -1363.009,
          -1376.057,
          -1389.007,
          -1401.855,
          -1414.6,
          -1427.239,
          -1439.771,
          -1452.193,
          -1464.503,
          -1476.6979999999999,
          -1488.776,
          -1500.735,
          -1512.5720000000001,
          -1524.285,
          -1535.871,
          -1547.3270000000002,
          -1558.651,
          -1569.839,
          -1580.889,
          -1591.799,
          -1602.5629999999999,
          -1613.181,
          -1623.648,
          -1633.961,
          -1644.1170000000002,
          -1654.112,
          -1663.943,
          -1673.6070000000002,
          -1683.098,
          -1692.414,
          -1701.55,
          -1710.503,
          -1719.267,
          -1727.84,
          -1736.2160000000001,
          -1744.39,
          -1752.359,
          -1760.116,
          -1767.658,
          -1774.9779999999998,
          -1782.0710000000001,
          -1788.932,
          -1795.555,
          -1801.935,
          -1808.0639999999999,
          -1813.9370000000001,
          -1819.5479999999998,
          -1824.889,
          -1829.953,
          -1834.734,
          -1839.223,
          -1843.4129999999998,
          -1847.297,
          -1850.865,
          -1854.109,
          -1857.02,
          -1859.589,
          -1861.806,
          -1863.661,
          -1865.144,
          -1866.243,
          -1866.9479999999999,
          -1867.247,
          -1867.128,
          -1866.578,
          -1865.5839999999998,
          -1864.132,
          -1862.207,
          -1859.796,
          -1856.882,
          -1853.4489999999998,
          -1849.48,
          -1844.9560000000001,
          -1839.861,
          -1834.1729999999998,
          -1827.874,
          -1820.941,
          -1813.3529999999998,
          -1805.086,
          -1796.116,
          -1786.4170000000001,
          -1775.963,
          -1764.726,
          -1752.6760000000002,
          -1739.7839999999999,
          -1726.014,
          -1711.336,
          -1695.713,
          -1679.108,
          -1661.483,
          -1642.796,
          -1623.006,
          -1602.067,
          -1579.934,
          -1556.558,
          -1531.889,
          -1505.874,
          -1478.461,
          -1449.592,
          -1419.211,
          -1387.26,
          -1353.6779999999999,
          -1318.405,
          -1281.382,
          -1242.548,
          -1201.846,
          -1159.221,
          -1114.62,
          -1067.998,
          -1019.314,
          -968.54,
          -915.6560000000001,
          -860.6560000000001,
          -803.553,
          -744.3739999999999,
          -683.17,
          -620.018,
          -555.016,
          -488.291,
          -419.99800000000005,
          -350.315,
          -279.447,
          -207.62099999999998,
          -135.078,
          -62.073,
          11.135,
          84.285,
          157.125,
          229.41299999999998,
          300.92400000000004,
          371.454,
          440.82300000000004,
          508.875,
          575.475,
          640.518,
          703.919,
          765.6139999999999,
          825.559,
          883.727,
          940.1060000000001,
          994.695,
          1047.507,
          1098.56,
          1147.881,
          1195.502,
          1241.4589999999998,
          1285.792,
          1328.5439999999999,
          1369.757,
          1409.475,
          1447.744,
          1484.608,
          1520.111,
          1554.296,
          1587.207,
          1618.885,
          1649.362,
          1678.7020000000002,
          1706.918,
          1734.058,
          1760.154,
          1785.241,
          1809.3529999999998,
          1832.52,
          1854.775,
          1876.146,
          1896.66,
          1916.344,
          1935.226,
          1953.329,
          1970.6779999999999,
          1987.295,
          2003.203,
          2018.421,
          2032.9720000000002,
          2046.8729999999998,
          2060.145,
          2072.804,
          2084.869,
          2096.355,
          2107.278,
          2117.654,
          2127.498,
          2136.824,
          2145.645,
          2153.976,
          2161.827,
          2169.2129999999997,
          2176.144,
          2182.631,
          2188.686,
          2194.32,
          2199.542,
          2204.362,
          2208.791,
          2212.837,
          2216.509,
          2219.815,
          2222.765,
          2225.367,
          2227.626,
          2229.553,
          2231.153,
          2232.4339999999997,
          2233.403,
          2234.0660000000003,
          2234.43,
          2234.501,
          2234.286,
          2233.79,
          2233.019,
          2231.978,
          2230.673,
          2229.11,
          2227.292,
          2225.226,
          2222.916,
          2220.367,
          2217.584,
          2214.57,
          2211.33,
          2207.869,
          2204.19,
          2200.298,
          2196.196,
          2191.888,
          2187.3779999999997,
          2182.67,
          2177.7670000000003,
          2172.672,
          2167.39,
          2161.922,
          2156.2729999999997,
          2150.446,
          2144.4429999999998,
          2138.268,
          2131.923,
          2125.4120000000003,
          2118.736,
          2111.9,
          2104.905,
          2097.755,
          2090.451,
          2082.996,
          2075.393,
          2067.644,
          2059.752,
          2051.718,
          2043.546,
          2035.236,
          2026.7920000000001,
          2018.215,
          2009.507,
          2000.671,
          1991.7089999999998,
          1982.622,
          1973.4129999999998,
          1964.0829999999999,
          1954.634,
          1945.068,
          1935.386,
          1925.5910000000001,
          1915.685,
          1905.668,
          1895.543,
          1885.3110000000001,
          1874.974,
          1864.533,
          1853.99,
          1843.346,
          1832.604,
          1821.763,
          1810.8270000000002,
          1799.795,
          1788.671,
          1777.454,
          1766.1470000000002,
          1754.75,
          1743.265,
          1731.694,
          1720.037,
          1708.296,
          1696.4720000000002,
          1684.566,
          1672.58,
          1660.514,
          1648.37,
          1636.149,
          1623.852,
          1611.48,
          1599.0339999999999,
          1586.516,
          1573.9260000000002,
          1561.266,
          1548.536,
          1535.7379999999998,
          1522.872,
          1509.94,
          1496.942,
          1483.88,
          1470.754,
          1457.565,
          1444.315,
          1431.005,
          1417.634,
          1404.204,
          1390.717,
          1377.172,
          1363.5720000000001,
          1349.915,
          1336.205,
          1322.44,
          1308.623,
          1294.754,
          1280.833,
          1266.863,
          1252.8419999999999,
          1238.7730000000001,
          1224.656,
          1210.492,
          1196.281,
          1182.025,
          1167.724,
          1153.379,
          1138.99,
          1124.559,
          1110.085,
          1095.5710000000001,
          1081.016,
          1066.421,
          1051.788,
          1037.116,
          1022.4060000000001,
          1007.659,
          992.8760000000001,
          978.058,
          963.205,
          948.317,
          933.3960000000001,
          918.442,
          903.456,
          888.438,
          873.39,
          858.311,
          843.203,
          828.065,
          812.9,
          797.706,
          782.4860000000001,
          767.2389999999999,
          751.966,
          736.669,
          721.346,
          706,
          690.6310000000001,
          675.238,
          659.824,
          644.388,
          628.932,
          613.455,
          597.9580000000001,
          582.443,
          566.909,
          551.357,
          535.788,
          520.203,
          504.601,
          488.98400000000004,
          473.352,
          457.70599999999996,
          442.046,
          426.37300000000005,
          410.68800000000005,
          394.991,
          379.282,
          363.56300000000005,
          347.834,
          332.095,
          316.348,
          300.592,
          284.828,
          269.057,
          253.28,
          237.497,
          221.709,
          205.915,
          190.118,
          174.317,
          158.514,
          142.708,
          126.9,
          111.09100000000001,
          95.28200000000001,
          79.473,
          63.665,
          47.858000000000004,
          32.053000000000004,
          16.25,
          0.451,
          -15.344000000000001,
          -31.135,
          -46.92,
          -62.7,
          -78.473,
          -94.24,
          -109.99799999999999,
          -125.74799999999999,
          -141.49,
          -157.221,
          -172.942,
          -188.65200000000002,
          -204.351,
          -220.037,
          -235.71,
          -251.36900000000003,
          -267.013,
          -282.643,
          -298.257,
          -313.85400000000004,
          -329.43300000000005,
          -344.995,
          -360.538,
          -376.06199999999995,
          -391.565,
          -407.04699999999997,
          -422.50800000000004,
          -437.94599999999997,
          -453.36,
          -468.751,
          -484.116,
          -499.45599999999996,
          -514.77,
          -530.056,
          -545.314,
          -560.543,
          -575.742,
          -590.911,
          -606.048,
          -621.1519999999999,
          -636.2230000000001,
          -651.26,
          -666.262,
          -681.2280000000001,
          -696.1560000000001,
          -711.047,
          -725.8989999999999,
          -740.711,
          -755.482,
          -770.211,
          -784.8969999999999,
          -799.539,
          -814.1360000000001,
          -828.687,
          -843.191,
          -857.6469999999999,
          -872.053,
          -886.409,
          -900.7130000000001,
          -914.9639999999999,
          -929.1610000000001,
          -943.303,
          -957.388,
          -971.415,
          -985.3839999999999,
          -999.2919999999999,
          -1013.1389999999999,
          -1026.922,
          -1040.641,
          -1054.295,
          -1067.881,
          -1081.3980000000001,
          -1094.846,
          -1108.222,
          -1121.524,
          -1134.752,
          -1147.903,
          -1160.9769999999999,
          -1173.971,
          -1186.883,
          -1199.713,
          -1212.458,
          -1225.116,
          -1237.685,
          -1250.165,
          -1262.5510000000002,
          -1274.844,
          -1287.04,
          -1299.138,
          -1311.136,
          -1323.031,
          -1334.8210000000001,
          -1346.504,
          -1358.078,
          -1369.54,
          -1380.888,
          -1392.119,
          -1403.231,
          -1414.221,
          -1425.0870000000002,
          -1435.825,
          -1446.433,
          -1456.908,
          -1467.247,
          -1477.4479999999999,
          -1487.506,
          -1497.418,
          -1507.182,
          -1516.795,
          -1526.251,
          -1535.5479999999998,
          -1544.683,
          -1553.651,
          -1562.4479999999999,
          -1571.0710000000001,
          -1579.515,
          -1587.776,
          -1595.85,
          -1603.7320000000002,
          -1611.4170000000001,
          -1618.9,
          -1626.1779999999999,
          -1633.243,
          -1640.092,
          -1646.7179999999998,
          -1653.1170000000002,
          -1659.281,
          -1665.205,
          -1670.8829999999998,
          -1676.308,
          -1681.473,
          -1686.372,
          -1690.9979999999998,
          -1695.342,
          -1699.3970000000002,
          -1703.155,
          -1706.608,
          -1709.747,
          -1712.5639999999999,
          -1715.0479999999998,
          -1717.19,
          -1718.98,
          -1720.408,
          -1721.4620000000002,
          -1722.132,
          -1722.405,
          -1722.269,
          -1721.711,
          -1720.7179999999998,
          -1719.276,
          -1717.371,
          -1714.987,
          -1712.1070000000002,
          -1708.7160000000001,
          -1704.797,
          -1700.33,
          -1695.2979999999998,
          -1689.68,
          -1683.4560000000001,
          -1676.6029999999998,
          -1669.099,
          -1660.92,
          -1652.04,
          -1642.434,
          -1632.0739999999998,
          -1620.932,
          -1608.976,
          -1596.175,
          -1582.495,
          -1567.902,
          -1552.36,
          -1535.83,
          -1518.27,
          -1499.641,
          -1479.8970000000002,
          -1458.994,
          -1436.882,
          -1413.514,
          -1388.8370000000002,
          -1362.799,
          -1335.344,
          -1306.4180000000001,
          -1275.962,
          -1243.9180000000001,
          -1210.23,
          -1174.839,
          -1137.688,
          -1098.725,
          -1057.897,
          -1015.158,
          -970.4689999999999,
          -923.797,
          -875.1210000000001,
          -824.431,
          -771.7339999999999,
          -717.051,
          -660.425,
          -601.922,
          -541.628,
          -479.66,
          -416.154,
          -351.275,
          -285.21,
          -218.169,
          -150.374,
          -82.06299999999999,
          -13.479000000000001,
          55.13399999999999,
          123.537,
          191.502,
          258.815,
          325.281,
          390.725,
          454.99699999999996,
          517.967,
          579.531,
          639.602,
          698.1189999999999,
          755.034,
          810.317,
          863.954,
          915.939,
          966.2810000000001,
          1014.9960000000001,
          1062.103,
          1107.631,
          1151.613,
          1194.0819999999999,
          1235.076,
          1274.635,
          1312.799,
          1349.6070000000002,
          1385.1,
          1419.3210000000001,
          1452.306,
          1484.096,
          1514.73,
          1544.244,
          1572.675,
          1600.058,
          1626.4279999999999,
          1651.817,
          1676.255,
          1699.776,
          1722.406,
          1744.1760000000002,
          1765.1129999999998,
          1785.2420000000002,
          1804.588,
          1823.1760000000002,
          1841.0279999999998,
          1858.168,
          1874.616,
          1890.394,
          1905.52,
          1920.013,
          1933.892,
          1947.175,
          1959.878,
          1972.017,
          1983.608,
          1994.6660000000002,
          2005.205,
          2015.239,
          2024.781,
          2033.845,
          2042.441,
          2050.584,
          2058.283,
          2065.55,
          2072.397,
          2078.8320000000003,
          2084.866,
          2090.508,
          2095.769,
          2100.656,
          2105.178,
          2109.345,
          2113.163,
          2116.641,
          2119.7870000000003,
          2122.607,
          2125.11,
          2127.301,
          2129.188,
          2130.777,
          2132.074,
          2133.085,
          2133.817,
          2134.274,
          2134.4629999999997,
          2134.389,
          2134.0570000000002,
          2133.473,
          2132.641,
          2131.5660000000003,
          2130.2529999999997,
          2128.706,
          2126.93,
          2124.93,
          2122.708,
          2120.271,
          2117.62,
          2114.761,
          2111.697,
          2108.4320000000002,
          2104.969,
          2101.312,
          2097.465,
          2093.43,
          2089.212,
          2084.812,
          2080.235,
          2075.4829999999997,
          2070.5589999999997,
          2065.466,
          2060.208,
          2054.786,
          2049.203,
          2043.463,
          2037.567,
          2031.519,
          2025.32,
          2018.973,
          2012.481,
          2005.845,
          1999.069,
          1992.154,
          1985.102,
          1977.9160000000002,
          1970.5970000000002,
          1963.148,
          1955.57,
          1947.8670000000002,
          1940.039,
          1932.088,
          1924.016,
          1915.826,
          1907.519,
          1899.096,
          1890.56,
          1881.912,
          1873.154,
          1864.287,
          1855.3120000000001,
          1846.233,
          1837.049,
          1827.763,
          1818.376,
          1808.89,
          1799.306,
          1789.624,
          1779.848,
          1769.9779999999998,
          1760.015,
          1749.961,
          1739.817,
          1729.585,
          1719.265,
          1708.859,
          1698.368,
          1687.7939999999999,
          1677.1370000000002,
          1666.398,
          1655.58,
          1644.682,
          1633.7060000000001,
          1622.654,
          1611.526,
          1600.3229999999999,
          1589.046,
          1577.6970000000001,
          1566.276,
          1554.7839999999999,
          1543.223,
          1531.594,
          1519.896,
          1508.132,
          1496.3029999999999,
          1484.408,
          1472.45,
          1460.4289999999999,
          1448.345,
          1436.201,
          1423.996,
          1411.731,
          1399.408,
          1387.0279999999998,
          1374.59,
          1362.096,
          1349.5479999999998,
          1336.944,
          1324.287,
          1311.5770000000002,
          1298.815,
          1286.002,
          1273.139,
          1260.225,
          1247.263,
          1234.252,
          1221.193,
          1208.088,
          1194.937,
          1181.741,
          1168.499,
          1155.214,
          1141.886,
          1128.515,
          1115.1019999999999,
          1101.6480000000001,
          1088.153,
          1074.619,
          1061.045,
          1047.433,
          1033.7830000000001,
          1020.095,
          1006.3710000000001,
          992.6110000000001,
          978.816,
          964.9860000000001,
          951.122,
          937.225,
          923.295,
          909.332,
          895.3380000000001,
          881.313,
          867.258,
          853.172,
          839.058,
          824.915,
          810.7439999999999,
          796.545,
          782.32,
          768.069,
          753.791,
          739.4889999999999,
          725.1619999999999,
          710.811,
          696.437,
          682.04,
          667.6210000000001,
          653.18,
          638.7180000000001,
          624.235,
          609.732,
          595.21,
          580.669,
          566.11,
          551.533,
          536.939,
          522.328,
          507.70099999999996,
          493.059,
          478.401,
          463.72900000000004,
          449.043,
          434.344,
          419.63199999999995,
          404.908,
          390.17199999999997,
          375.425,
          360.668,
          345.9,
          331.12300000000005,
          316.337,
          301.54200000000003,
          286.74,
          271.931,
          257.115,
          242.292,
          227.465,
          212.632,
          197.795,
          182.953,
          168.109,
          153.262,
          138.412,
          123.561,
          108.709,
          93.85700000000001,
          79.00399999999999,
          64.153,
          49.302,
          34.454,
          19.608,
          4.765,
          -10.074,
          -24.909000000000002,
          -39.739000000000004,
          -54.56399999999999,
          -69.382,
          -84.194,
          -98.99799999999999,
          -113.795,
          -128.582,
          -143.361,
          -158.13,
          -172.888,
          -187.635,
          -202.37,
          -217.093,
          -231.80200000000002,
          -246.498,
          -261.17900000000003,
          -275.845,
          -290.495,
          -305.129,
          -319.745,
          -334.344,
          -348.923,
          -363.483,
          -378.023,
          -392.542,
          -407.04,
          -421.514,
          -435.966,
          -450.394,
          -464.79699999999997,
          -479.17400000000004,
          -493.525,
          -507.849,
          -522.145,
          -536.4119999999999,
          -550.649,
          -564.856,
          -579.031,
          -593.175,
          -607.284,
          -621.36,
          -635.401,
          -649.405,
          -663.373,
          -677.303,
          -691.194,
          -705.045,
          -718.8560000000001,
          -732.6239999999999,
          -746.35,
          -760.0310000000001,
          -773.668,
          -787.258,
          -800.801,
          -814.296,
          -827.7410000000001,
          -841.1360000000001,
          -854.4789999999999,
          -867.768,
          -881.003,
          -894.183,
          -907.306,
          -920.37,
          -933.3760000000001,
          -946.32,
          -959.202,
          -972.02,
          -984.7739999999999,
          -997.46,
          -1010.079,
          -1022.628,
          -1035.107,
          -1047.512,
          -1059.843,
          -1072.098,
          -1084.276,
          -1096.374,
          -1108.391,
          -1120.325,
          -1132.175,
          -1143.937,
          -1155.611,
          -1167.195,
          -1178.6860000000001,
          -1190.0819999999999,
          -1201.381,
          -1212.5819999999999,
          -1223.681,
          -1234.677,
          -1245.567,
          -1256.349,
          -1267.019,
          -1277.577,
          -1288.019,
          -1298.343,
          -1308.545,
          -1318.624,
          -1328.575,
          -1338.3970000000002,
          -1348.086,
          -1357.639,
          -1367.0529999999999,
          -1376.3239999999998,
          -1385.45,
          -1394.4260000000002,
          -1403.249,
          -1411.9160000000002,
          -1420.422,
          -1428.763,
          -1436.9370000000001,
          -1444.9370000000001,
          -1452.761,
          -1460.4029999999998,
          -1467.859,
          -1475.124,
          -1482.194,
          -1489.0629999999999,
          -1495.727,
          -1502.1789999999999,
          -1508.4129999999998,
          -1514.425,
          -1520.2089999999998,
          -1525.757,
          -1531.0639999999999,
          -1536.1229999999998,
          -1540.9270000000001,
          -1545.469,
          -1549.741,
          -1553.736,
          -1557.4460000000001,
          -1560.8629999999998,
          -1563.977,
          -1566.78,
          -1569.263,
          -1571.4160000000002,
          -1573.2279999999998,
          -1574.69,
          -1575.79,
          -1576.516,
          -1576.858,
          -1576.8020000000001,
          -1576.335,
          -1575.445,
          -1574.116,
          -1572.335,
          -1570.085,
          -1567.351,
          -1564.115,
          -1560.36,
          -1556.067,
          -1551.2179999999998,
          -1545.7910000000002,
          -1539.766,
          -1533.12,
          -1525.83,
          -1517.87,
          -1509.2160000000001,
          -1499.8410000000001,
          -1489.715,
          -1478.81,
          -1467.094,
          -1454.5339999999999,
          -1441.096,
          -1426.743,
          -1411.4389999999999,
          -1395.144,
          -1377.815,
          -1359.411,
          -1339.886,
          -1319.194,
          -1297.285,
          -1274.109,
          -1249.614,
          -1223.748,
          -1196.455,
          -1167.68,
          -1137.367,
          -1105.461,
          -1071.906,
          -1036.651,
          -999.643,
          -960.8389999999999,
          -920.196,
          -877.681,
          -833.2710000000001,
          -786.95,
          -738.721,
          -688.5989999999999,
          -636.619,
          -582.835,
          -527.3240000000001,
          -470.18699999999995,
          -411.548,
          -351.55400000000003,
          -290.376,
          -228.205,
          -165.24599999999998,
          -101.719,
          -37.85,
          26.134,
          90.009,
          153.559,
          216.582,
          278.892,
          340.32300000000004,
          400.727,
          459.98,
          517.98,
          574.64,
          629.8969999999999,
          683.704,
          736.028,
          786.8489999999999,
          836.1610000000001,
          883.967,
          930.2769999999999,
          975.1080000000001,
          1018.485,
          1060.432,
          1100.982,
          1140.1680000000001,
          1178.0230000000001,
          1214.583,
          1249.884,
          1283.965,
          1316.859,
          1348.604,
          1379.236,
          1408.789,
          1437.297,
          1464.7939999999999,
          1491.3110000000001,
          1516.882,
          1541.533,
          1565.296,
          1588.1989999999998,
          1610.2679999999998,
          1631.53,
          1652.011,
          1671.7320000000002,
          1690.72,
          1708.994,
          1726.578,
          1743.4920000000002,
          1759.756,
          1775.3870000000002,
          1790.406,
          1804.829,
          1818.6729999999998,
          1831.955,
          1844.691,
          1856.895,
          1868.5810000000001,
          1879.765,
          1890.4579999999999,
          1900.674,
          1910.4260000000002,
          1919.725,
          1928.5829999999999,
          1937.011,
          1945.02,
          1952.62,
          1959.8210000000001,
          1966.6329999999998,
          1973.065,
          1979.126,
          1984.825,
          1990.1689999999999,
          1995.168,
          1999.829,
          2004.16,
          2008.1670000000001,
          2011.859,
          2015.2420000000002,
          2018.3220000000001,
          2021.106,
          2023.601,
          2025.8129999999999,
          2027.747,
          2029.4089999999999,
          2030.805,
          2031.9389999999999,
          2032.818,
          2033.4460000000001,
          2033.829,
          2033.97,
          2033.876,
          2033.549,
          2032.995,
          2032.219,
          2031.223,
          2030.013,
          2028.5910000000001,
          2026.963,
          2025.132,
          2023.101,
          2020.874,
          2018.455,
          2015.846,
          2013.0510000000002,
          2010.0739999999998,
          2006.9170000000001,
          2003.5839999999998,
          2000.0770000000002,
          1996.4,
          1992.556,
          1988.546,
          1984.374,
          1980.043,
          1975.555,
          1970.9129999999998,
          1966.119,
          1961.175,
          1956.085,
          1950.849,
          1945.4720000000002,
          1939.954,
          1934.2979999999998,
          1928.506,
          1922.5810000000001,
          1916.524,
          1910.3370000000002,
          1904.0220000000002,
          1897.582,
          1891.0179999999998,
          1884.3310000000001,
          1877.525,
          1870.599,
          1863.558,
          1856.401,
          1849.13,
          1841.7479999999998,
          1834.256,
          1826.656,
          1818.9479999999999,
          1811.135,
          1803.219,
          1795.1989999999998,
          1787.079,
          1778.86,
          1770.5420000000001,
          1762.1270000000002,
          1753.6170000000002,
          1745.013,
          1736.317,
          1727.5279999999998,
          1718.65,
          1709.683,
          1700.628,
          1691.486,
          1682.259,
          1672.9479999999999,
          1663.5539999999999,
          1654.078,
          1644.521,
          1634.885,
          1625.17,
          1615.3770000000002,
          1605.509,
          1595.5639999999999,
          1585.545,
          1575.453,
          1565.289,
          1555.0529999999999,
          1544.746,
          1534.37,
          1523.9260000000002,
          1513.4129999999998,
          1502.8339999999998,
          1492.19,
          1481.48,
          1470.7060000000001,
          1459.869,
          1448.97,
          1438.009,
          1426.9879999999998,
          1415.906,
          1404.766,
          1393.567,
          1382.3110000000001,
          1370.999,
          1359.63,
          1348.207,
          1336.729,
          1325.1970000000001,
          1313.6129999999998,
          1301.9769999999999,
          1290.289,
          1278.55,
          1266.762,
          1254.924,
          1243.038,
          1231.104,
          1219.123,
          1207.095,
          1195.022,
          1182.903,
          1170.74,
          1158.5330000000001,
          1146.2830000000001,
          1133.99,
          1121.655,
          1109.279,
          1096.863,
          1084.406,
          1071.91,
          1059.375,
          1046.802,
          1034.191,
          1021.544,
          1008.8589999999999,
          996.14,
          983.3839999999999,
          970.5939999999999,
          957.7710000000001,
          944.913,
          932.023,
          919.1,
          906.145,
          893.159,
          880.143,
          867.096,
          854.02,
          840.914,
          827.78,
          814.618,
          801.429,
          788.2130000000001,
          774.97,
          761.702,
          748.408,
          735.09,
          721.747,
          708.38,
          694.9910000000001,
          681.578,
          668.1439999999999,
          654.688,
          641.21,
          627.7130000000001,
          614.195,
          600.6569999999999,
          587.1,
          573.525,
          559.932,
          546.321,
          532.693,
          519.049,
          505.389,
          491.713,
          478.022,
          464.31699999999995,
          450.597,
          436.865,
          423.119,
          409.361,
          395.591,
          381.809,
          368.017,
          354.214,
          340.401,
          326.579,
          312.748,
          298.909,
          285.062,
          271.207,
          257.346,
          243.47799999999998,
          229.605,
          215.726,
          201.843,
          187.956,
          174.065,
          160.17,
          146.274,
          132.375,
          118.475,
          104.573,
          90.67200000000001,
          76.77,
          62.87,
          48.97,
          35.071999999999996,
          21.177,
          7.285,
          -6.604,
          -20.489,
          -34.369,
          -48.244,
          -62.113,
          -75.976,
          -89.831,
          -103.679,
          -117.51899999999999,
          -131.35,
          -145.171,
          -158.982,
          -172.783,
          -186.572,
          -200.35,
          -214.114,
          -227.86599999999999,
          -241.60299999999998,
          -255.326,
          -269.033,
          -282.725,
          -296.4,
          -310.057,
          -323.697,
          -337.31699999999995,
          -350.91900000000004,
          -364.5,
          -378.06,
          -391.598,
          -405.11400000000003,
          -418.606,
          -432.075,
          -445.51800000000003,
          -458.93699999999995,
          -472.32800000000003,
          -485.69300000000004,
          -499.029,
          -512.336,
          -525.614,
          -538.861,
          -552.077,
          -565.26,
          -578.409,
          -591.525,
          -604.605,
          -617.649,
          -630.656,
          -643.624,
          -656.554,
          -669.443,
          -682.291,
          -695.097,
          -707.86,
          -720.578,
          -733.2510000000001,
          -745.877,
          -758.455,
          -770.9839999999999,
          -783.462,
          -795.89,
          -808.2639999999999,
          -820.585,
          -832.8510000000001,
          -845.059,
          -857.21,
          -869.302,
          -881.332,
          -893.301,
          -905.206,
          -917.046,
          -928.819,
          -940.5239999999999,
          -952.159,
          -963.7230000000001,
          -975.2130000000001,
          -986.6289999999999,
          -997.9680000000001,
          -1009.2280000000001,
          -1020.408,
          -1031.506,
          -1042.521,
          -1053.4489999999998,
          -1064.289,
          -1075.038,
          -1085.6960000000001,
          -1096.259,
          -1106.726,
          -1117.093,
          -1127.359,
          -1137.522,
          -1147.578,
          -1157.526,
          -1167.362,
          -1177.0839999999998,
          -1186.69,
          -1196.175,
          -1205.539,
          -1214.776,
          -1223.885,
          -1232.862,
          -1241.704,
          -1250.4080000000001,
          -1258.969,
          -1267.385,
          -1275.651,
          -1283.765,
          -1291.721,
          -1299.516,
          -1307.146,
          -1314.6070000000002,
          -1321.8929999999998,
          -1329.001,
          -1335.925,
          -1342.66,
          -1349.2020000000002,
          -1355.546,
          -1361.684,
          -1367.6129999999998,
          -1373.326,
          -1378.816,
          -1384.079,
          -1389.106,
          -1393.892,
          -1398.4289999999999,
          -1402.71,
          -1406.727,
          -1410.4720000000002,
          -1413.9379999999999,
          -1417.115,
          -1419.994,
          -1422.567,
          -1424.8239999999998,
          -1426.754,
          -1428.3470000000002,
          -1429.5929999999998,
          -1430.4779999999998,
          -1430.9920000000002,
          -1431.1229999999998,
          -1430.8570000000002,
          -1430.18,
          -1429.078,
          -1427.537,
          -1425.5410000000002,
          -1423.0729999999999,
          -1420.116,
          -1416.652,
          -1412.6629999999998,
          -1408.129,
          -1403.0279999999998,
          -1397.34,
          -1391.0420000000001,
          -1384.11,
          -1376.517,
          -1368.239,
          -1359.247,
          -1349.5120000000002,
          -1339.004,
          -1327.691,
          -1315.539,
          -1302.512,
          -1288.5739999999998,
          -1273.687,
          -1257.808,
          -1240.896,
          -1222.907,
          -1203.796,
          -1183.514,
          -1162.012,
          -1139.24,
          -1115.145,
          -1089.6760000000002,
          -1062.777,
          -1034.396,
          -1004.48,
          -972.9760000000001,
          -939.837,
          -905.015,
          -868.4689999999999,
          -830.164,
          -790.074,
          -748.182,
          -704.4810000000001,
          -658.9839999999999,
          -611.715,
          -562.72,
          -512.063,
          -459.832,
          -406.13599999999997,
          -351.108,
          -294.899,
          -237.683,
          -179.64700000000002,
          -120.993,
          -61.928000000000004,
          -2.6639999999999997,
          56.591,
          115.634,
          174.275,
          232.338,
          289.664,
          346.11199999999997,
          401.561,
          455.911,
          509.077,
          560.995,
          611.615,
          660.9019999999999,
          708.835,
          755.403,
          800.6039999999999,
          844.444,
          886.936,
          928.1,
          967.956,
          1006.5310000000001,
          1043.853,
          1079.953,
          1114.86,
          1148.608,
          1181.23,
          1212.756,
          1243.22,
          1272.653,
          1301.088,
          1328.54,
          1355.0829999999999,
          1380.7020000000002,
          1405.442,
          1429.3270000000002,
          1452.386,
          1474.644,
          1496.126,
          1516.856,
          1536.8570000000002,
          1556.15,
          1574.7579999999998,
          1592.7,
          1609.996,
          1626.6660000000002,
          1642.727,
          1658.1970000000001,
          1673.094,
          1687.433,
          1701.229,
          1714.4979999999998,
          1727.254,
          1739.5120000000002,
          1751.2839999999999,
          1762.5829999999999,
          1773.422,
          1783.8129999999999,
          1793.766,
          1803.2939999999999,
          1812.4070000000002,
          1821.115,
          1829.4279999999999,
          1837.3570000000002,
          1844.9089999999999,
          1852.094,
          1858.921,
          1865.398,
          1871.533,
          1877.3339999999998,
          1882.808,
          1887.963,
          1892.805,
          1897.342,
          1901.5810000000001,
          1905.527,
          1909.1860000000001,
          1912.566,
          1915.672,
          1918.5079999999998,
          1921.082,
          1923.398,
          1925.4620000000002,
          1927.277,
          1928.851,
          1930.1860000000001,
          1931.287,
          1932.16,
          1932.808,
          1933.236,
          1933.4479999999999,
          1933.4470000000001,
          1933.2379999999998,
          1932.825,
          1932.211,
          1931.4,
          1930.395,
          1929.2,
          1927.818,
          1926.2520000000002,
          1924.506,
          1922.582,
          1920.484,
          1918.215,
          1915.777,
          1913.1729999999998,
          1910.406,
          1907.4779999999998,
          1904.3929999999998,
          1901.1529999999998,
          1897.76,
          1894.2160000000001,
          1890.525,
          1886.6879999999999,
          1882.7079999999999,
          1878.5870000000002,
          1874.3270000000002,
          1869.93,
          1865.399,
          1860.735,
          1855.94,
          1851.017,
          1845.967,
          1840.7920000000001,
          1835.494,
          1830.075,
          1824.537,
          1818.881,
          1813.109,
          1807.2220000000002,
          1801.223,
          1795.1129999999998,
          1788.894,
          1782.566,
          1776.132,
          1769.594,
          1762.951,
          1756.207,
          1749.362,
          1742.418,
          1735.376,
          1728.2379999999998,
          1721.004,
          1713.6760000000002,
          1706.256,
          1698.744,
          1691.1429999999998,
          1683.4520000000002,
          1675.6729999999998,
          1667.808,
          1659.8570000000002,
          1651.8220000000001,
          1643.704,
          1635.504,
          1627.2220000000002,
          1618.861,
          1610.421,
          1601.9029999999998,
          1593.308,
          1584.6370000000002,
          1575.891,
          1567.0720000000001,
          1558.1789999999999,
          1549.214,
          1540.1779999999999,
          1531.0729999999999,
          1521.8970000000002,
          1512.654,
          1503.3429999999998,
          1493.965,
          1484.521,
          1475.013,
          1465.44,
          1455.8039999999999,
          1446.106,
          1436.346,
          1426.525,
          1416.644,
          1406.704,
          1396.705,
          1386.648,
          1376.535,
          1366.365,
          1356.139,
          1345.858,
          1335.524,
          1325.135,
          1314.694,
          1304.201,
          1293.657,
          1283.062,
          1272.4160000000002,
          1261.722,
          1250.978,
          1240.1860000000001,
          1229.347,
          1218.461,
          1207.529,
          1196.5510000000002,
          1185.528,
          1174.461,
          1163.35,
          1152.1960000000001,
          1140.999,
          1129.761,
          1118.48,
          1107.1589999999999,
          1095.798,
          1084.397,
          1072.9560000000001,
          1061.478,
          1049.961,
          1038.406,
          1026.815,
          1015.187,
          1003.5239999999999,
          991.825,
          980.091,
          968.323,
          956.5210000000001,
          944.686,
          932.818,
          920.918,
          908.987,
          897.0239999999999,
          885.03,
          873.007,
          860.953,
          848.8710000000001,
          836.76,
          824.62,
          812.453,
          800.2589999999999,
          788.0369999999999,
          775.79,
          763.5169999999999,
          751.2189999999999,
          738.895,
          726.548,
          714.176,
          701.7819999999999,
          689.3639999999999,
          676.924,
          664.462,
          651.9780000000001,
          639.474,
          626.9490000000001,
          614.403,
          601.8380000000001,
          589.255,
          576.6519999999999,
          564.031,
          551.3919999999999,
          538.736,
          526.063,
          513.374,
          500.66900000000004,
          487.949,
          475.213,
          462.463,
          449.699,
          436.92199999999997,
          424.131,
          411.327,
          398.51199999999994,
          385.685,
          372.846,
          359.99699999999996,
          347.13699999999994,
          334.26800000000003,
          321.389,
          308.501,
          295.605,
          282.70099999999996,
          269.79,
          256.872,
          243.947,
          231.016,
          218.08,
          205.138,
          192.19299999999998,
          179.243,
          166.28900000000002,
          153.333,
          140.374,
          127.413,
          114.45100000000001,
          101.488,
          88.524,
          75.56,
          62.597,
          49.635,
          36.674,
          23.715999999999998,
          10.761,
          -2.1919999999999997,
          -15.14,
          -28.084,
          -41.023,
          -53.957,
          -66.884,
          -79.805,
          -92.719,
          -105.625,
          -118.523,
          -131.411,
          -144.29,
          -157.159,
          -170.017,
          -182.863,
          -195.697,
          -208.519,
          -221.327,
          -234.12099999999998,
          -246.90099999999998,
          -259.665,
          -272.413,
          -285.144,
          -297.858,
          -310.55400000000003,
          -323.231,
          -335.889,
          -348.526,
          -361.142,
          -373.736,
          -386.30800000000005,
          -398.856,
          -411.38,
          -423.88,
          -436.353,
          -448.8,
          -461.219,
          -473.61,
          -485.972,
          -498.30400000000003,
          -510.605,
          -522.874,
          -535.111,
          -547.313,
          -559.481,
          -571.613,
          -583.7090000000001,
          -595.7669999999999,
          -607.786,
          -619.765,
          -631.7040000000001,
          -643.6,
          -655.454,
          -667.263,
          -679.0269999999999,
          -690.7439999999999,
          -702.414,
          -714.034,
          -725.605,
          -737.123,
          -748.5889999999999,
          -760.0010000000001,
          -771.357,
          -782.6560000000001,
          -793.8969999999999,
          -805.078,
          -816.197,
          -827.253,
          -838.245,
          -849.171,
          -860.03,
          -870.818,
          -881.5360000000001,
          -892.18,
          -902.75,
          -913.243,
          -923.658,
          -933.992,
          -944.2439999999999,
          -954.4119999999999,
          -964.492,
          -974.4839999999999,
          -984.385,
          -994.192,
          -1003.904,
          -1013.518,
          -1023.0310000000001,
          -1032.441,
          -1041.745,
          -1050.941,
          -1060.025,
          -1068.995,
          -1077.849,
          -1086.5819999999999,
          -1095.191,
          -1103.675,
          -1112.028,
          -1120.248,
          -1128.3310000000001,
          -1136.274,
          -1144.072,
          -1151.722,
          -1159.22,
          -1166.5610000000001,
          -1173.742,
          -1180.757,
          -1187.6019999999999,
          -1194.2730000000001,
          -1200.764,
          -1207.07,
          -1213.187,
          -1219.107,
          -1224.826,
          -1230.337,
          -1235.635,
          -1240.713,
          -1245.5639999999999,
          -1250.181,
          -1254.558,
          -1258.6860000000001,
          -1262.559,
          -1266.167,
          -1269.502,
          -1272.556,
          -1275.319,
          -1277.782,
          -1279.935,
          -1281.767,
          -1283.267,
          -1284.424,
          -1285.226,
          -1285.66,
          -1285.713,
          -1285.373,
          -1284.623,
          -1283.451,
          -1281.839,
          -1279.771,
          -1277.231,
          -1274.198,
          -1270.656,
          -1266.583,
          -1261.9589999999998,
          -1256.761,
          -1250.9669999999999,
          -1244.552,
          -1237.491,
          -1229.755,
          -1221.318,
          -1212.149,
          -1202.2169999999999,
          -1191.489,
          -1179.932,
          -1167.508,
          -1154.1789999999999,
          -1139.907,
          -1124.65,
          -1108.364,
          -1091.005,
          -1072.527,
          -1052.882,
          -1032.02,
          -1009.8910000000001,
          -986.444,
          -961.628,
          -935.3910000000001,
          -907.683,
          -878.456,
          -847.663,
          -815.2639999999999,
          -781.22,
          -745.505,
          -708.096,
          -668.9839999999999,
          -628.173,
          -585.68,
          -541.54,
          -495.80800000000005,
          -448.556,
          -399.88,
          -349.89599999999996,
          -298.737,
          -246.56,
          -193.533,
          -139.84,
          -85.669,
          -31.215999999999998,
          23.326999999999998,
          77.771,
          131.939,
          185.66400000000002,
          238.794,
          291.197,
          342.754,
          393.36800000000005,
          442.95599999999996,
          491.452,
          538.806,
          584.981,
          629.951,
          673.702,
          716.2280000000001,
          757.5319999999999,
          797.6210000000001,
          836.5089999999999,
          874.215,
          910.7589999999999,
          946.163,
          980.454,
          1013.66,
          1045.807,
          1076.923,
          1107.037,
          1136.177,
          1164.373,
          1191.651,
          1218.039,
          1243.5639999999999,
          1268.252,
          1292.129,
          1315.217,
          1337.543,
          1359.129,
          1379.997,
          1400.17,
          1419.6670000000001,
          1438.509,
          1456.715,
          1474.3039999999999,
          1491.293,
          1507.7,
          1523.5420000000001,
          1538.835,
          1553.594,
          1567.8339999999998,
          1581.568,
          1594.8110000000001,
          1607.575,
          1619.875,
          1631.721,
          1643.1270000000002,
          1654.102,
          1664.658,
          1674.806,
          1684.555,
          1693.9160000000002,
          1702.898,
          1711.51,
          1719.761,
          1727.66,
          1735.214,
          1742.433,
          1749.3229999999999,
          1755.892,
          1762.1470000000002,
          1768.095,
          1773.7420000000002,
          1779.096,
          1784.1629999999998,
          1788.9479999999999,
          1793.4579999999999,
          1797.6979999999999,
          1801.675,
          1805.392,
          1808.8570000000002,
          1812.0729999999999,
          1815.046,
          1817.78,
          1820.28,
          1822.5510000000002,
          1824.5970000000002,
          1826.4229999999998,
          1828.031,
          1829.4279999999999,
          1830.615,
          1831.598,
          1832.38,
          1832.964,
          1833.354,
          1833.5539999999999,
          1833.567,
          1833.396,
          1833.0439999999999,
          1832.514,
          1831.81,
          1830.935,
          1829.89,
          1828.68,
          1827.306,
          1825.7720000000002,
          1824.08,
          1822.233,
          1820.233,
          1818.082,
          1815.783,
          1813.338,
          1810.75,
          1808.02,
          1805.151,
          1802.146,
          1799.005,
          1795.731,
          1792.3270000000002,
          1788.793,
          1785.1329999999998,
          1781.3470000000002,
          1777.4379999999999,
          1773.408,
          1769.257,
          1764.989,
          1760.604,
          1756.104,
          1751.491,
          1746.767,
          1741.932,
          1736.99,
          1731.94,
          1726.7839999999999,
          1721.525,
          1716.1629999999998,
          1710.7,
          1705.1370000000002,
          1699.475,
          1693.7160000000001,
          1687.861,
          1681.912,
          1675.869,
          1669.734,
          1663.5079999999998,
          1657.192,
          1650.7879999999998,
          1644.296,
          1637.717,
          1631.0539999999999,
          1624.306,
          1617.475,
          1610.5620000000001,
          1603.568,
          1596.495,
          1589.342,
          1582.111,
          1574.8029999999999,
          1567.4189999999999,
          1559.96,
          1552.4270000000001,
          1544.8210000000001,
          1537.142,
          1529.392,
          1521.5710000000001,
          1513.68,
          1505.721,
          1497.694,
          1489.599,
          1481.4379999999999,
          1473.2120000000002,
          1464.92,
          1456.565,
          1448.1470000000002,
          1439.6660000000002,
          1431.1229999999998,
          1422.52,
          1413.856,
          1405.1329999999998,
          1396.351,
          1387.511,
          1378.6129999999998,
          1369.6589999999999,
          1360.649,
          1351.5839999999998,
          1342.464,
          1333.29,
          1324.0629999999999,
          1314.783,
          1305.451,
          1296.067,
          1286.633,
          1277.149,
          1267.615,
          1258.032,
          1248.401,
          1238.722,
          1228.995,
          1219.222,
          1209.404,
          1199.539,
          1189.63,
          1179.6760000000002,
          1169.6789999999999,
          1159.638,
          1149.555,
          1139.4289999999999,
          1129.262,
          1119.053,
          1108.8039999999999,
          1098.515,
          1088.1860000000001,
          1077.819,
          1067.413,
          1056.968,
          1046.486,
          1035.968,
          1025.412,
          1014.821,
          1004.193,
          993.5310000000001,
          982.834,
          972.1030000000001,
          961.3380000000001,
          950.541,
          939.71,
          928.847,
          917.952,
          907.0260000000001,
          896.069,
          885.081,
          874.064,
          863.0160000000001,
          851.94,
          840.835,
          829.702,
          818.541,
          807.352,
          796.137,
          784.895,
          773.627,
          762.334,
          751.015,
          739.672,
          728.304,
          716.9119999999999,
          705.497,
          694.059,
          682.5980000000001,
          671.115,
          659.61,
          648.0830000000001,
          636.536,
          624.9680000000001,
          613.38,
          601.7719999999999,
          590.146,
          578.5,
          566.836,
          555.153,
          543.453,
          531.736,
          520.003,
          508.25199999999995,
          496.486,
          484.705,
          472.908,
          461.097,
          449.27099999999996,
          437.43199999999996,
          425.579,
          413.713,
          401.834,
          389.944,
          378.042,
          366.12800000000004,
          354.204,
          342.269,
          330.325,
          318.371,
          306.407,
          294.435,
          282.455,
          270.467,
          258.472,
          246.47,
          234.46200000000002,
          222.447,
          210.42700000000002,
          198.40200000000002,
          186.373,
          174.33900000000003,
          162.30100000000002,
          150.261,
          138.218,
          126.17200000000001,
          114.125,
          102.07700000000001,
          90.027,
          77.97800000000001,
          65.929,
          53.88,
          41.833,
          29.787,
          17.744,
          5.702999999999999,
          -6.334,
          -18.367,
          -30.396,
          -42.42,
          -54.438,
          -66.45,
          -78.456,
          -90.455,
          -102.446,
          -114.428,
          -126.402,
          -138.366,
          -150.319,
          -162.262,
          -174.19400000000002,
          -186.114,
          -198.021,
          -209.915,
          -221.794,
          -233.66,
          -245.50900000000001,
          -257.343,
          -269.16,
          -280.96,
          -292.742,
          -304.505,
          -316.248,
          -327.971,
          -339.673,
          -351.353,
          -363.01,
          -374.644,
          -386.254,
          -397.838,
          -409.397,
          -420.92900000000003,
          -432.43300000000005,
          -443.908,
          -455.35400000000004,
          -466.769,
          -478.153,
          -489.505,
          -500.824,
          -512.1080000000001,
          -523.356,
          -534.569,
          -545.743,
          -556.88,
          -567.976,
          -579.0319999999999,
          -590.0459999999999,
          -601.016,
          -611.943,
          -622.823,
          -633.6569999999999,
          -644.443,
          -655.179,
          -665.865,
          -676.498,
          -687.077,
          -697.602,
          -708.07,
          -718.48,
          -728.83,
          -739.1189999999999,
          -749.3439999999999,
          -759.5060000000001,
          -769.6010000000001,
          -779.628,
          -789.584,
          -799.47,
          -809.2810000000001,
          -819.0169999999999,
          -828.675,
          -838.253,
          -847.7489999999999,
          -857.1610000000001,
          -866.4860000000001,
          -875.7230000000001,
          -884.868,
          -893.92,
          -902.8760000000001,
          -911.732,
          -920.488,
          -929.1389999999999,
          -937.682,
          -946.1160000000001,
          -954.436,
          -962.6389999999999,
          -970.7230000000001,
          -978.684,
          -986.5189999999999,
          -994.2230000000001,
          -1001.793,
          -1009.225,
          -1016.515,
          -1023.66,
          -1030.654,
          -1037.494,
          -1044.175,
          -1050.69,
          -1057.037,
          -1063.211,
          -1069.204,
          -1075.012,
          -1080.63,
          -1086.0510000000002,
          -1091.269,
          -1096.277,
          -1101.069,
          -1105.637,
          -1109.975,
          -1114.0739999999998,
          -1117.927,
          -1121.526,
          -1124.861,
          -1127.924,
          -1130.705,
          -1133.195,
          -1135.383,
          -1137.259,
          -1138.81,
          -1140.025,
          -1140.892,
          -1141.397,
          -1141.528,
          -1141.269,
          -1140.606,
          -1139.524,
          -1138.004,
          -1136.031,
          -1133.586,
          -1130.649,
          -1127.2,
          -1123.218,
          -1118.681,
          -1113.566,
          -1107.847,
          -1101.497,
          -1094.492,
          -1086.8,
          -1078.391,
          -1069.235,
          -1059.297,
          -1048.5430000000001,
          -1036.935,
          -1024.435,
          -1011.003,
          -996.596,
          -981.172,
          -964.685,
          -947.0880000000001,
          -928.336,
          -908.3760000000001,
          -887.1619999999999,
          -864.645,
          -840.773,
          -815.502,
          -788.784,
          -760.578,
          -730.847,
          -699.558,
          -666.688,
          -632.222,
          -596.1569999999999,
          -558.503,
          -519.285,
          -478.545,
          -436.345,
          -392.76300000000003,
          -347.899,
          -301.873,
          -254.817,
          -206.885,
          -158.239,
          -109.052,
          -59.498999999999995,
          -9.759,
          39.995,
          89.598,
          138.894,
          187.739,
          236.007,
          283.586,
          330.37800000000004,
          376.30400000000003,
          421.29699999999997,
          465.305,
          508.289,
          550.222,
          591.085,
          630.867,
          669.567,
          707.19,
          743.742,
          779.2360000000001,
          813.691,
          847.1239999999999,
          879.555,
          911.008,
          941.505,
          971.071,
          999.7280000000001,
          1027.504,
          1054.42,
          1080.504,
          1105.777,
          1130.263,
          1153.985,
          1176.9669999999999,
          1199.229,
          1220.7930000000001,
          1241.678,
          1261.906,
          1281.496,
          1300.4660000000001,
          1318.8329999999999,
          1336.616,
          1353.8310000000001,
          1370.494,
          1386.62,
          1402.225,
          1417.3229999999999,
          1431.9270000000001,
          1446.0529999999999,
          1459.711,
          1472.914,
          1485.675,
          1498.005,
          1509.915,
          1521.415,
          1532.517,
          1543.23,
          1553.5629999999999,
          1563.526,
          1573.129,
          1582.378,
          1591.283,
          1599.852,
          1608.092,
          1616.0120000000002,
          1623.618,
          1630.918,
          1637.918,
          1644.624,
          1651.0439999999999,
          1657.182,
          1663.0479999999998,
          1668.6429999999998,
          1673.975,
          1679.049,
          1683.871,
          1688.445,
          1692.776,
          1696.87,
          1700.731,
          1704.3629999999998,
          1707.771,
          1710.9589999999998,
          1713.931,
          1716.692,
          1719.245,
          1721.594,
          1723.743,
          1725.695,
          1727.455,
          1729.024,
          1730.408,
          1731.608,
          1732.628,
          1733.471,
          1734.141,
          1734.639,
          1734.97,
          1735.135,
          1735.138,
          1734.981,
          1734.6660000000002,
          1734.1970000000001,
          1733.575,
          1732.8039999999999,
          1731.885,
          1730.8210000000001,
          1729.614,
          1728.266,
          1726.779,
          1725.156,
          1723.398,
          1721.5079999999998,
          1719.487,
          1717.338,
          1715.0620000000001,
          1712.661,
          1710.136,
          1707.491,
          1704.725,
          1701.842,
          1698.8429999999998,
          1695.729,
          1692.5020000000002,
          1689.1629999999998,
          1685.714,
          1682.1570000000002,
          1678.493,
          1674.723,
          1670.85,
          1666.8729999999998,
          1662.795,
          1658.6170000000002,
          1654.34,
          1649.9660000000001,
          1645.496,
          1640.931,
          1636.271,
          1631.52,
          1626.6770000000001,
          1621.744,
          1616.7220000000002,
          1611.611,
          1606.414,
          1601.131,
          1595.764,
          1590.3129999999999,
          1584.779,
          1579.164,
          1573.467,
          1567.691,
          1561.838,
          1555.906,
          1549.8970000000002,
          1543.8120000000001,
          1537.651,
          1531.4170000000001,
          1525.11,
          1518.73,
          1512.2779999999998,
          1505.756,
          1499.165,
          1492.504,
          1485.775,
          1478.9779999999998,
          1472.115,
          1465.1860000000001,
          1458.191,
          1451.1329999999998,
          1444.01,
          1436.8239999999998,
          1429.5770000000002,
          1422.267,
          1414.8970000000002,
          1407.467,
          1399.977,
          1392.4289999999999,
          1384.8220000000001,
          1377.158,
          1369.4370000000001,
          1361.6589999999999,
          1353.8270000000002,
          1345.9389999999999,
          1337.997,
          1330.001,
          1321.9520000000002,
          1313.85,
          1305.697,
          1297.492,
          1289.236,
          1280.93,
          1272.575,
          1264.17,
          1255.7169999999999,
          1247.215,
          1238.6660000000002,
          1230.0710000000001,
          1221.428,
          1212.74,
          1204.007,
          1195.228,
          1186.405,
          1177.539,
          1168.628,
          1159.675,
          1150.68,
          1141.643,
          1132.5639999999999,
          1123.444,
          1114.2839999999999,
          1105.083,
          1095.843,
          1086.5639999999999,
          1077.246,
          1067.891,
          1058.497,
          1049.066,
          1039.598,
          1030.093,
          1020.553,
          1010.977,
          1001.3660000000001,
          991.72,
          982.04,
          972.326,
          962.578,
          952.797,
          942.9839999999999,
          933.138,
          923.2610000000001,
          913.352,
          903.4119999999999,
          893.442,
          883.441,
          873.4110000000001,
          863.3510000000001,
          853.262,
          843.1439999999999,
          832.998,
          822.824,
          812.623,
          802.395,
          792.1389999999999,
          781.8580000000001,
          771.551,
          761.2180000000001,
          750.8589999999999,
          740.4760000000001,
          730.069,
          719.637,
          709.182,
          698.703,
          688.202,
          677.678,
          667.1310000000001,
          656.563,
          645.974,
          635.363,
          624.731,
          614.08,
          603.408,
          592.717,
          582.006,
          571.2769999999999,
          560.529,
          549.763,
          538.979,
          528.178,
          517.36,
          506.525,
          495.67400000000004,
          484.80699999999996,
          473.925,
          463.028,
          452.115,
          441.189,
          430.249,
          419.29400000000004,
          408.327,
          397.347,
          386.355,
          375.35,
          364.334,
          353.306,
          342.26800000000003,
          331.219,
          320.16,
          309.092,
          298.014,
          286.927,
          275.832,
          264.72900000000004,
          253.618,
          242.5,
          231.37599999999998,
          220.245,
          209.107,
          197.965,
          186.817,
          175.665,
          164.50900000000001,
          153.34799999999998,
          142.185,
          131.018,
          119.85,
          108.679,
          97.507,
          86.334,
          75.16,
          63.986000000000004,
          52.813,
          41.641000000000005,
          30.47,
          19.301,
          8.135,
          -3.029,
          -14.189,
          -25.345,
          -36.496,
          -47.641999999999996,
          -58.783,
          -69.917,
          -81.045,
          -92.165,
          -103.277,
          -114.381,
          -125.476,
          -136.56,
          -147.635,
          -158.69799999999998,
          -169.75,
          -180.79,
          -191.81599999999997,
          -202.829,
          -213.828,
          -224.812,
          -235.78,
          -246.731,
          -257.666,
          -268.58299999999997,
          -279.481,
          -290.35900000000004,
          -301.218,
          -312.055,
          -322.87,
          -333.663,
          -344.43300000000005,
          -355.17800000000005,
          -365.898,
          -376.591,
          -387.25800000000004,
          -397.897,
          -408.506,
          -419.086,
          -429.635,
          -440.152,
          -450.635,
          -461.085,
          -471.5,
          -481.87800000000004,
          -492.219,
          -502.52099999999996,
          -512.783,
          -523.005,
          -533.184,
          -543.319,
          -553.41,
          -563.4540000000001,
          -573.451,
          -583.398,
          -593.295,
          -603.14,
          -612.931,
          -622.6669999999999,
          -632.347,
          -641.967,
          -651.528,
          -661.0260000000001,
          -670.461,
          -679.83,
          -689.132,
          -698.3639999999999,
          -707.5239999999999,
          -716.6110000000001,
          -725.622,
          -734.555,
          -743.4069999999999,
          -752.177,
          -760.8610000000001,
          -769.4580000000001,
          -777.9639999999999,
          -786.378,
          -794.695,
          -802.914,
          -811.0310000000001,
          -819.044,
          -826.949,
          -834.742,
          -842.421,
          -849.982,
          -857.421,
          -864.735,
          -871.919,
          -878.97,
          -885.883,
          -892.654,
          -899.279,
          -905.752,
          -912.069,
          -918.2239999999999,
          -924.212,
          -930.029,
          -935.668,
          -941.123,
          -946.387,
          -951.455,
          -956.319,
          -960.972,
          -965.408,
          -969.618,
          -973.5939999999999,
          -977.328,
          -980.811,
          -984.034,
          -986.987,
          -989.66,
          -992.0419999999999,
          -994.122,
          -995.8889999999999,
          -997.331,
          -998.433,
          -999.184,
          -999.568,
          -999.57,
          -999.176,
          -998.368,
          -997.13,
          -995.443,
          -993.2869999999999,
          -990.6419999999999,
          -987.487,
          -983.799,
          -979.554,
          -974.7280000000001,
          -969.294,
          -963.2260000000001,
          -956.4910000000001,
          -949.06,
          -940.9019999999999,
          -931.9810000000001,
          -922.263,
          -911.71,
          -900.2819999999999,
          -887.939,
          -874.6410000000001,
          -860.341,
          -844.995,
          -828.558,
          -810.982,
          -792.221,
          -772.225,
          -750.95,
          -728.3510000000001,
          -704.3839999999999,
          -679.012,
          -652.2,
          -623.9209999999999,
          -594.156,
          -562.894,
          -530.139,
          -495.907,
          -460.226,
          -423.14599999999996,
          -384.73199999999997,
          -345.065,
          -304.246,
          -262.394,
          -219.64,
          -176.127,
          -132.01,
          -87.448,
          -42.6,
          2.374,
          47.32,
          92.096,
          136.566,
          180.61,
          224.12099999999998,
          267.005,
          309.185,
          350.592,
          391.175,
          430.89099999999996,
          469.711,
          507.61199999999997,
          544.581,
          580.61,
          615.6990000000001,
          649.852,
          683.076,
          715.3839999999999,
          746.788,
          777.306,
          806.955,
          835.753,
          863.72,
          890.877,
          917.2439999999999,
          942.842,
          967.69,
          991.925,
          1015.221,
          1037.944,
          1059.998,
          1081.401,
          1102.172,
          1122.329,
          1141.889,
          1160.87,
          1179.286,
          1197.156,
          1214.493,
          1231.312,
          1247.628,
          1263.454,
          1278.803,
          1293.6889999999999,
          1308.123,
          1322.118,
          1335.685,
          1348.835,
          1361.578,
          1373.9260000000002,
          1385.8870000000002,
          1397.4720000000002,
          1408.69,
          1419.55,
          1430.06,
          1440.2279999999998,
          1450.0639999999999,
          1459.5729999999999,
          1468.765,
          1477.646,
          1486.223,
          1494.5020000000002,
          1502.4920000000002,
          1510.1970000000001,
          1517.624,
          1524.78,
          1531.6689999999999,
          1538.2979999999998,
          1544.67,
          1550.793,
          1556.6729999999998,
          1562.3110000000001,
          1567.713,
          1572.885,
          1577.832,
          1582.556,
          1587.0629999999999,
          1591.356,
          1595.44,
          1599.319,
          1602.996,
          1606.474,
          1609.759,
          1612.852,
          1615.7579999999998,
          1618.479,
          1621.019,
          1623.382,
          1625.569,
          1627.585,
          1629.431,
          1631.111,
          1632.628,
          1633.983,
          1635.181,
          1636.223,
          1637.111,
          1637.849,
          1638.4379999999999,
          1638.881,
          1639.18,
          1639.338,
          1639.356,
          1639.237,
          1638.9820000000002,
          1638.594,
          1638.075,
          1637.4260000000002,
          1636.65,
          1635.7479999999998,
          1634.7220000000002,
          1633.5739999999998,
          1632.306,
          1630.918,
          1629.414,
          1627.7939999999999,
          1626.0610000000001,
          1624.215,
          1622.2579999999998,
          1620.192,
          1618.0179999999998,
          1615.737,
          1613.352,
          1610.862,
          1608.271,
          1605.578,
          1602.786,
          1599.895,
          1596.9070000000002,
          1593.8239999999998,
          1590.645,
          1587.3729999999998,
          1584.0079999999998,
          1580.5529999999999,
          1577.007,
          1573.372,
          1569.649,
          1565.84,
          1561.944,
          1557.964,
          1553.9,
          1549.753,
          1545.524,
          1541.214,
          1536.8239999999998,
          1532.356,
          1527.809,
          1523.185,
          1518.485,
          1513.7089999999998,
          1508.859,
          1503.935,
          1498.9379999999999,
          1493.868,
          1488.7279999999998,
          1483.517,
          1478.236,
          1472.8870000000002,
          1467.4679999999998,
          1461.984,
          1456.432,
          1450.8129999999999,
          1445.13,
          1439.381,
          1433.57,
          1427.695,
          1421.756,
          1415.7579999999998,
          1409.6970000000001,
          1403.575,
          1397.394,
          1391.1529999999998,
          1384.854,
          1378.496,
          1372.082,
          1365.61,
          1359.082,
          1352.4979999999998,
          1345.859,
          1339.1660000000002,
          1332.418,
          1325.618,
          1318.764,
          1311.858,
          1304.9,
          1297.89,
          1290.83,
          1283.72,
          1276.56,
          1269.351,
          1262.093,
          1254.787,
          1247.432,
          1240.031,
          1232.583,
          1225.089,
          1217.548,
          1209.963,
          1202.3319999999999,
          1194.657,
          1186.938,
          1179.175,
          1171.369,
          1163.52,
          1155.629,
          1147.697,
          1139.723,
          1131.7069999999999,
          1123.652,
          1115.556,
          1107.42,
          1099.245,
          1091.031,
          1082.778,
          1074.487,
          1066.1589999999999,
          1057.7930000000001,
          1049.39,
          1040.95,
          1032.474,
          1023.962,
          1015.415,
          1006.8330000000001,
          998.216,
          989.565,
          980.8789999999999,
          972.16,
          963.408,
          954.623,
          945.805,
          936.955,
          928.073,
          919.16,
          910.215,
          901.24,
          892.2339999999999,
          883.198,
          874.132,
          865.0369999999999,
          855.913,
          846.76,
          837.578,
          828.3689999999999,
          819.1310000000001,
          809.867,
          800.575,
          791.257,
          781.9119999999999,
          772.541,
          763.1439999999999,
          753.721,
          744.2739999999999,
          734.801,
          725.305,
          715.784,
          706.2389999999999,
          696.67,
          687.079,
          677.465,
          667.828,
          658.169,
          648.488,
          638.785,
          629.061,
          619.316,
          609.5509999999999,
          599.765,
          589.96,
          580.135,
          570.29,
          560.427,
          550.544,
          540.644,
          530.726,
          520.789,
          510.836,
          500.865,
          490.87800000000004,
          480.875,
          470.855,
          460.82,
          450.77,
          440.704,
          430.624,
          420.529,
          410.421,
          400.29900000000004,
          390.163,
          380.015,
          369.85400000000004,
          359.681,
          349.496,
          339.3,
          329.092,
          318.874,
          308.645,
          298.406,
          288.157,
          277.899,
          267.632,
          257.357,
          247.074,
          236.782,
          226.484,
          216.178,
          205.86599999999999,
          195.547,
          185.22299999999998,
          174.894,
          164.56,
          154.221,
          143.878,
          133.531,
          123.181,
          112.829,
          102.47399999999999,
          92.117,
          81.759,
          71.4,
          61.041000000000004,
          50.681000000000004,
          40.321999999999996,
          29.965,
          19.608,
          9.254,
          -1.0979999999999999,
          -11.446,
          -21.791,
          -32.132,
          -42.468999999999994,
          -52.799,
          -63.123999999999995,
          -73.443,
          -83.755,
          -94.059,
          -104.354,
          -114.641,
          -124.919,
          -135.186,
          -145.442,
          -155.687,
          -165.92,
          -176.14,
          -186.347,
          -196.53900000000002,
          -206.71599999999998,
          -216.878,
          -227.02200000000002,
          -237.15,
          -247.25900000000001,
          -257.35,
          -267.42,
          -277.47,
          -287.498,
          -297.504,
          -307.487,
          -317.445,
          -327.378,
          -337.284,
          -347.164,
          -357.015,
          -366.836,
          -376.62800000000004,
          -386.38699999999994,
          -396.11400000000003,
          -405.80699999999996,
          -415.465,
          -425.086,
          -434.67,
          -444.215,
          -453.72,
          -463.18300000000005,
          -472.603,
          -481.978,
          -491.30800000000005,
          -500.589,
          -509.82199999999995,
          -519.004,
          -528.133,
          -537.2080000000001,
          -546.227,
          -555.189,
          -564.09,
          -572.93,
          -581.706,
          -590.4159999999999,
          -599.058,
          -607.63,
          -616.13,
          -624.554,
          -632.901,
          -641.168,
          -649.3530000000001,
          -657.452,
          -665.4630000000001,
          -673.383,
          -681.209,
          -688.938,
          -696.567,
          -704.091,
          -711.508,
          -718.814,
          -726.005,
          -733.078,
          -740.0269999999999,
          -746.85,
          -753.541,
          -760.095,
          -766.5089999999999,
          -772.7769999999999,
          -778.893,
          -784.8530000000001,
          -790.6510000000001,
          -796.28,
          -801.735,
          -807.0089999999999,
          -812.095,
          -816.9860000000001,
          -821.675,
          -826.154,
          -830.415,
          -834.449,
          -838.248,
          -841.802,
          -845.1010000000001,
          -848.1339999999999,
          -850.8919999999999,
          -853.363,
          -855.534,
          -857.393,
          -858.927,
          -860.122,
          -860.962,
          -861.432,
          -861.5169999999999,
          -861.198,
          -860.4580000000001,
          -859.2769999999999,
          -857.635,
          -855.5110000000001,
          -852.8810000000001,
          -849.722,
          -846.0089999999999,
          -841.7139999999999,
          -836.811,
          -831.27,
          -825.059,
          -818.145,
          -810.4939999999999,
          -802.071,
          -792.8380000000001,
          -782.755,
          -771.7810000000001,
          -759.8739999999999,
          -746.992,
          -733.087,
          -718.117,
          -702.035,
          -684.797,
          -666.357,
          -646.673,
          -625.706,
          -603.418,
          -579.781,
          -554.77,
          -528.368,
          -500.57099999999997,
          -471.385,
          -440.82800000000003,
          -408.93699999999995,
          -375.76,
          -341.36300000000006,
          -305.832,
          -269.26099999999997,
          -231.766,
          -193.472,
          -154.513,
          -115.02799999999999,
          -75.163,
          -35.061,
          5.14,
          45.303999999999995,
          85.309,
          125.041,
          164.39700000000002,
          203.28799999999998,
          241.635,
          279.374,
          316.45099999999996,
          352.82199999999995,
          388.45300000000003,
          423.32,
          457.403,
          490.69300000000004,
          523.183,
          554.874,
          585.766,
          615.868,
          645.189,
          673.7389999999999,
          701.533,
          728.5830000000001,
          754.904,
          780.5139999999999,
          805.429,
          829.665,
          853.2389999999999,
          876.1669999999999,
          898.467,
          920.155,
          941.247,
          961.76,
          981.7080000000001,
          1001.1060000000001,
          1019.971,
          1038.316,
          1056.155,
          1073.502,
          1090.37,
          1106.772,
          1122.719,
          1138.224,
          1153.299,
          1167.954,
          1182.201,
          1196.049,
          1209.509,
          1222.5910000000001,
          1235.3039999999999,
          1247.657,
          1259.6580000000001,
          1271.315,
          1282.639,
          1293.635,
          1304.312,
          1314.6760000000002,
          1324.737,
          1334.499,
          1343.97,
          1353.156,
          1362.0629999999999,
          1370.6979999999999,
          1379.066,
          1387.1729999999998,
          1395.024,
          1402.625,
          1409.98,
          1417.096,
          1423.976,
          1430.625,
          1437.0479999999998,
          1443.249,
          1449.233,
          1455.003,
          1460.565,
          1465.92,
          1471.075,
          1476.031,
          1480.793,
          1485.364,
          1489.7479999999998,
          1493.9470000000001,
          1497.9660000000001,
          1501.807,
          1505.473,
          1508.9679999999998,
          1512.293,
          1515.453,
          1518.4489999999998,
          1521.285,
          1523.963,
          1526.485,
          1528.855,
          1531.0729999999999,
          1533.144,
          1535.069,
          1536.85,
          1538.49,
          1539.99,
          1541.3529999999998,
          1542.5810000000001,
          1543.6760000000002,
          1544.639,
          1545.473,
          1546.18,
          1546.761,
          1547.2179999999998,
          1547.5529999999999,
          1547.767,
          1547.8629999999998,
          1547.8410000000001,
          1547.705,
          1547.454,
          1547.09,
          1546.616,
          1546.033,
          1545.3410000000001,
          1544.543,
          1543.639,
          1542.632,
          1541.5220000000002,
          1540.3110000000001,
          1539,
          1537.59,
          1536.0829999999999,
          1534.479,
          1532.78,
          1530.9879999999998,
          1529.102,
          1527.125,
          1525.058,
          1522.9,
          1520.655,
          1518.3210000000001,
          1515.902,
          1513.3970000000002,
          1510.807,
          1508.134,
          1505.379,
          1502.5420000000001,
          1499.624,
          1496.6270000000002,
          1493.5510000000002,
          1490.396,
          1487.165,
          1483.8570000000002,
          1480.474,
          1477.016,
          1473.484,
          1469.88,
          1466.2020000000002,
          1462.454,
          1458.634,
          1454.745,
          1450.786,
          1446.759,
          1442.664,
          1438.5020000000002,
          1434.273,
          1429.9779999999998,
          1425.618,
          1421.194,
          1416.7060000000001,
          1412.155,
          1407.5410000000002,
          1402.865,
          1398.128,
          1393.33,
          1388.4720000000002,
          1383.555,
          1378.578,
          1373.543,
          1368.45,
          1363.3,
          1358.0929999999998,
          1352.83,
          1347.5120000000002,
          1342.138,
          1336.7089999999998,
          1331.227,
          1325.691,
          1320.101,
          1314.4589999999998,
          1308.765,
          1303.02,
          1297.223,
          1291.375,
          1285.4769999999999,
          1279.53,
          1273.5330000000001,
          1267.487,
          1261.393,
          1255.251,
          1249.0610000000001,
          1242.8239999999998,
          1236.5410000000002,
          1230.211,
          1223.835,
          1217.414,
          1210.948,
          1204.437,
          1197.882,
          1191.2830000000001,
          1184.64,
          1177.955,
          1171.226,
          1164.4560000000001,
          1157.643,
          1150.789,
          1143.894,
          1136.958,
          1129.981,
          1122.964,
          1115.9080000000001,
          1108.812,
          1101.677,
          1094.503,
          1087.2910000000002,
          1080.04,
          1072.752,
          1065.427,
          1058.065,
          1050.6660000000002,
          1043.23,
          1035.758,
          1028.251,
          1020.7080000000001,
          1013.13,
          1005.518,
          997.87,
          990.189,
          982.4739999999999,
          974.725,
          966.943,
          959.128,
          951.28,
          943.4,
          935.488,
          927.544,
          919.568,
          911.562,
          903.5239999999999,
          895.456,
          887.3580000000001,
          879.2289999999999,
          871.071,
          862.883,
          854.666,
          846.421,
          838.1460000000001,
          829.8430000000001,
          821.513,
          813.154,
          804.768,
          796.355,
          787.914,
          779.447,
          770.954,
          762.435,
          753.8889999999999,
          745.318,
          736.722,
          728.1010000000001,
          719.455,
          710.784,
          702.0889999999999,
          693.3710000000001,
          684.628,
          675.863,
          667.074,
          658.262,
          649.428,
          640.571,
          631.692,
          622.7919999999999,
          613.87,
          604.9259999999999,
          595.962,
          586.977,
          577.972,
          568.947,
          559.901,
          550.837,
          541.753,
          532.65,
          523.528,
          514.388,
          505.22900000000004,
          496.05300000000005,
          486.85900000000004,
          477.648,
          468.42,
          459.176,
          449.915,
          440.63699999999994,
          431.344,
          422.036,
          412.712,
          403.37300000000005,
          394.02,
          384.653,
          375.27099999999996,
          365.876,
          356.468,
          347.046,
          337.61199999999997,
          328.166,
          318.707,
          309.237,
          299.756,
          290.263,
          280.76,
          271.246,
          261.723,
          252.19,
          242.648,
          233.097,
          223.537,
          213.96900000000002,
          204.394,
          194.81099999999998,
          185.22099999999998,
          175.625,
          166.023,
          156.414,
          146.80100000000002,
          137.18200000000002,
          127.559,
          117.93299999999999,
          108.302,
          98.66799999999999,
          89.03200000000001,
          79.393,
          69.753,
          60.111999999999995,
          50.468999999999994,
          40.827,
          31.184,
          21.543000000000003,
          11.902999999999999,
          2.2640000000000002,
          -7.372000000000001,
          -17.005,
          -26.634,
          -36.26,
          -45.88,
          -55.496,
          -65.105,
          -74.708,
          -84.304,
          -93.891,
          -103.471,
          -113.04,
          -122.6,
          -132.15,
          -141.687,
          -151.213,
          -160.725,
          -170.22400000000002,
          -179.708,
          -189.17700000000002,
          -198.62900000000002,
          -208.06400000000002,
          -217.481,
          -226.87900000000002,
          -236.257,
          -245.614,
          -254.949,
          -264.26,
          -273.548,
          -282.811,
          -292.047,
          -301.255,
          -310.435,
          -319.585,
          -328.704,
          -337.79,
          -346.843,
          -355.86,
          -364.84,
          -373.783,
          -382.685,
          -391.54699999999997,
          -400.365,
          -409.139,
          -417.86699999999996,
          -426.54699999999997,
          -435.176,
          -443.754,
          -452.278,
          -460.74699999999996,
          -469.157,
          -477.50699999999995,
          -485.79400000000004,
          -494.017,
          -502.17199999999997,
          -510.25800000000004,
          -518.271,
          -526.2090000000001,
          -534.068,
          -541.847,
          -549.5419999999999,
          -557.149,
          -564.6659999999999,
          -572.089,
          -579.414,
          -586.637,
          -593.755,
          -600.764,
          -607.659,
          -614.436,
          -621.09,
          -627.617,
          -634.011,
          -640.266,
          -646.378,
          -652.341,
          -658.1489999999999,
          -663.794,
          -669.2710000000001,
          -674.573,
          -679.692,
          -684.62,
          -689.3489999999999,
          -693.8710000000001,
          -698.176,
          -702.2560000000001,
          -706.1,
          -709.698,
          -713.039,
          -716.112,
          -718.903,
          -721.4,
          -723.5889999999999,
          -725.457,
          -726.987,
          -728.163,
          -728.9680000000001,
          -729.385,
          -729.3939999999999,
          -728.9739999999999,
          -728.1060000000001,
          -726.7660000000001,
          -724.929,
          -722.572,
          -719.666,
          -716.184,
          -712.096,
          -707.372,
          -701.977,
          -695.877,
          -689.035,
          -681.415,
          -672.9760000000001,
          -663.678,
          -653.4780000000001,
          -642.3330000000001,
          -630.2,
          -617.035,
          -602.793,
          -587.433,
          -570.914,
          -553.197,
          -534.249,
          -514.0419999999999,
          -492.55400000000003,
          -469.77099999999996,
          -445.691,
          -420.32099999999997,
          -393.68300000000005,
          -365.81199999999995,
          -336.75800000000004,
          -306.586,
          -275.376,
          -243.222,
          -210.22799999999998,
          -176.51,
          -142.191,
          -107.396,
          -72.25399999999999,
          -36.89,
          -1.425,
          34.025,
          69.355,
          104.46799999999999,
          139.278,
          173.71,
          207.69799999999998,
          241.188,
          274.135,
          306.502,
          338.26099999999997,
          369.38800000000003,
          399.87,
          429.695,
          458.85900000000004,
          487.35900000000004,
          515.197,
          542.377,
          568.906,
          594.7909999999999,
          620.0419999999999,
          644.6709999999999,
          668.689,
          692.107,
          714.939,
          737.197,
          758.8960000000001,
          780.047,
          800.665,
          820.762,
          840.35,
          859.444,
          878.055,
          896.196,
          913.878,
          931.1139999999999,
          947.913,
          964.288,
          980.2489999999999,
          995.807,
          1010.971,
          1025.752,
          1040.1580000000001,
          1054.2,
          1067.885,
          1081.223,
          1094.221,
          1106.888,
          1119.232,
          1131.26,
          1142.979,
          1154.396,
          1165.518,
          1176.3519999999999,
          1186.904,
          1197.18,
          1207.187,
          1216.9289999999999,
          1226.414,
          1235.645,
          1244.629,
          1253.37,
          1261.874,
          1270.144,
          1278.187,
          1286.005,
          1293.604,
          1300.988,
          1308.162,
          1315.128,
          1321.891,
          1328.454,
          1334.8220000000001,
          1340.9979999999998,
          1346.986,
          1352.7879999999998,
          1358.408,
          1363.849,
          1369.114,
          1374.207,
          1379.13,
          1383.886,
          1388.477,
          1392.9070000000002,
          1397.1779999999999,
          1401.293,
          1405.254,
          1409.0639999999999,
          1412.725,
          1416.239,
          1419.609,
          1422.836,
          1425.924,
          1428.874,
          1431.6870000000001,
          1434.3670000000002,
          1436.915,
          1439.3329999999999,
          1441.6229999999998,
          1443.787,
          1445.826,
          1447.7420000000002,
          1449.537,
          1451.213,
          1452.771,
          1454.213,
          1455.54,
          1456.755,
          1457.8570000000002,
          1458.849,
          1459.733,
          1460.509,
          1461.18,
          1461.745,
          1462.2079999999999,
          1462.568,
          1462.828,
          1462.9879999999998,
          1463.05,
          1463.015,
          1462.884,
          1462.6589999999999,
          1462.339,
          1461.9279999999999,
          1461.424,
          1460.8310000000001,
          1460.148,
          1459.376,
          1458.517,
          1457.5720000000001,
          1456.5420000000001,
          1455.4270000000001,
          1454.229,
          1452.9479999999999,
          1451.585,
          1450.142,
          1448.619,
          1447.017,
          1445.336,
          1443.578,
          1441.743,
          1439.8329999999999,
          1437.848,
          1435.7879999999998,
          1433.655,
          1431.4489999999998,
          1429.171,
          1426.8220000000001,
          1424.402,
          1421.912,
          1419.3529999999998,
          1416.726,
          1414.03,
          1411.2679999999998,
          1408.4389999999999,
          1405.5439999999999,
          1402.5829999999999,
          1399.558,
          1396.469,
          1393.317,
          1390.101,
          1386.8239999999998,
          1383.484,
          1380.0839999999998,
          1376.622,
          1373.101,
          1369.52,
          1365.88,
          1362.182,
          1358.4260000000002,
          1354.612,
          1350.741,
          1346.8139999999999,
          1342.8310000000001,
          1338.7920000000001,
          1334.6989999999998,
          1330.5510000000002,
          1326.348,
          1322.0929999999998,
          1317.7839999999999,
          1313.422,
          1309.008,
          1304.542,
          1300.025,
          1295.4569999999999,
          1290.838,
          1286.1689999999999,
          1281.45,
          1276.682,
          1271.865,
          1266.999,
          1262.086,
          1257.124,
          1252.115,
          1247.059,
          1241.9569999999999,
          1236.808,
          1231.613,
          1226.372,
          1221.087,
          1215.756,
          1210.381,
          1204.962,
          1199.498,
          1193.992,
          1188.442,
          1182.849,
          1177.214,
          1171.536,
          1165.817,
          1160.056,
          1154.254,
          1148.411,
          1142.527,
          1136.6019999999999,
          1130.638,
          1124.634,
          1118.5910000000001,
          1112.508,
          1106.386,
          1100.226,
          1094.027,
          1087.7910000000002,
          1081.516,
          1075.205,
          1068.856,
          1062.469,
          1056.047,
          1049.588,
          1043.0919999999999,
          1036.5610000000001,
          1029.995,
          1023.3919999999999,
          1016.755,
          1010.0830000000001,
          1003.3760000000001,
          996.635,
          989.86,
          983.051,
          976.209,
          969.3330000000001,
          962.424,
          955.482,
          948.507,
          941.5,
          934.461,
          927.39,
          920.2869999999999,
          913.153,
          905.987,
          898.791,
          891.564,
          884.306,
          877.018,
          869.7,
          862.352,
          854.9739999999999,
          847.567,
          840.1310000000001,
          832.665,
          825.171,
          817.6489999999999,
          810.0980000000001,
          802.5189999999999,
          794.913,
          787.278,
          779.6160000000001,
          771.928,
          764.212,
          756.4689999999999,
          748.7,
          740.904,
          733.082,
          725.235,
          717.3610000000001,
          709.4630000000001,
          701.539,
          693.59,
          685.6160000000001,
          677.618,
          669.595,
          661.548,
          653.477,
          645.383,
          637.265,
          629.124,
          620.9590000000001,
          612.7719999999999,
          604.563,
          596.331,
          588.077,
          579.8,
          571.503,
          563.183,
          554.8430000000001,
          546.482,
          538.099,
          529.697,
          521.274,
          512.831,
          504.36800000000005,
          495.88599999999997,
          487.384,
          478.86300000000006,
          470.324,
          461.765,
          453.189,
          444.594,
          435.98199999999997,
          427.352,
          418.705,
          410.04,
          401.35900000000004,
          392.662,
          383.94800000000004,
          375.218,
          366.473,
          357.712,
          348.93699999999995,
          340.14599999999996,
          331.341,
          322.522,
          313.689,
          304.842,
          295.982,
          287.10900000000004,
          278.223,
          269.32599999999996,
          260.416,
          251.49400000000003,
          242.562,
          233.618,
          224.66400000000002,
          215.7,
          206.725,
          197.74200000000002,
          188.74900000000002,
          179.748,
          170.738,
          161.721,
          152.696,
          143.664,
          134.625,
          125.58,
          116.53,
          107.47399999999999,
          98.414,
          89.34899999999999,
          80.281,
          71.209,
          62.13399999999999,
          53.058,
          43.979,
          34.9,
          25.82,
          16.739,
          7.66,
          -1.4180000000000001,
          -10.495,
          -19.569000000000003,
          -28.64,
          -37.707,
          -46.769,
          -55.826,
          -64.877,
          -73.922,
          -82.959,
          -91.98700000000001,
          -101.006,
          -110.016,
          -119.014,
          -128.001,
          -136.975,
          -145.935,
          -154.881,
          -163.81,
          -172.72299999999998,
          -181.61900000000003,
          -190.495,
          -199.351,
          -208.18599999999998,
          -216.998,
          -225.787,
          -234.55,
          -243.287,
          -251.99599999999998,
          -260.675,
          -269.324,
          -277.94,
          -286.52099999999996,
          -295.067,
          -303.57599999999996,
          -312.045,
          -320.472,
          -328.856,
          -337.195,
          -345.48699999999997,
          -353.728,
          -361.918,
          -370.05400000000003,
          -378.13199999999995,
          -386.151,
          -394.108,
          -402,
          -409.82300000000004,
          -417.57599999999996,
          -425.255,
          -432.856,
          -440.376,
          -447.811,
          -455.157,
          -462.411,
          -469.56800000000004,
          -476.624,
          -483.575,
          -490.414,
          -497.13800000000003,
          -503.74,
          -510.216,
          -516.56,
          -522.765,
          -528.8240000000001,
          -534.732,
          -540.48,
          -546.062,
          -551.4680000000001,
          -556.691,
          -561.722,
          -566.5509999999999,
          -571.168,
          -575.563,
          -579.724,
          -583.64,
          -587.299,
          -590.686,
          -593.789,
          -596.592,
          -599.0790000000001,
          -601.234,
          -603.039,
          -604.475,
          -605.5219999999999,
          -606.159,
          -606.363,
          -606.111,
          -605.377,
          -604.135,
          -602.356,
          -600.011,
          -597.067,
          -593.491,
          -589.249,
          -584.305,
          -578.62,
          -572.153,
          -564.865,
          -556.7130000000001,
          -547.6569999999999,
          -537.65,
          -526.6519999999999,
          -514.622,
          -501.519,
          -487.306,
          -471.95099999999996,
          -455.42699999999996,
          -437.712,
          -418.79400000000004,
          -398.67,
          -377.348,
          -354.848,
          -331.20599999999996,
          -306.467,
          -280.692,
          -253.957,
          -226.345,
          -197.953,
          -168.88299999999998,
          -139.246,
          -109.152,
          -78.71300000000001,
          -48.038000000000004,
          -17.230999999999998,
          13.609000000000002,
          44.391999999999996,
          75.036,
          105.46799999999999,
          135.623,
          165.446,
          194.89,
          223.917,
          252.493,
          280.593,
          308.198,
          335.292,
          361.866,
          387.911,
          413.425,
          438.407,
          462.85900000000004,
          486.784,
          510.18699999999995,
          533.073,
          555.451,
          577.328,
          598.714,
          619.616,
          639.9730000000001,
          660.01,
          679.5210000000001,
          698.5880000000001,
          717.221,
          735.428,
          753.221,
          770.6080000000001,
          787.6,
          804.205,
          820.432,
          836.29,
          851.788,
          866.934,
          881.7360000000001,
          896.203,
          910.341,
          924.159,
          937.664,
          950.863,
          963.762,
          976.3689999999999,
          988.69,
          1000.7310000000001,
          1012.498,
          1023.997,
          1035.234,
          1046.215,
          1056.944,
          1067.427,
          1077.6689999999999,
          1087.675,
          1097.45,
          1106.999,
          1116.325,
          1125.433,
          1134.328,
          1143.013,
          1151.492,
          1159.77,
          1167.849,
          1175.734,
          1183.4289999999999,
          1190.9360000000001,
          1198.259,
          1205.401,
          1212.366,
          1219.156,
          1225.774,
          1232.224,
          1238.508,
          1244.629,
          1250.589,
          1256.392,
          1262.04,
          1267.535,
          1272.879,
          1278.076,
          1283.127,
          1288.0339999999999,
          1292.8,
          1297.427,
          1301.917,
          1306.272,
          1310.494,
          1314.5839999999998,
          1318.545,
          1322.379,
          1326.088,
          1329.672,
          1333.135,
          1336.477,
          1339.7,
          1342.805,
          1345.796,
          1348.672,
          1351.435,
          1354.088,
          1356.63,
          1359.065,
          1361.392,
          1363.614,
          1365.7320000000002,
          1367.746,
          1369.6589999999999,
          1371.4720000000002,
          1373.185,
          1374.8,
          1376.318,
          1377.74,
          1379.068,
          1380.3020000000001,
          1381.443,
          1382.493,
          1383.453,
          1384.3229999999999,
          1385.105,
          1385.799,
          1386.4070000000002,
          1386.9289999999999,
          1387.3670000000002,
          1387.721,
          1387.9920000000002,
          1388.181,
          1388.289,
          1388.317,
          1388.265,
          1388.135,
          1387.9270000000001,
          1387.642,
          1387.28,
          1386.8429999999998,
          1386.332,
          1385.746,
          1385.0870000000002,
          1384.355,
          1383.5510000000002,
          1382.6760000000002,
          1381.73,
          1380.715,
          1379.63,
          1378.477,
          1377.255,
          1375.9660000000001,
          1374.611,
          1373.1889999999999,
          1371.7020000000002,
          1370.149,
          1368.5320000000002,
          1366.851,
          1365.1070000000002,
          1363.3,
          1361.431,
          1359.5,
          1357.5079999999998,
          1355.455,
          1353.342,
          1351.1689999999999,
          1348.9370000000001,
          1346.6470000000002,
          1344.2979999999998,
          1341.891,
          1339.4270000000001,
          1336.906,
          1334.328,
          1331.695,
          1329.006,
          1326.2620000000002,
          1323.463,
          1320.61,
          1317.703,
          1314.7420000000002,
          1311.729,
          1308.663,
          1305.5439999999999,
          1302.374,
          1299.152,
          1295.879,
          1292.556,
          1289.181,
          1285.757,
          1282.2830000000001,
          1278.76,
          1275.188,
          1271.567,
          1267.8980000000001,
          1264.181,
          1260.4160000000002,
          1256.603,
          1252.744,
          1248.838,
          1244.886,
          1240.888,
          1236.843,
          1232.754,
          1228.619,
          1224.4389999999999,
          1220.215,
          1215.9460000000001,
          1211.5410000000002,
          1207.184,
          1202.7839999999999,
          1198.3410000000001,
          1193.855,
          1189.326,
          1184.755,
          1180.142,
          1175.487,
          1170.79,
          1166.052,
          1161.2730000000001,
          1156.453,
          1151.5919999999999,
          1146.691,
          1141.75,
          1136.769,
          1131.748,
          1126.688,
          1121.589,
          1116.451,
          1111.2730000000001,
          1106.058,
          1100.8039999999999,
          1095.512,
          1090.182,
          1084.815,
          1079.41,
          1073.9669999999999,
          1068.488,
          1062.972,
          1057.4189999999999,
          1051.83,
          1046.205,
          1040.5439999999999,
          1034.846,
          1029.114,
          1023.345,
          1017.5419999999999,
          1011.704,
          1005.83,
          999.922,
          993.98,
          988.003,
          981.992,
          975.947,
          969.8689999999999,
          963.7560000000001,
          957.6110000000001,
          951.432,
          945.22,
          938.9760000000001,
          932.698,
          926.388,
          920.046,
          913.672,
          907.265,
          900.827,
          894.357,
          887.8560000000001,
          881.323,
          874.7589999999999,
          868.164,
          861.539,
          854.882,
          848.195,
          841.4780000000001,
          834.7310000000001,
          827.953,
          821.1460000000001,
          814.309,
          807.442,
          800.547,
          793.6210000000001,
          786.6669999999999,
          779.684,
          772.672,
          765.632,
          758.563,
          751.466,
          744.34,
          737.187,
          730.0060000000001,
          722.798,
          715.561,
          708.298,
          701.008,
          693.69,
          686.346,
          678.975,
          671.577,
          664.153,
          656.703,
          649.227,
          641.725,
          634.197,
          626.644,
          619.066,
          611.462,
          603.8340000000001,
          596.18,
          588.502,
          580.799,
          573.072,
          565.321,
          557.5459999999999,
          549.747,
          541.925,
          534.0790000000001,
          526.2090000000001,
          518.317,
          510.402,
          502.464,
          494.504,
          486.522,
          478.517,
          470.491,
          462.44199999999995,
          454.37300000000005,
          446.282,
          438.17,
          430.037,
          421.884,
          413.71,
          405.51599999999996,
          397.30300000000005,
          389.069,
          380.816,
          372.54400000000004,
          364.25300000000004,
          355.94300000000004,
          347.615,
          339.26800000000003,
          330.904,
          322.522,
          314.123,
          305.70599999999996,
          297.27299999999997,
          288.823,
          280.357,
          271.876,
          263.378,
          254.86599999999999,
          246.338,
          237.796,
          229.24,
          220.67,
          212.08700000000002,
          203.49,
          194.88099999999997,
          186.25900000000001,
          177.62599999999998,
          168.981,
          160.325,
          151.659,
          142.982,
          134.296,
          125.601,
          116.897,
          108.185,
          99.465,
          90.738,
          82.005,
          73.266,
          64.521,
          55.772,
          47.019,
          38.262,
          29.503,
          20.741,
          11.979000000000001,
          3.216,
          -5.547000000000001,
          -14.309000000000001,
          -23.069000000000003,
          -31.826,
          -40.579,
          -49.328,
          -58.071000000000005,
          -66.807,
          -75.536,
          -84.256,
          -92.96600000000001,
          -101.665,
          -110.352,
          -119.02600000000001,
          -127.684,
          -136.327,
          -144.951,
          -153.55700000000002,
          -162.142,
          -170.705,
          -179.243,
          -187.757,
          -196.24200000000002,
          -204.69799999999998,
          -213.123,
          -221.514,
          -229.87,
          -238.188,
          -246.465,
          -254.699,
          -262.888,
          -271.029,
          -279.119,
          -287.154,
          -295.133,
          -303.051,
          -310.904,
          -318.69,
          -326.405,
          -334.04400000000004,
          -341.603,
          -349.077,
          -356.463,
          -363.754,
          -370.94599999999997,
          -378.033,
          -385.009,
          -391.86699999999996,
          -398.603,
          -405.207,
          -411.673,
          -417.994,
          -424.16,
          -430.164,
          -435.995,
          -441.645,
          -447.101,
          -452.35400000000004,
          -457.39099999999996,
          -462.2,
          -466.76599999999996,
          -471.077,
          -475.116,
          -478.86699999999996,
          -482.314,
          -485.43699999999995,
          -488.217,
          -490.63300000000004,
          -492.663,
          -494.283,
          -495.467,
          -496.19,
          -496.42199999999997,
          -496.13300000000004,
          -495.291,
          -493.86400000000003,
          -491.816,
          -489.10900000000004,
          -485.705,
          -481.564,
          -476.645,
          -470.906,
          -464.305,
          -456.79900000000004,
          -448.348,
          -438.912,
          -428.452,
          -416.93699999999995,
          -404.339,
          -390.635,
          -375.811,
          -359.86400000000003,
          -342.79900000000004,
          -324.632,
          -305.395,
          -285.129,
          -263.887,
          -241.735,
          -218.75,
          -195.015,
          -170.62099999999998,
          -145.662,
          -120.23700000000001,
          -94.44,
          -68.365,
          -42.103,
          -15.738,
          10.652999999999999,
          37,
          63.238,
          89.31299999999999,
          115.175,
          140.784,
          166.10299999999998,
          191.10299999999998,
          215.76,
          240.055,
          263.972,
          287.499,
          310.629,
          333.35400000000004,
          355.67199999999997,
          377.582,
          399.082,
          420.176,
          440.866,
          461.156,
          481.05,
          500.55300000000005,
          519.672,
          538.41,
          556.7769999999999,
          574.7769999999999,
          592.418,
          609.706,
          626.648,
          643.252,
          659.523,
          675.4689999999999,
          691.096,
          706.4110000000001,
          721.421,
          736.1310000000001,
          750.548,
          764.678,
          778.5269999999999,
          792.102,
          805.4069999999999,
          818.448,
          831.2310000000001,
          843.7610000000001,
          856.043,
          868.082,
          879.883,
          891.451,
          902.79,
          913.904,
          924.799,
          935.4780000000001,
          945.945,
          956.205,
          966.2610000000001,
          976.118,
          985.778,
          995.2460000000001,
          1004.5239999999999,
          1013.617,
          1022.5269999999999,
          1031.258,
          1039.813,
          1048.195,
          1056.406,
          1064.45,
          1072.329,
          1080.047,
          1087.605,
          1095.007,
          1102.255,
          1109.351,
          1116.298,
          1123.098,
          1129.753,
          1136.266,
          1142.639,
          1148.873,
          1154.971,
          1160.935,
          1166.767,
          1172.469,
          1178.042,
          1183.488,
          1188.81,
          1194.008,
          1199.085,
          1204.042,
          1208.881,
          1213.603,
          1218.21,
          1222.703,
          1227.085,
          1231.355,
          1235.517,
          1239.57,
          1243.517,
          1247.359,
          1251.096,
          1254.732,
          1258.265,
          1261.6989999999998,
          1265.0330000000001,
          1268.269,
          1271.4089999999999,
          1274.453,
          1277.402,
          1280.258,
          1283.022,
          1285.694,
          1288.275,
          1290.768,
          1293.171,
          1295.488,
          1297.7169999999999,
          1299.861,
          1301.921,
          1303.896,
          1305.788,
          1307.598,
          1309.327,
          1310.975,
          1312.5439999999999,
          1314.033,
          1315.444,
          1316.7779999999998,
          1318.035,
          1319.2160000000001,
          1320.3220000000001,
          1321.3529999999998,
          1322.31,
          1323.194,
          1324.006,
          1324.746,
          1325.414,
          1326.0120000000002,
          1326.54,
          1326.9979999999998,
          1327.388,
          1327.71,
          1327.964,
          1328.151,
          1328.271,
          1328.326,
          1328.315,
          1328.24,
          1328.1,
          1327.896,
          1327.63,
          1327.3,
          1326.908,
          1326.454,
          1325.94,
          1325.364,
          1324.7279999999998,
          1324.031,
          1323.276,
          1322.461,
          1321.588,
          1320.6570000000002,
          1319.668,
          1318.621,
          1317.5179999999998,
          1316.358,
          1315.1429999999998,
          1313.871,
          1312.5439999999999,
          1311.162,
          1309.726,
          1308.235,
          1306.69,
          1305.0919999999999,
          1303.441,
          1301.737,
          1299.981,
          1298.172,
          1296.312,
          1294.4,
          1292.438,
          1290.424,
          1288.36,
          1286.245,
          1284.0810000000001,
          1281.867,
          1279.604,
          1277.292,
          1274.931,
          1272.522,
          1270.0639999999999,
          1267.559,
          1265.006,
          1262.406,
          1259.759,
          1257.065,
          1254.3239999999998,
          1251.537,
          1248.705,
          1245.826,
          1242.902,
          1239.932,
          1236.9180000000001,
          1233.858,
          1230.754,
          1227.606,
          1224.414,
          1221.177,
          1217.897,
          1214.5739999999998,
          1211.2069999999999,
          1207.797,
          1204.344,
          1200.849,
          1197.3110000000001,
          1193.731,
          1190.109,
          1186.445,
          1182.74,
          1178.993,
          1175.205,
          1171.375,
          1167.505,
          1163.594,
          1159.643,
          1155.651,
          1151.619,
          1147.547,
          1143.435,
          1139.2830000000001,
          1135.0919999999999,
          1130.862,
          1126.5919999999999,
          1122.2830000000001,
          1117.9360000000001,
          1113.55,
          1109.125,
          1104.661,
          1100.16,
          1095.62,
          1091.0430000000001,
          1086.427,
          1081.774,
          1077.083,
          1072.355,
          1067.59,
          1062.787,
          1057.948,
          1053.072,
          1048.1589999999999,
          1043.2089999999998,
          1038.223,
          1033.2,
          1028.142,
          1023.047,
          1017.916,
          1012.75,
          1007.547,
          1002.309,
          997.0360000000001,
          991.727,
          986.383,
          981.0039999999999,
          975.59,
          970.14,
          964.6560000000001,
          959.138,
          953.584,
          947.997,
          942.3739999999999,
          936.7180000000001,
          931.0269999999999,
          925.303,
          919.544,
          913.752,
          907.925,
          902.065,
          896.172,
          890.245,
          884.285,
          878.291,
          872.2639999999999,
          866.205,
          860.112,
          853.9860000000001,
          847.828,
          841.6360000000001,
          835.413,
          829.1560000000001,
          822.868,
          816.546,
          810.193,
          803.808,
          797.39,
          790.941,
          784.46,
          777.947,
          771.4019999999999,
          764.825,
          758.2180000000001,
          751.578,
          744.908,
          738.206,
          731.4730000000001,
          724.709,
          717.914,
          711.0880000000001,
          704.2310000000001,
          697.3439999999999,
          690.426,
          683.4780000000001,
          676.4989999999999,
          669.49,
          662.45,
          655.3810000000001,
          648.281,
          641.1519999999999,
          633.993,
          626.804,
          619.585,
          612.337,
          605.06,
          597.753,
          590.4169999999999,
          583.052,
          575.658,
          568.235,
          560.783,
          553.303,
          545.794,
          538.257,
          530.691,
          523.097,
          515.476,
          507.82599999999996,
          500.149,
          492.44300000000004,
          484.711,
          476.95099999999996,
          469.164,
          461.35,
          453.509,
          445.64099999999996,
          437.746,
          429.82599999999996,
          421.87800000000004,
          413.905,
          405.906,
          397.881,
          389.83099999999996,
          381.756,
          373.655,
          365.529,
          357.379,
          349.204,
          341.005,
          332.782,
          324.535,
          316.265,
          307.971,
          299.655,
          291.316,
          282.954,
          274.57,
          266.165,
          257.738,
          249.29,
          240.821,
          232.332,
          223.82299999999998,
          215.294,
          206.74599999999998,
          198.179,
          189.59400000000002,
          180.99099999999999,
          172.37,
          163.733,
          155.079,
          146.409,
          137.724,
          129.024,
          120.31,
          111.583,
          102.84299999999999,
          94.09,
          85.32700000000001,
          76.55199999999999,
          67.768,
          58.975,
          50.173,
          41.365,
          32.55,
          23.73,
          14.905,
          6.077999999999999,
          -2.752,
          -11.583,
          -20.413,
          -29.241,
          -38.067,
          -46.887,
          -55.702,
          -64.509,
          -73.306,
          -82.09299999999999,
          -90.866,
          -99.624,
          -108.366,
          -117.088,
          -125.788,
          -134.465,
          -143.114,
          -151.735,
          -160.32299999999998,
          -168.877,
          -177.391,
          -185.864,
          -194.292,
          -202.671,
          -210.99599999999998,
          -219.264,
          -227.46900000000002,
          -235.608,
          -243.675,
          -251.66400000000002,
          -259.57,
          -267.387,
          -275.108,
          -282.725,
          -290.232,
          -297.621,
          -304.882,
          -312.007,
          -318.986,
          -325.809,
          -332.465,
          -338.941,
          -345.226,
          -351.30400000000003,
          -357.163,
          -362.785,
          -368.155,
          -373.254,
          -378.06300000000005,
          -382.561,
          -386.727,
          -390.535,
          -393.963,
          -396.981,
          -399.56199999999995,
          -401.676,
          -403.289,
          -404.36800000000005,
          -404.875,
          -404.774,
          -404.024,
          -402.586,
          -400.417,
          -397.473,
          -393.712,
          -389.093,
          -383.574,
          -377.116,
          -369.684,
          -361.246,
          -351.779,
          -341.26599999999996,
          -329.69699999999995,
          -317.073,
          -303.406,
          -288.719,
          -273.046,
          -256.432,
          -238.933,
          -220.614,
          -201.547,
          -181.80900000000003,
          -161.482,
          -140.65,
          -119.39399999999999,
          -97.79700000000001,
          -75.935,
          -53.881,
          -31.703000000000003,
          -9.463,
          12.784,
          34.986999999999995,
          57.102,
          79.09100000000001,
          100.921,
          122.56299999999999,
          143.99200000000002,
          165.18900000000002,
          186.137,
          206.82299999999998,
          227.235,
          247.365,
          267.207,
          286.756,
          306.01,
          324.966,
          343.624,
          361.98400000000004,
          380.048,
          397.816,
          415.292,
          432.478,
          449.37699999999995,
          465.994,
          482.33099999999996,
          498.39300000000003,
          514.183,
          529.707,
          544.9680000000001,
          559.97,
          574.7180000000001,
          589.216,
          603.469,
          617.48,
          631.254,
          644.795,
          658.1080000000001,
          671.196,
          684.063,
          696.7139999999999,
          709.1519999999999,
          721.3810000000001,
          733.405,
          745.227,
          756.8510000000001,
          768.2810000000001,
          779.5189999999999,
          790.569,
          801.435,
          812.1189999999999,
          822.6239999999999,
          832.954,
          843.1110000000001,
          853.0989999999999,
          862.92,
          872.577,
          882.072,
          891.408,
          900.5880000000001,
          909.6139999999999,
          918.4889999999999,
          927.2139999999999,
          935.7919999999999,
          944.2260000000001,
          952.518,
          960.669,
          968.682,
          976.558,
          984.301,
          991.9110000000001,
          999.39,
          1006.7410000000001,
          1013.965,
          1021.064,
          1028.039,
          1034.893,
          1041.627,
          1048.242,
          1054.74,
          1061.123,
          1067.392,
          1073.549,
          1079.595,
          1085.531,
          1091.358,
          1097.079,
          1102.695,
          1108.205,
          1113.613,
          1118.9189999999999,
          1124.124,
          1129.23,
          1134.237,
          1139.147,
          1143.961,
          1148.68,
          1153.3039999999999,
          1157.836,
          1162.276,
          1166.625,
          1170.883,
          1175.053,
          1179.134,
          1183.128,
          1187.036,
          1190.859,
          1194.597,
          1198.251,
          1201.822,
          1205.3110000000001,
          1208.718,
          1212.046,
          1215.2930000000001,
          1218.461,
          1221.552,
          1224.5639999999999,
          1227.5,
          1230.36,
          1233.144,
          1235.853,
          1238.488,
          1241.05,
          1243.539,
          1245.9560000000001,
          1248.3010000000002,
          1250.576,
          1252.78,
          1254.914,
          1256.979,
          1258.975,
          1260.903,
          1262.763,
          1264.557,
          1266.2839999999999,
          1267.945,
          1269.5410000000002,
          1271.0710000000001,
          1272.537,
          1273.9389999999999,
          1275.278,
          1276.553,
          1277.766,
          1278.917,
          1280.006,
          1281.0330000000001,
          1282,
          1282.907,
          1283.753,
          1284.54,
          1285.268,
          1285.9360000000001,
          1286.547,
          1287.099,
          1287.594,
          1288.032,
          1288.412,
          1288.736,
          1289.004,
          1289.2160000000001,
          1289.372,
          1289.474,
          1289.52,
          1289.512,
          1289.45,
          1289.3339999999998,
          1289.164,
          1288.941,
          1288.6660000000002,
          1288.337,
          1287.9560000000001,
          1287.5230000000001,
          1287.039,
          1286.502,
          1285.915,
          1285.276,
          1284.587,
          1283.848,
          1283.058,
          1282.218,
          1281.329,
          1280.39,
          1279.402,
          1278.365,
          1277.28,
          1276.146,
          1274.964,
          1273.733,
          1272.455,
          1271.129,
          1269.756,
          1268.336,
          1266.869,
          1265.355,
          1263.795,
          1262.188,
          1260.535,
          1258.836,
          1257.0910000000001,
          1255.3010000000002,
          1253.465,
          1251.5839999999998,
          1249.6580000000001,
          1247.687,
          1245.672,
          1243.612,
          1241.507,
          1239.359,
          1237.1660000000002,
          1234.9289999999999,
          1232.649,
          1230.325,
          1227.958,
          1225.547,
          1223.093,
          1220.596,
          1218.057,
          1215.474,
          1212.849,
          1210.182,
          1207.472,
          1204.72,
          1201.9260000000002,
          1199.09,
          1196.213,
          1193.2930000000001,
          1190.3319999999999,
          1187.33,
          1184.286,
          1181.201,
          1178.075,
          1174.9080000000001,
          1171.7,
          1168.451,
          1165.161,
          1161.8310000000001,
          1158.46,
          1155.049,
          1151.598,
          1148.106,
          1144.575,
          1141.003,
          1137.391,
          1133.739,
          1130.048,
          1126.317,
          1122.546,
          1118.736,
          1114.886,
          1110.997,
          1107.068,
          1103.1,
          1099.093,
          1095.047,
          1090.962,
          1086.838,
          1082.675,
          1078.473,
          1074.232,
          1069.953,
          1065.635,
          1061.278,
          1056.883,
          1052.4489999999998,
          1047.976,
          1043.4660000000001,
          1038.9160000000002,
          1034.329,
          1029.703,
          1025.039,
          1020.337,
          1015.597,
          1010.818,
          1006.002,
          1001.1469999999999,
          996.255,
          991.324,
          986.3560000000001,
          981.3489999999999,
          976.305,
          971.2230000000001,
          966.1030000000001,
          960.946,
          955.75,
          950.5169999999999,
          945.2460000000001,
          939.938,
          934.592,
          929.2080000000001,
          923.7860000000001,
          918.327,
          912.831,
          907.297,
          901.725,
          896.1160000000001,
          890.4689999999999,
          884.785,
          879.063,
          873.303,
          867.507,
          861.672,
          855.801,
          849.8919999999999,
          843.945,
          837.961,
          831.94,
          825.8810000000001,
          819.784,
          813.65,
          807.4789999999999,
          801.2710000000001,
          795.025,
          788.7410000000001,
          782.42,
          776.062,
          769.6669999999999,
          763.2330000000001,
          756.763,
          750.255,
          743.71,
          737.127,
          730.507,
          723.8489999999999,
          717.154,
          710.422,
          703.6519999999999,
          696.845,
          690,
          683.118,
          676.199,
          669.242,
          662.248,
          655.216,
          648.1469999999999,
          641.04,
          633.896,
          626.715,
          619.496,
          612.24,
          604.947,
          597.616,
          590.248,
          582.842,
          575.399,
          567.919,
          560.4019999999999,
          552.847,
          545.255,
          537.626,
          529.9590000000001,
          522.256,
          514.515,
          506.73699999999997,
          498.923,
          491.07099999999997,
          483.18199999999996,
          475.25699999999995,
          467.29400000000004,
          459.295,
          451.259,
          443.18699999999995,
          435.07800000000003,
          426.93300000000005,
          418.751,
          410.533,
          402.279,
          393.98900000000003,
          385.663,
          377.30199999999996,
          368.904,
          360.472,
          352.004,
          343.501,
          334.963,
          326.39,
          317.783,
          309.142,
          300.466,
          291.757,
          283.015,
          274.23900000000003,
          265.431,
          256.59,
          247.717,
          238.812,
          229.87599999999998,
          220.90900000000002,
          211.912,
          202.88400000000001,
          193.828,
          184.74200000000002,
          175.62900000000002,
          166.487,
          157.319,
          148.125,
          138.905,
          129.661,
          120.39299999999999,
          111.102,
          101.789,
          92.456,
          83.103,
          73.73100000000001,
          64.343,
          54.938,
          45.519,
          36.088,
          26.645,
          17.192999999999998,
          7.733,
          -1.733,
          -11.202,
          -20.671999999999997,
          -30.141,
          -39.606,
          -49.06399999999999,
          -58.513000000000005,
          -67.94800000000001,
          -77.368,
          -86.76700000000001,
          -96.14299999999999,
          -105.491,
          -114.806,
          -124.083,
          -133.31799999999998,
          -142.504,
          -151.636,
          -160.707,
          -169.71,
          -178.638,
          -187.482,
          -196.234,
          -204.88400000000001,
          -213.422,
          -221.83599999999998,
          -230.11599999999999,
          -238.248,
          -246.21900000000002,
          -254.013,
          -261.613,
          -269.003,
          -276.164,
          -283.075,
          -289.714,
          -296.057,
          -302.079,
          -307.753,
          -313.048,
          -317.934,
          -322.377,
          -326.341,
          -329.787,
          -332.67699999999996,
          -334.969,
          -336.62,
          -337.585,
          -337.82,
          -337.279,
          -335.91900000000004,
          -333.69699999999995,
          -330.574,
          -326.515,
          -321.48900000000003,
          -315.473,
          -308.452,
          -300.42,
          -291.379,
          -281.345,
          -270.344,
          -258.408,
          -245.584,
          -231.926,
          -217.49200000000002,
          -202.34900000000002,
          -186.567,
          -170.21599999999998,
          -153.369,
          -136.095,
          -118.463,
          -100.536,
          -82.376,
          -64.03699999999999,
          -45.571999999999996,
          -27.026,
          -8.44,
          10.147,
          28.703000000000003,
          47.2,
          65.613,
          83.919,
          102.101,
          120.14200000000001,
          138.029,
          155.75,
          173.297,
          190.66,
          207.835,
          224.815,
          241.59799999999998,
          258.17900000000003,
          274.607,
          290.73,
          306.699,
          322.462,
          338.019,
          353.37199999999996,
          368.522,
          383.469,
          398.216,
          412.764,
          427.11400000000003,
          441.269,
          455.231,
          469.00300000000004,
          482.586,
          495.98199999999997,
          509.195,
          522.226,
          535.0790000000001,
          547.754,
          560.256,
          572.586,
          584.746,
          596.74,
          608.569,
          620.236,
          631.743,
          643.092,
          654.2869999999999,
          665.328,
          676.2180000000001,
          686.959,
          697.553,
          708.003,
          718.31,
          728.477,
          738.5039999999999,
          748.3960000000001,
          758.1519999999999,
          767.775,
          777.2669999999999,
          786.63,
          795.865,
          804.9739999999999,
          813.9580000000001,
          822.82,
          831.561,
          840.182,
          848.685,
          857.072,
          865.3430000000001,
          873.5010000000001,
          881.547,
          889.482,
          897.307,
          905.0239999999999,
          912.6339999999999,
          920.138,
          927.538,
          934.835,
          942.03,
          949.1239999999999,
          956.118,
          963.013,
          969.811,
          976.512,
          983.118,
          989.63,
          996.048,
          1002.3739999999999,
          1008.6089999999999,
          1014.753,
          1020.807,
          1026.7730000000001,
          1032.651,
          1038.442,
          1044.147,
          1049.767,
          1055.302,
          1060.754,
          1066.124,
          1071.411,
          1076.617,
          1081.743,
          1086.788,
          1091.755,
          1096.644,
          1101.455,
          1106.1889999999999,
          1110.847,
          1115.4289999999999,
          1119.9360000000001,
          1124.369,
          1128.728,
          1133.015,
          1137.228,
          1141.37,
          1145.44,
          1149.44,
          1153.37,
          1157.229,
          1161.02,
          1164.742,
          1168.396,
          1171.983,
          1175.502,
          1178.955,
          1182.3410000000001,
          1185.662,
          1188.9180000000001,
          1192.109,
          1195.236,
          1198.3,
          1201.299,
          1204.236,
          1207.111,
          1209.923,
          1212.674,
          1215.363,
          1217.991,
          1220.559,
          1223.067,
          1225.515,
          1227.903,
          1230.233,
          1232.504,
          1234.7160000000001,
          1236.871,
          1238.968,
          1241.007,
          1242.99,
          1244.9160000000002,
          1246.785,
          1248.599,
          1250.357,
          1252.059,
          1253.7060000000001,
          1255.298,
          1256.836,
          1258.319,
          1259.749,
          1261.124,
          1262.4460000000001,
          1263.715,
          1264.931,
          1266.094,
          1267.205,
          1268.263,
          1269.27,
          1270.225,
          1271.128,
          1271.98,
          1272.78,
          1273.53,
          1274.23,
          1274.879,
          1275.4769999999999,
          1276.026,
          1276.525,
          1276.974,
          1277.374,
          1277.725,
          1278.026,
          1278.279,
          1278.483,
          1278.639,
          1278.746,
          1278.805,
          1278.816,
          1278.78,
          1278.695,
          1278.5639999999999,
          1278.384,
          1278.1580000000001,
          1277.885,
          1277.565,
          1277.198,
          1276.7839999999999,
          1276.3239999999998,
          1275.818,
          1275.265,
          1274.667,
          1274.022,
          1273.3319999999999,
          1272.596,
          1271.8139999999999,
          1270.987,
          1270.115,
          1269.197,
          1268.235,
          1267.2269999999999,
          1266.174,
          1265.077,
          1263.935,
          1262.748,
          1261.517,
          1260.242,
          1258.922,
          1257.558,
          1256.149,
          1254.697,
          1253.201,
          1251.66,
          1250.076,
          1248.448,
          1246.777,
          1245.062,
          1243.303,
          1241.501,
          1239.656,
          1237.767,
          1235.8339999999998,
          1233.859,
          1231.84,
          1229.779,
          1227.674,
          1225.526,
          1223.335,
          1221.101,
          1218.825,
          1216.505,
          1214.143,
          1211.738,
          1209.29,
          1206.799,
          1204.266,
          1201.69,
          1199.0710000000001,
          1196.41,
          1193.7060000000001,
          1190.96,
          1188.171,
          1185.34,
          1182.4660000000001,
          1179.55,
          1176.5910000000001,
          1173.589,
          1170.546,
          1167.4589999999998,
          1164.3310000000001,
          1161.16,
          1157.9460000000001,
          1154.69,
          1151.391,
          1148.05,
          1144.667,
          1141.241,
          1137.7730000000001,
          1134.262,
          1130.708,
          1127.112,
          1123.474,
          1119.7930000000001,
          1116.069,
          1112.303,
          1108.494,
          1104.642,
          1100.748,
          1096.8110000000001,
          1092.8310000000001,
          1088.809,
          1084.743,
          1080.635,
          1076.484,
          1072.289,
          1068.052,
          1063.772,
          1059.448,
          1055.0819999999999,
          1050.672,
          1046.219,
          1041.723,
          1037.183,
          1032.6,
          1027.973,
          1023.303,
          1018.5889999999999,
          1013.831,
          1009.03,
          1004.185,
          999.295,
          994.362,
          989.385,
          984.3639999999999,
          979.298,
          974.188,
          969.034,
          963.835,
          958.592,
          953.304,
          947.971,
          942.5939999999999,
          937.171,
          931.704,
          926.191,
          920.633,
          915.03,
          909.3810000000001,
          903.687,
          897.947,
          892.1610000000001,
          886.33,
          880.452,
          874.528,
          868.558,
          862.5419999999999,
          856.4789999999999,
          850.37,
          844.2139999999999,
          838.0110000000001,
          831.7610000000001,
          825.4639999999999,
          819.1189999999999,
          812.7280000000001,
          806.288,
          799.801,
          793.2669999999999,
          786.684,
          780.053,
          773.3739999999999,
          766.6469999999999,
          759.8710000000001,
          753.046,
          746.173,
          739.25,
          732.279,
          725.258,
          718.188,
          711.068,
          703.898,
          696.679,
          689.409,
          682.0889999999999,
          674.7189999999999,
          667.298,
          659.827,
          652.304,
          644.731,
          637.106,
          629.43,
          621.703,
          613.923,
          606.092,
          598.2090000000001,
          590.274,
          582.286,
          574.246,
          566.154,
          558.008,
          549.81,
          541.558,
          533.254,
          524.895,
          516.484,
          508.019,
          499.5,
          490.92699999999996,
          482.3,
          473.619,
          464.88300000000004,
          456.094,
          447.25,
          438.351,
          429.399,
          420.39099999999996,
          411.329,
          402.212,
          393.041,
          383.814,
          374.534,
          365.19800000000004,
          355.80800000000005,
          346.36300000000006,
          336.86400000000003,
          327.311,
          317.704,
          308.04200000000003,
          298.327,
          288.559,
          278.737,
          268.862,
          258.935,
          248.955,
          238.924,
          228.842,
          218.709,
          208.52599999999998,
          198.294,
          188.014,
          177.68599999999998,
          167.31099999999998,
          156.891,
          146.42600000000002,
          135.918,
          125.369,
          114.779,
          104.15,
          93.485,
          82.786,
          72.053,
          61.291000000000004,
          50.501000000000005,
          39.687,
          28.851,
          17.997,
          7.127999999999999,
          -3.75,
          -14.634,
          -25.519000000000002,
          -36.399,
          -47.269,
          -58.123000000000005,
          -68.952,
          -79.75,
          -90.508,
          -101.21700000000001,
          -111.867,
          -122.447,
          -132.945,
          -143.34799999999998,
          -153.641,
          -163.809,
          -173.835,
          -183.7,
          -193.38299999999998,
          -202.861,
          -212.112,
          -221.108,
          -229.82,
          -238.21900000000002,
          -246.269,
          -253.935,
          -261.17900000000003,
          -267.959,
          -274.233,
          -279.954,
          -285.075,
          -289.54900000000004,
          -293.32599999999996,
          -296.355,
          -298.591,
          -299.986,
          -300.498,
          -300.089,
          -298.728,
          -296.39099999999996,
          -293.063,
          -288.737,
          -283.418,
          -277.12,
          -269.869,
          -261.698,
          -252.649,
          -242.773,
          -232.125,
          -220.764,
          -208.752,
          -196.15,
          -183.023,
          -169.43,
          -155.431,
          -141.08,
          -126.43,
          -111.52799999999999,
          -96.421,
          -81.14699999999999,
          -65.745,
          -50.248000000000005,
          -34.684,
          -19.082,
          -3.464,
          12.147,
          27.734,
          43.281000000000006,
          58.772,
          74.195,
          89.54,
          104.796,
          119.956,
          135.013,
          149.96,
          164.792,
          179.50400000000002,
          194.09400000000002,
          208.558,
          222.894,
          237.1,
          251.173,
          265.113,
          278.91900000000004,
          292.59,
          306.127,
          319.528,
          332.79400000000004,
          345.925,
          358.92199999999997,
          371.784,
          384.514,
          397.111,
          409.57599999999996,
          421.91,
          434.115,
          446.191,
          458.139,
          469.96,
          481.656,
          493.227,
          504.675,
          516.001,
          527.205,
          538.29,
          549.257,
          560.106,
          570.839,
          581.456,
          591.96,
          602.352,
          612.631,
          622.8009999999999,
          632.861,
          642.813,
          652.658,
          662.398,
          672.033,
          681.564,
          690.992,
          700.319,
          709.545,
          718.672,
          727.701,
          736.632,
          745.466,
          754.205,
          762.8489999999999,
          771.4,
          779.8580000000001,
          788.2239999999999,
          796.4989999999999,
          804.684,
          812.78,
          820.7869999999999,
          828.707,
          836.54,
          844.2869999999999,
          851.949,
          859.5260000000001,
          867.02,
          874.431,
          881.76,
          889.007,
          896.174,
          903.26,
          910.2669999999999,
          917.196,
          924.046,
          930.819,
          937.515,
          944.135,
          950.679,
          957.1489999999999,
          963.544,
          969.8660000000001,
          976.1139999999999,
          982.29,
          988.393,
          994.426,
          1000.387,
          1006.278,
          1012.0980000000001,
          1017.85,
          1023.5319999999999,
          1029.146,
          1034.692,
          1040.171,
          1045.5819999999999,
          1050.927,
          1056.2060000000001,
          1061.4189999999999,
          1066.567,
          1071.65,
          1076.6680000000001,
          1081.623,
          1086.514,
          1091.3419999999999,
          1096.107,
          1100.81,
          1105.45,
          1110.029,
          1114.547,
          1119.003,
          1123.399,
          1127.735,
          1132.011,
          1136.2269999999999,
          1140.384,
          1144.482,
          1148.522,
          1152.503,
          1156.4260000000002,
          1160.2910000000002,
          1164.099,
          1167.85,
          1171.5439999999999,
          1175.182,
          1178.763,
          1182.288,
          1185.758,
          1189.172,
          1192.53,
          1195.8339999999998,
          1199.083,
          1202.278,
          1205.4180000000001,
          1208.504,
          1211.537,
          1214.516,
          1217.442,
          1220.3139999999999,
          1223.134,
          1225.901,
          1228.615,
          1231.277,
          1233.887,
          1236.4460000000001,
          1238.952,
          1241.407,
          1243.8110000000001,
          1246.164,
          1248.465,
          1250.7160000000001,
          1252.9160000000002,
          1255.066,
          1257.1660000000002,
          1259.215,
          1261.214,
          1263.164,
          1265.0639999999999,
          1266.914,
          1268.715,
          1270.4669999999999,
          1272.1689999999999,
          1273.823,
          1275.428,
          1276.984,
          1278.492,
          1279.951,
          1281.362,
          1282.724,
          1284.039,
          1285.305,
          1286.524,
          1287.694,
          1288.817,
          1289.893,
          1290.921,
          1291.902,
          1292.835,
          1293.721,
          1294.56,
          1295.3519999999999,
          1296.097,
          1296.796,
          1297.447,
          1298.052,
          1298.61,
          1299.122,
          1299.587,
          1300.005,
          1300.378,
          1300.704,
          1300.983,
          1301.2169999999999,
          1301.404,
          1301.545,
          1301.641,
          1301.69,
          1301.693,
          1301.651,
          1301.562,
          1301.428,
          1301.248,
          1301.022,
          1300.751,
          1300.433,
          1300.0710000000001,
          1299.662,
          1299.208,
          1298.708,
          1298.163,
          1297.572,
          1296.935,
          1296.253,
          1295.525,
          1294.752,
          1293.933,
          1293.069,
          1292.1589999999999,
          1291.204,
          1290.203,
          1289.156,
          1288.0639999999999,
          1286.927,
          1285.744,
          1284.515,
          1283.24,
          1281.92,
          1280.555,
          1279.143,
          1277.6860000000001,
          1276.183,
          1274.635,
          1273.04,
          1271.4,
          1269.714,
          1267.982,
          1266.204,
          1264.379,
          1262.509,
          1260.593,
          1258.631,
          1256.622,
          1254.567,
          1252.4660000000001,
          1250.318,
          1248.124,
          1245.883,
          1243.596,
          1241.262,
          1238.882,
          1236.454,
          1233.98,
          1231.4589999999998,
          1228.89,
          1226.275,
          1223.612,
          1220.902,
          1218.145,
          1215.34,
          1212.488,
          1209.588,
          1206.64,
          1203.644,
          1200.6,
          1197.508,
          1194.368,
          1191.18,
          1187.943,
          1184.657,
          1181.323,
          1177.94,
          1174.508,
          1171.027,
          1167.497,
          1163.917,
          1160.288,
          1156.61,
          1152.881,
          1149.103,
          1145.275,
          1141.396,
          1137.4669999999999,
          1133.488,
          1129.4569999999999,
          1125.376,
          1121.244,
          1117.0610000000001,
          1112.826,
          1108.54,
          1104.202,
          1099.812,
          1095.37,
          1090.875,
          1086.328,
          1081.729,
          1077.076,
          1072.371,
          1067.612,
          1062.799,
          1057.933,
          1053.013,
          1048.039,
          1043.01,
          1037.927,
          1032.788,
          1027.595,
          1022.346,
          1017.0419999999999,
          1011.682,
          1006.2660000000001,
          1000.793,
          995.2639999999999,
          989.678,
          984.035,
          978.334,
          972.576,
          966.76,
          960.885,
          954.952,
          948.96,
          942.909,
          936.798,
          930.628,
          924.3969999999999,
          918.107,
          911.755,
          905.342,
          898.8689999999999,
          892.3330000000001,
          885.735,
          879.075,
          872.352,
          865.566,
          858.717,
          851.803,
          844.826,
          837.784,
          830.677,
          823.5039999999999,
          816.2660000000001,
          808.962,
          801.591,
          794.154,
          786.648,
          779.076,
          771.435,
          763.725,
          755.946,
          748.0980000000001,
          740.18,
          732.191,
          724.132,
          716.0010000000001,
          707.798,
          699.5239999999999,
          691.176,
          682.7560000000001,
          674.2610000000001,
          665.693,
          657.05,
          648.332,
          639.538,
          630.668,
          621.721,
          612.698,
          603.597,
          594.418,
          585.16,
          575.823,
          566.406,
          556.909,
          547.332,
          537.674,
          527.934,
          518.112,
          508.207,
          498.22,
          488.148,
          477.99300000000005,
          467.754,
          457.42900000000003,
          447.02,
          436.524,
          425.94300000000004,
          415.275,
          404.52099999999996,
          393.67900000000003,
          382.75,
          371.73400000000004,
          360.63,
          349.43800000000005,
          338.158,
          326.79,
          315.335,
          303.791,
          292.16,
          280.441,
          268.635,
          256.743,
          244.765,
          232.701,
          220.553,
          208.321,
          196.00799999999998,
          183.613,
          171.14,
          158.589,
          145.963,
          133.264,
          120.495,
          107.66,
          94.76100000000001,
          81.803,
          68.79,
          55.728,
          42.621,
          29.478,
          16.303,
          3.1069999999999998,
          -10.103,
          -23.316,
          -36.522,
          -49.707,
          -62.857,
          -75.959,
          -88.993,
          -101.94200000000001,
          -114.78299999999999,
          -127.495,
          -140.05,
          -152.421,
          -164.576,
          -176.482,
          -188.101,
          -199.392,
          -210.31400000000002,
          -220.81900000000002,
          -230.857,
          -240.37599999999998,
          -249.32299999999998,
          -257.642,
          -265.276,
          -272.168,
          -278.264,
          -283.512,
          -287.865,
          -291.281,
          -293.726,
          -295.172,
          -295.60400000000004,
          -295.015,
          -293.411,
          -290.80400000000003,
          -287.22,
          -282.692,
          -277.259,
          -270.969,
          -263.874,
          -256.029,
          -247.488,
          -238.31099999999998,
          -228.55200000000002,
          -218.268,
          -207.51,
          -196.328,
          -184.771,
          -172.88299999999998,
          -160.704,
          -148.27200000000002,
          -135.623,
          -122.787,
          -109.794,
          -96.669,
          -83.43799999999999,
          -70.12,
          -56.736000000000004,
          -43.303000000000004,
          -29.836,
          -16.35,
          -2.8560000000000003,
          10.633,
          24.107,
          37.558,
          50.977,
          64.358,
          77.693,
          90.978,
          104.206,
          117.374,
          130.47799999999998,
          143.513,
          156.47799999999998,
          169.368,
          182.183,
          194.919,
          207.575,
          220.149,
          232.64,
          245.047,
          257.369,
          269.60400000000004,
          281.753,
          293.815,
          305.789,
          317.675,
          329.473,
          341.18300000000005,
          352.80400000000003,
          364.337,
          375.782,
          387.13800000000003,
          398.407,
          409.587,
          420.68,
          431.686,
          442.605,
          453.43699999999995,
          464.184,
          474.844,
          485.41900000000004,
          495.909,
          506.315,
          516.637,
          526.875,
          537.03,
          547.1030000000001,
          557.0930000000001,
          567.002,
          576.83,
          586.577,
          596.245,
          605.832,
          615.341,
          624.771,
          634.123,
          643.398,
          652.595,
          661.717,
          670.762,
          679.7310000000001,
          688.6260000000001,
          697.446,
          706.192,
          714.865,
          723.465,
          731.992,
          740.446,
          748.83,
          757.1419999999999,
          765.383,
          773.554,
          781.655,
          789.687,
          797.65,
          805.544,
          813.37,
          821.1289999999999,
          828.82,
          836.444,
          844.002,
          851.4939999999999,
          858.92,
          866.28,
          873.576,
          880.807,
          887.9739999999999,
          895.077,
          902.1160000000001,
          909.0930000000001,
          916.0060000000001,
          922.857,
          929.6460000000001,
          936.373,
          943.039,
          949.6439999999999,
          956.188,
          962.671,
          969.0939999999999,
          975.457,
          981.76,
          988.005,
          994.19,
          1000.316,
          1006.3839999999999,
          1012.3939999999999,
          1018.346,
          1024.24,
          1030.077,
          1035.856,
          1041.579,
          1047.245,
          1052.854,
          1058.4080000000001,
          1063.905,
          1069.347,
          1074.733,
          1080.065,
          1085.3410000000001,
          1090.562,
          1095.728,
          1100.84,
          1105.8980000000001,
          1110.902,
          1115.853,
          1120.749,
          1125.5919999999999,
          1130.382,
          1135.119,
          1139.803,
          1144.434,
          1149.013,
          1153.539,
          1158.013,
          1162.435,
          1166.806,
          1171.124,
          1175.391,
          1179.607,
          1183.771,
          1187.884,
          1191.9460000000001,
          1195.9569999999999,
          1199.9180000000001,
          1203.827,
          1207.687,
          1211.496,
          1215.255,
          1218.963,
          1222.622,
          1226.231,
          1229.79,
          1233.299,
          1236.759,
          1240.1689999999999,
          1243.53,
          1246.8419999999999,
          1250.105,
          1253.318,
          1256.483,
          1259.598,
          1262.665,
          1265.683,
          1268.653,
          1271.573,
          1274.4460000000001,
          1277.269,
          1280.045,
          1282.772,
          1285.451,
          1288.0819999999999,
          1290.664,
          1293.1989999999998,
          1295.685,
          1298.124,
          1300.515,
          1302.857,
          1305.152,
          1307.4,
          1309.599,
          1311.751,
          1313.855,
          1315.911,
          1317.92,
          1319.881,
          1321.795,
          1323.661,
          1325.479,
          1327.25,
          1328.974,
          1330.65,
          1332.2779999999998,
          1333.86,
          1335.3929999999998,
          1336.879,
          1338.318,
          1339.71,
          1341.0539999999999,
          1342.35,
          1343.599,
          1344.8,
          1345.954,
          1347.0610000000001,
          1348.12,
          1349.131,
          1350.095,
          1351.0120000000002,
          1351.88,
          1352.701,
          1353.475,
          1354.201,
          1354.879,
          1355.509,
          1356.0910000000001,
          1356.626,
          1357.1129999999998,
          1357.5520000000001,
          1357.942,
          1358.285,
          1358.58,
          1358.8270000000002,
          1359.025,
          1359.175,
          1359.277,
          1359.33,
          1359.335,
          1359.2920000000001,
          1359.2,
          1359.059,
          1358.869,
          1358.631,
          1358.3429999999998,
          1358.007,
          1357.622,
          1357.1870000000001,
          1356.704,
          1356.17,
          1355.588,
          1354.9560000000001,
          1354.274,
          1353.5420000000001,
          1352.761,
          1351.9289999999999,
          1351.0479999999998,
          1350.116,
          1349.134,
          1348.102,
          1347.019,
          1345.885,
          1344.701,
          1343.465,
          1342.1789999999999,
          1340.8410000000001,
          1339.4520000000002,
          1338.011,
          1336.519,
          1334.974,
          1333.378,
          1331.73,
          1330.03,
          1328.277,
          1326.471,
          1324.6129999999998,
          1322.7020000000002,
          1320.737,
          1318.72,
          1316.649,
          1314.524,
          1312.345,
          1310.113,
          1307.826,
          1305.484,
          1303.088,
          1300.637,
          1298.131,
          1295.57,
          1292.953,
          1290.281,
          1287.553,
          1284.768,
          1281.927,
          1279.03,
          1276.076,
          1273.0639999999999,
          1269.995,
          1266.869,
          1263.685,
          1260.442,
          1257.141,
          1253.782,
          1250.363,
          1246.886,
          1243.349,
          1239.752,
          1236.095,
          1232.377,
          1228.599,
          1224.76,
          1220.86,
          1216.8980000000001,
          1212.874,
          1208.788,
          1204.639,
          1200.427,
          1196.152,
          1191.813,
          1187.41,
          1182.943,
          1178.412,
          1173.815,
          1169.152,
          1164.424,
          1159.629,
          1154.768,
          1149.839,
          1144.844,
          1139.78,
          1134.6480000000001,
          1129.447,
          1124.1760000000002,
          1118.837,
          1113.427,
          1107.9460000000001,
          1102.395,
          1096.772,
          1091.077,
          1085.309,
          1079.468,
          1073.5539999999999,
          1067.566,
          1061.503,
          1055.365,
          1049.152,
          1042.862,
          1036.496,
          1030.052,
          1023.53,
          1016.93,
          1010.2510000000001,
          1003.4910000000001,
          996.6519999999999,
          989.7310000000001,
          982.7289999999999,
          975.645,
          968.4780000000001,
          961.227,
          953.8919999999999,
          946.471,
          938.965,
          931.373,
          923.693,
          915.926,
          908.07,
          900.1239999999999,
          892.0880000000001,
          883.961,
          875.742,
          867.43,
          859.025,
          850.5260000000001,
          841.931,
          833.24,
          824.452,
          815.566,
          806.582,
          797.497,
          788.312,
          779.025,
          769.6360000000001,
          760.1419999999999,
          750.544,
          740.841,
          731.0310000000001,
          721.113,
          711.086,
          700.949,
          690.701,
          680.341,
          669.868,
          659.2810000000001,
          648.578,
          637.758,
          626.82,
          615.764,
          604.587,
          593.289,
          581.869,
          570.325,
          558.656,
          546.861,
          534.939,
          522.889,
          510.709,
          498.398,
          485.95599999999996,
          473.381,
          460.67199999999997,
          447.829,
          434.849,
          421.733,
          408.47900000000004,
          395.087,
          381.556,
          367.88599999999997,
          354.075,
          340.12300000000005,
          326.032,
          311.79900000000004,
          297.426,
          282.913,
          268.26,
          253.468,
          238.54,
          223.475,
          208.27700000000002,
          192.94799999999998,
          177.49099999999999,
          161.909,
          146.207,
          130.389,
          114.463,
          98.434,
          82.31,
          66.101,
          49.818000000000005,
          33.472,
          17.077,
          0.649,
          -15.795,
          -32.233000000000004,
          -48.644,
          -65.001,
          -81.277,
          -97.439,
          -113.45100000000001,
          -129.274,
          -144.864,
          -160.175,
          -175.155,
          -189.748,
          -203.896,
          -217.53599999999997,
          -230.60299999999998,
          -243.032,
          -254.75400000000002,
          -265.70599999999996,
          -275.823,
          -285.045,
          -293.319,
          -300.599,
          -306.847,
          -312.035,
          -316.149,
          -319.18,
          -321.137,
          -322.033,
          -321.89599999999996,
          -320.759,
          -318.663,
          -315.653,
          -311.781,
          -307.099,
          -301.66,
          -295.519,
          -288.72900000000004,
          -281.342,
          -273.409,
          -264.976,
          -256.089,
          -246.79,
          -237.118,
          -227.112,
          -216.803,
          -206.22400000000002,
          -195.40400000000002,
          -184.37,
          -173.144,
          -161.751,
          -150.21,
          -138.54,
          -126.759,
          -114.88,
          -102.906,
          -90.89,
          -78.803,
          -66.668,
          -54.497,
          -42.299,
          -30.08,
          -17.849,
          -5.612,
          6.624,
          18.852999999999998,
          31.070999999999998,
          43.273,
          55.45399999999999,
          67.611,
          79.74,
          91.837,
          103.9,
          115.926,
          127.913,
          139.858,
          151.759,
          163.614,
          175.421,
          187.18,
          198.889,
          210.545,
          222.149,
          233.699,
          245.19400000000002,
          256.634,
          268.017,
          279.343,
          290.611,
          301.82099999999997,
          312.972,
          324.064,
          335.097,
          346.069,
          356.981,
          367.833,
          378.624,
          389.35400000000004,
          400.024,
          410.63199999999995,
          421.17900000000003,
          431.665,
          442.09,
          452.45300000000003,
          462.755,
          472.996,
          483.176,
          493.29400000000004,
          503.352,
          513.3480000000001,
          523.283,
          533.158,
          542.972,
          552.725,
          562.418,
          572.0509999999999,
          581.623,
          591.135,
          600.587,
          609.98,
          619.313,
          628.587,
          637.8009999999999,
          646.956,
          656.053,
          665.09,
          674.069,
          682.99,
          691.8530000000001,
          700.6569999999999,
          709.404,
          718.0930000000001,
          726.7239999999999,
          735.299,
          743.816,
          752.2760000000001,
          760.68,
          769.0269999999999,
          777.318,
          785.552,
          793.7310000000001,
          801.8530000000001,
          809.92,
          817.932,
          825.888,
          833.789,
          841.635,
          849.426,
          857.163,
          864.845,
          872.472,
          880.046,
          887.566,
          895.0310000000001,
          902.444,
          909.802,
          917.107,
          924.3589999999999,
          931.558,
          938.704,
          945.797,
          952.8380000000001,
          959.826,
          966.7610000000001,
          973.645,
          980.4760000000001,
          987.255,
          993.9830000000001,
          1000.658,
          1007.2819999999999,
          1013.855,
          1020.3760000000001,
          1026.846,
          1033.265,
          1039.633,
          1045.95,
          1052.2160000000001,
          1058.432,
          1064.597,
          1070.711,
          1076.775,
          1082.789,
          1088.752,
          1094.6660000000002,
          1100.529,
          1106.343,
          1112.106,
          1117.82,
          1123.484,
          1129.099,
          1134.664,
          1140.18,
          1145.646,
          1151.063,
          1156.43,
          1161.749,
          1167.018,
          1172.239,
          1177.41,
          1182.532,
          1187.606,
          1192.631,
          1197.607,
          1202.5339999999999,
          1207.412,
          1212.242,
          1217.0230000000001,
          1221.756,
          1226.44,
          1231.076,
          1235.663,
          1240.202,
          1244.693,
          1249.135,
          1253.529,
          1257.874,
          1262.171,
          1266.42,
          1270.62,
          1274.7730000000001,
          1278.877,
          1282.933,
          1286.94,
          1290.9,
          1294.8110000000001,
          1298.674,
          1302.489,
          1306.255,
          1309.973,
          1313.644,
          1317.265,
          1320.839,
          1324.364,
          1327.8410000000001,
          1331.27,
          1334.65,
          1337.9820000000002,
          1341.266,
          1344.501,
          1347.6879999999999,
          1350.8270000000002,
          1353.9170000000001,
          1356.9579999999999,
          1359.951,
          1362.895,
          1365.7910000000002,
          1368.638,
          1371.4360000000001,
          1374.1860000000001,
          1376.886,
          1379.5379999999998,
          1382.141,
          1384.695,
          1387.2,
          1389.655,
          1392.0620000000001,
          1394.4189999999999,
          1396.727,
          1398.986,
          1401.195,
          1403.355,
          1405.465,
          1407.526,
          1409.536,
          1411.497,
          1413.408,
          1415.269,
          1417.08,
          1418.84,
          1420.55,
          1422.21,
          1423.82,
          1425.378,
          1426.886,
          1428.344,
          1429.75,
          1431.105,
          1432.4089999999999,
          1433.662,
          1434.8629999999998,
          1436.013,
          1437.111,
          1438.158,
          1439.152,
          1440.095,
          1440.985,
          1441.8229999999999,
          1442.608,
          1443.3410000000001,
          1444.021,
          1444.648,
          1445.2220000000002,
          1445.743,
          1446.21,
          1446.624,
          1446.984,
          1447.29,
          1447.5420000000001,
          1447.74,
          1447.884,
          1447.973,
          1448.007,
          1447.986,
          1447.91,
          1447.7779999999998,
          1447.5910000000001,
          1447.348,
          1447.05,
          1446.695,
          1446.283,
          1445.815,
          1445.29,
          1444.7089999999998,
          1444.069,
          1443.3729999999998,
          1442.618,
          1441.806,
          1440.935,
          1440.006,
          1439.0179999999998,
          1437.971,
          1436.865,
          1435.6989999999998,
          1434.474,
          1433.1879999999999,
          1431.842,
          1430.4360000000001,
          1428.9679999999998,
          1427.44,
          1425.85,
          1424.1979999999999,
          1422.484,
          1420.7079999999999,
          1418.869,
          1416.9660000000001,
          1415.001,
          1412.9720000000002,
          1410.879,
          1408.721,
          1406.499,
          1404.2120000000002,
          1401.859,
          1399.44,
          1396.955,
          1394.404,
          1391.786,
          1389.1,
          1386.3470000000002,
          1383.526,
          1380.636,
          1377.6779999999999,
          1374.65,
          1371.5520000000001,
          1368.384,
          1365.145,
          1361.836,
          1358.455,
          1355.001,
          1351.476,
          1347.8770000000002,
          1344.205,
          1340.4589999999998,
          1336.639,
          1332.744,
          1328.773,
          1324.727,
          1320.604,
          1316.404,
          1312.126,
          1307.77,
          1303.336,
          1298.822,
          1294.228,
          1289.553,
          1284.798,
          1279.961,
          1275.0410000000002,
          1270.038,
          1264.952,
          1259.781,
          1254.526,
          1249.184,
          1243.756,
          1238.241,
          1232.638,
          1226.947,
          1221.1660000000002,
          1215.295,
          1209.333,
          1203.28,
          1197.134,
          1190.894,
          1184.5610000000001,
          1178.132,
          1171.608,
          1164.986,
          1158.267,
          1151.45,
          1144.5330000000001,
          1137.515,
          1130.396,
          1123.174,
          1115.849,
          1108.42,
          1100.885,
          1093.243,
          1085.494,
          1077.635,
          1069.667,
          1061.588,
          1053.396,
          1045.0910000000001,
          1036.671,
          1028.136,
          1019.4830000000001,
          1010.711,
          1001.82,
          992.807,
          983.672,
          974.413,
          965.028,
          955.5169999999999,
          945.877,
          936.107,
          926.206,
          916.172,
          906.0039999999999,
          895.699,
          885.257,
          874.674,
          863.951,
          853.084,
          842.073,
          830.914,
          819.607,
          808.15,
          796.54,
          784.7760000000001,
          772.8560000000001,
          760.7769999999999,
          748.538,
          736.1360000000001,
          723.569,
          710.836,
          697.934,
          684.86,
          671.613,
          658.191,
          644.59,
          630.809,
          616.845,
          602.697,
          588.362,
          573.837,
          559.12,
          544.21,
          529.104,
          513.799,
          498.29400000000004,
          482.586,
          466.675,
          450.55699999999996,
          434.231,
          417.69599999999997,
          400.95,
          383.99300000000005,
          366.82300000000004,
          349.44,
          331.844,
          314.035,
          296.014,
          277.782,
          259.342,
          240.697,
          221.84900000000002,
          202.804,
          183.56799999999998,
          164.14700000000002,
          144.55100000000002,
          124.789,
          104.875,
          84.822,
          64.648,
          44.373000000000005,
          24.018,
          3.61,
          -16.82,
          -37.239000000000004,
          -57.608999999999995,
          -77.88600000000001,
          -98.023,
          -117.965,
          -137.655,
          -157.029,
          -176.019,
          -194.55200000000002,
          -212.55200000000002,
          -229.94,
          -246.637,
          -262.562,
          -277.64,
          -291.797,
          -304.967,
          -317.091,
          -328.121,
          -338.02,
          -346.76099999999997,
          -354.33099999999996,
          -360.72900000000004,
          -365.964,
          -370.05800000000005,
          -373.039,
          -374.94599999999997,
          -375.82099999999997,
          -375.712,
          -374.671,
          -372.751,
          -370.005,
          -366.486,
          -362.24800000000005,
          -357.34,
          -351.81300000000005,
          -345.712,
          -339.083,
          -331.967,
          -324.403,
          -316.428,
          -308.075,
          -299.377,
          -290.363,
          -281.06,
          -271.494,
          -261.687,
          -251.662,
          -241.438,
          -231.033,
          -220.46400000000003,
          -209.747,
          -198.89700000000002,
          -187.926,
          -176.847,
          -165.671,
          -154.409,
          -143.07,
          -131.664,
          -120.198,
          -108.68,
          -97.117,
          -85.516,
          -73.883,
          -62.224,
          -50.543,
          -38.846,
          -27.136,
          -15.419,
          -3.698,
          8.023,
          19.741,
          31.453000000000003,
          43.156000000000006,
          54.847,
          66.524,
          78.184,
          89.82600000000001,
          101.446,
          113.044,
          124.617,
          136.164,
          147.683,
          159.173,
          170.63299999999998,
          182.06099999999998,
          193.455,
          204.81599999999997,
          216.142,
          227.43200000000002,
          238.685,
          249.9,
          261.077,
          272.214,
          283.312,
          294.369,
          305.385,
          316.35900000000004,
          327.291,
          338.181,
          349.027,
          359.83,
          370.589,
          381.30400000000003,
          391.974,
          402.6,
          413.18,
          423.715,
          434.204,
          444.648,
          455.045,
          465.39599999999996,
          475.7,
          485.958,
          496.16900000000004,
          506.333,
          516.45,
          526.52,
          536.5419999999999,
          546.5169999999999,
          556.445,
          566.325,
          576.1569999999999,
          585.942,
          595.679,
          605.368,
          615.01,
          624.6030000000001,
          634.149,
          643.646,
          653.096,
          662.498,
          671.8510000000001,
          681.1569999999999,
          690.415,
          699.6239999999999,
          708.7860000000001,
          717.8989999999999,
          726.965,
          735.982,
          744.951,
          753.873,
          762.7460000000001,
          771.572,
          780.3489999999999,
          789.079,
          797.76,
          806.3939999999999,
          814.9789999999999,
          823.5169999999999,
          832.007,
          840.449,
          848.8439999999999,
          857.19,
          865.4889999999999,
          873.74,
          881.943,
          890.0980000000001,
          898.206,
          906.2660000000001,
          914.278,
          922.243,
          930.16,
          938.029,
          945.8510000000001,
          953.6260000000001,
          961.352,
          969.0310000000001,
          976.663,
          984.247,
          991.784,
          999.273,
          1006.715,
          1014.1089999999999,
          1021.456,
          1028.755,
          1036.007,
          1043.211,
          1050.368,
          1057.478,
          1064.54,
          1071.555,
          1078.5230000000001,
          1085.443,
          1092.315,
          1099.14,
          1105.9180000000001,
          1112.649,
          1119.3319999999999,
          1125.9669999999999,
          1132.556,
          1139.096,
          1145.59,
          1152.035,
          1158.434,
          1164.785,
          1171.088,
          1177.344,
          1183.552,
          1189.713,
          1195.826,
          1201.892,
          1207.91,
          1213.88,
          1219.803,
          1225.678,
          1231.505,
          1237.2839999999999,
          1243.016,
          1248.7,
          1254.336,
          1259.924,
          1265.464,
          1270.955,
          1276.399,
          1281.795,
          1287.143,
          1292.442,
          1297.693,
          1302.896,
          1308.0510000000002,
          1313.1570000000002,
          1318.214,
          1323.223,
          1328.184,
          1333.096,
          1337.9589999999998,
          1342.773,
          1347.5379999999998,
          1352.255,
          1356.922,
          1361.5410000000002,
          1366.11,
          1370.63,
          1375.1,
          1379.5220000000002,
          1383.8929999999998,
          1388.215,
          1392.4879999999998,
          1396.71,
          1400.8829999999998,
          1405.006,
          1409.079,
          1413.101,
          1417.0729999999999,
          1420.995,
          1424.8670000000002,
          1428.6879999999999,
          1432.4579999999999,
          1436.1770000000001,
          1439.845,
          1443.463,
          1447.029,
          1450.5439999999999,
          1454.007,
          1457.4189999999999,
          1460.779,
          1464.088,
          1467.344,
          1470.549,
          1473.701,
          1476.8010000000002,
          1479.848,
          1482.8429999999998,
          1485.785,
          1488.674,
          1491.51,
          1494.2920000000001,
          1497.021,
          1499.6970000000001,
          1502.319,
          1504.8870000000002,
          1507.4,
          1509.86,
          1512.265,
          1514.616,
          1516.911,
          1519.152,
          1521.338,
          1523.4679999999998,
          1525.5420000000001,
          1527.5610000000001,
          1529.524,
          1531.431,
          1533.281,
          1535.075,
          1536.8120000000001,
          1538.4920000000002,
          1540.114,
          1541.6789999999999,
          1543.1870000000001,
          1544.6370000000002,
          1546.0279999999998,
          1547.361,
          1548.635,
          1549.851,
          1551.007,
          1552.104,
          1553.141,
          1554.119,
          1555.036,
          1555.8929999999998,
          1556.6889999999999,
          1557.424,
          1558.098,
          1558.71,
          1559.26,
          1559.749,
          1560.174,
          1560.537,
          1560.8370000000002,
          1561.0739999999998,
          1561.247,
          1561.356,
          1561.401,
          1561.381,
          1561.296,
          1561.145,
          1560.9289999999999,
          1560.6470000000002,
          1560.299,
          1559.884,
          1559.401,
          1558.852,
          1558.234,
          1557.5479999999998,
          1556.793,
          1555.969,
          1555.076,
          1554.1129999999998,
          1553.08,
          1551.976,
          1550.8010000000002,
          1549.5539999999999,
          1548.236,
          1546.844,
          1545.38,
          1543.8429999999998,
          1542.2320000000002,
          1540.546,
          1538.786,
          1536.95,
          1535.0379999999998,
          1533.0510000000002,
          1530.986,
          1528.844,
          1526.624,
          1524.325,
          1521.9479999999999,
          1519.491,
          1516.954,
          1514.336,
          1511.6370000000002,
          1508.856,
          1505.9920000000002,
          1503.046,
          1500.016,
          1496.901,
          1493.701,
          1490.4160000000002,
          1487.0439999999999,
          1483.585,
          1480.039,
          1476.404,
          1472.68,
          1468.866,
          1464.961,
          1460.965,
          1456.8770000000002,
          1452.6960000000001,
          1448.421,
          1444.0520000000001,
          1439.5870000000002,
          1435.026,
          1430.368,
          1425.612,
          1420.757,
          1415.8020000000001,
          1410.747,
          1405.59,
          1400.3310000000001,
          1394.9679999999998,
          1389.5,
          1383.9270000000001,
          1378.2479999999998,
          1372.46,
          1366.565,
          1360.559,
          1354.443,
          1348.214,
          1341.8729999999998,
          1335.4170000000001,
          1328.846,
          1322.1570000000002,
          1315.351,
          1308.4260000000002,
          1301.38,
          1294.212,
          1286.921,
          1279.505,
          1271.964,
          1264.295,
          1256.497,
          1248.568,
          1240.508,
          1232.3139999999999,
          1223.985,
          1215.519,
          1206.914,
          1198.17,
          1189.2839999999999,
          1180.254,
          1171.078,
          1161.755,
          1152.2839999999999,
          1142.661,
          1132.885,
          1122.953,
          1112.865,
          1102.617,
          1092.208,
          1081.635,
          1070.897,
          1059.989,
          1048.912,
          1037.661,
          1026.234,
          1014.63,
          1002.845,
          990.8760000000001,
          978.722,
          966.3789999999999,
          953.845,
          941.1160000000001,
          928.189,
          915.062,
          901.732,
          888.195,
          874.448,
          860.488,
          846.311,
          831.915,
          817.296,
          802.449,
          787.373,
          772.062,
          756.513,
          740.7239999999999,
          724.689,
          708.405,
          691.8689999999999,
          675.075,
          658.0219999999999,
          640.703,
          623.117,
          605.258,
          587.124,
          568.71,
          550.014,
          531.031,
          511.75800000000004,
          492.19199999999995,
          472.332,
          452.173,
          431.715,
          410.955,
          389.89300000000003,
          368.528,
          346.86199999999997,
          324.895,
          302.631,
          280.072,
          257.223,
          234.093,
          210.69,
          187.024,
          163.11,
          138.964,
          114.60600000000001,
          90.059,
          65.352,
          40.515,
          15.587,
          -9.389,
          -34.366,
          -59.287,
          -84.09299999999999,
          -108.715,
          -133.078,
          -157.10299999999998,
          -180.704,
          -203.791,
          -226.268,
          -248.043,
          -269.022,
          -289.11,
          -308.223,
          -326.281,
          -343.213,
          -358.961,
          -373.478,
          -386.73199999999997,
          -398.704,
          -409.385,
          -418.786,
          -426.921,
          -433.82099999999997,
          -439.52099999999996,
          -444.06300000000005,
          -447.496,
          -449.87199999999996,
          -451.24300000000005,
          -451.665,
          -451.19199999999995,
          -449.88,
          -447.78,
          -444.94300000000004,
          -441.42,
          -437.256,
          -432.496,
          -427.181,
          -421.351,
          -415.04400000000004,
          -408.293,
          -401.131,
          -393.587,
          -385.689,
          -377.465,
          -368.93800000000005,
          -360.13,
          -351.06300000000005,
          -341.756,
          -332.226,
          -322.491,
          -312.567,
          -302.468,
          -292.207,
          -281.797,
          -271.249,
          -260.575,
          -249.785,
          -238.889,
          -227.894,
          -216.81,
          -205.643,
          -194.40200000000002,
          -183.093,
          -171.722,
          -160.295,
          -148.81799999999998,
          -137.295,
          -125.73200000000001,
          -114.134,
          -102.50399999999999,
          -90.84700000000001,
          -79.165,
          -67.464,
          -55.746,
          -44.015,
          -32.272,
          -20.522,
          -8.766,
          2.992,
          14.751,
          26.506999999999998,
          38.260999999999996,
          50.008,
          61.747,
          73.477,
          85.196,
          96.90299999999999,
          108.595,
          120.271,
          131.931,
          143.572,
          155.19299999999998,
          166.795,
          178.37400000000002,
          189.93099999999998,
          201.46400000000003,
          212.972,
          224.455,
          235.912,
          247.34099999999998,
          258.743,
          270.116,
          281.459,
          292.77299999999997,
          304.056,
          315.307,
          326.527,
          337.715,
          348.87,
          359.991,
          371.079,
          382.13300000000004,
          393.152,
          404.135,
          415.084,
          425.996,
          436.87199999999996,
          447.712,
          458.515,
          469.281,
          480.009,
          490.7,
          501.352,
          511.966,
          522.5419999999999,
          533.0790000000001,
          543.576,
          554.035,
          564.4540000000001,
          574.8330000000001,
          585.173,
          595.472,
          605.732,
          615.95,
          626.129,
          636.266,
          646.362,
          656.418,
          666.432,
          676.405,
          686.336,
          696.2260000000001,
          706.074,
          715.88,
          725.6439999999999,
          735.3660000000001,
          745.046,
          754.683,
          764.278,
          773.831,
          783.34,
          792.807,
          802.2310000000001,
          811.612,
          820.95,
          830.245,
          839.4960000000001,
          848.705,
          857.8689999999999,
          866.9910000000001,
          876.068,
          885.102,
          894.092,
          903.039,
          911.941,
          920.799,
          929.613,
          938.383,
          947.1089999999999,
          955.791,
          964.428,
          973.02,
          981.568,
          990.071,
          998.53,
          1006.944,
          1015.312,
          1023.6360000000001,
          1031.915,
          1040.149,
          1048.337,
          1056.481,
          1064.579,
          1072.631,
          1080.638,
          1088.6,
          1096.515,
          1104.385,
          1112.21,
          1119.988,
          1127.72,
          1135.406,
          1143.046,
          1150.64,
          1158.188,
          1165.6889999999999,
          1173.143,
          1180.5510000000002,
          1187.913,
          1195.2269999999999,
          1202.495,
          1209.7160000000001,
          1216.89,
          1224.016,
          1231.096,
          1238.128,
          1245.113,
          1252.05,
          1258.9389999999999,
          1265.781,
          1272.575,
          1279.3210000000001,
          1286.019,
          1292.6689999999999,
          1299.271,
          1305.8239999999998,
          1312.329,
          1318.786,
          1325.193,
          1331.5520000000001,
          1337.862,
          1344.1229999999998,
          1350.3339999999998,
          1356.497,
          1362.61,
          1368.6729999999998,
          1374.6870000000001,
          1380.651,
          1386.565,
          1392.4289999999999,
          1398.243,
          1404.006,
          1409.72,
          1415.382,
          1420.994,
          1426.555,
          1432.065,
          1437.523,
          1442.931,
          1448.286,
          1453.5910000000001,
          1458.8429999999998,
          1464.0439999999999,
          1469.192,
          1474.2879999999998,
          1479.332,
          1484.3229999999999,
          1489.2620000000002,
          1494.1470000000002,
          1498.98,
          1503.759,
          1508.485,
          1513.1570000000002,
          1517.775,
          1522.339,
          1526.849,
          1531.305,
          1535.7060000000001,
          1540.0520000000001,
          1544.344,
          1548.58,
          1552.761,
          1556.886,
          1560.9560000000001,
          1564.969,
          1568.9260000000002,
          1572.8270000000002,
          1576.671,
          1580.4589999999998,
          1584.1889999999999,
          1587.862,
          1591.477,
          1595.0339999999999,
          1598.5339999999999,
          1601.975,
          1605.3570000000002,
          1608.681,
          1611.9460000000001,
          1615.151,
          1618.297,
          1621.3829999999998,
          1624.4089999999999,
          1627.375,
          1630.28,
          1633.124,
          1635.9070000000002,
          1638.628,
          1641.2879999999998,
          1643.886,
          1646.421,
          1648.894,
          1651.3029999999999,
          1653.65,
          1655.933,
          1658.151,
          1660.306,
          1662.396,
          1664.422,
          1666.382,
          1668.276,
          1670.105,
          1671.8670000000002,
          1673.5629999999999,
          1675.191,
          1676.753,
          1678.246,
          1679.672,
          1681.029,
          1682.317,
          1683.536,
          1684.6860000000001,
          1685.765,
          1686.774,
          1687.711,
          1688.578,
          1689.3729999999998,
          1690.095,
          1690.745,
          1691.3220000000001,
          1691.826,
          1692.255,
          1692.611,
          1692.891,
          1693.095,
          1693.224,
          1693.277,
          1693.253,
          1693.151,
          1692.971,
          1692.713,
          1692.376,
          1691.96,
          1691.463,
          1690.886,
          1690.2279999999998,
          1689.4879999999998,
          1688.665,
          1687.76,
          1686.771,
          1685.6979999999999,
          1684.54,
          1683.297,
          1681.9679999999998,
          1680.5520000000001,
          1679.0479999999998,
          1677.457,
          1675.777,
          1674.0079999999998,
          1672.148,
          1670.1979999999999,
          1668.156,
          1666.021,
          1663.7939999999999,
          1661.473,
          1659.057,
          1656.546,
          1653.9379999999999,
          1651.233,
          1648.431,
          1645.53,
          1642.529,
          1639.4279999999999,
          1636.225,
          1632.92,
          1629.5120000000002,
          1625.999,
          1622.382,
          1618.658,
          1614.828,
          1610.889,
          1606.8410000000001,
          1602.683,
          1598.414,
          1594.0320000000002,
          1589.537,
          1584.9270000000001,
          1580.2020000000002,
          1575.359,
          1570.398,
          1565.318,
          1560.1170000000002,
          1554.795,
          1549.349,
          1543.779,
          1538.0829999999999,
          1532.259,
          1526.307,
          1520.225,
          1514.0120000000002,
          1507.665,
          1501.184,
          1494.567,
          1487.8120000000001,
          1480.9170000000001,
          1473.882,
          1466.704,
          1459.382,
          1451.9129999999998,
          1444.297,
          1436.531,
          1428.6129999999998,
          1420.5410000000002,
          1412.3139999999999,
          1403.9289999999999,
          1395.385,
          1386.6789999999999,
          1377.809,
          1368.773,
          1359.568,
          1350.193,
          1340.645,
          1330.921,
          1321.019,
          1310.9370000000001,
          1300.672,
          1290.22,
          1279.5810000000001,
          1268.75,
          1257.725,
          1246.503,
          1235.0810000000001,
          1223.4560000000001,
          1211.625,
          1199.5839999999998,
          1187.3310000000001,
          1174.861,
          1162.172,
          1149.26,
          1136.12,
          1122.75,
          1109.145,
          1095.302,
          1081.2169999999999,
          1066.885,
          1052.303,
          1037.465,
          1022.368,
          1007.007,
          991.377,
          975.4730000000001,
          959.291,
          942.826,
          926.072,
          909.025,
          891.679,
          874.029,
          856.069,
          837.794,
          819.198,
          800.275,
          781.0210000000001,
          761.428,
          741.4910000000001,
          721.204,
          700.562,
          679.559,
          658.189,
          636.446,
          614.325,
          591.822,
          568.93,
          545.6469999999999,
          521.967,
          497.88699999999994,
          473.405,
          448.519,
          423.228,
          397.532,
          371.43300000000005,
          344.935,
          318.04200000000003,
          290.763,
          263.108,
          235.09,
          206.727,
          178.03799999999998,
          149.048,
          119.789,
          90.29700000000001,
          60.613,
          30.785999999999998,
          0.8740000000000001,
          -29.061,
          -58.946999999999996,
          -88.70299999999999,
          -118.242,
          -147.468,
          -176.28,
          -204.572,
          -232.232,
          -259.149,
          -285.214,
          -310.318,
          -334.361,
          -357.251,
          -378.908,
          -399.265,
          -418.269,
          -435.88300000000004,
          -452.083,
          -466.86199999999997,
          -480.227,
          -492.194,
          -502.793,
          -512.061,
          -520.0419999999999,
          -526.7869999999999,
          -532.3480000000001,
          -536.7819999999999,
          -540.145,
          -542.495,
          -543.889,
          -544.381,
          -544.025,
          -542.874,
          -540.976,
          -538.38,
          -535.128,
          -531.264,
          -526.828,
          -521.855,
          -516.381,
          -510.44,
          -504.06199999999995,
          -497.275,
          -490.105,
          -482.58,
          -474.721,
          -466.55,
          -458.087,
          -449.353,
          -440.36300000000006,
          -431.13599999999997,
          -421.686,
          -412.028,
          -402.176,
          -392.142,
          -381.939,
          -371.57599999999996,
          -361.066,
          -350.417,
          -339.639,
          -328.741,
          -317.73,
          -306.61400000000003,
          -295.401,
          -284.098,
          -272.709,
          -261.243,
          -249.704,
          -238.097,
          -226.428,
          -214.702,
          -202.923,
          -191.095,
          -179.222,
          -167.30900000000003,
          -155.358,
          -143.373,
          -131.358,
          -119.316,
          -107.249,
          -95.16,
          -83.052,
          -70.928,
          -58.788999999999994,
          -46.638999999999996,
          -34.479,
          -22.311999999999998,
          -10.138,
          2.039,
          14.218,
          26.397,
          38.575,
          50.75,
          62.92,
          75.085,
          87.242,
          99.391,
          111.53,
          123.65799999999999,
          135.774,
          147.877,
          159.966,
          172.03900000000002,
          184.09599999999998,
          196.136,
          208.157,
          220.16,
          232.143,
          244.106,
          256.047,
          267.966,
          279.862,
          291.735,
          303.584,
          315.408,
          327.207,
          338.98,
          350.727,
          362.44599999999997,
          374.13800000000003,
          385.80199999999996,
          397.43699999999995,
          409.04400000000004,
          420.621,
          432.168,
          443.684,
          455.17,
          466.625,
          478.048,
          489.439,
          500.798,
          512.124,
          523.418,
          534.677,
          545.904,
          557.096,
          568.254,
          579.377,
          590.466,
          601.519,
          612.5369999999999,
          623.519,
          634.465,
          645.375,
          656.2489999999999,
          667.085,
          677.885,
          688.6469999999999,
          699.373,
          710.06,
          720.709,
          731.321,
          741.8939999999999,
          752.428,
          762.924,
          773.3810000000001,
          783.798,
          794.177,
          804.5160000000001,
          814.815,
          825.074,
          835.293,
          845.472,
          855.61,
          865.7080000000001,
          875.765,
          885.7810000000001,
          895.7560000000001,
          905.69,
          915.582,
          925.432,
          935.2410000000001,
          945.008,
          954.7330000000001,
          964.415,
          974.055,
          983.6519999999999,
          993.207,
          1002.7189999999999,
          1012.187,
          1021.613,
          1030.995,
          1040.333,
          1049.628,
          1058.879,
          1068.087,
          1077.249,
          1086.368,
          1095.442,
          1104.472,
          1113.4569999999999,
          1122.397,
          1131.292,
          1140.142,
          1148.9460000000001,
          1157.705,
          1166.4180000000001,
          1175.086,
          1183.7069999999999,
          1192.2830000000001,
          1200.812,
          1209.2939999999999,
          1217.731,
          1226.12,
          1234.462,
          1242.758,
          1251.006,
          1259.2069999999999,
          1267.36,
          1275.4660000000001,
          1283.5230000000001,
          1291.5330000000001,
          1299.495,
          1307.4080000000001,
          1315.273,
          1323.089,
          1330.856,
          1338.5739999999998,
          1346.243,
          1353.862,
          1361.432,
          1368.953,
          1376.4229999999998,
          1383.844,
          1391.214,
          1398.533,
          1405.8029999999999,
          1413.021,
          1420.1879999999999,
          1427.3039999999999,
          1434.369,
          1441.3829999999998,
          1448.344,
          1455.254,
          1462.111,
          1468.9160000000002,
          1475.6689999999999,
          1482.369,
          1489.016,
          1495.609,
          1502.15,
          1508.6370000000002,
          1515.07,
          1521.4489999999998,
          1527.774,
          1534.0439999999999,
          1540.26,
          1546.421,
          1552.527,
          1558.5770000000002,
          1564.5720000000001,
          1570.511,
          1576.394,
          1582.221,
          1587.991,
          1593.704,
          1599.361,
          1604.96,
          1610.5020000000002,
          1615.986,
          1621.412,
          1626.779,
          1632.088,
          1637.339,
          1642.53,
          1647.662,
          1652.734,
          1657.746,
          1662.6979999999999,
          1667.59,
          1672.42,
          1677.19,
          1681.899,
          1686.545,
          1691.13,
          1695.6529999999998,
          1700.112,
          1704.509,
          1708.8429999999998,
          1713.1129999999998,
          1717.32,
          1721.4620000000002,
          1725.539,
          1729.5520000000001,
          1733.499,
          1737.381,
          1741.1970000000001,
          1744.9460000000001,
          1748.629,
          1752.245,
          1755.7939999999999,
          1759.275,
          1762.6870000000001,
          1766.031,
          1769.306,
          1772.5120000000002,
          1775.648,
          1778.714,
          1781.71,
          1784.634,
          1787.487,
          1790.2679999999998,
          1792.977,
          1795.614,
          1798.1770000000001,
          1800.6670000000001,
          1803.082,
          1805.424,
          1807.69,
          1809.881,
          1811.996,
          1814.0339999999999,
          1815.996,
          1817.88,
          1819.6860000000001,
          1821.414,
          1823.0629999999999,
          1824.632,
          1826.121,
          1827.53,
          1828.8570000000002,
          1830.1029999999998,
          1831.267,
          1832.3470000000002,
          1833.344,
          1834.257,
          1835.086,
          1835.829,
          1836.486,
          1837.057,
          1837.54,
          1837.9360000000001,
          1838.243,
          1838.461,
          1838.589,
          1838.6270000000002,
          1838.5729999999999,
          1838.4279999999999,
          1838.1889999999999,
          1837.8570000000002,
          1837.431,
          1836.91,
          1836.2939999999999,
          1835.5810000000001,
          1834.77,
          1833.861,
          1832.854,
          1831.746,
          1830.5379999999998,
          1829.229,
          1827.817,
          1826.3010000000002,
          1824.682,
          1822.957,
          1821.1270000000002,
          1819.1889999999999,
          1817.1429999999998,
          1814.9879999999998,
          1812.723,
          1810.3470000000002,
          1807.859,
          1805.257,
          1802.5410000000002,
          1799.71,
          1796.763,
          1793.6970000000001,
          1790.513,
          1787.2089999999998,
          1783.7839999999999,
          1780.236,
          1776.5639999999999,
          1772.7679999999998,
          1768.845,
          1764.795,
          1760.615,
          1756.305,
          1751.864,
          1747.289,
          1742.579,
          1737.733,
          1732.75,
          1727.6270000000002,
          1722.3629999999998,
          1716.957,
          1711.406,
          1705.71,
          1699.866,
          1693.8729999999998,
          1687.729,
          1681.432,
          1674.98,
          1668.371,
          1661.604,
          1654.675,
          1647.5839999999998,
          1640.328,
          1632.905,
          1625.3129999999999,
          1617.549,
          1609.612,
          1601.4979999999998,
          1593.2060000000001,
          1584.733,
          1576.0770000000002,
          1567.235,
          1558.204,
          1548.9820000000002,
          1539.565,
          1529.9520000000002,
          1520.138,
          1510.122,
          1499.9,
          1489.469,
          1478.826,
          1467.967,
          1456.89,
          1445.59,
          1434.0639999999999,
          1422.309,
          1410.3210000000001,
          1398.095,
          1385.629,
          1372.918,
          1359.957,
          1346.743,
          1333.271,
          1319.537,
          1305.536,
          1291.264,
          1276.715,
          1261.885,
          1246.768,
          1231.36,
          1215.654,
          1199.646,
          1183.329,
          1166.698,
          1149.746,
          1132.469,
          1114.858,
          1096.9089999999999,
          1078.613,
          1059.965,
          1040.9569999999999,
          1021.5830000000001,
          1001.835,
          981.706,
          961.188,
          940.273,
          918.954,
          897.2230000000001,
          875.072,
          852.493,
          829.477,
          806.0160000000001,
          782.1039999999999,
          757.73,
          732.888,
          707.571,
          681.77,
          655.4780000000001,
          628.689,
          601.398,
          573.5980000000001,
          545.2869999999999,
          516.4590000000001,
          487.115,
          457.25300000000004,
          426.876,
          395.98699999999997,
          364.594,
          332.707,
          300.339,
          267.508,
          234.238,
          200.55599999999998,
          166.49599999999998,
          132.101,
          97.42,
          62.50899999999999,
          27.436,
          -7.724,
          -42.886,
          -77.955,
          -112.82600000000001,
          -147.387,
          -181.518,
          -215.09400000000002,
          -247.986,
          -280.064,
          -311.20099999999996,
          -341.277,
          -370.176,
          -397.798,
          -424.05400000000003,
          -448.87,
          -472.191,
          -493.977,
          -514.205,
          -532.869,
          -549.976,
          -565.547,
          -579.613,
          -592.215,
          -603.401,
          -613.222,
          -621.737,
          -629.005,
          -635.0840000000001,
          -640.036,
          -643.92,
          -646.794,
          -648.716,
          -649.739,
          -649.9169999999999,
          -649.297,
          -647.93,
          -645.859,
          -643.125,
          -639.77,
          -635.832,
          -631.344,
          -626.34,
          -620.851,
          -614.9069999999999,
          -608.535,
          -601.76,
          -594.606,
          -587.095,
          -579.25,
          -571.0880000000001,
          -562.63,
          -553.893,
          -544.8919999999999,
          -535.6419999999999,
          -526.16,
          -516.456,
          -506.546,
          -496.439,
          -486.149,
          -475.684,
          -465.056,
          -454.274,
          -443.346,
          -432.282,
          -421.088,
          -409.773,
          -398.343,
          -386.805,
          -375.166,
          -363.431,
          -351.606,
          -339.69800000000004,
          -327.71,
          -315.647,
          -303.515,
          -291.318,
          -279.06,
          -266.744,
          -254.375,
          -241.957,
          -229.49200000000002,
          -216.985,
          -204.437,
          -191.85299999999998,
          -179.235,
          -166.585,
          -153.907,
          -141.203,
          -128.475,
          -115.726,
          -102.95700000000001,
          -90.171,
          -77.37,
          -64.556,
          -51.731,
          -38.896,
          -26.053,
          -13.204,
          -0.35,
          12.507,
          25.365,
          38.224000000000004,
          51.082,
          63.938,
          76.79,
          89.637,
          102.478,
          115.31200000000001,
          128.138,
          140.955,
          153.761,
          166.55599999999998,
          179.34,
          192.11,
          204.86599999999999,
          217.608,
          230.334,
          243.043,
          255.736,
          268.41,
          281.066,
          293.703,
          306.32,
          318.916,
          331.491,
          344.04400000000004,
          356.574,
          369.082,
          381.565,
          394.025,
          406.46,
          418.869,
          431.25300000000004,
          443.61,
          455.941,
          468.245,
          480.52,
          492.76800000000003,
          504.98699999999997,
          517.177,
          529.3380000000001,
          541.4680000000001,
          553.569,
          565.639,
          577.678,
          589.685,
          601.661,
          613.605,
          625.516,
          637.395,
          649.24,
          661.052,
          672.83,
          684.574,
          696.283,
          707.9580000000001,
          719.5980000000001,
          731.202,
          742.7710000000001,
          754.304,
          765.801,
          777.2610000000001,
          788.684,
          800.071,
          811.42,
          822.7310000000001,
          834.005,
          845.2410000000001,
          856.438,
          867.596,
          878.716,
          889.797,
          900.8380000000001,
          911.84,
          922.802,
          933.7239999999999,
          944.605,
          955.446,
          966.247,
          977.0060000000001,
          987.7239999999999,
          998.4,
          1009.035,
          1019.628,
          1030.1789999999999,
          1040.687,
          1051.153,
          1061.576,
          1071.955,
          1082.292,
          1092.585,
          1102.835,
          1113.04,
          1123.202,
          1133.319,
          1143.391,
          1153.4189999999999,
          1163.402,
          1173.339,
          1183.231,
          1193.078,
          1202.878,
          1212.632,
          1222.3410000000001,
          1232.002,
          1241.617,
          1251.185,
          1260.7060000000001,
          1270.1789999999999,
          1279.605,
          1288.983,
          1298.312,
          1307.594,
          1316.8270000000002,
          1326.011,
          1335.146,
          1344.233,
          1353.269,
          1362.256,
          1371.194,
          1380.0810000000001,
          1388.918,
          1397.704,
          1406.4389999999999,
          1415.124,
          1423.757,
          1432.339,
          1440.869,
          1449.346,
          1457.7720000000002,
          1466.145,
          1474.4660000000001,
          1482.734,
          1490.9479999999999,
          1499.109,
          1507.2160000000001,
          1515.269,
          1523.2679999999998,
          1531.213,
          1539.1029999999998,
          1546.9370000000001,
          1554.717,
          1562.441,
          1570.109,
          1577.721,
          1585.277,
          1592.776,
          1600.219,
          1607.604,
          1614.932,
          1622.201,
          1629.4129999999998,
          1636.567,
          1643.662,
          1650.6979999999999,
          1657.675,
          1664.592,
          1671.45,
          1678.247,
          1684.985,
          1691.661,
          1698.276,
          1704.83,
          1711.3220000000001,
          1717.7520000000002,
          1724.12,
          1730.425,
          1736.6670000000001,
          1742.845,
          1748.96,
          1755.011,
          1760.997,
          1766.9189999999999,
          1772.775,
          1778.566,
          1784.2910000000002,
          1789.95,
          1795.5420000000001,
          1801.067,
          1806.525,
          1811.915,
          1817.237,
          1822.49,
          1827.674,
          1832.789,
          1837.8339999999998,
          1842.809,
          1847.714,
          1852.547,
          1857.309,
          1861.999,
          1866.616,
          1871.161,
          1875.6329999999998,
          1880.03,
          1884.354,
          1888.6029999999998,
          1892.777,
          1896.875,
          1900.8970000000002,
          1904.842,
          1908.711,
          1912.501,
          1916.214,
          1919.848,
          1923.402,
          1926.8770000000002,
          1930.2720000000002,
          1933.586,
          1936.818,
          1939.969,
          1943.037,
          1946.0220000000002,
          1948.9229999999998,
          1951.74,
          1954.473,
          1957.119,
          1959.68,
          1962.154,
          1964.54,
          1966.839,
          1969.049,
          1971.1689999999999,
          1973.2,
          1975.139,
          1976.9879999999998,
          1978.744,
          1980.4070000000002,
          1981.977,
          1983.453,
          1984.8329999999999,
          1986.118,
          1987.306,
          1988.3970000000002,
          1989.389,
          1990.283,
          1991.0770000000002,
          1991.77,
          1992.361,
          1992.851,
          1993.237,
          1993.519,
          1993.6960000000001,
          1993.767,
          1993.731,
          1993.5870000000002,
          1993.335,
          1992.973,
          1992.5,
          1991.9160000000002,
          1991.2179999999998,
          1990.4070000000002,
          1989.481,
          1988.4389999999999,
          1987.28,
          1986.003,
          1984.606,
          1983.089,
          1981.45,
          1979.6889999999999,
          1977.8029999999999,
          1975.7920000000001,
          1973.654,
          1971.389,
          1968.994,
          1966.4679999999998,
          1963.8110000000001,
          1961.02,
          1958.095,
          1955.033,
          1951.8339999999998,
          1948.496,
          1945.017,
          1941.395,
          1937.63,
          1933.72,
          1929.662,
          1925.4560000000001,
          1921.099,
          1916.59,
          1911.9260000000002,
          1907.1070000000002,
          1902.13,
          1896.993,
          1891.695,
          1886.233,
          1880.605,
          1874.81,
          1868.845,
          1862.7079999999999,
          1856.396,
          1849.908,
          1843.2420000000002,
          1836.394,
          1829.3629999999998,
          1822.145,
          1814.739,
          1807.141,
          1799.35,
          1791.362,
          1783.174,
          1774.785,
          1766.19,
          1757.388,
          1748.374,
          1739.145,
          1729.7,
          1720.033,
          1710.142,
          1700.023,
          1689.6729999999998,
          1679.0870000000002,
          1668.264,
          1657.1979999999999,
          1645.885,
          1634.3220000000001,
          1622.504,
          1610.4270000000001,
          1598.0870000000002,
          1585.479,
          1572.598,
          1559.44,
          1546,
          1532.273,
          1518.253,
          1503.9360000000001,
          1489.316,
          1474.388,
          1459.144,
          1443.5810000000001,
          1427.69,
          1411.467,
          1394.904,
          1377.996,
          1360.735,
          1343.114,
          1325.126,
          1306.763,
          1288.018,
          1268.883,
          1249.35,
          1229.411,
          1209.057,
          1188.279,
          1167.068,
          1145.4160000000002,
          1123.313,
          1100.75,
          1077.715,
          1054.2,
          1030.194,
          1005.687,
          980.669,
          955.1289999999999,
          929.057,
          902.441,
          875.2710000000001,
          847.5369999999999,
          819.2289999999999,
          790.335,
          760.847,
          730.7560000000001,
          700.052,
          668.7289999999999,
          636.779,
          604.197,
          570.981,
          537.127,
          502.63599999999997,
          467.51300000000003,
          431.76300000000003,
          395.398,
          358.431,
          320.884,
          282.782,
          244.15900000000002,
          205.055,
          165.519,
          125.61,
          85.395,
          44.955,
          4.379,
          -36.23,
          -76.759,
          -117.086,
          -157.077,
          -196.593,
          -235.488,
          -273.613,
          -310.82099999999997,
          -346.97,
          -381.926,
          -415.56199999999995,
          -447.77099999999996,
          -478.458,
          -507.54699999999997,
          -534.982,
          -560.725,
          -584.756,
          -607.072,
          -627.684,
          -646.618,
          -663.9110000000001,
          -679.607,
          -693.758,
          -706.421,
          -717.659,
          -727.533,
          -736.107,
          -743.445,
          -749.6110000000001,
          -754.664,
          -758.666,
          -761.672,
          -763.74,
          -764.921,
          -765.265,
          -764.82,
          -763.63,
          -761.7389999999999,
          -759.186,
          -756.008,
          -752.2410000000001,
          -747.919,
          -743.072,
          -737.73,
          -731.92,
          -725.67,
          -719.002,
          -711.94,
          -704.505,
          -696.7180000000001,
          -688.597,
          -680.1610000000001,
          -671.427,
          -662.41,
          -653.125,
          -643.587,
          -633.808,
          -623.8009999999999,
          -613.5790000000001,
          -603.1519999999999,
          -592.531,
          -581.726,
          -570.747,
          -559.602,
          -548.3,
          -536.849,
          -525.257,
          -513.5319999999999,
          -501.67900000000003,
          -489.705,
          -477.61699999999996,
          -465.421,
          -453.12300000000005,
          -440.727,
          -428.23900000000003,
          -415.664,
          -403.006,
          -390.27099999999996,
          -377.461,
          -364.582,
          -351.63699999999994,
          -338.629,
          -325.563,
          -312.442,
          -299.269,
          -286.048,
          -272.78,
          -259.47,
          -246.11900000000003,
          -232.731,
          -219.30700000000002,
          -205.852,
          -192.36599999999999,
          -178.852,
          -165.312,
          -151.748,
          -138.16299999999998,
          -124.55799999999999,
          -110.935,
          -97.296,
          -83.64299999999999,
          -69.976,
          -56.299,
          -42.611999999999995,
          -28.916999999999998,
          -15.216,
          -1.5090000000000001,
          12.200999999999999,
          25.914,
          39.629,
          53.343,
          67.056,
          80.767,
          94.475,
          108.178,
          121.875,
          135.566,
          149.25,
          162.925,
          176.59099999999998,
          190.24599999999998,
          203.89,
          217.52200000000002,
          231.141,
          244.747,
          258.33799999999997,
          271.913,
          285.473,
          299.01599999999996,
          312.54200000000003,
          326.05,
          339.539,
          353.00800000000004,
          366.458,
          379.88699999999994,
          393.29400000000004,
          406.68,
          420.043,
          433.384,
          446.7,
          459.99300000000005,
          473.26099999999997,
          486.504,
          499.721,
          512.9119999999999,
          526.076,
          539.214,
          552.323,
          565.405,
          578.4580000000001,
          591.482,
          604.477,
          617.442,
          630.377,
          643.281,
          656.154,
          668.995,
          681.805,
          694.5830000000001,
          707.328,
          720.04,
          732.7180000000001,
          745.363,
          757.9739999999999,
          770.55,
          783.092,
          795.5980000000001,
          808.069,
          820.5039999999999,
          832.903,
          845.265,
          857.591,
          869.8789999999999,
          882.13,
          894.3430000000001,
          906.518,
          918.655,
          930.753,
          942.812,
          954.831,
          966.811,
          978.7510000000001,
          990.6510000000001,
          1002.51,
          1014.329,
          1026.106,
          1037.8419999999999,
          1049.536,
          1061.188,
          1072.798,
          1084.365,
          1095.89,
          1107.371,
          1118.809,
          1130.203,
          1141.553,
          1152.859,
          1164.121,
          1175.337,
          1186.509,
          1197.635,
          1208.715,
          1219.75,
          1230.738,
          1241.68,
          1252.575,
          1263.422,
          1274.223,
          1284.976,
          1295.681,
          1306.338,
          1316.9460000000001,
          1327.506,
          1338.017,
          1348.4779999999998,
          1358.89,
          1369.2520000000002,
          1379.5639999999999,
          1389.825,
          1400.036,
          1410.195,
          1420.3039999999999,
          1430.36,
          1440.365,
          1450.318,
          1460.2179999999998,
          1470.066,
          1479.861,
          1489.602,
          1499.29,
          1508.9229999999998,
          1518.503,
          1528.0279999999998,
          1537.4979999999998,
          1546.9129999999998,
          1556.2720000000002,
          1565.576,
          1574.8239999999998,
          1584.015,
          1593.15,
          1602.227,
          1611.2479999999998,
          1620.21,
          1629.115,
          1637.961,
          1646.749,
          1655.4779999999998,
          1664.1470000000002,
          1672.757,
          1681.307,
          1689.796,
          1698.225,
          1706.592,
          1714.899,
          1723.1429999999998,
          1731.326,
          1739.4460000000001,
          1747.503,
          1755.497,
          1763.4279999999999,
          1771.2939999999999,
          1779.0970000000002,
          1786.8339999999998,
          1794.507,
          1802.114,
          1809.655,
          1817.13,
          1824.539,
          1831.88,
          1839.154,
          1846.36,
          1853.4979999999998,
          1860.567,
          1867.567,
          1874.4979999999998,
          1881.358,
          1888.148,
          1894.868,
          1901.515,
          1908.092,
          1914.596,
          1921.027,
          1927.385,
          1933.67,
          1939.88,
          1946.016,
          1952.0770000000002,
          1958.0629999999999,
          1963.9720000000002,
          1969.805,
          1975.56,
          1981.2379999999998,
          1986.838,
          1992.359,
          1997.8010000000002,
          2003.164,
          2008.4460000000001,
          2013.6470000000002,
          2018.767,
          2023.805,
          2028.761,
          2033.6329999999998,
          2038.422,
          2043.126,
          2047.746,
          2052.28,
          2056.7270000000003,
          2061.0879999999997,
          2065.362,
          2069.547,
          2073.644,
          2077.652,
          2081.569,
          2085.396,
          2089.131,
          2092.774,
          2096.324,
          2099.78,
          2103.143,
          2106.41,
          2109.581,
          2112.656,
          2115.633,
          2118.512,
          2121.2929999999997,
          2123.973,
          2126.553,
          2129.032,
          2131.408,
          2133.6820000000002,
          2135.851,
          2137.916,
          2139.874,
          2141.7270000000003,
          2143.471,
          2145.107,
          2146.634,
          2148.05,
          2149.354,
          2150.5460000000003,
          2151.625,
          2152.589,
          2153.438,
          2154.17,
          2154.784,
          2155.28,
          2155.655,
          2155.91,
          2156.042,
          2156.051,
          2155.935,
          2155.6929999999998,
          2155.325,
          2154.828,
          2154.201,
          2153.444,
          2152.554,
          2151.53,
          2150.3720000000003,
          2149.077,
          2147.645,
          2146.073,
          2144.361,
          2142.506,
          2140.507,
          2138.363,
          2136.072,
          2133.632,
          2131.042,
          2128.3,
          2125.404,
          2122.353,
          2119.145,
          2115.777,
          2112.249,
          2108.5570000000002,
          2104.701,
          2100.678,
          2096.487,
          2092.124,
          2087.5879999999997,
          2082.877,
          2077.989,
          2072.9210000000003,
          2067.6710000000003,
          2062.237,
          2056.616,
          2050.805,
          2044.8039999999999,
          2038.608,
          2032.215,
          2025.622,
          2018.8270000000002,
          2011.828,
          2004.62,
          1997.2,
          1989.567,
          1981.717,
          1973.6470000000002,
          1965.3529999999998,
          1956.832,
          1948.0810000000001,
          1939.096,
          1929.874,
          1920.411,
          1910.703,
          1900.747,
          1890.537,
          1880.0710000000001,
          1869.345,
          1858.3529999999998,
          1847.092,
          1835.556,
          1823.7420000000002,
          1811.644,
          1799.2579999999998,
          1786.578,
          1773.599,
          1760.317,
          1746.725,
          1732.819,
          1718.5910000000001,
          1704.036,
          1689.148,
          1673.921,
          1658.348,
          1642.4229999999998,
          1626.138,
          1609.486,
          1592.461,
          1575.0539999999999,
          1557.2579999999998,
          1539.065,
          1520.4660000000001,
          1501.454,
          1482.019,
          1462.152,
          1441.845,
          1421.0870000000002,
          1399.869,
          1378.181,
          1356.0120000000002,
          1333.352,
          1310.19,
          1286.514,
          1262.3139999999999,
          1237.577,
          1212.2910000000002,
          1186.443,
          1160.022,
          1133.015,
          1105.4089999999999,
          1077.1889999999999,
          1048.343,
          1018.8589999999999,
          988.722,
          957.918,
          926.436,
          894.262,
          861.383,
          827.788,
          793.466,
          758.4060000000001,
          722.6,
          686.041,
          648.722,
          610.6419999999999,
          571.8,
          532.2,
          491.847,
          450.755,
          408.941,
          366.43,
          323.251,
          279.445,
          235.06,
          190.15599999999998,
          144.803,
          99.083,
          53.092,
          6.939,
          -39.257,
          -85.36,
          -131.226,
          -176.7,
          -221.62,
          -265.819,
          -309.13,
          -351.39,
          -392.441,
          -432.13800000000003,
          -470.348,
          -506.958,
          -541.872,
          -575.016,
          -606.335,
          -635.797,
          -663.387,
          -689.107,
          -712.9760000000001,
          -735.0260000000001,
          -755.299,
          -773.846,
          -790.725,
          -805.997,
          -819.7289999999999,
          -831.988,
          -842.841,
          -852.355,
          -860.5980000000001,
          -867.6339999999999,
          -873.525,
          -878.332,
          -882.112,
          -884.922,
          -886.814,
          -887.836,
          -888.038,
          -887.462,
          -886.153,
          -884.148,
          -881.488,
          -878.205,
          -874.3330000000001,
          -869.905,
          -864.948,
          -859.492,
          -853.561,
          -847.182,
          -840.3760000000001,
          -833.166,
          -825.573,
          -817.6139999999999,
          -809.31,
          -800.678,
          -791.7330000000001,
          -782.4910000000001,
          -772.966,
          -763.173,
          -753.1239999999999,
          -742.832,
          -732.308,
          -721.564,
          -710.6089999999999,
          -699.455,
          -688.1110000000001,
          -676.584,
          -664.885,
          -653.021,
          -641,
          -628.8290000000001,
          -616.515,
          -604.065,
          -591.486,
          -578.783,
          -565.9630000000001,
          -553.03,
          -539.99,
          -526.849,
          -513.611,
          -500.28,
          -486.86199999999997,
          -473.36,
          -459.778,
          -446.121,
          -432.39300000000003,
          -418.595,
          -404.73400000000004,
          -390.81,
          -376.829,
          -362.792,
          -348.704,
          -334.565,
          -320.38,
          -306.152,
          -291.881,
          -277.572,
          -263.226,
          -248.84599999999998,
          -234.433,
          -219.99099999999999,
          -205.52,
          -191.024,
          -176.503,
          -161.96,
          -147.39600000000002,
          -132.814,
          -118.214,
          -103.6,
          -88.971,
          -74.329,
          -59.677,
          -45.016000000000005,
          -30.346,
          -15.669,
          -0.987,
          13.699000000000002,
          28.388,
          43.07899999999999,
          57.771,
          72.462,
          87.15100000000001,
          101.838,
          116.521,
          131.2,
          145.873,
          160.539,
          175.19799999999998,
          189.84799999999998,
          204.488,
          219.11900000000003,
          233.738,
          248.34599999999998,
          262.941,
          277.522,
          292.089,
          306.64099999999996,
          321.177,
          335.69699999999995,
          350.2,
          364.685,
          379.151,
          393.598,
          408.025,
          422.43199999999996,
          436.81800000000004,
          451.18199999999996,
          465.524,
          479.843,
          494.13800000000003,
          508.41,
          522.6569999999999,
          536.879,
          551.075,
          565.245,
          579.389,
          593.505,
          607.594,
          621.654,
          635.686,
          649.689,
          663.6619999999999,
          677.605,
          691.518,
          705.3989999999999,
          719.2489999999999,
          733.068,
          746.8539999999999,
          760.607,
          774.327,
          788.0139999999999,
          801.666,
          815.285,
          828.868,
          842.416,
          855.929,
          869.4060000000001,
          882.846,
          896.25,
          909.6160000000001,
          922.945,
          936.2360000000001,
          949.4889999999999,
          962.703,
          975.878,
          989.0139999999999,
          1002.11,
          1015.166,
          1028.182,
          1041.156,
          1054.09,
          1066.982,
          1079.8319999999999,
          1092.64,
          1105.406,
          1118.128,
          1130.808,
          1143.443,
          1156.035,
          1168.583,
          1181.085,
          1193.5430000000001,
          1205.9560000000001,
          1218.323,
          1230.644,
          1242.9189999999999,
          1255.147,
          1267.328,
          1279.462,
          1291.548,
          1303.586,
          1315.575,
          1327.517,
          1339.4089999999999,
          1351.251,
          1363.0439999999999,
          1374.787,
          1386.48,
          1398.122,
          1409.713,
          1421.253,
          1432.74,
          1444.1760000000002,
          1455.559,
          1466.89,
          1478.168,
          1489.392,
          1500.5620000000001,
          1511.6779999999999,
          1522.739,
          1533.746,
          1544.6979999999999,
          1555.594,
          1566.434,
          1577.217,
          1587.945,
          1598.615,
          1609.227,
          1619.7820000000002,
          1630.279,
          1640.7179999999998,
          1651.0970000000002,
          1661.418,
          1671.6789999999999,
          1681.879,
          1692.02,
          1702.1,
          1712.118,
          1722.076,
          1731.971,
          1741.8039999999999,
          1751.5739999999998,
          1761.281,
          1770.925,
          1780.505,
          1790.02,
          1799.471,
          1808.8570000000002,
          1818.1770000000001,
          1827.431,
          1836.618,
          1845.739,
          1854.793,
          1863.779,
          1872.6960000000001,
          1881.545,
          1890.325,
          1899.036,
          1907.6760000000002,
          1916.247,
          1924.746,
          1933.174,
          1941.53,
          1949.8129999999999,
          1958.024,
          1966.162,
          1974.226,
          1982.215,
          1990.13,
          1997.969,
          2005.733,
          2013.42,
          2021.031,
          2028.5639999999999,
          2036.019,
          2043.395,
          2050.6929999999998,
          2057.911,
          2065.049,
          2072.106,
          2079.0820000000003,
          2085.976,
          2092.7870000000003,
          2099.516,
          2106.161,
          2112.722,
          2119.197,
          2125.5879999999997,
          2131.8920000000003,
          2138.109,
          2144.239,
          2150.281,
          2156.234,
          2162.098,
          2167.8720000000003,
          2173.554,
          2179.146,
          2184.645,
          2190.051,
          2195.364,
          2200.583,
          2205.706,
          2210.7329999999997,
          2215.6639999999998,
          2220.498,
          2225.2329999999997,
          2229.87,
          2234.407,
          2238.842,
          2243.177,
          2247.41,
          2251.5389999999998,
          2255.564,
          2259.485,
          2263.301,
          2267.008,
          2270.61,
          2274.101,
          2277.485,
          2280.757,
          2283.9179999999997,
          2286.967,
          2289.903,
          2292.724,
          2295.43,
          2298.02,
          2300.492,
          2302.845,
          2305.0789999999997,
          2307.192,
          2309.183,
          2311.051,
          2312.795,
          2314.4139999999998,
          2315.905,
          2317.269,
          2318.505,
          2319.61,
          2320.5820000000003,
          2321.422,
          2322.1279999999997,
          2322.698,
          2323.131,
          2323.426,
          2323.581,
          2323.594,
          2323.465,
          2323.1910000000003,
          2322.771,
          2322.2039999999997,
          2321.488,
          2320.6220000000003,
          2319.604,
          2318.43,
          2317.101,
          2315.615,
          2313.97,
          2312.1639999999998,
          2310.195,
          2308.061,
          2305.761,
          2303.291,
          2300.651,
          2297.839,
          2294.851,
          2291.687,
          2288.343,
          2284.819,
          2281.11,
          2277.216,
          2273.133,
          2268.86,
          2264.394,
          2259.732,
          2254.8720000000003,
          2249.811,
          2244.5460000000003,
          2239.075,
          2233.396,
          2227.5029999999997,
          2221.396,
          2215.072,
          2208.525,
          2201.756,
          2194.758,
          2187.53,
          2180.0679999999998,
          2172.368,
          2164.426,
          2156.241,
          2147.806,
          2139.12,
          2130.177,
          2120.974,
          2111.506,
          2101.77,
          2091.761,
          2081.474,
          2070.905,
          2060.05,
          2048.903,
          2037.4589999999998,
          2025.714,
          2013.661,
          2001.297,
          1988.614,
          1975.609,
          1962.273,
          1948.602,
          1934.589,
          1920.229,
          1905.514,
          1890.4370000000001,
          1874.9920000000002,
          1859.171,
          1842.9679999999998,
          1826.374,
          1809.381,
          1791.983,
          1774.168,
          1755.932,
          1737.2620000000002,
          1718.151,
          1698.589,
          1678.566,
          1658.0729999999999,
          1637.099,
          1615.6329999999998,
          1593.6660000000002,
          1571.184,
          1548.175,
          1524.631,
          1500.536,
          1475.878,
          1450.646,
          1424.8229999999999,
          1398.398,
          1371.356,
          1343.682,
          1315.3629999999998,
          1286.382,
          1256.724,
          1226.373,
          1195.3139999999999,
          1163.53,
          1131.005,
          1097.723,
          1063.6680000000001,
          1028.823,
          993.174,
          956.704,
          919.3989999999999,
          881.247,
          842.2330000000001,
          802.3480000000001,
          761.581,
          719.928,
          677.383,
          633.947,
          589.625,
          544.422,
          498.35699999999997,
          451.449,
          403.728,
          355.23199999999997,
          306.01099999999997,
          256.122,
          205.639,
          154.64700000000002,
          103.245,
          51.547,
          -0.316,
          -52.2,
          -103.948,
          -155.392,
          -206.35299999999998,
          -256.647,
          -306.087,
          -354.486,
          -401.668,
          -447.464,
          -491.72,
          -534.3009999999999,
          -575.091,
          -613.998,
          -650.951,
          -685.904,
          -718.828,
          -749.7180000000001,
          -778.587,
          -805.4580000000001,
          -830.372,
          -853.378,
          -874.534,
          -893.905,
          -911.556,
          -927.559,
          -941.9860000000001,
          -954.9069999999999,
          -966.395,
          -976.52,
          -985.3489999999999,
          -992.946,
          -999.377,
          -1004.701,
          -1008.9760000000001,
          -1012.257,
          -1014.596,
          -1016.043,
          -1016.643,
          -1016.442,
          -1015.482,
          -1013.802,
          -1011.438,
          -1008.426,
          -1004.798,
          -1000.587,
          -995.821,
          -990.528,
          -984.735,
          -978.466,
          -971.743,
          -964.59,
          -957.0260000000001,
          -949.072,
          -940.7460000000001,
          -932.066,
          -923.048,
          -913.707,
          -904.06,
          -894.1189999999999,
          -883.8989999999999,
          -873.41,
          -862.668,
          -851.682,
          -840.462,
          -829.0210000000001,
          -817.367,
          -805.51,
          -793.4580000000001,
          -781.221,
          -768.807,
          -756.222,
          -743.4760000000001,
          -730.572,
          -717.5219999999999,
          -704.328,
          -691,
          -677.541,
          -663.957,
          -650.254,
          -636.437,
          -622.511,
          -608.481,
          -594.352,
          -580.128,
          -565.812,
          -551.41,
          -536.925,
          -522.361,
          -507.721,
          -493.009,
          -478.228,
          -463.381,
          -448.472,
          -433.504,
          -418.48,
          -403.4,
          -388.27099999999996,
          -373.093,
          -357.869,
          -342.601,
          -327.293,
          -311.945,
          -296.56,
          -281.142,
          -265.69,
          -250.207,
          -234.697,
          -219.15900000000002,
          -203.59599999999998,
          -188.012,
          -172.40400000000002,
          -156.77700000000002,
          -141.132,
          -125.471,
          -109.79299999999999,
          -94.102,
          -78.4,
          -62.68600000000001,
          -46.963,
          -31.233,
          -15.494000000000002,
          0.249,
          15.998,
          31.749000000000002,
          47.503,
          63.258,
          79.01100000000001,
          94.764,
          110.516,
          126.26299999999999,
          142.007,
          157.745,
          173.476,
          189.202,
          204.918,
          220.625,
          236.324,
          252.01,
          267.687,
          283.35,
          299,
          314.63599999999997,
          330.259,
          345.865,
          361.45599999999996,
          377.029,
          392.586,
          408.12300000000005,
          423.642,
          439.14,
          454.62,
          470.077,
          485.514,
          500.92800000000005,
          516.32,
          531.688,
          547.0319999999999,
          562.351,
          577.646,
          592.915,
          608.1569999999999,
          623.372,
          638.56,
          653.72,
          668.8510000000001,
          683.954,
          699.0269999999999,
          714.07,
          729.082,
          744.064,
          759.0139999999999,
          773.931,
          788.817,
          803.669,
          818.488,
          833.273,
          848.0239999999999,
          862.7389999999999,
          877.42,
          892.065,
          906.673,
          921.245,
          935.78,
          950.2769999999999,
          964.7360000000001,
          979.1569999999999,
          993.539,
          1007.882,
          1022.185,
          1036.448,
          1050.67,
          1064.8519999999999,
          1078.992,
          1093.0910000000001,
          1107.147,
          1121.161,
          1135.131,
          1149.059,
          1162.943,
          1176.782,
          1190.577,
          1204.327,
          1218.031,
          1231.6889999999999,
          1245.302,
          1258.868,
          1272.387,
          1285.859,
          1299.2830000000001,
          1312.658,
          1325.985,
          1339.263,
          1352.4920000000002,
          1365.67,
          1378.8,
          1391.878,
          1404.906,
          1417.881,
          1430.805,
          1443.6779999999999,
          1456.497,
          1469.264,
          1481.9779999999998,
          1494.638,
          1507.244,
          1519.795,
          1532.2910000000002,
          1544.7320000000002,
          1557.118,
          1569.4470000000001,
          1581.719,
          1593.935,
          1606.0929999999998,
          1618.194,
          1630.236,
          1642.22,
          1654.144,
          1666.01,
          1677.815,
          1689.56,
          1701.245,
          1712.868,
          1724.43,
          1735.9289999999999,
          1747.3670000000002,
          1758.741,
          1770.0529999999999,
          1781.3,
          1792.483,
          1803.601,
          1814.655,
          1825.642,
          1836.5629999999999,
          1847.418,
          1858.207,
          1868.9279999999999,
          1879.5810000000001,
          1890.1660000000002,
          1900.681,
          1911.128,
          1921.504,
          1931.81,
          1942.045,
          1952.2089999999998,
          1962.3020000000001,
          1972.3220000000001,
          1982.2679999999998,
          1992.142,
          2001.942,
          2011.6670000000001,
          2021.318,
          2030.8929999999998,
          2040.391,
          2049.814,
          2059.159,
          2068.426,
          2077.616,
          2086.726,
          2095.757,
          2104.708,
          2113.5789999999997,
          2122.368,
          2131.077,
          2139.702,
          2148.244,
          2156.703,
          2165.078,
          2173.368,
          2181.572,
          2189.69,
          2197.721,
          2205.666,
          2213.522,
          2221.2889999999998,
          2228.967,
          2236.555,
          2244.051,
          2251.4570000000003,
          2258.77,
          2265.99,
          2273.116,
          2280.1479999999997,
          2287.085,
          2293.925,
          2300.669,
          2307.3160000000003,
          2313.864,
          2320.314,
          2326.6620000000003,
          2332.91,
          2339.0570000000002,
          2345.1020000000003,
          2351.0429999999997,
          2356.881,
          2362.613,
          2368.239,
          2373.758,
          2379.17,
          2384.473,
          2389.667,
          2394.749,
          2399.721,
          2404.58,
          2409.326,
          2413.9570000000003,
          2418.472,
          2422.8720000000003,
          2427.153,
          2431.3160000000003,
          2435.36,
          2439.282,
          2443.0820000000003,
          2446.76,
          2450.312,
          2453.739,
          2457.041,
          2460.214,
          2463.258,
          2466.172,
          2468.9539999999997,
          2471.604,
          2474.119,
          2476.499,
          2478.742,
          2480.847,
          2482.812,
          2484.637,
          2486.3179999999998,
          2487.856,
          2489.248,
          2490.494,
          2491.591,
          2492.5370000000003,
          2493.3320000000003,
          2493.975,
          2494.4610000000002,
          2494.791,
          2494.9629999999997,
          2494.975,
          2494.824,
          2494.51,
          2494.03,
          2493.383,
          2492.5660000000003,
          2491.5789999999997,
          2490.4179999999997,
          2489.081,
          2487.565,
          2485.8720000000003,
          2483.996,
          2481.936,
          2479.69,
          2477.255,
          2474.629,
          2471.81,
          2468.7960000000003,
          2465.5820000000003,
          2462.1679999999997,
          2458.551,
          2454.7270000000003,
          2450.695,
          2446.451,
          2441.993,
          2437.317,
          2432.4210000000003,
          2427.302,
          2421.956,
          2416.38,
          2410.572,
          2404.526,
          2398.242,
          2391.715,
          2384.9410000000003,
          2377.916,
          2370.637,
          2363.101,
          2355.301,
          2347.237,
          2338.903,
          2330.2929999999997,
          2321.405,
          2312.234,
          2302.775,
          2293.024,
          2282.976,
          2272.624,
          2261.966,
          2250.995,
          2239.7070000000003,
          2228.095,
          2216.153,
          2203.877,
          2191.26,
          2178.294,
          2164.976,
          2151.298,
          2137.2529999999997,
          2122.834,
          2108.034,
          2092.847,
          2077.262,
          2061.275,
          2044.876,
          2028.057,
          2010.809,
          1993.124,
          1974.994,
          1956.4070000000002,
          1937.354,
          1917.8270000000002,
          1897.8129999999999,
          1877.3029999999999,
          1856.287,
          1834.7520000000002,
          1812.6860000000001,
          1790.079,
          1766.9170000000001,
          1743.1870000000001,
          1718.8770000000002,
          1693.9720000000002,
          1668.46,
          1642.325,
          1615.5520000000001,
          1588.126,
          1560.03,
          1531.251,
          1501.769,
          1471.569,
          1440.632,
          1408.942,
          1376.479,
          1343.225,
          1309.161,
          1274.268,
          1238.528,
          1201.92,
          1164.4260000000002,
          1126.026,
          1086.702,
          1046.4360000000001,
          1005.211,
          963.0110000000001,
          919.821,
          875.628,
          830.423,
          784.197,
          736.948,
          688.675,
          639.385,
          589.0880000000001,
          537.804,
          485.56199999999995,
          432.395,
          378.35400000000004,
          323.498,
          267.899,
          211.64700000000002,
          154.845,
          97.61399999999999,
          40.09,
          -17.573,
          -75.205,
          -132.625,
          -189.637,
          -246.03799999999998,
          -301.625,
          -356.18800000000005,
          -409.53,
          -461.458,
          -511.798,
          -560.391,
          -607.104,
          -651.8240000000001,
          -694.465,
          -734.9630000000001,
          -773.2810000000001,
          -809.4,
          -843.327,
          -875.081,
          -904.697,
          -932.2239999999999,
          -957.7189999999999,
          -981.2460000000001,
          -1002.877,
          -1022.683,
          -1040.74,
          -1057.126,
          -1071.914,
          -1085.18,
          -1096.998,
          -1107.438,
          -1116.568,
          -1124.455,
          -1131.1589999999999,
          -1136.744,
          -1141.264,
          -1144.775,
          -1147.328,
          -1148.97,
          -1149.75,
          -1149.7089999999998,
          -1148.889,
          -1147.329,
          -1145.066,
          -1142.134,
          -1138.566,
          -1134.392,
          -1129.641,
          -1124.3419999999999,
          -1118.521,
          -1112.2,
          -1105.405,
          -1098.157,
          -1090.476,
          -1082.383,
          -1073.897,
          -1065.0339999999999,
          -1055.81,
          -1046.244,
          -1036.349,
          -1026.139,
          -1015.6289999999999,
          -1004.832,
          -993.758,
          -982.421,
          -970.832,
          -959,
          -946.937,
          -934.6519999999999,
          -922.154,
          -909.452,
          -896.553,
          -883.467,
          -870.202,
          -856.7639999999999,
          -843.16,
          -829.398,
          -815.4830000000001,
          -801.422,
          -787.22,
          -772.885,
          -758.42,
          -743.831,
          -729.123,
          -714.302,
          -699.372,
          -684.336,
          -669.201,
          -653.969,
          -638.644,
          -623.231,
          -607.734,
          -592.155,
          -576.499,
          -560.768,
          -544.966,
          -529.096,
          -513.1619999999999,
          -497.165,
          -481.10900000000004,
          -464.996,
          -448.83,
          -432.61199999999997,
          -416.345,
          -400.032,
          -383.67400000000004,
          -367.275,
          -350.836,
          -334.35900000000004,
          -317.847,
          -301.301,
          -284.723,
          -268.116,
          -251.48,
          -234.81799999999998,
          -218.132,
          -201.423,
          -184.69299999999998,
          -167.94299999999998,
          -151.175,
          -134.391,
          -117.59100000000001,
          -100.77799999999999,
          -83.95299999999999,
          -67.116,
          -50.27,
          -33.416,
          -16.554000000000002,
          0.313,
          17.185,
          34.06,
          50.938,
          67.817,
          84.696,
          101.574,
          118.45,
          135.32299999999998,
          152.192,
          169.05599999999998,
          185.91400000000002,
          202.766,
          219.609,
          236.44400000000002,
          253.269,
          270.084,
          286.887,
          303.678,
          320.45599999999996,
          337.22,
          353.97,
          370.705,
          387.423,
          404.124,
          420.80800000000005,
          437.474,
          454.12,
          470.74699999999996,
          487.353,
          503.93800000000005,
          520.502,
          537.043,
          553.56,
          570.055,
          586.524,
          602.969,
          619.388,
          635.781,
          652.146,
          668.485,
          684.795,
          701.077,
          717.33,
          733.553,
          749.745,
          765.9069999999999,
          782.038,
          798.1360000000001,
          814.202,
          830.235,
          846.2339999999999,
          862.199,
          878.13,
          894.025,
          909.885,
          925.709,
          941.4960000000001,
          957.2460000000001,
          972.9580000000001,
          988.633,
          1004.268,
          1019.865,
          1035.422,
          1050.9389999999999,
          1066.415,
          1081.85,
          1097.244,
          1112.596,
          1127.906,
          1143.172,
          1158.396,
          1173.575,
          1188.71,
          1203.8010000000002,
          1218.846,
          1233.846,
          1248.799,
          1263.7060000000001,
          1278.566,
          1293.378,
          1308.143,
          1322.859,
          1337.526,
          1352.144,
          1366.7120000000002,
          1381.23,
          1395.6979999999999,
          1410.114,
          1424.479,
          1438.7910000000002,
          1453.0520000000001,
          1467.259,
          1481.4129999999998,
          1495.513,
          1509.559,
          1523.5510000000002,
          1537.487,
          1551.3670000000002,
          1565.192,
          1578.96,
          1592.67,
          1606.3239999999998,
          1619.9189999999999,
          1633.4560000000001,
          1646.935,
          1660.354,
          1673.713,
          1687.0120000000002,
          1700.25,
          1713.4270000000001,
          1726.5420000000001,
          1739.595,
          1752.586,
          1765.513,
          1778.3770000000002,
          1791.1770000000001,
          1803.912,
          1816.582,
          1829.1860000000001,
          1841.725,
          1854.1960000000001,
          1866.601,
          1878.9379999999999,
          1891.207,
          1903.408,
          1915.539,
          1927.6,
          1939.5910000000001,
          1951.5120000000002,
          1963.361,
          1975.139,
          1986.844,
          1998.476,
          2010.035,
          2021.52,
          2032.93,
          2044.265,
          2055.525,
          2066.708,
          2077.814,
          2088.843,
          2099.794,
          2110.667,
          2121.46,
          2132.173,
          2142.806,
          2153.3579999999997,
          2163.8289999999997,
          2174.217,
          2184.522,
          2194.744,
          2204.881,
          2214.9339999999997,
          2224.901,
          2234.782,
          2244.576,
          2254.283,
          2263.901,
          2273.43,
          2282.87,
          2292.22,
          2301.478,
          2310.645,
          2319.72,
          2328.701,
          2337.5879999999997,
          2346.38,
          2355.077,
          2363.678,
          2372.181,
          2380.587,
          2388.894,
          2397.1020000000003,
          2405.21,
          2413.216,
          2421.12,
          2428.922,
          2436.62,
          2444.2129999999997,
          2451.701,
          2459.083,
          2466.357,
          2473.5229999999997,
          2480.58,
          2487.527,
          2494.363,
          2501.087,
          2507.698,
          2514.195,
          2520.577,
          2526.843,
          2532.992,
          2539.0229999999997,
          2544.935,
          2550.7270000000003,
          2556.397,
          2561.945,
          2567.369,
          2572.669,
          2577.842,
          2582.889,
          2587.8070000000002,
          2592.595,
          2597.2529999999997,
          2601.779,
          2606.1710000000003,
          2610.429,
          2614.551,
          2618.535,
          2622.381,
          2626.087,
          2629.652,
          2633.074,
          2636.3509999999997,
          2639.4829999999997,
          2642.468,
          2645.303,
          2647.989,
          2650.522,
          2652.902,
          2655.1259999999997,
          2657.1940000000004,
          2659.103,
          2660.8520000000003,
          2662.4390000000003,
          2663.863,
          2665.12,
          2666.211,
          2667.132,
          2667.882,
          2668.458,
          2668.86,
          2669.0840000000003,
          2669.1290000000004,
          2668.992,
          2668.672,
          2668.167,
          2667.473,
          2666.5890000000004,
          2665.513,
          2664.241,
          2662.7729999999997,
          2661.1040000000003,
          2659.2329999999997,
          2657.157,
          2654.8740000000003,
          2652.381,
          2649.675,
          2646.7529999999997,
          2643.612,
          2640.2509999999997,
          2636.664,
          2632.85,
          2628.8059999999996,
          2624.527,
          2620.012,
          2615.256,
          2610.257,
          2605.01,
          2599.513,
          2593.761,
          2587.75,
          2581.478,
          2574.94,
          2568.131,
          2561.049,
          2553.688,
          2546.045,
          2538.115,
          2529.893,
          2521.374,
          2512.555,
          2503.429,
          2493.993,
          2484.241,
          2474.167,
          2463.766,
          2453.032,
          2441.96,
          2430.544,
          2418.777,
          2406.654,
          2394.169,
          2381.313,
          2368.081,
          2354.465,
          2340.459,
          2326.055,
          2311.245,
          2296.021,
          2280.376,
          2264.3,
          2247.786,
          2230.824,
          2213.406,
          2195.521,
          2177.161,
          2158.314,
          2138.97,
          2119.12,
          2098.752,
          2077.853,
          2056.413,
          2034.42,
          2011.861,
          1988.7220000000002,
          1964.99,
          1940.6529999999998,
          1915.695,
          1890.1,
          1863.855,
          1836.944,
          1809.35,
          1781.057,
          1752.047,
          1722.3020000000001,
          1691.805,
          1660.536,
          1628.476,
          1595.605,
          1561.904,
          1527.351,
          1491.924,
          1455.6029999999998,
          1418.366,
          1380.19,
          1341.0529999999999,
          1300.932,
          1259.806,
          1217.652,
          1174.45,
          1130.178,
          1084.816,
          1038.347,
          990.753,
          942.0219999999999,
          892.1419999999999,
          841.1060000000001,
          788.909,
          735.557,
          681.055,
          625.422,
          568.681,
          510.87,
          452.033,
          392.231,
          331.54,
          270.048,
          207.865,
          145.114,
          81.94200000000001,
          18.51,
          -45,
          -108.39200000000001,
          -171.456,
          -233.97400000000002,
          -295.718,
          -356.463,
          -415.98400000000004,
          -474.07099999999997,
          -530.526,
          -585.168,
          -637.8430000000001,
          -688.42,
          -736.795,
          -782.8889999999999,
          -826.6519999999999,
          -868.056,
          -907.097,
          -943.79,
          -978.166,
          -1010.2710000000001,
          -1040.162,
          -1067.904,
          -1093.569,
          -1117.233,
          -1138.976,
          -1158.879,
          -1177.02,
          -1193.48,
          -1208.337,
          -1221.667,
          -1233.5439999999999,
          -1244.04,
          -1253.22,
          -1261.152,
          -1267.896,
          -1273.513,
          -1278.057,
          -1281.639,
          -1284.141,
          -1285.777,
          -1286.538,
          -1286.4660000000001,
          -1285.601,
          -1283.98,
          -1281.641,
          -1278.618,
          -1274.942,
          -1270.643,
          -1265.751,
          -1260.2930000000001,
          -1254.2939999999999,
          -1247.778,
          -1240.769,
          -1233.289,
          -1225.359,
          -1216.997,
          -1208.223,
          -1199.053,
          -1189.506,
          -1179.598,
          -1169.3419999999999,
          -1158.754,
          -1147.848,
          -1136.635,
          -1125.13,
          -1113.344,
          -1101.288,
          -1088.973,
          -1076.41,
          -1063.607,
          -1050.576,
          -1037.3239999999998,
          -1023.86,
          -1010.194,
          -996.331,
          -982.2810000000001,
          -968.05,
          -953.6460000000001,
          -939.075,
          -924.3439999999999,
          -909.4580000000001,
          -894.424,
          -879.247,
          -863.933,
          -848.487,
          -832.914,
          -817.2189999999999,
          -801.4069999999999,
          -785.482,
          -769.449,
          -753.312,
          -737.075,
          -720.7410000000001,
          -704.316,
          -687.802,
          -671.202,
          -654.521,
          -637.762,
          -620.927,
          -604.02,
          -587.045,
          -570.003,
          -552.8969999999999,
          -535.732,
          -518.508,
          -501.228,
          -483.89599999999996,
          -466.51300000000003,
          -449.082,
          -431.605,
          -414.085,
          -396.522,
          -378.921,
          -361.282,
          -343.60699999999997,
          -325.899,
          -308.159,
          -290.389,
          -272.591,
          -254.767,
          -236.918,
          -219.046,
          -201.153,
          -183.239,
          -165.30700000000002,
          -147.359,
          -129.394,
          -111.416,
          -93.425,
          -75.423,
          -57.41,
          -39.389,
          -21.36,
          -3.326,
          14.714,
          32.758,
          50.805,
          68.85300000000001,
          86.90100000000001,
          104.949,
          122.99600000000001,
          141.039,
          159.079,
          177.115,
          195.144,
          213.167,
          231.18200000000002,
          249.18900000000002,
          267.186,
          285.173,
          303.149,
          321.113,
          339.064,
          357.001,
          374.923,
          392.83,
          410.721,
          428.595,
          446.45099999999996,
          464.288,
          482.106,
          499.904,
          517.682,
          535.438,
          553.172,
          570.883,
          588.57,
          606.2330000000001,
          623.871,
          641.484,
          659.07,
          676.6289999999999,
          694.1610000000001,
          711.665,
          729.14,
          746.585,
          764.0010000000001,
          781.385,
          798.7389999999999,
          816.06,
          833.3489999999999,
          850.605,
          867.827,
          885.0160000000001,
          902.169,
          919.2869999999999,
          936.3689999999999,
          953.414,
          970.423,
          987.3939999999999,
          1004.326,
          1021.22,
          1038.075,
          1054.89,
          1071.664,
          1088.3980000000001,
          1105.09,
          1121.741,
          1138.348,
          1154.913,
          1171.435,
          1187.912,
          1204.345,
          1220.733,
          1237.075,
          1253.371,
          1269.62,
          1285.823,
          1301.9769999999999,
          1318.0839999999998,
          1334.142,
          1350.151,
          1366.11,
          1382.019,
          1397.8770000000002,
          1413.684,
          1429.4389999999999,
          1445.142,
          1460.793,
          1476.39,
          1491.933,
          1507.4229999999998,
          1522.8570000000002,
          1538.236,
          1553.56,
          1568.8270000000002,
          1584.0379999999998,
          1599.191,
          1614.286,
          1629.3229999999999,
          1644.3010000000002,
          1659.22,
          1674.079,
          1688.8770000000002,
          1703.615,
          1718.2910000000002,
          1732.905,
          1747.457,
          1761.9460000000001,
          1776.371,
          1790.7320000000002,
          1805.0279999999998,
          1819.26,
          1833.425,
          1847.524,
          1861.557,
          1875.5220000000002,
          1889.4189999999999,
          1903.2479999999998,
          1917.0079999999998,
          1930.6979999999999,
          1944.318,
          1957.8670000000002,
          1971.345,
          1984.751,
          1998.085,
          2011.346,
          2024.533,
          2037.646,
          2050.6839999999997,
          2063.647,
          2076.534,
          2089.344,
          2102.077,
          2114.732,
          2127.3089999999997,
          2139.806,
          2152.224,
          2164.562,
          2176.8179999999998,
          2188.993,
          2201.085,
          2213.095,
          2225.021,
          2236.862,
          2248.619,
          2260.29,
          2271.874,
          2283.3720000000003,
          2294.781,
          2306.1020000000003,
          2317.334,
          2328.476,
          2339.528,
          2350.488,
          2361.355,
          2372.13,
          2382.812,
          2393.399,
          2403.89,
          2414.286,
          2424.585,
          2434.786,
          2444.888,
          2454.8920000000003,
          2464.795,
          2474.598,
          2484.298,
          2493.896,
          2503.391,
          2512.781,
          2522.0660000000003,
          2531.244,
          2540.315,
          2549.279,
          2558.133,
          2566.877,
          2575.511,
          2584.032,
          2592.4410000000003,
          2600.736,
          2608.916,
          2616.98,
          2624.927,
          2632.757,
          2640.467,
          2648.0570000000002,
          2655.525,
          2662.8720000000003,
          2670.094,
          2677.1929999999998,
          2684.165,
          2691.01,
          2697.7270000000003,
          2704.315,
          2710.772,
          2717.097,
          2723.289,
          2729.347,
          2735.2690000000002,
          2741.054,
          2746.7009999999996,
          2752.208,
          2757.574,
          2762.797,
          2767.8759999999997,
          2772.81,
          2777.597,
          2782.235,
          2786.723,
          2791.06,
          2795.244,
          2799.2740000000003,
          2803.147,
          2806.862,
          2810.417,
          2813.812,
          2817.0429999999997,
          2820.1090000000004,
          2823.009,
          2825.74,
          2828.301,
          2830.69,
          2832.9040000000005,
          2834.9429999999998,
          2836.803,
          2838.4829999999997,
          2839.9809999999998,
          2841.2940000000003,
          2842.421,
          2843.3590000000004,
          2844.107,
          2844.6609999999996,
          2845.0190000000002,
          2845.18,
          2845.14,
          2844.897,
          2844.449,
          2843.7940000000003,
          2842.927,
          2841.847,
          2840.552,
          2839.0370000000003,
          2837.301,
          2835.34,
          2833.152,
          2830.7340000000004,
          2828.0820000000003,
          2825.1940000000004,
          2822.065,
          2818.6929999999998,
          2815.074,
          2811.205,
          2807.083,
          2802.703,
          2798.062,
          2793.157,
          2787.9829999999997,
          2782.5359999999996,
          2776.813,
          2770.809,
          2764.5190000000002,
          2757.94,
          2751.067,
          2743.8959999999997,
          2736.422,
          2728.639,
          2720.5440000000003,
          2712.13,
          2703.393,
          2694.327,
          2684.927,
          2675.187,
          2665.1020000000003,
          2654.6659999999997,
          2643.8709999999996,
          2632.7129999999997,
          2621.1839999999997,
          2609.278,
          2596.989,
          2584.3089999999997,
          2571.231,
          2557.7470000000003,
          2543.849,
          2529.531,
          2514.784,
          2499.599,
          2483.968,
          2467.882,
          2451.3320000000003,
          2434.308,
          2416.801,
          2398.8,
          2380.2960000000003,
          2361.276,
          2341.732,
          2321.651,
          2301.021,
          2279.83,
          2258.065,
          2235.714,
          2212.764,
          2189.2,
          2165.007,
          2140.172,
          2114.679,
          2088.512,
          2061.655,
          2034.0910000000001,
          2005.8029999999999,
          1976.7720000000002,
          1946.98,
          1916.4089999999999,
          1885.037,
          1852.845,
          1819.8129999999999,
          1785.9170000000001,
          1751.1370000000002,
          1715.4489999999998,
          1678.83,
          1641.257,
          1602.704,
          1563.148,
          1522.5629999999999,
          1480.924,
          1438.205,
          1394.381,
          1349.4260000000002,
          1303.316,
          1256.025,
          1207.532,
          1157.8139999999999,
          1106.851,
          1054.624,
          1001.1210000000001,
          946.328,
          890.2410000000001,
          832.857,
          774.183,
          714.2310000000001,
          653.026,
          590.599,
          526.998,
          462.28,
          396.523,
          329.819,
          262.278,
          194.03099999999998,
          125.23100000000001,
          56.048,
          -13.325999999999999,
          -82.681,
          -151.793,
          -220.425,
          -288.33099999999996,
          -355.264,
          -420.981,
          -485.246,
          -547.839,
          -608.561,
          -667.232,
          -723.704,
          -777.8530000000001,
          -829.5880000000001,
          -878.8430000000001,
          -925.58,
          -969.7869999999999,
          -1011.471,
          -1050.66,
          -1087.396,
          -1121.737,
          -1153.747,
          -1183.5,
          -1211.076,
          -1236.557,
          -1260.027,
          -1281.5710000000001,
          -1301.275,
          -1319.219,
          -1335.487,
          -1350.1570000000002,
          -1363.306,
          -1375.005,
          -1385.3270000000002,
          -1394.3370000000002,
          -1402.1,
          -1408.6760000000002,
          -1414.1229999999998,
          -1418.496,
          -1421.846,
          -1424.223,
          -1425.672,
          -1426.239,
          -1425.964,
          -1424.888,
          -1423.045,
          -1420.474,
          -1417.2060000000001,
          -1413.2720000000002,
          -1408.703,
          -1403.5279999999998,
          -1397.773,
          -1391.4620000000002,
          -1384.621,
          -1377.2720000000002,
          -1369.4370000000001,
          -1361.135,
          -1352.388,
          -1343.2120000000002,
          -1333.626,
          -1323.6470000000002,
          -1313.2910000000002,
          -1302.573,
          -1291.506,
          -1280.106,
          -1268.385,
          -1256.356,
          -1244.03,
          -1231.42,
          -1218.537,
          -1205.39,
          -1191.99,
          -1178.346,
          -1164.4669999999999,
          -1150.364,
          -1136.0430000000001,
          -1121.513,
          -1106.781,
          -1091.856,
          -1076.744,
          -1061.453,
          -1045.988,
          -1030.356,
          -1014.564,
          -998.6160000000001,
          -982.52,
          -966.28,
          -949.9010000000001,
          -933.3889999999999,
          -916.7489999999999,
          -899.985,
          -883.102,
          -866.1039999999999,
          -848.9960000000001,
          -831.7810000000001,
          -814.4639999999999,
          -797.048,
          -779.538,
          -761.936,
          -744.2460000000001,
          -726.472,
          -708.617,
          -690.683,
          -672.675,
          -654.595,
          -636.445,
          -618.23,
          -599.95,
          -581.61,
          -563.211,
          -544.757,
          -526.249,
          -507.69,
          -489.082,
          -470.42800000000005,
          -451.72900000000004,
          -432.98800000000006,
          -414.20599999999996,
          -395.38599999999997,
          -376.53,
          -357.639,
          -338.716,
          -319.762,
          -300.779,
          -281.769,
          -262.733,
          -243.673,
          -224.59,
          -205.487,
          -186.364,
          -167.22400000000002,
          -148.067,
          -128.895,
          -109.71,
          -90.512,
          -71.304,
          -52.086000000000006,
          -32.86,
          -13.626,
          5.6129999999999995,
          24.857,
          44.104,
          63.353,
          82.604,
          101.855,
          121.104,
          140.352,
          159.596,
          178.83599999999998,
          198.071,
          217.3,
          236.521,
          255.734,
          274.939,
          294.133,
          313.316,
          332.48699999999997,
          351.645,
          370.79,
          389.92,
          409.035,
          428.134,
          447.216,
          466.28,
          485.325,
          504.351,
          523.356,
          542.341,
          561.304,
          580.244,
          599.161,
          618.054,
          636.922,
          655.765,
          674.582,
          693.372,
          712.1339999999999,
          730.868,
          749.573,
          768.2489999999999,
          786.8939999999999,
          805.508,
          824.091,
          842.6419999999999,
          861.159,
          879.643,
          898.0930000000001,
          916.508,
          934.888,
          953.232,
          971.538,
          989.808,
          1008.04,
          1026.233,
          1044.387,
          1062.501,
          1080.576,
          1098.609,
          1116.6,
          1134.55,
          1152.4569999999999,
          1170.3210000000001,
          1188.141,
          1205.9160000000002,
          1223.647,
          1241.3319999999999,
          1258.97,
          1276.562,
          1294.107,
          1311.604,
          1329.0529999999999,
          1346.4520000000002,
          1363.8029999999999,
          1381.102,
          1398.352,
          1415.55,
          1432.6960000000001,
          1449.79,
          1466.8310000000001,
          1483.818,
          1500.7520000000002,
          1517.631,
          1534.454,
          1551.2220000000002,
          1567.934,
          1584.588,
          1601.1860000000001,
          1617.725,
          1634.2060000000001,
          1650.6270000000002,
          1666.989,
          1683.2910000000002,
          1699.531,
          1715.711,
          1731.828,
          1747.8829999999998,
          1763.875,
          1779.8020000000001,
          1795.6660000000002,
          1811.465,
          1827.1979999999999,
          1842.865,
          1858.4660000000001,
          1873.999,
          1889.465,
          1904.862,
          1920.19,
          1935.4479999999999,
          1950.636,
          1965.753,
          1980.799,
          1995.773,
          2010.674,
          2025.501,
          2040.255,
          2054.9339999999997,
          2069.5370000000003,
          2084.065,
          2098.516,
          2112.89,
          2127.186,
          2141.404,
          2155.5429999999997,
          2169.601,
          2183.5789999999997,
          2197.476,
          2211.291,
          2225.024,
          2238.673,
          2252.238,
          2265.719,
          2279.114,
          2292.424,
          2305.646,
          2318.781,
          2331.827,
          2344.785,
          2357.653,
          2370.43,
          2383.116,
          2395.71,
          2408.2110000000002,
          2420.618,
          2432.931,
          2445.149,
          2457.271,
          2469.2960000000003,
          2481.223,
          2493.051,
          2504.781,
          2516.409,
          2527.937,
          2539.363,
          2550.686,
          2561.906,
          2573.02,
          2584.029,
          2594.9320000000002,
          2605.7270000000003,
          2616.4139999999998,
          2626.992,
          2637.46,
          2647.816,
          2658.06,
          2668.191,
          2678.2070000000003,
          2688.1079999999997,
          2697.893,
          2707.5609999999997,
          2717.11,
          2726.539,
          2735.848,
          2745.035,
          2754.1,
          2763.04,
          2771.855,
          2780.5440000000003,
          2789.1059999999998,
          2797.539,
          2805.842,
          2814.014,
          2822.053,
          2829.9590000000003,
          2837.73,
          2845.365,
          2852.862,
          2860.22,
          2867.438,
          2874.514,
          2881.447,
          2888.236,
          2894.8790000000004,
          2901.3740000000003,
          2907.7209999999995,
          2913.917,
          2919.961,
          2925.8509999999997,
          2931.587,
          2937.1659999999997,
          2942.586,
          2947.847,
          2952.945,
          2957.88,
          2962.65,
          2967.2529999999997,
          2971.688,
          2975.9509999999996,
          2980.042,
          2983.9590000000003,
          2987.699,
          2991.261,
          2994.643,
          2997.842,
          3000.857,
          3003.685,
          3006.325,
          3008.7729999999997,
          3011.0290000000005,
          3013.0890000000004,
          3014.9509999999996,
          3016.613,
          3018.072,
          3019.3259999999996,
          3020.373,
          3021.21,
          3021.8340000000003,
          3022.243,
          3022.434,
          3022.4040000000005,
          3022.15,
          3021.67,
          3020.96,
          3020.018,
          3018.84,
          3017.4240000000004,
          3015.765,
          3013.861,
          3011.7090000000003,
          3009.305,
          3006.6459999999997,
          3003.728,
          3000.547,
          2997.1,
          2993.382,
          2989.39,
          2985.1209999999996,
          2980.5690000000004,
          2975.7309999999998,
          2970.6020000000003,
          2965.179,
          2959.4559999999997,
          2953.428,
          2947.092,
          2940.442,
          2933.474,
          2926.1809999999996,
          2918.5609999999997,
          2910.605,
          2902.31,
          2893.67,
          2884.678,
          2875.329,
          2865.617,
          2855.5359999999996,
          2845.079,
          2834.239,
          2823.009,
          2811.384,
          2799.355,
          2786.915,
          2774.0570000000002,
          2760.772,
          2747.053,
          2732.89,
          2718.277,
          2703.204,
          2687.6620000000003,
          2671.6409999999996,
          2655.132,
          2638.125,
          2620.61,
          2602.576,
          2584.011,
          2564.906,
          2545.248,
          2525.026,
          2504.226,
          2482.8360000000002,
          2460.843,
          2438.2329999999997,
          2414.992,
          2391.105,
          2366.5570000000002,
          2341.333,
          2315.417,
          2288.791,
          2261.438,
          2233.342,
          2204.482,
          2174.841,
          2144.3979999999997,
          2113.133,
          2081.024,
          2048.052,
          2014.192,
          1979.422,
          1943.7179999999998,
          1907.055,
          1869.4089999999999,
          1830.754,
          1791.0620000000001,
          1750.308,
          1708.464,
          1665.501,
          1621.391,
          1576.105,
          1529.615,
          1481.892,
          1432.908,
          1382.634,
          1331.0439999999999,
          1278.113,
          1223.815,
          1168.131,
          1111.0410000000002,
          1052.531,
          992.5889999999999,
          931.2139999999999,
          868.404,
          804.174,
          738.54,
          671.5369999999999,
          603.2080000000001,
          533.612,
          462.825,
          390.94199999999995,
          318.077,
          244.36599999999999,
          169.965,
          95.056,
          19.84,
          -55.461000000000006,
          -130.606,
          -205.342,
          -279.407,
          -352.53,
          -424.449,
          -494.904,
          -563.654,
          -630.475,
          -695.17,
          -757.567,
          -817.528,
          -874.942,
          -929.732,
          -981.8480000000001,
          -1031.266,
          -1077.99,
          -1122.04,
          -1163.4589999999998,
          -1202.299,
          -1238.628,
          -1272.52,
          -1304.057,
          -1333.325,
          -1360.412,
          -1385.4070000000002,
          -1408.4,
          -1429.479,
          -1448.731,
          -1466.2379999999998,
          -1482.0829999999999,
          -1496.345,
          -1509.098,
          -1520.414,
          -1530.3629999999998,
          -1539.0079999999998,
          -1546.414,
          -1552.639,
          -1557.739,
          -1561.766,
          -1564.7720000000002,
          -1566.8029999999999,
          -1567.906,
          -1568.1229999999998,
          -1567.494,
          -1566.057,
          -1563.849,
          -1560.904,
          -1557.253,
          -1552.9289999999999,
          -1547.961,
          -1542.376,
          -1536.2,
          -1529.457,
          -1522.1729999999998,
          -1514.369,
          -1506.067,
          -1497.287,
          -1488.047,
          -1478.368,
          -1468.265,
          -1457.757,
          -1446.858,
          -1435.5839999999998,
          -1423.9489999999998,
          -1411.967,
          -1399.651,
          -1387.014,
          -1374.068,
          -1360.825,
          -1347.295,
          -1333.49,
          -1319.418,
          -1305.0910000000001,
          -1290.516,
          -1275.704,
          -1260.662,
          -1245.4,
          -1229.924,
          -1214.243,
          -1198.363,
          -1182.2930000000001,
          -1166.037,
          -1149.604,
          -1133,
          -1116.229,
          -1099.299,
          -1082.214,
          -1064.981,
          -1047.604,
          -1030.089,
          -1012.44,
          -994.6619999999999,
          -976.76,
          -958.738,
          -940.6010000000001,
          -922.352,
          -903.995,
          -885.535,
          -866.9739999999999,
          -848.317,
          -829.568,
          -810.7289999999999,
          -791.804,
          -772.796,
          -753.7080000000001,
          -734.544,
          -715.306,
          -695.9960000000001,
          -676.6189999999999,
          -657.176,
          -637.67,
          -618.104,
          -598.48,
          -578.8,
          -559.067,
          -539.284,
          -519.452,
          -499.57300000000004,
          -479.65,
          -459.685,
          -439.68,
          -419.63699999999994,
          -399.55699999999996,
          -379.44199999999995,
          -359.295,
          -339.11699999999996,
          -318.91,
          -298.676,
          -278.416,
          -258.131,
          -237.824,
          -217.49599999999998,
          -197.149,
          -176.78400000000002,
          -156.40200000000002,
          -136.005,
          -115.594,
          -95.171,
          -74.737,
          -54.293,
          -33.841,
          -13.382,
          7.082999999999999,
          27.552,
          48.025,
          68.5,
          88.977,
          109.45299999999999,
          129.928,
          150.401,
          170.87099999999998,
          191.33599999999998,
          211.796,
          232.24900000000002,
          252.695,
          273.133,
          293.56,
          313.978,
          334.384,
          354.778,
          375.159,
          395.525,
          415.87699999999995,
          436.213,
          456.531,
          476.833,
          497.115,
          517.379,
          537.622,
          557.844,
          578.044,
          598.222,
          618.376,
          638.506,
          658.6110000000001,
          678.691,
          698.7439999999999,
          718.7689999999999,
          738.7669999999999,
          758.7360000000001,
          778.675,
          798.585,
          818.4630000000001,
          838.31,
          858.1239999999999,
          877.905,
          897.653,
          917.3660000000001,
          937.044,
          956.686,
          976.2919999999999,
          995.8610000000001,
          1015.3910000000001,
          1034.884,
          1054.337,
          1073.75,
          1093.123,
          1112.455,
          1131.745,
          1150.992,
          1170.197,
          1189.358,
          1208.474,
          1227.546,
          1246.572,
          1265.5510000000002,
          1284.484,
          1303.37,
          1322.207,
          1340.996,
          1359.735,
          1378.424,
          1397.0629999999999,
          1415.65,
          1434.1860000000001,
          1452.6689999999999,
          1471.1,
          1489.476,
          1507.7979999999998,
          1526.065,
          1544.277,
          1562.433,
          1580.531,
          1598.5729999999999,
          1616.556,
          1634.481,
          1652.346,
          1670.152,
          1687.8970000000002,
          1705.5810000000001,
          1723.203,
          1740.763,
          1758.26,
          1775.693,
          1793.0620000000001,
          1810.366,
          1827.604,
          1844.777,
          1861.882,
          1878.92,
          1895.89,
          1912.7920000000001,
          1929.6229999999998,
          1946.385,
          1963.0770000000002,
          1979.6970000000001,
          1996.244,
          2012.72,
          2029.122,
          2045.4489999999998,
          2061.703,
          2077.88,
          2093.982,
          2110.007,
          2125.955,
          2141.824,
          2157.615,
          2173.326,
          2188.9570000000003,
          2204.507,
          2219.975,
          2235.361,
          2250.6639999999998,
          2265.883,
          2281.0170000000003,
          2296.0660000000003,
          2311.029,
          2325.905,
          2340.694,
          2355.394,
          2370.005,
          2384.526,
          2398.956,
          2413.295,
          2427.542,
          2441.695,
          2455.755,
          2469.72,
          2483.589,
          2497.361,
          2511.0370000000003,
          2524.614,
          2538.093,
          2551.471,
          2564.749,
          2577.925,
          2590.998,
          2603.968,
          2616.834,
          2629.594,
          2642.248,
          2654.795,
          2667.2340000000004,
          2679.5640000000003,
          2691.783,
          2703.8920000000003,
          2715.888,
          2727.772,
          2739.5409999999997,
          2751.195,
          2762.7329999999997,
          2774.1540000000005,
          2785.4559999999997,
          2796.639,
          2807.702,
          2818.6420000000003,
          2829.46,
          2840.1540000000005,
          2850.723,
          2861.1659999999997,
          2871.4809999999998,
          2881.6679999999997,
          2891.725,
          2901.651,
          2911.4440000000004,
          2921.1040000000003,
          2930.6279999999997,
          2940.0170000000003,
          2949.268,
          2958.38,
          2967.3520000000003,
          2976.1820000000002,
          2984.869,
          2993.4120000000003,
          3001.809,
          3010.059,
          3018.16,
          3026.11,
          3033.909,
          3041.555,
          3049.045,
          3056.3790000000004,
          3063.554,
          3070.57,
          3077.4240000000004,
          3084.115,
          3090.6409999999996,
          3097,
          3103.191,
          3109.212,
          3115.06,
          3120.7340000000004,
          3126.2329999999997,
          3131.553,
          3136.6940000000004,
          3141.653,
          3146.428,
          3151.0170000000003,
          3155.4179999999997,
          3159.6279999999997,
          3163.6459999999997,
          3167.47,
          3171.0959999999995,
          3174.5240000000003,
          3177.7490000000003,
          3180.7709999999997,
          3183.587,
          3186.1929999999998,
          3188.5879999999997,
          3190.7690000000002,
          3192.7329999999997,
          3194.4770000000003,
          3196,
          3197.298,
          3198.368,
          3199.2070000000003,
          3199.813,
          3200.1820000000002,
          3200.312,
          3200.198,
          3199.8390000000004,
          3199.23,
          3198.368,
          3197.25,
          3195.8720000000003,
          3194.2309999999998,
          3192.323,
          3190.1440000000002,
          3187.691,
          3184.96,
          3181.946,
          3178.645,
          3175.054,
          3171.1679999999997,
          3166.982,
          3162.492,
          3157.6940000000004,
          3152.583,
          3147.155,
          3141.403,
          3135.322,
          3128.909,
          3122.157,
          3115.0609999999997,
          3107.616,
          3099.815,
          3091.653,
          3083.1240000000003,
          3074.2209999999995,
          3064.938,
          3055.2690000000002,
          3045.2070000000003,
          3034.745,
          3023.875,
          3012.591,
          3000.885,
          2988.7490000000003,
          2976.175,
          2963.155,
          2949.6809999999996,
          2935.744,
          2921.335,
          2906.4440000000004,
          2891.063,
          2875.1820000000002,
          2858.79,
          2841.877,
          2824.4320000000002,
          2806.4440000000004,
          2787.903,
          2768.796,
          2749.11,
          2728.8340000000003,
          2707.953,
          2686.4559999999997,
          2664.328,
          2641.555,
          2618.121,
          2594.013,
          2569.2129999999997,
          2543.705,
          2517.473,
          2490.5,
          2462.766,
          2434.252,
          2404.942,
          2374.813,
          2343.845,
          2312.016,
          2279.305,
          2245.689,
          2211.143,
          2175.644,
          2139.166,
          2101.683,
          2063.169,
          2023.596,
          1982.9360000000001,
          1941.1589999999999,
          1898.236,
          1854.1370000000002,
          1808.83,
          1762.285,
          1714.4679999999998,
          1665.35,
          1614.896,
          1563.076,
          1509.8570000000002,
          1455.211,
          1399.106,
          1341.516,
          1282.415,
          1221.782,
          1159.596,
          1095.844,
          1030.52,
          963.62,
          895.154,
          825.1389999999999,
          753.6039999999999,
          680.592,
          606.161,
          530.389,
          453.369,
          375.22,
          296.08299999999997,
          216.11900000000003,
          135.517,
          54.489,
          -26.730999999999998,
          -107.88799999999999,
          -188.71200000000002,
          -268.921,
          -348.228,
          -426.346,
          -502.995,
          -577.91,
          -650.846,
          -721.585,
          -789.933,
          -855.7330000000001,
          -918.8589999999999,
          -979.22,
          -1036.752,
          -1091.423,
          -1143.229,
          -1192.1860000000001,
          -1238.3310000000001,
          -1281.7169999999999,
          -1322.412,
          -1360.489,
          -1396.0339999999999,
          -1429.135,
          -1459.884,
          -1488.376,
          -1514.703,
          -1538.9589999999998,
          -1561.236,
          -1581.6229999999998,
          -1600.207,
          -1617.07,
          -1632.2939999999999,
          -1645.955,
          -1658.1270000000002,
          -1668.881,
          -1678.2579999999998,
          -1686.394,
          -1693.277,
          -1698.99,
          -1703.585,
          -1707.114,
          -1709.6270000000002,
          -1711.168,
          -1711.7820000000002,
          -1711.51,
          -1710.391,
          -1708.4620000000002,
          -1705.759,
          -1702.3139999999999,
          -1698.16,
          -1693.326,
          -1687.8410000000001,
          -1681.731,
          -1675.023,
          -1667.7420000000002,
          -1659.9089999999999,
          -1651.5479999999998,
          -1642.6779999999999,
          -1633.3210000000001,
          -1623.495,
          -1613.219,
          -1602.509,
          -1591.3829999999998,
          -1579.855,
          -1567.942,
          -1555.656,
          -1543.013,
          -1530.025,
          -1516.705,
          -1503.065,
          -1489.1170000000002,
          -1474.871,
          -1460.339,
          -1445.529,
          -1430.453,
          -1415.119,
          -1399.537,
          -1383.715,
          -1367.661,
          -1351.384,
          -1334.891,
          -1318.19,
          -1301.287,
          -1284.19,
          -1266.905,
          -1249.4389999999999,
          -1231.797,
          -1213.987,
          -1196.012,
          -1177.88,
          -1159.596,
          -1141.163,
          -1122.589,
          -1103.876,
          -1085.031,
          -1066.058,
          -1046.96,
          -1027.743,
          -1008.41,
          -988.965,
          -969.413,
          -949.757,
          -930,
          -910.1460000000001,
          -890.199,
          -870.1619999999999,
          -850.038,
          -829.83,
          -809.5419999999999,
          -789.176,
          -768.735,
          -748.222,
          -727.64,
          -706.992,
          -686.279,
          -665.505,
          -644.672,
          -623.7819999999999,
          -602.8380000000001,
          -581.842,
          -560.7959999999999,
          -539.703,
          -518.564,
          -497.381,
          -476.158,
          -454.895,
          -433.594,
          -412.25800000000004,
          -390.88699999999994,
          -369.485,
          -348.05300000000005,
          -326.592,
          -305.105,
          -283.592,
          -262.055,
          -240.497,
          -218.918,
          -197.32,
          -175.705,
          -154.07399999999998,
          -132.428,
          -110.77,
          -89.09899999999999,
          -67.418,
          -45.728,
          -24.03,
          -2.326,
          19.384,
          41.098,
          62.81399999999999,
          84.53200000000001,
          106.251,
          127.96799999999999,
          149.684,
          171.39700000000002,
          193.106,
          214.81,
          236.507,
          258.197,
          279.879,
          301.552,
          323.214,
          344.865,
          366.504,
          388.129,
          409.74,
          431.336,
          452.915,
          474.478,
          496.023,
          517.549,
          539.055,
          560.5409999999999,
          582.005,
          603.447,
          624.866,
          646.26,
          667.63,
          688.9739999999999,
          710.2919999999999,
          731.5830000000001,
          752.845,
          774.079,
          795.2819999999999,
          816.456,
          837.5980000000001,
          858.7080000000001,
          879.7860000000001,
          900.83,
          921.84,
          942.814,
          963.753,
          984.6560000000001,
          1005.5210000000001,
          1026.349,
          1047.138,
          1067.887,
          1088.597,
          1109.265,
          1129.892,
          1150.4769999999999,
          1171.019,
          1191.518,
          1211.972,
          1232.381,
          1252.745,
          1273.062,
          1293.3319999999999,
          1313.5539999999999,
          1333.7279999999998,
          1353.8529999999998,
          1373.9289999999999,
          1393.953,
          1413.9270000000001,
          1433.849,
          1453.7179999999998,
          1473.5339999999999,
          1493.296,
          1513.004,
          1532.6570000000002,
          1552.254,
          1571.7939999999999,
          1591.277,
          1610.703,
          1630.069,
          1649.3770000000002,
          1668.625,
          1687.8120000000001,
          1706.9379999999999,
          1726.0020000000002,
          1745.003,
          1763.942,
          1782.816,
          1801.625,
          1820.37,
          1839.0479999999998,
          1857.66,
          1876.204,
          1894.68,
          1913.088,
          1931.4260000000002,
          1949.694,
          1967.891,
          1986.016,
          2004.069,
          2022.049,
          2039.9560000000001,
          2057.788,
          2075.545,
          2093.226,
          2110.831,
          2128.3579999999997,
          2145.8070000000002,
          2163.177,
          2180.468,
          2197.679,
          2214.808,
          2231.856,
          2248.821,
          2265.703,
          2282.501,
          2299.214,
          2315.842,
          2332.383,
          2348.8360000000002,
          2365.202,
          2381.479,
          2397.666,
          2413.763,
          2429.768,
          2445.681,
          2461.502,
          2477.228,
          2492.86,
          2508.396,
          2523.8360000000002,
          2539.179,
          2554.423,
          2569.569,
          2584.614,
          2599.5589999999997,
          2614.402,
          2629.1420000000003,
          2643.7790000000005,
          2658.3109999999997,
          2672.737,
          2687.0570000000002,
          2701.27,
          2715.3740000000003,
          2729.369,
          2743.2529999999997,
          2757.026,
          2770.6859999999997,
          2784.2329999999997,
          2797.6659999999997,
          2810.9829999999997,
          2824.183,
          2837.265,
          2850.228,
          2863.072,
          2875.7940000000003,
          2888.3940000000002,
          2900.8709999999996,
          2913.223,
          2925.449,
          2937.5490000000004,
          2949.5209999999997,
          2961.363,
          2973.075,
          2984.655,
          2996.1009999999997,
          3007.414,
          3018.591,
          3029.631,
          3040.532,
          3051.2940000000003,
          3061.915,
          3072.393,
          3082.7270000000003,
          3092.9159999999997,
          3102.9590000000003,
          3112.853,
          3122.597,
          3132.191,
          3141.631,
          3150.9179999999997,
          3160.048,
          3169.0209999999997,
          3177.835,
          3186.489,
          3194.9790000000003,
          3203.3059999999996,
          3211.467,
          3219.46,
          3227.283,
          3234.9359999999997,
          3242.415,
          3249.719,
          3256.847,
          3263.795,
          3270.563,
          3277.1479999999997,
          3283.5490000000004,
          3289.762,
          3295.7859999999996,
          3301.62,
          3307.26,
          3312.705,
          3317.952,
          3322.9990000000003,
          3327.844,
          3332.4829999999997,
          3336.9159999999997,
          3341.139,
          3345.1490000000003,
          3348.946,
          3352.5240000000003,
          3355.883,
          3359.02,
          3361.9309999999996,
          3364.613,
          3367.065,
          3369.282,
          3371.263,
          3373.0029999999997,
          3374.5009999999997,
          3375.752,
          3376.7529999999997,
          3377.502,
          3377.995,
          3378.228,
          3378.198,
          3377.901,
          3377.3340000000003,
          3376.493,
          3375.3740000000003,
          3373.973,
          3372.2859999999996,
          3370.309,
          3368.038,
          3365.469,
          3362.598,
          3359.4190000000003,
          3355.928,
          3352.1209999999996,
          3347.993,
          3343.538,
          3338.752,
          3333.63,
          3328.167,
          3322.3559999999998,
          3316.1929999999998,
          3309.671,
          3302.7859999999996,
          3295.53,
          3287.8990000000003,
          3279.884,
          3271.4809999999998,
          3262.683,
          3253.4809999999998,
          3243.87,
          3233.843,
          3223.3909999999996,
          3212.508,
          3201.185,
          3189.415,
          3177.1890000000003,
          3164.498,
          3151.335,
          3137.6890000000003,
          3123.552,
          3108.914,
          3093.765,
          3078.095,
          3061.8940000000002,
          3045.15,
          3027.853,
          3009.991,
          2991.551,
          2972.5229999999997,
          2952.893,
          2932.6490000000003,
          2911.775,
          2890.26,
          2868.0890000000004,
          2845.245,
          2821.715,
          2797.482,
          2772.53,
          2746.842,
          2720.4,
          2693.1859999999997,
          2665.1809999999996,
          2636.365,
          2606.719,
          2576.221,
          2544.85,
          2512.584,
          2479.399,
          2445.272,
          2410.177,
          2374.09,
          2336.9829999999997,
          2298.83,
          2259.6020000000003,
          2219.269,
          2177.804,
          2135.173,
          2091.347,
          2046.2920000000001,
          1999.975,
          1952.3629999999998,
          1903.421,
          1853.114,
          1801.406,
          1748.264,
          1693.65,
          1637.53,
          1579.871,
          1520.638,
          1459.8010000000002,
          1397.33,
          1333.2,
          1267.387,
          1199.875,
          1130.652,
          1059.713,
          987.063,
          912.716,
          836.7,
          759.057,
          679.842,
          599.134,
          517.0269999999999,
          433.644,
          349.125,
          263.64099999999996,
          177.389,
          90.588,
          3.485,
          -83.65299999999999,
          -170.53799999999998,
          -256.872,
          -342.346,
          -426.652,
          -509.49,
          -590.571,
          -669.6289999999999,
          -746.42,
          -820.735,
          -892.3960000000001,
          -961.2589999999999,
          -1027.218,
          -1090.198,
          -1150.1580000000001,
          -1207.0819999999999,
          -1260.984,
          -1311.895,
          -1359.868,
          -1404.9679999999998,
          -1447.2720000000002,
          -1486.866,
          -1523.842,
          -1558.295,
          -1590.3239999999998,
          -1620.026,
          -1647.5,
          -1672.844,
          -1696.149,
          -1717.509,
          -1737.0120000000002,
          -1754.744,
          -1770.787,
          -1785.2179999999998,
          -1798.1129999999998,
          -1809.5439999999999,
          -1819.5770000000002,
          -1828.279,
          -1835.7089999999998,
          -1841.925,
          -1846.983,
          -1850.9360000000001,
          -1853.832,
          -1855.7179999999998,
          -1856.64,
          -1856.639,
          -1855.755,
          -1854.026,
          -1851.487,
          -1848.174,
          -1844.118,
          -1839.35,
          -1833.899,
          -1827.793,
          -1821.057,
          -1813.719,
          -1805.8,
          -1797.325,
          -1788.3139999999999,
          -1778.787,
          -1768.766,
          -1758.267,
          -1747.31,
          -1735.912,
          -1724.088,
          -1711.854,
          -1699.226,
          -1686.2160000000001,
          -1672.84,
          -1659.111,
          -1645.04,
          -1630.639,
          -1615.921,
          -1600.896,
          -1585.575,
          -1569.9679999999998,
          -1554.085,
          -1537.935,
          -1521.527,
          -1504.871,
          -1487.974,
          -1470.844,
          -1453.489,
          -1435.918,
          -1418.136,
          -1400.151,
          -1381.969,
          -1363.5970000000002,
          -1345.0420000000001,
          -1326.309,
          -1307.404,
          -1288.3339999999998,
          -1269.1019999999999,
          -1249.715,
          -1230.178,
          -1210.496,
          -1190.673,
          -1170.714,
          -1150.623,
          -1130.406,
          -1110.065,
          -1089.606,
          -1069.032,
          -1048.347,
          -1027.555,
          -1006.66,
          -985.664,
          -964.572,
          -943.3860000000001,
          -922.1110000000001,
          -900.7489999999999,
          -879.303,
          -857.7760000000001,
          -836.172,
          -814.493,
          -792.7410000000001,
          -770.92,
          -749.0319999999999,
          -727.079,
          -705.065,
          -682.9910000000001,
          -660.86,
          -638.675,
          -616.437,
          -594.149,
          -571.812,
          -549.43,
          -527.004,
          -504.536,
          -482.027,
          -459.481,
          -436.899,
          -414.283,
          -391.634,
          -368.954,
          -346.245,
          -323.509,
          -300.748,
          -277.962,
          -255.15400000000002,
          -232.326,
          -209.47799999999998,
          -186.612,
          -163.73,
          -140.833,
          -117.92299999999999,
          -95.001,
          -72.068,
          -49.126000000000005,
          -26.176,
          -3.219,
          19.743,
          42.708999999999996,
          65.678,
          88.648,
          111.619,
          134.589,
          157.55700000000002,
          180.52200000000002,
          203.483,
          226.438,
          249.387,
          272.329,
          295.26099999999997,
          318.184,
          341.096,
          363.99699999999996,
          386.885,
          409.75800000000004,
          432.61699999999996,
          455.461,
          478.287,
          501.096,
          523.886,
          546.6569999999999,
          569.4069999999999,
          592.136,
          614.842,
          637.525,
          660.184,
          682.818,
          705.426,
          728.008,
          750.561,
          773.087,
          795.5830000000001,
          818.048,
          840.4830000000001,
          862.8860000000001,
          885.257,
          907.5939999999999,
          929.8969999999999,
          952.164,
          974.3960000000001,
          996.591,
          1018.7489999999999,
          1040.869,
          1062.95,
          1084.991,
          1106.991,
          1128.95,
          1150.868,
          1172.742,
          1194.573,
          1216.359,
          1238.101,
          1259.797,
          1281.4460000000001,
          1303.048,
          1324.601,
          1346.106,
          1367.5620000000001,
          1388.967,
          1410.3220000000001,
          1431.624,
          1452.875,
          1474.0720000000001,
          1495.215,
          1516.3029999999999,
          1537.3370000000002,
          1558.3139999999999,
          1579.234,
          1600.0970000000002,
          1620.902,
          1641.6470000000002,
          1662.3329999999999,
          1682.9589999999998,
          1703.523,
          1724.025,
          1744.465,
          1764.842,
          1785.154,
          1805.402,
          1825.5839999999998,
          1845.7,
          1865.749,
          1885.73,
          1905.642,
          1925.486,
          1945.259,
          1964.961,
          1984.592,
          2004.151,
          2023.6370000000002,
          2043.049,
          2062.387,
          2081.649,
          2100.835,
          2119.944,
          2138.976,
          2157.929,
          2176.803,
          2195.597,
          2214.31,
          2232.942,
          2251.492,
          2269.958,
          2288.34,
          2306.638,
          2324.849,
          2342.975,
          2361.013,
          2378.9629999999997,
          2396.824,
          2414.596,
          2432.276,
          2449.865,
          2467.362,
          2484.766,
          2502.075,
          2519.29,
          2536.408,
          2553.43,
          2570.353,
          2587.179,
          2603.904,
          2620.529,
          2637.053,
          2653.474,
          2669.792,
          2686.006,
          2702.114,
          2718.116,
          2734.011,
          2749.797,
          2765.474,
          2781.0409999999997,
          2796.4959999999996,
          2811.8390000000004,
          2827.0679999999998,
          2842.183,
          2857.1820000000002,
          2872.0640000000003,
          2886.829,
          2901.475,
          2916,
          2930.405,
          2944.687,
          2958.8459999999995,
          2972.88,
          2986.788,
          3000.5690000000004,
          3014.222,
          3027.745,
          3041.137,
          3054.3979999999997,
          3067.525,
          3080.5170000000003,
          3093.373,
          3106.092,
          3118.673,
          3131.113,
          3143.4120000000003,
          3155.5690000000004,
          3167.5809999999997,
          3179.448,
          3191.167,
          3202.738,
          3214.159,
          3225.428,
          3236.5440000000003,
          3247.506,
          3258.3109999999997,
          3268.958,
          3279.446,
          3289.7729999999997,
          3299.9359999999997,
          3309.9359999999997,
          3319.7690000000002,
          3329.434,
          3338.929,
          3348.252,
          3357.403,
          3366.3779999999997,
          3375.175,
          3383.7940000000003,
          3392.2309999999998,
          3400.486,
          3408.555,
          3416.437,
          3424.13,
          3431.631,
          3438.9390000000003,
          3446.052,
          3452.966,
          3459.68,
          3466.191,
          3472.498,
          3478.597,
          3484.487,
          3490.164,
          3495.627,
          3500.873,
          3505.8990000000003,
          3510.702,
          3515.28,
          3519.6290000000004,
          3523.748,
          3527.634,
          3531.282,
          3534.692,
          3537.8579999999997,
          3540.7790000000005,
          3543.4509999999996,
          3545.87,
          3548.035,
          3549.94,
          3551.583,
          3552.96,
          3554.0690000000004,
          3554.9040000000005,
          3555.4629999999997,
          3555.741,
          3555.735,
          3555.441,
          3554.8540000000003,
          3553.9709999999995,
          3552.7870000000003,
          3551.298,
          3549.4990000000003,
          3547.386,
          3544.955,
          3542.2,
          3539.117,
          3535.7,
          3531.945,
          3527.847,
          3523.3990000000003,
          3518.597,
          3513.4359999999997,
          3507.908,
          3502.009,
          3495.732,
          3489.07,
          3482.0190000000002,
          3474.571,
          3466.719,
          3458.4570000000003,
          3449.778,
          3440.6740000000004,
          3431.137,
          3421.1609999999996,
          3410.736,
          3399.8559999999998,
          3388.512,
          3376.696,
          3364.397,
          3351.6079999999997,
          3338.3190000000004,
          3324.52,
          3310.202,
          3295.3540000000003,
          3279.966,
          3264.027,
          3247.526,
          3230.452,
          3212.7909999999997,
          3194.533,
          3175.664,
          3156.171,
          3136.042,
          3115.261,
          3093.815,
          3071.6890000000003,
          3048.867,
          3025.333,
          3001.072,
          2976.065,
          2950.296,
          2923.7459999999996,
          2896.3959999999997,
          2868.228,
          2839.22,
          2809.3520000000003,
          2778.6020000000003,
          2746.947,
          2714.366,
          2680.833,
          2646.324,
          2610.813,
          2574.275,
          2536.679,
          2498,
          2458.206,
          2417.269,
          2375.156,
          2331.8360000000002,
          2287.275,
          2241.44,
          2194.294,
          2145.801,
          2095.927,
          2044.631,
          1991.878,
          1937.628,
          1881.8429999999998,
          1824.483,
          1765.511,
          1704.889,
          1642.579,
          1578.547,
          1512.76,
          1445.1879999999999,
          1375.8029999999999,
          1304.586,
          1231.521,
          1156.601,
          1079.825,
          1001.206,
          920.7689999999999,
          838.553,
          754.615,
          669.029,
          581.895,
          493.333,
          403.48900000000003,
          312.54,
          220.687,
          128.161,
          35.218,
          -57.858999999999995,
          -150.77,
          -243.197,
          -334.81199999999995,
          -425.288,
          -514.3009999999999,
          -601.5409999999999,
          -686.717,
          -769.566,
          -849.8560000000001,
          -927.3910000000001,
          -1002.01,
          -1073.59,
          -1142.045,
          -1207.32,
          -1269.395,
          -1328.274,
          -1383.987,
          -1436.582,
          -1486.125,
          -1532.695,
          -1576.376,
          -1617.266,
          -1655.4620000000002,
          -1691.067,
          -1724.183,
          -1754.9129999999998,
          -1783.359,
          -1809.621,
          -1833.793,
          -1855.9720000000002,
          -1876.2479999999998,
          -1894.707,
          -1911.432,
          -1926.503,
          -1939.997,
          -1951.984,
          -1962.5339999999999,
          -1971.713,
          -1979.5810000000001,
          -1986.2,
          -1991.6229999999998,
          -1995.9029999999998,
          -1999.092,
          -2001.236,
          -2002.381,
          -2002.569,
          -2001.842,
          -2000.236,
          -1997.79,
          -1994.539,
          -1990.513,
          -1985.746,
          -1980.266,
          -1974.1029999999998,
          -1967.2839999999999,
          -1959.832,
          -1951.773,
          -1943.132,
          -1933.9289999999999,
          -1924.185,
          -1913.921,
          -1903.156,
          -1891.9089999999999,
          -1880.1970000000001,
          -1868.037,
          -1855.444,
          -1842.435,
          -1829.025,
          -1815.226,
          -1801.0529999999999,
          -1786.519,
          -1771.636,
          -1756.4160000000002,
          -1740.87,
          -1725.009,
          -1708.845,
          -1692.386,
          -1675.644,
          -1658.6270000000002,
          -1641.345,
          -1623.805,
          -1606.0179999999998,
          -1587.989,
          -1569.7279999999998,
          -1551.2420000000002,
          -1532.539,
          -1513.624,
          -1494.506,
          -1475.19,
          -1455.683,
          -1435.9920000000002,
          -1416.121,
          -1396.0770000000002,
          -1375.865,
          -1355.49,
          -1334.9579999999999,
          -1314.274,
          -1293.443,
          -1272.469,
          -1251.357,
          -1230.111,
          -1208.736,
          -1187.236,
          -1165.615,
          -1143.877,
          -1122.025,
          -1100.0639999999999,
          -1077.997,
          -1055.828,
          -1033.56,
          -1011.196,
          -988.74,
          -966.195,
          -943.563,
          -920.8489999999999,
          -898.054,
          -875.182,
          -852.2360000000001,
          -829.2180000000001,
          -806.13,
          -782.9760000000001,
          -759.758,
          -736.4789999999999,
          -713.14,
          -689.7439999999999,
          -666.294,
          -642.7909999999999,
          -619.239,
          -595.638,
          -571.991,
          -548.3009999999999,
          -524.569,
          -500.79699999999997,
          -476.98699999999997,
          -453.14099999999996,
          -429.26099999999997,
          -405.348,
          -381.405,
          -357.43300000000005,
          -333.434,
          -309.41,
          -285.361,
          -261.29,
          -237.199,
          -213.08900000000003,
          -188.96099999999998,
          -164.817,
          -140.658,
          -116.48700000000001,
          -92.303,
          -68.109,
          -43.907,
          -19.695999999999998,
          4.52,
          28.741999999999997,
          52.967,
          77.194,
          101.42299999999999,
          125.65100000000001,
          149.878,
          174.10299999999998,
          198.32299999999998,
          222.53900000000002,
          246.74900000000002,
          270.952,
          295.14599999999996,
          319.33099999999996,
          343.506,
          367.66900000000004,
          391.819,
          415.95599999999996,
          440.07800000000003,
          464.184,
          488.273,
          512.345,
          536.3969999999999,
          560.43,
          584.442,
          608.433,
          632.401,
          656.345,
          680.265,
          704.159,
          728.0260000000001,
          751.867,
          775.679,
          799.462,
          823.215,
          846.937,
          870.627,
          894.285,
          917.909,
          941.4989999999999,
          965.053,
          988.571,
          1012.053,
          1035.496,
          1058.901,
          1082.267,
          1105.5919999999999,
          1128.876,
          1152.118,
          1175.318,
          1198.474,
          1221.585,
          1244.652,
          1267.672,
          1290.646,
          1313.5720000000001,
          1336.4489999999998,
          1359.2779999999998,
          1382.057,
          1404.7839999999999,
          1427.461,
          1450.085,
          1472.656,
          1495.1729999999998,
          1517.635,
          1540.0420000000001,
          1562.3929999999998,
          1584.6860000000001,
          1606.922,
          1629.099,
          1651.217,
          1673.275,
          1695.2720000000002,
          1717.207,
          1739.08,
          1760.89,
          1782.635,
          1804.316,
          1825.931,
          1847.479,
          1868.961,
          1890.374,
          1911.719,
          1932.994,
          1954.1989999999998,
          1975.3329999999999,
          1996.394,
          2017.3829999999998,
          2038.299,
          2059.14,
          2079.905,
          2100.595,
          2121.208,
          2141.743,
          2162.2,
          2182.578,
          2202.875,
          2223.091,
          2243.226,
          2263.278,
          2283.246,
          2303.13,
          2322.929,
          2342.6420000000003,
          2362.268,
          2381.805,
          2401.255,
          2420.614,
          2439.883,
          2459.061,
          2478.147,
          2497.139,
          2516.0370000000003,
          2534.84,
          2553.547,
          2572.157,
          2590.669,
          2609.083,
          2627.3959999999997,
          2645.6090000000004,
          2663.7209999999995,
          2681.7290000000003,
          2699.634,
          2717.435,
          2735.1290000000004,
          2752.717,
          2770.197,
          2787.5690000000004,
          2804.83,
          2821.9809999999998,
          2839.02,
          2855.945,
          2872.757,
          2889.453,
          2906.033,
          2922.4959999999996,
          2938.84,
          2955.0640000000003,
          2971.1679999999997,
          2987.1490000000003,
          3003.007,
          3018.741,
          3034.349,
          3049.8309999999997,
          3065.184,
          3080.408,
          3095.502,
          3110.4640000000004,
          3125.292,
          3139.986,
          3154.5440000000003,
          3168.966,
          3183.248,
          3197.3909999999996,
          3211.393,
          3225.252,
          3238.967,
          3252.5359999999996,
          3265.9590000000003,
          3279.2329999999997,
          3292.357,
          3305.329,
          3318.1479999999997,
          3330.813,
          3343.322,
          3355.673,
          3367.864,
          3379.895,
          3391.763,
          3403.466,
          3415.0029999999997,
          3426.373,
          3437.572,
          3448.6009999999997,
          3459.4559999999997,
          3470.135,
          3480.638,
          3490.961,
          3501.1040000000003,
          3511.0640000000003,
          3520.8390000000004,
          3530.427,
          3539.8259999999996,
          3549.035,
          3558.05,
          3566.869,
          3575.491,
          3583.913,
          3592.133,
          3600.1490000000003,
          3607.9570000000003,
          3615.5570000000002,
          3622.945,
          3630.118,
          3637.0759999999996,
          3643.8140000000003,
          3650.33,
          3656.6220000000003,
          3662.6859999999997,
          3668.5209999999997,
          3674.123,
          3679.489,
          3684.616,
          3689.502,
          3694.1440000000002,
          3698.5370000000003,
          3702.68,
          3706.5690000000004,
          3710.2,
          3713.571,
          3716.678,
          3719.5170000000003,
          3722.085,
          3724.3779999999997,
          3726.393,
          3728.1259999999997,
          3729.572,
          3730.7290000000003,
          3731.591,
          3732.156,
          3732.4179999999997,
          3732.3740000000003,
          3732.0190000000002,
          3731.348,
          3730.357,
          3729.0409999999997,
          3727.3959999999997,
          3725.4159999999997,
          3723.0959999999995,
          3720.4320000000002,
          3717.4190000000003,
          3714.0490000000004,
          3710.3190000000004,
          3706.223,
          3701.7540000000004,
          3696.907,
          3691.676,
          3686.054,
          3680.035,
          3673.613,
          3666.781,
          3659.531,
          3651.857,
          3643.7509999999997,
          3635.2059999999997,
          3626.215,
          3616.7690000000002,
          3606.86,
          3596.48,
          3585.62,
          3574.272,
          3562.426,
          3550.074,
          3537.204,
          3523.808,
          3509.8759999999997,
          3495.397,
          3480.36,
          3464.7529999999997,
          3448.565,
          3431.785,
          3414.401,
          3396.3990000000003,
          3377.7670000000003,
          3358.491,
          3338.558,
          3317.952,
          3296.66,
          3274.6659999999997,
          3251.953,
          3228.507,
          3204.309,
          3179.342,
          3153.59,
          3127.032,
          3099.6479999999997,
          3071.42,
          3042.327,
          3012.3459999999995,
          2981.4559999999997,
          2949.634,
          2916.855,
          2883.0959999999995,
          2848.3309999999997,
          2812.532,
          2775.672,
          2737.725,
          2698.658,
          2658.4440000000004,
          2617.05,
          2574.442,
          2530.589,
          2485.455,
          2439.006,
          2391.203,
          2342.01,
          2291.387,
          2239.295,
          2185.694,
          2130.544,
          2073.8,
          2015.4229999999998,
          1955.37,
          1893.599,
          1830.068,
          1764.736,
          1697.567,
          1628.521,
          1557.566,
          1484.671,
          1409.8110000000001,
          1332.967,
          1254.128,
          1173.292,
          1090.4660000000001,
          1005.674,
          918.952,
          830.3560000000001,
          739.961,
          647.863,
          554.188,
          459.084,
          362.73199999999997,
          265.339,
          167.145,
          68.417,
          -30.551,
          -129.442,
          -227.921,
          -325.643,
          -422.25800000000004,
          -517.423,
          -610.802,
          -702.085,
          -790.9860000000001,
          -877.2510000000001,
          -960.665,
          -1041.048,
          -1118.263,
          -1192.208,
          -1262.82,
          -1330.069,
          -1393.951,
          -1454.494,
          -1511.7420000000002,
          -1565.76,
          -1616.626,
          -1664.4279999999999,
          -1709.264,
          -1751.236,
          -1790.45,
          -1827.013,
          -1861.033,
          -1892.615,
          -1921.865,
          -1948.884,
          -1973.7720000000002,
          -1996.6229999999998,
          -2017.53,
          -2036.58,
          -2053.859,
          -2069.474,
          -2083.4179999999997,
          -2095.847,
          -2106.804,
          -2116.355,
          -2124.561,
          -2131.482,
          -2137.176,
          -2141.694,
          -2145.0879999999997,
          -2147.406,
          -2148.694,
          -2148.994,
          -2148.349,
          -2146.7960000000003,
          -2144.374,
          -2141.117,
          -2137.058,
          -2132.23,
          -2126.6639999999998,
          -2120.387,
          -2113.427,
          -2105.8089999999997,
          -2097.561,
          -2088.7039999999997,
          -2079.262,
          -2069.255,
          -2058.705,
          -2047.6329999999998,
          -2036.055,
          -2023.991,
          -2011.457,
          -1998.47,
          -1985.046,
          -1971.2,
          -1956.9470000000001,
          -1942.3,
          -1927.273,
          -1911.878,
          -1896.128,
          -1880.035,
          -1863.61,
          -1846.8629999999998,
          -1829.807,
          -1812.45,
          -1794.8020000000001,
          -1776.8729999999998,
          -1758.672,
          -1740.207,
          -1721.487,
          -1702.519,
          -1683.3129999999999,
          -1663.875,
          -1644.213,
          -1624.3329999999999,
          -1604.243,
          -1583.9489999999998,
          -1563.4579999999999,
          -1542.775,
          -1521.906,
          -1500.858,
          -1479.636,
          -1458.245,
          -1436.691,
          -1414.9779999999998,
          -1393.112,
          -1371.0970000000002,
          -1348.9389999999999,
          -1326.641,
          -1304.208,
          -1281.645,
          -1258.954,
          -1236.142,
          -1213.211,
          -1190.164,
          -1167.007,
          -1143.743,
          -1120.374,
          -1096.904,
          -1073.338,
          -1049.677,
          -1025.925,
          -1002.086,
          -978.1619999999999,
          -954.1560000000001,
          -930.071,
          -905.91,
          -881.675,
          -857.37,
          -832.9960000000001,
          -808.556,
          -784.054,
          -759.49,
          -734.8689999999999,
          -710.191,
          -685.459,
          -660.676,
          -635.8430000000001,
          -610.9630000000001,
          -586.038,
          -561.07,
          -536.06,
          -511.01099999999997,
          -485.925,
          -460.80400000000003,
          -435.649,
          -410.462,
          -385.245,
          -360.001,
          -334.72900000000004,
          -309.433,
          -284.113,
          -258.772,
          -233.41099999999997,
          -208.03099999999998,
          -182.635,
          -157.22299999999998,
          -131.798,
          -106.36,
          -80.911,
          -55.452,
          -29.986,
          -4.513,
          20.965999999999998,
          46.449,
          71.934,
          97.421,
          122.90899999999999,
          148.395,
          173.87900000000002,
          199.36,
          224.835,
          250.305,
          275.768,
          301.222,
          326.66700000000003,
          352.101,
          377.524,
          402.93300000000005,
          428.329,
          453.71,
          479.075,
          504.42199999999997,
          529.752,
          555.062,
          580.352,
          605.621,
          630.867,
          656.09,
          681.289,
          706.462,
          731.6089999999999,
          756.7289999999999,
          781.821,
          806.883,
          831.916,
          856.9169999999999,
          881.887,
          906.823,
          931.7260000000001,
          956.5939999999999,
          981.427,
          1006.2230000000001,
          1030.981,
          1055.701,
          1080.382,
          1105.0230000000001,
          1129.623,
          1154.18,
          1178.6960000000001,
          1203.167,
          1227.594,
          1251.976,
          1276.312,
          1300.6,
          1324.8410000000001,
          1349.033,
          1373.175,
          1397.267,
          1420.816,
          1444.8039999999999,
          1468.7379999999998,
          1492.618,
          1516.444,
          1540.214,
          1563.9279999999999,
          1587.585,
          1611.184,
          1634.724,
          1658.205,
          1681.625,
          1704.984,
          1728.28,
          1751.514,
          1774.684,
          1797.789,
          1820.828,
          1843.8020000000001,
          1866.7079999999999,
          1889.546,
          1912.316,
          1935.016,
          1957.645,
          1980.203,
          2002.6879999999999,
          2025.101,
          2047.4389999999999,
          2069.703,
          2091.891,
          2114.0029999999997,
          2136.0370000000003,
          2157.993,
          2179.87,
          2201.667,
          2223.383,
          2245.0170000000003,
          2266.5679999999998,
          2288.036,
          2309.42,
          2330.718,
          2351.93,
          2373.054,
          2394.091,
          2415.038,
          2435.896,
          2456.6620000000003,
          2477.337,
          2497.919,
          2518.408,
          2538.802,
          2559.1,
          2579.301,
          2599.405,
          2619.41,
          2639.316,
          2659.1209999999996,
          2678.825,
          2698.426,
          2717.9240000000004,
          2737.316,
          2756.603,
          2775.784,
          2794.8559999999998,
          2813.82,
          2832.6740000000004,
          2851.417,
          2870.047,
          2888.565,
          2906.968,
          2925.256,
          2943.427,
          2961.48,
          2979.414,
          2997.228,
          3014.921,
          3032.492,
          3049.938,
          3067.26,
          3084.4559999999997,
          3101.525,
          3118.4640000000004,
          3135.2740000000003,
          3151.953,
          3168.4990000000003,
          3184.9120000000003,
          3201.1890000000003,
          3217.33,
          3233.333,
          3249.197,
          3264.92,
          3280.5009999999997,
          3295.9390000000003,
          3311.2309999999998,
          3326.3779999999997,
          3341.3759999999997,
          3356.225,
          3370.923,
          3385.469,
          3399.861,
          3414.097,
          3428.176,
          3442.0959999999995,
          3455.8559999999998,
          3469.453,
          3482.887,
          3496.155,
          3509.256,
          3522.188,
          3534.949,
          3547.538,
          3559.952,
          3572.1890000000003,
          3584.2490000000003,
          3596.1279999999997,
          3607.825,
          3619.3379999999997,
          3630.664,
          3641.803,
          3652.7509999999997,
          3663.507,
          3674.0690000000004,
          3684.434,
          3694.599,
          3704.5640000000003,
          3714.3259999999996,
          3723.881,
          3733.2290000000003,
          3742.366,
          3751.29,
          3759.998,
          3768.489,
          3776.759,
          3784.805,
          3792.6259999999997,
          3800.219,
          3807.58,
          3814.7070000000003,
          3821.597,
          3828.2470000000003,
          3834.655,
          3840.816,
          3846.7290000000003,
          3852.39,
          3857.795,
          3862.942,
          3867.827,
          3872.446,
          3876.797,
          3880.8759999999997,
          3884.679,
          3888.203,
          3891.4429999999998,
          3894.397,
          3897.059,
          3899.427,
          3901.495,
          3903.261,
          3904.719,
          3905.865,
          3906.696,
          3907.2059999999997,
          3907.3909999999996,
          3907.245,
          3906.765,
          3905.946,
          3904.781,
          3903.2659999999996,
          3901.3959999999997,
          3899.1659999999997,
          3896.5690000000004,
          3893.6,
          3890.2540000000004,
          3886.5240000000003,
          3882.403,
          3877.887,
          3872.969,
          3867.6409999999996,
          3861.8979999999997,
          3855.732,
          3849.136,
          3842.1020000000003,
          3834.6240000000003,
          3826.6929999999998,
          3818.303,
          3809.4440000000004,
          3800.1079999999997,
          3790.2870000000003,
          3779.972,
          3769.1540000000005,
          3757.823,
          3745.97,
          3733.586,
          3720.659,
          3707.18,
          3693.137,
          3678.52,
          3663.3179999999998,
          3647.5170000000003,
          3631.1079999999997,
          3614.075,
          3596.407,
          3578.091,
          3559.113,
          3539.4590000000003,
          3519.113,
          3498.06,
          3476.2859999999996,
          3453.7729999999997,
          3430.506,
          3406.466,
          3381.637,
          3355.9990000000003,
          3329.533,
          3302.219,
          3274.038,
          3244.968,
          3214.985,
          3184.0690000000004,
          3152.196,
          3119.34,
          3085.4770000000003,
          3050.5809999999997,
          3014.623,
          2977.577,
          2939.4120000000003,
          2900.099,
          2859.6079999999997,
          2817.9040000000005,
          2774.955,
          2730.7270000000003,
          2685.1820000000002,
          2638.2859999999996,
          2589.998,
          2540.282,
          2489.095,
          2436.397,
          2382.146,
          2326.297,
          2268.8070000000002,
          2209.631,
          2148.724,
          2086.04,
          2021.5339999999999,
          1955.161,
          1886.876,
          1816.638,
          1744.404,
          1670.138,
          1593.805,
          1515.3770000000002,
          1434.83,
          1352.15,
          1267.3319999999999,
          1180.379,
          1091.312,
          1000.166,
          906.993,
          811.8689999999999,
          714.89,
          616.181,
          515.8969999999999,
          414.218,
          311.36,
          207.57,
          103.125,
          -1.6680000000000001,
          -106.479,
          -210.956,
          -314.736,
          -417.44800000000004,
          -518.727,
          -618.216,
          -715.581,
          -810.5160000000001,
          -902.7439999999999,
          -992.029,
          -1078.1760000000002,
          -1161.028,
          -1240.473,
          -1316.434,
          -1388.871,
          -1457.776,
          -1523.17,
          -1585.094,
          -1643.611,
          -1698.8,
          -1750.751,
          -1799.5629999999999,
          -1845.3410000000001,
          -1888.1960000000001,
          -1928.237,
          -1965.578,
          -2000.33,
          -2032.601,
          -2062.498,
          -2090.126,
          -2115.5860000000002,
          -2138.973,
          -2160.381,
          -2179.899,
          -2197.611,
          -2213.599,
          -2227.94,
          -2240.7070000000003,
          -2251.97,
          -2261.7960000000003,
          -2270.2470000000003,
          -2277.384,
          -2283.263,
          -2287.937,
          -2291.458,
          -2293.875,
          -2295.2329999999997,
          -2295.577,
          -2294.948,
          -2293.384,
          -2290.924,
          -2287.603,
          -2283.455,
          -2278.513,
          -2272.808,
          -2266.367,
          -2259.22,
          -2251.3920000000003,
          -2242.909,
          -2233.7960000000003,
          -2224.075,
          -2213.768,
          -2202.896,
          -2191.48,
          -2179.538,
          -2167.09,
          -2154.152,
          -2140.741,
          -2126.874,
          -2112.5660000000003,
          -2097.833,
          -2082.688,
          -2067.145,
          -2051.217,
          -2034.9170000000001,
          -2018.257,
          -2001.2479999999998,
          -1983.902,
          -1966.23,
          -1948.2420000000002,
          -1929.9479999999999,
          -1911.359,
          -1892.4820000000002,
          -1873.3270000000002,
          -1853.904,
          -1834.219,
          -1814.2820000000002,
          -1794.1,
          -1773.68,
          -1753.031,
          -1732.158,
          -1711.069,
          -1689.771,
          -1668.269,
          -1646.5710000000001,
          -1624.682,
          -1602.6070000000002,
          -1580.3529999999998,
          -1557.925,
          -1535.329,
          -1512.568,
          -1489.649,
          -1466.576,
          -1443.355,
          -1419.9879999999998,
          -1396.4820000000002,
          -1372.84,
          -1349.066,
          -1325.165,
          -1301.141,
          -1276.997,
          -1252.737,
          -1228.366,
          -1203.885,
          -1179.3,
          -1154.613,
          -1129.828,
          -1104.947,
          -1079.975,
          -1054.913,
          -1029.766,
          -1004.5360000000001,
          -979.225,
          -953.837,
          -928.375,
          -902.841,
          -877.237,
          -851.567,
          -825.832,
          -800.0360000000001,
          -774.18,
          -748.2669999999999,
          -722.299,
          -696.278,
          -670.2080000000001,
          -644.0880000000001,
          -617.923,
          -591.714,
          -565.462,
          -539.1709999999999,
          -512.841,
          -486.475,
          -460.075,
          -433.64300000000003,
          -407.17900000000003,
          -380.68699999999995,
          -354.167,
          -327.622,
          -301.05400000000003,
          -274.46299999999997,
          -247.852,
          -221.22099999999998,
          -194.574,
          -167.91099999999997,
          -141.233,
          -114.54299999999999,
          -87.84100000000001,
          -61.13,
          -34.41,
          -7.683,
          19.049,
          45.785,
          72.525,
          99.265,
          126.006,
          152.746,
          179.483,
          206.217,
          232.946,
          259.66900000000004,
          286.384,
          313.091,
          339.788,
          366.473,
          393.147,
          419.80800000000005,
          446.454,
          473.084,
          499.69800000000004,
          526.294,
          552.872,
          579.429,
          605.965,
          632.479,
          658.97,
          685.437,
          711.878,
          738.294,
          764.682,
          791.041,
          817.372,
          843.672,
          869.941,
          896.177,
          922.38,
          948.549,
          974.683,
          1000.78,
          1026.8410000000001,
          1052.863,
          1078.847,
          1104.79,
          1130.693,
          1156.553,
          1182.371,
          1208.146,
          1233.875,
          1259.559,
          1285.197,
          1310.7879999999998,
          1336.33,
          1361.8229999999999,
          1387.266,
          1412.658,
          1437.9979999999998,
          1463.286,
          1488.52,
          1513.6989999999998,
          1538.8229999999999,
          1563.891,
          1588.901,
          1613.8529999999998,
          1638.747,
          1663.58,
          1688.3529999999998,
          1713.0639999999999,
          1737.713,
          1762.2979999999998,
          1786.819,
          1811.275,
          1835.664,
          1859.987,
          1884.2420000000002,
          1908.4279999999999,
          1932.545,
          1956.59,
          1980.565,
          2004.467,
          2028.296,
          2052.05,
          2075.73,
          2099.334,
          2122.861,
          2146.31,
          2169.68,
          2192.971,
          2216.181,
          2239.3089999999997,
          2262.356,
          2285.3179999999998,
          2308.197,
          2330.99,
          2353.698,
          2376.3179999999998,
          2398.85,
          2421.2929999999997,
          2443.645,
          2465.907,
          2488.077,
          2510.154,
          2532.137,
          2554.025,
          2575.817,
          2597.512,
          2619.109,
          2640.607,
          2662.0040000000004,
          2683.301,
          2704.4959999999996,
          2725.587,
          2746.574,
          2767.4559999999997,
          2788.2309999999998,
          2808.8990000000003,
          2829.458,
          2849.907,
          2870.2459999999996,
          2890.473,
          2910.586,
          2930.586,
          2950.47,
          2970.238,
          2989.887,
          3009.4179999999997,
          3028.829,
          3048.118,
          3067.285,
          3086.329,
          3105.2470000000003,
          3124.039,
          3142.703,
          3161.238,
          3179.6440000000002,
          3197.9179999999997,
          3216.059,
          3234.066,
          3251.937,
          3269.672,
          3287.268,
          3304.725,
          3322.0409999999997,
          3339.2140000000004,
          3356.244,
          3373.1279999999997,
          3389.865,
          3406.454,
          3422.893,
          3439.18,
          3455.315,
          3471.295,
          3487.119,
          3502.785,
          3518.2909999999997,
          3533.637,
          3548.82,
          3563.8379999999997,
          3578.69,
          3593.3740000000003,
          3607.888,
          3622.2309999999998,
          3636.4,
          3650.3940000000002,
          3664.211,
          3677.849,
          3691.305,
          3704.579,
          3717.6690000000003,
          3730.571,
          3743.284,
          3755.8059999999996,
          3768.135,
          3780.2690000000002,
          3792.205,
          3803.941,
          3815.475,
          3826.805,
          3837.929,
          3848.843,
          3859.547,
          3870.0359999999996,
          3880.309,
          3890.364,
          3900.197,
          3909.8059999999996,
          3919.188,
          3928.341,
          3937.262,
          3945.949,
          3954.397,
          3962.605,
          3970.5690000000004,
          3978.2859999999996,
          3985.7540000000004,
          3992.97,
          3999.929,
          4006.63,
          4013.0679999999998,
          4019.24,
          4025.143,
          4030.7740000000003,
          4036.1279999999997,
          4041.202,
          4045.993,
          4050.4959999999996,
          4054.7090000000003,
          4058.6259999999997,
          4062.244,
          4065.559,
          4068.567,
          4071.263,
          4073.643,
          4075.702,
          4077.4359999999997,
          4078.841,
          4079.9120000000003,
          4080.643,
          4081.03,
          4081.0679999999998,
          4080.752,
          4080.075,
          4079.034,
          4077.6209999999996,
          4075.8320000000003,
          4073.66,
          4071.1009999999997,
          4068.147,
          4064.792,
          4061.031,
          4056.855,
          4052.26,
          4047.236,
          4041.778,
          4035.8790000000004,
          4029.53,
          4022.725,
          4015.455,
          4007.712,
          3999.487,
          3990.7740000000003,
          3981.5609999999997,
          3971.842,
          3961.6059999999998,
          3950.843,
          3939.5440000000003,
          3927.699,
          3915.298,
          3902.33,
          3888.783,
          3874.647,
          3859.909,
          3844.559,
          3828.5820000000003,
          3811.968,
          3794.7009999999996,
          3776.77,
          3758.159,
          3738.855,
          3718.842,
          3698.105,
          3676.627,
          3654.393,
          3631.386,
          3607.587,
          3582.978,
          3557.5409999999997,
          3531.257,
          3504.103,
          3476.062,
          3447.1090000000004,
          3417.224,
          3386.382,
          3354.56,
          3321.7329999999997,
          3287.8740000000003,
          3252.958,
          3216.9559999999997,
          3179.84,
          3141.5809999999997,
          3102.1459999999997,
          3061.505,
          3019.6240000000003,
          2976.469,
          2932.005,
          2886.1940000000004,
          2839,
          2790.383,
          2740.301,
          2688.716,
          2635.5809999999997,
          2580.855,
          2524.491,
          2466.445,
          2406.667,
          2345.112,
          2281.729,
          2216.47,
          2149.286,
          2080.129,
          2008.951,
          1935.705,
          1860.346,
          1782.8339999999998,
          1703.131,
          1621.2020000000002,
          1537.023,
          1450.5729999999999,
          1361.844,
          1270.838,
          1177.5710000000001,
          1082.075,
          984.403,
          884.627,
          782.8430000000001,
          679.18,
          573.789,
          466.85900000000004,
          358.61,
          249.295,
          139.203,
          28.649,
          -82.02,
          -192.43900000000002,
          -302.224,
          -410.986,
          -518.3380000000001,
          -623.9019999999999,
          -727.322,
          -828.2660000000001,
          -926.44,
          -1021.587,
          -1113.49,
          -1201.98,
          -1286.928,
          -1368.245,
          -1445.881,
          -1519.8220000000001,
          -1590.0810000000001,
          -1656.6979999999999,
          -1719.734,
          -1779.267,
          -1835.388,
          -1888.1979999999999,
          -1937.806,
          -1984.3229999999999,
          -2027.8670000000002,
          -2068.552,
          -2106.496,
          -2141.811,
          -2174.612,
          -2205.004,
          -2233.095,
          -2258.986,
          -2282.774,
          -2304.554,
          -2324.415,
          -2342.4410000000003,
          -2358.715,
          -2373.314,
          -2386.313,
          -2397.78,
          -2407.783,
          -2416.384,
          -2423.644,
          -2429.619,
          -2434.365,
          -2437.9320000000002,
          -2440.369,
          -2441.721,
          -2442.035,
          -2441.351,
          -2439.708,
          -2437.145,
          -2433.698,
          -2429.401,
          -2424.286,
          -2418.384,
          -2411.725,
          -2404.3379999999997,
          -2396.248,
          -2387.4829999999997,
          -2378.0660000000003,
          -2368.021,
          -2357.37,
          -2346.133,
          -2334.333,
          -2321.988,
          -2309.118,
          -2295.739,
          -2281.87,
          -2267.527,
          -2252.725,
          -2237.48,
          -2221.8070000000002,
          -2205.719,
          -2189.23,
          -2172.353,
          -2155.099,
          -2137.482,
          -2119.513,
          -2101.203,
          -2082.563,
          -2063.6020000000003,
          -2044.332,
          -2024.76,
          -2004.8970000000002,
          -1984.7520000000002,
          -1964.3329999999999,
          -1943.649,
          -1922.707,
          -1901.515,
          -1880.082,
          -1858.4129999999998,
          -1836.5179999999998,
          -1814.401,
          -1792.069,
          -1769.53,
          -1746.79,
          -1723.8529999999998,
          -1700.727,
          -1677.4170000000001,
          -1653.9270000000001,
          -1630.265,
          -1606.434,
          -1582.441,
          -1558.2879999999998,
          -1533.983,
          -1509.5279999999998,
          -1484.9289999999999,
          -1460.19,
          -1435.316,
          -1410.309,
          -1385.1760000000002,
          -1359.918,
          -1334.5410000000002,
          -1309.047,
          -1283.441,
          -1257.726,
          -1231.906,
          -1205.983,
          -1179.962,
          -1153.845,
          -1127.635,
          -1101.336,
          -1074.951,
          -1048.482,
          -1021.932,
          -995.304,
          -968.602,
          -941.826,
          -914.9810000000001,
          -888.068,
          -861.091,
          -834.051,
          -806.951,
          -779.793,
          -752.58,
          -725.314,
          -697.998,
          -670.632,
          -643.22,
          -615.763,
          -588.263,
          -560.724,
          -533.145,
          -505.531,
          -477.881,
          -450.199,
          -422.485,
          -394.74300000000005,
          -366.973,
          -339.17699999999996,
          -311.358,
          -283.51599999999996,
          -255.65400000000002,
          -227.77200000000002,
          -199.87400000000002,
          -171.959,
          -144.03,
          -116.089,
          -88.13600000000001,
          -60.174,
          -32.203,
          -4.226,
          23.756999999999998,
          51.744,
          79.733,
          107.723,
          135.713,
          163.702,
          191.688,
          219.67,
          247.646,
          275.616,
          303.577,
          331.53,
          359.472,
          387.402,
          415.319,
          443.223,
          471.111,
          498.983,
          526.837,
          554.672,
          582.488,
          610.283,
          638.055,
          665.804,
          693.529,
          721.2289999999999,
          748.9019999999999,
          776.548,
          804.165,
          831.752,
          859.309,
          886.834,
          914.326,
          941.784,
          969.207,
          996.595,
          1023.946,
          1051.259,
          1078.532,
          1105.766,
          1132.96,
          1160.111,
          1187.22,
          1214.2839999999999,
          1241.3039999999999,
          1268.278,
          1295.2060000000001,
          1322.086,
          1348.9170000000001,
          1375.6979999999999,
          1402.4289999999999,
          1429.109,
          1455.736,
          1482.309,
          1508.829,
          1535.293,
          1561.7,
          1588.0510000000002,
          1614.344,
          1640.5770000000002,
          1666.75,
          1692.8629999999998,
          1718.9129999999998,
          1744.901,
          1770.825,
          1796.684,
          1822.4779999999998,
          1848.205,
          1873.865,
          1899.4560000000001,
          1924.977,
          1950.4289999999999,
          1975.809,
          2001.116,
          2026.351,
          2051.511,
          2076.596,
          2101.605,
          2126.5370000000003,
          2151.391,
          2176.166,
          2200.861,
          2225.476,
          2250.008,
          2274.4570000000003,
          2298.823,
          2323.104,
          2347.298,
          2371.406,
          2395.427,
          2419.3579999999997,
          2443.2,
          2466.951,
          2490.609,
          2514.175,
          2537.647,
          2561.024,
          2584.305,
          2607.489,
          2630.575,
          2653.562,
          2676.448,
          2699.2329999999997,
          2721.915,
          2744.494,
          2766.969,
          2789.337,
          2811.599,
          2833.7529999999997,
          2855.797,
          2877.732,
          2899.555,
          2921.265,
          2942.861,
          2964.343,
          2985.708,
          3006.9559999999997,
          3028.086,
          3049.0959999999995,
          3069.985,
          3090.7509999999997,
          3111.3940000000002,
          3131.9120000000003,
          3152.305,
          3172.57,
          3192.7059999999997,
          3212.712,
          3232.587,
          3252.33,
          3271.938,
          3291.4109999999996,
          3310.7470000000003,
          3329.945,
          3349.0029999999997,
          3367.921,
          3386.696,
          3405.327,
          3423.812,
          3442.15,
          3460.34,
          3478.38,
          3496.2690000000002,
          3514.0040000000004,
          3531.5840000000003,
          3549.008,
          3566.2740000000003,
          3583.381,
          3600.3259999999996,
          3617.1079999999997,
          3633.7259999999997,
          3650.177,
          3666.4590000000003,
          3682.572,
          3698.513,
          3714.28,
          3729.8720000000003,
          3745.2859999999996,
          3760.5209999999997,
          3775.574,
          3790.445,
          3805.13,
          3819.627,
          3833.9359999999997,
          3848.053,
          3861.9770000000003,
          3875.705,
          3889.235,
          3902.565,
          3915.692,
          3928.615,
          3941.3309999999997,
          3953.8379999999997,
          3966.133,
          3978.2140000000004,
          3990.079,
          4001.724,
          4013.147,
          4024.347,
          4035.3190000000004,
          4046.062,
          4056.573,
          4066.848,
          4076.886,
          4086.683,
          4096.236,
          4105.543,
          4114.6,
          4123.404,
          4131.952,
          4140.241,
          4148.267,
          4156.028,
          4163.519,
          4170.7390000000005,
          4177.682,
          4184.346,
          4190.726,
          4196.819,
          4202.622,
          4208.129,
          4213.338,
          4218.245,
          4222.845,
          4227.134,
          4231.108,
          4234.762,
          4238.092000000001,
          4241.094,
          4243.762,
          4246.092000000001,
          4248.079000000001,
          4249.718,
          4251.004,
          4251.933,
          4252.498,
          4252.693,
          4252.515,
          4251.956,
          4251.0109999999995,
          4249.674,
          4247.939,
          4245.8,
          4243.25,
          4240.282999999999,
          4236.892,
          4233.069,
          4228.809,
          4224.104,
          4218.946,
          4213.327,
          4207.24,
          4200.678,
          4193.63,
          4186.09,
          4178.048,
          4169.496,
          4160.424,
          4150.823,
          4140.683,
          4129.994000000001,
          4118.745,
          4106.927,
          4094.5290000000005,
          4081.539,
          4067.945,
          4053.736,
          4038.8990000000003,
          4023.423,
          4007.2929999999997,
          3990.4970000000003,
          3973.02,
          3954.849,
          3935.968,
          3916.363,
          3896.018,
          3874.915,
          3853.04,
          3830.3740000000003,
          3806.9,
          3782.598,
          3757.45,
          3731.437,
          3704.5359999999996,
          3676.728,
          3647.991,
          3618.301,
          3587.634,
          3555.968,
          3523.276,
          3489.532,
          3454.7090000000003,
          3418.778,
          3381.711,
          3343.478,
          3304.047,
          3263.385,
          3221.4590000000003,
          3178.2340000000004,
          3133.6740000000004,
          3087.741,
          3040.3979999999997,
          2991.6040000000003,
          2941.316,
          2889.494,
          2836.092,
          2781.065,
          2724.367,
          2665.95,
          2605.765,
          2543.761,
          2479.888,
          2414.094,
          2346.326,
          2276.532,
          2204.661,
          2130.661,
          2054.48,
          1976.0720000000001,
          1895.391,
          1812.395,
          1727.046,
          1639.316,
          1549.181,
          1456.6270000000002,
          1361.654,
          1264.275,
          1164.521,
          1062.4389999999999,
          958.1010000000001,
          851.605,
          743.076,
          632.672,
          520.581,
          407.029,
          292.276,
          176.61900000000003,
          60.386,
          -56.065,
          -172.35299999999998,
          -288.07599999999996,
          -402.82599999999996,
          -516.196,
          -627.786,
          -737.217,
          -844.135,
          -948.2239999999999,
          -1049.2060000000001,
          -1146.848,
          -1240.962,
          -1331.4029999999998,
          -1418.07,
          -1500.906,
          -1579.885,
          -1655.016,
          -1726.335,
          -1793.9,
          -1857.79,
          -1918.095,
          -1974.9189999999999,
          -2028.3729999999998,
          -2078.572,
          -2125.636,
          -2169.686,
          -2210.843,
          -2249.225,
          -2284.947,
          -2318.126,
          -2348.871,
          -2377.288,
          -2403.479,
          -2427.544,
          -2449.635,
          -2469.6639999999998,
          -2487.894,
          -2504.349,
          -2519.104,
          -2532.236,
          -2543.813,
          -2553.902,
          -2562.567,
          -2569.868,
          -2575.861,
          -2580.601,
          -2584.14,
          -2586.526,
          -2587.806,
          -2588.024,
          -2587.222,
          -2585.44,
          -2582.716,
          -2579.087,
          -2574.587,
          -2569.2470000000003,
          -2563.101,
          -2556.178,
          -2548.505,
          -2540.111,
          -2531.021,
          -2521.261,
          -2510.853,
          -2499.82,
          -2488.1839999999997,
          -2475.967,
          -2463.187,
          -2449.864,
          -2436.016,
          -2421.66,
          -2406.814,
          -2391.492,
          -2375.712,
          -2359.487,
          -2342.8320000000003,
          -2325.761,
          -2308.2870000000003,
          -2290.423,
          -2272.179,
          -2253.57,
          -2234.605,
          -2215.297,
          -2195.655,
          -2175.69,
          -2155.411,
          -2134.828,
          -2113.951,
          -2092.7870000000003,
          -2071.346,
          -2049.635,
          -2027.6629999999998,
          -2005.4379999999999,
          -1982.967,
          -1960.257,
          -1937.316,
          -1914.149,
          -1890.765,
          -1867.1689999999999,
          -1843.3670000000002,
          -1819.365,
          -1795.1689999999999,
          -1770.786,
          -1746.22,
          -1721.476,
          -1696.5610000000001,
          -1671.4779999999998,
          -1646.234,
          -1620.832,
          -1595.277,
          -1569.5739999999998,
          -1543.7279999999998,
          -1517.7420000000002,
          -1491.62,
          -1465.368,
          -1438.9879999999998,
          -1412.485,
          -1385.8629999999998,
          -1359.124,
          -1332.273,
          -1305.3139999999999,
          -1278.249,
          -1251.0810000000001,
          -1223.815,
          -1196.454,
          -1169,
          -1141.4560000000001,
          -1113.826,
          -1086.112,
          -1058.317,
          -1030.444,
          -1002.4960000000001,
          -974.4760000000001,
          -946.385,
          -918.227,
          -890.0039999999999,
          -861.7180000000001,
          -833.373,
          -804.9689999999999,
          -776.51,
          -747.998,
          -719.435,
          -690.823,
          -662.164,
          -633.461,
          -604.715,
          -575.929,
          -547.104,
          -518.243,
          -489.347,
          -460.418,
          -431.459,
          -402.47,
          -373.454,
          -344.413,
          -315.347,
          -286.26,
          -257.152,
          -228.02599999999998,
          -198.88299999999998,
          -169.72400000000002,
          -140.55100000000002,
          -111.366,
          -82.17,
          -52.965,
          -23.752,
          5.4670000000000005,
          34.691,
          63.919,
          93.148,
          122.37799999999999,
          151.607,
          180.834,
          210.05700000000002,
          239.27599999999998,
          268.488,
          297.693,
          326.888,
          356.074,
          385.24800000000005,
          414.41,
          443.55800000000005,
          472.69,
          501.80699999999996,
          530.905,
          559.986,
          589.0459999999999,
          618.085,
          647.101,
          676.095,
          705.063,
          734.007,
          762.923,
          791.811,
          820.67,
          849.4989999999999,
          878.297,
          907.062,
          935.794,
          964.492,
          993.153,
          1021.779,
          1050.366,
          1078.915,
          1107.423,
          1135.891,
          1164.317,
          1192.7,
          1221.04,
          1249.3339999999998,
          1277.5819999999999,
          1305.7830000000001,
          1333.9360000000001,
          1362.04,
          1390.0929999999998,
          1418.096,
          1446.047,
          1473.944,
          1501.7879999999998,
          1529.576,
          1557.308,
          1584.983,
          1612.6,
          1640.158,
          1667.656,
          1695.0929999999998,
          1722.4679999999998,
          1749.78,
          1777.027,
          1804.21,
          1831.3270000000002,
          1858.376,
          1885.358,
          1912.27,
          1939.1129999999998,
          1965.884,
          1992.5839999999998,
          2019.211,
          2045.763,
          2072.241,
          2098.6420000000003,
          2124.967,
          2151.2129999999997,
          2177.381,
          2203.468,
          2229.474,
          2255.3979999999997,
          2281.239,
          2306.996,
          2332.6679999999997,
          2358.2529999999997,
          2383.752,
          2409.161,
          2434.482,
          2459.712,
          2484.85,
          2509.897,
          2534.849,
          2559.7070000000003,
          2584.468,
          2609.133,
          2633.7,
          2658.1679999999997,
          2682.5359999999996,
          2706.803,
          2730.966,
          2755.027,
          2778.982,
          2802.8320000000003,
          2826.575,
          2850.21,
          2873.735,
          2897.15,
          2920.453,
          2943.643,
          2966.719,
          2989.679,
          3012.5229999999997,
          3035.25,
          3057.857,
          3080.343,
          3102.7090000000003,
          3124.9509999999996,
          3147.0690000000004,
          3169.062,
          3190.928,
          3212.6659999999997,
          3234.2740000000003,
          3255.752,
          3277.097,
          3298.309,
          3319.386,
          3340.327,
          3361.13,
          3381.7929999999997,
          3402.316,
          3422.697,
          3442.935,
          3463.027,
          3482.972,
          3502.7690000000002,
          3522.417,
          3541.913,
          3561.257,
          3580.445,
          3599.478,
          3618.353,
          3637.0679999999998,
          3655.6220000000003,
          3674.014,
          3692.241,
          3710.301,
          3728.1940000000004,
          3745.917,
          3763.468,
          3780.845,
          3798.047,
          3815.072,
          3831.917,
          3848.5820000000003,
          3865.063,
          3881.3590000000004,
          3897.468,
          3913.388,
          3929.116,
          3944.651,
          3959.99,
          3975.131,
          3990.073,
          4004.812,
          4019.347,
          4033.675,
          4047.7940000000003,
          4061.702,
          4075.395,
          4088.873,
          4102.130999999999,
          4115.168,
          4127.98,
          4140.567,
          4152.923,
          4165.048,
          4176.938,
          4188.59,
          4200.002,
          4211.170999999999,
          4222.093,
          4232.766,
          4243.187,
          4253.353,
          4263.259,
          4272.904,
          4282.284000000001,
          4291.395,
          4300.235,
          4308.799,
          4317.085,
          4325.088,
          4332.805,
          4340.232,
          4347.366,
          4354.202,
          4360.736,
          4366.965,
          4372.885,
          4378.49,
          4383.777,
          4388.742,
          4393.38,
          4397.686,
          4401.657,
          4405.286,
          4408.569,
          4411.502,
          4414.079000000001,
          4416.294,
          4418.143,
          4419.62,
          4420.72,
          4421.437,
          4421.766,
          4421.6990000000005,
          4421.232,
          4420.357,
          4419.069,
          4417.36,
          4415.225,
          4412.657,
          4409.648,
          4406.191,
          4402.279,
          4397.904,
          4393.059,
          4387.735,
          4381.924,
          4375.619000000001,
          4368.809,
          4361.488,
          4353.644,
          4345.27,
          4336.354,
          4326.888,
          4316.862,
          4306.265,
          4295.085999999999,
          4283.313,
          4270.937,
          4257.945,
          4244.325,
          4230.065,
          4215.151,
          4199.57,
          4183.31,
          4166.356,
          4148.693,
          4130.307,
          4111.181,
          4091.301,
          4070.65,
          4049.211,
          4026.965,
          4003.8959999999997,
          3979.9840000000004,
          3955.21,
          3929.554,
          3902.995,
          3875.512,
          3847.083,
          3817.683,
          3787.29,
          3755.8790000000004,
          3723.425,
          3689.901,
          3655.278,
          3619.53,
          3582.6259999999997,
          3544.5359999999996,
          3505.2270000000003,
          3464.6679999999997,
          3422.824,
          3379.66,
          3335.139,
          3289.222,
          3241.8720000000003,
          3193.046,
          3142.703,
          3090.8,
          3037.292,
          2982.131,
          2925.2709999999997,
          2866.6609999999996,
          2806.252,
          2743.991,
          2679.8259999999996,
          2613.702,
          2545.565,
          2475.3579999999997,
          2403.026,
          2328.516,
          2251.768,
          2172.732,
          2091.355,
          2007.5870000000002,
          1921.382,
          1832.7,
          1741.507,
          1647.775,
          1551.489,
          1452.6429999999998,
          1351.2479999999998,
          1247.33,
          1140.937,
          1032.137,
          921.028,
          807.7339999999999,
          692.416,
          575.263,
          456.506,
          336.412,
          215.28400000000002,
          93.463,
          -28.683000000000003,
          -150.756,
          -272.339,
          -393.004,
          -512.325,
          -629.878,
          -745.265,
          -858.1080000000001,
          -968.07,
          -1074.8519999999999,
          -1178.202,
          -1277.913,
          -1373.828,
          -1465.8310000000001,
          -1553.855,
          -1637.865,
          -1717.865,
          -1793.886,
          -1865.983,
          -1934.234,
          -1998.731,
          -2059.577,
          -2116.887,
          -2170.78,
          -2221.3779999999997,
          -2268.8070000000002,
          -2313.1910000000003,
          -2354.654,
          -2393.317,
          -2429.298,
          -2462.715,
          -2493.675,
          -2522.288,
          -2548.656,
          -2572.879,
          -2595.048,
          -2615.255,
          -2633.585,
          -2650.12,
          -2664.9359999999997,
          -2678.1090000000004,
          -2689.7070000000003,
          -2699.798,
          -2708.4440000000004,
          -2715.7070000000003,
          -2721.6420000000003,
          -2726.304,
          -2729.7459999999996,
          -2732.014,
          -2733.157,
          -2733.218,
          -2732.24,
          -2730.262,
          -2727.324,
          -2723.461,
          -2718.7070000000003,
          -2713.095,
          -2706.659,
          -2699.427,
          -2691.427,
          -2682.688,
          -2673.235,
          -2663.095,
          -2652.289,
          -2640.842,
          -2628.775,
          -2616.109,
          -2602.865,
          -2589.062,
          -2574.717,
          -2559.849,
          -2544.475,
          -2528.612,
          -2512.274,
          -2495.478,
          -2478.237,
          -2460.565,
          -2442.476,
          -2423.9829999999997,
          -2405.099,
          -2385.834,
          -2366.202,
          -2346.214,
          -2325.8779999999997,
          -2305.208,
          -2284.2110000000002,
          -2262.899,
          -2241.28,
          -2219.363,
          -2197.158,
          -2174.672,
          -2151.9139999999998,
          -2128.8920000000003,
          -2105.614,
          -2082.0860000000002,
          -2058.317,
          -2034.3129999999999,
          -2010.0810000000001,
          -1985.6270000000002,
          -1960.9579999999999,
          -1936.0810000000001,
          -1911,
          -1885.7220000000002,
          -1860.253,
          -1834.598,
          -1808.7620000000002,
          -1782.751,
          -1756.57,
          -1730.224,
          -1703.717,
          -1677.0539999999999,
          -1650.24,
          -1623.279,
          -1596.1760000000002,
          -1568.934,
          -1541.558,
          -1514.0510000000002,
          -1486.4189999999999,
          -1458.6629999999998,
          -1430.789,
          -1402.8,
          -1374.6989999999998,
          -1346.489,
          -1318.175,
          -1289.759,
          -1261.245,
          -1232.636,
          -1203.934,
          -1175.143,
          -1146.267,
          -1117.307,
          -1088.266,
          -1059.1480000000001,
          -1029.955,
          -1000.689,
          -971.3539999999999,
          -941.952,
          -912.4839999999999,
          -882.955,
          -853.3660000000001,
          -823.7189999999999,
          -794.018,
          -764.263,
          -734.457,
          -704.6039999999999,
          -674.703,
          -644.759,
          -614.7719999999999,
          -584.746,
          -554.681,
          -524.58,
          -494.444,
          -464.277,
          -434.079,
          -403.852,
          -373.599,
          -343.32,
          -313.019,
          -282.695,
          -252.352,
          -221.99099999999999,
          -191.613,
          -161.221,
          -130.815,
          -100.398,
          -69.971,
          -39.535,
          -9.092,
          21.357,
          51.809,
          82.264,
          112.72,
          143.17600000000002,
          173.62900000000002,
          204.08,
          234.52599999999998,
          264.966,
          295.399,
          325.822,
          356.23699999999997,
          386.639,
          417.03,
          447.406,
          477.767,
          508.11199999999997,
          538.439,
          568.747,
          599.035,
          629.302,
          659.546,
          689.7660000000001,
          719.962,
          750.1310000000001,
          780.2719999999999,
          810.385,
          840.4689999999999,
          870.5219999999999,
          900.5419999999999,
          930.53,
          960.4830000000001,
          990.4010000000001,
          1020.2819999999999,
          1050.126,
          1079.931,
          1109.6960000000001,
          1139.42,
          1169.103,
          1198.742,
          1228.337,
          1257.887,
          1287.39,
          1316.846,
          1346.253,
          1375.611,
          1404.9189999999999,
          1434.174,
          1463.3770000000002,
          1492.527,
          1521.621,
          1550.66,
          1579.641,
          1608.565,
          1637.4289999999999,
          1666.234,
          1694.977,
          1723.6589999999999,
          1752.277,
          1780.83,
          1809.319,
          1837.741,
          1866.096,
          1894.382,
          1922.599,
          1950.746,
          1978.8210000000001,
          2006.8229999999999,
          2034.7520000000002,
          2062.606,
          2090.384,
          2118.0860000000002,
          2145.709,
          2173.254,
          2200.719,
          2228.103,
          2255.404,
          2282.6220000000003,
          2309.757,
          2336.805,
          2363.768,
          2390.6420000000003,
          2417.428,
          2444.125,
          2470.73,
          2497.244,
          2523.665,
          2549.991,
          2576.222,
          2602.357,
          2628.3940000000002,
          2654.333,
          2680.172,
          2705.909,
          2731.545,
          2757.077,
          2782.505,
          2807.827,
          2833.042,
          2858.1490000000003,
          2883.147,
          2908.034,
          2932.809,
          2957.472,
          2982.02,
          3006.453,
          3030.7690000000002,
          3054.967,
          3079.046,
          3103.005,
          3126.841,
          3150.555,
          3174.1440000000002,
          3197.607,
          3220.9429999999998,
          3244.15,
          3267.2270000000003,
          3290.173,
          3312.987,
          3335.6659999999997,
          3358.21,
          3380.617,
          3402.885,
          3425.013,
          3447,
          3468.844,
          3490.5440000000003,
          3512.097,
          3533.5029999999997,
          3554.76,
          3575.867,
          3596.821,
          3617.6209999999996,
          3638.2659999999996,
          3658.7529999999997,
          3679.0820000000003,
          3699.25,
          3719.256,
          3739.099,
          3758.775,
          3778.284,
          3797.623,
          3816.7909999999997,
          3835.7870000000003,
          3854.607,
          3873.2509999999997,
          3891.716,
          3910,
          3928.1020000000003,
          3946.0190000000002,
          3963.7490000000003,
          3981.2909999999997,
          3998.6420000000003,
          4015.8,
          4032.763,
          4049.5290000000005,
          4066.095,
          4082.46,
          4098.621,
          4114.576,
          4130.322,
          4145.858,
          4161.18,
          4176.286,
          4191.174,
          4205.842000000001,
          4220.286,
          4234.504,
          4248.4929999999995,
          4262.252,
          4275.776,
          4289.063,
          4302.111,
          4314.916,
          4327.476,
          4339.788,
          4351.848,
          4363.654,
          4375.2029999999995,
          4386.49,
          4397.514,
          4408.271,
          4418.7570000000005,
          4428.969,
          4438.903,
          4448.557,
          4457.925,
          4467.005999999999,
          4475.794,
          4484.286,
          4492.479,
          4500.3679999999995,
          4507.9490000000005,
          4515.219,
          4522.1720000000005,
          4528.805,
          4535.1140000000005,
          4541.092000000001,
          4546.737,
          4552.044,
          4557.0070000000005,
          4561.623,
          4565.885,
          4569.79,
          4573.331,
          4576.503,
          4579.302,
          4581.721,
          4583.755,
          4585.398,
          4586.644,
          4587.488,
          4587.9220000000005,
          4587.941,
          4587.538,
          4586.707,
          4585.44,
          4583.731,
          4581.572,
          4578.957,
          4575.877,
          4572.326,
          4568.294,
          4563.775,
          4558.759,
          4553.238,
          4547.204000000001,
          4540.648,
          4533.56,
          4525.931,
          4517.751,
          4509.009,
          4499.696,
          4489.802,
          4479.315,
          4468.224,
          4456.518,
          4444.184,
          4431.21,
          4417.585,
          4403.295,
          4388.326,
          4372.666,
          4356.299,
          4339.21,
          4321.3859999999995,
          4302.81,
          4283.467000000001,
          4263.339,
          4242.409000000001,
          4220.661,
          4198.075,
          4174.633,
          4150.314,
          4125.099,
          4098.968,
          4071.897,
          4043.865,
          4014.848,
          3984.824,
          3953.7659999999996,
          3921.6479999999997,
          3888.445,
          3854.1279999999997,
          3818.6679999999997,
          3782.0370000000003,
          3744.203,
          3705.133,
          3664.795,
          3623.155,
          3580.177,
          3535.823,
          3490.0559999999996,
          3442.835,
          3394.12,
          3343.867,
          3292.033,
          3238.572,
          3183.437,
          3126.579,
          3067.946,
          3007.49,
          2945.1540000000005,
          2880.886,
          2814.6290000000004,
          2746.3259999999996,
          2675.92,
          2603.35,
          2528.56,
          2451.488,
          2372.077,
          2290.269,
          2206.008,
          2119.242,
          2029.92,
          1937.997,
          1843.4360000000001,
          1746.207,
          1646.287,
          1543.67,
          1438.3629999999998,
          1330.3870000000002,
          1219.789,
          1106.636,
          991.0219999999999,
          873.074,
          752.951,
          630.845,
          506.99300000000005,
          381.663,
          255.171,
          127.86200000000001,
          0.121,
          -127.64299999999999,
          -254.99599999999998,
          -381.49300000000005,
          -506.685,
          -630.131,
          -751.4069999999999,
          -870.1160000000001,
          -985.898,
          -1098.433,
          -1207.451,
          -1312.727,
          -1414.086,
          -1511.4029999999998,
          -1604.595,
          -1693.622,
          -1778.479,
          -1859.194,
          -1935.819,
          -2008.43,
          -2077.118,
          -2141.99,
          -2203.1620000000003,
          -2260.754,
          -2314.894,
          -2365.71,
          -2413.3320000000003,
          -2457.888,
          -2499.5029999999997,
          -2538.301,
          -2574.402,
          -2607.922,
          -2638.972,
          -2667.659,
          -2694.0879999999997,
          -2718.3559999999998,
          -2740.5559999999996,
          -2760.78,
          -2779.111,
          -2795.631,
          -2810.4190000000003,
          -2823.545,
          -2835.0820000000003,
          -2845.095,
          -2853.6459999999997,
          -2860.798,
          -2866.6040000000003,
          -2871.1209999999996,
          -2874.4,
          -2876.489,
          -2877.435,
          -2877.282,
          -2876.073,
          -2873.847,
          -2870.643,
          -2866.4970000000003,
          -2861.4440000000004,
          -2855.5170000000003,
          -2848.748,
          -2841.1659999999997,
          -2832.801,
          -2823.68,
          -2813.829,
          -2803.275,
          -2792.04,
          -2780.1479999999997,
          -2767.62,
          -2754.4790000000003,
          -2740.744,
          -2726.435,
          -2711.571,
          -2696.1690000000003,
          -2680.2470000000003,
          -2663.821,
          -2646.907,
          -2629.5209999999997,
          -2611.676,
          -2593.389,
          -2574.6710000000003,
          -2555.5370000000003,
          -2535.998,
          -2516.0679999999998,
          -2495.757,
          -2475.077,
          -2454.0389999999998,
          -2432.654,
          -2410.933,
          -2388.884,
          -2366.5170000000003,
          -2343.843,
          -2320.868,
          -2297.604,
          -2274.056,
          -2250.235,
          -2226.147,
          -2201.8,
          -2177.202,
          -2152.359,
          -2127.28,
          -2101.969,
          -2076.435,
          -2050.683,
          -2024.72,
          -1998.5510000000002,
          -1972.183,
          -1945.62,
          -1918.869,
          -1891.934,
          -1864.8220000000001,
          -1837.537,
          -1810.0839999999998,
          -1782.467,
          -1754.692,
          -1726.763,
          -1698.684,
          -1670.461,
          -1642.096,
          -1613.595,
          -1584.961,
          -1556.1970000000001,
          -1527.309,
          -1498.3,
          -1469.1729999999998,
          -1439.932,
          -1410.58,
          -1381.121,
          -1351.558,
          -1321.895,
          -1292.134,
          -1262.278,
          -1232.3319999999999,
          -1202.297,
          -1172.177,
          -1141.974,
          -1111.692,
          -1081.3319999999999,
          -1050.899,
          -1020.3939999999999,
          -989.819,
          -959.179,
          -928.4739999999999,
          -897.707,
          -866.882,
          -836,
          -805.063,
          -774.074,
          -743.035,
          -711.948,
          -680.815,
          -649.639,
          -618.4209999999999,
          -587.164,
          -555.87,
          -524.54,
          -493.176,
          -461.781,
          -430.35699999999997,
          -398.904,
          -367.426,
          -335.923,
          -304.39799999999997,
          -272.85200000000003,
          -241.287,
          -209.705,
          -178.108,
          -146.496,
          -114.87200000000001,
          -83.238,
          -51.595,
          -19.944000000000003,
          11.713,
          43.373999999999995,
          75.038,
          106.704,
          138.369,
          170.033,
          201.69400000000002,
          233.35,
          265.001,
          296.644,
          328.279,
          359.903,
          391.517,
          423.11699999999996,
          454.704,
          486.275,
          517.8290000000001,
          549.365,
          580.882,
          612.379,
          643.8530000000001,
          675.305,
          706.732,
          738.1339999999999,
          769.508,
          800.855,
          832.173,
          863.46,
          894.715,
          925.938,
          957.1260000000001,
          988.279,
          1019.3960000000001,
          1050.476,
          1081.516,
          1112.517,
          1143.4769999999999,
          1174.395,
          1205.269,
          1236.099,
          1266.883,
          1297.621,
          1328.3110000000001,
          1358.9520000000002,
          1389.543,
          1420.0829999999999,
          1450.5710000000001,
          1481.005,
          1511.384,
          1541.7089999999998,
          1571.976,
          1602.1860000000001,
          1632.3370000000002,
          1662.4279999999999,
          1692.4579999999999,
          1722.425,
          1752.33,
          1782.17,
          1811.945,
          1841.6529999999998,
          1871.293,
          1900.865,
          1930.3670000000002,
          1959.7979999999998,
          1989.1570000000002,
          2018.444,
          2047.655,
          2076.792,
          2105.8520000000003,
          2134.835,
          2163.739,
          2192.563,
          2221.306,
          2249.968,
          2278.5460000000003,
          2307.04,
          2335.449,
          2363.772,
          2392.006,
          2420.152,
          2448.209,
          2476.174,
          2504.047,
          2531.827,
          2559.512,
          2587.1020000000003,
          2614.594,
          2641.989,
          2669.285,
          2696.48,
          2723.574,
          2750.565,
          2777.452,
          2804.2329999999997,
          2830.909,
          2857.4759999999997,
          2883.935,
          2910.283,
          2936.52,
          2962.645,
          2988.655,
          3014.55,
          3040.329,
          3065.99,
          3091.531,
          3116.952,
          3142.2509999999997,
          3167.427,
          3192.4790000000003,
          3217.4040000000005,
          3242.203,
          3266.8720000000003,
          3291.4109999999996,
          3315.8190000000004,
          3340.094,
          3364.235,
          3388.24,
          3412.107,
          3435.836,
          3459.4240000000004,
          3482.8709999999996,
          3506.1740000000004,
          3529.333,
          3552.345,
          3575.2090000000003,
          3597.923,
          3620.486,
          3642.897,
          3665.152,
          3687.252,
          3709.1940000000004,
          3730.9759999999997,
          3752.597,
          3774.055,
          3795.347,
          3816.474,
          3837.4320000000002,
          3858.22,
          3878.835,
          3899.277,
          3919.5440000000003,
          3939.632,
          3959.5409999999997,
          3979.268,
          3998.8109999999997,
          4018.1690000000003,
          4037.3390000000004,
          4056.3190000000004,
          4075.1079999999997,
          4093.702,
          4112.1,
          4130.3,
          4148.299,
          4166.095,
          4183.685,
          4201.069,
          4218.242,
          4235.204000000001,
          4251.95,
          4268.48,
          4284.79,
          4300.878,
          4316.741,
          4332.377,
          4347.782,
          4362.955,
          4377.893,
          4392.592000000001,
          4407.05,
          4421.264,
          4435.231,
          4448.948,
          4462.413,
          4475.621,
          4488.57,
          4501.2570000000005,
          4513.679,
          4525.831,
          4537.712,
          4549.316,
          4560.642,
          4571.685,
          4582.441,
          4592.907999999999,
          4603.081,
          4612.956,
          4622.53,
          4631.799,
          4640.758,
          4649.403,
          4657.731,
          4665.737,
          4673.417,
          4680.766,
          4687.779,
          4694.4529999999995,
          4700.782,
          4706.76,
          4712.385,
          4717.65,
          4722.55,
          4727.08,
          4731.235,
          4735.009,
          4738.397,
          4741.392,
          4743.99,
          4746.183,
          4747.965,
          4749.332,
          4750.275,
          4750.79,
          4750.867,
          4750.502,
          4749.687,
          4748.413,
          4746.675,
          4744.464,
          4741.774,
          4738.595,
          4734.919,
          4730.7390000000005,
          4726.045,
          4720.8279999999995,
          4715.08,
          4708.791,
          4701.9529999999995,
          4694.553,
          4686.584,
          4678.032999999999,
          4668.89,
          4659.146,
          4648.788,
          4637.804,
          4626.183,
          4613.913,
          4600.979,
          4587.37,
          4573.072,
          4558.072,
          4542.354,
          4525.904,
          4508.707,
          4490.747,
          4472.008,
          4452.474,
          4432.126,
          4410.947,
          4388.919,
          4366.023,
          4342.238,
          4317.544,
          4291.9220000000005,
          4265.348,
          4237.8,
          4209.255,
          4179.689,
          4149.076,
          4117.391,
          4084.6059999999998,
          4050.6940000000004,
          4015.627,
          3979.373,
          3941.902,
          3903.183,
          3863.18,
          3821.862,
          3779.19,
          3735.127,
          3689.636,
          3642.675,
          3594.205,
          3544.1809999999996,
          3492.559,
          3439.2929999999997,
          3384.3340000000003,
          3327.635,
          3269.143,
          3208.8059999999996,
          3146.5690000000004,
          3082.3779999999997,
          3016.1740000000004,
          2947.9,
          2877.493,
          2804.8959999999997,
          2730.0440000000003,
          2652.8759999999997,
          2573.328,
          2491.34,
          2406.85,
          2319.798,
          2230.127,
          2137.784,
          2042.72,
          1944.8929999999998,
          1844.269,
          1740.8229999999999,
          1634.5439999999999,
          1525.434,
          1413.514,
          1298.826,
          1181.434,
          1061.434,
          938.95,
          814.1389999999999,
          687.201,
          558.37,
          427.92400000000004,
          296.18,
          163.498,
          30.27,
          -103.079,
          -236.101,
          -368.333,
          -499.306,
          -628.56,
          -755.6469999999999,
          -880.15,
          -1001.687,
          -1119.9189999999999,
          -1234.552,
          -1345.346,
          -1452.11,
          -1554.705,
          -1653.036,
          -1747.055,
          -1836.75,
          -1922.141,
          -2003.281,
          -2080.24,
          -2153.114,
          -2222.006,
          -2287.035,
          -2348.327,
          -2406.009,
          -2460.216,
          -2511.08,
          -2558.734,
          -2603.308,
          -2644.9309999999996,
          -2683.7259999999997,
          -2719.815,
          -2753.312,
          -2784.3320000000003,
          -2813.0209999999997,
          -2839.3590000000004,
          -2863.567,
          -2885.698,
          -2905.841,
          -2924.0809999999997,
          -2940.4990000000003,
          -2955.171,
          -2968.17,
          -2979.567,
          -2989.427,
          -2997.812,
          -3004.782,
          -3010.3940000000002,
          -3014.703,
          -3017.758,
          -3019.6090000000004,
          -3020.303,
          -3019.883,
          -3018.3909999999996,
          -3015.868,
          -3012.3520000000003,
          -3007.8790000000004,
          -3002.4829999999997,
          -2996.2,
          -2989.059,
          -2981.091,
          -2972.324,
          -2962.788,
          -2952.507,
          -2941.509,
          -2929.815,
          -2917.45,
          -2904.437,
          -2890.795,
          -2876.546,
          -2861.71,
          -2846.305,
          -2830.349,
          -2813.86,
          -2796.8540000000003,
          -2779.348,
          -2761.357,
          -2742.8959999999997,
          -2723.9790000000003,
          -2704.6209999999996,
          -2684.8340000000003,
          -2664.631,
          -2644.0240000000003,
          -2623.026,
          -2601.6479999999997,
          -2579.901,
          -2557.797,
          -2535.345,
          -2512.555,
          -2489.438,
          -2466.002,
          -2442.257,
          -2418.2110000000002,
          -2393.873,
          -2369.252,
          -2344.355,
          -2319.19,
          -2293.765,
          -2268.0860000000002,
          -2242.1620000000003,
          -2215.999,
          -2189.603,
          -2162.982,
          -2136.14,
          -2109.085,
          -2081.823,
          -2054.359,
          -2026.6989999999998,
          -1998.848,
          -1970.8120000000001,
          -1942.596,
          -1914.204,
          -1885.6429999999998,
          -1856.9160000000002,
          -1828.029,
          -1798.985,
          -1769.79,
          -1740.4479999999999,
          -1710.963,
          -1681.339,
          -1651.58,
          -1621.69,
          -1591.6729999999998,
          -1561.533,
          -1531.2720000000002,
          -1500.896,
          -1470.408,
          -1439.81,
          -1409.106,
          -1378.3,
          -1347.395,
          -1316.3929999999998,
          -1285.299,
          -1254.114,
          -1222.8419999999999,
          -1191.486,
          -1160.049,
          -1128.5330000000001,
          -1096.941,
          -1065.276,
          -1033.5410000000002,
          -1001.737,
          -969.8689999999999,
          -937.937,
          -905.944,
          -873.8939999999999,
          -841.7869999999999,
          -809.627,
          -777.416,
          -745.1560000000001,
          -712.8489999999999,
          -680.497,
          -648.1030000000001,
          -615.668,
          -583.195,
          -550.686,
          -518.1419999999999,
          -485.565,
          -452.958,
          -420.32300000000004,
          -387.661,
          -354.973,
          -322.263,
          -289.532,
          -256.781,
          -224.012,
          -191.227,
          -158.428,
          -125.616,
          -92.79299999999999,
          -59.96,
          -27.12,
          5.726,
          38.577,
          71.431,
          104.286,
          137.142,
          169.99599999999998,
          202.847,
          235.69299999999998,
          268.534,
          301.367,
          334.191,
          367.005,
          399.80800000000005,
          432.597,
          465.37199999999996,
          498.131,
          530.873,
          563.597,
          596.3009999999999,
          628.9830000000001,
          661.643,
          694.28,
          726.8910000000001,
          759.4760000000001,
          792.034,
          824.563,
          857.061,
          889.528,
          921.9630000000001,
          954.363,
          986.7289999999999,
          1019.058,
          1051.35,
          1083.603,
          1115.817,
          1147.989,
          1180.118,
          1212.205,
          1244.246,
          1276.242,
          1308.191,
          1340.0910000000001,
          1371.942,
          1403.743,
          1435.491,
          1467.1870000000001,
          1498.829,
          1530.4160000000002,
          1561.9460000000001,
          1593.4189999999999,
          1624.8329999999999,
          1656.1879999999999,
          1687.481,
          1718.713,
          1749.881,
          1780.985,
          1812.024,
          1842.995,
          1873.9,
          1904.735,
          1935.5,
          1966.193,
          1996.815,
          2027.3629999999998,
          2057.8360000000002,
          2088.234,
          2118.554,
          2148.797,
          2178.96,
          2209.0429999999997,
          2239.044,
          2268.962,
          2298.797,
          2328.5460000000003,
          2358.209,
          2387.785,
          2417.272,
          2446.669,
          2475.976,
          2505.19,
          2534.31,
          2563.3360000000002,
          2592.2670000000003,
          2621.1,
          2649.835,
          2678.47,
          2707.005,
          2735.438,
          2763.7670000000003,
          2791.992,
          2820.112,
          2848.1240000000003,
          2876.028,
          2903.823,
          2931.507,
          2959.078,
          2986.5370000000003,
          3013.88,
          3041.1079999999997,
          3068.218,
          3095.2090000000003,
          3122.08,
          3148.829,
          3175.4559999999997,
          3201.958,
          3228.335,
          3254.585,
          3280.7059999999997,
          3306.697,
          3332.5570000000002,
          3358.284,
          3383.8759999999997,
          3409.333,
          3434.653,
          3459.833,
          3484.8740000000003,
          3509.772,
          3534.527,
          3559.137,
          3583.6,
          3607.915,
          3632.08,
          3656.094,
          3679.955,
          3703.6609999999996,
          3727.21,
          3750.6020000000003,
          3773.833,
          3796.903,
          3819.809,
          3842.55,
          3865.1240000000003,
          3887.5290000000005,
          3909.763,
          3931.825,
          3953.7129999999997,
          3975.423,
          3996.9559999999997,
          4018.308,
          4039.478,
          4060.4629999999997,
          4081.263,
          4101.873,
          4122.294,
          4142.521,
          4162.554,
          4182.39,
          4202.027,
          4221.462,
          4240.694,
          4259.719,
          4278.536,
          4297.143,
          4315.536,
          4333.714,
          4351.673,
          4369.412,
          4386.928,
          4404.218,
          4421.28,
          4438.11,
          4454.707,
          4471.068,
          4487.189,
          4503.068,
          4518.7029999999995,
          4534.089,
          4549.224,
          4564.105,
          4578.729,
          4593.093,
          4607.193,
          4621.027,
          4634.59,
          4647.880999999999,
          4660.895,
          4673.628,
          4686.0779999999995,
          4698.24,
          4710.112,
          4721.688,
          4732.965999999999,
          4743.942,
          4754.611,
          4764.97,
          4775.014,
          4784.7390000000005,
          4794.141,
          4803.215999999999,
          4811.959,
          4820.365,
          4828.431,
          4836.151,
          4843.521,
          4850.536,
          4857.19,
          4863.478,
          4869.396,
          4874.937,
          4880.097,
          4884.87,
          4889.25,
          4893.232,
          4896.809,
          4899.976,
          4902.726,
          4905.052,
          4906.948,
          4908.407999999999,
          4909.4259999999995,
          4909.9929999999995,
          4910.102,
          4909.747,
          4908.92,
          4907.612,
          4905.817,
          4903.526,
          4900.731,
          4897.424,
          4893.595,
          4889.235,
          4884.335999999999,
          4878.888,
          4872.8820000000005,
          4866.307,
          4859.154,
          4851.411,
          4843.068,
          4834.1140000000005,
          4824.537,
          4814.326,
          4803.469,
          4791.954000000001,
          4779.766,
          4766.894,
          4753.323,
          4739.041,
          4724.031,
          4708.281,
          4691.773,
          4674.492,
          4656.423,
          4637.548,
          4617.85,
          4597.311,
          4575.912,
          4553.635,
          4530.46,
          4506.365,
          4481.33,
          4455.333,
          4428.352,
          4400.363,
          4371.340999999999,
          4341.263,
          4310.101,
          4277.829000000001,
          4244.418,
          4209.840999999999,
          4174.066,
          4137.063,
          4098.8,
          4059.242,
          4018.3559999999998,
          3976.105,
          3932.452,
          3887.3590000000004,
          3840.784,
          3792.687,
          3743.0240000000003,
          3691.75,
          3638.8190000000004,
          3584.183,
          3527.792,
          3469.594,
          3409.5370000000003,
          3347.5640000000003,
          3283.6209999999996,
          3217.647,
          3149.5840000000003,
          3079.369,
          3006.941,
          2932.2329999999997,
          2855.184,
          2775.7259999999997,
          2693.7929999999997,
          2609.32,
          2522.242,
          2432.498,
          2340.0229999999997,
          2244.762,
          2146.663,
          2045.6779999999999,
          1941.77,
          1834.912,
          1725.086,
          1612.2920000000001,
          1496.5479999999998,
          1377.8929999999998,
          1256.389,
          1132.128,
          1005.235,
          875.867,
          744.2230000000001,
          610.543,
          475.10699999999997,
          338.24,
          200.308,
          61.715,
          -77.102,
          -215.68,
          -353.539,
          -490.191,
          -625.156,
          -757.965,
          -888.18,
          -1015.3960000000001,
          -1139.252,
          -1259.438,
          -1375.693,
          -1487.8120000000001,
          -1595.64,
          -1699.0710000000001,
          -1798.047,
          -1892.5479999999998,
          -1982.5910000000001,
          -2068.223,
          -2149.513,
          -2226.556,
          -2299.456,
          -2368.334,
          -2433.317,
          -2494.5370000000003,
          -2552.132,
          -2606.236,
          -2656.989,
          -2704.5229999999997,
          -2748.974,
          -2790.468,
          -2829.13,
          -2865.083,
          -2898.442,
          -2929.317,
          -2957.8179999999998,
          -2984.045,
          -3008.0959999999995,
          -3030.062,
          -3050.035,
          -3068.097,
          -3084.329,
          -3098.8059999999996,
          -3111.6020000000003,
          -3122.7859999999996,
          -3132.422,
          -3140.573,
          -3147.298,
          -3152.6540000000005,
          -3156.695,
          -3159.4709999999995,
          -3161.0290000000005,
          -3161.4190000000003,
          -3160.6820000000002,
          -3158.86,
          -3155.995,
          -3152.1240000000003,
          -3147.283,
          -3141.507,
          -3134.829,
          -3127.28,
          -3118.8920000000003,
          -3109.6929999999998,
          -3099.711,
          -3088.9709999999995,
          -3077.5,
          -3065.323,
          -3052.461,
          -3038.937,
          -3024.7729999999997,
          -3009.991,
          -2994.6079999999997,
          -2978.6440000000002,
          -2962.118,
          -2945.047,
          -2927.448,
          -2909.336,
          -2890.728,
          -2871.638,
          -2852.0820000000003,
          -2832.074,
          -2811.625,
          -2790.7509999999997,
          -2769.462,
          -2747.7709999999997,
          -2725.69,
          -2703.23,
          -2680.403,
          -2657.218,
          -2633.6859999999997,
          -2609.817,
          -2585.62,
          -2561.104,
          -2536.279,
          -2511.153,
          -2485.734,
          -2460.031,
          -2434.052,
          -2407.804,
          -2381.294,
          -2354.53,
          -2327.519,
          -2300.268,
          -2272.784,
          -2245.072,
          -2217.139,
          -2188.991,
          -2160.635,
          -2132.075,
          -2103.3179999999998,
          -2074.368,
          -2045.231,
          -2015.9129999999998,
          -1986.4189999999999,
          -1956.7520000000002,
          -1926.9189999999999,
          -1896.9229999999998,
          -1866.769,
          -1836.463,
          -1806.007,
          -1775.4070000000002,
          -1744.6660000000002,
          -1713.7879999999998,
          -1682.7779999999998,
          -1651.64,
          -1620.376,
          -1588.9920000000002,
          -1557.489,
          -1525.8729999999998,
          -1494.146,
          -1462.3110000000001,
          -1430.3729999999998,
          -1398.3339999999998,
          -1366.1970000000001,
          -1333.965,
          -1301.643,
          -1269.232,
          -1236.735,
          -1204.155,
          -1171.496,
          -1138.76,
          -1105.9489999999998,
          -1073.066,
          -1040.114,
          -1007.096,
          -974.0139999999999,
          -940.87,
          -907.666,
          -874.4060000000001,
          -841.091,
          -807.725,
          -774.308,
          -740.8430000000001,
          -707.334,
          -673.78,
          -640.186,
          -606.552,
          -572.881,
          -539.175,
          -505.436,
          -471.666,
          -437.86699999999996,
          -404.04,
          -370.18800000000005,
          -336.31300000000005,
          -302.416,
          -268.499,
          -234.56400000000002,
          -200.612,
          -166.646,
          -132.667,
          -98.677,
          -64.67699999999999,
          -30.669,
          3.344,
          37.363,
          71.384,
          105.40700000000001,
          139.43,
          173.451,
          207.46900000000002,
          241.483,
          275.49,
          309.48900000000003,
          343.47900000000004,
          377.459,
          411.42699999999996,
          445.381,
          479.32,
          513.243,
          547.148,
          581.034,
          614.899,
          648.743,
          682.563,
          716.3589999999999,
          750.1289999999999,
          783.872,
          817.587,
          851.2710000000001,
          884.925,
          918.546,
          952.133,
          985.685,
          1019.201,
          1052.68,
          1086.12,
          1119.52,
          1152.878,
          1186.194,
          1219.4669999999999,
          1252.694,
          1285.875,
          1319.009,
          1352.094,
          1385.129,
          1418.1129999999998,
          1451.045,
          1483.9229999999998,
          1516.746,
          1549.514,
          1582.225,
          1614.8770000000002,
          1647.469,
          1680.0020000000002,
          1712.4720000000002,
          1744.879,
          1777.221,
          1809.499,
          1841.7089999999998,
          1873.852,
          1905.9260000000002,
          1937.9289999999999,
          1969.862,
          2001.721,
          2033.507,
          2065.217,
          2096.8520000000003,
          2128.409,
          2159.887,
          2191.286,
          2222.603,
          2253.839,
          2284.99,
          2316.058,
          2347.0389999999998,
          2377.933,
          2408.739,
          2439.455,
          2470.081,
          2500.614,
          2531.055,
          2561.401,
          2591.651,
          2621.803,
          2651.8579999999997,
          2681.813,
          2711.6679999999997,
          2741.42,
          2771.0690000000004,
          2800.613,
          2830.051,
          2859.382,
          2888.6040000000003,
          2917.716,
          2946.717,
          2975.6059999999998,
          3004.38,
          3033.039,
          3061.5809999999997,
          3090.005,
          3118.31,
          3146.494,
          3174.5559999999996,
          3202.494,
          3230.3059999999996,
          3257.992,
          3285.551,
          3312.9790000000003,
          3340.277,
          3367.442,
          3394.473,
          3421.369,
          3448.1279999999997,
          3474.748,
          3501.228,
          3527.567,
          3553.762,
          3579.813,
          3605.717,
          3631.473,
          3657.079,
          3682.534,
          3707.836,
          3732.9829999999997,
          3757.974,
          3782.8059999999996,
          3807.4790000000003,
          3831.99,
          3856.337,
          3880.5190000000002,
          3904.534,
          3928.38,
          3952.055,
          3975.5570000000002,
          3998.885,
          4022.0359999999996,
          4045.008,
          4067.8,
          4090.409,
          4112.834,
          4135.071,
          4157.121,
          4178.979,
          4200.644,
          4222.1140000000005,
          4243.387,
          4264.46,
          4285.332,
          4305.999,
          4326.459,
          4346.710999999999,
          4366.752,
          4386.579000000001,
          4406.19,
          4425.582,
          4444.754,
          4463.701,
          4482.4220000000005,
          4500.915,
          4519.175,
          4537.202,
          4554.991,
          4572.541,
          4589.848,
          4606.909000000001,
          4623.722,
          4640.282999999999,
          4656.59,
          4672.639,
          4688.427,
          4703.951,
          4719.208,
          4734.194,
          4748.907,
          4763.342000000001,
          4777.496,
          4791.365,
          4804.947,
          4818.237,
          4831.232,
          4843.928,
          4856.321,
          4868.407,
          4880.183,
          4891.643,
          4902.782999999999,
          4913.601,
          4924.09,
          4934.247,
          4944.068,
          4953.548,
          4962.681,
          4971.464,
          4979.891,
          4987.958,
          4995.659000000001,
          5002.99,
          5009.943,
          5016.516,
          5022.701,
          5028.494000000001,
          5033.889,
          5038.879,
          5043.459,
          5047.623,
          5051.3640000000005,
          5054.675,
          5057.5509999999995,
          5059.984,
          5061.968,
          5063.495,
          5064.558,
          5065.151,
          5065.265,
          5064.893,
          5064.026,
          5062.656,
          5060.775,
          5058.375,
          5055.447,
          5051.982,
          5047.97,
          5043.402,
          5038.269,
          5032.559,
          5026.263,
          5019.371,
          5011.871,
          5003.753,
          4995.004,
          4985.6140000000005,
          4975.569,
          4964.858,
          4953.467000000001,
          4941.384,
          4928.595,
          4915.084,
          4900.839,
          4885.845,
          4870.085999999999,
          4853.545999999999,
          4836.208,
          4818.056,
          4799.073,
          4779.24,
          4758.539000000001,
          4736.951,
          4714.455,
          4691.032999999999,
          4666.661,
          4641.319,
          4614.984,
          4587.630999999999,
          4559.238,
          4529.779,
          4499.227,
          4467.557,
          4434.7390000000005,
          4400.745,
          4365.545999999999,
          4329.11,
          4291.405,
          4252.396,
          4212.05,
          4170.331,
          4127.2,
          4082.6209999999996,
          4036.552,
          3988.95,
          3939.775,
          3888.9790000000003,
          3836.518,
          3782.341,
          3726.401,
          3668.645,
          3609.018,
          3547.466,
          3483.9309999999996,
          3418.3559999999998,
          3350.677,
          3280.835,
          3208.762,
          3134.395,
          3057.6679999999997,
          2978.509,
          2896.8540000000003,
          2812.63,
          2725.77,
          2636.205,
          2543.869,
          2448.696,
          2350.627,
          2249.603,
          2145.575,
          2038.5020000000002,
          1928.351,
          1815.101,
          1698.75,
          1579.3110000000001,
          1456.819,
          1331.336,
          1202.9489999999998,
          1071.7830000000001,
          937.9960000000001,
          801.7860000000001,
          663.395,
          523.107,
          381.25300000000004,
          238.206,
          94.38,
          -49.776,
          -193.785,
          -337.15,
          -479.36800000000005,
          -619.934,
          -758.363,
          -894.193,
          -1026.998,
          -1156.3980000000001,
          -1282.0610000000001,
          -1403.7089999999998,
          -1521.12,
          -1634.125,
          -1742.606,
          -1846.494,
          -1945.7620000000002,
          -2040.421,
          -2130.513,
          -2216.1079999999997,
          -2297.295,
          -2374.1839999999997,
          -2446.8920000000003,
          -2515.551,
          -2580.297,
          -2641.268,
          -2698.607,
          -2752.452,
          -2802.9429999999998,
          -2850.218,
          -2894.41,
          -2935.6490000000003,
          -2974.058,
          -3009.759,
          -3042.868,
          -3073.495,
          -3101.7470000000003,
          -3127.725,
          -3151.526,
          -3173.241,
          -3192.958,
          -3210.761,
          -3226.7290000000003,
          -3240.937,
          -3253.4590000000003,
          -3264.36,
          -3273.7070000000003,
          -3281.562,
          -3287.982,
          -3293.025,
          -3296.743,
          -3299.1859999999997,
          -3300.403,
          -3300.44,
          -3299.341,
          -3297.1459999999997,
          -3293.8979999999997,
          -3289.632,
          -3284.385,
          -3278.192,
          -3271.086,
          -3263.098,
          -3254.26,
          -3244.598,
          -3234.1420000000003,
          -3222.9179999999997,
          -3210.952,
          -3198.2670000000003,
          -3184.886,
          -3170.833,
          -3156.1290000000004,
          -3140.7940000000003,
          -3124.849,
          -3108.312,
          -3091.202,
          -3073.5359999999996,
          -3055.33,
          -3036.603,
          -3017.368,
          -2997.6420000000003,
          -2977.44,
          -2956.7740000000003,
          -2935.659,
          -2914.1079999999997,
          -2892.133,
          -2869.7459999999996,
          -2846.96,
          -2823.7859999999996,
          -2800.235,
          -2776.3179999999998,
          -2752.045,
          -2727.425,
          -2702.469,
          -2677.1859999999997,
          -2651.585,
          -2625.675,
          -2599.464,
          -2572.96,
          -2546.172,
          -2519.1079999999997,
          -2491.774,
          -2464.179,
          -2436.33,
          -2408.2329999999997,
          -2379.895,
          -2351.323,
          -2322.522,
          -2293.5,
          -2264.262,
          -2234.815,
          -2205.163,
          -2175.313,
          -2145.269,
          -2115.0370000000003,
          -2084.623,
          -2054.031,
          -2023.266,
          -1992.3329999999999,
          -1961.237,
          -1929.9820000000002,
          -1898.5720000000001,
          -1867.0120000000002,
          -1835.306,
          -1803.4589999999998,
          -1771.474,
          -1739.355,
          -1707.106,
          -1674.731,
          -1642.234,
          -1609.618,
          -1576.886,
          -1544.043,
          -1511.0910000000001,
          -1478.0339999999999,
          -1444.875,
          -1411.618,
          -1378.265,
          -1344.819,
          -1311.2839999999999,
          -1277.662,
          -1243.9569999999999,
          -1210.171,
          -1176.307,
          -1142.367,
          -1108.355,
          -1074.272,
          -1040.122,
          -1005.908,
          -971.6310000000001,
          -937.293,
          -902.8989999999999,
          -868.449,
          -833.946,
          -799.393,
          -764.791,
          -730.143,
          -695.451,
          -660.7180000000001,
          -625.945,
          -591.134,
          -556.288,
          -521.408,
          -486.49699999999996,
          -451.55699999999996,
          -416.588,
          -381.595,
          -346.577,
          -311.538,
          -276.478,
          -241.4,
          -206.30599999999998,
          -171.197,
          -136.075,
          -100.94200000000001,
          -65.8,
          -30.649,
          4.507,
          39.668,
          74.831,
          109.99600000000001,
          145.161,
          180.32299999999998,
          215.482,
          250.636,
          285.784,
          320.923,
          356.05199999999996,
          391.171,
          426.276,
          461.36800000000005,
          496.444,
          531.503,
          566.543,
          601.564,
          636.564,
          671.54,
          706.493,
          741.42,
          776.32,
          811.193,
          846.035,
          880.847,
          915.6260000000001,
          950.372,
          985.0830000000001,
          1019.757,
          1054.395,
          1088.993,
          1123.5510000000002,
          1158.068,
          1192.542,
          1226.971,
          1261.356,
          1295.694,
          1329.984,
          1364.225,
          1398.4160000000002,
          1432.555,
          1466.641,
          1500.6729999999998,
          1534.65,
          1568.57,
          1602.432,
          1636.235,
          1669.9779999999998,
          1703.658,
          1737.277,
          1770.8310000000001,
          1804.319,
          1837.741,
          1871.095,
          1904.381,
          1937.596,
          1970.739,
          2003.809,
          2036.806,
          2069.7270000000003,
          2102.572,
          2135.339,
          2168.027,
          2200.635,
          2233.161,
          2265.604,
          2297.964,
          2330.238,
          2362.425,
          2394.525,
          2426.536,
          2458.456,
          2490.285,
          2522.021,
          2553.6620000000003,
          2585.208,
          2616.657,
          2648.009,
          2679.26,
          2710.4109999999996,
          2741.46,
          2772.405,
          2803.2459999999996,
          2833.9809999999998,
          2864.6079999999997,
          2895.1259999999997,
          2925.534,
          2955.8309999999997,
          2986.015,
          3016.0840000000003,
          3046.039,
          3075.8759999999997,
          3105.593,
          3135.192,
          3164.6690000000003,
          3194.0229999999997,
          3223.2529999999997,
          3252.357,
          3281.3340000000003,
          3310.1820000000002,
          3338.9,
          3367.486,
          3395.9390000000003,
          3424.258,
          3452.44,
          3480.4829999999997,
          3508.388,
          3536.151,
          3563.772,
          3591.248,
          3618.579,
          3645.762,
          3672.795,
          3699.678,
          3726.408,
          3752.9829999999997,
          3779.402,
          3805.664,
          3831.7659999999996,
          3857.7059999999997,
          3883.4829999999997,
          3909.095,
          3934.5409999999997,
          3959.817,
          3984.923,
          4009.8559999999998,
          4034.615,
          4059.197,
          4083.6009999999997,
          4107.825,
          4131.866,
          4155.722,
          4179.392,
          4202.873,
          4226.164000000001,
          4249.2609999999995,
          4272.163,
          4294.8679999999995,
          4317.373,
          4339.6759999999995,
          4361.776,
          4383.668,
          4405.352,
          4426.8240000000005,
          4448.083,
          4469.125,
          4489.9490000000005,
          4510.552,
          4530.93,
          4551.083,
          4571.0070000000005,
          4590.6990000000005,
          4610.156,
          4629.376,
          4648.357,
          4667.094,
          4685.585999999999,
          4703.829000000001,
          4721.82,
          4739.557,
          4757.035,
          4774.253,
          4791.207,
          4807.893,
          4824.309,
          4840.45,
          4856.314,
          4871.898,
          4887.197,
          4902.208,
          4916.927,
          4931.351,
          4945.476,
          4959.298,
          4972.813,
          4986.018,
          4998.907,
          5011.477,
          5023.724,
          5035.644,
          5047.231,
          5058.481,
          5069.391,
          5079.956,
          5090.17,
          5100.028,
          5109.527,
          5118.661,
          5127.424,
          5135.812,
          5143.819,
          5151.44,
          5158.668,
          5165.499,
          5171.927,
          5177.945,
          5183.548,
          5188.73,
          5193.483,
          5197.802,
          5201.68,
          5205.111,
          5208.085999999999,
          5210.599,
          5212.643,
          5214.21,
          5215.293,
          5215.884,
          5215.975,
          5215.557,
          5214.623,
          5213.163,
          5211.169,
          5208.630999999999,
          5205.541,
          5201.889,
          5197.665,
          5192.859,
          5187.460999999999,
          5181.459,
          5174.843,
          5167.602,
          5159.725,
          5151.2,
          5142.013,
          5132.154,
          5121.608,
          5110.363,
          5098.404,
          5085.719,
          5072.293,
          5058.109,
          5043.154,
          5027.411,
          5010.863,
          4993.495,
          4975.288,
          4956.225,
          4936.287,
          4915.454000000001,
          4893.707,
          4871.026,
          4847.389,
          4822.775,
          4797.16,
          4770.522,
          4742.837,
          4714.0779999999995,
          4684.22,
          4653.236,
          4621.1,
          4587.78,
          4553.248,
          4517.473,
          4480.4220000000005,
          4442.062,
          4402.359,
          4361.276,
          4318.777,
          4274.822,
          4229.371,
          4182.384,
          4133.816,
          4083.623,
          4031.759,
          3978.1740000000004,
          3922.82,
          3865.6440000000002,
          3806.592,
          3745.6090000000004,
          3682.638,
          3617.619,
          3550.491,
          3481.19,
          3409.651,
          3335.809,
          3259.593,
          3180.935,
          3099.764,
          3016.008,
          2929.593,
          2840.449,
          2748.5040000000004,
          2653.685,
          2555.927,
          2455.1639999999998,
          2351.334,
          2244.386,
          2134.272,
          2020.955,
          1904.414,
          1784.64,
          1661.642,
          1535.453,
          1406.132,
          1273.765,
          1138.472,
          1000.413,
          859.785,
          716.832,
          571.841,
          425.148,
          277.133,
          128.219,
          -21.136,
          -170.43900000000002,
          -319.17900000000003,
          -466.834,
          -612.881,
          -756.815,
          -898.153,
          -1036.448,
          -1171.297,
          -1302.351,
          -1429.3120000000001,
          -1551.942,
          -1670.057,
          -1783.527,
          -1892.273,
          -1996.259,
          -2095.489,
          -2190.0029999999997,
          -2279.865,
          -2365.167,
          -2446.014,
          -2522.529,
          -2594.844,
          -2663.0959999999995,
          -2727.429,
          -2787.986,
          -2844.9120000000003,
          -2898.3509999999997,
          -2948.4440000000004,
          -2995.328,
          -3039.138,
          -3080.002,
          -3118.046,
          -3153.4240000000004,
          -3186.145,
          -3216.426,
          -3244.336,
          -3269.975,
          -3293.44,
          -3314.82,
          -3334.204,
          -3351.673,
          -3367.305,
          -3381.176,
          -3393.3559999999998,
          -3403.913,
          -3412.9109999999996,
          -3420.4109999999996,
          -3426.4709999999995,
          -3431.1479999999997,
          -3434.493,
          -3436.555,
          -3437.385,
          -3437.026,
          -3435.522,
          -3432.915,
          -3429.245,
          -3424.5490000000004,
          -3418.863,
          -3412.22,
          -3404.656,
          -3396.2009999999996,
          -3386.885,
          -3376.736,
          -3365.783,
          -3354.052,
          -3341.5679999999998,
          -3328.357,
          -3314.44,
          -3299.841,
          -3284.5809999999997,
          -3268.68,
          -3252.158,
          -3235.0359999999996,
          -3217.33,
          -3199.06,
          -3180.24,
          -3160.89,
          -3141.022,
          -3120.6540000000005,
          -3099.8,
          -3078.473,
          -3056.6890000000003,
          -3034.4590000000003,
          -3011.798,
          -2988.716,
          -2965.225,
          -2941.3390000000004,
          -2917.067,
          -2892.42,
          -2867.408,
          -2842.0429999999997,
          -2816.333,
          -2790.288,
          -2763.917,
          -2737.23,
          -2710.2340000000004,
          -2682.9390000000003,
          -2655.3520000000003,
          -2627.4809999999998,
          -2599.334,
          -2570.9179999999997,
          -2542.241,
          -2513.3089999999997,
          -2484.13,
          -2454.709,
          -2425.055,
          -2395.173,
          -2365.0679999999998,
          -2334.746,
          -2304.215,
          -2273.479,
          -2242.544,
          -2211.415,
          -2180.098,
          -2148.597,
          -2116.9179999999997,
          -2085.0660000000003,
          -2053.045,
          -2020.859,
          -1988.514,
          -1956.014,
          -1923.3629999999998,
          -1890.565,
          -1857.624,
          -1824.546,
          -1791.332,
          -1757.9879999999998,
          -1724.517,
          -1690.922,
          -1657.2079999999999,
          -1623.378,
          -1589.435,
          -1555.3829999999998,
          -1521.225,
          -1486.964,
          -1452.604,
          -1418.1470000000002,
          -1383.598,
          -1348.9579999999999,
          -1314.231,
          -1279.4189999999999,
          -1244.526,
          -1209.5539999999999,
          -1174.506,
          -1139.385,
          -1104.194,
          -1068.934,
          -1033.609,
          -998.221,
          -962.7719999999999,
          -927.265,
          -891.703,
          -856.087,
          -820.42,
          -784.705,
          -748.943,
          -713.137,
          -677.289,
          -641.401,
          -605.475,
          -569.514,
          -533.518,
          -497.49199999999996,
          -461.435,
          -425.351,
          -389.241,
          -353.10699999999997,
          -316.952,
          -280.776,
          -244.583,
          -208.373,
          -172.148,
          -135.911,
          -99.662,
          -63.405,
          -27.14,
          9.131,
          45.406000000000006,
          81.684,
          117.962,
          154.24,
          190.515,
          226.78599999999997,
          263.051,
          299.309,
          335.559,
          371.798,
          408.025,
          444.23900000000003,
          480.43800000000005,
          516.621,
          552.786,
          588.931,
          625.056,
          661.159,
          697.238,
          733.291,
          769.319,
          805.318,
          841.288,
          877.227,
          913.1339999999999,
          949.008,
          984.846,
          1020.6489999999999,
          1056.414,
          1092.14,
          1127.825,
          1163.469,
          1199.07,
          1234.627,
          1270.138,
          1305.6019999999999,
          1341.0179999999998,
          1376.385,
          1411.7,
          1446.963,
          1482.1729999999998,
          1517.328,
          1552.4260000000002,
          1587.4679999999998,
          1622.451,
          1657.3729999999998,
          1692.235,
          1727.0339999999999,
          1761.769,
          1796.4379999999999,
          1831.0420000000001,
          1865.578,
          1900.0439999999999,
          1934.441,
          1968.766,
          2003.0179999999998,
          2037.1960000000001,
          2071.298,
          2105.324,
          2139.272,
          2173.141,
          2206.929,
          2240.635,
          2274.257,
          2307.7960000000003,
          2341.249,
          2374.614,
          2407.891,
          2441.078,
          2474.175,
          2507.179,
          2540.089,
          2572.904,
          2605.623,
          2638.244,
          2670.7659999999996,
          2703.187,
          2735.507,
          2767.724,
          2799.836,
          2831.842,
          2863.741,
          2895.531,
          2927.211,
          2958.7790000000005,
          2990.2340000000004,
          3021.5759999999996,
          3052.801,
          3083.909,
          3114.8979999999997,
          3145.7670000000003,
          3176.514,
          3207.139,
          3237.638,
          3268.012,
          3298.258,
          3328.3740000000003,
          3358.361,
          3388.2140000000004,
          3417.934,
          3447.5190000000002,
          3476.967,
          3506.276,
          3535.4440000000004,
          3564.4709999999995,
          3593.355,
          3622.093,
          3650.685,
          3679.1279999999997,
          3707.421,
          3735.562,
          3763.5490000000004,
          3791.381,
          3819.055,
          3846.571,
          3873.926,
          3901.118,
          3928.1459999999997,
          3955.008,
          3981.7009999999996,
          4008.224,
          4034.575,
          4060.752,
          4086.7529999999997,
          4112.576,
          4138.219,
          4163.68,
          4188.957,
          4214.048,
          4238.951,
          4263.663,
          4288.183,
          4312.508,
          4336.6359999999995,
          4360.565,
          4384.292,
          4407.815,
          4431.1320000000005,
          4454.241,
          4477.139,
          4499.823,
          4522.292,
          4544.542,
          4566.571,
          4588.377,
          4609.957,
          4631.308,
          4652.427,
          4673.313,
          4693.960999999999,
          4714.37,
          4734.536,
          4754.458,
          4774.13,
          4793.552,
          4812.718,
          4831.628,
          4850.277,
          4868.662,
          4886.78,
          4904.628,
          4922.202,
          4939.5,
          4956.516,
          4973.249,
          4989.694,
          5005.848,
          5021.707,
          5037.268,
          5052.527,
          5067.479,
          5082.12,
          5096.448,
          5110.457,
          5124.144,
          5137.503,
          5150.532,
          5163.224,
          5175.577,
          5187.585,
          5199.2429999999995,
          5210.5470000000005,
          5221.492,
          5232.073,
          5242.286,
          5252.1230000000005,
          5261.581999999999,
          5270.655,
          5279.338000000001,
          5287.624,
          5295.509,
          5302.986999999999,
          5310.05,
          5316.693,
          5322.911,
          5328.696,
          5334.0419999999995,
          5338.943,
          5343.391,
          5347.38,
          5350.901999999999,
          5353.95,
          5356.517,
          5358.594,
          5360.174,
          5361.249,
          5361.811,
          5361.851,
          5361.361,
          5360.331,
          5358.753000000001,
          5356.616999999999,
          5353.914000000001,
          5350.633000000001,
          5346.766,
          5342.3009999999995,
          5337.227,
          5331.534000000001,
          5325.21,
          5318.244000000001,
          5310.625,
          5302.339,
          5293.375,
          5283.72,
          5273.359,
          5262.279,
          5250.467,
          5237.907999999999,
          5224.588,
          5210.4890000000005,
          5195.598,
          5179.896,
          5163.367,
          5145.995,
          5127.762,
          5108.648,
          5088.634,
          5067.7,
          5045.827,
          5022.9929999999995,
          4999.1759999999995,
          4974.355,
          4948.503,
          4921.6,
          4893.62,
          4864.535,
          4834.32,
          4802.947,
          4770.387,
          4736.611,
          4701.587,
          4665.282999999999,
          4627.667,
          4588.704000000001,
          4548.357,
          4506.592000000001,
          4463.367,
          4418.644,
          4372.3820000000005,
          4324.537,
          4275.064,
          4223.918,
          4171.05,
          4116.41,
          4059.948,
          4001.6079999999997,
          3941.336,
          3879.073,
          3814.761,
          3748.3390000000004,
          3679.741,
          3608.903,
          3535.757,
          3460.235,
          3382.264,
          3301.7740000000003,
          3218.688,
          3132.934,
          3044.435,
          2953.115,
          2858.901,
          2761.716,
          2661.49,
          2558.155,
          2451.645,
          2341.903,
          2228.88,
          2112.534,
          1992.839,
          1869.783,
          1743.3729999999998,
          1613.635,
          1480.6270000000002,
          1344.433,
          1205.1689999999999,
          1062.995,
          918.1080000000001,
          770.752,
          621.2180000000001,
          469.846,
          317.019,
          163.171,
          8.771,
          -145.67700000000002,
          -299.647,
          -452.6,
          -603.996,
          -753.308,
          -900.034,
          -1043.704,
          -1183.8980000000001,
          -1320.245,
          -1452.4289999999999,
          -1580.194,
          -1703.342,
          -1821.73,
          -1935.269,
          -2043.9129999999998,
          -2147.661,
          -2246.547,
          -2340.634,
          -2430.009,
          -2514.781,
          -2595.07,
          -2671.011,
          -2742.744,
          -2810.414,
          -2874.171,
          -2934.1609999999996,
          -2990.533,
          -3043.4309999999996,
          -3092.998,
          -3139.37,
          -3182.683,
          -3223.063,
          -3260.637,
          -3295.5209999999997,
          -3327.8320000000003,
          -3357.675,
          -3385.157,
          -3410.3740000000003,
          -3433.4240000000004,
          -3454.3940000000002,
          -3473.3709999999996,
          -3490.4359999999997,
          -3505.6659999999997,
          -3519.135,
          -3530.913,
          -3541.067,
          -3549.6609999999996,
          -3556.7529999999997,
          -3562.403,
          -3566.665,
          -3569.591,
          -3571.2290000000003,
          -3571.6290000000004,
          -3570.835,
          -3568.89,
          -3565.835,
          -3561.71,
          -3556.551,
          -3550.395,
          -3543.276,
          -3535.2270000000003,
          -3526.278,
          -3516.461,
          -3505.803,
          -3494.3320000000003,
          -3482.075,
          -3469.058,
          -3455.303,
          -3440.835,
          -3425.676,
          -3409.8459999999995,
          -3393.368,
          -3376.261,
          -3358.5440000000003,
          -3340.236,
          -3321.3540000000003,
          -3301.915,
          -3281.9359999999997,
          -3261.4320000000002,
          -3240.4190000000003,
          -3218.9120000000003,
          -3196.9240000000004,
          -3174.4709999999995,
          -3151.5640000000003,
          -3128.217,
          -3104.442,
          -3080.2509999999997,
          -3055.655,
          -3030.667,
          -3005.296,
          -2979.553,
          -2953.449,
          -2926.993,
          -2900.195,
          -2873.0640000000003,
          -2845.61,
          -2817.84,
          -2789.764,
          -2761.389,
          -2732.723,
          -2703.775,
          -2674.552,
          -2645.0609999999997,
          -2615.3089999999997,
          -2585.304,
          -2555.051,
          -2524.558,
          -2493.83,
          -2462.875,
          -2431.698,
          -2400.305,
          -2368.701,
          -2336.894,
          -2304.887,
          -2272.686,
          -2240.2960000000003,
          -2207.723,
          -2174.972,
          -2142.0460000000003,
          -2108.952,
          -2075.6929999999998,
          -2042.274,
          -2008.6989999999998,
          -1974.974,
          -1941.101,
          -1907.085,
          -1872.93,
          -1838.64,
          -1804.219,
          -1769.671,
          -1734.9979999999998,
          -1700.2060000000001,
          -1665.297,
          -1630.275,
          -1595.1429999999998,
          -1559.905,
          -1524.5639999999999,
          -1489.1229999999998,
          -1453.585,
          -1417.954,
          -1382.231,
          -1346.421,
          -1310.527,
          -1274.55,
          -1238.494,
          -1202.362,
          -1166.157,
          -1129.88,
          -1093.535,
          -1057.125,
          -1020.6510000000001,
          -984.1160000000001,
          -947.523,
          -910.8739999999999,
          -874.172,
          -837.418,
          -800.6160000000001,
          -763.7669999999999,
          -726.8739999999999,
          -689.938,
          -652.9630000000001,
          -615.95,
          -578.901,
          -541.818,
          -504.704,
          -467.56,
          -430.389,
          -393.19199999999995,
          -355.972,
          -318.73,
          -281.468,
          -244.188,
          -206.892,
          -169.582,
          -132.26,
          -94.926,
          -57.583999999999996,
          -20.235,
          17.119,
          54.477,
          91.837,
          129.19799999999998,
          166.55700000000002,
          203.912,
          241.263,
          278.608,
          315.945,
          353.272,
          390.589,
          427.892,
          465.18199999999996,
          502.455,
          539.711,
          576.9490000000001,
          614.1659999999999,
          651.361,
          688.534,
          725.681,
          762.802,
          799.895,
          836.959,
          873.993,
          910.995,
          947.9630000000001,
          984.895,
          1021.793,
          1058.652,
          1095.472,
          1132.252,
          1168.99,
          1205.685,
          1242.335,
          1278.9389999999999,
          1315.496,
          1352.004,
          1388.4620000000002,
          1424.868,
          1461.2220000000002,
          1497.5220000000002,
          1533.766,
          1569.953,
          1606.082,
          1642.152,
          1678.161,
          1714.108,
          1749.991,
          1785.81,
          1821.5620000000001,
          1857.247,
          1892.8629999999998,
          1928.4089999999999,
          1963.8829999999998,
          1999.285,
          2034.612,
          2069.864,
          2105.0389999999998,
          2140.136,
          2175.154,
          2210.091,
          2244.945,
          2279.716,
          2314.403,
          2349.0029999999997,
          2383.516,
          2417.939,
          2452.2729999999997,
          2486.514,
          2520.663,
          2554.718,
          2588.676,
          2622.538,
          2656.301,
          2689.9640000000004,
          2723.526,
          2756.985,
          2790.3390000000004,
          2823.5890000000004,
          2856.7309999999998,
          2889.765,
          2922.6890000000003,
          2955.502,
          2988.202,
          3020.788,
          3053.258,
          3085.611,
          3117.845,
          3149.9590000000003,
          3181.9509999999996,
          3213.82,
          3245.565,
          3277.183,
          3308.673,
          3340.034,
          3371.264,
          3402.361,
          3433.325,
          3464.152,
          3494.842,
          3525.393,
          3555.803,
          3586.071,
          3616.195,
          3646.1740000000004,
          3676.005,
          3705.687,
          3735.218,
          3764.5959999999995,
          3793.82,
          3822.888,
          3851.798,
          3880.548,
          3909.136,
          3937.5609999999997,
          3965.82,
          3993.9120000000003,
          4021.835,
          4049.587,
          4077.165,
          4104.569,
          4131.795,
          4158.842000000001,
          4185.708,
          4212.391,
          4238.889,
          4265.198,
          4291.319,
          4317.247,
          4342.981,
          4368.519,
          4393.859,
          4418.998,
          4443.934,
          4468.664000000001,
          4493.187,
          4517.499,
          4541.599,
          4565.484,
          4589.151,
          4612.598,
          4635.822,
          4658.821,
          4681.592000000001,
          4704.1320000000005,
          4726.439,
          4748.509,
          4770.340999999999,
          4791.931,
          4813.276,
          4834.373,
          4855.22,
          4875.813,
          4896.15,
          4916.227,
          4936.041,
          4955.589,
          4974.8679999999995,
          4993.873,
          5012.603,
          5031.053,
          5049.22,
          5067.101,
          5084.691,
          5101.988,
          5118.987,
          5135.684,
          5152.076,
          5168.159000000001,
          5183.929,
          5199.3820000000005,
          5214.513,
          5229.319,
          5243.795,
          5257.937,
          5271.74,
          5285.2,
          5298.311,
          5311.07,
          5323.472,
          5335.5109999999995,
          5347.183000000001,
          5358.482,
          5369.404,
          5379.943,
          5390.093000000001,
          5399.849,
          5409.206,
          5418.156999999999,
          5426.696999999999,
          5434.819,
          5442.518,
          5449.786999999999,
          5456.621,
          5463.0109999999995,
          5468.951999999999,
          5474.437,
          5479.4580000000005,
          5484.008000000001,
          5488.081,
          5491.668000000001,
          5494.7609999999995,
          5497.354,
          5499.438,
          5501.004,
          5502.045,
          5502.55,
          5502.513000000001,
          5501.923000000001,
          5500.77,
          5499.045999999999,
          5496.741,
          5493.843000000001,
          5490.344,
          5486.232,
          5481.496999999999,
          5476.1269999999995,
          5470.111,
          5463.436,
          5456.090999999999,
          5448.062,
          5439.339,
          5429.905,
          5419.75,
          5408.857,
          5397.213000000001,
          5384.802,
          5371.609,
          5357.62,
          5342.816,
          5327.182,
          5310.7,
          5293.352,
          5275.119000000001,
          5255.984,
          5235.925,
          5214.923,
          5192.956,
          5170.003,
          5146.041,
          5121.048,
          5094.999,
          5067.87,
          5039.633,
          5010.264,
          4979.734,
          4948.016,
          4915.0779999999995,
          4880.891,
          4845.423,
          4808.641,
          4770.51,
          4730.996,
          4690.062,
          4647.669,
          4603.776,
          4558.345,
          4511.332,
          4462.692,
          4412.38,
          4360.348,
          4306.545,
          4250.9220000000005,
          4193.423,
          4133.995,
          4072.58,
          4009.118,
          3943.548,
          3875.8059999999996,
          3805.827,
          3733.5429999999997,
          3658.883,
          3581.777,
          3502.15,
          3419.928,
          3335.033,
          3247.389,
          3156.9159999999997,
          3063.535,
          2967.1690000000003,
          2867.739,
          2765.171,
          2659.3920000000003,
          2550.334,
          2437.936,
          2322.1420000000003,
          2202.91,
          2080.21,
          1954.0220000000002,
          1824.351,
          1691.223,
          1554.6889999999999,
          1414.829,
          1271.761,
          1125.639,
          976.663,
          825.074,
          671.168,
          515.285,
          357.81699999999995,
          199.203,
          39.923,
          -119.51,
          -278.55400000000003,
          -436.654,
          -593.253,
          -747.805,
          -899.7860000000001,
          -1048.7089999999998,
          -1194.13,
          -1335.6589999999999,
          -1472.963,
          -1605.769,
          -1733.862,
          -1857.089,
          -1975.345,
          -2088.58,
          -2196.784,
          -2299.985,
          -2398.243,
          -2491.645,
          -2580.297,
          -2664.321,
          -2743.853,
          -2819.035,
          -2890.015,
          -2956.946,
          -3019.9770000000003,
          -3079.262,
          -3134.948,
          -3187.1809999999996,
          -3236.103,
          -3281.853,
          -3324.562,
          -3364.36,
          -3401.367,
          -3435.702,
          -3467.4770000000003,
          -3496.8,
          -3523.7729999999997,
          -3548.493,
          -3571.054,
          -3591.545,
          -3610.048,
          -3626.645,
          -3641.4120000000003,
          -3654.421,
          -3665.742,
          -3675.44,
          -3683.578,
          -3690.215,
          -3695.408,
          -3699.212,
          -3701.676,
          -3702.8520000000003,
          -3702.785,
          -3701.52,
          -3699.1,
          -3695.565,
          -3690.955,
          -3685.3059999999996,
          -3678.6540000000005,
          -3671.033,
          -3662.475,
          -3653.012,
          -3642.6740000000004,
          -3631.488,
          -3619.4829999999997,
          -3606.684,
          -3593.117,
          -3578.8059999999996,
          -3563.775,
          -3548.045,
          -3531.638,
          -3514.575,
          -3496.875,
          -3478.558,
          -3459.6420000000003,
          -3440.145,
          -3420.083,
          -3399.474,
          -3378.3340000000003,
          -3356.676,
          -3334.518,
          -3311.8709999999996,
          -3288.7509999999997,
          -3265.17,
          -3241.1420000000003,
          -3216.679,
          -3191.7940000000003,
          -3166.4970000000003,
          -3140.8,
          -3114.7129999999997,
          -3088.2490000000003,
          -3061.4159999999997,
          -3034.225,
          -3006.685,
          -2978.8059999999996,
          -2950.5959999999995,
          -2922.065,
          -2893.2209999999995,
          -2864.073,
          -2834.6279999999997,
          -2804.8940000000002,
          -2774.88,
          -2744.591,
          -2714.0359999999996,
          -2683.222,
          -2652.155,
          -2620.841,
          -2589.2889999999998,
          -2557.502,
          -2525.489,
          -2493.255,
          -2460.805,
          -2428.145,
          -2395.281,
          -2362.218,
          -2328.962,
          -2295.5170000000003,
          -2261.89,
          -2228.083,
          -2194.103,
          -2159.955,
          -2125.641,
          -2091.1679999999997,
          -2056.5389999999998,
          -2021.759,
          -1986.832,
          -1951.7620000000002,
          -1916.5529999999999,
          -1881.2079999999999,
          -1845.733,
          -1810.129,
          -1774.402,
          -1738.555,
          -1702.5910000000001,
          -1666.514,
          -1630.3270000000002,
          -1594.033,
          -1557.636,
          -1521.139,
          -1484.545,
          -1447.8570000000002,
          -1411.079,
          -1374.213,
          -1337.261,
          -1300.228,
          -1263.116,
          -1225.927,
          -1188.664,
          -1151.33,
          -1113.928,
          -1076.46,
          -1038.9289999999999,
          -1001.337,
          -963.686,
          -925.98,
          -888.221,
          -850.41,
          -812.55,
          -774.6439999999999,
          -736.694,
          -698.702,
          -660.67,
          -622.6,
          -584.495,
          -546.357,
          -508.18699999999995,
          -469.98800000000006,
          -431.76099999999997,
          -393.51,
          -355.235,
          -316.939,
          -278.623,
          -240.29,
          -201.94099999999997,
          -163.579,
          -125.204,
          -86.82,
          -48.427,
          -10.027999999999999,
          28.375999999999998,
          66.783,
          105.19200000000001,
          143.599,
          182.005,
          220.407,
          258.803,
          297.192,
          335.57300000000004,
          373.94300000000004,
          412.3,
          450.645,
          488.974,
          527.286,
          565.58,
          603.854,
          642.107,
          680.336,
          718.5419999999999,
          756.721,
          794.872,
          832.995,
          871.087,
          909.1469999999999,
          947.174,
          985.166,
          1023.122,
          1061.04,
          1098.9180000000001,
          1136.756,
          1174.552,
          1212.3039999999999,
          1250.012,
          1287.673,
          1325.286,
          1362.85,
          1400.364,
          1437.825,
          1475.234,
          1512.5870000000002,
          1549.885,
          1587.125,
          1624.306,
          1661.4270000000001,
          1698.486,
          1735.4820000000002,
          1772.414,
          1809.28,
          1846.078,
          1882.809,
          1919.469,
          1956.058,
          1992.575,
          2029.017,
          2065.384,
          2101.674,
          2137.886,
          2174.019,
          2210.071,
          2246.04,
          2281.925,
          2317.726,
          2353.44,
          2389.0660000000003,
          2424.603,
          2460.049,
          2495.404,
          2530.6639999999998,
          2565.83,
          2600.899,
          2635.8709999999996,
          2670.744,
          2705.515,
          2740.185,
          2774.7509999999997,
          2809.2129999999997,
          2843.5679999999998,
          2877.815,
          2911.952,
          2945.9790000000003,
          2979.893,
          3013.6940000000004,
          3047.3790000000004,
          3080.947,
          3114.397,
          3147.7259999999997,
          3180.935,
          3214.02,
          3246.9809999999998,
          3279.815,
          3312.522,
          3345.099,
          3377.546,
          3409.86,
          3442.039,
          3474.083,
          3505.99,
          3537.757,
          3569.383,
          3600.867,
          3632.2059999999997,
          3663.4,
          3694.445,
          3725.341,
          3756.086,
          3786.678,
          3817.115,
          3847.3959999999997,
          3877.5170000000003,
          3907.4790000000003,
          3937.278,
          3966.913,
          3996.382,
          4025.683,
          4054.8140000000003,
          4083.7729999999997,
          4112.558,
          4141.167,
          4169.598,
          4197.849,
          4225.918,
          4253.803,
          4281.502,
          4309.012,
          4336.331,
          4363.458,
          4390.389,
          4417.124,
          4443.657999999999,
          4469.991,
          4496.119000000001,
          4522.04,
          4547.753,
          4573.253,
          4598.54,
          4623.611,
          4648.462,
          4673.092000000001,
          4697.497,
          4721.6759999999995,
          4745.625,
          4769.340999999999,
          4792.823,
          4816.067,
          4839.07,
          4861.83,
          4884.344,
          4906.608,
          4928.619000000001,
          4950.376,
          4971.874,
          4993.11,
          5014.081,
          5034.784000000001,
          5055.215999999999,
          5075.373,
          5095.252,
          5114.849,
          5134.161,
          5153.184,
          5171.915,
          5190.35,
          5208.485,
          5226.316,
          5243.84,
          5261.052,
          5277.9490000000005,
          5294.526,
          5310.779,
          5326.705,
          5342.298000000001,
          5357.554,
          5372.469,
          5387.0380000000005,
          5401.255999999999,
          5415.12,
          5428.6230000000005,
          5441.76,
          5454.528,
          5466.92,
          5478.932,
          5490.559,
          5501.794,
          5512.632,
          5523.066999999999,
          5533.095,
          5542.7080000000005,
          5551.9,
          5560.6669999999995,
          5569,
          5576.893,
          5584.340999999999,
          5591.3369999999995,
          5597.8730000000005,
          5603.943,
          5609.5380000000005,
          5614.653,
          5619.279,
          5623.409000000001,
          5627.034000000001,
          5630.146,
          5632.738,
          5634.8009999999995,
          5636.326999999999,
          5637.305,
          5637.727,
          5637.584,
          5636.866999999999,
          5635.564,
          5633.6669999999995,
          5631.1630000000005,
          5628.044,
          5624.299,
          5619.915,
          5614.882,
          5609.187,
          5602.819,
          5595.764,
          5588.009,
          5579.543000000001,
          5570.351,
          5560.42,
          5549.733,
          5538.278,
          5526.036999999999,
          5512.996,
          5499.139,
          5484.4490000000005,
          5468.908,
          5452.499,
          5435.201999999999,
          5417,
          5397.8730000000005,
          5377.8009999999995,
          5356.762,
          5334.735,
          5311.696999999999,
          5287.626,
          5262.4980000000005,
          5236.289000000001,
          5208.971,
          5180.52,
          5150.907999999999,
          5120.107,
          5088.087,
          5054.818,
          5020.268,
          4984.406,
          4947.195,
          4908.603,
          4868.592000000001,
          4827.125,
          4784.161,
          4739.661,
          4693.583,
          4645.880999999999,
          4596.5109999999995,
          4545.4259999999995,
          4492.576,
          4437.911,
          4381.377,
          4322.918,
          4262.48,
          4200.002,
          4135.423,
          4068.68,
          3999.7070000000003,
          3928.437,
          3854.7990000000004,
          3778.722,
          3700.13,
          3618.95,
          3535.1009999999997,
          3448.507,
          3359.0840000000003,
          3266.752,
          3171.429,
          3073.034,
          2971.486,
          2866.704,
          2758.615,
          2647.147,
          2532.232,
          2413.815,
          2291.847,
          2166.291,
          2037.129,
          1904.361,
          1768.006,
          1628.112,
          1484.759,
          1338.059,
          1188.167,
          1035.279,
          879.638,
          721.54,
          561.327,
          399.399,
          236.197,
          72.212,
          -92.027,
          -255.975,
          -419.059,
          -580.703,
          -740.341,
          -897.433,
          -1051.47,
          -1201.988,
          -1348.578,
          -1490.8870000000002,
          -1628.626,
          -1761.565,
          -1889.536,
          -2012.425,
          -2130.17,
          -2242.755,
          -2350.2039999999997,
          -2452.573,
          -2549.9429999999998,
          -2642.423,
          -2730.134,
          -2813.2129999999997,
          -2891.804,
          -2966.058,
          -3036.1290000000004,
          -3102.172,
          -3164.342,
          -3222.7909999999997,
          -3277.67,
          -3329.1240000000003,
          -3377.295,
          -3422.3179999999998,
          -3464.312,
          -3503.446,
          -3539.7990000000004,
          -3573.4990000000003,
          -3604.66,
          -3633.385,
          -3659.775,
          -3683.927,
          -3705.933,
          -3725.8779999999997,
          -3743.847,
          -3759.9179999999997,
          -3774.165,
          -3786.6609999999996,
          -3797.474,
          -3806.6659999999997,
          -3814.303,
          -3820.441,
          -3825.136,
          -3828.44,
          -3830.407,
          -3831.0840000000003,
          -3830.5159999999996,
          -3828.7490000000003,
          -3825.823,
          -3821.781,
          -3816.659,
          -3810.4959999999996,
          -3803.325,
          -3795.1809999999996,
          -3786.094,
          -3776.099,
          -3765.222,
          -3753.494,
          -3740.94,
          -3727.587,
          -3713.46,
          -3698.583,
          -3682.9790000000003,
          -3666.671,
          -3649.68,
          -3632.027,
          -3613.73,
          -3594.81,
          -3575.285,
          -3555.172,
          -3534.488,
          -3513.25,
          -3491.474,
          -3469.175,
          -3446.369,
          -3423.0679999999998,
          -3399.2870000000003,
          -3375.04,
          -3350.3390000000004,
          -3325.197,
          -3299.625,
          -3273.636,
          -3247.241,
          -3220.4509999999996,
          -3193.276,
          -3165.7259999999997,
          -3137.813,
          -3109.545,
          -3080.9320000000002,
          -3051.9829999999997,
          -3022.7070000000003,
          -2993.113,
          -2963.208,
          -2933.0009999999997,
          -2902.4990000000003,
          -2871.712,
          -2840.645,
          -2809.3070000000002,
          -2777.703,
          -2745.842,
          -2713.73,
          -2681.373,
          -2648.778,
          -2615.951,
          -2582.897,
          -2549.624,
          -2516.136,
          -2482.439,
          -2448.54,
          -2414.442,
          -2380.151,
          -2345.673,
          -2311.012,
          -2276.173,
          -2241.161,
          -2205.98,
          -2170.636,
          -2135.132,
          -2099.472,
          -2063.6620000000003,
          -2027.705,
          -1991.605,
          -1955.3670000000002,
          -1918.993,
          -1882.489,
          -1845.8570000000002,
          -1809.101,
          -1772.226,
          -1735.233,
          -1698.128,
          -1660.9129999999998,
          -1623.592,
          -1586.1670000000001,
          -1548.6429999999998,
          -1511.021,
          -1473.306,
          -1435.501,
          -1397.608,
          -1359.629,
          -1321.569,
          -1283.43,
          -1245.215,
          -1206.9260000000002,
          -1168.566,
          -1130.138,
          -1091.645,
          -1053.088,
          -1014.471,
          -975.795,
          -937.064,
          -898.28,
          -859.445,
          -820.562,
          -781.632,
          -742.658,
          -703.643,
          -664.5880000000001,
          -625.496,
          -586.369,
          -547.2090000000001,
          -508.01800000000003,
          -468.79900000000004,
          -429.55199999999996,
          -390.281,
          -350.98699999999997,
          -311.672,
          -272.33799999999997,
          -232.987,
          -193.622,
          -154.243,
          -114.853,
          -75.454,
          -36.047,
          3.366,
          42.782,
          82.20100000000001,
          121.62,
          161.03799999999998,
          200.453,
          239.863,
          279.267,
          318.663,
          358.04900000000004,
          397.423,
          436.785,
          476.131,
          515.461,
          554.774,
          594.067,
          633.339,
          672.5880000000001,
          711.813,
          751.012,
          790.183,
          829.326,
          868.439,
          907.5189999999999,
          946.567,
          985.579,
          1024.555,
          1063.493,
          1102.391,
          1141.249,
          1180.0639999999999,
          1218.836,
          1257.562,
          1296.242,
          1334.8729999999998,
          1373.455,
          1411.986,
          1450.464,
          1488.889,
          1527.2579999999998,
          1565.57,
          1603.8239999999998,
          1642.019,
          1680.152,
          1718.223,
          1756.23,
          1794.172,
          1832.047,
          1869.854,
          1907.5910000000001,
          1945.257,
          1982.851,
          2020.372,
          2057.817,
          2095.185,
          2132.475,
          2169.686,
          2206.8160000000003,
          2243.863,
          2280.827,
          2317.705,
          2354.4970000000003,
          2391.201,
          2427.815,
          2464.3379999999997,
          2500.769,
          2537.106,
          2573.348,
          2609.493,
          2645.54,
          2681.487,
          2717.3320000000003,
          2753.075,
          2788.7140000000004,
          2824.248,
          2859.6740000000004,
          2894.991,
          2930.198,
          2965.2940000000003,
          3000.276,
          3035.143,
          3069.8940000000002,
          3104.528,
          3139.0409999999997,
          3173.434,
          3207.704,
          3241.85,
          3275.87,
          3309.762,
          3343.525,
          3377.158,
          3410.658,
          3444.0240000000003,
          3477.255,
          3510.348,
          3543.302,
          3576.115,
          3608.785,
          3641.3109999999997,
          3673.692,
          3705.9240000000004,
          3738.007,
          3769.9390000000003,
          3801.717,
          3833.34,
          3864.8070000000002,
          3896.114,
          3927.261,
          3958.245,
          3989.065,
          4019.719,
          4050.204,
          4080.518,
          4110.66,
          4140.628,
          4170.42,
          4200.032999999999,
          4229.465,
          4258.715,
          4287.78,
          4316.657,
          4345.346,
          4373.843,
          4402.147,
          4430.255,
          4458.164000000001,
          4485.873,
          4513.379,
          4540.68,
          4567.773,
          4594.656,
          4621.327,
          4647.782999999999,
          4674.021,
          4700.039000000001,
          4725.835,
          4751.405,
          4776.747,
          4801.859,
          4826.737,
          4851.379,
          4875.781,
          4899.942,
          4923.858,
          4947.526,
          4970.944,
          4994.108,
          5017.015,
          5039.662,
          5062.045999999999,
          5084.163,
          5106.0109999999995,
          5127.585,
          5148.884,
          5169.902,
          5190.637,
          5211.085999999999,
          5231.244000000001,
          5251.108,
          5270.674,
          5289.939,
          5308.898,
          5327.548000000001,
          5345.885,
          5363.904,
          5381.602,
          5398.974,
          5416.016,
          5432.723000000001,
          5449.092,
          5465.118,
          5480.795,
          5496.12,
          5511.0869999999995,
          5525.691999999999,
          5539.931,
          5553.797,
          5567.285,
          5580.391,
          5593.109,
          5605.433000000001,
          5617.358,
          5628.879,
          5639.988,
          5650.681,
          5660.951999999999,
          5670.794,
          5680.2,
          5689.164000000001,
          5697.681,
          5705.741999999999,
          5713.342,
          5720.473000000001,
          5727.128000000001,
          5733.299,
          5738.979,
          5744.16,
          5748.835,
          5752.994000000001,
          5756.630999999999,
          5759.735,
          5762.299,
          5764.315,
          5765.772,
          5766.661,
          5766.973000000001,
          5766.698,
          5765.826,
          5764.346,
          5762.246999999999,
          5759.52,
          5756.151,
          5752.132,
          5747.4490000000005,
          5742.089,
          5736.0419999999995,
          5729.294,
          5721.831,
          5713.64,
          5704.706999999999,
          5695.018,
          5684.558000000001,
          5673.313,
          5661.265,
          5648.399,
          5634.6990000000005,
          5620.146,
          5604.724,
          5588.414000000001,
          5571.198,
          5553.056,
          5533.967,
          5513.911999999999,
          5492.868,
          5470.814,
          5447.727,
          5423.5830000000005,
          5398.359,
          5372.026999999999,
          5344.562,
          5315.938,
          5286.1269999999995,
          5255.099,
          5222.823,
          5189.27,
          5154.406,
          5118.1990000000005,
          5080.613,
          5041.612,
          5001.16,
          4959.217000000001,
          4915.7429999999995,
          4870.695,
          4824.032999999999,
          4775.708,
          4725.6759999999995,
          4673.887,
          4620.291,
          4564.835999999999,
          4507.465999999999,
          4448.127,
          4386.759,
          4323.3009999999995,
          4257.691,
          4189.8640000000005,
          4119.751,
          4047.284,
          3972.389,
          3894.994,
          3815.0209999999997,
          3732.393,
          3647.0290000000005,
          3558.8459999999995,
          3467.762,
          3373.691,
          3276.551,
          3176.2540000000004,
          3072.718,
          2965.86,
          2855.6,
          2741.865,
          2624.5820000000003,
          2503.6929999999998,
          2379.143,
          2250.895,
          2118.924,
          1983.225,
          1843.815,
          1700.739,
          1554.0720000000001,
          1403.924,
          1250.447,
          1093.835,
          934.332,
          772.2330000000001,
          607.883,
          441.684,
          274.085,
          105.583,
          -63.287,
          -231.959,
          -399.849,
          -566.367,
          -730.929,
          -892.9739999999999,
          -1051.974,
          -1207.447,
          -1358.961,
          -1506.149,
          -1648.701,
          -1786.375,
          -1918.986,
          -2046.411,
          -2168.577,
          -2285.4610000000002,
          -2397.0789999999997,
          -2503.485,
          -2604.759,
          -2701.006,
          -2792.347,
          -2878.921,
          -2960.873,
          -3038.357,
          -3111.5290000000005,
          -3180.546,
          -3245.5690000000004,
          -3306.752,
          -3364.2490000000003,
          -3418.211,
          -3468.78,
          -3516.099,
          -3560.302,
          -3601.5209999999997,
          -3639.8779999999997,
          -3675.495,
          -3708.4829999999997,
          -3738.954,
          -3767.01,
          -3792.7509999999997,
          -3816.27,
          -3837.658,
          -3857.0009999999997,
          -3874.3790000000004,
          -3889.869,
          -3903.546,
          -3915.4809999999998,
          -3925.738,
          -3934.383,
          -3941.4759999999997,
          -3947.074,
          -3951.2329999999997,
          -3954.005,
          -3955.44,
          -3955.586,
          -3954.489,
          -3952.191,
          -3948.735,
          -3944.16,
          -3938.505,
          -3931.805,
          -3924.0959999999995,
          -3915.41,
          -3905.781,
          -3895.237,
          -3883.81,
          -3871.526,
          -3858.413,
          -3844.4959999999996,
          -3829.801,
          -3814.3509999999997,
          -3798.17,
          -3781.28,
          -3763.7009999999996,
          -3745.455,
          -3726.5609999999997,
          -3707.038,
          -3686.9040000000005,
          -3666.177,
          -3644.8740000000003,
          -3623.012,
          -3600.6059999999998,
          -3577.672,
          -3554.224,
          -3530.277,
          -3505.844,
          -3480.94,
          -3455.575,
          -3429.765,
          -3403.5190000000002,
          -3376.8509999999997,
          -3349.77,
          -3322.29,
          -3294.4190000000003,
          -3266.17,
          -3237.55,
          -3208.571,
          -3179.241,
          -3149.571,
          -3119.5679999999998,
          -3089.241,
          -3058.599,
          -3027.65,
          -2996.402,
          -2964.863,
          -2933.04,
          -2900.94,
          -2868.57,
          -2835.9390000000003,
          -2803.051,
          -2769.915,
          -2736.535,
          -2702.9190000000003,
          -2669.073,
          -2635.002,
          -2600.712,
          -2566.21,
          -2531.499,
          -2496.587,
          -2461.479,
          -2426.178,
          -2390.6910000000003,
          -2355.022,
          -2319.176,
          -2283.158,
          -2246.972,
          -2210.623,
          -2174.115,
          -2137.452,
          -2100.639,
          -2063.68,
          -2026.579,
          -1989.34,
          -1951.9660000000001,
          -1914.4620000000002,
          -1876.8310000000001,
          -1839.0770000000002,
          -1801.203,
          -1763.213,
          -1725.111,
          -1686.899,
          -1648.5810000000001,
          -1610.16,
          -1571.64,
          -1533.024,
          -1494.3139999999999,
          -1455.514,
          -1416.626,
          -1377.655,
          -1338.601,
          -1299.469,
          -1260.261,
          -1220.98,
          -1181.629,
          -1142.2089999999998,
          -1102.725,
          -1063.177,
          -1023.57,
          -983.905,
          -944.185,
          -904.4119999999999,
          -864.5880000000001,
          -824.717,
          -784.8,
          -744.84,
          -704.8380000000001,
          -664.798,
          -624.721,
          -584.609,
          -544.465,
          -504.29,
          -464.088,
          -423.85900000000004,
          -383.606,
          -343.33099999999996,
          -303.036,
          -262.723,
          -222.394,
          -182.05,
          -141.695,
          -101.32799999999999,
          -60.95399999999999,
          -20.572,
          19.814,
          60.20399999999999,
          100.595,
          140.985,
          181.373,
          221.757,
          262.135,
          302.505,
          342.86699999999996,
          383.217,
          423.555,
          463.879,
          504.18699999999995,
          544.477,
          584.748,
          624.999,
          665.227,
          705.43,
          745.6089999999999,
          785.76,
          825.882,
          865.9739999999999,
          906.034,
          946.061,
          986.053,
          1026.008,
          1065.925,
          1105.803,
          1145.639,
          1185.433,
          1225.183,
          1264.888,
          1304.545,
          1344.154,
          1383.7120000000002,
          1423.219,
          1462.674,
          1502.0729999999999,
          1541.4170000000001,
          1580.703,
          1619.93,
          1659.0970000000002,
          1698.203,
          1737.245,
          1776.2220000000002,
          1815.1329999999998,
          1853.976,
          1892.75,
          1931.454,
          1970.085,
          2008.6429999999998,
          2047.1270000000002,
          2085.533,
          2123.862,
          2162.112,
          2200.281,
          2238.367,
          2276.37,
          2314.288,
          2352.118,
          2389.861,
          2427.514,
          2465.076,
          2502.5460000000003,
          2539.9210000000003,
          2577.201,
          2614.383,
          2651.468,
          2688.4509999999996,
          2725.3340000000003,
          2762.113,
          2798.7870000000003,
          2835.3559999999998,
          2871.816,
          2908.167,
          2944.408,
          2980.535,
          3016.5490000000004,
          3052.448,
          3088.2290000000003,
          3123.8909999999996,
          3159.433,
          3194.853,
          3230.1490000000003,
          3265.32,
          3300.364,
          3335.28,
          3370.065,
          3404.719,
          3439.238,
          3473.623,
          3507.87,
          3541.978,
          3575.946,
          3609.772,
          3643.454,
          3676.99,
          3710.3779999999997,
          3743.617,
          3776.705,
          3809.64,
          3842.4190000000003,
          3875.042,
          3907.506,
          3939.809,
          3971.95,
          4003.926,
          4035.736,
          4067.377,
          4098.848,
          4130.146,
          4161.27,
          4192.217000000001,
          4222.985,
          4253.572,
          4283.977,
          4314.196,
          4344.228,
          4374.07,
          4403.721,
          4433.177,
          4462.437,
          4491.499,
          4520.359,
          4549.016,
          4577.468,
          4605.710999999999,
          4633.7429999999995,
          4661.563,
          4689.166,
          4716.552,
          4743.715999999999,
          4770.657,
          4797.372,
          4823.859,
          4850.113,
          4876.134,
          4901.918,
          4927.460999999999,
          4952.762,
          4977.818,
          5002.624,
          5027.179,
          5051.479,
          5075.521,
          5099.302,
          5122.819,
          5146.069,
          5169.0470000000005,
          5191.752,
          5214.179,
          5236.326,
          5258.187,
          5279.7609999999995,
          5301.043000000001,
          5322.029,
          5342.717,
          5363.102,
          5383.18,
          5402.946999999999,
          5422.4,
          5441.534000000001,
          5460.345,
          5478.829000000001,
          5496.982,
          5514.799,
          5532.275,
          5549.406999999999,
          5566.189,
          5582.618,
          5598.687,
          5614.393,
          5629.729,
          5644.691999999999,
          5659.276,
          5673.476,
          5687.286,
          5700.701,
          5713.715,
          5726.323,
          5738.519,
          5750.295999999999,
          5761.649,
          5772.571999999999,
          5783.058000000001,
          5793.1,
          5802.693,
          5811.828,
          5820.5,
          5828.701999999999,
          5836.4259999999995,
          5843.665,
          5850.411,
          5856.656999999999,
          5862.394,
          5867.615,
          5872.311,
          5876.473000000001,
          5880.094,
          5883.164000000001,
          5885.674,
          5887.615,
          5888.977,
          5889.751,
          5889.9259999999995,
          5889.491999999999,
          5888.438,
          5886.754,
          5884.429,
          5881.4490000000005,
          5877.806,
          5873.485,
          5868.476,
          5862.764,
          5856.3369999999995,
          5849.182,
          5841.284000000001,
          5832.628000000001,
          5823.201,
          5812.988,
          5801.973000000001,
          5790.14,
          5777.471,
          5763.951,
          5749.562,
          5734.285,
          5718.102,
          5700.994000000001,
          5682.94,
          5663.920999999999,
          5643.916,
          5622.9,
          5600.854,
          5577.753000000001,
          5553.573,
          5528.289000000001,
          5501.875,
          5474.305,
          5445.55,
          5415.5830000000005,
          5384.3730000000005,
          5351.89,
          5318.1,
          5282.973000000001,
          5246.473000000001,
          5208.565,
          5169.212,
          5128.375,
          5086.016,
          5042.092000000001,
          4996.561,
          4949.378,
          4900.498,
          4849.873,
          4797.451,
          4743.183,
          4687.014,
          4628.888,
          4568.748,
          4506.534000000001,
          4442.183,
          4375.630999999999,
          4306.811,
          4235.653,
          4162.087,
          4086.0359999999996,
          4007.428,
          3926.18,
          3842.215,
          3755.449,
          3665.796,
          3573.172,
          3477.488,
          3378.659,
          3276.594,
          3171.2070000000003,
          3062.413,
          2950.1290000000004,
          2834.276,
          2714.781,
          2591.578,
          2464.611,
          2333.837,
          2199.229,
          2060.776,
          1918.4920000000002,
          1772.4189999999999,
          1622.626,
          1469.223,
          1312.356,
          1152.219,
          989.053,
          823.155,
          654.87,
          484.603,
          312.809,
          139.989,
          -33.31,
          -206.513,
          -379.022,
          -550.231,
          -719.539,
          -886.368,
          -1050.1689999999999,
          -1210.442,
          -1366.737,
          -1518.665,
          -1665.902,
          -1808.1870000000001,
          -1945.325,
          -2077.178,
          -2203.665,
          -2324.754,
          -2440.4570000000003,
          -2550.821,
          -2655.9240000000004,
          -2755.868,
          -2850.777,
          -2940.7870000000003,
          -3026.047,
          -3106.7090000000003,
          -3182.9359999999997,
          -3254.886,
          -3322.723,
          -3386.605,
          -3446.688,
          -3503.127,
          -3556.07,
          -3605.6609999999996,
          -3652.038,
          -3695.337,
          -3735.683,
          -3773.202,
          -3808.007,
          -3840.215,
          -3869.929,
          -3897.252,
          -3922.282,
          -3945.111,
          -3965.8259999999996,
          -3984.512,
          -4001.2490000000003,
          -4016.111,
          -4029.173,
          -4040.502,
          -4050.163,
          -4058.2209999999995,
          -4064.7329999999997,
          -4069.758,
          -4073.348,
          -4075.555,
          -4076.43,
          -4076.0190000000002,
          -4074.366,
          -4071.513,
          -4067.505,
          -4062.3779999999997,
          -4056.17,
          -4048.917,
          -4040.6540000000005,
          -4031.413,
          -4021.2259999999997,
          -4010.1240000000003,
          -3998.135,
          -3985.288,
          -3971.6079999999997,
          -3957.1220000000003,
          -3941.853,
          -3925.828,
          -3909.067,
          -3891.593,
          -3873.427,
          -3854.5890000000004,
          -3835.099,
          -3814.9759999999997,
          -3794.238,
          -3772.902,
          -3750.987,
          -3728.507,
          -3705.4790000000003,
          -3681.9179999999997,
          -3657.8390000000004,
          -3633.256,
          -3608.1820000000002,
          -3582.632,
          -3556.618,
          -3530.152,
          -3503.2470000000003,
          -3475.914,
          -3448.165,
          -3420.011,
          -3391.4629999999997,
          -3362.53,
          -3333.223,
          -3303.552,
          -3273.526,
          -3243.1540000000005,
          -3212.445,
          -3181.408,
          -3150.052,
          -3118.384,
          -3086.4120000000003,
          -3054.145,
          -3021.5890000000004,
          -2988.7529999999997,
          -2955.643,
          -2922.2670000000003,
          -2888.63,
          -2854.74,
          -2820.603,
          -2786.2259999999997,
          -2751.615,
          -2716.775,
          -2681.712,
          -2646.433,
          -2610.9429999999998,
          -2575.2470000000003,
          -2539.35,
          -2503.258,
          -2466.976,
          -2430.508,
          -2393.86,
          -2357.036,
          -2320.042,
          -2282.88,
          -2245.5570000000002,
          -2208.076,
          -2170.4410000000003,
          -2132.657,
          -2094.7270000000003,
          -2056.657,
          -2018.4489999999998,
          -1980.108,
          -1941.636,
          -1903.039,
          -1864.32,
          -1825.481,
          -1786.527,
          -1747.461,
          -1708.287,
          -1669.007,
          -1629.625,
          -1590.145,
          -1550.568,
          -1510.899,
          -1471.14,
          -1431.295,
          -1391.365,
          -1351.355,
          -1311.267,
          -1271.103,
          -1230.867,
          -1190.5610000000001,
          -1150.188,
          -1109.75,
          -1069.25,
          -1028.691,
          -988.075,
          -947.404,
          -906.681,
          -865.908,
          -825.0880000000001,
          -784.2230000000001,
          -743.316,
          -702.368,
          -661.382,
          -620.359,
          -579.303,
          -538.215,
          -497.098,
          -455.954,
          -414.784,
          -373.59,
          -332.376,
          -291.142,
          -249.891,
          -208.625,
          -167.345,
          -126.054,
          -84.75399999999999,
          -43.446000000000005,
          -2.1319999999999997,
          39.186,
          80.505,
          121.825,
          163.144,
          204.458,
          245.768,
          287.07099999999997,
          328.365,
          369.649,
          410.921,
          452.17900000000003,
          493.421,
          534.646,
          575.8530000000001,
          617.038,
          658.202,
          699.342,
          740.456,
          781.543,
          822.602,
          863.63,
          904.627,
          945.59,
          986.518,
          1027.4089999999999,
          1068.262,
          1109.076,
          1149.848,
          1190.577,
          1231.262,
          1271.901,
          1312.4920000000002,
          1353.0339999999999,
          1393.526,
          1433.9660000000001,
          1474.3529999999998,
          1514.684,
          1554.9589999999998,
          1595.1760000000002,
          1635.3339999999998,
          1675.43,
          1715.464,
          1755.433,
          1795.3370000000002,
          1835.174,
          1874.943,
          1914.641,
          1954.2679999999998,
          1993.8220000000001,
          2033.3010000000002,
          2072.7039999999997,
          2112.03,
          2151.276,
          2190.442,
          2229.526,
          2268.527,
          2307.442,
          2346.271,
          2385.011,
          2423.6620000000003,
          2462.222,
          2500.689,
          2539.062,
          2577.34,
          2615.52,
          2653.6009999999997,
          2691.5809999999997,
          2729.46,
          2767.236,
          2804.906,
          2842.47,
          2879.925,
          2917.2709999999997,
          2954.505,
          2991.627,
          3028.633,
          3065.5240000000003,
          3102.297,
          3138.95,
          3175.482,
          3211.8909999999996,
          3248.176,
          3284.335,
          3320.366,
          3356.2670000000003,
          3392.038,
          3427.675,
          3463.177,
          3498.5440000000003,
          3533.772,
          3568.86,
          3603.8059999999996,
          3638.6090000000004,
          3673.2659999999996,
          3707.776,
          3742.138,
          3776.348,
          3810.406,
          3844.309,
          3878.0559999999996,
          3911.6440000000002,
          3945.071,
          3978.337,
          4011.438,
          4044.373,
          4077.139,
          4109.735,
          4142.159000000001,
          4174.407999999999,
          4206.481,
          4238.375,
          4270.088,
          4301.6179999999995,
          4332.963,
          4364.12,
          4395.088,
          4425.8640000000005,
          4456.446,
          4486.831,
          4517.018,
          4547.004,
          4576.786,
          4606.362,
          4635.729,
          4664.8859999999995,
          4693.829000000001,
          4722.557,
          4751.066,
          4779.353,
          4807.417,
          4835.255,
          4862.863,
          4890.2390000000005,
          4917.380999999999,
          4944.285,
          4970.9490000000005,
          4997.369000000001,
          5023.543,
          5049.468,
          5075.141,
          5100.558,
          5125.717000000001,
          5150.615,
          5175.247,
          5199.612,
          5223.704000000001,
          5247.522,
          5271.062,
          5294.32,
          5317.293000000001,
          5339.978,
          5362.37,
          5384.465999999999,
          5406.262,
          5427.754,
          5448.939,
          5469.812,
          5490.37,
          5510.608,
          5530.522,
          5550.109,
          5569.363,
          5588.28,
          5606.856,
          5625.0869999999995,
          5642.967,
          5660.491999999999,
          5677.656,
          5694.456999999999,
          5710.888000000001,
          5726.944,
          5742.62,
          5757.911,
          5772.811,
          5787.315,
          5801.4169999999995,
          5815.111999999999,
          5828.394,
          5841.255999999999,
          5853.693,
          5865.6990000000005,
          5877.267,
          5888.391,
          5899.063,
          5909.278,
          5919.029,
          5928.308000000001,
          5937.108,
          5945.423000000001,
          5953.243,
          5960.563,
          5967.3730000000005,
          5973.666,
          5979.433000000001,
          5984.6669999999995,
          5989.358,
          5993.496999999999,
          5997.075,
          6000.084,
          6002.513000000001,
          6004.354,
          6005.595,
          6006.227,
          6006.2390000000005,
          6005.62,
          6004.359,
          6002.445,
          5999.866,
          5996.609,
          5992.664000000001,
          5988.017,
          5982.655,
          5976.565,
          5969.732,
          5962.143,
          5953.784000000001,
          5944.638000000001,
          5934.691,
          5923.927,
          5912.329000000001,
          5899.882,
          5886.566,
          5872.365,
          5857.259,
          5841.231,
          5824.259,
          5806.3240000000005,
          5787.405,
          5767.48,
          5746.528,
          5724.524,
          5701.444,
          5677.265,
          5651.960999999999,
          5625.505999999999,
          5597.871,
          5569.029,
          5538.95,
          5507.605,
          5474.960999999999,
          5440.986,
          5405.647,
          5368.908,
          5330.732,
          5291.0830000000005,
          5249.920999999999,
          5207.206,
          5162.894,
          5116.944,
          5069.309,
          5019.943,
          4968.794,
          4915.814,
          4860.95,
          4804.146,
          4745.344,
          4684.488,
          4621.514,
          4556.358,
          4488.956,
          4419.238,
          4347.133,
          4272.568,
          4195.468,
          4115.752,
          4033.343,
          3948.1540000000005,
          3860.1040000000003,
          3769.103,
          3675.065,
          3577.8990000000003,
          3477.513,
          3373.8179999999998,
          3266.725,
          3156.1420000000003,
          3041.985,
          2924.17,
          2802.623,
          2677.2709999999997,
          2548.058,
          2414.933,
          2277.867,
          2136.845,
          1991.876,
          1842.999,
          1690.2779999999998,
          1533.82,
          1373.7679999999998,
          1210.313,
          1043.695,
          874.209,
          702.203,
          528.081,
          352.30300000000005,
          175.378,
          -2.1430000000000002,
          -179.672,
          -356.599,
          -532.304,
          -706.17,
          -877.6010000000001,
          -1046.031,
          -1210.937,
          -1371.8529999999998,
          -1528.372,
          -1680.152,
          -1826.9160000000002,
          -1968.455,
          -2104.6220000000003,
          -2235.321,
          -2360.514,
          -2480.205,
          -2594.437,
          -2703.2870000000003,
          -2806.8520000000003,
          -2905.256,
          -2998.636,
          -3087.1420000000003,
          -3170.928,
          -3250.156,
          -3324.992,
          -3395.598,
          -3462.137,
          -3524.77,
          -3583.652,
          -3638.938,
          -3690.772,
          -3739.383,
          -3784.655,
          -3826.9709999999995,
          -3866.3740000000003,
          -3902.982,
          -3936.913,
          -3968.2740000000003,
          -3997.172,
          -4023.7059999999997,
          -4047.969,
          -4070.055,
          -4090.048,
          -4108.03,
          -4124.08,
          -4138.273,
          -4150.678,
          -4161.362,
          -4170.392,
          -4177.8279999999995,
          -4183.729,
          -4188.149,
          -4191.141,
          -4192.758,
          -4193.0470000000005,
          -4192.055,
          -4189.825,
          -4186.399,
          -4181.819,
          -4176.123,
          -4169.348,
          -4161.529,
          -4152.7,
          -4142.893,
          -4132.14,
          -4120.471,
          -4107.915,
          -4094.498,
          -4080.248,
          -4065.1890000000003,
          -4049.347,
          -4032.745,
          -4015.4040000000005,
          -3997.348,
          -3978.598,
          -3959.172,
          -3939.092,
          -3918.375,
          -3897.04,
          -3875.105,
          -3852.585,
          -3829.4970000000003,
          -3805.857,
          -3781.6809999999996,
          -3756.9829999999997,
          -3731.778,
          -3706.078,
          -3679.897,
          -3653.2490000000003,
          -3626.145,
          -3598.598,
          -3570.619,
          -3542.22,
          -3513.4120000000003,
          -3484.205,
          -3454.61,
          -3424.637,
          -3394.296,
          -3363.595,
          -3332.545,
          -3301.1540000000005,
          -3269.4309999999996,
          -3237.385,
          -3205.0229999999997,
          -3172.3540000000003,
          -3139.385,
          -3106.1240000000003,
          -3072.579,
          -3038.757,
          -3004.664,
          -2970.3070000000002,
          -2935.6940000000004,
          -2900.83,
          -2865.722,
          -2830.3759999999997,
          -2794.798,
          -2758.995,
          -2722.9709999999995,
          -2686.732,
          -2650.284,
          -2613.633,
          -2576.782,
          -2539.739,
          -2502.506,
          -2465.091,
          -2427.496,
          -2389.7270000000003,
          -2351.7889999999998,
          -2313.685,
          -2275.4210000000003,
          -2237,
          -2198.428,
          -2159.7070000000003,
          -2120.842,
          -2081.837,
          -2042.6960000000001,
          -2003.4229999999998,
          -1964.021,
          -1924.494,
          -1884.845,
          -1845.079,
          -1805.1979999999999,
          -1765.2060000000001,
          -1725.1070000000002,
          -1684.9029999999998,
          -1644.598,
          -1604.195,
          -1563.6970000000001,
          -1523.1070000000002,
          -1482.4289999999999,
          -1441.665,
          -1400.817,
          -1359.89,
          -1318.885,
          -1277.806,
          -1236.655,
          -1195.4360000000001,
          -1154.149,
          -1112.799,
          -1071.388,
          -1029.9180000000001,
          -988.3919999999999,
          -946.812,
          -905.181,
          -863.5010000000001,
          -821.775,
          -780.0039999999999,
          -738.192,
          -696.34,
          -654.451,
          -612.526,
          -570.569,
          -528.581,
          -486.564,
          -444.52099999999996,
          -402.454,
          -360.36400000000003,
          -318.254,
          -276.125,
          -233.981,
          -191.822,
          -149.651,
          -107.469,
          -65.279,
          -23.083000000000002,
          19.118,
          61.321999999999996,
          103.52600000000001,
          145.73,
          187.93099999999998,
          230.127,
          272.317,
          314.499,
          356.67,
          398.83,
          440.977,
          483.10900000000004,
          525.2230000000001,
          567.319,
          609.395,
          651.4490000000001,
          693.4789999999999,
          735.4839999999999,
          777.462,
          819.4110000000001,
          861.33,
          903.217,
          945.071,
          986.8889999999999,
          1028.671,
          1070.414,
          1112.118,
          1153.78,
          1195.399,
          1236.973,
          1278.501,
          1319.981,
          1361.412,
          1402.7920000000001,
          1444.119,
          1485.392,
          1526.61,
          1567.771,
          1608.8729999999998,
          1649.915,
          1690.894,
          1731.8110000000001,
          1772.6629999999998,
          1813.4479999999999,
          1854.1660000000002,
          1894.8139999999999,
          1935.391,
          1975.896,
          2016.3270000000002,
          2056.6820000000002,
          2096.959,
          2137.159,
          2177.278,
          2217.315,
          2257.269,
          2297.139,
          2336.9210000000003,
          2376.616,
          2416.222,
          2455.736,
          2495.158,
          2534.486,
          2573.718,
          2612.8520000000003,
          2651.888,
          2690.824,
          2729.657,
          2768.386,
          2807.011,
          2845.528,
          2883.937,
          2922.236,
          2960.423,
          2998.4959999999996,
          3036.455,
          3074.297,
          3112.02,
          3149.623,
          3187.105,
          3224.4629999999997,
          3261.697,
          3298.803,
          3335.781,
          3372.6290000000004,
          3409.344,
          3445.926,
          3482.373,
          3518.6809999999996,
          3554.8509999999997,
          3590.88,
          3626.7659999999996,
          3662.508,
          3698.103,
          3733.55,
          3768.8459999999995,
          3803.991,
          3838.9809999999998,
          3873.816,
          3908.493,
          3943.01,
          3977.365,
          4011.5559999999996,
          4045.5809999999997,
          4079.4390000000003,
          4113.127,
          4146.642,
          4179.984,
          4213.15,
          4246.137,
          4278.943,
          4311.567,
          4344.0070000000005,
          4376.259,
          4408.321,
          4440.192,
          4471.87,
          4503.35,
          4534.633,
          4565.714,
          4596.590999999999,
          4627.263,
          4657.727,
          4687.979,
          4718.019,
          4747.842000000001,
          4777.448,
          4806.832,
          4835.991,
          4864.925,
          4893.629,
          4922.102,
          4950.34,
          4978.34,
          5006.1,
          5033.616,
          5060.8859999999995,
          5087.906,
          5114.674,
          5141.187,
          5167.441,
          5193.433,
          5219.16,
          5244.619000000001,
          5269.806,
          5294.718000000001,
          5319.352,
          5343.704000000001,
          5367.77,
          5391.548000000001,
          5415.031999999999,
          5438.22,
          5461.108,
          5483.691999999999,
          5505.968000000001,
          5527.932,
          5549.58,
          5570.908,
          5591.911999999999,
          5612.588000000001,
          5632.931,
          5652.937,
          5672.601,
          5691.92,
          5710.887,
          5729.499,
          5747.751,
          5765.638000000001,
          5783.155,
          5800.295999999999,
          5817.057,
          5833.433000000001,
          5849.4169999999995,
          5865.005,
          5880.191,
          5894.969,
          5909.334,
          5923.279,
          5936.798000000001,
          5949.8859999999995,
          5962.535,
          5974.7390000000005,
          5986.493,
          5997.789000000001,
          6008.62,
          6018.98,
          6028.86,
          6038.254,
          6047.155,
          6055.554,
          6063.444,
          6070.816,
          6077.6630000000005,
          6083.976,
          6089.746999999999,
          6094.965999999999,
          6099.624,
          6103.713000000001,
          6107.223000000001,
          6110.144,
          6112.465999999999,
          6114.18,
          6115.274,
          6115.738,
          6115.561,
          6114.731,
          6113.238,
          6111.068,
          6108.21,
          6104.651,
          6100.378000000001,
          6095.379,
          6089.639,
          6083.145,
          6075.880999999999,
          6067.834,
          6058.986999999999,
          6049.326,
          6038.8330000000005,
          6027.493,
          6015.286999999999,
          6002.1990000000005,
          5988.21,
          5973.3009999999995,
          5957.453,
          5940.646,
          5922.859,
          5904.071,
          5884.26,
          5863.401,
          5841.474,
          5818.451999999999,
          5794.312,
          5769.026999999999,
          5742.569,
          5714.911999999999,
          5686.025,
          5655.88,
          5624.445,
          5591.689,
          5557.578,
          5522.078,
          5485.151999999999,
          5446.764,
          5406.876,
          5365.448,
          5322.438,
          5277.803000000001,
          5231.498,
          5183.477,
          5133.693,
          5082.095,
          5028.630999999999,
          4973.245,
          4915.885,
          4856.491,
          4795.002,
          4731.354,
          4665.485,
          4597.326,
          4526.806,
          4453.852,
          4378.392,
          4300.346,
          4219.633,
          4136.1720000000005,
          4049.8790000000004,
          3960.664,
          3868.4390000000003,
          3773.115,
          3674.5959999999995,
          3572.792,
          3467.6079999999997,
          3358.95,
          3246.7290000000003,
          3130.8520000000003,
          3011.235,
          2887.798,
          2760.468,
          2629.179,
          2493.883,
          2354.542,
          2211.139,
          2063.68,
          1912.195,
          1756.749,
          1597.442,
          1434.4160000000002,
          1267.857,
          1098.004,
          925.1510000000001,
          749.643,
          571.889,
          392.35,
          211.54,
          30.018,
          -151.621,
          -332.754,
          -512.747,
          -690.97,
          -866.806,
          -1039.675,
          -1209.035,
          -1374.4,
          -1535.345,
          -1691.5120000000002,
          -1842.608,
          -1988.411,
          -2128.756,
          -2263.544,
          -2392.725,
          -2516.2960000000003,
          -2634.296,
          -2746.796,
          -2853.8940000000002,
          -2955.711,
          -3052.384,
          -3144.062,
          -3230.9040000000005,
          -3313.073,
          -3390.735,
          -3464.0570000000002,
          -3533.205,
          -3598.34,
          -3659.6259999999997,
          -3717.215,
          -3771.258,
          -3821.903,
          -3869.2859999999996,
          -3913.546,
          -3954.81,
          -3993.199,
          -4028.835,
          -4061.829,
          -4092.2859999999996,
          -4120.312,
          -4146.003,
          -4169.452,
          -4190.746,
          -4209.971,
          -4227.207,
          -4242.531,
          -4256.013,
          -4267.725,
          -4277.732,
          -4286.098,
          -4292.8820000000005,
          -4298.141,
          -4301.929,
          -4304.3,
          -4305.303,
          -4304.985,
          -4303.393,
          -4300.568,
          -4296.552,
          -4291.3859999999995,
          -4285.107,
          -4277.753,
          -4269.357,
          -4259.9529999999995,
          -4249.573,
          -4238.248,
          -4226.0070000000005,
          -4212.878,
          -4198.89,
          -4184.069,
          -4168.438,
          -4152.023,
          -4134.846,
          -4116.931,
          -4098.298,
          -4078.968,
          -4058.9629999999997,
          -4038.2990000000004,
          -4016.9970000000003,
          -3995.074,
          -3972.5490000000004,
          -3949.437,
          -3925.7540000000004,
          -3901.5170000000003,
          -3876.741,
          -3851.4390000000003,
          -3825.6259999999997,
          -3799.317,
          -3772.5240000000003,
          -3745.259,
          -3717.5359999999996,
          -3689.367,
          -3660.762,
          -3631.7340000000004,
          -3602.2940000000003,
          -3572.4509999999996,
          -3542.217,
          -3511.6020000000003,
          -3480.614,
          -3449.265,
          -3417.562,
          -3385.5159999999996,
          -3353.134,
          -3320.425,
          -3287.397,
          -3254.059,
          -3220.4179999999997,
          -3186.4809999999998,
          -3152.257,
          -3117.752,
          -3082.974,
          -3047.929,
          -3012.623,
          -2977.0640000000003,
          -2941.258,
          -2905.211,
          -2868.929,
          -2832.4179999999997,
          -2795.683,
          -2758.7309999999998,
          -2721.567,
          -2684.196,
          -2646.623,
          -2608.854,
          -2570.894,
          -2532.7470000000003,
          -2494.419,
          -2455.9139999999998,
          -2417.236,
          -2378.391,
          -2339.382,
          -2300.214,
          -2260.8920000000003,
          -2221.419,
          -2181.799,
          -2142.0370000000003,
          -2102.136,
          -2062.101,
          -2021.935,
          -1981.641,
          -1941.223,
          -1900.6860000000001,
          -1860.0320000000002,
          -1819.264,
          -1778.3870000000002,
          -1737.4029999999998,
          -1696.316,
          -1655.129,
          -1613.845,
          -1572.4679999999998,
          -1530.999,
          -1489.443,
          -1447.8020000000001,
          -1406.079,
          -1364.277,
          -1322.399,
          -1280.448,
          -1238.425,
          -1196.335,
          -1154.1789999999999,
          -1111.961,
          -1069.682,
          -1027.346,
          -984.954,
          -942.51,
          -900.015,
          -857.4730000000001,
          -814.885,
          -772.2539999999999,
          -729.582,
          -686.872,
          -644.125,
          -601.345,
          -558.5319999999999,
          -515.69,
          -472.82,
          -429.92400000000004,
          -387.006,
          -344.066,
          -301.107,
          -258.131,
          -215.14,
          -172.136,
          -129.12,
          -86.096,
          -43.06399999999999,
          -0.027000000000000003,
          43.013000000000005,
          86.055,
          129.097,
          172.136,
          215.171,
          258.20099999999996,
          301.222,
          344.235,
          387.235,
          430.223,
          473.19599999999997,
          516.1519999999999,
          559.09,
          602.008,
          644.904,
          687.7769999999999,
          730.6239999999999,
          773.444,
          816.2360000000001,
          858.998,
          901.7280000000001,
          944.424,
          987.085,
          1029.7089999999998,
          1072.295,
          1114.8410000000001,
          1157.344,
          1199.805,
          1242.22,
          1284.589,
          1326.91,
          1369.181,
          1411.401,
          1453.568,
          1495.68,
          1537.736,
          1579.735,
          1621.674,
          1663.5520000000001,
          1705.368,
          1747.12,
          1788.806,
          1830.425,
          1871.976,
          1913.4560000000001,
          1954.864,
          1996.1989999999998,
          2037.4589999999998,
          2078.643,
          2119.748,
          2160.7729999999997,
          2201.717,
          2242.5789999999997,
          2283.356,
          2324.047,
          2364.65,
          2405.1639999999998,
          2445.587,
          2485.9179999999997,
          2526.155,
          2566.2960000000003,
          2606.341,
          2646.2859999999996,
          2686.131,
          2725.873,
          2765.513,
          2805.046,
          2844.473,
          2883.7909999999997,
          2922.9990000000003,
          2962.094,
          3001.077,
          3039.9429999999998,
          3078.6929999999998,
          3117.324,
          3155.835,
          3194.224,
          3232.488,
          3270.6279999999997,
          3308.64,
          3346.522,
          3384.2740000000003,
          3421.8940000000002,
          3459.3779999999997,
          3496.7270000000003,
          3533.937,
          3571.008,
          3607.937,
          3644.722,
          3681.362,
          3717.855,
          3754.198,
          3790.39,
          3826.429,
          3862.313,
          3898.04,
          3933.607,
          3969.014,
          4004.258,
          4039.337,
          4074.2490000000003,
          4108.991,
          4143.563,
          4177.960999999999,
          4212.183,
          4246.228,
          4280.093,
          4313.775,
          4347.274,
          4380.585999999999,
          4413.71,
          4446.642,
          4479.380999999999,
          4511.924,
          4544.269,
          4576.413,
          4608.355,
          4640.090999999999,
          4671.619000000001,
          4702.937,
          4734.042,
          4764.931,
          4795.603,
          4826.053,
          4856.28,
          4886.282,
          4916.053,
          4945.594,
          4974.9,
          5003.969,
          5032.7970000000005,
          5061.383,
          5089.722,
          5117.813,
          5145.651,
          5173.233,
          5200.558,
          5227.621,
          5254.418000000001,
          5280.948,
          5307.206999999999,
          5333.19,
          5358.895,
          5384.319,
          5409.456999999999,
          5434.306,
          5458.863,
          5483.1230000000005,
          5507.084,
          5530.74,
          5554.089,
          5577.126,
          5599.847,
          5622.249,
          5644.326,
          5666.075,
          5687.491999999999,
          5708.571,
          5729.309,
          5749.701,
          5769.743,
          5789.429,
          5808.755999999999,
          5827.717,
          5846.308000000001,
          5864.525,
          5882.361,
          5899.812,
          5916.871999999999,
          5933.535,
          5949.797,
          5965.651999999999,
          5981.093000000001,
          5996.1140000000005,
          6010.710999999999,
          6024.876,
          6038.603,
          6051.8859999999995,
          6064.718000000001,
          6077.092,
          6089.003000000001,
          6100.441999999999,
          6111.403,
          6121.879,
          6131.861,
          6141.342,
          6150.315,
          6158.771,
          6166.703,
          6174.101,
          6180.9580000000005,
          6187.264,
          6193.0109999999995,
          6198.19,
          6202.79,
          6206.803000000001,
          6210.218000000001,
          6213.026,
          6215.215999999999,
          6216.776999999999,
          6217.6990000000005,
          6217.97,
          6217.579000000001,
          6216.514,
          6214.763000000001,
          6212.314,
          6209.151999999999,
          6205.266,
          6200.642,
          6195.267,
          6189.125,
          6182.203,
          6174.485,
          6165.955,
          6156.598000000001,
          6146.397,
          6135.335,
          6123.394,
          6110.557,
          6096.805,
          6082.119000000001,
          6066.479,
          6049.865,
          6032.255,
          6013.629,
          5993.9619999999995,
          5973.234,
          5951.4169999999995,
          5928.49,
          5904.4259999999995,
          5879.1990000000005,
          5852.78,
          5825.143,
          5796.255999999999,
          5766.09,
          5734.6140000000005,
          5701.795,
          5667.599,
          5631.991,
          5594.935,
          5556.391,
          5516.323,
          5474.689,
          5431.448,
          5386.554,
          5339.963000000001,
          5291.626,
          5241.497,
          5189.523,
          5135.651,
          5079.827,
          5021.9929999999995,
          4962.09,
          4900.056,
          4835.8279999999995,
          4769.337,
          4700.518,
          4629.295999999999,
          4555.598,
          4479.348,
          4400.467000000001,
          4318.872,
          4234.478,
          4147.1990000000005,
          4056.946,
          3963.627,
          3867.15,
          3767.4179999999997,
          3664.3379999999997,
          3557.812,
          3447.743,
          3334.038,
          3216.6040000000003,
          3095.3520000000003,
          2970.197,
          2841.065,
          2707.885,
          2570.604,
          2429.1820000000002,
          2283.596,
          2133.848,
          1979.965,
          1822.007,
          1660.069,
          1494.29,
          1324.8529999999998,
          1151.994,
          976.003,
          797.227,
          616.075,
          433.009,
          248.546,
          63.253,
          -122.26700000000001,
          -307.382,
          -491.44599999999997,
          -673.813,
          -853.8510000000001,
          -1030.961,
          -1204.585,
          -1374.217,
          -1539.4170000000001,
          -1699.807,
          -1855.0810000000001,
          -2004.999,
          -2149.388,
          -2288.136,
          -2421.183,
          -2548.52,
          -2670.1809999999996,
          -2786.2309999999998,
          -2896.768,
          -3001.9109999999996,
          -3101.7940000000003,
          -3196.571,
          -3286.3979999999997,
          -3371.441,
          -3451.869,
          -3527.85,
          -3599.553,
          -3667.145,
          -3730.7870000000003,
          -3790.639,
          -3846.8540000000003,
          -3899.5809999999997,
          -3948.962,
          -3995.137,
          -4038.236,
          -4078.385,
          -4115.705,
          -4150.313,
          -4182.316,
          -4211.821,
          -4238.928,
          -4263.73,
          -4286.319,
          -4306.782999999999,
          -4325.202,
          -4341.655,
          -4356.217000000001,
          -4368.957,
          -4379.946,
          -4389.246,
          -4396.920999999999,
          -4403.027,
          -4407.621,
          -4410.7570000000005,
          -4412.486,
          -4412.857,
          -4411.916,
          -4409.707,
          -4406.273,
          -4401.655,
          -4395.893,
          -4389.023,
          -4381.081,
          -4372.102,
          -4362.1179999999995,
          -4351.161,
          -4339.2609999999995,
          -4326.447,
          -4312.748,
          -4298.19,
          -4282.799,
          -4266.599,
          -4249.616,
          -4231.871,
          -4213.387,
          -4194.185,
          -4174.286,
          -4153.709,
          -4132.474,
          -4110.599,
          -4088.1020000000003,
          -4065,
          -4041.31,
          -4017.048,
          -3992.23,
          -3966.869,
          -3940.982,
          -3914.5820000000003,
          -3887.6820000000002,
          -3860.297,
          -3832.437,
          -3804.117,
          -3775.347,
          -3746.1409999999996,
          -3716.508,
          -3686.4590000000003,
          -3656.006,
          -3625.159,
          -3593.927,
          -3562.322,
          -3530.3509999999997,
          -3498.0240000000003,
          -3465.3509999999997,
          -3432.3390000000004,
          -3398.9970000000003,
          -3365.3340000000003,
          -3331.3579999999997,
          -3297.0759999999996,
          -3262.4959999999996,
          -3227.625,
          -3192.4709999999995,
          -3157.04,
          -3121.34,
          -3085.377,
          -3049.157,
          -3012.688,
          -2975.975,
          -2939.0240000000003,
          -2901.842,
          -2864.434,
          -2826.805,
          -2788.962,
          -2750.909,
          -2712.652,
          -2674.196,
          -2635.547,
          -2596.708,
          -2557.686,
          -2518.484,
          -2479.107,
          -2439.56,
          -2399.848,
          -2359.974,
          -2319.944,
          -2279.76,
          -2239.428,
          -2198.951,
          -2158.333,
          -2117.578,
          -2076.69,
          -2035.6729999999998,
          -1994.53,
          -1953.264,
          -1911.88,
          -1870.381,
          -1828.771,
          -1787.0510000000002,
          -1745.227,
          -1703.3010000000002,
          -1661.276,
          -1619.156,
          -1576.943,
          -1534.64,
          -1492.251,
          -1449.779,
          -1407.226,
          -1364.595,
          -1321.889,
          -1279.111,
          -1236.263,
          -1193.349,
          -1150.37,
          -1107.329,
          -1064.23,
          -1021.074,
          -977.8639999999999,
          -934.6030000000001,
          -891.2919999999999,
          -847.935,
          -804.533,
          -761.09,
          -717.6060000000001,
          -674.086,
          -630.53,
          -586.941,
          -543.322,
          -499.67400000000004,
          -456,
          -412.301,
          -368.58099999999996,
          -324.84,
          -281.082,
          -237.308,
          -193.52,
          -149.72,
          -105.91,
          -62.092,
          -18.268,
          25.559,
          69.389,
          113.219,
          157.047,
          200.87099999999998,
          244.69,
          288.502,
          332.305,
          376.096,
          419.875,
          463.639,
          507.38699999999994,
          551.117,
          594.827,
          638.515,
          682.18,
          725.82,
          769.433,
          813.0169999999999,
          856.572,
          900.0939999999999,
          943.5830000000001,
          987.0360000000001,
          1030.453,
          1073.83,
          1117.1680000000001,
          1160.463,
          1203.715,
          1246.922,
          1290.0819999999999,
          1333.193,
          1376.255,
          1419.264,
          1462.22,
          1505.121,
          1547.9660000000001,
          1590.7520000000002,
          1633.4779999999998,
          1676.1429999999998,
          1718.745,
          1761.2820000000002,
          1803.753,
          1846.156,
          1888.49,
          1930.7520000000002,
          1972.942,
          2015.058,
          2057.097,
          2099.06,
          2140.9429999999998,
          2182.745,
          2224.465,
          2266.101,
          2307.651,
          2349.115,
          2390.489,
          2431.7729999999997,
          2472.965,
          2514.064,
          2555.067,
          2595.973,
          2636.78,
          2677.487,
          2718.093,
          2758.594,
          2798.991,
          2839.28,
          2879.461,
          2919.531,
          2959.49,
          2999.335,
          3039.0640000000003,
          3078.676,
          3118.17,
          3157.542,
          3196.792,
          3235.9190000000003,
          3274.9190000000003,
          3313.7909999999997,
          3352.534,
          3391.1459999999997,
          3429.625,
          3467.969,
          3506.176,
          3544.244,
          3582.173,
          3619.958,
          3657.6,
          3695.095,
          3732.442,
          3769.64,
          3806.685,
          3843.577,
          3880.312,
          3916.89,
          3953.3070000000002,
          3989.563,
          4025.655,
          4061.5809999999997,
          4097.338,
          4132.9259999999995,
          4168.340999999999,
          4203.581,
          4238.645,
          4273.53,
          4308.233,
          4342.753,
          4377.088,
          4411.235,
          4445.192,
          4478.956,
          4512.525,
          4545.897,
          4579.069,
          4612.039000000001,
          4644.804,
          4677.363,
          4709.712,
          4741.848,
          4773.77,
          4805.474,
          4836.959,
          4868.22,
          4899.2570000000005,
          4930.065,
          4960.642,
          4990.985,
          5021.090999999999,
          5050.958,
          5080.583,
          5109.962,
          5139.093,
          5167.972,
          5196.597,
          5224.964,
          5253.07,
          5280.911,
          5308.485,
          5335.789000000001,
          5362.818,
          5389.569,
          5416.039000000001,
          5442.225,
          5468.121999999999,
          5493.727,
          5519.036999999999,
          5544.047,
          5568.753000000001,
          5593.153,
          5617.241999999999,
          5641.015,
          5664.469,
          5687.6,
          5710.403,
          5732.874,
          5755.009,
          5776.803000000001,
          5798.251,
          5819.35,
          5840.095,
          5860.48,
          5880.5,
          5900.151999999999,
          5919.429,
          5938.326999999999,
          5956.84,
          5974.963000000001,
          5992.691,
          6010.017,
          6026.937,
          6043.445,
          6059.534000000001,
          6075.1990000000005,
          6090.433000000001,
          6105.231,
          6119.585,
          6133.49,
          6146.939,
          6159.924,
          6172.439,
          6184.477,
          6196.031,
          6207.093000000001,
          6217.655,
          6227.710999999999,
          6237.251,
          6246.268,
          6254.754,
          6262.7,
          6270.097,
          6276.936,
          6283.209,
          6288.906,
          6294.018,
          6298.533,
          6302.444,
          6305.7390000000005,
          6308.408,
          6310.44,
          6311.825,
          6312.549,
          6312.603,
          6311.974,
          6310.649,
          6308.616,
          6305.861999999999,
          6302.374,
          6298.137,
          6293.139,
          6287.3640000000005,
          6280.797,
          6273.424,
          6265.228,
          6256.193,
          6246.302,
          6235.5380000000005,
          6223.884,
          6211.32,
          6197.829000000001,
          6183.39,
          6167.984,
          6151.59,
          6134.187,
          6115.7519999999995,
          6096.263000000001,
          6075.695,
          6054.025,
          6031.228,
          6007.278,
          5982.147,
          5955.808000000001,
          5928.232,
          5899.389,
          5869.2480000000005,
          5837.778,
          5804.945,
          5770.715,
          5735.0509999999995,
          5697.918000000001,
          5659.276,
          5619.085999999999,
          5577.308000000001,
          5533.897,
          5488.809,
          5441.9980000000005,
          5393.416,
          5343.013000000001,
          5290.738,
          5236.536,
          5180.351,
          5122.125,
          5061.799,
          4999.309,
          4934.588,
          4867.572,
          4798.189,
          4726.366,
          4652.026,
          4575.094,
          4495.488,
          4413.123,
          4327.915,
          4239.773,
          4148.607,
          4054.324,
          3956.828,
          3856.022,
          3751.808,
          3644.087,
          3532.76,
          3417.7309999999998,
          3298.901,
          3176.1809999999996,
          3049.482,
          2918.725,
          2783.837,
          2644.761,
          2501.451,
          2353.883,
          2202.051,
          2045.981,
          1885.725,
          1721.378,
          1553.0720000000001,
          1380.985,
          1205.354,
          1026.462,
          844.658,
          660.3480000000001,
          473.996,
          286.122,
          97.29700000000001,
          -91.866,
          -280.72900000000004,
          -468.631,
          -654.9159999999999,
          -838.937,
          -1020.077,
          -1197.759,
          -1371.464,
          -1540.729,
          -1705.164,
          -1864.444,
          -2018.317,
          -2166.596,
          -2309.157,
          -2445.9339999999997,
          -2576.909,
          -2702.1090000000004,
          -2821.5959999999995,
          -2935.4640000000004,
          -3043.83,
          -3146.8320000000003,
          -3244.617,
          -3337.348,
          -3425.188,
          -3508.31,
          -3586.883,
          -3661.08,
          -3731.0690000000004,
          -3797.014,
          -3859.079,
          -3917.42,
          -3972.2540000000004,
          -4023.527,
          -4071.5809999999997,
          -4116.483,
          -4158.362,
          -4197.342000000001,
          -4233.539000000001,
          -4267.067,
          -4298.032999999999,
          -4326.539000000001,
          -4352.682,
          -4376.556,
          -4398.248,
          -4417.843,
          -4435.42,
          -4451.057,
          -4464.825,
          -4476.795999999999,
          -4487.034000000001,
          -4495.602,
          -4502.562,
          -4507.968,
          -4511.878,
          -4514.343,
          -4515.413,
          -4515.1359999999995,
          -4513.558,
          -4510.721,
          -4506.669,
          -4501.439,
          -4495.072,
          -4487.604,
          -4479.071,
          -4469.504,
          -4458.938,
          -4447.403,
          -4434.929,
          -4421.544,
          -4407.276,
          -4392.151,
          -4376.196,
          -4359.434,
          -4341.89,
          -4323.585,
          -4304.542,
          -4284.781,
          -4264.3240000000005,
          -4243.189,
          -4221.395,
          -4198.962,
          -4175.906,
          -4152.244000000001,
          -4127.994000000001,
          -4103.17,
          -4077.789,
          -4051.864,
          -4025.4120000000003,
          -3998.445,
          -3970.9770000000003,
          -3943.022,
          -3914.591,
          -3885.697,
          -3856.353,
          -3826.5690000000004,
          -3796.357,
          -3765.728,
          -3734.6929999999998,
          -3703.261,
          -3671.442,
          -3639.2470000000003,
          -3606.685,
          -3573.765,
          -3540.4959999999996,
          -3506.886,
          -3472.9440000000004,
          -3438.678,
          -3404.097,
          -3369.2070000000003,
          -3334.0170000000003,
          -3298.534,
          -3262.7659999999996,
          -3226.719,
          -3190.4,
          -3153.815,
          -3116.973,
          -3079.8779999999997,
          -3042.5370000000003,
          -3004.9559999999997,
          -2967.1409999999996,
          -2929.097,
          -2890.8320000000003,
          -2852.349,
          -2813.655,
          -2774.7540000000004,
          -2735.653,
          -2696.355,
          -2656.866,
          -2617.192,
          -2577.335,
          -2537.302,
          -2497.097,
          -2456.724,
          -2416.188,
          -2375.492,
          -2334.6420000000003,
          -2293.641,
          -2252.493,
          -2211.202,
          -2169.7729999999997,
          -2128.209,
          -2086.513,
          -2044.69,
          -2002.743,
          -1960.675,
          -1918.491,
          -1876.193,
          -1833.785,
          -1791.27,
          -1748.652,
          -1705.933,
          -1663.118,
          -1620.2079999999999,
          -1577.207,
          -1534.118,
          -1490.945,
          -1447.6889999999999,
          -1404.354,
          -1360.942,
          -1317.457,
          -1273.901,
          -1230.276,
          -1186.587,
          -1142.8339999999998,
          -1099.021,
          -1055.15,
          -1011.225,
          -967.2460000000001,
          -923.217,
          -879.1410000000001,
          -835.0189999999999,
          -790.8539999999999,
          -746.648,
          -702.404,
          -658.1239999999999,
          -613.81,
          -569.464,
          -525.089,
          -480.68699999999995,
          -436.26,
          -391.81,
          -347.339,
          -302.85,
          -258.344,
          -213.82299999999998,
          -169.29,
          -124.74700000000001,
          -80.195,
          -35.635999999999996,
          8.927,
          53.492,
          98.059,
          142.624,
          187.185,
          231.74200000000002,
          276.29200000000003,
          320.83299999999997,
          365.36300000000006,
          409.881,
          454.384,
          498.87199999999996,
          543.341,
          587.7909999999999,
          632.219,
          676.6239999999999,
          721.0039999999999,
          765.357,
          809.682,
          853.977,
          898.2389999999999,
          942.4680000000001,
          986.6619999999999,
          1030.818,
          1074.9360000000001,
          1119.013,
          1163.048,
          1207.039,
          1250.985,
          1294.883,
          1338.733,
          1382.5320000000002,
          1426.279,
          1469.9720000000002,
          1513.61,
          1557.191,
          1600.713,
          1644.174,
          1687.5739999999998,
          1730.91,
          1774.18,
          1817.384,
          1860.519,
          1903.5839999999998,
          1946.5770000000002,
          1989.497,
          2032.3410000000001,
          2075.109,
          2117.798,
          2160.407,
          2202.935,
          2245.379,
          2287.739,
          2330.011,
          2372.196,
          2414.29,
          2456.2929999999997,
          2498.203,
          2540.018,
          2581.736,
          2623.3559999999998,
          2664.8759999999997,
          2706.295,
          2747.61,
          2788.82,
          2829.923,
          2870.9179999999997,
          2911.803,
          2952.575,
          2993.235,
          3033.778,
          3074.205,
          3114.513,
          3154.7,
          3194.765,
          3234.705,
          3274.5190000000002,
          3314.2059999999997,
          3353.763,
          3393.188,
          3432.48,
          3471.637,
          3510.657,
          3549.538,
          3588.278,
          3626.875,
          3665.328,
          3703.634,
          3741.7909999999997,
          3779.798,
          3817.652,
          3855.3520000000003,
          3892.895,
          3930.28,
          3967.5040000000004,
          4004.566,
          4041.4629999999997,
          4078.192,
          4114.753,
          4151.143,
          4187.36,
          4223.401,
          4259.264,
          4294.947,
          4330.448,
          4365.765,
          4400.895,
          4435.835999999999,
          4470.585999999999,
          4505.142,
          4539.502,
          4573.663,
          4607.624,
          4641.38,
          4674.931,
          4708.274,
          4741.405,
          4774.323,
          4807.024,
          4839.505999999999,
          4871.767,
          4903.803,
          4935.613,
          4967.192,
          4998.538,
          5029.649,
          5060.522,
          5091.153,
          5121.54,
          5151.679,
          5181.567,
          5211.202,
          5240.581,
          5269.6990000000005,
          5298.554,
          5327.142,
          5355.460999999999,
          5383.507,
          5411.276,
          5438.764,
          5465.969,
          5492.887,
          5519.514,
          5545.846,
          5571.88,
          5597.611,
          5623.036999999999,
          5648.151999999999,
          5672.954000000001,
          5697.437,
          5721.598000000001,
          5745.433000000001,
          5768.937,
          5792.105,
          5814.934,
          5837.419,
          5859.555,
          5881.338000000001,
          5902.763000000001,
          5923.8240000000005,
          5944.518,
          5964.839,
          5984.781,
          6004.340999999999,
          6023.5109999999995,
          6042.2880000000005,
          6060.665,
          6078.6359999999995,
          6096.196999999999,
          6113.340999999999,
          6130.063,
          6146.355,
          6162.2119999999995,
          6177.628000000001,
          6192.595,
          6207.108,
          6221.16,
          6234.744000000001,
          6247.853,
          6260.479,
          6272.615,
          6284.254,
          6295.388000000001,
          6306.01,
          6316.11,
          6325.681,
          6334.715,
          6343.203,
          6351.1359999999995,
          6358.505,
          6365.3,
          6371.513000000001,
          6377.134,
          6382.151999999999,
          6386.558000000001,
          6390.342,
          6393.491999999999,
          6395.996999999999,
          6397.847,
          6399.029,
          6399.533,
          6399.345,
          6398.454000000001,
          6396.846,
          6394.508000000001,
          6391.427,
          6387.589,
          6382.979,
          6377.5830000000005,
          6371.3859999999995,
          6364.3730000000005,
          6356.526,
          6347.831,
          6338.269,
          6327.823,
          6316.476,
          6304.2080000000005,
          6291.001,
          6276.834,
          6261.687,
          6245.54,
          6228.371999999999,
          6210.158,
          6190.8769999999995,
          6170.504,
          6149.014,
          6126.383000000001,
          6102.5830000000005,
          6077.588000000001,
          6051.368,
          6023.896,
          5995.141,
          5965.071,
          5933.653,
          5900.855,
          5866.642,
          5830.975,
          5793.82,
          5755.137,
          5714.885,
          5673.022,
          5629.505999999999,
          5584.289000000001,
          5537.326,
          5488.569,
          5437.965999999999,
          5385.464,
          5331.01,
          5274.544,
          5216.0109999999995,
          5155.347,
          5092.4890000000005,
          5027.371,
          4959.923,
          4890.075,
          4817.752,
          4742.877,
          4665.371,
          4585.153,
          4502.1359999999995,
          4416.232,
          4327.351,
          4235.402,
          4140.286,
          4041.909,
          3940.17,
          3834.969,
          3726.204,
          3613.776,
          3497.5809999999997,
          3377.5240000000003,
          3253.507,
          3125.441,
          2993.242,
          2856.835,
          2716.157,
          2571.161,
          2421.814,
          2268.111,
          2110.069,
          1947.74,
          1781.21,
          1610.609,
          1436.112,
          1257.947,
          1076.401,
          891.816,
          704.5980000000001,
          515.211,
          324.178,
          132.07399999999998,
          -60.485,
          -252.84900000000002,
          -444.35,
          -634.317,
          -822.0889999999999,
          -1007.035,
          -1188.5610000000001,
          -1366.129,
          -1539.2620000000002,
          -1707.55,
          -1870.656,
          -2028.3110000000001,
          -2180.317,
          -2326.5370000000003,
          -2466.897,
          -2601.3720000000003,
          -2729.98,
          -2852.783,
          -2969.869,
          -3081.353,
          -3187.369,
          -3288.0690000000004,
          -3383.612,
          -3474.167,
          -3559.903,
          -3640.9959999999996,
          -3717.618,
          -3789.94,
          -3858.131,
          -3922.3540000000003,
          -3982.7690000000002,
          -4039.53,
          -4092.7859999999996,
          -4142.68,
          -4189.348,
          -4232.924,
          -4273.532,
          -4311.294,
          -4346.321,
          -4378.727,
          -4408.6140000000005,
          -4436.082,
          -4461.224,
          -4484.134,
          -4504.895,
          -4523.59,
          -4540.2970000000005,
          -4555.09,
          -4568.04,
          -4579.215999999999,
          -4588.681,
          -4596.497,
          -4602.722,
          -4607.412,
          -4610.622,
          -4612.402,
          -4612.8,
          -4611.865,
          -4609.639,
          -4606.167,
          -4601.488,
          -4595.642,
          -4588.667,
          -4580.599,
          -4571.472,
          -4561.318,
          -4550.170999999999,
          -4538.061,
          -4525.016,
          -4511.065,
          -4496.234,
          -4480.55,
          -4464.04,
          -4446.725,
          -4428.63,
          -4409.776,
          -4390.186,
          -4369.880999999999,
          -4348.879,
          -4327.202,
          -4304.866,
          -4281.892,
          -4258.295,
          -4234.092000000001,
          -4209.3009999999995,
          -4183.936,
          -4158.014,
          -4131.548,
          -4104.553,
          -4077.0440000000003,
          -4049.033,
          -4020.533,
          -3991.5570000000002,
          -3962.117,
          -3932.225,
          -3901.893,
          -3871.131,
          -3839.95,
          -3808.362,
          -3776.3759999999997,
          -3744.0029999999997,
          -3711.25,
          -3678.1290000000004,
          -3644.6479999999997,
          -3610.817,
          -3576.643,
          -3542.135,
          -3507.302,
          -3472.152,
          -3436.691,
          -3400.929,
          -3364.8709999999996,
          -3328.526,
          -3291.901,
          -3255.0009999999997,
          -3217.835,
          -3180.408,
          -3142.7259999999997,
          -3104.797,
          -3066.6259999999997,
          -3028.22,
          -2989.583,
          -2950.722,
          -2911.6420000000003,
          -2872.349,
          -2832.847,
          -2793.143,
          -2753.24,
          -2713.145,
          -2672.862,
          -2632.395,
          -2591.75,
          -2550.931,
          -2509.9429999999998,
          -2468.7889999999998,
          -2427.475,
          -2386.004,
          -2344.38,
          -2302.6079999999997,
          -2260.692,
          -2218.635,
          -2176.442,
          -2134.116,
          -2091.66,
          -2049.0789999999997,
          -2006.3770000000002,
          -1963.555,
          -1920.619,
          -1877.5710000000001,
          -1834.415,
          -1791.154,
          -1747.7910000000002,
          -1704.33,
          -1660.773,
          -1617.124,
          -1573.385,
          -1529.56,
          -1485.652,
          -1441.6629999999998,
          -1397.5970000000002,
          -1353.455,
          -1309.242,
          -1264.9589999999998,
          -1220.61,
          -1176.197,
          -1131.722,
          -1087.188,
          -1042.598,
          -997.955,
          -953.26,
          -908.5160000000001,
          -863.7260000000001,
          -818.8919999999999,
          -774.0169999999999,
          -729.102,
          -684.15,
          -639.164,
          -594.145,
          -549.096,
          -504.019,
          -458.916,
          -413.79,
          -368.642,
          -323.475,
          -278.291,
          -233.09099999999998,
          -187.87900000000002,
          -142.655,
          -97.42299999999999,
          -52.183,
          -6.939,
          38.309,
          83.55799999999999,
          128.806,
          174.051,
          219.291,
          264.525,
          309.75,
          354.965,
          400.168,
          445.356,
          490.529,
          535.684,
          580.819,
          625.933,
          671.0239999999999,
          716.09,
          761.1289999999999,
          806.14,
          851.1210000000001,
          896.069,
          940.9839999999999,
          985.863,
          1030.705,
          1075.509,
          1120.271,
          1164.992,
          1209.6680000000001,
          1254.298,
          1298.881,
          1343.415,
          1387.898,
          1432.329,
          1476.705,
          1521.025,
          1565.2879999999998,
          1609.4920000000002,
          1653.635,
          1697.715,
          1741.731,
          1785.681,
          1829.5639999999999,
          1873.3770000000002,
          1917.12,
          1960.79,
          2004.385,
          2047.905,
          2091.348,
          2134.7110000000002,
          2177.993,
          2221.192,
          2264.308,
          2307.337,
          2350.279,
          2393.132,
          2435.894,
          2478.563,
          2521.137,
          2563.616,
          2605.9970000000003,
          2648.278,
          2690.458,
          2732.535,
          2774.508,
          2816.3740000000003,
          2858.132,
          2899.78,
          2941.317,
          2982.74,
          3024.048,
          3065.239,
          3106.312,
          3147.264,
          3188.093,
          3228.7990000000004,
          3269.3779999999997,
          3309.83,
          3350.151,
          3390.342,
          3430.3990000000003,
          3470.32,
          3510.105,
          3549.75,
          3589.255,
          3628.616,
          3667.8320000000003,
          3706.902,
          3745.823,
          3784.593,
          3823.21,
          3861.672,
          3899.9770000000003,
          3938.123,
          3976.1079999999997,
          4013.93,
          4051.586,
          4089.075,
          4126.395,
          4163.543,
          4200.517,
          4237.315,
          4273.934,
          4310.373,
          4346.629,
          4382.7,
          4418.583,
          4454.276,
          4489.777,
          4525.083,
          4560.192,
          4595.102,
          4629.81,
          4664.313,
          4698.609,
          4732.695,
          4766.569,
          4800.228,
          4833.67,
          4866.891,
          4899.889,
          4932.662,
          4965.206,
          4997.519,
          5029.598,
          5061.439,
          5093.041,
          5124.399,
          5155.512,
          5186.375,
          5216.986,
          5247.342,
          5277.439,
          5307.275,
          5336.845,
          5366.147,
          5395.177,
          5423.932,
          5452.408,
          5480.602,
          5508.5109999999995,
          5536.13,
          5563.455,
          5590.484,
          5617.2119999999995,
          5643.6359999999995,
          5669.751,
          5695.554,
          5721.04,
          5746.205,
          5771.045,
          5795.557,
          5819.734,
          5843.5740000000005,
          5867.071999999999,
          5890.222,
          5913.02,
          5935.4619999999995,
          5957.543000000001,
          5979.258000000001,
          6000.601,
          6021.569,
          6042.155,
          6062.355,
          6082.161999999999,
          6101.571999999999,
          6120.578,
          6139.1759999999995,
          6157.359,
          6175.121,
          6192.456999999999,
          6209.36,
          6225.8240000000005,
          6241.842,
          6257.408,
          6272.515,
          6287.156999999999,
          6301.326,
          6315.015,
          6328.217,
          6340.925,
          6353.130999999999,
          6364.826999999999,
          6376.005,
          6386.656,
          6396.774,
          6406.349,
          6415.371999999999,
          6423.835,
          6431.728,
          6439.0419999999995,
          6445.768,
          6451.896,
          6457.415,
          6462.316,
          6466.588000000001,
          6470.219,
          6473.2,
          6475.518,
          6477.161999999999,
          6478.119000000001,
          6478.379,
          6477.927,
          6476.751,
          6474.838000000001,
          6472.174,
          6468.744000000001,
          6464.535,
          6459.531,
          6453.718000000001,
          6447.079000000001,
          6439.597,
          6431.258000000001,
          6422.043000000001,
          6411.934,
          6400.914000000001,
          6388.964,
          6376.063,
          6362.193,
          6347.3330000000005,
          6331.460999999999,
          6314.555,
          6296.593000000001,
          6277.5509999999995,
          6257.405,
          6236.13,
          6213.6990000000005,
          6190.088000000001,
          6165.267,
          6139.209,
          6111.884,
          6083.26,
          6053.306,
          6021.99,
          5989.276999999999,
          5955.132,
          5919.518,
          5882.396,
          5843.729,
          5803.474,
          5761.59,
          5718.031999999999,
          5672.755,
          5625.710999999999,
          5576.849,
          5526.12,
          5473.469,
          5418.842,
          5362.18,
          5303.424,
          5242.5109999999995,
          5179.377,
          5113.955,
          5046.173,
          4975.960999999999,
          4903.244000000001,
          4827.942,
          4749.975,
          4669.259,
          4585.709,
          4499.234,
          4409.7429999999995,
          4317.141,
          4221.331,
          4122.213,
          4019.687,
          3913.65,
          3803.998,
          3690.627,
          3573.435,
          3452.321,
          3327.1859999999997,
          3197.935,
          3064.4829999999997,
          2926.752,
          2784.673,
          2638.195,
          2487.284,
          2331.928,
          2172.14,
          2007.9660000000001,
          1839.49,
          1666.8339999999998,
          1490.171,
          1309.726,
          1125.778,
          938.668,
          748.8,
          556.639,
          362.708,
          167.584,
          -28.112,
          -223.72299999999998,
          -418.57099999999997,
          -611.975,
          -803.26,
          -991.778,
          -1176.923,
          -1358.139,
          -1534.932,
          -1706.875,
          -1873.6170000000002,
          -2034.875,
          -2190.435,
          -2340.154,
          -2483.944,
          -2621.7740000000003,
          -2753.656,
          -2879.6440000000002,
          -2999.8259999999996,
          -3114.312,
          -3223.238,
          -3326.752,
          -3425.014,
          -3518.1929999999998,
          -3606.4629999999997,
          -3689.9970000000003,
          -3768.973,
          -3843.5609999999997,
          -3913.934,
          -3980.256,
          -4042.692,
          -4101.397,
          -4156.522,
          -4208.212,
          -4256.609,
          -4301.846,
          -4344.05,
          -4383.345,
          -4419.847,
          -4453.668,
          -4484.914000000001,
          -4513.688,
          -4540.085,
          -4564.198,
          -4586.113,
          -4605.916,
          -4623.686,
          -4639.499,
          -4653.427,
          -4665.539000000001,
          -4675.901,
          -4684.576,
          -4691.623,
          -4697.1,
          -4701.062,
          -4703.56,
          -4704.645,
          -4704.365,
          -4702.764,
          -4699.8859999999995,
          -4695.774,
          -4690.467000000001,
          -4684.003,
          -4676.419,
          -4667.751,
          -4658.032999999999,
          -4647.2970000000005,
          -4635.5740000000005,
          -4622.893,
          -4609.285,
          -4594.776,
          -4579.392,
          -4563.161,
          -4546.106,
          -4528.251,
          -4509.6179999999995,
          -4490.231,
          -4470.11,
          -4449.276,
          -4427.748,
          -4405.545,
          -4382.687,
          -4359.191,
          -4335.0740000000005,
          -4310.353,
          -4285.044,
          -4259.162,
          -4232.723,
          -4205.741,
          -4178.23,
          -4150.204000000001,
          -4121.677,
          -4092.6609999999996,
          -4063.1679999999997,
          -4033.211,
          -4002.802,
          -3971.9509999999996,
          -3940.671,
          -3908.9709999999995,
          -3876.862,
          -3844.355,
          -3811.4590000000003,
          -3778.183,
          -3744.538,
          -3710.532,
          -3676.1740000000004,
          -3641.473,
          -3606.4359999999997,
          -3571.073,
          -3535.3909999999996,
          -3499.3979999999997,
          -3463.1020000000003,
          -3426.509,
          -3389.627,
          -3352.4629999999997,
          -3315.0240000000003,
          -3277.316,
          -3239.3459999999995,
          -3201.1209999999996,
          -3162.6459999999997,
          -3123.929,
          -3084.973,
          -3045.7870000000003,
          -3006.3740000000003,
          -2966.741,
          -2926.893,
          -2886.835,
          -2846.573,
          -2806.112,
          -2765.4559999999997,
          -2724.61,
          -2683.58,
          -2642.37,
          -2600.984,
          -2559.427,
          -2517.7039999999997,
          -2475.819,
          -2433.775,
          -2391.578,
          -2349.23,
          -2306.737,
          -2264.1020000000003,
          -2221.3289999999997,
          -2178.422,
          -2135.384,
          -2092.219,
          -2048.931,
          -2005.524,
          -1962,
          -1918.3629999999998,
          -1874.616,
          -1830.764,
          -1786.808,
          -1742.753,
          -1698.601,
          -1654.355,
          -1610.019,
          -1565.595,
          -1521.0870000000002,
          -1476.4979999999998,
          -1431.829,
          -1387.085,
          -1342.267,
          -1297.379,
          -1252.423,
          -1207.403,
          -1162.32,
          -1117.177,
          -1071.9769999999999,
          -1026.722,
          -981.415,
          -936.059,
          -890.655,
          -845.207,
          -799.716,
          -754.185,
          -708.6160000000001,
          -663.012,
          -617.375,
          -571.707,
          -526.01,
          -480.287,
          -434.54,
          -388.77,
          -342.981,
          -297.17400000000004,
          -251.351,
          -205.514,
          -159.666,
          -113.80799999999999,
          -67.943,
          -22.073,
          23.801,
          69.676,
          115.551,
          161.424,
          207.292,
          253.15400000000002,
          299.007,
          344.851,
          390.68199999999996,
          436.5,
          482.30199999999996,
          528.086,
          573.851,
          619.595,
          665.316,
          711.0110000000001,
          756.68,
          802.321,
          847.932,
          893.51,
          939.055,
          984.564,
          1030.035,
          1075.468,
          1120.86,
          1166.2089999999998,
          1211.515,
          1256.774,
          1301.985,
          1347.1470000000002,
          1392.2579999999998,
          1437.316,
          1482.32,
          1527.267,
          1572.156,
          1616.986,
          1661.755,
          1706.46,
          1751.1,
          1795.675,
          1840.181,
          1884.6170000000002,
          1928.981,
          1973.273,
          2017.49,
          2061.63,
          2105.6910000000003,
          2149.673,
          2193.573,
          2237.39,
          2281.121,
          2324.766,
          2368.322,
          2411.788,
          2455.163,
          2498.4429999999998,
          2541.6279999999997,
          2584.716,
          2627.705,
          2670.594,
          2713.38,
          2756.062,
          2798.638,
          2841.1059999999998,
          2883.466,
          2925.7140000000004,
          2967.848,
          3009.869,
          3051.772,
          3093.5570000000002,
          3135.222,
          3176.765,
          3218.184,
          3259.478,
          3300.643,
          3341.679,
          3382.5840000000003,
          3423.3559999999998,
          3463.992,
          3504.491,
          3544.8509999999997,
          3585.07,
          3625.1459999999997,
          3665.078,
          3704.862,
          3744.4970000000003,
          3783.982,
          3823.313,
          3862.489,
          3901.509,
          3940.369,
          3979.067,
          4017.6020000000003,
          4055.972,
          4094.1740000000004,
          4132.206,
          4170.065,
          4207.751,
          4245.259,
          4282.589,
          4319.738,
          4356.704000000001,
          4393.484,
          4430.075,
          4466.476,
          4502.684,
          4538.697,
          4574.512,
          4610.127,
          4645.539000000001,
          4680.746,
          4715.744000000001,
          4750.532,
          4785.107,
          4819.467000000001,
          4853.608,
          4887.527,
          4921.223,
          4954.692,
          4987.931,
          5020.938,
          5053.709,
          5086.242,
          5118.534000000001,
          5150.582,
          5182.383,
          5213.932,
          5245.229,
          5276.269,
          5307.048000000001,
          5337.565,
          5367.815,
          5397.795,
          5427.501,
          5456.931,
          5486.08,
          5514.946,
          5543.524,
          5571.811,
          5599.803000000001,
          5627.496,
          5654.8859999999995,
          5681.971,
          5708.744000000001,
          5735.203,
          5761.344,
          5787.161,
          5812.651999999999,
          5837.811,
          5862.634,
          5887.116999999999,
          5911.255,
          5935.044,
          5958.478,
          5981.554,
          6004.265,
          6026.609,
          6048.578,
          6070.168000000001,
          6091.375,
          6112.191,
          6132.613,
          6152.634,
          6172.249,
          6191.451999999999,
          6210.236999999999,
          6228.598000000001,
          6246.529,
          6264.025,
          6281.076999999999,
          6297.681,
          6313.828,
          6329.514,
          6344.73,
          6359.469,
          6373.725,
          6387.49,
          6400.757,
          6413.517,
          6425.763000000001,
          6437.486999999999,
          6448.68,
          6459.335,
          6469.443,
          6478.994000000001,
          6487.981,
          6496.392,
          6504.22,
          6511.454000000001,
          6518.085,
          6524.102,
          6529.495,
          6534.254,
          6538.366999999999,
          6541.823,
          6544.611,
          6546.719,
          6548.134,
          6548.845,
          6548.839,
          6548.101,
          6546.62,
          6544.380999999999,
          6541.369000000001,
          6537.571,
          6532.971,
          6527.553000000001,
          6521.303000000001,
          6514.201999999999,
          6506.235,
          6497.384,
          6487.632,
          6476.959,
          6465.347,
          6452.776,
          6439.227,
          6424.677,
          6409.106,
          6392.491,
          6374.81,
          6356.0380000000005,
          6336.151999999999,
          6315.126,
          6292.933000000001,
          6269.547,
          6244.94,
          6219.0830000000005,
          6191.946,
          6163.499,
          6133.7080000000005,
          6102.54,
          6069.9619999999995,
          6035.937,
          6000.429,
          5963.398,
          5924.804,
          5884.608,
          5842.765,
          5799.232,
          5753.96,
          5706.904,
          5658.0109999999995,
          5607.231,
          5554.509,
          5499.789000000001,
          5443.014,
          5384.121999999999,
          5323.05,
          5259.732,
          5194.101,
          5126.085,
          5055.612,
          4982.605,
          4906.986,
          4828.670999999999,
          4747.576,
          4663.6140000000005,
          4576.693,
          4486.721,
          4393.602,
          4297.235,
          4197.52,
          4094.355,
          3987.635,
          3877.2540000000004,
          3763.1059999999998,
          3645.085,
          3523.0890000000004,
          3397.015,
          3266.7659999999996,
          3132.2540000000004,
          2993.3959999999997,
          2850.1209999999996,
          2702.373,
          2550.115,
          2393.328,
          2232.022,
          2066.24,
          1896.058,
          1721.594,
          1543.0179999999998,
          1360.547,
          1174.458,
          985.0880000000001,
          792.837,
          598.17,
          401.61,
          203.733,
          5.167999999999999,
          -193.425,
          -391.36,
          -587.944,
          -782.492,
          -974.341,
          -1162.87,
          -1347.507,
          -1527.7420000000002,
          -1703.132,
          -1873.3110000000001,
          -2037.981,
          -2196.917,
          -2349.9629999999997,
          -2497.021,
          -2638.052,
          -2773.063,
          -2902.1,
          -3025.248,
          -3142.616,
          -3254.335,
          -3360.555,
          -3461.435,
          -3557.145,
          -3647.8590000000004,
          -3733.7509999999997,
          -3815.0009999999997,
          -3891.783,
          -3964.2690000000002,
          -4032.6279999999997,
          -4097.024,
          -4157.959,
          -4214.561,
          -4268.001,
          -4318.082,
          -4364.94,
          -4408.704000000001,
          -4449.499,
          -4487.443,
          -4522.653,
          -4555.235,
          -4585.292,
          -4612.924,
          -4638.223,
          -4661.279,
          -4682.179,
          -4701.002,
          -4717.827,
          -4732.727,
          -4745.772,
          -4757.03,
          -4766.565,
          -4774.436,
          -4780.704000000001,
          -4785.423,
          -4788.647,
          -4790.427,
          -4790.812,
          -4789.847,
          -4787.577,
          -4784.045999999999,
          -4779.293,
          -4773.358,
          -4766.278,
          -4758.09,
          -4748.827,
          -4738.524,
          -4727.210999999999,
          -4714.92,
          -4701.679,
          -4687.517,
          -4672.460999999999,
          -4656.537,
          -4639.77,
          -4622.185,
          -4603.805,
          -4584.652,
          -4564.748,
          -4544.1140000000005,
          -4522.77,
          -4500.736,
          -4478.03,
          -4454.670999999999,
          -4430.6759999999995,
          -4406.062,
          -4380.846,
          -4355.044,
          -4328.670999999999,
          -4301.741,
          -4274.27,
          -4246.271,
          -4217.758,
          -4188.744000000001,
          -4159.241,
          -4129.263,
          -4098.821,
          -4067.926,
          -4036.59,
          -4004.824,
          -3972.639,
          -3940.045,
          -3907.051,
          -3873.6690000000003,
          -3839.907,
          -3805.7740000000003,
          -3771.281,
          -3736.434,
          -3701.244,
          -3665.718,
          -3629.864,
          -3593.691,
          -3557.205,
          -3520.415,
          -3483.328,
          -3445.9509999999996,
          -3408.2909999999997,
          -3370.355,
          -3332.1490000000003,
          -3293.68,
          -3254.955,
          -3215.9790000000003,
          -3176.759,
          -3137.3,
          -3097.6079999999997,
          -3057.69,
          -3017.55,
          -2977.1929999999998,
          -2936.6259999999997,
          -2895.8540000000003,
          -2854.88,
          -2813.711,
          -2772.3520000000003,
          -2730.8059999999996,
          -2689.079,
          -2647.176,
          -2605.1,
          -2562.857,
          -2520.45,
          -2477.883,
          -2435.1620000000003,
          -2392.29,
          -2349.271,
          -2306.1079999999997,
          -2262.8070000000002,
          -2219.37,
          -2175.801,
          -2132.105,
          -2088.284,
          -2044.342,
          -2000.283,
          -1956.109,
          -1911.826,
          -1867.435,
          -1822.9389999999999,
          -1778.3429999999998,
          -1733.65,
          -1688.862,
          -1643.9820000000002,
          -1599.014,
          -1553.96,
          -1508.8239999999998,
          -1463.608,
          -1418.315,
          -1372.9479999999999,
          -1327.509,
          -1282.003,
          -1236.43,
          -1190.7939999999999,
          -1145.097,
          -1099.343,
          -1053.5330000000001,
          -1007.67,
          -961.757,
          -915.795,
          -869.789,
          -823.7389999999999,
          -777.648,
          -731.5189999999999,
          -685.3530000000001,
          -639.154,
          -592.924,
          -546.664,
          -500.37699999999995,
          -454.066,
          -407.73199999999997,
          -361.37699999999995,
          -315.004,
          -268.615,
          -222.21099999999998,
          -175.796,
          -129.371,
          -82.93799999999999,
          -36.499,
          9.943999999999999,
          56.388999999999996,
          102.833,
          149.276,
          195.71400000000003,
          242.146,
          288.57,
          334.985,
          381.38699999999994,
          427.776,
          474.15,
          520.506,
          566.8430000000001,
          613.158,
          659.451,
          705.7189999999999,
          751.96,
          798.299,
          844.482,
          890.632,
          936.7489999999999,
          982.83,
          1028.874,
          1074.878,
          1120.8419999999999,
          1166.763,
          1212.64,
          1258.47,
          1304.252,
          1349.985,
          1395.6660000000002,
          1441.295,
          1486.868,
          1532.385,
          1577.8429999999998,
          1623.241,
          1668.578,
          1713.851,
          1759.059,
          1804.2,
          1849.2720000000002,
          1894.274,
          1939.204,
          1984.06,
          2028.8410000000001,
          2073.544,
          2118.1679999999997,
          2162.712,
          2207.173,
          2251.55,
          2295.841,
          2340.045,
          2384.159,
          2428.1820000000002,
          2472.113,
          2515.948,
          2559.688,
          2603.3289999999997,
          2646.8709999999996,
          2690.31,
          2733.647,
          2776.8779999999997,
          2820.002,
          2863.0170000000003,
          2905.922,
          2948.7140000000004,
          2991.393,
          3033.955,
          3076.3990000000003,
          3118.723,
          3160.926,
          3203.005,
          3244.958,
          3286.785,
          3328.4829999999997,
          3370.0490000000004,
          3411.4829999999997,
          3452.781,
          3493.9429999999998,
          3534.966,
          3575.848,
          3616.5879999999997,
          3657.1820000000002,
          3697.63,
          3737.929,
          3778.078,
          3818.073,
          3857.913,
          3897.5959999999995,
          3937.12,
          3976.4829999999997,
          4015.6820000000002,
          4054.715,
          4093.5809999999997,
          4132.277,
          4170.8,
          4209.149,
          4247.321,
          4285.314,
          4323.125,
          4360.753,
          4398.195,
          4435.448,
          4472.5109999999995,
          4509.38,
          4546.053,
          4582.528,
          4618.803,
          4654.874,
          4690.7390000000005,
          4726.396,
          4761.842000000001,
          4797.0740000000005,
          4832.09,
          4866.8859999999995,
          4901.460999999999,
          4935.811,
          4969.933,
          5003.826,
          5037.485,
          5070.907,
          5104.090999999999,
          5137.032,
          5169.729,
          5202.177,
          5234.374,
          5266.316,
          5298,
          5329.423000000001,
          5360.581999999999,
          5391.473000000001,
          5422.093000000001,
          5452.438,
          5482.505999999999,
          5512.2919999999995,
          5541.7919999999995,
          5571.004,
          5599.924,
          5628.547,
          5656.869000000001,
          5684.888000000001,
          5712.598000000001,
          5739.996999999999,
          5767.079000000001,
          5793.842,
          5820.279,
          5846.388000000001,
          5872.164000000001,
          5897.602,
          5922.696999999999,
          5947.446999999999,
          5971.844,
          5995.8859999999995,
          6019.566999999999,
          6042.882,
          6065.826,
          6088.394,
          6110.58,
          6132.380999999999,
          6153.789000000001,
          6174.8,
          6195.408,
          6215.608,
          6235.392,
          6254.757,
          6273.695,
          6292.2,
          6310.266,
          6327.887,
          6345.056,
          6361.766,
          6378.0109999999995,
          6393.783,
          6409.076,
          6423.882,
          6438.194,
          6452.003000000001,
          6465.304,
          6478.085999999999,
          6490.343000000001,
          6502.066,
          6513.246,
          6523.875,
          6533.943,
          6543.443,
          6552.3640000000005,
          6560.698,
          6568.433000000001,
          6575.561,
          6582.071,
          6587.951999999999,
          6593.194,
          6597.785,
          6601.715,
          6604.972,
          6607.543000000001,
          6609.4169999999995,
          6610.581,
          6611.021,
          6610.726,
          6609.681,
          6607.871999999999,
          6605.285,
          6601.906,
          6597.718000000001,
          6592.706,
          6586.855,
          6580.147,
          6572.566,
          6564.095,
          6554.714,
          6544.404,
          6533.149,
          6520.927,
          6507.718000000001,
          6493.501,
          6478.255,
          6461.956,
          6444.581999999999,
          6426.109,
          6406.5109999999995,
          6385.764,
          6363.842,
          6340.715999999999,
          6316.359,
          6290.741,
          6263.831999999999,
          6235.601,
          6206.015,
          6175.041,
          6142.644,
          6108.7880000000005,
          6073.435,
          6036.547,
          5998.0830000000005,
          5958.0019999999995,
          5916.259,
          5872.811,
          5827.61,
          5780.607,
          5731.7519999999995,
          5680.991,
          5628.272,
          5573.536999999999,
          5516.727,
          5457.781,
          5396.634,
          5333.221,
          5267.473000000001,
          5199.318,
          5128.681,
          5055.487,
          4979.655,
          4901.101,
          4819.74,
          4735.482,
          4648.237,
          4557.907999999999,
          4464.399,
          4367.61,
          4267.438,
          4163.777,
          4056.522,
          3945.5640000000003,
          3830.797,
          3712.112,
          3589.402,
          3462.565,
          3331.4990000000003,
          3196.113,
          3056.322,
          2912.05,
          2763.238,
          2609.843,
          2451.845,
          2289.248,
          2122.0879999999997,
          1950.4370000000001,
          1774.41,
          1594.1689999999999,
          1409.9279999999999,
          1221.958,
          1030.593,
          836.2280000000001,
          639.327,
          440.411,
          240.058,
          38.898,
          -162.403,
          -363.153,
          -562.649,
          -760.196,
          -955.118,
          -1146.78,
          -1334.594,
          -1518.0339999999999,
          -1696.645,
          -1870.0420000000001,
          -2037.915,
          -2200.026,
          -2356.2070000000003,
          -2506.3520000000003,
          -2650.4109999999996,
          -2788.385,
          -2920.315,
          -3046.282,
          -3166.3920000000003,
          -3280.772,
          -3389.573,
          -3492.954,
          -3591.083,
          -3684.134,
          -3772.2870000000003,
          -3855.719,
          -3934.607,
          -4009.125,
          -4079.442,
          -4145.729,
          -4208.143,
          -4266.842000000001,
          -4321.975,
          -4373.685,
          -4422.113,
          -4467.39,
          -4509.642,
          -4548.992,
          -4585.553,
          -4619.437,
          -4650.748,
          -4679.587,
          -4706.049,
          -4730.225,
          -4752.2029999999995,
          -4772.063,
          -4789.8859999999995,
          -4805.746,
          -4819.715,
          -4831.862,
          -4842.249,
          -4850.943,
          -4858,
          -4863.478,
          -4867.43,
          -4869.91,
          -4870.965,
          -4870.644,
          -4868.992,
          -4866.052,
          -4861.865,
          -4856.472,
          -4849.911,
          -4842.219,
          -4833.43,
          -4823.577,
          -4812.695,
          -4800.813,
          -4787.962,
          -4774.170999999999,
          -4759.465999999999,
          -4743.875,
          -4727.424,
          -4710.1359999999995,
          -4692.036,
          -4673.147,
          -4653.491,
          -4633.088,
          -4611.960999999999,
          -4590.127,
          -4567.608,
          -4544.42,
          -4520.583,
          -4496.113,
          -4471.028,
          -4445.342000000001,
          -4419.073,
          -4392.235,
          -4364.843,
          -4336.911,
          -4308.4529999999995,
          -4279.482,
          -4250.012,
          -4220.054,
          -4189.621,
          -4158.725,
          -4127.378,
          -4095.591,
          -4063.3740000000003,
          -4030.739,
          -3997.695,
          -3964.252,
          -3930.42,
          -3896.208,
          -3861.6259999999997,
          -3826.683,
          -3791.387,
          -3755.7470000000003,
          -3719.772,
          -3683.468,
          -3646.844,
          -3609.908,
          -3572.667,
          -3535.1279999999997,
          -3497.2990000000004,
          -3459.1859999999997,
          -3420.797,
          -3382.138,
          -3343.2140000000004,
          -3304.034,
          -3264.6020000000003,
          -3224.925,
          -3185.009,
          -3144.8590000000004,
          -3104.4809999999998,
          -3063.881,
          -3023.0640000000003,
          -2982.0359999999996,
          -2940.801,
          -2899.364,
          -2857.7309999999998,
          -2815.906,
          -2773.895,
          -2731.7009999999996,
          -2689.33,
          -2646.7859999999996,
          -2604.073,
          -2561.195,
          -2518.158,
          -2474.964,
          -2431.619,
          -2388.125,
          -2344.488,
          -2300.71,
          -2256.797,
          -2212.75,
          -2168.575,
          -2124.274,
          -2079.8520000000003,
          -2035.3110000000001,
          -1990.656,
          -1945.889,
          -1901.014,
          -1856.0339999999999,
          -1810.9520000000002,
          -1765.771,
          -1720.496,
          -1675.128,
          -1629.67,
          -1584.1270000000002,
          -1538.5,
          -1492.7920000000001,
          -1447.007,
          -1401.1470000000002,
          -1355.214,
          -1309.213,
          -1263.145,
          -1217.013,
          -1170.82,
          -1124.568,
          -1078.259,
          -1031.8980000000001,
          -985.485,
          -939.023,
          -892.5160000000001,
          -845.9639999999999,
          -799.372,
          -752.74,
          -706.071,
          -659.3689999999999,
          -612.634,
          -565.869,
          -519.077,
          -472.26,
          -425.41900000000004,
          -378.55800000000005,
          -331.67800000000005,
          -284.781,
          -237.87,
          -190.946,
          -144.012,
          -97.069,
          -50.121,
          -3.168,
          43.787,
          90.742,
          137.695,
          184.644,
          231.588,
          278.52299999999997,
          325.45,
          372.36400000000003,
          419.265,
          466.151,
          513.019,
          559.869,
          606.697,
          653.502,
          700.283,
          747.0369999999999,
          793.762,
          840.457,
          887.1210000000001,
          933.75,
          980.3439999999999,
          1026.9,
          1073.417,
          1119.893,
          1166.326,
          1212.715,
          1259.057,
          1305.351,
          1351.595,
          1397.7879999999998,
          1443.9270000000001,
          1490.011,
          1536.0379999999998,
          1582.006,
          1627.915,
          1673.76,
          1719.5420000000001,
          1765.259,
          1810.908,
          1856.4879999999998,
          1901.997,
          1947.433,
          1992.796,
          2038.082,
          2083.29,
          2128.419,
          2173.466,
          2218.43,
          2263.31,
          2308.103,
          2352.8070000000002,
          2397.422,
          2441.944,
          2486.373,
          2530.7070000000003,
          2574.9429999999998,
          2619.081,
          2663.117,
          2707.051,
          2750.881,
          2794.6040000000003,
          2838.22,
          2881.725,
          2925.119,
          2968.4,
          3011.565,
          3054.612,
          3097.5409999999997,
          3140.349,
          3183.034,
          3225.594,
          3268.027,
          3310.3320000000003,
          3352.506,
          3394.548,
          3436.455,
          3478.2259999999997,
          3519.8590000000004,
          3561.3509999999997,
          3602.7009999999996,
          3643.907,
          3684.966,
          3725.8759999999997,
          3766.636,
          3807.244,
          3847.696,
          3887.992,
          3928.1290000000004,
          3968.105,
          4007.917,
          4047.5640000000003,
          4087.0429999999997,
          4126.353,
          4165.49,
          4204.4529999999995,
          4243.2390000000005,
          4281.846,
          4320.271,
          4358.513,
          4396.569,
          4434.436,
          4472.112,
          4509.595,
          4546.8820000000005,
          4583.971,
          4620.859,
          4657.543,
          4694.022,
          4730.291,
          4766.349,
          4802.194,
          4837.821,
          4873.229,
          4908.415,
          4943.376,
          4978.109,
          5012.611,
          5046.879,
          5080.911,
          5114.7029999999995,
          5148.253,
          5181.556,
          5214.611,
          5247.414000000001,
          5279.9619999999995,
          5312.251,
          5344.278,
          5376.041,
          5407.534000000001,
          5438.755999999999,
          5469.703,
          5500.37,
          5530.755,
          5560.854,
          5590.664000000001,
          5620.18,
          5649.398,
          5678.315,
          5706.927,
          5735.23,
          5763.22,
          5790.892,
          5818.243,
          5845.269,
          5871.964,
          5898.3240000000005,
          5924.346,
          5950.024,
          5975.355,
          6000.331999999999,
          6024.951,
          6049.2080000000005,
          6073.098000000001,
          6096.615,
          6119.754,
          6142.5109999999995,
          6164.88,
          6186.854,
          6208.43,
          6229.601,
          6250.361,
          6270.705,
          6290.626,
          6310.119000000001,
          6329.177,
          6347.793000000001,
          6365.963000000001,
          6383.678000000001,
          6400.932,
          6417.718000000001,
          6434.029,
          6449.859,
          6465.198,
          6480.041,
          6494.38,
          6508.206,
          6521.512,
          6534.289000000001,
          6546.529,
          6558.224,
          6569.3640000000005,
          6579.941999999999,
          6589.946999999999,
          6599.37,
          6608.201999999999,
          6616.433000000001,
          6624.052,
          6631.05,
          6637.415,
          6643.138000000001,
          6648.206,
          6652.608,
          6656.334,
          6659.37,
          6661.704000000001,
          6663.3240000000005,
          6664.217,
          6664.369000000001,
          6663.766,
          6662.395,
          6660.241,
          6657.29,
          6653.525,
          6648.931,
          6643.491999999999,
          6637.191,
          6630.0109999999995,
          6621.935,
          6612.944,
          6603.019,
          6592.141,
          6580.29,
          6567.445,
          6553.585999999999,
          6538.69,
          6522.735,
          6505.698,
          6487.553000000001,
          6468.276999999999,
          6447.844,
          6426.227,
          6403.398,
          6379.329000000001,
          6353.991,
          6327.353,
          6299.384,
          6270.05,
          6239.316999999999,
          6207.153,
          6173.518,
          6138.376,
          6101.688,
          6063.411999999999,
          6023.507,
          5981.929,
          5938.632,
          5893.569,
          5846.691,
          5797.948,
          5747.285,
          5694.648,
          5639.98,
          5583.221,
          5524.309,
          5463.18,
          5399.767,
          5334,
          5265.807,
          5195.113,
          5121.840999999999,
          5045.907999999999,
          4967.232,
          4885.725,
          4801.2970000000005,
          4713.856,
          4623.305,
          4529.545999999999,
          4432.477,
          4331.994000000001,
          4227.991,
          4120.359,
          4008.99,
          3893.772,
          3774.597,
          3651.3559999999998,
          3523.942,
          3392.2529999999997,
          3256.1929999999998,
          3115.673,
          2970.617,
          2820.958,
          2666.653,
          2507.675,
          2344.025,
          2175.7329999999997,
          2002.866,
          1825.533,
          1643.89,
          1458.1470000000002,
          1268.569,
          1075.485,
          879.2869999999999,
          680.434,
          479.445,
          276.899,
          73.42699999999999,
          -130.30200000000002,
          -333.59,
          -535.727,
          -736.0060000000001,
          -933.742,
          -1128.2839999999999,
          -1319.031,
          -1505.443,
          -1687.049,
          -1863.4479999999999,
          -2034.319,
          -2199.409,
          -2358.5389999999998,
          -2511.593,
          -2658.512,
          -2799.2909999999997,
          -2933.965,
          -3062.6090000000004,
          -3185.3259999999996,
          -3302.244,
          -3413.507,
          -3519.275,
          -3619.718,
          -3715.01,
          -3805.329,
          -3890.8559999999998,
          -3971.768,
          -4048.241,
          -4120.448,
          -4188.557,
          -4252.731,
          -4313.127,
          -4369.898,
          -4423.19,
          -4473.143,
          -4519.891,
          -4563.562,
          -4604.28,
          -4642.162,
          -4677.319,
          -4709.859,
          -4739.880999999999,
          -4767.486,
          -4792.764,
          -4815.803,
          -4836.688,
          -4855.499,
          -4872.311,
          -4887.198,
          -4900.228,
          -4911.47,
          -4920.984,
          -4928.833,
          -4935.073,
          -4939.759,
          -4942.945,
          -4944.68,
          -4945.013,
          -4943.99,
          -4941.654,
          -4938.049,
          -4933.215,
          -4927.19,
          -4920.012,
          -4911.715999999999,
          -4902.337,
          -4891.907999999999,
          -4880.46,
          -4868.024,
          -4854.629,
          -4840.304,
          -4825.0740000000005,
          -4808.967000000001,
          -4792.0070000000005,
          -4774.218,
          -4755.624,
          -4736.248,
          -4716.111,
          -4695.234,
          -4673.637,
          -4651.339,
          -4628.36,
          -4604.718,
          -4580.43,
          -4555.514,
          -4529.985,
          -4503.86,
          -4477.154,
          -4449.883,
          -4422.06,
          -4393.7,
          -4364.816,
          -4335.4220000000005,
          -4305.529,
          -4275.153,
          -4244.302,
          -4212.99,
          -4181.228,
          -4149.027,
          -4116.398,
          -4083.3509999999997,
          -4049.8959999999997,
          -4016.0440000000003,
          -3981.803,
          -3947.183,
          -3912.1940000000004,
          -3876.843,
          -3841.1409999999996,
          -3805.094,
          -3768.712,
          -3732.002,
          -3694.972,
          -3657.63,
          -3619.9829999999997,
          -3582.039,
          -3543.804,
          -3505.285,
          -3466.489,
          -3427.423,
          -3388.093,
          -3348.505,
          -3308.6659999999997,
          -3268.5809999999997,
          -3228.256,
          -3187.698,
          -3146.9109999999996,
          -3105.901,
          -3064.6740000000004,
          -3023.235,
          -2981.5879999999997,
          -2939.74,
          -2897.695,
          -2855.4570000000003,
          -2813.032,
          -2770.4240000000004,
          -2727.638,
          -2684.678,
          -2641.5490000000004,
          -2598.254,
          -2554.799,
          -2511.187,
          -2467.423,
          -2423.51,
          -2379.452,
          -2335.254,
          -2290.9179999999997,
          -2246.449,
          -2201.851,
          -2157.127,
          -2112.28,
          -2067.314,
          -2022.2320000000002,
          -1977.0379999999998,
          -1931.736,
          -1886.328,
          -1840.817,
          -1795.207,
          -1749.5020000000002,
          -1703.703,
          -1657.8139999999999,
          -1611.838,
          -1565.7779999999998,
          -1519.6370000000002,
          -1473.4170000000001,
          -1427.1229999999998,
          -1380.755,
          -1334.318,
          -1287.813,
          -1241.244,
          -1194.612,
          -1147.922,
          -1101.175,
          -1054.373,
          -1007.52,
          -960.618,
          -913.669,
          -866.676,
          -819.6410000000001,
          -772.566,
          -725.454,
          -678.308,
          -631.129,
          -583.919,
          -536.682,
          -489.41900000000004,
          -442.13199999999995,
          -394.824,
          -347.49699999999996,
          -300.153,
          -252.794,
          -205.422,
          -158.04,
          -110.649,
          -63.251000000000005,
          -15.849,
          31.555,
          78.96,
          126.363,
          173.763,
          221.157,
          268.54400000000004,
          315.921,
          363.286,
          410.639,
          457.976,
          505.296,
          552.597,
          599.877,
          647.134,
          694.367,
          741.573,
          788.7510000000001,
          835.898,
          883.013,
          930.095,
          977.1410000000001,
          1024.149,
          1071.118,
          1118.046,
          1164.931,
          1211.771,
          1258.565,
          1305.31,
          1352.005,
          1398.649,
          1445.239,
          1491.773,
          1538.25,
          1584.6689999999999,
          1631.026,
          1677.3220000000001,
          1723.5529999999999,
          1769.7179999999998,
          1815.815,
          1861.8429999999998,
          1907.799,
          1953.683,
          1999.491,
          2045.224,
          2090.877,
          2136.451,
          2181.9429999999998,
          2227.351,
          2272.674,
          2317.91,
          2363.056,
          2408.112,
          2453.075,
          2497.944,
          2542.717,
          2587.3920000000003,
          2631.967,
          2676.441,
          2720.8109999999997,
          2765.0759999999996,
          2809.2329999999997,
          2853.282,
          2897.22,
          2941.046,
          2984.756,
          3028.3509999999997,
          3071.827,
          3115.183,
          3158.417,
          3201.527,
          3244.511,
          3287.367,
          3330.094,
          3372.688,
          3415.1490000000003,
          3457.474,
          3499.6609999999996,
          3541.7090000000003,
          3583.615,
          3625.377,
          3666.993,
          3708.461,
          3749.78,
          3790.946,
          3831.958,
          3872.813,
          3913.51,
          3954.046,
          3994.42,
          4034.6279999999997,
          4074.6690000000003,
          4114.541,
          4154.24,
          4193.766,
          4233.115,
          4272.285,
          4311.274,
          4350.08,
          4388.7,
          4427.1320000000005,
          4465.373,
          4503.42,
          4541.272,
          4578.9259999999995,
          4616.379,
          4653.628,
          4690.6720000000005,
          4727.5070000000005,
          4764.13,
          4800.54,
          4836.733,
          4872.706,
          4908.458,
          4943.984,
          4979.282,
          5014.349,
          5049.182,
          5083.778,
          5118.135,
          5152.249,
          5186.117,
          5219.735,
          5253.102,
          5286.213000000001,
          5319.065,
          5351.655,
          5383.98,
          5416.036,
          5447.819,
          5479.326999999999,
          5510.555,
          5541.501,
          5572.159000000001,
          5602.528,
          5632.601,
          5662.378000000001,
          5691.852,
          5721.021,
          5749.88,
          5778.425,
          5806.651999999999,
          5834.557,
          5862.135,
          5889.383000000001,
          5916.295,
          5942.866999999999,
          5969.095,
          5994.974,
          6020.499,
          6045.666,
          6070.469,
          6094.903,
          6118.964,
          6142.646,
          6165.944,
          6188.852,
          6211.366,
          6233.479,
          6255.186,
          6276.482,
          6297.359,
          6317.812,
          6337.835999999999,
          6357.423000000001,
          6376.566999999999,
          6395.262,
          6413.5019999999995,
          6431.278,
          6448.585999999999,
          6465.416,
          6481.763000000001,
          6497.618,
          6512.975,
          6527.825,
          6542.161,
          6555.974,
          6569.257,
          6582,
          6594.196,
          6605.835999999999,
          6616.909000000001,
          6627.408,
          6637.323,
          6646.644,
          6655.361,
          6663.464,
          6670.943,
          6677.786999999999,
          6683.985,
          6689.526,
          6694.398,
          6698.59,
          6702.089,
          6704.883000000001,
          6706.96,
          6708.306,
          6708.906999999999,
          6708.751,
          6707.823,
          6706.107,
          6703.590999999999,
          6700.257,
          6696.09,
          6691.073,
          6685.191,
          6678.425,
          6670.758000000001,
          6662.170999999999,
          6652.647,
          6642.164000000001,
          6630.703,
          6618.243,
          6604.764,
          6590.241999999999,
          6574.656,
          6557.981,
          6540.193,
          6521.268,
          6501.179,
          6479.9,
          6457.403,
          6433.659000000001,
          6408.638000000001,
          6382.311,
          6354.644,
          6325.605,
          6295.161,
          6263.275,
          6229.911,
          6195.031,
          6158.597,
          6120.566,
          6080.895,
          6039.541,
          5996.459,
          5951.6,
          5904.915,
          5856.353,
          5805.861,
          5753.382,
          5698.859,
          5642.233,
          5583.44,
          5522.416,
          5459.093000000001,
          5393.401999999999,
          5325.269,
          5254.618,
          5181.372,
          5105.448,
          5026.7609999999995,
          4945.225,
          4860.748,
          4773.236,
          4682.592000000001,
          4588.715999999999,
          4491.505999999999,
          4390.856,
          4286.657999999999,
          4178.804,
          4067.1809999999996,
          3951.677,
          3832.1820000000002,
          3708.585,
          3580.776,
          3448.651,
          3312.11,
          3171.0640000000003,
          3025.43,
          2875.1409999999996,
          2720.1459999999997,
          2560.416,
          2395.945,
          2226.762,
          2052.926,
          1874.5410000000002,
          1691.757,
          1504.7779999999998,
          1313.864,
          1119.338,
          921.5880000000001,
          721.067,
          518.2919999999999,
          313.842,
          108.346,
          -97.523,
          -303.063,
          -507.55800000000005,
          -710.2919999999999,
          -910.568,
          -1107.725,
          -1301.147,
          -1490.28,
          -1674.638,
          -1853.808,
          -2027.4520000000002,
          -2195.308,
          -2357.1839999999997,
          -2512.952,
          -2662.548,
          -2805.9559999999997,
          -2943.2070000000003,
          -3074.37,
          -3199.545,
          -3318.8559999999998,
          -3432.448,
          -3540.478,
          -3643.115,
          -3740.534,
          -3832.915,
          -3920.437,
          -4003.2790000000005,
          -4081.619,
          -4155.6320000000005,
          -4225.486,
          -4291.36,
          -4353.373,
          -4411.718,
          -4466.531,
          -4517.954000000001,
          -4566.122,
          -4611.165,
          -4653.208,
          -4692.37,
          -4728.764,
          -4762.498,
          -4793.6759999999995,
          -4822.395,
          -4848.751,
          -4872.831,
          -4894.721,
          -4914.502,
          -4932.253,
          -4948.045999999999,
          -4961.952,
          -4974.038,
          -4984.369000000001,
          -4993.005999999999,
          -5000.0070000000005,
          -5005.428,
          -5009.323,
          -5011.7429999999995,
          -5012.736,
          -5012.35,
          -5010.629,
          -5007.616,
          -5003.353,
          -4997.878,
          -4991.23,
          -4983.445,
          -4974.557,
          -4964.601,
          -4953.607,
          -4941.608,
          -4928.633,
          -4914.71,
          -4899.867,
          -4884.13,
          -4867.525,
          -4850.077,
          -4831.809,
          -4812.7429999999995,
          -4792.903,
          -4772.308,
          -4750.981,
          -4728.939,
          -4706.204000000001,
          -4682.793,
          -4658.723,
          -4634.013,
          -4608.68,
          -4582.738,
          -4556.204000000001,
          -4529.094,
          -4501.420999999999,
          -4473.201,
          -4444.446,
          -4415.170999999999,
          -4385.389,
          -4355.111,
          -4324.35,
          -4293.119000000001,
          -4261.428,
          -4229.29,
          -4196.714,
          -4163.710999999999,
          -4130.293,
          -4096.468,
          -4062.2470000000003,
          -4027.638,
          -3992.652,
          -3957.297,
          -3921.583,
          -3885.5170000000003,
          -3849.1079999999997,
          -3812.364,
          -3775.292,
          -3737.902,
          -3700.2,
          -3662.1929999999998,
          -3623.889,
          -3585.295,
          -3546.4179999999997,
          -3507.263,
          -3467.8390000000004,
          -3428.15,
          -3388.205,
          -3348.007,
          -3307.5640000000003,
          -3266.881,
          -3225.9640000000004,
          -3184.8190000000004,
          -3143.4509999999996,
          -3101.865,
          -3060.066,
          -3018.0609999999997,
          -2975.853,
          -2933.448,
          -2890.85,
          -2848.0640000000003,
          -2805.0959999999995,
          -2761.949,
          -2718.627,
          -2675.136,
          -2631.4790000000003,
          -2587.661,
          -2543.686,
          -2499.558,
          -2455.281,
          -2410.859,
          -2366.295,
          -2321.594,
          -2276.759,
          -2231.794,
          -2186.703,
          -2141.488,
          -2096.154,
          -2050.7039999999997,
          -2005.141,
          -1959.469,
          -1913.691,
          -1867.81,
          -1821.829,
          -1775.751,
          -1729.58,
          -1683.318,
          -1636.969,
          -1590.535,
          -1544.02,
          -1497.425,
          -1450.755,
          -1404.0120000000002,
          -1357.1979999999999,
          -1310.316,
          -1263.369,
          -1216.36,
          -1169.2910000000002,
          -1122.165,
          -1074.985,
          -1027.752,
          -980.4689999999999,
          -933.14,
          -885.765,
          -838.3489999999999,
          -790.8919999999999,
          -743.398,
          -695.8689999999999,
          -648.306,
          -600.7130000000001,
          -553.092,
          -505.445,
          -457.773,
          -410.08,
          -362.36800000000005,
          -314.638,
          -266.893,
          -219.135,
          -171.365,
          -123.587,
          -75.803,
          -28.013,
          19.779,
          67.572,
          115.36399999999999,
          163.15200000000002,
          210.935,
          258.71,
          306.476,
          354.231,
          401.973,
          449.7,
          497.41,
          545.101,
          592.771,
          640.418,
          688.04,
          735.637,
          783.204,
          830.742,
          878.248,
          925.7189999999999,
          973.155,
          1020.554,
          1067.913,
          1115.231,
          1162.506,
          1209.736,
          1256.9189999999999,
          1304.055,
          1351.139,
          1398.172,
          1445.151,
          1492.075,
          1538.941,
          1585.7479999999998,
          1632.494,
          1679.1770000000001,
          1725.796,
          1772.349,
          1818.8329999999999,
          1865.2479999999998,
          1911.5910000000001,
          1957.861,
          2004.055,
          2050.173,
          2096.2110000000002,
          2142.17,
          2188.045,
          2233.837,
          2279.5429999999997,
          2325.161,
          2370.69,
          2416.127,
          2461.471,
          2506.72,
          2551.8720000000003,
          2596.926,
          2641.8790000000004,
          2686.73,
          2731.4770000000003,
          2776.118,
          2820.651,
          2865.074,
          2909.386,
          2953.5840000000003,
          2997.667,
          3041.632,
          3085.478,
          3129.203,
          3172.8059999999996,
          3216.283,
          3259.633,
          3302.8540000000003,
          3345.9440000000004,
          3388.902,
          3431.724,
          3474.41,
          3516.9570000000003,
          3559.363,
          3601.625,
          3643.743,
          3685.7140000000004,
          3727.535,
          3769.205,
          3810.7209999999995,
          3852.0820000000003,
          3893.284,
          3934.327,
          3975.208,
          4015.9240000000004,
          4056.473,
          4096.854,
          4137.063,
          4177.098,
          4216.958,
          4256.64,
          4296.141,
          4335.459,
          4374.590999999999,
          4413.536,
          4452.291,
          4490.853,
          4529.219,
          4567.388,
          4605.356,
          4643.121,
          4680.681,
          4718.032,
          4755.173,
          4792.099,
          4828.81,
          4865.3009999999995,
          4901.57,
          4937.6140000000005,
          4973.43,
          5009.016,
          5044.3679999999995,
          5079.483,
          5114.359,
          5148.992,
          5183.379,
          5217.518,
          5251.404,
          5285.034000000001,
          5318.406,
          5351.516,
          5384.36,
          5416.936,
          5449.2390000000005,
          5481.266,
          5513.014,
          5544.479,
          5575.656999999999,
          5606.545,
          5637.138000000001,
          5667.434,
          5697.427,
          5727.1140000000005,
          5756.491,
          5785.554,
          5814.299,
          5842.721,
          5870.816999999999,
          5898.581,
          5926.009,
          5953.097,
          5979.840999999999,
          6006.235,
          6032.274,
          6057.955,
          6083.271,
          6108.219,
          6132.7919999999995,
          6156.986,
          6180.795,
          6204.214,
          6227.238,
          6249.86,
          6272.075,
          6293.878000000001,
          6315.262,
          6336.221,
          6356.75,
          6376.840999999999,
          6396.4890000000005,
          6415.686,
          6434.427,
          6452.704000000001,
          6470.51,
          6487.839,
          6504.682,
          6521.033,
          6536.885,
          6552.228,
          6567.056,
          6581.359,
          6595.130999999999,
          6608.363,
          6621.045,
          6633.169,
          6644.726,
          6655.706,
          6666.101,
          6675.9,
          6685.094,
          6693.672,
          6701.6230000000005,
          6708.938,
          6715.605,
          6721.613,
          6726.9490000000005,
          6731.604,
          6735.563,
          6738.816,
          6741.348000000001,
          6743.148,
          6744.2,
          6744.491999999999,
          6744.01,
          6742.738,
          6740.661,
          6737.765,
          6734.031999999999,
          6729.446999999999,
          6723.993,
          6717.653,
          6710.408,
          6702.24,
          6693.13,
          6683.058000000001,
          6672.005999999999,
          6659.95,
          6646.871,
          6632.745,
          6617.5509999999995,
          6601.264,
          6583.859,
          6565.313,
          6545.599,
          6524.689,
          6502.556,
          6479.170999999999,
          6454.505,
          6428.526,
          6401.203,
          6372.501,
          6342.388000000001,
          6310.828,
          6277.783,
          6243.215999999999,
          6207.085999999999,
          6169.352,
          6129.973000000001,
          6088.903,
          6046.096,
          6001.505,
          5955.08,
          5906.769,
          5856.518,
          5804.271,
          5749.972,
          5693.558000000001,
          5634.967,
          5574.134,
          5510.991,
          5445.468000000001,
          5377.491,
          5306.983,
          5233.866,
          5158.057,
          5079.472,
          4998.021,
          4913.612,
          4826.152,
          4735.542,
          4641.682,
          4544.467000000001,
          4443.791,
          4339.545999999999,
          4231.619000000001,
          4119.9,
          4004.2729999999997,
          3884.6259999999997,
          3760.8459999999995,
          3632.822,
          3500.447,
          3363.619,
          3222.244,
          3076.237,
          2925.5290000000005,
          2770.063,
          2609.8070000000002,
          2444.75,
          2274.915,
          2100.357,
          1921.174,
          1737.509,
          1549.5610000000001,
          1357.5829999999999,
          1161.893,
          962.873,
          760.971,
          556.702,
          350.639,
          143.41299999999998,
          -64.30199999999999,
          -271.803,
          -478.366,
          -683.268,
          -885.804,
          -1085.3,
          -1281.129,
          -1472.7220000000002,
          -1659.58,
          -1841.277,
          -2017.461,
          -2187.8579999999997,
          -2352.263,
          -2510.541,
          -2662.615,
          -2808.466,
          -2948.115,
          -3081.6290000000004,
          -3209.1009999999997,
          -3330.655,
          -3446.4309999999996,
          -3556.586,
          -3661.2870000000003,
          -3760.7129999999997,
          -3855.039,
          -3944.449,
          -4029.12,
          -4109.231,
          -4184.959,
          -4256.473,
          -4323.941,
          -4387.522,
          -4447.373,
          -4503.643,
          -4556.474,
          -4606.005999999999,
          -4652.3679999999995,
          -4695.688,
          -4736.085,
          -4773.675,
          -4808.566,
          -4840.863,
          -4870.667,
          -4898.071,
          -4923.166,
          -4946.039000000001,
          -4966.772,
          -4985.443,
          -5002.127,
          -5016.896,
          -5029.818,
          -5040.957,
          -5050.377,
          -5058.135,
          -5064.29,
          -5068.894,
          -5072,
          -5073.657999999999,
          -5073.915,
          -5072.816,
          -5070.405,
          -5066.723,
          -5061.811,
          -5055.707,
          -5048.447,
          -5040.068,
          -5030.602,
          -5020.083,
          -5008.541,
          -4996.0070000000005,
          -4982.51,
          -4968.0779999999995,
          -4952.738,
          -4936.515,
          -4919.434,
          -4901.519,
          -4882.794,
          -4863.281,
          -4843.001,
          -4821.976,
          -4800.224,
          -4777.767,
          -4754.621,
          -4730.807,
          -4706.34,
          -4681.2390000000005,
          -4655.519,
          -4629.197,
          -4602.287,
          -4574.805,
          -4546.766,
          -4518.183,
          -4489.07,
          -4459.44,
          -4429.306,
          -4398.68,
          -4367.5740000000005,
          -4336,
          -4303.97,
          -4271.494000000001,
          -4238.584,
          -4205.249,
          -4171.5,
          -4137.347,
          -4102.8,
          -4067.867,
          -4032.558,
          -3996.883,
          -3960.848,
          -3924.4640000000004,
          -3887.738,
          -3850.678,
          -3813.292,
          -3775.5879999999997,
          -3737.573,
          -3699.2540000000004,
          -3660.639,
          -3621.735,
          -3582.547,
          -3543.0840000000003,
          -3503.3509999999997,
          -3463.3540000000003,
          -3423.1,
          -3382.5959999999995,
          -3341.8459999999995,
          -3300.8559999999998,
          -3259.633,
          -3218.1809999999996,
          -3176.507,
          -3134.615,
          -3092.511,
          -3050.2,
          -3007.6859999999997,
          -2964.975,
          -2922.071,
          -2878.98,
          -2835.7059999999997,
          -2792.252,
          -2748.625,
          -2704.827,
          -2660.864,
          -2616.74,
          -2572.458,
          -2528.0229999999997,
          -2483.438,
          -2438.709,
          -2393.837,
          -2348.828,
          -2303.685,
          -2258.411,
          -2213.011,
          -2167.487,
          -2121.843,
          -2076.083,
          -2030.21,
          -1984.227,
          -1938.138,
          -1891.945,
          -1845.6529999999998,
          -1799.263,
          -1752.779,
          -1706.205,
          -1659.543,
          -1612.795,
          -1565.9660000000001,
          -1519.057,
          -1472.0720000000001,
          -1425.014,
          -1377.884,
          -1330.6870000000001,
          -1283.424,
          -1236.098,
          -1188.712,
          -1141.269,
          -1093.77,
          -1046.219,
          -998.618,
          -950.97,
          -903.2760000000001,
          -855.54,
          -807.763,
          -759.949,
          -712.0989999999999,
          -664.216,
          -616.3009999999999,
          -568.359,
          -520.389,
          -472.39599999999996,
          -424.38,
          -376.345,
          -328.292,
          -280.223,
          -232.141,
          -184.048,
          -135.946,
          -87.837,
          -39.723,
          8.394,
          56.512,
          104.62899999999999,
          152.743,
          200.852,
          248.953,
          297.045,
          345.12699999999995,
          393.195,
          441.24800000000005,
          489.285,
          537.302,
          585.299,
          633.273,
          681.2230000000001,
          729.1460000000001,
          777.041,
          824.9060000000001,
          872.7389999999999,
          920.538,
          968.302,
          1016.0269999999999,
          1063.714,
          1111.359,
          1158.961,
          1206.519,
          1254.029,
          1301.491,
          1348.9029999999998,
          1396.263,
          1443.569,
          1490.819,
          1538.011,
          1585.145,
          1632.217,
          1679.226,
          1726.171,
          1773.049,
          1819.858,
          1866.598,
          1913.266,
          1959.86,
          2006.378,
          2052.819,
          2099.1820000000002,
          2145.4629999999997,
          2191.661,
          2237.775,
          2283.803,
          2329.742,
          2375.592,
          2421.35,
          2467.014,
          2512.5820000000003,
          2558.053,
          2603.426,
          2648.697,
          2693.865,
          2738.928,
          2783.885,
          2828.7329999999997,
          2873.4709999999995,
          2918.097,
          2962.6079999999997,
          3007.0029999999997,
          3051.28,
          3095.438,
          3139.473,
          3183.384,
          3227.17,
          3270.828,
          3314.355,
          3357.752,
          3401.014,
          3444.14,
          3487.1290000000004,
          3529.9770000000003,
          3572.683,
          3615.2459999999996,
          3657.6620000000003,
          3699.93,
          3742.047,
          3784.012,
          3825.822,
          3867.475,
          3908.969,
          3950.301,
          3991.47,
          4032.474,
          4073.309,
          4113.973,
          4154.465,
          4194.782,
          4234.920999999999,
          4274.880999999999,
          4314.657999999999,
          4354.251,
          4393.657,
          4432.873,
          4471.897,
          4510.727,
          4549.359,
          4587.792,
          4626.022,
          4664.048,
          4701.865,
          4739.473,
          4776.867,
          4814.045999999999,
          4851.005,
          4887.744000000001,
          4924.258,
          4960.545,
          4996.602,
          5032.425,
          5068.013,
          5103.361,
          5138.467000000001,
          5173.3279999999995,
          5207.94,
          5242.3,
          5276.406,
          5310.253000000001,
          5343.838000000001,
          5377.159000000001,
          5410.21,
          5442.99,
          5475.495,
          5507.72,
          5539.6630000000005,
          5571.319,
          5602.685,
          5633.755999999999,
          5664.531,
          5695.003000000001,
          5725.169,
          5755.026,
          5784.569,
          5813.794,
          5842.696,
          5871.271,
          5899.516,
          5927.424,
          5954.993,
          5982.217,
          6009.090999999999,
          6035.611,
          6061.772,
          6087.569,
          6112.996999999999,
          6138.0509999999995,
          6162.725,
          6187.014,
          6210.9130000000005,
          6234.4169999999995,
          6257.519,
          6280.214,
          6302.496,
          6324.359,
          6345.798000000001,
          6366.805,
          6387.374,
          6407.5,
          6427.175,
          6446.393,
          6465.147,
          6483.43,
          6501.235,
          6518.554,
          6535.380999999999,
          6551.706999999999,
          6567.524,
          6582.825,
          6597.602,
          6611.846,
          6625.549,
          6638.701999999999,
          6651.297,
          6663.323,
          6674.772,
          6685.635,
          6695.901,
          6705.561,
          6714.604,
          6723.02,
          6730.797,
          6737.9259999999995,
          6744.395,
          6750.191999999999,
          6755.304,
          6759.722,
          6763.43,
          6766.4169999999995,
          6768.67,
          6770.175,
          6770.9169999999995,
          6770.884,
          6770.059,
          6768.428000000001,
          6765.976,
          6762.686,
          6758.5419999999995,
          6753.526,
          6747.6230000000005,
          6740.812,
          6733.076999999999,
          6724.398,
          6714.755,
          6704.128000000001,
          6692.496,
          6679.838000000001,
          6666.130999999999,
          6651.353,
          6635.479,
          6618.486,
          6600.347,
          6581.036999999999,
          6560.529,
          6538.795,
          6515.805,
          6491.53,
          6465.94,
          6439.001,
          6410.68,
          6380.945,
          6349.757,
          6317.08,
          6282.8769999999995,
          6247.106,
          6209.728,
          6170.698,
          6129.972,
          6087.505,
          6043.2480000000005,
          5997.151,
          5949.161,
          5899.227,
          5847.29,
          5793.2919999999995,
          5737.174,
          5678.871999999999,
          5618.32,
          5555.45,
          5490.191,
          5422.469,
          5352.2080000000005,
          5279.326999999999,
          5203.745,
          5125.375,
          5044.129,
          4959.913,
          4872.633,
          4782.191,
          4688.484,
          4591.407,
          4490.853,
          4386.712,
          4278.872,
          4167.219,
          4051.639,
          3932.015,
          3808.2340000000004,
          3680.183,
          3547.752,
          3410.8379999999997,
          3269.342,
          3123.178,
          2972.2729999999997,
          2816.565,
          2656.0190000000002,
          2490.619,
          2320.383,
          2145.36,
          1965.642,
          1781.368,
          1592.727,
          1399.969,
          1203.402,
          1003.404,
          800.4169999999999,
          594.95,
          387.575,
          178.919,
          -30.344,
          -239.50799999999998,
          -447.846,
          -654.629,
          -859.1410000000001,
          -1060.701,
          -1258.6680000000001,
          -1452.4620000000002,
          -1641.57,
          -1825.5529999999999,
          -2004.046,
          -2176.762,
          -2343.486,
          -2504.072,
          -2658.434,
          -2806.545,
          -2948.421,
          -3084.1209999999996,
          -3213.735,
          -3337.384,
          -3455.205,
          -3567.355,
          -3673.9990000000003,
          -3775.313,
          -3871.475,
          -3962.667,
          -4049.0679999999998,
          -4130.858,
          -4208.214,
          -4281.307,
          -4350.305,
          -4415.37,
          -4476.659000000001,
          -4534.323,
          -4588.505,
          -4639.346,
          -4686.977,
          -4731.527,
          -4773.116,
          -4811.862,
          -4847.873,
          -4881.2570000000005,
          -4912.1140000000005,
          -4940.541,
          -4966.627,
          -4990.460999999999,
          -5012.126,
          -5031.701,
          -5049.263,
          -5064.883,
          -5078.630999999999,
          -5090.571,
          -5100.768,
          -5109.281,
          -5116.168,
          -5121.483,
          -5125.279,
          -5127.606,
          -5128.512,
          -5128.043,
          -5126.2429999999995,
          -5123.154,
          -5118.818,
          -5113.271,
          -5106.553,
          -5098.698,
          -5089.742,
          -5079.715999999999,
          -5068.653,
          -5056.583,
          -5043.535,
          -5029.539000000001,
          -5014.62,
          -4998.805,
          -4982.12,
          -4964.588,
          -4946.233,
          -4927.0779999999995,
          -4907.145,
          -4886.454000000001,
          -4865.026,
          -4842.88,
          -4820.037,
          -4796.513,
          -4772.327,
          -4747.496,
          -4722.036,
          -4695.964,
          -4669.295999999999,
          -4642.045999999999,
          -4614.228,
          -4585.859,
          -4556.95,
          -4527.516,
          -4497.569,
          -4467.122,
          -4436.187,
          -4404.776,
          -4372.901,
          -4340.572,
          -4307.802,
          -4274.599,
          -4240.975,
          -4206.939,
          -4172.502,
          -4137.673,
          -4102.460999999999,
          -4066.875,
          -4030.9240000000004,
          -3994.616,
          -3957.96,
          -3920.9640000000004,
          -3883.636,
          -3845.9829999999997,
          -3808.014,
          -3769.735,
          -3731.153,
          -3692.277,
          -3653.112,
          -3613.665,
          -3573.9429999999998,
          -3533.952,
          -3493.699,
          -3453.1890000000003,
          -3412.429,
          -3371.425,
          -3330.1809999999996,
          -3288.705,
          -3247,
          -3205.074,
          -3162.93,
          -3120.574,
          -3078.012,
          -3035.2470000000003,
          -2992.2859999999996,
          -2949.132,
          -2905.7909999999997,
          -2862.2659999999996,
          -2818.563,
          -2774.6859999999997,
          -2730.639,
          -2686.426,
          -2642.052,
          -2597.521,
          -2552.8360000000002,
          -2508.0029999999997,
          -2463.0229999999997,
          -2417.902,
          -2372.644,
          -2327.251,
          -2281.7270000000003,
          -2236.077,
          -2190.303,
          -2144.41,
          -2098.399,
          -2052.276,
          -2006.0420000000001,
          -1959.7020000000002,
          -1913.259,
          -1866.715,
          -1820.0729999999999,
          -1773.338,
          -1726.5120000000002,
          -1679.5970000000002,
          -1632.5970000000002,
          -1585.515,
          -1538.3529999999998,
          -1491.115,
          -1443.8029999999999,
          -1396.42,
          -1348.9679999999998,
          -1301.451,
          -1253.87,
          -1206.23,
          -1158.531,
          -1110.777,
          -1062.97,
          -1015.113,
          -967.2080000000001,
          -919.258,
          -871.265,
          -823.2310000000001,
          -775.16,
          -727.052,
          -678.9110000000001,
          -630.738,
          -582.5369999999999,
          -534.309,
          -486.056,
          -437.781,
          -389.486,
          -341.17400000000004,
          -292.845,
          -244.503,
          -196.15,
          -147.787,
          -99.417,
          -51.041000000000004,
          -2.6630000000000003,
          45.717,
          94.095,
          142.471,
          190.842,
          239.205,
          287.56,
          335.904,
          384.235,
          432.551,
          480.851,
          529.131,
          577.3919999999999,
          625.629,
          673.842,
          722.029,
          770.188,
          818.317,
          866.413,
          914.4760000000001,
          962.503,
          1010.493,
          1058.444,
          1106.353,
          1154.219,
          1202.04,
          1249.815,
          1297.5410000000002,
          1345.2160000000001,
          1392.84,
          1440.4089999999999,
          1487.9229999999998,
          1535.379,
          1582.776,
          1630.111,
          1677.384,
          1724.5910000000001,
          1771.7320000000002,
          1818.805,
          1865.807,
          1912.737,
          1959.5929999999998,
          2006.3729999999998,
          2053.076,
          2099.7,
          2146.242,
          2192.701,
          2239.076,
          2285.364,
          2331.563,
          2377.672,
          2423.689,
          2469.612,
          2515.439,
          2561.1679999999997,
          2606.797,
          2652.325,
          2697.75,
          2743.07,
          2788.282,
          2833.385,
          2878.377,
          2923.257,
          2968.0209999999997,
          3012.6690000000003,
          3057.198,
          3101.607,
          3145.893,
          3190.054,
          3234.0890000000004,
          3277.995,
          3321.7709999999997,
          3365.414,
          3408.922,
          3452.2940000000003,
          3495.527,
          3538.619,
          3581.5679999999998,
          3624.373,
          3667.03,
          3709.5370000000003,
          3751.8940000000002,
          3794.0959999999995,
          3836.143,
          3878.032,
          3919.76,
          3961.327,
          4002.728,
          4043.962,
          4085.027,
          4125.92,
          4166.64,
          4207.183,
          4247.5470000000005,
          4287.73,
          4327.729,
          4367.542,
          4407.167,
          4446.601,
          4485.840999999999,
          4524.884,
          4563.73,
          4602.373,
          4640.813,
          4679.045999999999,
          4717.069,
          4754.880999999999,
          4792.477,
          4829.856,
          4867.014,
          4903.9490000000005,
          4940.657,
          4977.1359999999995,
          5013.383,
          5049.395,
          5085.168,
          5120.7,
          5155.987,
          5191.026,
          5225.815,
          5260.349,
          5294.625,
          5328.641,
          5362.393,
          5395.876,
          5429.089,
          5462.026999999999,
          5494.686,
          5527.063,
          5559.155,
          5590.956999999999,
          5622.465999999999,
          5653.677,
          5684.5869999999995,
          5715.193,
          5745.4890000000005,
          5775.471,
          5805.1359999999995,
          5834.48,
          5863.496999999999,
          5892.183000000001,
          5920.535,
          5948.547,
          5976.215,
          6003.533,
          6030.499,
          6057.105,
          6083.348000000001,
          6109.223000000001,
          6134.723000000001,
          6159.845,
          6184.581999999999,
          6208.93,
          6232.882,
          6256.433000000001,
          6279.578,
          6302.31,
          6324.6230000000005,
          6346.512,
          6367.97,
          6388.991,
          6409.568,
          6429.695,
          6449.366,
          6468.571999999999,
          6487.308000000001,
          6505.565,
          6523.3369999999995,
          6540.616999999999,
          6557.396,
          6573.6669999999995,
          6589.422,
          6604.654,
          6619.352,
          6633.509,
          6647.116,
          6660.165,
          6672.646,
          6684.549,
          6695.866,
          6706.585999999999,
          6716.7,
          6726.196999999999,
          6735.066,
          6743.298000000001,
          6750.88,
          6757.802,
          6764.052,
          6769.618,
          6774.488,
          6778.649,
          6782.088000000001,
          6784.7919999999995,
          6786.7480000000005,
          6787.941999999999,
          6788.359,
          6787.984,
          6786.803000000001,
          6784.8,
          6781.9580000000005,
          6778.2609999999995,
          6773.693,
          6768.236,
          6761.871,
          6754.581,
          6746.345,
          6737.146,
          6726.960999999999,
          6715.771,
          6703.553000000001,
          6690.285,
          6675.945,
          6660.509,
          6643.951,
          6626.246999999999,
          6607.37,
          6587.293000000001,
          6565.9890000000005,
          6543.428000000001,
          6519.58,
          6494.414000000001,
          6467.899,
          6440,
          6410.683000000001,
          6379.911999999999,
          6347.651,
          6313.86,
          6278.5,
          6241.53,
          6202.906,
          6162.5830000000005,
          6120.516,
          6076.655,
          6030.953,
          5983.354,
          5933.806,
          5882.253000000001,
          5828.635,
          5772.892,
          5714.960999999999,
          5654.776,
          5592.268,
          5527.366,
          5459.995,
          5390.08,
          5317.54,
          5242.293,
          5164.25,
          5083.323,
          4999.42,
          4912.444,
          4822.295999999999,
          4728.874,
          4632.073,
          4531.782999999999,
          4427.895,
          4320.295999999999,
          4208.869000000001,
          4093.4990000000003,
          3974.0690000000004,
          3850.4629999999997,
          3722.567,
          3590.27,
          3453.4640000000004,
          3312.05,
          3165.938,
          3015.05,
          2859.324,
          2698.717,
          2533.212,
          2362.82,
          2187.585,
          2007.592,
          1822.974,
          1633.914,
          1440.654,
          1243.497,
          1042.8110000000001,
          839.034,
          632.668,
          424.282,
          214.498,
          3.99,
          -206.535,
          -416.348,
          -624.715,
          -830.913,
          -1034.25,
          -1234.078,
          -1429.8020000000001,
          -1620.898,
          -1806.912,
          -1987.47,
          -2162.271,
          -2331.09,
          -2493.768,
          -2650.2129999999997,
          -2800.388,
          -2944.303,
          -3082.013,
          -3213.6009999999997,
          -3339.185,
          -3458.9,
          -3572.901,
          -3681.3520000000003,
          -3784.425,
          -3882.301,
          -3975.16,
          -4063.183,
          -4146.55,
          -4225.437,
          -4300.02,
          -4370.82,
          -4436.932,
          -4499.584,
          -4558.571,
          -4614.039000000001,
          -4666.127,
          -4714.971,
          -4760.6990000000005,
          -4803.431,
          -4843.287,
          -4880.377,
          -4914.809,
          -4946.684,
          -4976.099,
          -5003.147,
          -5027.916,
          -5050.49,
          -5070.9490000000005,
          -5089.37,
          -5105.826,
          -5120.387,
          -5133.1179999999995,
          -5144.084,
          -5153.345,
          -5160.96,
          -5166.983,
          -5171.468,
          -5174.465999999999,
          -5176.024,
          -5176.19,
          -5175.009,
          -5172.522,
          -5168.77,
          -5163.794,
          -5157.63,
          -5150.315,
          -5141.883,
          -5132.369000000001,
          -5121.803,
          -5110.217000000001,
          -5097.64,
          -5084.102,
          -5069.629,
          -5054.248,
          -5037.984,
          -5020.862,
          -5002.906,
          -4984.139,
          -4964.582,
          -4944.2570000000005,
          -4923.185,
          -4901.385,
          -4878.877,
          -4855.679,
          -4831.809,
          -4807.285,
          -4782.123,
          -4756.34,
          -4729.951,
          -4702.972,
          -4675.418,
          -4647.303,
          -4618.641,
          -4589.445,
          -4559.728,
          -4529.504,
          -4498.785,
          -4467.582,
          -4435.907,
          -4403.772,
          -4371.187,
          -4338.164000000001,
          -4304.713,
          -4270.844,
          -4236.566,
          -4201.89,
          -4166.8240000000005,
          -4131.378,
          -4095.5609999999997,
          -4059.382,
          -4022.848,
          -3985.968,
          -3948.75,
          -3911.203,
          -3873.3320000000003,
          -3835.147,
          -3796.6540000000005,
          -3757.86,
          -3718.772,
          -3679.3979999999997,
          -3639.743,
          -3599.815,
          -3559.618,
          -3519.1609999999996,
          -3478.448,
          -3437.486,
          -3396.28,
          -3354.837,
          -3313.1609999999996,
          -3271.258,
          -3229.134,
          -3186.7929999999997,
          -3144.241,
          -3101.4829999999997,
          -3058.5240000000003,
          -3015.368,
          -2972.02,
          -2928.485,
          -2884.7670000000003,
          -2840.8720000000003,
          -2796.802,
          -2752.563,
          -2708.159,
          -2663.593,
          -2618.871,
          -2573.996,
          -2528.971,
          -2483.801,
          -2438.49,
          -2393.041,
          -2347.458,
          -2301.744,
          -2255.904,
          -2209.94,
          -2163.857,
          -2117.656,
          -2071.343,
          -2024.9189999999999,
          -1978.389,
          -1931.756,
          -1885.021,
          -1838.19,
          -1791.264,
          -1744.247,
          -1697.142,
          -1649.9520000000002,
          -1602.6789999999999,
          -1555.326,
          -1507.8970000000002,
          -1460.394,
          -1412.819,
          -1365.1760000000002,
          -1317.467,
          -1269.695,
          -1221.862,
          -1173.971,
          -1126.025,
          -1078.025,
          -1029.976,
          -981.878,
          -933.7339999999999,
          -885.548,
          -837.321,
          -789.055,
          -740.753,
          -692.418,
          -644.0509999999999,
          -595.655,
          -547.232,
          -498.784,
          -450.314,
          -401.824,
          -353.315,
          -304.791,
          -256.253,
          -207.703,
          -159.144,
          -110.57700000000001,
          -62.005,
          -13.429,
          35.148,
          83.72399999999999,
          132.297,
          180.86599999999999,
          229.42700000000002,
          277.98,
          326.522,
          375.05199999999996,
          423.566,
          472.064,
          520.544,
          569.003,
          617.44,
          665.852,
          714.238,
          762.597,
          810.925,
          859.221,
          907.4839999999999,
          955.711,
          1003.9,
          1052.0510000000002,
          1100.16,
          1148.226,
          1196.247,
          1244.222,
          1292.1480000000001,
          1340.023,
          1387.8470000000002,
          1435.6170000000002,
          1483.33,
          1530.986,
          1578.5829999999999,
          1626.118,
          1673.59,
          1720.9979999999998,
          1768.338,
          1815.61,
          1862.8120000000001,
          1909.941,
          1956.996,
          2003.976,
          2050.877,
          2097.7,
          2144.44,
          2191.098,
          2237.6710000000003,
          2284.156,
          2330.553,
          2376.86,
          2423.073,
          2469.1929999999998,
          2515.216,
          2561.1420000000003,
          2606.967,
          2652.691,
          2698.3109999999997,
          2743.825,
          2789.232,
          2834.5290000000005,
          2879.715,
          2924.788,
          2969.745,
          3014.585,
          3059.3059999999996,
          3103.906,
          3148.383,
          3192.7340000000004,
          3236.9590000000003,
          3281.054,
          3325.018,
          3368.849,
          3412.545,
          3456.103,
          3499.522,
          3542.7990000000004,
          3585.933,
          3628.92,
          3671.76,
          3714.45,
          3756.988,
          3799.3709999999996,
          3841.597,
          3883.665,
          3925.571,
          3967.3140000000003,
          4008.8909999999996,
          4050.3,
          4091.539,
          4132.605,
          4173.496,
          4214.209,
          4254.742,
          4295.094,
          4335.26,
          4375.2390000000005,
          4415.028,
          4454.625,
          4494.027,
          4533.232,
          4572.236,
          4611.037,
          4649.633,
          4688.021,
          4726.198,
          4764.161,
          4801.907999999999,
          4839.435,
          4876.74,
          4913.819,
          4950.670999999999,
          4987.292,
          5023.678,
          5059.827,
          5095.736,
          5131.402,
          5166.821,
          5201.99,
          5236.906,
          5271.565,
          5305.965,
          5340.102,
          5373.972,
          5407.571,
          5440.898,
          5473.946,
          5506.714,
          5539.198,
          5571.392,
          5603.295,
          5634.901,
          5666.2080000000005,
          5697.21,
          5727.904,
          5758.286,
          5788.351,
          5818.096,
          5847.516,
          5876.606,
          5905.361999999999,
          5933.779,
          5961.854,
          5989.58,
          6016.953,
          6043.969,
          6070.6230000000005,
          6096.909000000001,
          6122.821999999999,
          6148.356,
          6173.508000000001,
          6198.271,
          6222.639,
          6246.608,
          6270.170999999999,
          6293.321999999999,
          6316.055,
          6338.365,
          6360.245,
          6381.689,
          6402.69,
          6423.241999999999,
          6443.3369999999995,
          6462.97,
          6482.133000000001,
          6500.819,
          6519.021,
          6536.73,
          6553.94,
          6570.643,
          6586.831,
          6602.495,
          6617.6269999999995,
          6632.219,
          6646.262,
          6659.746999999999,
          6672.665,
          6685.007,
          6696.763000000001,
          6707.923000000001,
          6718.478,
          6728.4169999999995,
          6737.729,
          6746.403,
          6754.429,
          6761.795,
          6768.49,
          6774.5019999999995,
          6779.818,
          6784.4259999999995,
          6788.314,
          6791.467,
          6793.871999999999,
          6795.515,
          6796.382,
          6796.459,
          6795.729,
          6794.178000000001,
          6791.789000000001,
          6788.545999999999,
          6784.432,
          6779.429,
          6773.519,
          6766.684,
          6758.904,
          6750.161,
          6740.434,
          6729.701,
          6717.94,
          6705.130999999999,
          6691.249,
          6676.271,
          6660.172,
          6642.927,
          6624.509,
          6604.892,
          6584.048000000001,
          6561.946999999999,
          6538.559,
          6513.854,
          6487.798000000001,
          6460.359,
          6431.504,
          6401.194,
          6369.392,
          6336.062,
          6301.161999999999,
          6264.651,
          6226.486,
          6186.621999999999,
          6145.013000000001,
          6101.61,
          6056.3640000000005,
          6009.222,
          5960.13,
          5909.031999999999,
          5855.868,
          5800.578,
          5743.098000000001,
          5683.363,
          5621.304,
          5556.848000000001,
          5489.923000000001,
          5420.451999999999,
          5348.353,
          5273.5419999999995,
          5195.935,
          5115.44,
          5031.965,
          4945.414000000001,
          4855.687,
          4762.68,
          4666.289000000001,
          4566.403,
          4462.912,
          4355.701,
          4244.656,
          4129.657,
          4010.587,
          3887.329,
          3759.7659999999996,
          3627.7870000000003,
          3491.281,
          3350.1459999999997,
          3204.29,
          3053.633,
          2898.107,
          2737.667,
          2572.29,
          2401.9829999999997,
          2226.783,
          2046.771,
          1862.0729999999999,
          1672.865,
          1479.38,
          1281.914,
          1080.829,
          876.556,
          669.59,
          460.49300000000005,
          249.887,
          38.439,
          -173.142,
          -384.12699999999995,
          -593.776,
          -801.362,
          -1006.184,
          -1207.5839999999998,
          -1404.9589999999998,
          -1597.771,
          -1785.555,
          -1967.924,
          -2144.565,
          -2315.243,
          -2479.7889999999998,
          -2638.1009999999997,
          -2790.135,
          -2935.8940000000002,
          -3075.425,
          -3208.81,
          -3336.16,
          -3457.6090000000004,
          -3573.3070000000002,
          -3683.42,
          -3788.117,
          -3887.577,
          -3981.9809999999998,
          -4071.511,
          -4156.346,
          -4236.662,
          -4312.635,
          -4384.434,
          -4452.221,
          -4516.155,
          -4576.389,
          -4633.071,
          -4686.340999999999,
          -4736.335,
          -4783.181,
          -4827.002,
          -4867.918,
          -4906.041,
          -4941.478,
          -4974.332,
          -5004.701,
          -5032.678,
          -5058.352,
          -5081.808,
          -5103.126,
          -5122.385,
          -5139.657999999999,
          -5155.015,
          -5168.523,
          -5180.246,
          -5190.248,
          -5198.583,
          -5205.31,
          -5210.481,
          -5214.148,
          -5216.361,
          -5217.165,
          -5216.606,
          -5214.727,
          -5211.569,
          -5207.1720000000005,
          -5201.5740000000005,
          -5194.812,
          -5186.92,
          -5177.932,
          -5167.8820000000005,
          -5156.798,
          -5144.712,
          -5131.653,
          -5117.648,
          -5102.723,
          -5086.906,
          -5070.22,
          -5052.689,
          -5034.337,
          -5015.186,
          -4995.258,
          -4974.572,
          -4953.15,
          -4931.01,
          -4908.1720000000005,
          -4884.653,
          -4860.472,
          -4835.644,
          -4810.187,
          -4784.117,
          -4757.448,
          -4730.197,
          -4702.377,
          -4674.002,
          -4645.087,
          -4615.644,
          -4585.687,
          -4555.226,
          -4524.276,
          -4492.847,
          -4460.951,
          -4428.6,
          -4395.803,
          -4362.572,
          -4328.917,
          -4294.847,
          -4260.373,
          -4225.504,
          -4190.249,
          -4154.617,
          -4118.616,
          -4082.256,
          -4045.545,
          -4008.49,
          -3971.1,
          -3933.382,
          -3895.344,
          -3856.993,
          -3818.337,
          -3779.382,
          -3740.135,
          -3700.603,
          -3660.7929999999997,
          -3620.71,
          -3580.361,
          -3539.7529999999997,
          -3498.8909999999996,
          -3457.781,
          -3416.428,
          -3374.8390000000004,
          -3333.0190000000002,
          -3290.973,
          -3248.7070000000003,
          -3206.225,
          -3163.533,
          -3120.635,
          -3077.538,
          -3034.244,
          -2990.759,
          -2947.0879999999997,
          -2903.235,
          -2859.205,
          -2815.0009999999997,
          -2770.6290000000004,
          -2726.092,
          -2681.3940000000002,
          -2636.539,
          -2591.532,
          -2546.376,
          -2501.076,
          -2455.634,
          -2410.055,
          -2364.342,
          -2318.498,
          -2272.528,
          -2226.435,
          -2180.223,
          -2133.893,
          -2087.451,
          -2040.899,
          -1994.24,
          -1947.4779999999998,
          -1900.616,
          -1853.656,
          -1806.602,
          -1759.457,
          -1712.224,
          -1664.905,
          -1617.504,
          -1570.024,
          -1522.4660000000001,
          -1474.835,
          -1427.132,
          -1379.36,
          -1331.523,
          -1283.622,
          -1235.661,
          -1187.642,
          -1139.566,
          -1091.438,
          -1043.259,
          -995.033,
          -946.76,
          -898.444,
          -850.087,
          -801.692,
          -753.2610000000001,
          -704.795,
          -656.298,
          -607.7719999999999,
          -559.219,
          -510.64,
          -462.039,
          -413.418,
          -364.779,
          -316.123,
          -267.453,
          -218.77200000000002,
          -170.081,
          -121.382,
          -72.678,
          -23.97,
          24.739,
          73.44800000000001,
          122.154,
          170.855,
          219.55,
          268.236,
          316.91200000000003,
          365.575,
          414.223,
          462.855,
          511.469,
          560.062,
          608.633,
          657.18,
          705.701,
          754.194,
          802.6569999999999,
          851.0880000000001,
          899.4860000000001,
          947.8480000000001,
          996.173,
          1044.4589999999998,
          1092.703,
          1140.905,
          1189.062,
          1237.172,
          1285.234,
          1333.246,
          1381.205,
          1429.111,
          1476.961,
          1524.753,
          1572.485,
          1620.1570000000002,
          1667.765,
          1715.309,
          1762.785,
          1810.193,
          1857.531,
          1904.796,
          1951.987,
          1999.1029999999998,
          2046.14,
          2093.098,
          2139.975,
          2186.768,
          2233.476,
          2280.097,
          2326.629,
          2373.07,
          2419.419,
          2465.672,
          2511.83,
          2557.89,
          2603.85,
          2649.7070000000003,
          2695.461,
          2741.1090000000004,
          2786.6490000000003,
          2832.079,
          2877.3979999999997,
          2922.603,
          2967.692,
          3012.664,
          3057.5159999999996,
          3102.2470000000003,
          3146.8540000000003,
          3191.336,
          3235.691,
          3279.915,
          3324.008,
          3367.968,
          3411.7909999999997,
          3455.4770000000003,
          3499.0229999999997,
          3542.427,
          3585.6859999999997,
          3628.7990000000004,
          3671.764,
          3714.578,
          3757.239,
          3799.745,
          3842.093,
          3884.282,
          3926.309,
          3968.172,
          4009.869,
          4051.3959999999997,
          4092.752,
          4133.935,
          4174.942,
          4215.77,
          4256.418,
          4296.8820000000005,
          4337.161,
          4377.251,
          4417.151,
          4456.857,
          4496.367,
          4535.678,
          4574.788,
          4613.694,
          4652.393,
          4690.883,
          4729.161,
          4767.224,
          4805.069,
          4842.693,
          4880.093,
          4917.267,
          4954.210999999999,
          4990.923,
          5027.398,
          5063.635,
          5099.63,
          5135.38,
          5170.8820000000005,
          5206.1320000000005,
          5241.127,
          5275.863,
          5310.338000000001,
          5344.548000000001,
          5378.4890000000005,
          5412.158,
          5445.552,
          5478.665,
          5511.496,
          5544.039000000001,
          5576.2919999999995,
          5608.25,
          5639.91,
          5671.267,
          5702.316999999999,
          5733.057,
          5763.481,
          5793.585999999999,
          5823.368,
          5852.821,
          5881.941999999999,
          5910.726,
          5939.169,
          5967.265,
          5995.009,
          6022.398,
          6049.425,
          6076.0869999999995,
          6102.3769999999995,
          6128.29,
          6153.821999999999,
          6178.965999999999,
          6203.718000000001,
          6228.071,
          6252.02,
          6275.559,
          6298.682,
          6321.382,
          6343.655,
          6365.493,
          6386.889,
          6407.838000000001,
          6428.331999999999,
          6448.365,
          6467.929,
          6487.018,
          6505.624,
          6523.74,
          6541.358,
          6558.47,
          6575.068,
          6591.144,
          6606.691,
          6621.698,
          6636.158,
          6650.062,
          6663.401,
          6676.164000000001,
          6688.344,
          6699.929,
          6710.91,
          6721.276999999999,
          6731.019,
          6740.125,
          6748.584,
          6756.3859999999995,
          6763.518,
          6769.968000000001,
          6775.724,
          6780.773,
          6785.104,
          6788.701999999999,
          6791.553000000001,
          6793.645,
          6794.9619999999995,
          6795.491,
          6795.214,
          6794.118,
          6792.186,
          6789.401999999999,
          6785.7480000000005,
          6781.206999999999,
          6775.7609999999995,
          6769.392,
          6762.081,
          6753.807,
          6744.55,
          6734.29,
          6723.004,
          6710.670999999999,
          6697.268,
          6682.77,
          6667.153,
          6650.392,
          6632.460999999999,
          6613.331999999999,
          6592.977,
          6571.369000000001,
          6548.475,
          6524.265,
          6498.706999999999,
          6471.768,
          6443.4130000000005,
          6413.606,
          6382.311,
          6349.486999999999,
          6315.097,
          6279.097,
          6241.446999999999,
          6202.098000000001,
          6161.007,
          6118.124,
          6073.399,
          6026.78,
          5978.213000000001,
          5927.642,
          5875.008000000001,
          5820.25,
          5763.303000000001,
          5704.103,
          5642.58,
          5578.6630000000005,
          5512.279,
          5443.349,
          5371.7919999999995,
          5297.526,
          5220.464,
          5140.515,
          5057.589,
          4971.585,
          4882.405,
          4789.946,
          4694.102,
          4594.763,
          4491.816,
          4385.147,
          4274.64,
          4160.177,
          4041.637,
          3918.903,
          3791.857,
          3660.384,
          3524.373,
          3383.722,
          3238.3320000000003,
          3088.12,
          2933.0190000000002,
          2772.9770000000003,
          2607.967,
          2437.991,
          2263.081,
          2083.312,
          1898.8010000000002,
          1709.72,
          1516.2920000000001,
          1318.807,
          1117.618,
          913.1469999999999,
          705.883,
          496.38199999999995,
          285.259,
          73.18,
          -139.15,
          -351,
          -561.629,
          -770.305,
          -976.32,
          -1179.009,
          -1377.756,
          -1572.014,
          -1761.307,
          -1945.235,
          -2123.475,
          -2295.78,
          -2461.972,
          -2621.94,
          -2775.63,
          -2923.039,
          -3064.2090000000003,
          -3199.216,
          -3328.167,
          -3451.192,
          -3568.4390000000003,
          -3680.072,
          -3786.258,
          -3887.176,
          -3983.007,
          -4073.929,
          -4160.124,
          -4241.77,
          -4319.039000000001,
          -4392.101,
          -4461.122,
          -4526.259,
          -4587.667,
          -4645.4929999999995,
          -4699.88,
          -4750.962,
          -4798.87,
          -4843.728,
          -4885.655,
          -4924.765,
          -4961.165,
          -4994.96,
          -5026.246,
          -5055.12,
          -5081.669,
          -5105.981,
          -5128.1359999999995,
          -5148.212,
          -5166.282999999999,
          -5182.42,
          -5196.692,
          -5209.162,
          -5219.892,
          -5228.942,
          -5236.3679999999995,
          -5242.223,
          -5246.559,
          -5249.4259999999995,
          -5250.871,
          -5250.94,
          -5249.675,
          -5247.119000000001,
          -5243.311,
          -5238.291,
          -5232.093,
          -5224.755999999999,
          -5216.311,
          -5206.791,
          -5196.229,
          -5184.653,
          -5172.094,
          -5158.579000000001,
          -5144.135,
          -5128.788,
          -5112.564,
          -5095.485,
          -5077.577,
          -5058.86,
          -5039.358,
          -5019.09,
          -4998.077,
          -4976.339,
          -4953.895,
          -4930.762,
          -4906.959,
          -4882.502,
          -4857.407999999999,
          -4831.694,
          -4805.375,
          -4778.465,
          -4750.98,
          -4722.934,
          -4694.340999999999,
          -4665.213,
          -4635.565,
          -4605.407,
          -4574.754,
          -4543.616,
          -4512.005,
          -4479.932,
          -4447.409000000001,
          -4414.445,
          -4381.052,
          -4347.2390000000005,
          -4313.016,
          -4278.392,
          -4243.378,
          -4207.981,
          -4172.210999999999,
          -4136.076,
          -4099.584,
          -4062.745,
          -4025.565,
          -3988.054,
          -3950.217,
          -3912.063,
          -3873.598,
          -3834.83,
          -3795.7659999999996,
          -3756.413,
          -3716.776,
          -3676.863,
          -3636.68,
          -3596.2329999999997,
          -3555.528,
          -3514.571,
          -3473.368,
          -3431.9240000000004,
          -3390.244,
          -3348.336,
          -3306.203,
          -3263.85,
          -3221.284,
          -3178.508,
          -3135.5290000000005,
          -3092.35,
          -3048.9759999999997,
          -3005.413,
          -2961.664,
          -2917.7340000000004,
          -2873.627,
          -2829.348,
          -2784.901,
          -2740.29,
          -2695.5190000000002,
          -2650.592,
          -2605.513,
          -2560.285,
          -2514.9139999999998,
          -2469.402,
          -2423.7529999999997,
          -2377.971,
          -2332.0589999999997,
          -2286.02,
          -2239.859,
          -2193.5789999999997,
          -2147.1820000000002,
          -2100.673,
          -2054.054,
          -2007.329,
          -1960.5,
          -1913.5720000000001,
          -1866.546,
          -1819.4270000000001,
          -1772.2160000000001,
          -1724.918,
          -1677.5339999999999,
          -1630.068,
          -1582.5220000000002,
          -1534.9,
          -1487.203,
          -1439.435,
          -1391.599,
          -1343.6970000000001,
          -1295.732,
          -1247.705,
          -1199.621,
          -1151.481,
          -1103.288,
          -1055.0439999999999,
          -1006.753,
          -958.415,
          -910.034,
          -861.612,
          -813.1510000000001,
          -764.655,
          -716.1239999999999,
          -667.561,
          -618.969,
          -570.35,
          -521.706,
          -473.039,
          -424.352,
          -375.64599999999996,
          -326.92400000000004,
          -278.187,
          -229.43900000000002,
          -180.68099999999998,
          -131.915,
          -83.14399999999999,
          -34.368,
          14.408,
          63.185,
          111.959,
          160.72799999999998,
          209.49099999999999,
          258.246,
          306.99,
          355.721,
          404.439,
          453.14,
          501.82300000000004,
          550.485,
          599.126,
          647.743,
          696.3330000000001,
          744.8960000000001,
          793.43,
          841.931,
          890.3989999999999,
          938.832,
          987.2280000000001,
          1035.5839999999998,
          1083.9,
          1132.173,
          1180.401,
          1228.583,
          1276.7169999999999,
          1324.8,
          1372.8310000000001,
          1420.809,
          1468.731,
          1516.595,
          1564.4,
          1612.144,
          1659.8239999999998,
          1707.44,
          1754.989,
          1802.47,
          1849.88,
          1897.2179999999998,
          1944.4820000000002,
          1991.67,
          2038.781,
          2085.812,
          2132.761,
          2179.627,
          2226.408,
          2273.1020000000003,
          2319.7070000000003,
          2366.221,
          2412.643,
          2458.97,
          2505.2,
          2551.333,
          2597.365,
          2643.295,
          2689.1209999999996,
          2734.841,
          2780.453,
          2825.955,
          2871.345,
          2916.6220000000003,
          2961.783,
          3006.8259999999996,
          3051.75,
          3096.551,
          3141.23,
          3185.782,
          3230.2059999999997,
          3274.5009999999997,
          3318.664,
          3362.692,
          3406.585,
          3450.34,
          3493.954,
          3537.426,
          3580.7529999999997,
          3623.933,
          3666.965,
          3709.845,
          3752.572,
          3795.143,
          3837.5570000000002,
          3879.81,
          3921.901,
          3963.828,
          4005.587,
          4047.177,
          4088.595,
          4129.839,
          4170.906,
          4211.794,
          4252.501,
          4293.024,
          4333.36,
          4373.5070000000005,
          4413.463,
          4453.224,
          4492.788,
          4532.153,
          4571.316,
          4610.274,
          4649.024,
          4687.563,
          4725.89,
          4764,
          4801.892,
          4839.562,
          4877.0070000000005,
          4914.224,
          4951.21,
          4987.962,
          5024.477,
          5060.752,
          5096.784000000001,
          5132.569,
          5168.105,
          5203.387,
          5238.413,
          5273.179,
          5307.682,
          5341.918000000001,
          5375.884,
          5409.575,
          5442.99,
          5476.121999999999,
          5508.969,
          5541.528,
          5573.794,
          5605.764,
          5637.432,
          5668.795999999999,
          5699.852,
          5730.594,
          5761.019,
          5791.121999999999,
          5820.899,
          5850.345,
          5879.456,
          5908.228,
          5936.655,
          5964.732,
          5992.456,
          6019.821,
          6046.821,
          6073.453,
          6099.709,
          6125.585999999999,
          6151.078,
          6176.179,
          6200.883000000001,
          6225.186,
          6249.08,
          6272.56,
          6295.621,
          6318.255,
          6340.456,
          6362.219,
          6383.536,
          6404.4,
          6424.806,
          6444.745,
          6464.210999999999,
          6483.196999999999,
          6501.694,
          6519.696,
          6537.194,
          6554.181,
          6570.648,
          6586.5869999999995,
          6601.99,
          6616.848000000001,
          6631.151999999999,
          6644.892,
          6658.061,
          6670.647,
          6682.642,
          6694.035,
          6704.816,
          6714.975,
          6724.501,
          6733.382,
          6741.608,
          6749.1669999999995,
          6756.047,
          6762.236,
          6767.721,
          6772.4890000000005,
          6776.526999999999,
          6779.821999999999,
          6782.36,
          6784.126,
          6785.106,
          6785.284000000001,
          6784.645,
          6783.174,
          6780.852,
          6777.665,
          6773.593000000001,
          6768.619000000001,
          6762.726,
          6755.893,
          6748.1,
          6739.328,
          6729.556,
          6718.7609999999995,
          6706.923000000001,
          6694.017,
          6680.02,
          6664.908,
          6648.656,
          6631.236,
          6612.6230000000005,
          6592.786999999999,
          6571.701,
          6549.3330000000005,
          6525.653,
          6500.629,
          6474.228,
          6446.415,
          6417.154,
          6386.409000000001,
          6354.14,
          6320.308000000001,
          6284.871,
          6247.786,
          6209.009,
          6168.493,
          6126.191,
          6082.0509999999995,
          6036.022,
          5988.05,
          5938.076999999999,
          5886.047,
          5831.898,
          5775.565,
          5716.984,
          5656.085,
          5592.797,
          5527.047,
          5458.755999999999,
          5387.844,
          5314.228,
          5237.821,
          5158.532999999999,
          5076.271,
          4990.937,
          4902.432,
          4810.653,
          4715.492,
          4616.84,
          4514.585,
          4408.611,
          4298.8009999999995,
          4185.036,
          4067.196,
          3945.1620000000003,
          3818.8140000000003,
          3688.0370000000003,
          3552.718,
          3412.75,
          3268.0359999999996,
          3118.488,
          2964.0359999999996,
          2804.623,
          2640.2209999999995,
          2470.822,
          2296.456,
          2117.192,
          1933.139,
          1744.46,
          1551.372,
          1354.156,
          1153.1580000000001,
          948.789,
          741.5310000000001,
          531.933,
          320.60200000000003,
          108.20100000000001,
          -104.568,
          -316.976,
          -528.2819999999999,
          -737.748,
          -944.6619999999999,
          -1148.351,
          -1348.191,
          -1543.6229999999998,
          -1734.1629999999998,
          -1919.3970000000002,
          -2098.994,
          -2272.692,
          -2440.3070000000002,
          -2601.716,
          -2756.8590000000004,
          -2905.724,
          -3048.348,
          -3184.801,
          -3315.1859999999997,
          -3439.6279999999997,
          -3558.2740000000003,
          -3671.283,
          -3778.823,
          -3881.072,
          -3978.2059999999997,
          -4070.408,
          -4157.856,
          -4240.726,
          -4319.196,
          -4393.2390000000005,
          -4463.6,
          -4529.86,
          -4592.366,
          -4651.266,
          -4706.702,
          -4758.811,
          -4807.723,
          -4853.563,
          -4896.451,
          -4936.501,
          -4973.821,
          -5008.515,
          -5040.684,
          -5070.420999999999,
          -5097.815,
          -5122.955,
          -5145.92,
          -5166.791,
          -5185.642,
          -5202.542,
          -5217.562,
          -5230.766,
          -5242.215999999999,
          -5251.972,
          -5260.09,
          -5266.625,
          -5271.629,
          -5275.15,
          -5277.238,
          -5277.938,
          -5277.293000000001,
          -5275.346,
          -5272.1359999999995,
          -5267.703,
          -5262.0830000000005,
          -5255.312,
          -5247.424,
          -5238.452,
          -5228.428,
          -5217.380999999999,
          -5205.342000000001,
          -5192.339,
          -5178.397,
          -5163.545,
          -5147.807,
          -5131.207,
          -5113.769,
          -5095.516,
          -5076.469,
          -5056.648,
          -5036.076,
          -5014.771,
          -4992.753,
          -4970.039000000001,
          -4946.648,
          -4922.598,
          -4897.904,
          -4872.583,
          -4846.65,
          -4820.122,
          -4793.0109999999995,
          -4765.334,
          -4737.104,
          -4708.333,
          -4679.036,
          -4649.225,
          -4618.912,
          -4588.109,
          -4556.8279999999995,
          -4525.08,
          -4492.876,
          -4460.226,
          -4427.142,
          -4393.633,
          -4359.709,
          -4325.38,
          -4290.655,
          -4255.543,
          -4220.054,
          -4184.195,
          -4147.975,
          -4111.402,
          -4074.485,
          -4037.2309999999998,
          -3999.6479999999997,
          -3961.743,
          -3923.5240000000003,
          -3884.998,
          -3846.171,
          -3807.051,
          -3767.6440000000002,
          -3727.9559999999997,
          -3687.995,
          -3647.765,
          -3607.2740000000003,
          -3566.527,
          -3525.53,
          -3484.289,
          -3442.809,
          -3401.095,
          -3359.1540000000005,
          -3316.99,
          -3274.6090000000004,
          -3232.015,
          -3189.2140000000004,
          -3146.21,
          -3103.008,
          -3059.612,
          -3016.027,
          -2972.259,
          -2928.31,
          -2884.1859999999997,
          -2839.8909999999996,
          -2795.428,
          -2750.802,
          -2706.018,
          -2661.078,
          -2615.987,
          -2570.749,
          -2525.367,
          -2479.845,
          -2434.187,
          -2388.397,
          -2342.4770000000003,
          -2296.431,
          -2250.263,
          -2203.9770000000003,
          -2157.575,
          -2111.06,
          -2064.436,
          -2017.707,
          -1970.874,
          -1923.942,
          -1876.9129999999998,
          -1829.79,
          -1782.5770000000002,
          -1735.276,
          -1687.89,
          -1640.421,
          -1592.874,
          -1545.25,
          -1497.5520000000001,
          -1449.783,
          -1401.945,
          -1354.0420000000001,
          -1306.075,
          -1258.048,
          -1209.963,
          -1161.822,
          -1113.628,
          -1065.383,
          -1017.091,
          -968.752,
          -920.37,
          -871.947,
          -823.4860000000001,
          -774.988,
          -726.456,
          -677.893,
          -629.3,
          -580.679,
          -532.034,
          -483.365,
          -434.676,
          -385.969,
          -337.245,
          -288.507,
          -239.757,
          -190.997,
          -142.22899999999998,
          -93.455,
          -44.677,
          4.103,
          52.882,
          101.65899999999999,
          150.43200000000002,
          199.19799999999998,
          247.956,
          296.704,
          345.44,
          394.161,
          442.866,
          491.55400000000003,
          540.221,
          588.867,
          637.488,
          686.084,
          734.6519999999999,
          783.191,
          831.699,
          880.173,
          928.612,
          977.0139999999999,
          1025.377,
          1073.7,
          1121.98,
          1170.215,
          1218.404,
          1266.545,
          1314.636,
          1362.675,
          1410.661,
          1458.5910000000001,
          1506.463,
          1554.277,
          1602.029,
          1649.719,
          1697.344,
          1744.902,
          1792.392,
          1839.8120000000001,
          1887.16,
          1934.433,
          1981.631,
          2028.7520000000002,
          2075.7929999999997,
          2122.752,
          2169.629,
          2216.42,
          2263.125,
          2309.74,
          2356.265,
          2402.698,
          2449.036,
          2495.277,
          2541.4210000000003,
          2587.464,
          2633.405,
          2679.242,
          2724.973,
          2770.5959999999995,
          2816.11,
          2861.511,
          2906.7990000000004,
          2951.9709999999995,
          2997.026,
          3041.96,
          3086.7729999999997,
          3131.462,
          3176.025,
          3220.46,
          3264.7659999999996,
          3308.9390000000003,
          3352.978,
          3396.881,
          3440.6459999999997,
          3484.27,
          3527.7509999999997,
          3571.0879999999997,
          3614.278,
          3657.3190000000004,
          3700.208,
          3742.9440000000004,
          3785.5240000000003,
          3827.946,
          3870.2070000000003,
          3912.3059999999996,
          3954.24,
          3996.006,
          4037.6020000000003,
          4079.026,
          4120.276,
          4161.348,
          4202.241,
          4242.9529999999995,
          4283.479,
          4323.819,
          4363.969,
          4403.927,
          4443.689,
          4483.255,
          4522.62,
          4561.782999999999,
          4600.74,
          4639.488,
          4678.026,
          4716.349,
          4754.456,
          4792.343,
          4830.0070000000005,
          4867.445,
          4904.655,
          4941.633,
          4978.376,
          5014.880999999999,
          5051.145,
          5087.165,
          5122.937,
          5158.458,
          5193.725,
          5228.735,
          5263.483,
          5297.965999999999,
          5332.182,
          5366.126,
          5399.794,
          5433.184,
          5466.29,
          5499.11,
          5531.64,
          5563.875,
          5595.812,
          5627.446,
          5658.774,
          5689.791,
          5720.493,
          5750.876,
          5780.935,
          5810.666,
          5840.065,
          5869.125,
          5897.844,
          5926.215999999999,
          5954.236999999999,
          5981.901,
          6009.203,
          6036.139,
          6062.701999999999,
          6088.888000000001,
          6114.691999999999,
          6140.108,
          6165.129,
          6189.751,
          6213.968000000001,
          6237.774,
          6261.161999999999,
          6284.126,
          6306.661,
          6328.759,
          6350.415,
          6371.621,
          6392.371,
          6412.656999999999,
          6432.473000000001,
          6451.811,
          6470.664000000001,
          6489.025,
          6506.885,
          6524.236,
          6541.071,
          6557.380999999999,
          6573.156999999999,
          6588.392,
          6603.075,
          6617.1990000000005,
          6630.754,
          6643.73,
          6656.116999999999,
          6667.906,
          6679.0869999999995,
          6689.648,
          6699.58,
          6708.87,
          6717.509,
          6725.484,
          6732.784000000001,
          6739.396,
          6745.308000000001,
          6750.507,
          6754.98,
          6758.713000000001,
          6761.693,
          6763.905,
          6765.334,
          6765.965999999999,
          6765.785,
          6764.774,
          6762.919,
          6760.201,
          6756.603,
          6752.108,
          6746.696,
          6740.351,
          6733.05,
          6724.774,
          6715.5019999999995,
          6705.213000000001,
          6693.884,
          6681.493,
          6668.016,
          6653.43,
          6637.706999999999,
          6620.821999999999,
          6602.7480000000005,
          6583.4580000000005,
          6562.922,
          6541.11,
          6517.991999999999,
          6493.536999999999,
          6467.709,
          6440.475,
          6411.799,
          6381.644,
          6349.972,
          6316.744000000001,
          6281.918000000001,
          6245.45,
          6207.297,
          6167.411,
          6125.746,
          6082.25,
          6036.874,
          5989.561,
          5940.255,
          5888.899,
          5835.431,
          5779.789000000001,
          5721.906,
          5661.714,
          5599.141,
          5534.115,
          5466.556,
          5396.385,
          5323.518,
          5247.871,
          5169.351,
          5087.865,
          5003.318,
          4915.609,
          4824.634,
          4730.287,
          4632.458,
          4531.032999999999,
          4425.899,
          4316.936,
          4204.027,
          4087.0490000000004,
          3965.882,
          3840.407,
          3710.506,
          3576.065,
          3436.975,
          3293.138,
          3144.462,
          2990.873,
          2832.313,
          2668.7459999999996,
          2500.163,
          2326.5879999999997,
          2148.08,
          1964.746,
          1776.737,
          1584.266,
          1387.602,
          1187.0819999999999,
          983.11,
          776.158,
          566.765,
          355.534,
          143.12,
          -69.78,
          -282.437,
          -494.11199999999997,
          -704.064,
          -911.578,
          -1115.973,
          -1316.6170000000002,
          -1512.945,
          -1704.4579999999999,
          -1890.737,
          -2071.433,
          -2246.282,
          -2415.083,
          -2577.71,
          -2734.09,
          -2884.2059999999997,
          -3028.087,
          -3165.798,
          -3297.438,
          -3423.1290000000004,
          -3543.012,
          -3657.2459999999996,
          -3765.995,
          -3869.4359999999997,
          -3967.744,
          -4061.1009999999997,
          -4149.683,
          -4233.67,
          -4313.234,
          -4388.545,
          -4459.768,
          -4527.063,
          -4590.584,
          -4650.479,
          -4706.892,
          -4759.959,
          -4809.811,
          -4856.573,
          -4900.366,
          -4941.303,
          -4979.495,
          -5015.045999999999,
          -5048.053,
          -5078.615,
          -5106.819,
          -5132.754,
          -5156.502,
          -5178.141,
          -5197.746,
          -5215.389,
          -5231.14,
          -5245.062,
          -5257.218000000001,
          -5267.668000000001,
          -5276.469,
          -5283.6759999999995,
          -5289.343000000001,
          -5293.516,
          -5296.246,
          -5297.576999999999,
          -5297.555,
          -5296.22,
          -5293.6140000000005,
          -5289.776,
          -5284.743,
          -5278.549,
          -5271.231,
          -5262.82,
          -5253.349,
          -5242.848,
          -5231.346,
          -5218.873,
          -5205.455,
          -5191.119000000001,
          -5175.891,
          -5159.793,
          -5142.85,
          -5125.085,
          -5106.52,
          -5087.1759999999995,
          -5067.073,
          -5046.231,
          -5024.67,
          -5002.407999999999,
          -4979.463,
          -4955.852,
          -4931.593,
          -4906.702,
          -4881.192,
          -4855.082,
          -4828.384,
          -4801.115,
          -4773.286,
          -4744.913,
          -4716.008,
          -4686.585,
          -4656.654,
          -4626.229,
          -4595.321,
          -4563.941,
          -4532.101,
          -4499.811,
          -4467.082,
          -4433.924,
          -4400.346,
          -4366.36,
          -4331.972,
          -4297.194,
          -4262.035,
          -4226.501,
          -4190.603,
          -4154.348,
          -4117.745,
          -4080.801,
          -4043.5240000000003,
          -4005.921,
          -3968,
          -3929.7690000000002,
          -3891.2329999999997,
          -3852.4,
          -3813.277,
          -3773.87,
          -3734.185,
          -3694.2290000000003,
          -3654.007,
          -3613.527,
          -3572.7929999999997,
          -3531.8109999999997,
          -3490.587,
          -3449.127,
          -3407.4359999999997,
          -3365.518,
          -3323.38,
          -3281.026,
          -3238.462,
          -3195.691,
          -3152.72,
          -3109.552,
          -3066.192,
          -3022.645,
          -2978.915,
          -2935.007,
          -2890.9240000000004,
          -2846.671,
          -2802.2529999999997,
          -2757.672,
          -2712.934,
          -2668.0409999999997,
          -2622.9990000000003,
          -2577.81,
          -2532.478,
          -2487.007,
          -2441.401,
          -2395.663,
          -2349.7960000000003,
          -2303.805,
          -2257.692,
          -2211.4610000000002,
          -2165.114,
          -2118.656,
          -2072.09,
          -2025.418,
          -1978.6429999999998,
          -1931.77,
          -1884.8,
          -1837.737,
          -1790.5829999999999,
          -1743.342,
          -1696.017,
          -1648.609,
          -1601.1229999999998,
          -1553.56,
          -1505.924,
          -1458.217,
          -1410.441,
          -1362.6,
          -1314.6960000000001,
          -1266.732,
          -1218.7089999999998,
          -1170.631,
          -1122.501,
          -1074.319,
          -1026.09,
          -977.814,
          -929.4960000000001,
          -881.1360000000001,
          -832.738,
          -784.304,
          -735.835,
          -687.335,
          -638.805,
          -590.248,
          -541.6659999999999,
          -493.061,
          -444.435,
          -395.79,
          -347.129,
          -298.454,
          -249.766,
          -201.06900000000002,
          -152.363,
          -103.65100000000001,
          -54.93600000000001,
          -6.218,
          42.498999999999995,
          91.215,
          139.92600000000002,
          188.63099999999997,
          237.328,
          286.015,
          334.69,
          383.351,
          431.996,
          480.62300000000005,
          529.231,
          577.816,
          626.379,
          674.915,
          723.425,
          771.905,
          820.3539999999999,
          868.7689999999999,
          917.15,
          965.495,
          1013.8,
          1062.065,
          1110.288,
          1158.4669999999999,
          1206.599,
          1254.684,
          1302.719,
          1350.7020000000002,
          1398.632,
          1446.506,
          1494.3239999999998,
          1542.0829999999999,
          1589.78,
          1637.4160000000002,
          1684.986,
          1732.491,
          1779.9270000000001,
          1827.293,
          1874.588,
          1921.809,
          1968.954,
          2016.0220000000002,
          2063.01,
          2109.9179999999997,
          2156.742,
          2203.482,
          2250.135,
          2296.7,
          2343.174,
          2389.555,
          2435.843,
          2482.034,
          2528.127,
          2574.12,
          2620.011,
          2665.798,
          2711.48,
          2757.054,
          2802.518,
          2847.87,
          2893.1090000000004,
          2938.2329999999997,
          2983.238,
          3028.1240000000003,
          3072.888,
          3117.5290000000005,
          3162.0440000000003,
          3206.4309999999996,
          3250.688,
          3294.813,
          3338.804,
          3382.659,
          3426.3759999999997,
          3469.952,
          3513.385,
          3556.6740000000004,
          3599.816,
          3642.808,
          3685.6490000000003,
          3728.337,
          3770.869,
          3813.242,
          3855.455,
          3897.505,
          3939.39,
          3981.107,
          4022.655,
          4064.03,
          4105.23,
          4146.253,
          4187.097,
          4227.758,
          4268.234,
          4308.523,
          4348.623,
          4388.529,
          4428.241,
          4467.755,
          4507.068,
          4546.178,
          4585.082,
          4623.778,
          4662.2609999999995,
          4700.531,
          4738.583,
          4776.414000000001,
          4814.022,
          4851.405,
          4888.557,
          4925.478,
          4962.163,
          4998.609,
          5034.813,
          5070.773,
          5106.484,
          5141.943,
          5177.148,
          5212.093,
          5246.776999999999,
          5281.195,
          5315.344,
          5349.22,
          5382.82,
          5416.14,
          5449.175,
          5481.923000000001,
          5514.38,
          5546.54,
          5578.401,
          5609.9580000000005,
          5641.206999999999,
          5672.144,
          5702.765,
          5733.064,
          5763.0380000000005,
          5792.683000000001,
          5821.993,
          5850.964,
          5879.590999999999,
          5907.869000000001,
          5935.794,
          5963.36,
          5990.562,
          6017.396,
          6043.855,
          6069.935,
          6095.629,
          6120.933000000001,
          6145.840999999999,
          6170.347,
          6194.445,
          6218.128000000001,
          6241.391,
          6264.227,
          6286.630999999999,
          6308.595,
          6330.113,
          6351.177,
          6371.781999999999,
          6391.92,
          6411.584,
          6430.766,
          6449.459,
          6467.656,
          6485.347,
          6502.525,
          6519.183000000001,
          6535.311,
          6550.901,
          6565.944,
          6580.431,
          6594.352,
          6607.6990000000005,
          6620.4619999999995,
          6632.63,
          6644.193,
          6655.142,
          6665.465,
          6675.151,
          6684.19,
          6692.57,
          6700.279,
          6707.304,
          6713.634,
          6719.255999999999,
          6724.156999999999,
          6728.321999999999,
          6731.738,
          6734.392,
          6736.268,
          6737.352,
          6737.6269999999995,
          6737.079000000001,
          6735.691,
          6733.445,
          6730.326,
          6726.314,
          6721.392,
          6715.541,
          6708.74,
          6700.97,
          6692.210999999999,
          6682.44,
          6671.6359999999995,
          6659.776,
          6646.835999999999,
          6632.7919999999995,
          6617.62,
          6601.2919999999995,
          6583.781999999999,
          6565.062,
          6545.103,
          6523.8769999999995,
          6501.351,
          6477.495,
          6452.275,
          6425.656,
          6397.603,
          6368.08,
          6337.048000000001,
          6304.467,
          6270.297,
          6234.496,
          6197.017,
          6157.815,
          6116.843000000001,
          6074.05,
          6029.3859999999995,
          5982.795999999999,
          5934.223000000001,
          5883.61,
          5830.897,
          5776.02,
          5718.914000000001,
          5659.509,
          5597.736,
          5533.52,
          5466.785,
          5397.45,
          5325.432,
          5250.646,
          5173.001,
          5092.403,
          5008.7570000000005,
          4921.963,
          4831.916,
          4738.5109999999995,
          4641.638,
          4541.183,
          4437.032999999999,
          4329.067,
          4217.166,
          4101.210999999999,
          3981.078,
          3856.6490000000003,
          3727.803,
          3594.426,
          3456.407,
          3313.645,
          3166.047,
          3013.535,
          2856.0490000000004,
          2693.548,
          2526.018,
          2353.4770000000003,
          2175.978,
          1993.62,
          1806.5510000000002,
          1614.969,
          1419.139,
          1219.384,
          1016.102,
          809.7539999999999,
          600.871,
          390.045,
          177.925,
          -34.796,
          -247.395,
          -459.12699999999995,
          -669.263,
          -877.077,
          -1081.883,
          -1283.046,
          -1479.9879999999998,
          -1672.204,
          -1859.2620000000002,
          -2040.807,
          -2216.56,
          -2386.3160000000003,
          -2549.9320000000002,
          -2707.3340000000003,
          -2858.495,
          -3003.4359999999997,
          -3142.219,
          -3274.9359999999997,
          -3401.7059999999997,
          -3522.665,
          -3637.969,
          -3747.782,
          -3852.276,
          -3951.6279999999997,
          -4046.015,
          -4135.616,
          -4220.606,
          -4301.16,
          -4377.446,
          -4449.630999999999,
          -4517.871,
          -4582.325,
          -4643.137,
          -4700.4529999999995,
          -4754.407999999999,
          -4805.134,
          -4852.758,
          -4897.398,
          -4939.17,
          -4978.184,
          -5014.544,
          -5048.349,
          -5079.695,
          -5108.675,
          -5135.372,
          -5159.871,
          -5182.25,
          -5202.587,
          -5220.95,
          -5237.41,
          -5252.031999999999,
          -5264.88,
          -5276.013000000001,
          -5285.486999999999,
          -5293.359,
          -5299.68,
          -5304.501,
          -5307.871,
          -5309.8330000000005,
          -5310.434,
          -5309.715999999999,
          -5307.719,
          -5304.481,
          -5300.0419999999995,
          -5294.436,
          -5287.698,
          -5279.861,
          -5270.956999999999,
          -5261.017,
          -5250.07,
          -5238.145,
          -5225.271,
          -5211.471,
          -5196.772,
          -5181.1990000000005,
          -5164.775,
          -5147.524,
          -5129.467000000001,
          -5110.626,
          -5091.02,
          -5070.6720000000005,
          -5049.599,
          -5027.819,
          -5005.352,
          -4982.214,
          -4958.4220000000005,
          -4933.9929999999995,
          -4908.943,
          -4883.286,
          -4857.039000000001,
          -4830.214,
          -4802.827,
          -4774.89,
          -4746.417,
          -4717.420999999999,
          -4687.916,
          -4657.91,
          -4627.418,
          -4596.45,
          -4565.018,
          -4533.1320000000005,
          -4500.803,
          -4468.041,
          -4434.856,
          -4401.258,
          -4367.255999999999,
          -4332.859,
          -4298.077,
          -4262.918,
          -4227.39,
          -4191.502,
          -4155.263,
          -4118.679,
          -4081.759,
          -4044.51,
          -4006.94,
          -3969.055,
          -3930.863,
          -3892.3709999999996,
          -3853.585,
          -3814.513,
          -3775.159,
          -3735.531,
          -3695.634,
          -3655.475,
          -3615.06,
          -3574.3940000000002,
          -3533.4829999999997,
          -3492.333,
          -3450.948,
          -3409.3340000000003,
          -3367.4970000000003,
          -3325.441,
          -3283.172,
          -3240.6940000000004,
          -3198.012,
          -3155.131,
          -3112.055,
          -3068.789,
          -3025.3379999999997,
          -2981.705,
          -2937.895,
          -2893.913,
          -2849.761,
          -2805.446,
          -2760.969,
          -2716.337,
          -2671.551,
          -2626.616,
          -2581.536,
          -2536.314,
          -2490.955,
          -2445.4610000000002,
          -2399.8360000000002,
          -2354.084,
          -2308.2070000000003,
          -2262.21,
          -2216.095,
          -2169.866,
          -2123.526,
          -2077.078,
          -2030.526,
          -1983.871,
          -1937.119,
          -1890.27,
          -1843.329,
          -1796.297,
          -1749.1789999999999,
          -1701.977,
          -1654.693,
          -1607.33,
          -1559.892,
          -1512.381,
          -1464.7979999999998,
          -1417.148,
          -1369.433,
          -1321.655,
          -1273.816,
          -1225.92,
          -1177.968,
          -1129.964,
          -1081.9089999999999,
          -1033.807,
          -985.658,
          -937.467,
          -889.235,
          -840.9639999999999,
          -792.6560000000001,
          -744.315,
          -695.942,
          -647.54,
          -599.11,
          -550.655,
          -502.17699999999996,
          -453.67800000000005,
          -405.16,
          -356.626,
          -308.078,
          -259.517,
          -210.946,
          -162.36700000000002,
          -113.78200000000001,
          -65.193,
          -16.601,
          31.99,
          80.58,
          129.165,
          177.745,
          226.317,
          274.879,
          323.42900000000003,
          371.965,
          420.486,
          468.98900000000003,
          517.4730000000001,
          565.935,
          614.373,
          662.7869999999999,
          711.173,
          759.5310000000001,
          807.857,
          856.1510000000001,
          904.41,
          952.633,
          1000.818,
          1048.962,
          1097.0639999999999,
          1145.122,
          1193.135,
          1241.1,
          1289.015,
          1336.88,
          1384.691,
          1432.4470000000001,
          1480.1470000000002,
          1527.787,
          1575.368,
          1622.886,
          1670.34,
          1717.7279999999998,
          1765.0479999999998,
          1812.299,
          1859.4779999999998,
          1906.5829999999999,
          1953.614,
          2000.567,
          2047.442,
          2094.236,
          2140.947,
          2187.573,
          2234.114,
          2280.565,
          2326.927,
          2373.197,
          2419.373,
          2465.453,
          2511.435,
          2557.317,
          2603.098,
          2648.775,
          2694.347,
          2739.8109999999997,
          2785.1659999999997,
          2830.41,
          2875.54,
          2920.555,
          2965.453,
          3010.2309999999998,
          3054.887,
          3099.421,
          3143.828,
          3188.1090000000004,
          3232.259,
          3276.278,
          3320.163,
          3363.9120000000003,
          3407.5229999999997,
          3450.994,
          3494.322,
          3537.506,
          3580.5429999999997,
          3623.43,
          3666.167,
          3708.75,
          3751.178,
          3793.447,
          3835.5559999999996,
          3877.502,
          3919.283,
          3960.897,
          4002.34,
          4043.612,
          4084.7090000000003,
          4125.628,
          4166.3679999999995,
          4206.9259999999995,
          4247.299,
          4287.484,
          4327.48,
          4367.282999999999,
          4406.891,
          4446.302,
          4485.5109999999995,
          4524.518,
          4563.318,
          4601.909000000001,
          4640.288,
          4678.4529999999995,
          4716.4,
          4754.126,
          4791.629,
          4828.905,
          4865.952,
          4902.766,
          4939.345,
          4975.684,
          5011.781,
          5047.6320000000005,
          5083.235,
          5118.585,
          5153.68,
          5188.515,
          5223.088,
          5257.395,
          5291.432,
          5325.196,
          5358.683000000001,
          5391.889,
          5424.81,
          5457.441999999999,
          5489.781999999999,
          5521.825,
          5553.568,
          5585.005999999999,
          5616.135,
          5646.95,
          5677.4490000000005,
          5707.624,
          5737.475,
          5766.993,
          5796.1759999999995,
          5825.018,
          5853.515,
          5881.661999999999,
          5909.453,
          5936.885,
          5963.951,
          5990.646,
          6016.965,
          6042.903,
          6068.454000000001,
          6093.611999999999,
          6118.371999999999,
          6142.728,
          6166.673000000001,
          6190.201,
          6213.307,
          6235.984,
          6258.226,
          6280.025,
          6301.376,
          6322.271,
          6342.703,
          6362.665,
          6382.149,
          6401.148,
          6419.655,
          6437.661,
          6455.159000000001,
          6472.14,
          6488.596,
          6504.519,
          6519.899,
          6534.728,
          6548.996,
          6562.694,
          6575.813,
          6588.343000000001,
          6600.273,
          6611.593000000001,
          6622.2919999999995,
          6632.36,
          6641.786,
          6650.557,
          6658.6630000000005,
          6666.090999999999,
          6672.829000000001,
          6678.8640000000005,
          6684.184,
          6688.774,
          6692.621999999999,
          6695.713000000001,
          6698.031999999999,
          6699.564,
          6700.295,
          6700.2080000000005,
          6699.286999999999,
          6697.516,
          6694.8769999999995,
          6691.353,
          6686.9259999999995,
          6681.575,
          6675.283,
          6668.028,
          6659.791,
          6650.5509999999995,
          6640.284000000001,
          6628.969,
          6616.5830000000005,
          6603.1,
          6588.496,
          6572.745,
          6555.821,
          6537.696,
          6518.34,
          6497.726,
          6475.821999999999,
          6452.596,
          6428.015,
          6402.045999999999,
          6374.653,
          6345.8,
          6315.448,
          6283.558000000001,
          6250.09,
          6215,
          6178.244000000001,
          6139.779,
          6099.554,
          6057.52,
          6013.6269999999995,
          5967.821,
          5920.045999999999,
          5870.244000000001,
          5818.355,
          5764.315,
          5708.062,
          5649.524,
          5588.632,
          5525.314,
          5459.491999999999,
          5391.085,
          5320.013000000001,
          5246.188,
          5169.521,
          5089.919,
          5007.287,
          4921.524,
          4832.528,
          4740.191,
          4644.404,
          4545.056,
          4442.029,
          4335.206,
          4224.467000000001,
          4109.692,
          3990.757,
          3867.5429999999997,
          3739.928,
          3607.798,
          3471.039,
          3329.5490000000004,
          3183.232,
          3032.01,
          2875.8140000000003,
          2714.6040000000003,
          2548.361,
          2377.094,
          2200.855,
          2019.731,
          1833.864,
          1643.444,
          1448.724,
          1250.021,
          1047.72,
          842.2719999999999,
          634.198,
          424.082,
          212.563,
          0.32799999999999996,
          -211.905,
          -423.398,
          -633.413,
          -841.2280000000001,
          -1046.153,
          -1247.547,
          -1444.8229999999999,
          -1637.47,
          -1825.043,
          -2007.182,
          -2183.595,
          -2354.067,
          -2518.449,
          -2676.657,
          -2828.655,
          -2974.46,
          -3114.1259999999997,
          -3247.74,
          -3375.4159999999997,
          -3497.289,
          -3613.51,
          -3724.239,
          -3829.6479999999997,
          -3929.91,
          -4025.202,
          -4115.702,
          -4201.584,
          -4283.021,
          -4360.219,
          -4433.232,
          -4502.329000000001,
          -4567.629,
          -4629.279,
          -4687.420999999999,
          -4742.195,
          -4793.73,
          -4842.152,
          -4887.582,
          -4930.134,
          -4969.919,
          -5007.04,
          -5041.599,
          -5073.69,
          -5103.405,
          -5130.83,
          -5156.049,
          -5179.141,
          -5200.181,
          -5219.241,
          -5236.391,
          -5251.695,
          -5265.217,
          -5277.018,
          -5287.154,
          -5295.68,
          -5302.65,
          -5308.113,
          -5312.118,
          -5314.71,
          -5315.935,
          -5315.834,
          -5314.4490000000005,
          -5311.818,
          -5307.98,
          -5302.969,
          -5296.821,
          -5289.569,
          -5281.245,
          -5271.879,
          -5261.5019999999995,
          -5250.143,
          -5237.8279999999995,
          -5224.584,
          -5210.436,
          -5195.409000000001,
          -5179.528,
          -5162.814,
          -5145.29,
          -5126.977,
          -5107.896,
          -5088.069,
          -5067.512,
          -5046.244000000001,
          -5024.285,
          -5001.651,
          -4978.36,
          -4954.428,
          -4929.87,
          -4904.702,
          -4878.94,
          -4852.597,
          -4825.688,
          -4798.226,
          -4770.225,
          -4741.696,
          -4712.653,
          -4683.108,
          -4653.073,
          -4622.559,
          -4591.577,
          -4560.138,
          -4528.253,
          -4495.932,
          -4463.184,
          -4430.021,
          -4396.45,
          -4362.482,
          -4328.125,
          -4293.387,
          -4258.279,
          -4222.807,
          -4186.98,
          -4150.806,
          -4114.293,
          -4077.448,
          -4040.2790000000005,
          -4002.7929999999997,
          -3964.9970000000003,
          -3926.897,
          -3888.5009999999997,
          -3849.815,
          -3810.845,
          -3771.599,
          -3732.0809999999997,
          -3692.298,
          -3652.256,
          -3611.961,
          -3571.4179999999997,
          -3530.633,
          -3489.611,
          -3448.357,
          -3406.8779999999997,
          -3365.177,
          -3323.26,
          -3281.132,
          -3238.797,
          -3196.261,
          -3153.527,
          -3110.6009999999997,
          -3067.487,
          -3024.1890000000003,
          -2980.711,
          -2937.059,
          -2893.235,
          -2849.244,
          -2805.09,
          -2760.777,
          -2716.309,
          -2671.6890000000003,
          -2626.922,
          -2582.011,
          -2536.96,
          -2491.771,
          -2446.45,
          -2400.998,
          -2355.42,
          -2309.719,
          -2263.8979999999997,
          -2217.9610000000002,
          -2171.91,
          -2125.75,
          -2079.482,
          -2033.11,
          -1986.6370000000002,
          -1940.066,
          -1893.4,
          -1846.642,
          -1799.795,
          -1752.861,
          -1705.844,
          -1658.746,
          -1611.569,
          -1564.318,
          -1516.993,
          -1469.598,
          -1422.136,
          -1374.608,
          -1327.019,
          -1279.369,
          -1231.661,
          -1183.899,
          -1136.0839999999998,
          -1088.219,
          -1040.306,
          -992.3480000000001,
          -944.347,
          -896.305,
          -848.2239999999999,
          -800.1080000000001,
          -751.957,
          -703.7739999999999,
          -655.562,
          -607.323,
          -559.059,
          -510.77099999999996,
          -462.463,
          -414.13599999999997,
          -365.793,
          -317.435,
          -269.064,
          -220.68400000000003,
          -172.295,
          -123.899,
          -75.5,
          -27.098000000000003,
          21.304000000000002,
          69.704,
          118.101,
          166.49099999999999,
          214.875,
          263.248,
          311.61,
          359.958,
          408.291,
          456.60699999999997,
          504.903,
          553.178,
          601.43,
          649.6569999999999,
          697.8580000000001,
          746.03,
          794.171,
          842.279,
          890.3539999999999,
          938.3919999999999,
          986.3919999999999,
          1034.353,
          1082.272,
          1130.147,
          1177.9769999999999,
          1225.76,
          1273.493,
          1321.1760000000002,
          1368.806,
          1416.381,
          1463.901,
          1511.362,
          1558.7620000000002,
          1606.101,
          1653.3770000000002,
          1700.586,
          1747.729,
          1794.8020000000001,
          1841.8039999999999,
          1888.733,
          1935.5870000000002,
          1982.365,
          2029.0639999999999,
          2075.683,
          2122.22,
          2168.672,
          2215.0389999999998,
          2261.3179999999998,
          2307.507,
          2353.604,
          2399.6079999999997,
          2445.5170000000003,
          2491.328,
          2537.04,
          2582.651,
          2628.159,
          2673.562,
          2718.857,
          2764.0440000000003,
          2809.12,
          2854.083,
          2898.9309999999996,
          2943.6620000000003,
          2988.2740000000003,
          3032.765,
          3077.133,
          3121.3759999999997,
          3165.491,
          3209.478,
          3253.333,
          3297.055,
          3340.6409999999996,
          3384.09,
          3427.3990000000003,
          3470.565,
          3513.5879999999997,
          3556.4640000000004,
          3599.192,
          3641.768,
          3684.192,
          3726.46,
          3768.57,
          3810.52,
          3852.308,
          3893.9309999999996,
          3935.387,
          3976.673,
          4017.7870000000003,
          4058.7270000000003,
          4099.49,
          4140.073,
          4180.475,
          4220.692,
          4260.721,
          4300.562,
          4340.209,
          4379.662,
          4418.917,
          4457.972,
          4496.823,
          4535.468,
          4573.905,
          4612.13,
          4650.14,
          4687.933,
          4725.505,
          4762.854,
          4799.976,
          4836.8679999999995,
          4873.528,
          4909.952,
          4946.137,
          4982.08,
          5017.776,
          5053.224,
          5088.42,
          5123.359,
          5158.04,
          5192.458,
          5226.609,
          5260.49,
          5294.098000000001,
          5327.428000000001,
          5360.476,
          5393.24,
          5425.714,
          5457.895,
          5489.78,
          5521.363,
          5552.64,
          5583.608,
          5614.262,
          5644.598000000001,
          5674.611,
          5704.297,
          5733.65,
          5762.668000000001,
          5791.343000000001,
          5819.673000000001,
          5847.651,
          5875.273,
          5902.534000000001,
          5929.428000000001,
          5955.95,
          5982.095,
          6007.857,
          6033.23,
          6058.21,
          6082.789000000001,
          6106.9619999999995,
          6130.723000000001,
          6154.066,
          6176.985,
          6199.472,
          6221.522,
          6243.1269999999995,
          6264.281999999999,
          6284.978,
          6305.209,
          6324.967,
          6344.246,
          6363.036999999999,
          6381.331999999999,
          6399.124,
          6416.404,
          6433.165,
          6449.397,
          6465.092,
          6480.241,
          6494.835,
          6508.8640000000005,
          6522.319,
          6535.191,
          6547.469,
          6559.143,
          6570.203,
          6580.6359999999995,
          6590.434,
          6599.5830000000005,
          6608.073,
          6615.891,
          6623.026,
          6629.465,
          6635.194,
          6640.201,
          6644.473000000001,
          6647.994000000001,
          6650.75,
          6652.727,
          6653.909000000001,
          6654.281,
          6653.826999999999,
          6652.53,
          6650.3730000000005,
          6647.338000000001,
          6643.408,
          6638.564,
          6632.785,
          6626.053000000001,
          6618.347,
          6609.646,
          6599.928000000001,
          6589.170999999999,
          6577.352,
          6564.445,
          6550.427,
          6535.271,
          6518.953,
          6501.443,
          6482.715,
          6462.736999999999,
          6441.479,
          6418.911999999999,
          6395.001,
          6369.713000000001,
          6343.014,
          6314.865,
          6285.231,
          6254.071,
          6221.345,
          6187.012,
          6151.026,
          6113.343000000001,
          6073.915,
          6032.694,
          5989.629,
          5944.664000000001,
          5897.746,
          5848.818,
          5797.818,
          5744.686,
          5689.355,
          5631.759,
          5571.826999999999,
          5509.486,
          5444.661,
          5377.271,
          5307.234,
          5234.465999999999,
          5158.876,
          5080.373,
          4998.861,
          4914.2390000000005,
          4826.407999999999,
          4735.259,
          4640.684,
          4542.57,
          4440.8009999999995,
          4335.2609999999995,
          4225.829000000001,
          4112.383,
          3994.802,
          3872.9640000000004,
          3746.7490000000003,
          3616.038,
          3480.7209999999995,
          3340.69,
          3195.85,
          3046.117,
          2891.423,
          2731.72,
          2566.987,
          2397.2270000000003,
          2222.486,
          2042.845,
          1858.434,
          1669.4379999999999,
          1476.101,
          1278.726,
          1077.6889999999999,
          873.431,
          666.461,
          457.352,
          246.737,
          35.292,
          -176.269,
          -387.215,
          -596.807,
          -804.323,
          -1009.071,
          -1210.404,
          -1407.7320000000002,
          -1600.531,
          -1788.354,
          -1970.8239999999998,
          -2147.646,
          -2318.593,
          -2483.509,
          -2642.2990000000004,
          -2794.921,
          -2941.385,
          -3081.738,
          -3216.0640000000003,
          -3344.47,
          -3467.086,
          -3584.062,
          -3695.555,
          -3801.732,
          -3902.7670000000003,
          -3998.833,
          -4090.107,
          -4176.762,
          -4258.971,
          -4336.901,
          -4410.717000000001,
          -4480.575,
          -4546.6320000000005,
          -4609.034000000001,
          -4667.925,
          -4723.441,
          -4775.713,
          -4824.8679999999995,
          -4871.024,
          -4914.299,
          -4954.799,
          -4992.630999999999,
          -5027.896,
          -5060.688,
          -5091.098,
          -5119.213,
          -5145.1179999999995,
          -5168.889,
          -5190.603,
          -5210.334,
          -5228.149,
          -5244.1140000000005,
          -5258.2919999999995,
          -5270.744000000001,
          -5281.526999999999,
          -5290.696,
          -5298.303000000001,
          -5304.4,
          -5309.034000000001,
          -5312.2519999999995,
          -5314.098000000001,
          -5314.6140000000005,
          -5313.842,
          -5311.82,
          -5308.5869999999995,
          -5304.178000000001,
          -5298.628000000001,
          -5291.969,
          -5284.235,
          -5275.456999999999,
          -5265.6630000000005,
          -5254.883000000001,
          -5243.144,
          -5230.472,
          -5216.894,
          -5202.433,
          -5187.113,
          -5170.959,
          -5153.991,
          -5136.231,
          -5117.7,
          -5098.418,
          -5078.404,
          -5057.677,
          -5036.255,
          -5014.155,
          -4991.395,
          -4967.991,
          -4943.958,
          -4919.313,
          -4894.07,
          -4868.2429999999995,
          -4841.847,
          -4814.896,
          -4787.403,
          -4759.379,
          -4730.839,
          -4701.794,
          -4672.255,
          -4642.235,
          -4611.745,
          -4580.795,
          -4549.396,
          -4517.558,
          -4485.292,
          -4452.606,
          -4419.5109999999995,
          -4386.015,
          -4352.129,
          -4317.86
         ],
         "z": [
          -1599.129,
          -1737.642,
          -1875.378,
          -2012.057,
          -2147.652,
          -2282.145,
          -2415.515,
          -2547.751,
          -2678.841,
          -2808.777,
          -2937.551,
          -3065.16,
          -3191.6,
          -3316.87,
          -3440.97,
          -3563.902,
          -3685.6690000000003,
          -3806.272,
          -3925.717,
          -4044.009,
          -4161.152,
          -4277.151,
          -4392.016,
          -4505.751,
          -4618.3640000000005,
          -4729.863,
          -4840.254,
          -4949.5470000000005,
          -5057.748,
          -5164.866,
          -5270.911,
          -5375.889,
          -5479.809,
          -5582.681,
          -5684.5109999999995,
          -5785.31,
          -5885.084,
          -5983.843000000001,
          -6081.595,
          -6178.35,
          -6274.1140000000005,
          -6368.896,
          -6462.704000000001,
          -6555.548000000001,
          -6647.433000000001,
          -6738.369000000001,
          -6828.3640000000005,
          -6917.424,
          -7005.559,
          -7092.775,
          -7179.081,
          -7264.482,
          -7348.988,
          -7432.605,
          -7515.34,
          -7597.2,
          -7678.191,
          -7758.321999999999,
          -7837.599,
          -7916.028,
          -7993.616,
          -8070.369000000001,
          -8146.294,
          -8221.396999999999,
          -8295.683,
          -8369.16,
          -8441.832,
          -8513.706,
          -8584.788,
          -8655.083,
          -8724.597,
          -8793.336,
          -8861.304,
          -8928.507,
          -8994.951,
          -9060.64,
          -9125.58,
          -9189.775,
          -9253.23,
          -9315.952,
          -9377.943000000001,
          -9439.209,
          -9499.755,
          -9559.584,
          -9618.702,
          -9677.113000000001,
          -9734.821,
          -9791.83,
          -9848.144,
          -9903.768,
          -9958.706,
          -10012.962,
          -10066.539,
          -10119.442,
          -10171.675,
          -10223.24,
          -10274.142,
          -10324.384,
          -10373.971,
          -10422.904,
          -10471.189,
          -10518.827,
          -10565.823,
          -10612.18,
          -10657.902,
          -10702.99,
          -10747.448999999999,
          -10791.282,
          -10834.491000000002,
          -10877.08,
          -10919.051000000001,
          -10960.408000000001,
          -11001.153,
          -11041.288999999999,
          -11080.818000000001,
          -11119.743999999999,
          -11158.069,
          -11195.796,
          -11232.928,
          -11269.466,
          -11305.413999999999,
          -11340.774,
          -11375.548,
          -11409.739,
          -11443.348999999998,
          -11476.38,
          -11508.835,
          -11540.715,
          -11572.024,
          -11602.763,
          -11632.935,
          -11662.54,
          -11691.582,
          -11720.063,
          -11747.983999999999,
          -11775.348999999998,
          -11802.157,
          -11828.412,
          -11854.115,
          -11879.268,
          -11903.872,
          -11927.931,
          -11951.445,
          -11974.415,
          -11996.845,
          -12018.735,
          -12040.086000000001,
          -12060.902,
          -12081.181999999999,
          -12100.93,
          -12120.146,
          -12138.831,
          -12156.988000000001,
          -12174.617,
          -12191.721000000001,
          -12208.3,
          -12224.356000000002,
          -12239.889,
          -12254.903,
          -12269.396999999999,
          -12283.373,
          -12296.832,
          -12309.776000000002,
          -12322.205,
          -12334.121000000001,
          -12345.525,
          -12356.419,
          -12366.802,
          -12376.677,
          -12386.044,
          -12394.905,
          -12403.26,
          -12411.11,
          -12418.457,
          -12425.301000000001,
          -12431.643,
          -12437.485,
          -12442.826000000001,
          -12447.668,
          -12452.002,
          -12455.848,
          -12459.198,
          -12462.052,
          -12464.411,
          -12466.275,
          -12467.646999999999,
          -12468.525,
          -12468.911,
          -12468.805,
          -12468.208999999999,
          -12467.122,
          -12465.545,
          -12463.48,
          -12460.926000000001,
          -12457.883999999998,
          -12454.355,
          -12450.339,
          -12445.836000000001,
          -12440.847,
          -12435.374,
          -12429.415,
          -12422.972,
          -12416.045,
          -12408.633999999998,
          -12400.74,
          -12392.363000000001,
          -12383.503,
          -12374.161,
          -12364.338,
          -12354.032,
          -12343.245,
          -12331.976999999999,
          -12320.228000000001,
          -12307.998,
          -12295.288,
          -12282.097,
          -12268.427,
          -12254.277,
          -12239.646999999999,
          -12224.537,
          -12208.948,
          -12192.88,
          -12176.332,
          -12159.303999999998,
          -12141.798,
          -12123.812,
          -12105.347,
          -12086.403,
          -12066.98,
          -12047.077,
          -12026.695,
          -12005.833,
          -11984.492,
          -11962.671999999999,
          -11940.372,
          -11917.591999999999,
          -11894.332,
          -11870.591,
          -11846.371000000001,
          -11821.67,
          -11796.488000000001,
          -11770.825,
          -11744.68,
          -11718.055,
          -11690.947,
          -11663.357,
          -11635.285,
          -11606.73,
          -11577.691,
          -11548.169,
          -11518.163,
          -11487.673,
          -11456.698999999999,
          -11425.239,
          -11393.293,
          -11360.861,
          -11327.943000000001,
          -11294.538,
          -11260.645,
          -11226.263,
          -11191.393,
          -11156.034,
          -11120.185,
          -11083.845,
          -11047.014,
          -11009.691,
          -10971.876,
          -10933.568000000001,
          -10894.765,
          -10855.468,
          -10815.675,
          -10775.386999999999,
          -10734.601999999999,
          -10693.319,
          -10651.538,
          -10609.257,
          -10566.476999999999,
          -10523.195,
          -10479.411,
          -10435.125,
          -10390.334,
          -10345.039,
          -10299.239,
          -10252.931,
          -10206.116,
          -10158.792,
          -10110.959,
          -10062.614,
          -10013.758,
          -9964.39,
          -9914.507,
          -9864.108,
          -9813.194,
          -9761.761,
          -9709.81,
          -9657.34,
          -9604.347,
          -9550.833,
          -9496.794,
          -9442.23,
          -9387.14,
          -9331.521999999999,
          -9275.375,
          -9218.697,
          -9161.488000000001,
          -9103.745,
          -9045.466999999999,
          -8986.653,
          -8927.302,
          -8867.411,
          -8806.979,
          -8746.005,
          -8684.485999999999,
          -8622.423,
          -8559.812,
          -8496.652,
          -8432.942,
          -8368.679,
          -8303.863000000001,
          -8238.491,
          -8172.562,
          -8106.0740000000005,
          -8039.025,
          -7971.414000000001,
          -7903.238,
          -7834.496,
          -7765.185,
          -7695.305,
          -7624.853,
          -7553.828,
          -7482.226,
          -7410.047,
          -7337.2880000000005,
          -7263.948,
          -7190.024,
          -7115.515,
          -7040.419,
          -6964.734,
          -6888.456999999999,
          -6811.585999999999,
          -6734.12,
          -6656.057,
          -6577.394,
          -6498.13,
          -6418.262,
          -6337.789000000001,
          -6256.7080000000005,
          -6175.017,
          -6092.715,
          -6009.8,
          -5926.269,
          -5842.121,
          -5757.354,
          -5671.965,
          -5585.954000000001,
          -5499.316999999999,
          -5412.054,
          -5324.1630000000005,
          -5235.642,
          -5146.488,
          -5056.702,
          -4966.281,
          -4875.224,
          -4783.53,
          -4691.197,
          -4598.225,
          -4504.612,
          -4410.358,
          -4315.462,
          -4219.923,
          -4123.741,
          -4026.915,
          -3929.447,
          -3831.335,
          -3732.5809999999997,
          -3633.185,
          -3533.1490000000003,
          -3432.474,
          -3331.1609999999996,
          -3229.2129999999997,
          -3126.632,
          -3023.421,
          -2919.583,
          -2815.123,
          -2710.045,
          -2604.354,
          -2498.0570000000002,
          -2391.158,
          -2283.667,
          -2175.592,
          -2066.9410000000003,
          -1957.726,
          -1847.9579999999999,
          -1737.649,
          -1626.8129999999999,
          -1515.4679999999998,
          -1403.629,
          -1291.316,
          -1178.55,
          -1065.355,
          -951.7560000000001,
          -837.7819999999999,
          -723.4639999999999,
          -608.835,
          -493.935,
          -378.80400000000003,
          -263.48900000000003,
          -148.039,
          -32.510999999999996,
          83.035,
          198.53099999999998,
          313.904,
          429.07300000000004,
          543.948,
          658.43,
          772.4119999999999,
          885.775,
          998.387,
          1110.104,
          1220.769,
          1330.2060000000001,
          1438.226,
          1544.618,
          1649.154,
          1751.582,
          1851.628,
          1948.995,
          2043.358,
          2134.364,
          2221.639,
          2304.774,
          2383.3379999999997,
          2456.8720000000003,
          2524.8979999999997,
          2586.915,
          2642.4120000000003,
          2690.8720000000003,
          2731.782,
          2764.643,
          2788.985,
          2804.3759999999997,
          2810.4440000000004,
          2806.884,
          2793.4770000000003,
          2770.095,
          2736.715,
          2693.415,
          2640.382,
          2577.8979999999997,
          2506.337,
          2426.15,
          2337.85,
          2241.998,
          2139.186,
          2030.016,
          1915.1,
          1795.036,
          1670.401,
          1541.751,
          1409.605,
          1274.453,
          1136.744,
          996.8919999999999,
          855.2760000000001,
          712.24,
          568.092,
          423.111,
          277.548,
          131.624,
          -14.462,
          -160.532,
          -306.432,
          -452.022,
          -597.181,
          -741.802,
          -885.79,
          -1029.062,
          -1171.547,
          -1313.183,
          -1453.914,
          -1593.694,
          -1732.481,
          -1870.2420000000002,
          -2006.9460000000001,
          -2142.5679999999998,
          -2277.087,
          -2410.487,
          -2542.7529999999997,
          -2673.873,
          -2803.84,
          -2932.6459999999997,
          -3060.2859999999996,
          -3186.758,
          -3312.0609999999997,
          -3436.195,
          -3559.1609999999996,
          -3680.961,
          -3801.599,
          -3921.079,
          -4039.403,
          -4156.581,
          -4272.616,
          -4387.515,
          -4501.285,
          -4613.933,
          -4725.465999999999,
          -4835.892,
          -4945.219,
          -5053.455,
          -5160.608,
          -5266.687,
          -5371.7,
          -5475.655,
          -5578.56,
          -5680.425,
          -5781.257,
          -5881.066,
          -5979.859,
          -6077.645,
          -6174.433000000001,
          -6270.231,
          -6365.047,
          -6458.889,
          -6551.765,
          -6643.683000000001,
          -6734.653,
          -6824.68,
          -6913.774,
          -7001.941999999999,
          -7089.191,
          -7175.528,
          -7260.963000000001,
          -7345.501,
          -7429.149,
          -7511.916,
          -7593.808000000001,
          -7674.831999999999,
          -7754.995,
          -7834.303000000001,
          -7912.764,
          -7990.383000000001,
          -8067.1669999999995,
          -8143.1230000000005,
          -8218.257,
          -8292.574,
          -8366.081,
          -8438.784,
          -8510.689,
          -8581.801,
          -8652.127,
          -8721.671,
          -8790.44,
          -8858.438,
          -8925.671,
          -8992.145,
          -9057.863000000001,
          -9122.832,
          -9187.056999999999,
          -9250.543,
          -9313.293,
          -9375.314,
          -9436.609,
          -9497.184000000001,
          -9557.042,
          -9616.189,
          -9674.629,
          -9732.365,
          -9789.402,
          -9845.745,
          -9901.398000000001,
          -9956.364,
          -10010.648000000001,
          -10064.254,
          -10117.185,
          -10169.445,
          -10221.038,
          -10271.968,
          -10322.238000000001,
          -10371.851999999999,
          -10420.813,
          -10469.125,
          -10516.791000000001,
          -10563.815,
          -10610.198999999999,
          -10655.948,
          -10701.063999999998,
          -10745.55,
          -10789.409,
          -10832.645,
          -10875.261,
          -10917.258999999998,
          -10958.642,
          -10999.413999999999,
          -11039.576000000001,
          -11079.132,
          -11118.083999999999,
          -11156.436000000002,
          -11194.188999999998,
          -11231.347,
          -11267.912,
          -11303.886,
          -11339.271999999999,
          -11374.072,
          -11408.288999999999,
          -11441.923999999999,
          -11474.981000000002,
          -11507.462,
          -11539.368,
          -11570.703000000001,
          -11601.466999999999,
          -11631.663,
          -11661.295,
          -11690.363000000001,
          -11718.868999999999,
          -11746.816,
          -11774.205,
          -11801.038999999999,
          -11827.319,
          -11853.046999999999,
          -11878.225,
          -11902.854,
          -11926.938,
          -11950.476,
          -11973.472,
          -11995.926000000001,
          -12017.84,
          -12039.216999999999,
          -12060.056999999999,
          -12080.362,
          -12100.133999999998,
          -12119.375,
          -12138.085,
          -12156.266000000001,
          -12173.919,
          -12191.046999999999,
          -12207.65,
          -12223.73,
          -12239.288,
          -12254.326000000001,
          -12268.844,
          -12282.844,
          -12296.328000000001,
          -12309.295,
          -12321.748,
          -12333.688,
          -12345.116000000002,
          -12356.033000000001,
          -12366.441,
          -12376.339,
          -12385.73,
          -12394.614,
          -12402.993,
          -12410.867,
          -12418.237,
          -12425.105,
          -12431.47,
          -12437.335,
          -12442.7,
          -12447.565,
          -12451.931999999999,
          -12455.801000000001,
          -12459.173999999999,
          -12462.051000000001,
          -12464.434,
          -12466.321000000002,
          -12467.715,
          -12468.616000000002,
          -12469.025,
          -12468.943000000001,
          -12468.368999999999,
          -12467.305,
          -12465.751,
          -12463.708999999999,
          -12461.177,
          -12458.158000000001,
          -12454.652,
          -12450.658000000001,
          -12446.178,
          -12441.212,
          -12435.761,
          -12429.825,
          -12423.403999999999,
          -12416.499,
          -12409.111,
          -12401.239,
          -12392.883999999998,
          -12384.046999999999,
          -12374.726999999999,
          -12364.926000000001,
          -12354.642,
          -12343.878,
          -12332.632,
          -12320.905,
          -12308.697,
          -12296.008999999998,
          -12282.84,
          -12269.192,
          -12255.063999999998,
          -12240.456,
          -12225.368,
          -12209.801000000001,
          -12193.753999999999,
          -12177.228000000001,
          -12160.223,
          -12142.738000000001,
          -12124.774,
          -12106.331,
          -12087.409,
          -12068.007,
          -12048.126,
          -12027.766000000001,
          -12006.926000000001,
          -11985.607,
          -11963.808,
          -11941.528999999999,
          -11918.77,
          -11895.531,
          -11871.813,
          -11847.614,
          -11822.934,
          -11797.773000000001,
          -11772.132,
          -11746.008999999998,
          -11719.403999999999,
          -11692.318000000001,
          -11664.75,
          -11636.698999999999,
          -11608.165,
          -11579.148000000001,
          -11549.646999999999,
          -11519.662,
          -11489.193000000001,
          -11458.239,
          -11426.8,
          -11394.876,
          -11362.465,
          -11329.568000000001,
          -11296.184,
          -11262.311000000002,
          -11227.951000000001,
          -11193.101999999999,
          -11157.764,
          -11121.935,
          -11085.617,
          -11048.806999999999,
          -11011.505,
          -10973.71,
          -10935.423,
          -10896.641000000001,
          -10857.364,
          -10817.593,
          -10777.325,
          -10736.561000000002,
          -10695.298,
          -10653.538,
          -10611.278,
          -10568.518,
          -10525.257,
          -10481.493,
          -10437.228000000001,
          -10392.458,
          -10347.183,
          -10301.403,
          -10255.116,
          -10208.322,
          -10161.019,
          -10113.206,
          -10064.882,
          -10016.046,
          -9966.697,
          -9916.835,
          -9866.457,
          -9815.562,
          -9764.15,
          -9712.22,
          -9659.769,
          -9606.796999999999,
          -9553.303,
          -9499.284,
          -9444.741,
          -9389.671,
          -9334.073,
          -9277.946,
          -9221.289,
          -9164.099,
          -9106.376,
          -9048.118,
          -8989.325,
          -8929.993,
          -8870.122,
          -8809.71,
          -8748.756,
          -8687.258,
          -8625.214,
          -8562.623,
          -8499.483,
          -8435.793,
          -8371.55,
          -8306.754,
          -8241.401,
          -8175.491999999999,
          -8109.023,
          -8041.994000000001,
          -7974.403,
          -7906.246,
          -7837.524,
          -7768.233,
          -7698.3730000000005,
          -7627.94,
          -7556.934,
          -7485.352,
          -7413.193,
          -7340.453,
          -7267.133000000001,
          -7193.228,
          -7118.738,
          -7043.661999999999,
          -6967.995,
          -6891.736999999999,
          -6814.8859999999995,
          -6737.44,
          -6659.395,
          -6580.7519999999995,
          -6501.507,
          -6421.658,
          -6341.204000000001,
          -6260.142,
          -6178.47,
          -6096.188,
          -6013.291,
          -5929.778,
          -5845.649,
          -5760.9,
          -5675.53,
          -5589.536999999999,
          -5502.919,
          -5415.674,
          -5327.8009999999995,
          -5239.2970000000005,
          -5150.163,
          -5060.394,
          -4969.992,
          -4878.952,
          -4787.275,
          -4694.96,
          -4602.005,
          -4508.41,
          -4414.173,
          -4319.293,
          -4223.771,
          -4127.606,
          -4030.797,
          -3933.345,
          -3835.25,
          -3736.512,
          -3637.133,
          -3537.112,
          -3436.452,
          -3335.1540000000005,
          -3233.2209999999995,
          -3130.6540000000005,
          -3027.4570000000003,
          -2923.634,
          -2819.188,
          -2714.123,
          -2608.445,
          -2502.16,
          -2395.274,
          -2287.795,
          -2179.731,
          -2071.091,
          -1961.885,
          -1852.126,
          -1741.826,
          -1630.9979999999998,
          -1519.66,
          -1407.828,
          -1295.52,
          -1182.759,
          -1069.567,
          -955.971,
          -841.998,
          -727.679,
          -613.049,
          -498.14599999999996,
          -383.01099999999997,
          -267.689,
          -152.231,
          -36.692,
          78.866,
          194.378,
          309.77,
          424.96,
          539.859,
          654.37,
          768.3839999999999,
          881.7819999999999,
          994.435,
          1106.198,
          1216.914,
          1326.408,
          1434.4920000000002,
          1540.9560000000001,
          1645.5710000000001,
          1748.0870000000002,
          1848.229,
          1945.703,
          2040.183,
          2131.319,
          2218.736,
          2302.026,
          2380.759,
          2454.478,
          2522.7039999999997,
          2584.938,
          2640.6679999999997,
          2689.377,
          2730.553,
          2763.695,
          2788.333,
          2804.033,
          2810.422,
          2807.191,
          2794.119,
          2771.0759999999996,
          2738.034,
          2695.07,
          2642.363,
          2580.197,
          2508.942,
          2429.0460000000003,
          2341.02,
          2245.425,
          2142.849,
          2033.898,
          1919.181,
          1799.296,
          1674.8229999999999,
          1546.317,
          1414.3,
          1279.26,
          1141.649,
          1001.883,
          860.341,
          717.3660000000001,
          573.27,
          428.33099999999996,
          282.802,
          136.905,
          -9.161,
          -155.217,
          -301.108,
          -446.694,
          -591.854,
          -736.4780000000001,
          -880.4739999999999,
          -1023.757,
          -1166.257,
          -1307.9089999999999,
          -1448.6589999999999,
          -1588.4589999999998,
          -1727.269,
          -1865.0529999999999,
          -2001.783,
          -2137.431,
          -2271.978,
          -2405.407,
          -2537.702,
          -2668.853,
          -2798.8509999999997,
          -2927.688,
          -3055.361,
          -3181.866,
          -3307.202,
          -3431.369,
          -3554.369,
          -3676.203,
          -3796.875,
          -3916.389,
          -4034.748,
          -4151.96,
          -4268.03,
          -4382.964,
          -4496.769,
          -4609.451,
          -4721.02,
          -4831.48,
          -4940.842000000001,
          -5049.113,
          -5156.302,
          -5262.415,
          -5367.463000000001,
          -5471.451999999999,
          -5574.393,
          -5676.2919999999995,
          -5777.159000000001,
          -5877.001,
          -5975.829000000001,
          -6073.65,
          -6170.472,
          -6266.303000000001,
          -6361.153,
          -6455.029,
          -6547.939,
          -6639.891,
          -6730.894,
          -6820.955,
          -6910.081999999999,
          -6998.281999999999,
          -7085.564,
          -7171.935,
          -7257.401999999999,
          -7341.973000000001,
          -7425.654,
          -7508.453,
          -7590.3769999999995,
          -7671.434,
          -7751.628000000001,
          -7830.969,
          -7909.460999999999,
          -7987.111999999999,
          -8063.929,
          -8139.916,
          -8215.081,
          -8289.429,
          -8362.966999999999,
          -8435.702,
          -8507.638,
          -8578.780999999999,
          -8649.138,
          -8718.713,
          -8787.511999999999,
          -8855.541,
          -8922.804,
          -8989.308,
          -9055.056999999999,
          -9120.056,
          -9184.311,
          -9247.826,
          -9310.607,
          -9372.657,
          -9433.982,
          -9494.586,
          -9554.474,
          -9613.65,
          -9672.119,
          -9729.884,
          -9786.951,
          -9843.323,
          -9899.004,
          -9954,
          -10008.312,
          -10061.947,
          -10114.905999999999,
          -10167.195,
          -10218.817,
          -10269.775,
          -10320.073,
          -10369.715,
          -10418.704,
          -10467.044,
          -10514.738000000001,
          -10561.788999999999,
          -10608.202,
          -10653.978000000001,
          -10699.122,
          -10743.635,
          -10787.523000000001,
          -10830.786,
          -10873.428999999998,
          -10915.454,
          -10956.865,
          -10997.663999999999,
          -11037.853000000001,
          -11077.436000000002,
          -11116.415,
          -11154.794,
          -11192.573999999999,
          -11229.758999999998,
          -11266.35,
          -11302.351,
          -11337.763,
          -11372.59,
          -11406.833,
          -11440.495,
          -11473.579,
          -11506.085,
          -11538.018,
          -11569.378999999999,
          -11600.169,
          -11630.392,
          -11660.048999999999,
          -11689.143,
          -11717.675,
          -11745.648000000001,
          -11773.063,
          -11799.921999999999,
          -11826.228000000001,
          -11851.981000000002,
          -11877.185,
          -11901.84,
          -11925.948999999999,
          -11949.513,
          -11972.534,
          -11995.013,
          -12016.953000000001,
          -12038.355,
          -12059.22,
          -12079.551000000001,
          -12099.348,
          -12118.613000000001,
          -12137.348,
          -12155.553999999998,
          -12173.233,
          -12190.386,
          -12207.014,
          -12223.118999999999,
          -12238.701000000001,
          -12253.764,
          -12268.306,
          -12282.331,
          -12295.839,
          -12308.831,
          -12321.309,
          -12333.273000000001,
          -12344.726,
          -12355.667,
          -12366.098999999998,
          -12376.021999999999,
          -12385.437,
          -12394.345,
          -12402.748,
          -12410.646,
          -12418.04,
          -12424.931999999999,
          -12431.322,
          -12437.21,
          -12442.598999999998,
          -12447.488000000001,
          -12451.878999999999,
          -12455.771999999999,
          -12459.169,
          -12462.07,
          -12464.476,
          -12466.386999999999,
          -12467.805,
          -12468.73,
          -12469.162,
          -12469.103000000001,
          -12468.553,
          -12467.511999999999,
          -12465.982,
          -12463.963,
          -12461.455,
          -12458.46,
          -12454.976,
          -12451.006000000001,
          -12446.548999999999,
          -12441.606000000002,
          -12436.178,
          -12430.265,
          -12423.868,
          -12416.986,
          -12409.621000000001,
          -12401.771999999999,
          -12393.441,
          -12384.626,
          -12375.33,
          -12365.551000000001,
          -12355.29,
          -12344.548999999999,
          -12333.326000000001,
          -12321.622,
          -12309.437,
          -12296.771,
          -12283.625,
          -12270,
          -12255.893999999998,
          -12241.309,
          -12226.243999999999,
          -12210.698999999999,
          -12194.675,
          -12178.171999999999,
          -12161.188999999998,
          -12143.726999999999,
          -12125.785,
          -12107.365,
          -12088.465,
          -12069.085,
          -12049.226999999999,
          -12028.889,
          -12008.071000000002,
          -11986.775,
          -11964.998,
          -11942.741000000002,
          -11920.003999999999,
          -11896.788,
          -11873.091,
          -11848.913999999999,
          -11824.257,
          -11799.118,
          -11773.499,
          -11747.398000000001,
          -11720.816,
          -11693.751,
          -11666.205,
          -11638.176000000001,
          -11609.663999999999,
          -11580.669,
          -11551.19,
          -11521.226999999999,
          -11490.78,
          -11459.848,
          -11428.431,
          -11396.528,
          -11364.139,
          -11331.264,
          -11297.901000000002,
          -11264.051000000001,
          -11229.712,
          -11194.885,
          -11159.568000000001,
          -11123.761,
          -11087.464,
          -11050.676000000001,
          -11013.395,
          -10975.623,
          -10937.356000000002,
          -10898.596000000001,
          -10859.341,
          -10819.591,
          -10779.345,
          -10738.601999999999,
          -10697.361,
          -10655.622,
          -10613.383,
          -10570.645,
          -10527.405,
          -10483.663,
          -10439.418,
          -10394.67,
          -10349.417,
          -10303.658000000001,
          -10257.392,
          -10210.619,
          -10163.337,
          -10115.545,
          -10067.242,
          -10018.428,
          -9969.1,
          -9919.259,
          -9868.902,
          -9818.028,
          -9766.638,
          -9714.728000000001,
          -9662.298,
          -9609.347,
          -9555.874,
          -9501.876,
          -9447.354,
          -9392.305,
          -9336.728000000001,
          -9280.622,
          -9223.985,
          -9166.815999999999,
          -9109.114,
          -9050.878,
          -8992.104,
          -8932.794,
          -8872.943000000001,
          -8812.552,
          -8751.619,
          -8690.141,
          -8628.118,
          -8565.548,
          -8502.428,
          -8438.759,
          -8374.537,
          -8309.761,
          -8244.429,
          -8178.54,
          -8112.092,
          -8045.084,
          -7977.512,
          -7909.3769999999995,
          -7840.674,
          -7771.404,
          -7701.564,
          -7631.151999999999,
          -7560.166,
          -7488.604,
          -7416.465,
          -7343.746,
          -7270.445,
          -7196.561,
          -7122.090999999999,
          -7047.035,
          -6971.388000000001,
          -6895.151,
          -6818.319,
          -6740.893,
          -6662.868,
          -6584.245,
          -6505.019,
          -6425.19,
          -6344.755999999999,
          -6263.714,
          -6182.062,
          -6099.799,
          -6016.920999999999,
          -5933.428000000001,
          -5849.318,
          -5764.588000000001,
          -5679.238,
          -5593.264,
          -5506.665,
          -5419.439,
          -5331.585,
          -5243.101,
          -5153.985,
          -5064.235,
          -4973.851,
          -4882.83,
          -4791.1720000000005,
          -4698.875,
          -4605.938,
          -4512.361,
          -4418.142,
          -4323.28,
          -4227.776,
          -4131.628,
          -4034.837,
          -3937.402,
          -3839.324,
          -3740.603,
          -3641.239,
          -3541.235,
          -3440.591,
          -3339.309,
          -3237.3909999999996,
          -3134.84,
          -3031.658,
          -2927.849,
          -2823.417,
          -2718.367,
          -2612.702,
          -2506.43,
          -2399.5570000000002,
          -2292.09,
          -2184.038,
          -2075.409,
          -1966.214,
          -1856.465,
          -1746.1729999999998,
          -1635.355,
          -1524.024,
          -1412.1979999999999,
          -1299.897,
          -1187.141,
          -1073.953,
          -960.3589999999999,
          -846.387,
          -732.069,
          -617.437,
          -502.531,
          -387.39099999999996,
          -272.063,
          -156.596,
          -41.04600000000001,
          74.52600000000001,
          190.053,
          305.464,
          420.675,
          535.6,
          650.14,
          764.187,
          877.623,
          990.318,
          1102.128,
          1212.897,
          1322.451,
          1430.601,
          1537.138,
          1641.835,
          1744.442,
          1844.685,
          1942.27,
          2036.872,
          2128.143,
          2215.706,
          2299.158,
          2378.0679999999998,
          2451.979,
          2520.413,
          2582.871,
          2638.844,
          2687.813,
          2729.265,
          2762.7,
          2787.6459999999997,
          2803.6690000000003,
          2810.3909999999996,
          2807.5040000000004,
          2794.782,
          2772.092,
          2739.402,
          2696.7870000000003,
          2644.4240000000004,
          2582.59,
          2511.654,
          2432.061,
          2344.323,
          2248.995,
          2146.667,
          2037.944,
          1923.4360000000001,
          1803.739,
          1679.4360000000001,
          1551.0810000000001,
          1419.1979999999999,
          1284.275,
          1146.768,
          1007.091,
          865.625,
          722.715,
          578.673,
          433.779,
          288.286,
          142.417,
          -3.627,
          -149.66899999999998,
          -295.551,
          -441.13300000000004,
          -586.293,
          -730.922,
          -874.926,
          -1018.221,
          -1160.735,
          -1302.404,
          -1443.1729999999998,
          -1583.391,
          -1721.828,
          -1859.638,
          -1996.394,
          -2132.07,
          -2266.646,
          -2400.105,
          -2532.431,
          -2663.614,
          -2793.6440000000002,
          -2922.515,
          -3050.2209999999995,
          -3176.76,
          -3302.131,
          -3426.333,
          -3549.368,
          -3671.238,
          -3791.945,
          -3911.495,
          -4029.8909999999996,
          -4147.139,
          -4263.245,
          -4378.215,
          -4492.057,
          -4604.776,
          -4716.380999999999,
          -4826.878,
          -4936.276,
          -5044.584,
          -5151.809,
          -5257.959,
          -5363.043000000001,
          -5467.069,
          -5570.045,
          -5671.981,
          -5772.883000000001,
          -5872.762,
          -5971.626,
          -6069.482,
          -6166.34,
          -6262.206999999999,
          -6357.092,
          -6451.003000000001,
          -6543.9490000000005,
          -6635.936,
          -6726.973000000001,
          -6817.069,
          -6906.231,
          -6994.465999999999,
          -7081.783,
          -7168.188,
          -7253.689,
          -7338.294,
          -7422.009,
          -7504.842,
          -7586.8,
          -7667.89,
          -7748.119000000001,
          -7827.493,
          -7906.018,
          -7983.703,
          -8060.552,
          -8136.571999999999,
          -8211.77,
          -8286.151,
          -8359.722,
          -8432.489,
          -8504.457,
          -8575.633,
          -8646.021,
          -8715.628,
          -8784.459,
          -8852.52,
          -8919.815,
          -8986.351,
          -9052.131,
          -9117.162,
          -9181.448,
          -9244.994,
          -9307.806,
          -9369.886999999999,
          -9431.243,
          -9491.878,
          -9551.796,
          -9611.003,
          -9669.502,
          -9727.298,
          -9784.395,
          -9840.796999999999,
          -9896.509,
          -9951.534,
          -10005.877,
          -10059.541,
          -10112.530999999999,
          -10164.849,
          -10216.5,
          -10267.488000000001,
          -10317.815999999999,
          -10367.487,
          -10416.505,
          -10464.874,
          -10512.597,
          -10559.678,
          -10606.118999999999,
          -10651.923999999999,
          -10697.097,
          -10741.639,
          -10785.555,
          -10828.847,
          -10871.518999999998,
          -10913.572,
          -10955.011,
          -10995.838,
          -11036.056,
          -11075.667,
          -11114.673999999999,
          -11153.081,
          -11190.889,
          -11228.101,
          -11264.72,
          -11300.749,
          -11336.188999999998,
          -11371.043,
          -11405.313999999998,
          -11439.003999999999,
          -11472.114,
          -11504.649,
          -11536.608999999999,
          -11567.996000000001,
          -11598.813999999998,
          -11629.063999999998,
          -11658.748,
          -11687.868999999999,
          -11716.428,
          -11744.427,
          -11771.868999999999,
          -11798.755,
          -11825.088,
          -11850.868,
          -11876.098,
          -11900.78,
          -11924.915,
          -11948.506000000001,
          -11971.553,
          -11994.059,
          -12016.024,
          -12037.452,
          -12058.344,
          -12078.701000000001,
          -12098.524,
          -12117.815,
          -12136.576000000001,
          -12154.808,
          -12172.513,
          -12189.691,
          -12206.345,
          -12222.475,
          -12238.083999999999,
          -12253.171999999999,
          -12267.74,
          -12281.79,
          -12295.323999999999,
          -12308.341,
          -12320.844,
          -12332.833999999999,
          -12344.312,
          -12355.278,
          -12365.735,
          -12375.683,
          -12385.124,
          -12394.056999999999,
          -12402.485,
          -12410.408000000001,
          -12417.827,
          -12424.743999999999,
          -12431.158000000001,
          -12437.072,
          -12442.485,
          -12447.399,
          -12451.815,
          -12455.732,
          -12459.153999999999,
          -12462.079,
          -12464.51,
          -12466.446000000002,
          -12467.888,
          -12468.837,
          -12469.294,
          -12469.258999999998,
          -12468.733,
          -12467.716999999999,
          -12466.211000000001,
          -12464.216,
          -12461.733,
          -12458.761,
          -12455.302,
          -12451.355,
          -12446.921999999999,
          -12442.003999999999,
          -12436.6,
          -12430.711000000001,
          -12424.337,
          -12417.48,
          -12410.138,
          -12402.313,
          -12394.005,
          -12385.215,
          -12375.942,
          -12366.186000000002,
          -12355.95,
          -12345.231000000002,
          -12334.032,
          -12322.351,
          -12310.19,
          -12297.548,
          -12284.426000000001,
          -12270.823,
          -12256.741000000002,
          -12242.178999999998,
          -12227.138,
          -12211.616000000002,
          -12195.615,
          -12179.135,
          -12162.175,
          -12144.736,
          -12126.818000000001,
          -12108.42,
          -12089.544,
          -12070.187,
          -12050.351999999999,
          -12030.037,
          -12009.242,
          -11987.968,
          -11966.214,
          -11943.98,
          -11921.267,
          -11898.073,
          -11874.399,
          -11850.245,
          -11825.61,
          -11800.495,
          -11774.898000000001,
          -11748.82,
          -11722.26,
          -11695.218,
          -11667.694,
          -11639.688,
          -11611.198,
          -11582.226,
          -11552.77,
          -11522.829,
          -11492.403999999999,
          -11461.493999999999,
          -11430.1,
          -11398.219,
          -11365.853000000001,
          -11333,
          -11299.659,
          -11265.831,
          -11231.515,
          -11196.71,
          -11161.415,
          -11125.631000000001,
          -11089.355,
          -11052.589,
          -11015.331,
          -10977.58,
          -10939.336000000001,
          -10900.597,
          -10861.364,
          -10821.636,
          -10781.412,
          -10740.691,
          -10699.472,
          -10657.755,
          -10615.538,
          -10572.821000000002,
          -10529.603000000001,
          -10485.883,
          -10441.66,
          -10396.933,
          -10351.702,
          -10305.965,
          -10259.721,
          -10212.969000000001,
          -10165.709,
          -10117.939,
          -10069.657,
          -10020.864,
          -9971.558,
          -9921.738000000001,
          -9871.402,
          -9820.551,
          -9769.181,
          -9717.293,
          -9664.884,
          -9611.955,
          -9558.503,
          -9504.527,
          -9450.025,
          -9394.998,
          -9339.442,
          -9283.357,
          -9226.742,
          -9169.594000000001,
          -9111.913,
          -9053.697,
          -8994.945,
          -8935.655,
          -8875.826,
          -8815.456,
          -8754.543,
          -8693.087,
          -8631.085,
          -8568.535,
          -8505.437,
          -8441.788,
          -8377.587,
          -8312.832,
          -8247.521,
          -8181.651999999999,
          -8115.225,
          -8048.236999999999,
          -7980.687,
          -7912.571999999999,
          -7843.89,
          -7774.64,
          -7704.821,
          -7634.429,
          -7563.464,
          -7491.922,
          -7419.803000000001,
          -7347.105,
          -7273.825,
          -7199.96,
          -7125.5109999999995,
          -7050.475,
          -6974.848000000001,
          -6898.630999999999,
          -6821.82,
          -6744.4130000000005,
          -6666.409000000001,
          -6587.805,
          -6508.599,
          -6428.79,
          -6348.376,
          -6267.353,
          -6185.721,
          -6103.477,
          -6020.62,
          -5937.146,
          -5853.055,
          -5768.345,
          -5683.014,
          -5597.059,
          -5510.479,
          -5423.272,
          -5335.437,
          -5246.972,
          -5157.874,
          -5068.144,
          -4977.778,
          -4886.776,
          -4795.1359999999995,
          -4702.857,
          -4609.938,
          -4516.379,
          -4422.177,
          -4327.334,
          -4231.847,
          -4135.715999999999,
          -4038.942,
          -3941.5240000000003,
          -3843.4629999999997,
          -3744.758,
          -3645.4120000000003,
          -3545.423,
          -3444.795,
          -3343.5290000000005,
          -3241.6259999999997,
          -3139.09,
          -3035.923,
          -2932.1279999999997,
          -2827.71,
          -2722.673,
          -2617.022,
          -2510.763,
          -2403.902,
          -2296.447,
          -2188.406,
          -2079.788,
          -1970.6029999999998,
          -1860.8629999999998,
          -1750.58,
          -1639.769,
          -1528.4460000000001,
          -1416.626,
          -1304.33,
          -1191.578,
          -1078.394,
          -964.802,
          -850.831,
          -736.512,
          -621.879,
          -506.969,
          -391.82300000000004,
          -276.487,
          -161.011,
          -45.45,
          70.13600000000001,
          185.68,
          301.11,
          416.345,
          531.295,
          645.865,
          759.946,
          873.42,
          986.158,
          1098.017,
          1208.84,
          1318.454,
          1426.672,
          1533.2839999999999,
          1638.0639999999999,
          1740.7620000000002,
          1841.1070000000002,
          1938.8029999999999,
          2033.529,
          2124.935,
          2212.647,
          2296.261,
          2375.348,
          2449.452,
          2518.095,
          2580.78,
          2636.9959999999996,
          2686.225,
          2727.955,
          2761.685,
          2786.9390000000003,
          2803.2859999999996,
          2810.343,
          2807.8,
          2795.429,
          2773.094,
          2740.759,
          2698.495,
          2646.475,
          2584.975,
          2514.36,
          2435.074,
          2347.623,
          2252.565,
          2150.487,
          2041.994,
          1927.6960000000001,
          1808.1889999999999,
          1684.058,
          1555.855,
          1424.108,
          1289.305,
          1151.902,
          1012.315,
          870.927,
          728.0830000000001,
          584.096,
          439.24800000000005,
          293.79200000000003,
          147.952,
          1.93,
          -144.096,
          -289.968,
          -435.545,
          -580.705,
          -725.3380000000001,
          -869.3489999999999,
          -1012.6560000000001,
          -1155.184,
          -1296.869,
          -1437.6570000000002,
          -1577.5,
          -1716.356,
          -1854.191,
          -1990.973,
          -2126.677,
          -2261.281,
          -2394.77,
          -2527.127,
          -2658.341,
          -2788.403,
          -2917.3070000000002,
          -3045.047,
          -3171.619,
          -3297.025,
          -3421.262,
          -3544.3320000000003,
          -3666.237,
          -3786.98,
          -3906.566,
          -4024.998,
          -4142.282,
          -4258.424,
          -4373.431,
          -4487.309,
          -4600.065,
          -4711.706,
          -4822.24,
          -4931.675,
          -5040.019,
          -5147.28,
          -5253.467,
          -5358.5869999999995,
          -5462.649,
          -5565.661999999999,
          -5667.634,
          -5768.573,
          -5868.486999999999,
          -5967.387,
          -6065.279,
          -6162.172,
          -6258.075,
          -6352.996,
          -6446.943,
          -6539.924,
          -6631.946,
          -6723.018,
          -6813.149,
          -6902.346,
          -6990.616,
          -7077.967,
          -7164.406999999999,
          -7249.943,
          -7334.581999999999,
          -7418.331,
          -7501.198,
          -7583.19,
          -7664.314,
          -7744.576,
          -7823.984,
          -7902.543000000001,
          -7980.2609999999995,
          -8057.143,
          -8133.196999999999,
          -8208.427,
          -8282.841999999999,
          -8356.445,
          -8429.245,
          -8501.245,
          -8572.454,
          -8642.875,
          -8712.514000000001,
          -8781.377,
          -8849.47,
          -8916.796999999999,
          -8983.365,
          -9049.177,
          -9114.239,
          -9178.556,
          -9242.134,
          -9304.976999999999,
          -9367.09,
          -9428.476999999999,
          -9489.143,
          -9549.091999999999,
          -9608.33,
          -9666.86,
          -9724.686,
          -9781.814,
          -9838.246,
          -9893.988000000001,
          -9949.044,
          -10003.417,
          -10057.110999999999,
          -10110.131,
          -10162.479,
          -10214.16,
          -10265.178,
          -10315.535,
          -10365.237,
          -10414.284,
          -10462.683,
          -10510.435,
          -10557.545,
          -10604.016000000001,
          -10649.85,
          -10695.051000000001,
          -10739.623,
          -10783.568000000001,
          -10826.889,
          -10869.589,
          -10911.671,
          -10953.139,
          -10993.993999999999,
          -11034.241000000002,
          -11073.88,
          -11112.916000000001,
          -11151.35,
          -11189.187,
          -11226.427,
          -11263.075,
          -11299.131000000001,
          -11334.598999999998,
          -11369.481000000002,
          -11403.78,
          -11437.497,
          -11470.636,
          -11503.198,
          -11535.185,
          -11566.601,
          -11597.446000000002,
          -11627.723,
          -11657.435,
          -11686.583,
          -11715.169,
          -11743.196000000002,
          -11770.665,
          -11797.578000000001,
          -11823.937,
          -11849.743999999999,
          -11875.001,
          -11899.71,
          -11923.872,
          -11947.489,
          -11970.563999999998,
          -11993.096000000001,
          -12015.088,
          -12036.543,
          -12057.461000000001,
          -12077.844,
          -12097.693000000001,
          -12117.011,
          -12135.798,
          -12154.056,
          -12171.787,
          -12188.992,
          -12205.671999999999,
          -12221.828000000001,
          -12237.463,
          -12252.576000000001,
          -12267.171,
          -12281.247,
          -12294.806,
          -12307.848999999998,
          -12320.378,
          -12332.393,
          -12343.896999999999,
          -12354.889,
          -12365.371000000001,
          -12375.345,
          -12384.811000000002,
          -12393.77,
          -12402.223,
          -12410.171,
          -12417.616000000002,
          -12424.556999999999,
          -12430.997,
          -12436.936000000002,
          -12442.374,
          -12447.313,
          -12451.753999999999,
          -12455.697,
          -12459.143,
          -12462.093,
          -12464.548999999999,
          -12466.508999999998,
          -12467.976,
          -12468.95,
          -12469.431999999999,
          -12469.421999999999,
          -12468.921,
          -12467.928999999998,
          -12466.448,
          -12464.476999999999,
          -12462.018,
          -12459.071000000002,
          -12455.636,
          -12451.714,
          -12447.306,
          -12442.411,
          -12437.032,
          -12431.167,
          -12424.818000000001,
          -12417.983999999999,
          -12410.667,
          -12402.866000000002,
          -12394.582,
          -12385.815,
          -12376.566,
          -12366.835,
          -12356.622,
          -12345.928,
          -12334.753,
          -12323.096000000001,
          -12310.958,
          -12298.34,
          -12285.241000000002,
          -12271.663,
          -12257.604,
          -12243.066,
          -12228.048,
          -12212.55,
          -12196.573,
          -12180.116000000002,
          -12163.18,
          -12145.765,
          -12127.87,
          -12109.495,
          -12090.642,
          -12071.309,
          -12051.497,
          -12031.205,
          -12010.434,
          -11989.183,
          -11967.452,
          -11945.242,
          -11922.551000000001,
          -11899.381000000001,
          -11875.73,
          -11851.598999999998,
          -11826.987,
          -11801.893999999998,
          -11776.32,
          -11750.265,
          -11723.728000000001,
          -11696.708999999999,
          -11669.208,
          -11641.225,
          -11612.758,
          -11583.808,
          -11554.375,
          -11524.457,
          -11494.055,
          -11463.168,
          -11431.796,
          -11399.938,
          -11367.594,
          -11334.764,
          -11301.446000000002,
          -11267.64,
          -11233.346000000001,
          -11198.563999999998,
          -11163.291000000001,
          -11127.528999999999,
          -11091.277,
          -11054.533000000001,
          -11017.296999999999,
          -10979.568000000001,
          -10941.346000000001,
          -10902.63,
          -10863.419,
          -10823.713,
          -10783.511,
          -10742.812,
          -10701.616000000002,
          -10659.92,
          -10617.726,
          -10575.031,
          -10531.835,
          -10488.136999999999,
          -10443.936,
          -10399.231,
          -10354.021999999999,
          -10308.306,
          -10262.084,
          -10215.354,
          -10168.116,
          -10120.368,
          -10072.108,
          -10023.336,
          -9974.052,
          -9924.254,
          -9873.94,
          -9823.11,
          -9771.761999999999,
          -9719.895,
          -9667.509,
          -9614.601,
          -9561.17,
          -9507.215,
          -9452.735999999999,
          -9397.729,
          -9342.195,
          -9286.132,
          -9229.537,
          -9172.411,
          -9114.751,
          -9056.556999999999,
          -8997.826,
          -8938.558,
          -8878.75,
          -8818.401,
          -8757.509,
          -8696.074,
          -8634.093,
          -8571.564,
          -8508.487,
          -8444.859,
          -8380.679,
          -8315.945,
          -8250.655,
          -8184.807,
          -8118.401,
          -8051.434,
          -7983.904,
          -7915.81,
          -7847.149,
          -7777.92,
          -7708.121,
          -7637.75,
          -7566.805,
          -7495.284000000001,
          -7423.186,
          -7350.508000000001,
          -7277.2480000000005,
          -7203.404,
          -7128.975,
          -7053.959,
          -6978.353,
          -6902.156,
          -6825.365,
          -6747.978,
          -6669.994000000001,
          -6591.41,
          -6512.225,
          -6432.435,
          -6352.041,
          -6271.039000000001,
          -6189.4259999999995,
          -6107.201999999999,
          -6024.3640000000005,
          -5940.911,
          -5856.84,
          -5772.149,
          -5686.8369999999995,
          -5600.901,
          -5514.34,
          -5427.151999999999,
          -5339.335999999999,
          -5250.889,
          -5161.81,
          -5072.098,
          -4981.751,
          -4890.768,
          -4799.146,
          -4706.8859999999995,
          -4613.985,
          -4520.444,
          -4426.26,
          -4331.434,
          -4235.964,
          -4139.851,
          -4043.093,
          -3945.692,
          -3847.647,
          -3748.9590000000003,
          -3649.6290000000004,
          -3549.657,
          -3449.045,
          -3347.7940000000003,
          -3245.907,
          -3143.385,
          -3040.2329999999997,
          -2936.452,
          -2832.048,
          -2727.025,
          -2621.386,
          -2515.14,
          -2408.291,
          -2300.847,
          -2192.8160000000003,
          -2084.209,
          -1975.0339999999999,
          -1865.3029999999999,
          -1755.03,
          -1644.227,
          -1532.91,
          -1421.096,
          -1308.805,
          -1196.057,
          -1082.876,
          -969.2860000000001,
          -855.315,
          -740.995,
          -626.359,
          -511.445,
          -396.29400000000004,
          -280.95,
          -165.465,
          -49.891000000000005,
          65.709,
          181.271,
          296.721,
          411.97900000000004,
          526.956,
          641.556,
          755.671,
          869.184,
          981.966,
          1093.874,
          1204.752,
          1314.4279999999999,
          1422.713,
          1529.4,
          1634.263,
          1737.0539999999999,
          1837.5020000000002,
          1935.3110000000001,
          2030.16,
          2121.703,
          2209.564,
          2293.342,
          2372.607,
          2446.905,
          2515.758,
          2578.67,
          2635.13,
          2684.6220000000003,
          2726.631,
          2760.656,
          2786.222,
          2802.893,
          2810.2870000000003,
          2808.091,
          2796.073,
          2774.095,
          2742.116,
          2700.2059999999997,
          2648.534,
          2587.3720000000003,
          2517.081,
          2438.1020000000003,
          2350.9429999999998,
          2256.157,
          2154.333,
          2046.0729999999999,
          1931.987,
          1812.674,
          1688.7160000000001,
          1560.6689999999999,
          1429.059,
          1294.378,
          1157.08,
          1017.586,
          876.2769999999999,
          733.5010000000001,
          589.571,
          444.77099999999996,
          299.35200000000003,
          153.543,
          7.544,
          -138.465,
          -284.32599999999996,
          -429.898,
          -575.057,
          -719.694,
          -863.7130000000001,
          -1007.03,
          -1149.5710000000001,
          -1291.2730000000001,
          -1432.08,
          -1571.943,
          -1710.8220000000001,
          -1848.68,
          -1985.4879999999998,
          -2121.219,
          -2255.853,
          -2389.371,
          -2521.759,
          -2653.005,
          -2783.099,
          -2912.035,
          -3039.808,
          -3166.415,
          -3291.855,
          -3416.127,
          -3539.2329999999997,
          -3661.173,
          -3781.952,
          -3901.574,
          -4020.0429999999997,
          -4137.363,
          -4253.541,
          -4368.585,
          -4482.499,
          -4595.292,
          -4706.97,
          -4817.541,
          -4927.013,
          -5035.394,
          -5142.691,
          -5248.914000000001,
          -5354.071,
          -5458.17,
          -5561.219,
          -5663.228,
          -5764.203,
          -5864.155,
          -5963.090999999999,
          -6061.019,
          -6157.948,
          -6253.887,
          -6348.843000000001,
          -6442.826,
          -6535.842,
          -6627.901,
          -6719.009,
          -6809.175,
          -6898.406999999999,
          -6986.713000000001,
          -7074.098000000001,
          -7160.573,
          -7246.143,
          -7330.816999999999,
          -7414.602,
          -7497.503000000001,
          -7579.53,
          -7660.688,
          -7740.984,
          -7820.4259999999995,
          -7899.019,
          -7976.771,
          -8053.686,
          -8129.773,
          -8205.037,
          -8279.485,
          -8353.122,
          -8425.955,
          -8497.989,
          -8569.23,
          -8639.684000000001,
          -8709.356,
          -8778.252,
          -8846.377,
          -8913.737,
          -8980.336,
          -9046.18,
          -9111.275,
          -9175.625,
          -9239.235,
          -9302.109,
          -9364.254,
          -9425.671999999999,
          -9486.37,
          -9546.351,
          -9605.62,
          -9664.181,
          -9722.039,
          -9779.198,
          -9835.661,
          -9891.434000000001,
          -9946.52,
          -10000.924,
          -10054.649,
          -10107.699,
          -10160.078000000001,
          -10211.789,
          -10262.837,
          -10313.225,
          -10362.956,
          -10412.034,
          -10460.463,
          -10508.246000000001,
          -10555.386,
          -10601.885,
          -10647.749,
          -10692.98,
          -10737.581,
          -10781.555,
          -10824.905,
          -10867.635,
          -10909.747,
          -10951.243999999999,
          -10992.128,
          -11032.403999999999,
          -11072.072,
          -11111.136999999999,
          -11149.601,
          -11187.466,
          -11224.735,
          -11261.411,
          -11297.496000000001,
          -11332.992,
          -11367.903,
          -11402.23,
          -11435.975,
          -11469.142,
          -11501.732,
          -11533.748,
          -11565.191,
          -11596.065,
          -11626.37,
          -11656.11,
          -11685.286,
          -11713.9,
          -11741.955,
          -11769.451000000001,
          -11796.392,
          -11822.778999999999,
          -11848.613000000001,
          -11873.896999999999,
          -11898.633,
          -11922.823,
          -11946.466999999999,
          -11969.569,
          -11992.128,
          -12014.148000000001,
          -12035.63,
          -12056.575,
          -12076.985,
          -12096.862,
          -12116.206,
          -12135.02,
          -12153.306,
          -12171.063,
          -12188.294,
          -12205.001,
          -12221.184,
          -12236.845,
          -12251.985,
          -12266.605,
          -12280.708,
          -12294.293,
          -12307.363000000001,
          -12319.918,
          -12331.96,
          -12343.49,
          -12354.508,
          -12365.017,
          -12375.016000000001,
          -12384.508,
          -12393.493,
          -12401.972,
          -12409.946000000002,
          -12417.417,
          -12424.383999999998,
          -12430.85,
          -12436.813999999998,
          -12442.278,
          -12447.242,
          -12451.708999999999,
          -12455.678,
          -12459.15,
          -12462.126,
          -12464.606000000002,
          -12466.591999999999,
          -12468.085,
          -12469.083999999999,
          -12469.591,
          -12469.606000000002,
          -12469.13,
          -12468.163999999999,
          -12466.708,
          -12464.761999999999,
          -12462.328000000001,
          -12459.406,
          -12455.997,
          -12452.1,
          -12447.716999999999,
          -12442.847,
          -12437.492,
          -12431.652,
          -12425.327,
          -12418.518999999998,
          -12411.226,
          -12403.45,
          -12395.191,
          -12386.448999999999,
          -12377.223999999998,
          -12367.518,
          -12357.33,
          -12346.66,
          -12335.508999999998,
          -12323.876,
          -12311.763,
          -12299.17,
          -12286.096000000001,
          -12272.542,
          -12258.508,
          -12243.993,
          -12228.999,
          -12213.525,
          -12197.572,
          -12181.14,
          -12164.226999999999,
          -12146.836000000001,
          -12128.965,
          -12110.615,
          -12091.786,
          -12072.476999999999,
          -12052.688,
          -12032.421,
          -12011.673,
          -11990.446000000002,
          -11968.74,
          -11946.553,
          -11923.886999999999,
          -11900.74,
          -11877.113000000001,
          -11853.006000000001,
          -11828.417,
          -11803.348,
          -11777.798,
          -11751.765,
          -11725.252,
          -11698.257,
          -11670.778999999999,
          -11642.819,
          -11614.376,
          -11585.448999999999,
          -11556.038999999999,
          -11526.145,
          -11495.767,
          -11464.903,
          -11433.555,
          -11401.72,
          -11369.399,
          -11336.591999999999,
          -11303.296999999999,
          -11269.515,
          -11235.243999999999,
          -11200.483999999999,
          -11165.235,
          -11129.495,
          -11093.266000000001,
          -11056.545,
          -11019.332,
          -10981.626,
          -10943.427,
          -10904.735,
          -10865.546999999999,
          -10825.864,
          -10785.685,
          -10745.008999999998,
          -10703.835,
          -10662.162,
          -10619.99,
          -10577.318000000001,
          -10534.145,
          -10490.47,
          -10446.291,
          -10401.609,
          -10356.421999999999,
          -10310.729,
          -10264.529,
          -10217.822,
          -10170.606,
          -10122.88,
          -10074.643,
          -10025.894,
          -9976.632,
          -9926.857,
          -9876.565,
          -9825.757,
          -9774.431999999999,
          -9722.587,
          -9670.223,
          -9617.337,
          -9563.929,
          -9509.996,
          -9455.539,
          -9400.554,
          -9345.042,
          -9289,
          -9232.428,
          -9175.324,
          -9117.687,
          -9059.514000000001,
          -9000.806,
          -8941.559000000001,
          -8881.773000000001,
          -8821.446,
          -8760.576,
          -8699.163,
          -8637.203000000001,
          -8574.697,
          -8511.641,
          -8448.035,
          -8383.877,
          -8319.164,
          -8253.896,
          -8188.071,
          -8121.686,
          -8054.74,
          -7987.231,
          -7919.158,
          -7850.519,
          -7781.311,
          -7711.534000000001,
          -7641.184,
          -7570.26,
          -7498.7609999999995,
          -7426.684,
          -7354.026999999999,
          -7280.7880000000005,
          -7206.965999999999,
          -7132.559,
          -7057.563,
          -6981.978,
          -6905.8009999999995,
          -6829.031,
          -6751.665,
          -6673.701999999999,
          -6595.139,
          -6515.974,
          -6436.205,
          -6355.831,
          -6274.849,
          -6193.257,
          -6111.053000000001,
          -6028.236,
          -5944.802,
          -5860.751,
          -5776.081,
          -5690.789000000001,
          -5604.8730000000005,
          -5518.331999999999,
          -5431.164000000001,
          -5343.366999999999,
          -5254.94,
          -5165.880999999999,
          -5076.188,
          -4985.86,
          -4894.896,
          -4803.294,
          -4711.052,
          -4618.17,
          -4524.647,
          -4430.482,
          -4335.674,
          -4240.223,
          -4144.127,
          -4047.388,
          -3950.0040000000004,
          -3851.9770000000003,
          -3753.3059999999996,
          -3653.993,
          -3554.0370000000003,
          -3453.442,
          -3352.2070000000003,
          -3250.336,
          -3147.83,
          -3044.6929999999998,
          -2940.927,
          -2836.5370000000003,
          -2731.528,
          -2625.903,
          -2519.67,
          -2412.834,
          -2305.402,
          -2197.383,
          -2088.7870000000003,
          -1979.622,
          -1869.902,
          -1759.6370000000002,
          -1648.842,
          -1537.533,
          -1425.726,
          -1313.44,
          -1200.697,
          -1087.518,
          -973.93,
          -859.961,
          -745.64,
          -631.002,
          -516.0840000000001,
          -400.92699999999996,
          -285.57599999999996,
          -170.08,
          -54.495,
          61.121,
          176.7,
          292.17,
          407.45099999999996,
          522.456,
          637.086,
          751.237,
          864.79,
          977.617,
          1089.575,
          1200.509,
          1310.248,
          1418.6029999999998,
          1525.368,
          1630.318,
          1733.204,
          1833.7579999999998,
          1931.682,
          2026.66,
          2118.344,
          2206.359,
          2290.306,
          2369.756,
          2444.254,
          2513.325,
          2576.473,
          2633.1859999999997,
          2682.949,
          2725.248,
          2759.579,
          2785.468,
          2802.4759999999997,
          2810.2209999999995,
          2808.385,
          2796.735,
          2775.127,
          2743.52,
          2701.978,
          2650.667,
          2589.855,
          2519.902,
          2441.245,
          2354.389,
          2259.888,
          2158.327,
          2050.31,
          1936.4460000000001,
          1817.3339999999998,
          1693.557,
          1565.671,
          1434.205,
          1299.651,
          1162.464,
          1023.066,
          881.8389999999999,
          739.133,
          595.263,
          450.51099999999997,
          305.133,
          159.355,
          13.38,
          -132.613,
          -278.46299999999997,
          -424.029,
          -569.187,
          -713.828,
          -857.8539999999999,
          -1001.182,
          -1143.738,
          -1285.4569999999999,
          -1426.283,
          -1566.06,
          -1705.0710000000001,
          -1842.955,
          -1979.789,
          -2115.55,
          -2250.2129999999997,
          -2383.762,
          -2516.1820000000002,
          -2647.461,
          -2777.5890000000004,
          -2906.56,
          -3034.368,
          -3161.011,
          -3286.487,
          -3410.795,
          -3533.937,
          -3655.915,
          -3776.732,
          -3896.3909999999996,
          -4014.897,
          -4132.255,
          -4248.472,
          -4363.554,
          -4477.505999999999,
          -4590.337,
          -4702.054,
          -4812.663,
          -4922.173,
          -5030.593,
          -5137.928,
          -5244.19,
          -5349.385,
          -5453.522,
          -5556.609,
          -5658.656,
          -5759.669,
          -5859.659000000001,
          -5958.632,
          -6056.599,
          -6153.565,
          -6249.541,
          -6344.535,
          -6438.555,
          -6531.609,
          -6623.704000000001,
          -6714.85,
          -6805.053000000001,
          -6894.321,
          -6982.6630000000005,
          -7070.085999999999,
          -7156.596,
          -7242.203,
          -7326.9130000000005,
          -7410.733,
          -7493.670999999999,
          -7575.733,
          -7656.927,
          -7737.259,
          -7816.736,
          -7895.3640000000005,
          -7973.151,
          -8050.102,
          -8126.223000000001,
          -8201.521999999999,
          -8276.005,
          -8349.676,
          -8422.544,
          -8494.612,
          -8565.886999999999,
          -8636.375,
          -8706.081,
          -8775.011,
          -8843.17,
          -8910.563,
          -8977.195,
          -9043.073,
          -9108.201,
          -9172.584,
          -9236.226999999999,
          -9299.135,
          -9361.312,
          -9422.763,
          -9483.494,
          -9543.507,
          -9602.809000000001,
          -9661.402,
          -9719.292,
          -9776.483,
          -9832.979,
          -9888.784,
          -9943.902,
          -9998.338,
          -10052.094000000001,
          -10105.176,
          -10157.586,
          -10209.329,
          -10260.408000000001,
          -10310.827,
          -10360.59,
          -10409.699,
          -10458.159,
          -10505.972,
          -10553.143,
          -10599.673999999999,
          -10645.568000000001,
          -10690.829,
          -10735.461000000001,
          -10779.466,
          -10822.846000000001,
          -10865.606000000002,
          -10907.748,
          -10949.275,
          -10990.19,
          -11030.495,
          -11070.194,
          -11109.288999999999,
          -11147.782,
          -11185.677,
          -11222.976,
          -11259.681,
          -11295.796,
          -11331.321000000002,
          -11366.261,
          -11400.617,
          -11434.392,
          -11467.588,
          -11500.207,
          -11532.252,
          -11563.723999999998,
          -11594.627,
          -11624.961000000001,
          -11654.729,
          -11683.934,
          -11712.577,
          -11740.66,
          -11768.185,
          -11795.153999999999,
          -11821.569,
          -11847.431999999999,
          -11872.743999999999,
          -11897.508,
          -11921.726,
          -11945.399,
          -11968.528,
          -11991.116000000002,
          -12013.163999999999,
          -12034.673,
          -12055.646,
          -12076.083999999999,
          -12095.988000000001,
          -12115.36,
          -12134.202,
          -12152.515,
          -12170.3,
          -12187.558,
          -12204.292,
          -12220.503,
          -12236.191,
          -12251.358,
          -12266.005,
          -12280.135,
          -12293.748,
          -12306.845,
          -12319.427,
          -12331.496000000001,
          -12343.052,
          -12354.098,
          -12364.633,
          -12374.659,
          -12384.178,
          -12393.188999999998,
          -12401.695,
          -12409.696000000002,
          -12417.193000000001,
          -12424.187,
          -12430.678999999998,
          -12436.669,
          -12442.159,
          -12447.15,
          -12451.643,
          -12455.638,
          -12459.136,
          -12462.138,
          -12464.645,
          -12466.657,
          -12468.175,
          -12469.201000000001,
          -12469.733,
          -12469.774,
          -12469.323999999999,
          -12468.383999999998,
          -12466.953000000001,
          -12465.034,
          -12462.625,
          -12459.729,
          -12456.345,
          -12452.473999999998,
          -12448.116000000002,
          -12443.271999999999,
          -12437.942,
          -12432.127,
          -12425.828000000001,
          -12419.045,
          -12411.777,
          -12404.026000000002,
          -12395.792,
          -12387.076000000001,
          -12377.876,
          -12368.195,
          -12358.032,
          -12347.386999999999,
          -12336.261,
          -12324.653999999999,
          -12312.566,
          -12299.997,
          -12286.948,
          -12273.419,
          -12259.409,
          -12244.919,
          -12229.95,
          -12214.501,
          -12198.572,
          -12182.163999999999,
          -12165.277,
          -12147.91,
          -12130.063,
          -12111.738000000001,
          -12092.933,
          -12073.648000000001,
          -12053.883999999998,
          -12033.641000000001,
          -12012.918,
          -11991.715,
          -11970.033000000001,
          -11947.87,
          -11925.228000000001,
          -11902.105,
          -11878.503,
          -11854.419,
          -11829.855,
          -11804.81,
          -11779.283000000001,
          -11753.275,
          -11726.785,
          -11699.813999999998,
          -11672.36,
          -11644.423999999999,
          -11616.005,
          -11587.101999999999,
          -11557.716,
          -11527.845,
          -11497.49,
          -11466.651000000002,
          -11435.325,
          -11403.515,
          -11371.216999999999,
          -11338.433,
          -11305.162,
          -11271.403,
          -11237.156,
          -11202.42,
          -11167.194,
          -11131.476999999999,
          -11095.271,
          -11058.573,
          -11021.383,
          -10983.701000000001,
          -10945.525,
          -10906.856000000002,
          -10867.691,
          -10828.032,
          -10787.875,
          -10747.222,
          -10706.071000000002,
          -10664.421999999999,
          -10622.273000000001,
          -10579.624,
          -10536.473,
          -10492.821000000002,
          -10448.665,
          -10404.006,
          -10358.841999999999,
          -10313.171999999999,
          -10266.994,
          -10220.31,
          -10173.116,
          -10125.413,
          -10077.199,
          -10028.473,
          -9979.234,
          -9929.48,
          -9879.211,
          -9828.426,
          -9777.123,
          -9725.301,
          -9672.959,
          -9620.095,
          -9566.709,
          -9512.799,
          -9458.364,
          -9403.402,
          -9347.911,
          -9291.892,
          -9235.341999999999,
          -9178.26,
          -9120.645,
          -9062.495,
          -9003.808,
          -8944.583,
          -8884.819,
          -8824.514000000001,
          -8763.666,
          -8702.274,
          -8640.337,
          -8577.851999999999,
          -8514.818000000001,
          -8451.234,
          -8387.097,
          -8322.407,
          -8257.16,
          -8191.356,
          -8124.993,
          -8058.068,
          -7990.581,
          -7922.53,
          -7853.911999999999,
          -7784.726,
          -7714.969,
          -7644.641,
          -7573.738,
          -7502.26,
          -7430.204000000001,
          -7357.568,
          -7284.351,
          -7210.55,
          -7136.1630000000005,
          -7061.189,
          -6985.624,
          -6909.468000000001,
          -6832.719,
          -6755.374,
          -6677.431,
          -6598.888000000001,
          -6519.744000000001,
          -6439.996,
          -6359.642,
          -6278.68,
          -6197.109,
          -6114.925,
          -6032.128000000001,
          -5948.714,
          -5864.683000000001,
          -5780.033,
          -5694.76,
          -5608.865,
          -5522.343000000001,
          -5435.194,
          -5347.4169999999995,
          -5259.009,
          -5169.969,
          -5080.295999999999,
          -4989.987,
          -4899.041,
          -4807.458,
          -4715.235,
          -4622.372,
          -4528.867,
          -4434.72,
          -4339.93,
          -4244.496,
          -4148.418,
          -4051.696,
          -3954.33,
          -3856.3190000000004,
          -3757.665,
          -3658.368,
          -3558.429,
          -3457.85,
          -3356.631,
          -3254.775,
          -3152.284,
          -3049.1620000000003,
          -2945.4109999999996,
          -2841.035,
          -2736.039,
          -2630.428,
          -2524.2070000000003,
          -2417.383,
          -2309.9629999999997,
          -2201.955,
          -2093.369,
          -1984.215,
          -1874.503,
          -1764.247,
          -1653.4589999999998,
          -1542.1570000000002,
          -1430.356,
          -1318.075,
          -1205.335,
          -1092.16,
          -978.573,
          -864.6030000000001,
          -750.2810000000001,
          -635.64,
          -520.7180000000001,
          -405.55400000000003,
          -290.195,
          -174.68900000000002,
          -59.091,
          56.54,
          172.137,
          287.628,
          402.934,
          517.966,
          632.628,
          746.814,
          860.408,
          973.28,
          1085.289,
          1196.28,
          1306.0819999999999,
          1414.507,
          1521.349,
          1626.385,
          1729.3670000000002,
          1830.026,
          1928.067,
          2023.172,
          2114.996,
          2203.1639999999998,
          2287.279,
          2366.913,
          2441.61,
          2510.897,
          2574.278,
          2631.243,
          2681.275,
          2723.861,
          2758.4959999999996,
          2784.704,
          2802.047,
          2810.139,
          2808.66,
          2797.3740000000003,
          2776.134,
          2744.8959999999997,
          2703.719,
          2652.7659999999996,
          2592.303,
          2522.685,
          2444.348,
          2357.794,
          2263.575,
          2162.277,
          2054.502,
          1940.859,
          1821.9470000000001,
          1698.351,
          1570.6270000000002,
          1439.305,
          1304.878,
          1167.8010000000002,
          1028.5,
          887.357,
          744.721,
          600.911,
          456.209,
          310.871,
          165.125,
          19.174,
          -126.8,
          -272.638,
          -418.19800000000004,
          -563.354,
          -707.998,
          -852.0310000000001,
          -995.3689999999999,
          -1137.938,
          -1279.673,
          -1420.519,
          -1560.425,
          -1699.351,
          -1837.259,
          -1974.12,
          -2109.909,
          -2244.601,
          -2378.181,
          -2510.632,
          -2641.9429999999998,
          -2772.1040000000003,
          -2901.1090000000004,
          -3028.9509999999996,
          -3155.6290000000004,
          -3281.14,
          -3405.4840000000004,
          -3528.663,
          -3650.677,
          -3771.531,
          -3891.2270000000003,
          -4009.77,
          -4127.166,
          -4243.42,
          -4358.54,
          -4472.53,
          -4585.399,
          -4697.153,
          -4807.8,
          -4917.349,
          -5025.806,
          -5133.179,
          -5239.479,
          -5344.7119999999995,
          -5448.887,
          -5552.012,
          -5654.096,
          -5755.147,
          -5855.174,
          -5954.185,
          -6052.189,
          -6149.193,
          -6245.206,
          -6340.236999999999,
          -6434.294,
          -6527.385,
          -6619.517,
          -6710.6990000000005,
          -6800.939,
          -6890.244000000001,
          -6978.621999999999,
          -7066.08,
          -7152.6269999999995,
          -7238.27,
          -7323.016,
          -7406.871999999999,
          -7489.845,
          -7571.943,
          -7653.172,
          -7733.539000000001,
          -7813.052,
          -7891.715,
          -7969.536999999999,
          -8046.522,
          -8122.679,
          -8198.011999999999,
          -8272.529,
          -8346.235,
          -8419.136999999999,
          -8491.239,
          -8562.549,
          -8633.071,
          -8702.81,
          -8771.774,
          -8839.966999999999,
          -8907.393,
          -8974.059000000001,
          -9039.971,
          -9105.132,
          -9169.548,
          -9233.224,
          -9296.164,
          -9358.374,
          -9419.859,
          -9480.621,
          -9540.668,
          -9600.001,
          -9658.627,
          -9716.55,
          -9773.773000000001,
          -9830.301,
          -9886.138,
          -9941.288,
          -9995.755,
          -10049.543,
          -10102.657,
          -10155.098,
          -10206.873,
          -10257.983,
          -10308.434000000001,
          -10358.226999999999,
          -10407.368,
          -10455.859,
          -10503.703000000001,
          -10550.905,
          -10597.466,
          -10643.391000000001,
          -10688.683,
          -10733.345,
          -10777.38,
          -10820.792,
          -10863.582,
          -10905.753999999999,
          -10947.311000000002,
          -10988.256000000001,
          -11028.591,
          -11068.32,
          -11107.445,
          -11145.968,
          -11183.893,
          -11221.221000000001,
          -11257.956,
          -11294.1,
          -11329.655,
          -11364.624,
          -11399.01,
          -11432.813999999998,
          -11466.038999999999,
          -11498.688,
          -11530.761,
          -11562.263,
          -11593.194,
          -11623.556999999999,
          -11653.355,
          -11682.588,
          -11711.26,
          -11739.371000000001,
          -11766.925,
          -11793.923,
          -11820.366000000002,
          -11846.257,
          -11871.598,
          -11896.391000000001,
          -11920.636999999999,
          -11944.338,
          -11967.495,
          -11990.111,
          -12012.187,
          -12033.723999999998,
          -12054.725,
          -12075.191,
          -12095.123,
          -12114.523000000001,
          -12133.392,
          -12151.733,
          -12169.545,
          -12186.832,
          -12203.593,
          -12219.831,
          -12235.546,
          -12250.741000000002,
          -12265.416000000001,
          -12279.573,
          -12293.213,
          -12306.337,
          -12318.946000000002,
          -12331.042,
          -12342.625,
          -12353.698,
          -12364.26,
          -12374.313,
          -12383.858999999999,
          -12392.896999999999,
          -12401.428999999998,
          -12409.457,
          -12416.98,
          -12424.001,
          -12430.52,
          -12436.537,
          -12442.053,
          -12447.071000000002,
          -12451.59,
          -12455.611,
          -12459.136,
          -12462.163999999999,
          -12464.697,
          -12466.735,
          -12468.28,
          -12469.331,
          -12469.89,
          -12469.957,
          -12469.533000000001,
          -12468.618,
          -12467.214,
          -12465.32,
          -12462.938,
          -12460.067,
          -12456.708999999999,
          -12452.863000000001,
          -12448.531,
          -12443.713,
          -12438.409,
          -12432.618999999999,
          -12426.346000000001,
          -12419.588,
          -12412.346000000001,
          -12404.62,
          -12396.412,
          -12387.72,
          -12378.546,
          -12368.89,
          -12358.752,
          -12348.133,
          -12337.032,
          -12325.45,
          -12313.386999999999,
          -12300.843,
          -12287.819,
          -12274.315,
          -12260.33,
          -12245.865,
          -12230.921,
          -12215.496000000001,
          -12199.593,
          -12183.208999999999,
          -12166.347,
          -12149.003999999999,
          -12131.183,
          -12112.882,
          -12094.101,
          -12074.841,
          -12055.101999999999,
          -12034.883,
          -12014.184,
          -11993.006000000001,
          -11971.348,
          -11949.21,
          -11926.591999999999,
          -11903.493999999999,
          -11879.915,
          -11855.856000000002,
          -11831.316,
          -11806.295,
          -11780.793,
          -11754.809,
          -11728.343,
          -11701.396,
          -11673.966,
          -11646.053999999998,
          -11617.658000000001,
          -11588.78,
          -11559.417,
          -11529.571000000002,
          -11499.24,
          -11468.423999999999,
          -11437.122,
          -11405.335,
          -11373.062,
          -11340.302,
          -11307.053999999998,
          -11273.319,
          -11239.095,
          -11204.382,
          -11169.18,
          -11133.487,
          -11097.303999999998,
          -11060.63,
          -11023.464,
          -10985.805,
          -10947.652,
          -10909.006000000001,
          -10869.865,
          -10830.228000000001,
          -10790.095,
          -10749.466,
          -10708.338,
          -10666.711000000001,
          -10624.586000000001,
          -10581.958999999999,
          -10538.832,
          -10495.203000000001,
          -10451.07,
          -10406.434000000001,
          -10361.293,
          -10315.645,
          -10269.491,
          -10222.829,
          -10175.659,
          -10127.978000000001,
          -10079.787,
          -10031.083,
          -9981.867,
          -9932.136,
          -9881.89,
          -9831.127,
          -9779.847,
          -9728.046999999999,
          -9675.728000000001,
          -9622.886999999999,
          -9569.523000000001,
          -9515.635,
          -9461.222,
          -9406.283000000001,
          -9350.815,
          -9294.818000000001,
          -9238.29,
          -9181.231,
          -9123.636999999999,
          -9065.509,
          -9006.845,
          -8947.642,
          -8887.9,
          -8827.617,
          -8766.791,
          -8705.421,
          -8643.506,
          -8581.043,
          -8518.030999999999,
          -8454.469000000001,
          -8390.354,
          -8325.685,
          -8260.46,
          -8194.678,
          -8128.335999999999,
          -8061.433000000001,
          -7993.968000000001,
          -7925.938,
          -7857.340999999999,
          -7788.1759999999995,
          -7718.441999999999,
          -7648.134,
          -7577.253000000001,
          -7505.795999999999,
          -7433.762,
          -7361.147,
          -7287.951,
          -7214.170999999999,
          -7139.805,
          -7064.852,
          -6989.308000000001,
          -6913.173000000001,
          -6836.444,
          -6759.12,
          -6681.198,
          -6602.6759999999995,
          -6523.552,
          -6443.825,
          -6363.491,
          -6282.55,
          -6200.999,
          -6118.835,
          -6036.058000000001,
          -5952.665,
          -5868.654,
          -5784.023,
          -5698.771,
          -5612.894,
          -5526.393,
          -5439.263000000001,
          -5351.505999999999,
          -5263.116999999999,
          -5174.097,
          -5084.442,
          -4994.152,
          -4903.225,
          -4811.66,
          -4719.456,
          -4626.611,
          -4533.125,
          -4438.996,
          -4344.224,
          -4248.808,
          -4152.748,
          -4056.0429999999997,
          -3958.6940000000004,
          -3860.7,
          -3762.063,
          -3662.782,
          -3562.86,
          -3462.296,
          -3361.093,
          -3259.252,
          -3156.776,
          -3053.6679999999997,
          -2949.9320000000002,
          -2845.57,
          -2740.587,
          -2634.989,
          -2528.781,
          -2421.969,
          -2314.56,
          -2206.564,
          -2097.988,
          -1988.8429999999998,
          -1879.14,
          -1768.892,
          -1658.1129999999998,
          -1546.817,
          -1435.021,
          -1322.745,
          -1210.009,
          -1096.836,
          -983.2510000000001,
          -869.2810000000001,
          -754.957,
          -640.313,
          -525.386,
          -410.216,
          -294.847,
          -179.331,
          -63.718999999999994,
          51.927,
          167.542,
          283.055,
          398.385,
          513.445,
          628.139,
          742.3610000000001,
          855.995,
          968.913,
          1080.973,
          1192.021,
          1301.886,
          1410.382,
          1517.3029999999999,
          1622.4260000000002,
          1725.504,
          1826.2679999999998,
          1924.4260000000002,
          2019.6589999999999,
          2111.624,
          2199.946,
          2284.23,
          2364.047,
          2438.945,
          2508.449,
          2572.065,
          2629.282,
          2679.585,
          2722.458,
          2757.3990000000003,
          2783.929,
          2801.6090000000004,
          2810.0490000000004,
          2808.93,
          2798.01,
          2777.1420000000003,
          2746.2740000000003,
          2705.465,
          2654.8740000000003,
          2594.762,
          2525.4829999999997,
          2447.469,
          2361.22,
          2267.2870000000003,
          2166.255,
          2058.725,
          1945.306,
          1826.5970000000002,
          1703.185,
          1575.625,
          1444.4489999999998,
          1310.15,
          1173.187,
          1033.984,
          892.925,
          750.362,
          606.613,
          461.961,
          316.665,
          170.952,
          25.026999999999997,
          -120.928,
          -266.753,
          -412.306,
          -557.461,
          -702.1060000000001,
          -846.1460000000001,
          -989.4939999999999,
          -1132.076,
          -1273.827,
          -1414.691,
          -1554.618,
          -1693.567,
          -1831.5,
          -1968.3870000000002,
          -2104.203,
          -2238.925,
          -2372.535,
          -2505.018,
          -2636.361,
          -2766.555,
          -2895.594,
          -3023.47,
          -3150.183,
          -3275.73,
          -3400.111,
          -3523.325,
          -3645.3759999999997,
          -3766.2670000000003,
          -3886,
          -4004.5820000000003,
          -4122.015,
          -4238.307,
          -4353.464,
          -4467.4929999999995,
          -4580.4,
          -4692.192,
          -4802.878,
          -4912.464,
          -5020.96,
          -5128.371,
          -5234.709,
          -5339.98,
          -5444.193,
          -5547.357,
          -5649.479,
          -5750.568,
          -5850.633000000001,
          -5949.682,
          -6047.723000000001,
          -6144.765,
          -6240.816,
          -6335.884,
          -6429.978,
          -6523.106,
          -6615.276,
          -6706.495,
          -6796.772,
          -6886.1140000000005,
          -6974.529,
          -7062.024,
          -7148.607,
          -7234.286,
          -7319.069,
          -7402.960999999999,
          -7485.97,
          -7568.104,
          -7649.369000000001,
          -7729.772,
          -7809.32,
          -7888.019,
          -7965.876,
          -8042.897,
          -8119.088000000001,
          -8194.457,
          -8269.009,
          -8342.75,
          -8415.686,
          -8487.823,
          -8559.167,
          -8629.724,
          -8699.498,
          -8768.496,
          -8836.722,
          -8904.183,
          -8970.883,
          -9036.828000000001,
          -9102.023000000001,
          -9166.473,
          -9230.181999999999,
          -9293.155999999999,
          -9355.399,
          -9416.917,
          -9477.713,
          -9537.792,
          -9597.159,
          -9655.818000000001,
          -9713.773000000001,
          -9771.029,
          -9827.589,
          -9883.458,
          -9938.64,
          -9993.14,
          -10046.961,
          -10100.106,
          -10152.58,
          -10204.386,
          -10255.529,
          -10306.011,
          -10355.836,
          -10405.008,
          -10453.530999999999,
          -10501.407,
          -10548.639,
          -10595.232,
          -10641.188,
          -10686.511999999999,
          -10731.205,
          -10775.271,
          -10818.713,
          -10861.534,
          -10903.737,
          -10945.325,
          -10986.3,
          -11026.666000000001,
          -11066.425,
          -11105.58,
          -11144.133999999998,
          -11182.089,
          -11219.448,
          -11256.213,
          -11292.386999999999,
          -11327.972,
          -11362.971000000001,
          -11397.386,
          -11431.22,
          -11464.475,
          -11497.153,
          -11529.257,
          -11560.788,
          -11591.749,
          -11622.141000000001,
          -11651.968,
          -11681.231000000002,
          -11709.931,
          -11738.072,
          -11765.655,
          -11792.681999999999,
          -11819.155,
          -11845.075,
          -11870.444,
          -11895.266000000001,
          -11919.54,
          -11943.27,
          -11966.456,
          -11989.101,
          -12011.205,
          -12032.771,
          -12053.8,
          -12074.295,
          -12094.255,
          -12113.683,
          -12132.581,
          -12150.948999999999,
          -12168.79,
          -12186.105,
          -12202.893999999998,
          -12219.16,
          -12234.903,
          -12250.126,
          -12264.828000000001,
          -12279.013,
          -12292.681,
          -12305.833,
          -12318.47,
          -12330.593,
          -12342.204,
          -12353.303999999998,
          -12363.893999999998,
          -12373.975,
          -12383.546999999999,
          -12392.613000000001,
          -12401.173,
          -12409.226999999999,
          -12416.777,
          -12423.825,
          -12430.371000000001,
          -12436.415,
          -12441.958999999999,
          -12447.003999999999,
          -12451.55,
          -12455.598,
          -12459.149,
          -12462.205,
          -12464.764,
          -12466.829,
          -12468.401000000002,
          -12469.479,
          -12470.063999999998,
          -12470.158000000001,
          -12469.76,
          -12468.872,
          -12467.493999999999,
          -12465.627,
          -12463.271,
          -12460.426000000001,
          -12457.094,
          -12453.275,
          -12448.969,
          -12444.177,
          -12438.9,
          -12433.136999999999,
          -12426.889,
          -12420.157,
          -12412.941,
          -12405.241000000002,
          -12397.058,
          -12388.393,
          -12379.245,
          -12369.614,
          -12359.502,
          -12348.908000000001,
          -12337.833,
          -12326.277,
          -12314.239,
          -12301.721000000001,
          -12288.723,
          -12275.243999999999,
          -12261.285,
          -12246.846000000001,
          -12231.927,
          -12216.528999999999,
          -12200.65,
          -12184.292,
          -12167.455,
          -12150.138,
          -12132.341999999999,
          -12114.066,
          -12095.31,
          -12076.076000000001,
          -12056.361,
          -12036.167,
          -12015.493999999999,
          -11994.341,
          -11972.707,
          -11950.594,
          -11928.001,
          -11904.927,
          -11881.373,
          -11857.339,
          -11832.823999999999,
          -11807.828000000001,
          -11782.35,
          -11756.392,
          -11729.951000000001,
          -11703.028,
          -11675.623,
          -11647.735,
          -11619.364,
          -11590.51,
          -11561.171999999999,
          -11531.35,
          -11501.044,
          -11470.252,
          -11438.975,
          -11407.212,
          -11374.963,
          -11342.226999999999,
          -11309.003999999999,
          -11275.293,
          -11241.093,
          -11206.405,
          -11171.226999999999,
          -11135.559,
          -11099.4,
          -11062.75,
          -11025.607,
          -10987.972,
          -10949.843,
          -10911.221000000001,
          -10872.104,
          -10832.491000000002,
          -10792.382,
          -10751.776000000002,
          -10710.671999999999,
          -10669.069,
          -10626.966999999999,
          -10584.365,
          -10541.261,
          -10497.655,
          -10453.546,
          -10408.934000000001,
          -10363.815999999999,
          -10318.192,
          -10272.062,
          -10225.424,
          -10178.277,
          -10130.62,
          -10082.452,
          -10033.771999999999,
          -9984.579,
          -9934.871,
          -9884.648000000001,
          -9833.909,
          -9782.652,
          -9730.875,
          -9678.578000000001,
          -9625.76,
          -9572.42,
          -9518.555,
          -9464.165,
          -9409.249,
          -9353.804,
          -9297.83,
          -9241.326,
          -9184.289,
          -9126.719000000001,
          -9068.614,
          -9009.972,
          -8950.792,
          -8891.073,
          -8830.812,
          -8770.009,
          -8708.662,
          -8646.769,
          -8584.329,
          -8521.34,
          -8457.8,
          -8393.707,
          -8329.061,
          -8263.858,
          -8198.099,
          -8131.78,
          -8064.899,
          -7997.456,
          -7929.448,
          -7860.8730000000005,
          -7791.731,
          -7722.018,
          -7651.733,
          -7580.874,
          -7509.439,
          -7437.4259999999995,
          -7364.834,
          -7291.659000000001,
          -7217.901,
          -7143.557,
          -7068.625,
          -6993.104,
          -6916.991,
          -6840.284000000001,
          -6762.981,
          -6685.08,
          -6606.58,
          -6527.477,
          -6447.771,
          -6367.459,
          -6286.539000000001,
          -6205.008000000001,
          -6122.865,
          -6040.109,
          -5956.736,
          -5872.746,
          -5788.1359999999995,
          -5702.904,
          -5617.048000000001,
          -5530.566999999999,
          -5443.459,
          -5355.721,
          -5267.353,
          -5178.353,
          -5088.718,
          -4998.448,
          -4907.541,
          -4815.995,
          -4723.81,
          -4630.985,
          -4537.517,
          -4443.407,
          -4348.654,
          -4253.2570000000005,
          -4157.215,
          -4060.5290000000005,
          -3963.197,
          -3865.2209999999995,
          -3766.6009999999997,
          -3667.3379999999997,
          -3567.4320000000002,
          -3466.885,
          -3365.698,
          -3263.8740000000003,
          -3161.414,
          -3058.322,
          -2954.6,
          -2850.2529999999997,
          -2745.284,
          -2639.7,
          -2533.505,
          -2426.706,
          -2319.31,
          -2211.326,
          -2102.761,
          -1993.6270000000002,
          -1883.934,
          -1773.694,
          -1662.9229999999998,
          -1551.634,
          -1439.845,
          -1327.5729999999999,
          -1214.8410000000001,
          -1101.671,
          -988.087,
          -874.118,
          -759.793,
          -645.146,
          -530.214,
          -415.038,
          -299.66200000000003,
          -184.13400000000001,
          -68.51,
          47.152,
          162.785,
          278.319,
          393.67400000000004,
          508.76300000000003,
          623.49,
          737.7489999999999,
          851.424,
          964.388,
          1076.5,
          1187.606,
          1297.537,
          1406.105,
          1513.1070000000002,
          1618.319,
          1721.495,
          1822.369,
          1920.646,
          2016.0120000000002,
          2108.1220000000003,
          2196.605,
          2281.062,
          2361.069,
          2436.174,
          2505.903,
          2569.761,
          2627.24,
          2677.823,
          2720.9959999999996,
          2756.2529999999997,
          2783.117,
          2801.1459999999997,
          2809.948,
          2809.203,
          2798.664,
          2778.18,
          2747.699,
          2707.272,
          2657.0570000000002,
          2597.312,
          2528.384,
          2450.7070000000003,
          2364.777,
          2271.143,
          2170.386,
          2063.112,
          1949.925,
          1831.4289999999999,
          1708.2079999999999,
          1580.819,
          1449.7939999999999,
          1315.63,
          1178.785,
          1039.684,
          898.7139999999999,
          756.225,
          612.539,
          467.94,
          322.687,
          177.00799999999998,
          31.11,
          -114.82600000000001,
          -260.639,
          -406.184,
          -551.337,
          -695.985,
          -840.0319999999999,
          -983.39,
          -1125.986,
          -1267.754,
          -1408.6370000000002,
          -1548.7079999999999,
          -1687.559,
          -1825.519,
          -1962.434,
          -2098.279,
          -2233.032,
          -2366.674,
          -2499.189,
          -2630.566,
          -2760.795,
          -2889.869,
          -3017.782,
          -3144.532,
          -3270.116,
          -3394.534,
          -3517.7870000000003,
          -3639.8759999999997,
          -3760.805,
          -3880.578,
          -3999.198,
          -4116.6720000000005,
          -4233.003,
          -4348.2,
          -4462.269,
          -4575.215,
          -4687.045999999999,
          -4797.772,
          -4907.398,
          -5015.934,
          -5123.3859999999995,
          -5229.764,
          -5335.075,
          -5439.328,
          -5542.531,
          -5644.691999999999,
          -5745.821,
          -5845.9259999999995,
          -5945.014,
          -6043.094,
          -6140.175,
          -6236.265,
          -6331.3730000000005,
          -6425.505999999999,
          -6518.673000000001,
          -6610.880999999999,
          -6702.138000000001,
          -6792.453,
          -6881.834,
          -6970.286999999999,
          -7057.821,
          -7144.441999999999,
          -7230.16,
          -7314.979,
          -7398.909000000001,
          -7481.956,
          -7564.1269999999995,
          -7645.429,
          -7725.869000000001,
          -7805.453,
          -7884.189,
          -7962.0830000000005,
          -8039.141,
          -8115.369000000001,
          -8190.775,
          -8265.363000000001,
          -8339.14,
          -8412.112,
          -8484.285,
          -8555.665,
          -8626.257,
          -8696.065999999999,
          -8765.1,
          -8833.360999999999,
          -8900.857,
          -8967.591999999999,
          -9033.573,
          -9098.802,
          -9163.287,
          -9227.030999999999,
          -9290.04,
          -9352.317,
          -9413.869,
          -9474.699,
          -9534.812,
          -9594.213,
          -9652.905999999999,
          -9710.895,
          -9768.185,
          -9824.779,
          -9880.681999999999,
          -9935.898000000001,
          -9990.431,
          -10044.285,
          -10097.463,
          -10149.97,
          -10201.809000000001,
          -10252.984,
          -10303.499,
          -10353.357,
          -10402.561,
          -10451.116,
          -10499.025,
          -10546.29,
          -10592.915,
          -10638.903999999999,
          -10684.258999999998,
          -10728.985,
          -10773.083,
          -10816.556999999999,
          -10859.409,
          -10901.643999999998,
          -10943.263,
          -10984.27,
          -11024.668,
          -11064.458,
          -11103.645,
          -11142.229,
          -11180.215,
          -11217.604,
          -11254.401000000002,
          -11290.606000000002,
          -11326.222,
          -11361.252,
          -11395.698,
          -11429.563,
          -11462.848,
          -11495.556999999999,
          -11527.691,
          -11559.252,
          -11590.243,
          -11620.666000000001,
          -11650.523000000001,
          -11679.816,
          -11708.546,
          -11736.716999999999,
          -11764.33,
          -11791.386999999999,
          -11817.889,
          -11843.839,
          -11869.239,
          -11894.09,
          -11918.393999999998,
          -11942.153,
          -11965.368999999999,
          -11988.042,
          -12010.176000000001,
          -12031.771,
          -12052.829,
          -12073.351999999999,
          -12093.341999999999,
          -12112.798999999999,
          -12131.726,
          -12150.123,
          -12167.993,
          -12185.336000000001,
          -12202.153999999999,
          -12218.448999999999,
          -12234.221000000001,
          -12249.472,
          -12264.204,
          -12278.417,
          -12292.113000000001,
          -12305.293,
          -12317.958,
          -12330.11,
          -12341.749,
          -12352.877,
          -12363.495,
          -12373.604,
          -12383.205,
          -12392.298,
          -12400.886,
          -12408.968,
          -12416.546,
          -12423.621000000001,
          -12430.195,
          -12436.267,
          -12441.838,
          -12446.911,
          -12451.483999999999,
          -12455.56,
          -12459.139,
          -12462.221000000001,
          -12464.808,
          -12466.901000000002,
          -12468.499,
          -12469.604,
          -12470.216999999999,
          -12470.338,
          -12469.966999999999,
          -12469.106000000002,
          -12467.755,
          -12465.915,
          -12463.585,
          -12460.768,
          -12457.463,
          -12453.67,
          -12449.391000000001,
          -12444.626,
          -12439.375,
          -12433.639,
          -12427.418,
          -12420.712,
          -12413.521999999999,
          -12405.848999999998,
          -12397.692,
          -12389.053,
          -12379.931,
          -12370.327,
          -12360.241000000002,
          -12349.673,
          -12338.624,
          -12327.094,
          -12315.083,
          -12302.591,
          -12289.618,
          -12276.165,
          -12262.232,
          -12247.819,
          -12232.926000000001,
          -12217.553,
          -12201.701000000001,
          -12185.368999999999,
          -12168.556999999999,
          -12151.266000000001,
          -12133.495,
          -12115.243999999999,
          -12096.515,
          -12077.305,
          -12057.617,
          -12037.448,
          -12016.8,
          -11995.671999999999,
          -11974.063999999998,
          -11951.976,
          -11929.408000000001,
          -11906.36,
          -11882.831,
          -11858.822,
          -11834.332,
          -11809.361,
          -11783.908000000001,
          -11757.973999999998,
          -11731.559,
          -11704.661,
          -11677.281,
          -11649.418,
          -11621.072,
          -11592.242,
          -11562.928999999998,
          -11533.132,
          -11502.85,
          -11472.083,
          -11440.831,
          -11409.093,
          -11376.868,
          -11344.156,
          -11310.958,
          -11277.271,
          -11243.096000000001,
          -11208.431999999999,
          -11173.278,
          -11137.633999999998,
          -11101.5,
          -11064.874,
          -11027.756000000001,
          -10990.143999999998,
          -10952.04,
          -10913.442,
          -10874.348,
          -10834.76,
          -10794.675,
          -10754.093,
          -10713.013,
          -10671.434,
          -10629.356000000002,
          -10586.777,
          -10543.697,
          -10500.115,
          -10456.03,
          -10411.440999999999,
          -10366.347,
          -10320.748,
          -10274.641,
          -10228.026,
          -10180.903,
          -10133.269,
          -10085.125,
          -10036.468,
          -9987.298,
          -9937.614,
          -9887.415,
          -9836.699,
          -9785.465,
          -9733.711,
          -9681.438,
          -9628.643,
          -9575.326,
          -9521.484,
          -9467.117,
          -9412.224,
          -9356.802,
          -9300.851999999999,
          -9244.37,
          -9187.356,
          -9129.809000000001,
          -9071.726,
          -9013.107,
          -8953.95,
          -8894.254,
          -8834.016,
          -8773.235999999999,
          -8711.911,
          -8650.041,
          -8587.623,
          -8524.657,
          -8461.139000000001,
          -8397.069,
          -8332.445,
          -8267.265,
          -8201.528,
          -8135.231,
          -8068.3730000000005,
          -8000.951,
          -7932.965,
          -7864.4130000000005,
          -7795.293000000001,
          -7725.602,
          -7655.339,
          -7584.5019999999995,
          -7513.089,
          -7441.097,
          -7368.526999999999,
          -7295.374,
          -7221.637,
          -7147.315,
          -7072.405,
          -6996.905,
          -6920.813,
          -6844.128000000001,
          -6766.846,
          -6688.967,
          -6610.486999999999,
          -6531.406,
          -6451.721,
          -6371.43,
          -6290.53,
          -6209.021,
          -6126.898,
          -6044.161999999999,
          -5960.811,
          -5876.840999999999,
          -5792.251,
          -5707.04,
          -5621.204000000001,
          -5534.743,
          -5447.655,
          -5359.937,
          -5271.589,
          -5182.608,
          -5092.9929999999995,
          -5002.742,
          -4911.854,
          -4820.3279999999995,
          -4728.162,
          -4635.355,
          -4541.906,
          -4447.815,
          -4353.08,
          -4257.701,
          -4161.677,
          -4065.008,
          -3967.6940000000004,
          -3869.736,
          -3771.133,
          -3671.886,
          -3571.9970000000003,
          -3471.466,
          -3370.295,
          -3268.486,
          -3166.042,
          -3062.9640000000004,
          -2959.257,
          -2854.9240000000004,
          -2749.969,
          -2644.3979999999997,
          -2538.216,
          -2431.429,
          -2324.045,
          -2216.071,
          -2107.5170000000003,
          -1998.3929999999998,
          -1888.7089999999998,
          -1778.4779999999998,
          -1667.714,
          -1556.432,
          -1444.648,
          -1332.381,
          -1219.653,
          -1106.485,
          -992.9019999999999,
          -878.932,
          -764.6060000000001,
          -649.956,
          -535.019,
          -419.835,
          -304.45,
          -188.912,
          -73.274,
          42.403999999999996,
          158.05700000000002,
          273.612,
          388.99300000000005,
          504.11,
          618.869,
          733.166,
          846.883,
          959.8939999999999,
          1072.058,
          1183.222,
          1293.218,
          1401.859,
          1508.941,
          1614.2420000000002,
          1717.516,
          1818.4979999999998,
          1916.894,
          2012.391,
          2104.645,
          2193.286,
          2277.916,
          2358.111,
          2433.4210000000003,
          2503.371,
          2567.47,
          2625.2070000000003,
          2676.066,
          2719.534,
          2755.1040000000003,
          2782.298,
          2800.671,
          2809.8309999999997,
          2809.455,
          2799.292,
          2779.1890000000003,
          2749.09,
          2709.042,
          2659.199,
          2599.815,
          2531.237,
          2453.893,
          2368.278,
          2274.939,
          2174.4570000000003,
          2067.436,
          1954.481,
          1836.1960000000001,
          1713.165,
          1585.9460000000001,
          1455.0729999999999,
          1321.043,
          1184.316,
          1045.317,
          904.435,
          762.0219999999999,
          618.399,
          473.85400000000004,
          328.644,
          183,
          37.129,
          -108.787,
          -254.58599999999998,
          -400.124,
          -545.274,
          -689.924,
          -833.9760000000001,
          -977.345,
          -1119.953,
          -1261.737,
          -1402.639,
          -1542.609,
          -1681.605,
          -1819.59,
          -1956.533,
          -2092.406,
          -2227.189,
          -2360.861,
          -2493.409,
          -2624.8190000000004,
          -2755.0820000000003,
          -2884.191,
          -3012.139,
          -3138.9240000000004,
          -3264.545,
          -3389,
          -3512.29,
          -3634.417,
          -3755.384,
          -3875.195,
          -3993.8540000000003,
          -4111.366,
          -4227.737,
          -4342.973,
          -4457.08,
          -4570.065,
          -4681.936,
          -4792.701,
          -4902.367,
          -5010.942,
          -5118.433,
          -5224.85,
          -5330.2,
          -5434.491999999999,
          -5537.735,
          -5639.936,
          -5741.103,
          -5841.246999999999,
          -5940.374,
          -6038.493,
          -6135.613,
          -6231.741999999999,
          -6326.888000000001,
          -6421.059,
          -6514.264,
          -6606.5109999999995,
          -6697.807,
          -6788.16,
          -6877.578,
          -6966.069,
          -7053.641,
          -7140.3,
          -7226.055,
          -7310.911999999999,
          -7394.879,
          -7477.963000000001,
          -7560.17,
          -7641.509,
          -7721.986,
          -7801.608,
          -7880.38,
          -7958.31,
          -8035.404,
          -8111.669,
          -8187.11,
          -8261.735,
          -8335.548,
          -8408.556,
          -8480.764000000001,
          -8552.18,
          -8622.806999999999,
          -8692.652,
          -8761.72,
          -8830.017,
          -8897.548,
          -8964.318000000001,
          -9030.333,
          -9095.598,
          -9160.117,
          -9223.895,
          -9286.938,
          -9349.25,
          -9410.836,
          -9471.7,
          -9531.848,
          -9591.282,
          -9650.009,
          -9708.030999999999,
          -9765.355,
          -9821.982,
          -9877.919,
          -9933.168,
          -9987.734,
          -10041.621,
          -10094.833,
          -10147.372,
          -10199.244,
          -10250.452,
          -10301,
          -10350.89,
          -10400.128,
          -10448.715,
          -10496.655,
          -10543.953000000001,
          -10590.61,
          -10636.631000000001,
          -10682.018999999998,
          -10726.776000000002,
          -10770.906,
          -10814.412,
          -10857.296,
          -10899.562,
          -10941.213,
          -10982.252,
          -11022.68,
          -11062.502,
          -11101.72,
          -11140.336000000001,
          -11178.351999999999,
          -11215.773000000001,
          -11252.6,
          -11288.836000000001,
          -11324.483,
          -11359.544,
          -11394.021,
          -11427.916000000001,
          -11461.232,
          -11493.971000000001,
          -11526.135,
          -11557.726999999999,
          -11588.748,
          -11619.202,
          -11649.088,
          -11678.411,
          -11707.171999999999,
          -11735.373,
          -11763.016000000001,
          -11790.101999999999,
          -11816.633999999998,
          -11842.614,
          -11868.044,
          -11892.923999999999,
          -11917.258,
          -11941.046999999999,
          -11964.292,
          -11986.993999999999,
          -12009.157,
          -12030.781,
          -12051.868999999999,
          -12072.421,
          -12092.44,
          -12111.926000000001,
          -12130.882,
          -12149.308,
          -12167.206,
          -12184.578000000001,
          -12201.425,
          -12217.749,
          -12233.548999999999,
          -12248.829,
          -12263.59,
          -12277.831,
          -12291.556,
          -12304.764,
          -12317.458,
          -12329.638,
          -12341.305,
          -12352.462,
          -12363.108,
          -12373.243999999999,
          -12382.873,
          -12391.995,
          -12400.61,
          -12408.72,
          -12416.326000000001,
          -12423.428999999998,
          -12430.03,
          -12436.13,
          -12441.729,
          -12446.829,
          -12451.43,
          -12455.534,
          -12459.14,
          -12462.25,
          -12464.864,
          -12466.983999999999,
          -12468.61,
          -12469.742,
          -12470.382,
          -12470.53,
          -12470.187,
          -12469.353000000001,
          -12468.028999999999,
          -12466.215,
          -12463.913,
          -12461.122,
          -12457.844,
          -12454.078000000001,
          -12449.826000000001,
          -12445.087,
          -12439.863000000001,
          -12434.153,
          -12427.958999999999,
          -12421.28,
          -12414.117,
          -12406.47,
          -12398.34,
          -12389.726999999999,
          -12380.632,
          -12371.053999999998,
          -12360.993999999999,
          -12350.453000000001,
          -12339.43,
          -12327.926000000001,
          -12315.94,
          -12303.475,
          -12290.528,
          -12277.101,
          -12263.194,
          -12248.806999999999,
          -12233.94,
          -12218.593,
          -12202.766000000001,
          -12186.46,
          -12169.673999999999,
          -12152.408000000001,
          -12134.663,
          -12116.438999999998,
          -12097.733999999999,
          -12078.551000000001,
          -12058.886999999999,
          -12038.743999999999,
          -12018.122,
          -11997.018999999998,
          -11975.437,
          -11953.374,
          -11930.831,
          -11907.808,
          -11884.305,
          -11860.321000000002,
          -11835.856000000002,
          -11810.91,
          -11785.483,
          -11759.573999999999,
          -11733.183,
          -11706.311000000002,
          -11678.955,
          -11651.117,
          -11622.796,
          -11593.992,
          -11564.703000000001,
          -11534.931,
          -11504.673999999999,
          -11473.931999999999,
          -11442.704,
          -11410.99,
          -11378.79,
          -11346.104,
          -11312.928999999998,
          -11279.267,
          -11245.117,
          -11210.476999999999,
          -11175.348,
          -11139.728000000001,
          -11103.618,
          -11067.016000000001,
          -11029.923,
          -10992.336000000001,
          -10954.255,
          -10915.681,
          -10876.612,
          -10837.048,
          -10796.987,
          -10756.428999999998,
          -10715.373,
          -10673.818000000001,
          -10631.764,
          -10589.208999999999,
          -10546.153,
          -10502.595,
          -10458.534,
          -10413.969000000001,
          -10368.899,
          -10323.322,
          -10277.239,
          -10230.648000000001,
          -10183.549,
          -10135.939,
          -10087.818000000001,
          -10039.185,
          -9990.039,
          -9940.378,
          -9890.202,
          -9839.509,
          -9788.298,
          -9736.568000000001,
          -9684.318000000001,
          -9631.546,
          -9578.252,
          -9524.434000000001,
          -9470.09,
          -9415.22,
          -9359.822,
          -9303.894,
          -9247.435,
          -9190.444,
          -9132.92,
          -9074.86,
          -9016.264000000001,
          -8957.13,
          -8897.456,
          -8837.241,
          -8776.484,
          -8715.181999999999,
          -8653.334,
          -8590.939,
          -8527.995,
          -8464.5,
          -8400.452,
          -8335.85,
          -8270.693000000001,
          -8204.978000000001,
          -8138.703,
          -8071.866999999999,
          -8004.468000000001,
          -7936.504,
          -7867.974,
          -7798.876,
          -7729.206999999999,
          -7658.965999999999,
          -7588.151,
          -7516.759,
          -7444.79,
          -7372.241,
          -7299.11,
          -7225.395,
          -7151.094,
          -7076.206,
          -7000.727,
          -6924.656999999999,
          -6847.993,
          -6770.732,
          -6692.874,
          -6614.416,
          -6535.356,
          -6455.691999999999,
          -6375.420999999999,
          -6294.543000000001,
          -6213.054,
          -6130.951999999999,
          -6048.236999999999,
          -5964.906,
          -5880.956999999999,
          -5796.387,
          -5711.196,
          -5625.38,
          -5538.94,
          -5451.871,
          -5364.173000000001,
          -5275.844,
          -5186.883,
          -5097.287,
          -5007.056,
          -4916.187,
          -4824.68,
          -4732.532999999999,
          -4639.745,
          -4546.315,
          -4452.242,
          -4357.525,
          -4262.164000000001,
          -4166.157999999999,
          -4069.507,
          -3972.21,
          -3874.2690000000002,
          -3775.683,
          -3676.453,
          -3576.58,
          -3476.065,
          -3374.91,
          -3273.117,
          -3170.687,
          -3067.6240000000003,
          -2963.9309999999996,
          -2859.612,
          -2754.671,
          -2649.113,
          -2542.944,
          -2436.169,
          -2328.7960000000003,
          -2220.834,
          -2112.29,
          -2003.175,
          -1893.5,
          -1783.277,
          -1672.52,
          -1561.245,
          -1449.4660000000001,
          -1337.204,
          -1224.479,
          -1111.313,
          -997.7310000000001,
          -883.7610000000001,
          -769.433,
          -654.779,
          -539.837,
          -424.64599999999996,
          -309.252,
          -193.702,
          -78.05,
          37.644,
          153.315,
          268.893,
          384.29900000000004,
          499.44599999999997,
          614.238,
          728.571,
          842.33,
          955.388,
          1067.605,
          1178.828,
          1288.889,
          1397.602,
          1504.765,
          1610.155,
          1713.527,
          1814.6170000000002,
          1913.1329999999998,
          2008.761,
          2101.159,
          2189.9570000000003,
          2274.76,
          2355.143,
          2430.658,
          2500.83,
          2565.169,
          2623.165,
          2674.301,
          2718.0640000000003,
          2753.947,
          2781.4709999999995,
          2800.1890000000003,
          2809.708,
          2809.7009999999996,
          2799.9159999999997,
          2780.195,
          2750.4790000000003,
          2710.8109999999997,
          2661.342,
          2602.323,
          2534.095,
          2457.087,
          2371.7889999999998,
          2278.748,
          2178.5429999999997,
          2071.778,
          1959.057,
          1840.985,
          1718.146,
          1591.099,
          1460.38,
          1326.485,
          1189.877,
          1050.982,
          910.19,
          767.8539999999999,
          624.2959999999999,
          479.806,
          334.64,
          189.033,
          43.18899999999999,
          -102.706,
          -248.49,
          -394.02,
          -539.1659999999999,
          -683.817,
          -827.875,
          -971.253,
          -1113.874,
          -1255.673,
          -1396.594,
          -1536.585,
          -1675.604,
          -1813.6129999999998,
          -1950.5829999999999,
          -2086.485,
          -2221.297,
          -2355,
          -2487.58,
          -2619.0229999999997,
          -2749.32,
          -2878.4629999999997,
          -3006.446,
          -3133.268,
          -3258.925,
          -3383.417,
          -3506.744,
          -3628.909,
          -3749.915,
          -3869.764,
          -3988.461,
          -4106.012,
          -4222.4220000000005,
          -4337.697,
          -4451.843,
          -4564.8679999999995,
          -4676.779,
          -4787.583,
          -4897.288,
          -5005.902,
          -5113.434,
          -5219.89,
          -5325.28,
          -5429.611,
          -5532.893,
          -5635.133000000001,
          -5736.34,
          -5836.523,
          -5935.69,
          -6033.848000000001,
          -6131.005999999999,
          -6227.174,
          -6322.359,
          -6416.57,
          -6509.813,
          -6602.098000000001,
          -6693.433000000001,
          -6783.8240000000005,
          -6873.281,
          -6961.81,
          -7049.419,
          -7136.116999999999,
          -7221.909000000001,
          -7306.804,
          -7390.809,
          -7473.93,
          -7556.175,
          -7637.5509999999995,
          -7718.065,
          -7797.724,
          -7876.533,
          -7954.5,
          -8031.630999999999,
          -8107.932,
          -8183.41,
          -8258.071,
          -8331.92,
          -8404.964,
          -8477.209,
          -8548.66,
          -8619.323,
          -8689.204,
          -8758.308,
          -8826.64,
          -8894.206,
          -8961.011999999999,
          -9027.062,
          -9092.360999999999,
          -9156.915,
          -9220.729,
          -9283.806999999999,
          -9346.153,
          -9407.774,
          -9468.671999999999,
          -9528.854,
          -9588.323,
          -9647.084,
          -9705.14,
          -9762.498,
          -9819.159,
          -9875.13,
          -9930.413,
          -9985.011999999999,
          -10038.933,
          -10092.178,
          -10144.751,
          -10196.655999999999,
          -10247.896999999999,
          -10298.476999999999,
          -10348.401,
          -10397.671,
          -10446.291,
          -10494.265,
          -10541.595,
          -10588.285,
          -10634.339,
          -10679.758,
          -10724.548,
          -10768.71,
          -10812.248,
          -10855.165,
          -10897.463,
          -10939.146,
          -10980.216,
          -11020.677,
          -11060.53,
          -11099.778999999999,
          -11138.427,
          -11176.475,
          -11213.927,
          -11250.786,
          -11287.053,
          -11322.731000000002,
          -11357.823,
          -11392.331,
          -11426.258,
          -11459.605,
          -11492.375,
          -11524.57,
          -11556.192,
          -11587.243999999999,
          -11617.728000000001,
          -11647.646,
          -11676.999,
          -11705.79,
          -11734.021,
          -11761.694,
          -11788.811000000002,
          -11815.374,
          -11841.383999999998,
          -11866.843,
          -11891.753999999999,
          -11916.118,
          -11939.936000000002,
          -11963.211000000001,
          -11985.944,
          -12008.136,
          -12029.79,
          -12050.907,
          -12071.489,
          -12091.537,
          -12111.053,
          -12130.038,
          -12148.493999999999,
          -12166.421,
          -12183.823,
          -12200.698999999999,
          -12217.051000000001,
          -12232.881000000001,
          -12248.19,
          -12262.979,
          -12277.25,
          -12291.003,
          -12304.241000000002,
          -12316.963,
          -12329.171999999999,
          -12340.868,
          -12352.053,
          -12362.728000000001,
          -12372.893,
          -12382.55,
          -12391.7,
          -12400.344,
          -12408.483,
          -12416.117,
          -12423.248,
          -12429.877,
          -12436.005,
          -12441.633,
          -12446.761,
          -12451.39,
          -12455.521,
          -12459.155,
          -12462.293,
          -12464.936000000002,
          -12467.083,
          -12468.737,
          -12469.896999999999,
          -12470.563999999998,
          -12470.74,
          -12470.423999999999,
          -12469.618,
          -12468.321000000002,
          -12466.535,
          -12464.26,
          -12461.497,
          -12458.246000000001,
          -12454.508,
          -12450.283000000001,
          -12445.571000000002,
          -12440.374,
          -12434.692,
          -12428.524,
          -12421.873,
          -12414.737,
          -12407.117,
          -12399.013,
          -12390.427,
          -12381.358999999999,
          -12371.808,
          -12361.775,
          -12351.26,
          -12340.264,
          -12328.787,
          -12316.828000000001,
          -12304.389,
          -12291.469,
          -12278.069,
          -12264.188,
          -12249.827,
          -12234.987,
          -12219.666000000001,
          -12203.866000000002,
          -12187.586000000001,
          -12170.826000000001,
          -12153.586000000001,
          -12135.868,
          -12117.669,
          -12098.991000000002,
          -12079.833,
          -12060.196000000002,
          -12040.079,
          -12019.483,
          -11998.406,
          -11976.848999999998,
          -11954.813,
          -11932.296,
          -11909.298,
          -11885.821000000002,
          -11861.863000000001,
          -11837.423999999999,
          -11812.503,
          -11787.101999999999,
          -11761.218,
          -11734.853000000001,
          -11708.006000000001,
          -11680.676000000001,
          -11652.864,
          -11624.568000000001,
          -11595.788999999999,
          -11566.526000000002,
          -11536.778999999999,
          -11506.546999999999,
          -11475.83,
          -11444.628,
          -11412.938999999998,
          -11380.764,
          -11348.103000000001,
          -11314.954,
          -11281.317,
          -11247.191,
          -11212.576000000001,
          -11177.472,
          -11141.878,
          -11105.792,
          -11069.216,
          -11032.146999999999,
          -10994.583999999999,
          -10956.528999999999,
          -10917.979,
          -10878.935,
          -10839.395,
          -10799.358999999999,
          -10758.826000000001,
          -10717.794,
          -10676.264,
          -10634.235,
          -10591.704,
          -10548.673,
          -10505.139,
          -10461.101999999999,
          -10416.561,
          -10371.516,
          -10325.964,
          -10279.905,
          -10233.338,
          -10186.263,
          -10138.677,
          -10090.58,
          -10041.971,
          -9992.849,
          -9943.212,
          -9893.06,
          -9842.391,
          -9791.205,
          -9739.499,
          -9687.271999999999,
          -9634.524,
          -9581.254,
          -9527.46,
          -9473.14,
          -9418.293,
          -9362.918,
          -9307.014000000001,
          -9250.579,
          -9193.612,
          -9136.110999999999,
          -9078.075,
          -9019.502,
          -8960.391,
          -8900.741,
          -8840.549,
          -8779.815,
          -8718.537,
          -8656.712,
          -8594.34,
          -8531.419,
          -8467.947,
          -8403.923,
          -8339.344000000001,
          -8274.209,
          -8208.517,
          -8142.266,
          -8075.453,
          -8008.076999999999,
          -7940.135,
          -7871.628000000001,
          -7802.552,
          -7732.906,
          -7662.687,
          -7591.895,
          -7520.526,
          -7448.579000000001,
          -7376.053000000001,
          -7302.944,
          -7229.251,
          -7154.973000000001,
          -7080.106,
          -7004.65,
          -6928.602,
          -6851.96,
          -6774.721,
          -6696.885,
          -6618.4490000000005,
          -6539.41,
          -6459.768,
          -6379.519,
          -6298.661999999999,
          -6217.195,
          -6135.115,
          -6052.420999999999,
          -5969.111,
          -5885.182,
          -5800.634,
          -5715.464,
          -5629.669,
          -5543.249,
          -5456.201,
          -5368.524,
          -5280.215999999999,
          -5191.275,
          -5101.6990000000005,
          -5011.488,
          -4920.639,
          -4829.152,
          -4737.024,
          -4644.255999999999,
          -4550.845,
          -4456.791,
          -4362.093,
          -4266.751,
          -4170.763,
          -4074.131,
          -3976.8520000000003,
          -3878.929,
          -3780.36,
          -3681.1479999999997,
          -3581.292,
          -3480.7940000000003,
          -3379.656,
          -3277.8779999999997,
          -3175.465,
          -3072.4179999999997,
          -2968.74,
          -2864.4359999999997,
          -2759.509,
          -2653.9640000000004,
          -2547.808,
          -2441.0460000000003,
          -2333.686,
          -2225.735,
          -2117.202,
          -2008.0970000000002,
          -1898.432,
          -1788.2179999999998,
          -1677.469,
          -1566.2,
          -1454.4279999999999,
          -1342.171,
          -1229.45,
          -1116.287,
          -1002.706,
          -888.7360000000001,
          -774.4060000000001,
          -659.75,
          -544.802,
          -429.605,
          -314.202,
          -198.641,
          -82.976,
          32.735,
          148.42600000000002,
          264.026,
          379.457,
          494.63300000000004,
          609.4580000000001,
          723.829,
          837.6310000000001,
          950.7360000000001,
          1063.007,
          1174.2910000000002,
          1284.4180000000001,
          1393.2060000000001,
          1500.45,
          1605.931,
          1709.404,
          1810.605,
          1909.243,
          2005.006,
          2097.552,
          2186.513,
          2271.493,
          2352.07,
          2427.7960000000003,
          2498.197,
          2562.783,
          2621.0460000000003,
          2672.468,
          2716.5359999999996,
          2752.742,
          2780.607,
          2799.683,
          2809.573,
          2809.948,
          2800.554,
          2781.228,
          2751.909,
          2712.636,
          2663.554,
          2604.913,
          2537.05,
          2460.389,
          2375.4210000000003,
          2282.689,
          2182.772,
          2076.272,
          1963.795,
          1845.944,
          1723.3039999999999,
          1596.4370000000001,
          1465.8770000000002,
          1332.1229999999998,
          1195.638,
          1056.851,
          916.1519999999999,
          773.8969999999999,
          630.4069999999999,
          485.972,
          340.853,
          195.282,
          49.468,
          -96.406,
          -242.176,
          -387.69599999999997,
          -532.839,
          -677.492,
          -821.556,
          -964.944,
          -1107.579,
          -1249.395,
          -1390.3339999999998,
          -1530.0710000000001,
          -1669.39,
          -1807.4260000000002,
          -1944.424,
          -2080.355,
          -2215.198,
          -2348.9339999999997,
          -2481.547,
          -2613.024,
          -2743.3559999999998,
          -2872.535,
          -3000.5559999999996,
          -3127.415,
          -3253.111,
          -3377.6409999999996,
          -3501.008,
          -3623.212,
          -3744.257,
          -3864.1459999999997,
          -3982.884,
          -4100.475,
          -4216.9259999999995,
          -4332.241,
          -4446.428,
          -4559.494000000001,
          -4671.446,
          -4782.291,
          -4892.038,
          -5000.693,
          -5108.265,
          -5214.763,
          -5320.193,
          -5424.566,
          -5527.889,
          -5630.17,
          -5731.418000000001,
          -5831.641,
          -5930.847,
          -6029.045999999999,
          -6126.246,
          -6222.454000000001,
          -6317.68,
          -6411.93,
          -6505.214,
          -6597.539000000001,
          -6688.9130000000005,
          -6779.344,
          -6868.840999999999,
          -6957.409000000001,
          -7045.058000000001,
          -7131.795,
          -7217.626,
          -7302.56,
          -7386.603,
          -7469.763000000001,
          -7552.048000000001,
          -7633.4619999999995,
          -7714.015,
          -7793.7119999999995,
          -7872.559,
          -7950.564,
          -8027.733,
          -8104.071999999999,
          -8179.588000000001,
          -8254.286,
          -8328.173,
          -8401.254,
          -8473.536,
          -8545.024,
          -8615.724,
          -8685.642,
          -8754.782,
          -8823.151,
          -8890.754,
          -8957.596,
          -9023.683,
          -9089.018,
          -9153.608,
          -9217.458,
          -9280.571,
          -9342.954,
          -9404.61,
          -9465.544,
          -9525.761,
          -9585.265,
          -9644.061,
          -9702.153,
          -9759.545,
          -9816.242,
          -9872.247,
          -9927.565,
          -9982.199,
          -10036.154,
          -10089.433,
          -10142.04,
          -10193.98,
          -10245.255,
          -10295.87,
          -10345.828000000001,
          -10395.132,
          -10443.786,
          -10491.793,
          -10539.157,
          -10585.88,
          -10631.966999999999,
          -10677.42,
          -10722.243,
          -10766.438,
          -10810.008999999998,
          -10852.958999999999,
          -10895.29,
          -10937.006000000001,
          -10978.108999999999,
          -11018.601999999999,
          -11058.488000000001,
          -11097.77,
          -11136.45,
          -11174.531,
          -11212.015,
          -11248.906,
          -11285.205,
          -11320.916000000001,
          -11356.04,
          -11390.58,
          -11424.538,
          -11457.916000000001,
          -11490.718,
          -11522.945,
          -11554.598999999998,
          -11585.681999999999,
          -11616.198,
          -11646.146999999999,
          -11675.531,
          -11704.354,
          -11732.616000000002,
          -11760.32,
          -11787.468,
          -11814.061000000002,
          -11840.101999999999,
          -11865.593,
          -11890.534,
          -11914.928999999998,
          -11938.777,
          -11962.082,
          -11984.845,
          -12007.069,
          -12028.753,
          -12049.901000000002,
          -12070.513,
          -12090.591,
          -12110.136999999999,
          -12129.152,
          -12147.638,
          -12165.596000000001,
          -12183.027,
          -12199.933,
          -12216.315,
          -12232.175,
          -12247.513,
          -12262.332,
          -12276.632,
          -12290.415,
          -12303.681999999999,
          -12316.434,
          -12328.671999999999,
          -12340.398000000001,
          -12351.612,
          -12362.315,
          -12372.51,
          -12382.196000000002,
          -12391.375,
          -12400.048,
          -12408.216,
          -12415.878999999999,
          -12423.038999999999,
          -12429.697,
          -12435.854,
          -12441.51,
          -12446.666000000001,
          -12451.323999999999,
          -12455.483999999999,
          -12459.146999999999,
          -12462.313,
          -12464.983999999999,
          -12467.159,
          -12468.841,
          -12470.03,
          -12470.725,
          -12470.928999999998,
          -12470.641000000001,
          -12469.863000000001,
          -12468.594,
          -12466.836000000001,
          -12464.589,
          -12461.854,
          -12458.631000000001,
          -12454.92,
          -12450.723,
          -12446.038999999999,
          -12440.87,
          -12435.215,
          -12429.075,
          -12422.451000000001,
          -12415.341999999999,
          -12407.75,
          -12399.673999999999,
          -12391.115,
          -12382.073999999999,
          -12372.55,
          -12362.544,
          -12352.056999999999,
          -12341.088,
          -12329.636999999999,
          -12317.706,
          -12305.294,
          -12292.401000000002,
          -12279.027,
          -12265.173999999999,
          -12250.84,
          -12236.026000000002,
          -12220.732,
          -12204.958,
          -12188.705,
          -12171.972,
          -12154.758999999998,
          -12137.067,
          -12118.895,
          -12100.243,
          -12081.112,
          -12061.501,
          -12041.41,
          -12020.84,
          -11999.79,
          -11978.26,
          -11956.249,
          -11933.758999999998,
          -11910.788,
          -11887.336000000001,
          -11863.403,
          -11838.99,
          -11814.096000000001,
          -11788.72,
          -11762.863000000001,
          -11736.523000000001,
          -11709.702,
          -11682.398000000001,
          -11654.611,
          -11626.341,
          -11597.588,
          -11568.35,
          -11538.628999999999,
          -11508.421999999999,
          -11477.731000000002,
          -11446.553999999998,
          -11414.891000000001,
          -11382.742,
          -11350.105,
          -11316.982,
          -11283.37,
          -11249.268999999998,
          -11214.68,
          -11179.601,
          -11144.032,
          -11107.971000000001,
          -11071.42,
          -11034.376,
          -10996.839,
          -10958.808,
          -10920.284,
          -10881.264,
          -10841.749,
          -10801.738000000001,
          -10761.229,
          -10720.222,
          -10678.716999999999,
          -10636.712,
          -10594.206,
          -10551.2,
          -10507.69,
          -10463.678,
          -10419.162,
          -10374.14,
          -10328.613000000001,
          -10282.578000000001,
          -10236.036,
          -10188.985,
          -10141.423,
          -10093.351,
          -10044.766,
          -9995.668,
          -9946.055,
          -9895.927,
          -9845.283000000001,
          -9794.12,
          -9742.438,
          -9690.235999999999,
          -9637.511999999999,
          -9584.265,
          -9530.494,
          -9476.198,
          -9421.375,
          -9366.024,
          -9310.143,
          -9253.732,
          -9196.788,
          -9139.311,
          -9081.298,
          -9022.749,
          -8963.662,
          -8904.035,
          -8843.867,
          -8783.155999999999,
          -8721.9,
          -8660.099,
          -8597.75,
          -8534.851999999999,
          -8471.403,
          -8407.402,
          -8342.846,
          -8277.735,
          -8212.065,
          -8145.8369999999995,
          -8079.045999999999,
          -8011.693,
          -7943.775,
          -7875.29,
          -7806.236999999999,
          -7736.613,
          -7666.4169999999995,
          -7595.647,
          -7524.3,
          -7452.376,
          -7379.871999999999,
          -7306.785,
          -7233.115,
          -7158.858,
          -7084.014,
          -7008.579000000001,
          -6932.553000000001,
          -6855.933000000001,
          -6778.715999999999,
          -6700.901999999999,
          -6622.486999999999,
          -6543.47,
          -6463.849,
          -6383.621999999999,
          -6302.786,
          -6221.34,
          -6139.281999999999,
          -6056.609,
          -5973.32,
          -5889.4130000000005,
          -5804.884,
          -5719.734,
          -5633.960999999999,
          -5547.561,
          -5460.533,
          -5372.876,
          -5284.588000000001,
          -5195.667,
          -5106.112,
          -5015.92,
          -4925.090999999999,
          -4833.623,
          -4741.515,
          -4648.765,
          -4555.373,
          -4461.338,
          -4366.659000000001,
          -4271.335,
          -4175.366,
          -4078.7509999999997,
          -3981.491,
          -3883.585,
          -3785.034,
          -3685.837,
          -3585.998,
          -3485.5170000000003,
          -3384.3940000000002,
          -3282.633,
          -3180.235,
          -3077.202,
          -2973.539,
          -2869.2490000000003,
          -2764.336,
          -2658.805,
          -2552.6620000000003,
          -2445.9120000000003,
          -2338.563,
          -2230.623,
          -2122.101,
          -2013.006,
          -1903.35,
          -1793.144,
          -1682.402,
          -1571.14,
          -1459.374,
          -1347.121,
          -1234.404,
          -1121.243,
          -1007.663,
          -893.692,
          -779.36,
          -664.699,
          -549.746,
          -434.542,
          -319.129,
          -203.55599999999998,
          -87.87700000000001,
          27.85,
          143.561,
          259.183,
          374.64099999999996,
          489.846,
          604.705,
          719.1139999999999,
          832.959,
          946.112,
          1058.437,
          1169.78,
          1279.974,
          1388.835,
          1496.162,
          1601.733,
          1705.307,
          1806.618,
          1905.378,
          2001.275,
          2093.968,
          2183.09,
          2268.245,
          2349.014,
          2424.949,
          2495.577,
          2560.408,
          2618.9339999999997,
          2670.638,
          2715.008,
          2751.534,
          2779.736,
          2799.165,
          2809.422,
          2810.175,
          2801.167,
          2782.2329999999997,
          2753.3070000000002,
          2714.4240000000004,
          2665.7270000000003,
          2607.459,
          2539.9570000000003,
          2463.643,
          2379.001,
          2286.576,
          2186.945,
          2080.709,
          1968.474,
          1850.8429999999998,
          1728.402,
          1601.714,
          1471.3120000000001,
          1337.6989999999998,
          1201.338,
          1062.6589999999999,
          922.053,
          779.878,
          636.456,
          492.07800000000003,
          347.006,
          201.47299999999998,
          55.688,
          -90.164,
          -235.918,
          -381.42900000000003,
          -526.568,
          -671.222,
          -815.29,
          -958.687,
          -1101.335,
          -1243.1660000000002,
          -1384.124,
          -1524.158,
          -1663.225,
          -1801.286,
          -1938.31,
          -2074.27,
          -2209.144,
          -2342.911,
          -2475.556,
          -2607.0679999999998,
          -2737.434,
          -2866.6479999999997,
          -2994.7059999999997,
          -3121.6020000000003,
          -3247.3340000000003,
          -3371.903,
          -3495.3070000000002,
          -3617.55,
          -3738.634,
          -3858.563,
          -3977.34,
          -4094.9709999999995,
          -4211.462,
          -4326.817,
          -4441.044,
          -4554.151,
          -4666.143,
          -4777.029,
          -4886.816,
          -4995.512,
          -5103.124,
          -5209.662,
          -5315.134,
          -5419.547,
          -5522.91,
          -5625.231,
          -5726.52,
          -5826.784000000001,
          -5926.03,
          -6024.269,
          -6121.509,
          -6217.757,
          -6313.023,
          -6407.313,
          -6500.6359999999995,
          -6593.001,
          -6684.414000000001,
          -6774.885,
          -6864.420999999999,
          -6953.028,
          -7040.715999999999,
          -7127.491999999999,
          -7213.361999999999,
          -7298.335,
          -7382.416,
          -7465.615,
          -7547.938,
          -7629.391,
          -7709.982,
          -7789.715999999999,
          -7868.602,
          -7946.645,
          -8023.851,
          -8100.228,
          -8175.781,
          -8250.516,
          -8324.44,
          -8397.559000000001,
          -8469.878,
          -8541.403,
          -8612.14,
          -8682.094000000001,
          -8751.271,
          -8819.676,
          -8887.315999999999,
          -8954.194,
          -9020.315999999999,
          -9085.688,
          -9150.314,
          -9214.199,
          -9277.349,
          -9339.767,
          -9401.458,
          -9462.428,
          -9522.68,
          -9582.22,
          -9641.051,
          -9699.178,
          -9756.605,
          -9813.336,
          -9869.376,
          -9924.728000000001,
          -9979.396999999999,
          -10033.386,
          -10086.7,
          -10139.341,
          -10191.315,
          -10242.625,
          -10293.273000000001,
          -10343.265,
          -10392.603000000001,
          -10441.29,
          -10489.331,
          -10536.728000000001,
          -10583.485,
          -10629.606000000002,
          -10675.091999999999,
          -10719.948,
          -10764.176000000001,
          -10807.78,
          -10850.763,
          -10893.127,
          -10934.876,
          -10976.011,
          -11016.537,
          -11056.456,
          -11095.77,
          -11134.483,
          -11172.596000000001,
          -11210.112,
          -11247.035,
          -11283.367,
          -11319.108999999999,
          -11354.265,
          -11388.837,
          -11422.827,
          -11456.238000000001,
          -11489.071000000002,
          -11521.329,
          -11553.015,
          -11584.13,
          -11614.677,
          -11644.657,
          -11674.073,
          -11702.926000000001,
          -11731.22,
          -11758.955,
          -11786.133999999998,
          -11812.758,
          -11838.83,
          -11864.351,
          -11889.323999999999,
          -11913.749,
          -11937.628,
          -11960.964,
          -11983.758,
          -12006.011,
          -12027.726,
          -12048.903999999999,
          -12069.546999999999,
          -12089.655,
          -12109.231000000002,
          -12128.277,
          -12146.792,
          -12164.78,
          -12182.241000000002,
          -12199.177,
          -12215.589,
          -12231.478000000001,
          -12246.847,
          -12261.695,
          -12276.025,
          -12289.837,
          -12303.133999999998,
          -12315.915,
          -12328.183,
          -12339.938,
          -12351.181,
          -12361.913999999999,
          -12372.138,
          -12381.853000000001,
          -12391.061000000002,
          -12399.763,
          -12407.958999999999,
          -12415.652,
          -12422.841,
          -12429.528,
          -12435.713,
          -12441.398000000001,
          -12446.583,
          -12451.268999999998,
          -12455.458,
          -12459.149,
          -12462.344,
          -12465.043,
          -12467.247,
          -12468.957,
          -12470.173999999999,
          -12470.898000000001,
          -12471.13,
          -12470.87,
          -12470.12,
          -12468.88,
          -12467.15,
          -12464.931,
          -12462.223,
          -12459.028,
          -12455.345,
          -12451.176000000001,
          -12446.52,
          -12441.378,
          -12435.751,
          -12429.639,
          -12423.042,
          -12415.961000000001,
          -12408.396,
          -12400.347,
          -12391.816,
          -12382.802,
          -12373.306,
          -12363.328000000001,
          -12352.867,
          -12341.925,
          -12330.502,
          -12318.598,
          -12306.213,
          -12293.347,
          -12280,
          -12266.173999999999,
          -12251.867,
          -12237.08,
          -12221.812,
          -12206.066,
          -12189.839,
          -12173.132,
          -12155.946000000002,
          -12138.281,
          -12120.135,
          -12101.51,
          -12082.406,
          -12062.821000000002,
          -12042.757,
          -12022.213,
          -12001.188999999998,
          -11979.685,
          -11957.701000000001,
          -11935.237,
          -11912.292,
          -11888.866000000002,
          -11864.96,
          -11840.573,
          -11815.704,
          -11790.355,
          -11764.523000000001,
          -11738.21,
          -11711.413999999999,
          -11684.136,
          -11656.375,
          -11628.131000000001,
          -11599.403,
          -11570.192,
          -11540.496000000001,
          -11510.315,
          -11479.649,
          -11448.498,
          -11416.86,
          -11384.737,
          -11352.126,
          -11319.027,
          -11285.441,
          -11251.366000000002,
          -11216.802,
          -11181.748,
          -11146.204,
          -11110.169,
          -11073.642,
          -11036.623,
          -10999.111,
          -10961.106000000002,
          -10922.606000000002,
          -10883.612,
          -10844.122,
          -10804.135,
          -10763.651000000002,
          -10722.669,
          -10681.188999999998,
          -10639.208,
          -10596.728000000001,
          -10553.745,
          -10510.261,
          -10466.273000000001,
          -10421.780999999999,
          -10376.784,
          -10331.280999999999,
          -10285.271,
          -10238.753,
          -10191.726,
          -10144.189,
          -10096.141,
          -10047.58,
          -9998.507,
          -9948.918,
          -9898.814,
          -9848.194,
          -9797.055,
          -9745.396999999999,
          -9693.219000000001,
          -9640.519,
          -9587.296,
          -9533.549,
          -9479.277,
          -9424.476999999999,
          -9369.15,
          -9313.293,
          -9256.905999999999,
          -9199.985999999999,
          -9142.532,
          -9084.543,
          -9026.017,
          -8966.953000000001,
          -8907.349,
          -8847.205,
          -8786.517,
          -8725.285,
          -8663.507,
          -8601.181,
          -8538.306,
          -8474.88,
          -8410.902,
          -8346.369,
          -8281.280999999999,
          -8215.634,
          -8149.428000000001,
          -8082.661,
          -8015.331,
          -7947.436,
          -7878.973000000001,
          -7809.941999999999,
          -7740.340999999999,
          -7670.1669999999995,
          -7599.42,
          -7528.096,
          -7456.194,
          -7383.710999999999,
          -7310.647,
          -7236.999,
          -7162.764,
          -7087.941999999999,
          -7012.53,
          -6936.525,
          -6859.927,
          -6782.732,
          -6704.939,
          -6626.545999999999,
          -6547.5509999999995,
          -6467.951,
          -6387.745,
          -6306.931,
          -6225.505999999999,
          -6143.469,
          -6060.816999999999,
          -5977.549,
          -5893.661999999999,
          -5809.155,
          -5724.025,
          -5638.272,
          -5551.893,
          -5464.8859999999995,
          -5377.249,
          -5288.981,
          -5200.079000000001,
          -5110.544,
          -5020.372,
          -4929.562,
          -4838.113,
          -4746.024,
          -4653.294,
          -4559.920999999999,
          -4465.904,
          -4371.244000000001,
          -4275.938,
          -4179.987,
          -4083.39,
          -3986.147,
          -3888.259,
          -3789.725,
          -3690.545,
          -3590.723,
          -3490.257,
          -3389.151,
          -3287.405,
          -3185.022,
          -3082.005,
          -2978.3559999999998,
          -2874.08,
          -2769.1809999999996,
          -2663.663,
          -2557.532,
          -2450.795,
          -2343.4570000000003,
          -2235.528,
          -2127.016,
          -2017.931,
          -1908.283,
          -1798.085,
          -1687.351,
          -1576.095,
          -1464.3339999999998,
          -1352.086,
          -1239.371,
          -1126.212,
          -1012.6339999999999,
          -898.6619999999999,
          -784.327,
          -669.663,
          -554.7040000000001,
          -439.49199999999996,
          -324.069,
          -208.485,
          -92.791,
          22.953000000000003,
          138.683,
          254.329,
          369.81199999999995,
          485.048,
          599.941,
          714.388,
          828.275,
          941.477,
          1053.855,
          1165.258,
          1275.519,
          1384.454,
          1491.8629999999998,
          1597.525,
          1701.1989999999998,
          1802.621,
          1901.5020000000002,
          1997.533,
          2090.373,
          2179.656,
          2264.987,
          2345.948,
          2422.092,
          2492.946,
          2558.022,
          2616.812,
          2668.8,
          2713.4709999999995,
          2750.3179999999998,
          2778.8579999999997,
          2798.64,
          2809.265,
          2810.397,
          2801.777,
          2783.237,
          2754.705,
          2716.2140000000004,
          2667.903,
          2610.012,
          2542.873,
          2466.906,
          2382.594,
          2290.479,
          2191.136,
          2085.167,
          1973.1760000000002,
          1855.767,
          1733.527,
          1607.02,
          1476.779,
          1343.309,
          1207.0739999999998,
          1068.504,
          927.9939999999999,
          785.9,
          642.547,
          498.228,
          353.204,
          207.709,
          61.955,
          -83.874,
          -229.612,
          -375.11199999999997,
          -520.246,
          -664.9,
          -808.9739999999999,
          -952.3789999999999,
          -1095.038,
          -1236.885,
          -1377.862,
          -1517.9160000000002,
          -1657.006,
          -1795.092,
          -1932.1429999999998,
          -2068.132,
          -2203.035,
          -2336.833,
          -2469.512,
          -2601.056,
          -2731.4570000000003,
          -2860.7070000000003,
          -2988.8,
          -3115.7329999999997,
          -3241.5029999999997,
          -3366.1090000000004,
          -3489.553,
          -3611.835,
          -3732.958,
          -3852.926,
          -3971.743,
          -4089.414,
          -4205.944,
          -4321.34,
          -4435.607,
          -4548.754,
          -4660.787,
          -4771.714,
          -4881.542,
          -4990.278,
          -5097.932,
          -5204.5109999999995,
          -5310.023,
          -5414.477,
          -5517.88,
          -5620.243,
          -5721.571999999999,
          -5821.876,
          -5921.1630000000005,
          -6019.443,
          -6116.723000000001,
          -6213.0109999999995,
          -6308.316999999999,
          -6402.647,
          -6496.0109999999995,
          -6588.415,
          -6679.869000000001,
          -6770.379,
          -6859.954000000001,
          -6948.602,
          -7036.329000000001,
          -7123.144,
          -7209.053000000001,
          -7294.065,
          -7378.185,
          -7461.423000000001,
          -7543.784000000001,
          -7625.276,
          -7705.905,
          -7785.678000000001,
          -7864.602,
          -7942.683000000001,
          -8019.928000000001,
          -8096.343000000001,
          -8171.933000000001,
          -8246.707,
          -8320.668,
          -8393.824,
          -8466.181,
          -8537.743,
          -8608.517,
          -8678.508,
          -8747.722,
          -8816.164,
          -8883.84,
          -8950.755,
          -9016.915,
          -9082.323,
          -9146.985,
          -9210.907,
          -9274.091999999999,
          -9336.546,
          -9398.273000000001,
          -9459.279,
          -9519.567,
          -9579.142,
          -9638.008,
          -9696.171,
          -9753.633,
          -9810.4,
          -9866.475,
          -9921.862,
          -9976.565999999999,
          -10030.59,
          -10083.938,
          -10136.614,
          -10188.623,
          -10239.966999999999,
          -10290.65,
          -10340.676,
          -10390.048,
          -10438.769,
          -10486.844,
          -10534.275,
          -10581.066,
          -10627.22,
          -10672.741000000002,
          -10717.63,
          -10761.892,
          -10805.53,
          -10848.546,
          -10890.943000000001,
          -10932.725,
          -10973.893999999998,
          -11014.453000000001,
          -11054.405,
          -11093.752,
          -11132.497,
          -11170.643,
          -11208.192,
          -11245.148000000001,
          -11281.511999999999,
          -11317.287,
          -11352.475,
          -11387.079,
          -11421.101999999999,
          -11454.545,
          -11487.41,
          -11519.7,
          -11551.418,
          -11582.565,
          -11613.143999999998,
          -11643.156,
          -11672.603000000001,
          -11701.489,
          -11729.813999999998,
          -11757.581,
          -11784.791000000001,
          -11811.447,
          -11837.55,
          -11863.101999999999,
          -11888.106000000002,
          -11912.562,
          -11936.473,
          -11959.839,
          -11982.663999999999,
          -12004.948999999999,
          -12026.695,
          -12047.903,
          -12068.577,
          -12088.716,
          -12108.323,
          -12127.398000000001,
          -12145.945,
          -12163.963,
          -12181.454,
          -12198.42,
          -12214.863000000001,
          -12230.783000000001,
          -12246.181,
          -12261.06,
          -12275.42,
          -12289.261999999999,
          -12302.588,
          -12315.4,
          -12327.697,
          -12339.482,
          -12350.755,
          -12361.518,
          -12371.771,
          -12381.516000000001,
          -12390.753999999999,
          -12399.485,
          -12407.711000000001,
          -12415.433,
          -12422.651000000002,
          -12429.367,
          -12435.582,
          -12441.296,
          -12446.51,
          -12451.226,
          -12455.443000000001,
          -12459.163999999999,
          -12462.386999999999,
          -12465.115,
          -12467.348999999998,
          -12469.088,
          -12470.333,
          -12471.086000000001,
          -12471.346000000001,
          -12471.115,
          -12470.393999999998,
          -12469.181999999999,
          -12467.48,
          -12465.29,
          -12462.611,
          -12459.444,
          -12455.79,
          -12451.648000000001,
          -12447.021,
          -12441.907,
          -12436.308,
          -12430.223999999998,
          -12423.655,
          -12416.603000000001,
          -12409.065,
          -12401.045,
          -12392.542,
          -12383.555,
          -12374.087,
          -12364.136,
          -12353.704,
          -12342.79,
          -12331.393999999998,
          -12319.517,
          -12307.16,
          -12294.321000000002,
          -12281.002,
          -12267.203000000001,
          -12252.923,
          -12238.163999999999,
          -12222.923999999999,
          -12207.205,
          -12191.005,
          -12174.326000000001,
          -12157.167,
          -12139.528,
          -12121.41,
          -12102.812,
          -12083.733999999999,
          -12064.177,
          -12044.14,
          -12023.623,
          -12002.626,
          -11981.149,
          -11959.191,
          -11936.753999999999,
          -11913.835,
          -11890.436000000002,
          -11866.556999999999,
          -11842.196000000002,
          -11817.354,
          -11792.031,
          -11766.226,
          -11739.938999999998,
          -11713.17,
          -11685.919,
          -11658.184,
          -11629.966,
          -11601.265,
          -11572.079,
          -11542.409,
          -11512.255,
          -11481.615,
          -11450.49,
          -11418.878,
          -11386.78,
          -11354.196000000002,
          -11321.123,
          -11287.562,
          -11253.513,
          -11218.975,
          -11183.947,
          -11148.428999999998,
          -11112.419,
          -11075.918,
          -11038.925,
          -11001.438999999998,
          -10963.458999999999,
          -10924.985,
          -10886.016000000001,
          -10846.551000000001,
          -10806.59,
          -10766.132,
          -10725.175,
          -10683.72,
          -10641.765,
          -10599.309,
          -10556.351999999999,
          -10512.893,
          -10468.93,
          -10424.463,
          -10379.491,
          -10334.014000000001,
          -10288.029,
          -10241.535,
          -10194.533000000001,
          -10147.021,
          -10098.998,
          -10050.462,
          -10001.413,
          -9951.849,
          -9901.77,
          -9851.174,
          -9800.06,
          -9748.427,
          -9696.273000000001,
          -9643.598,
          -9590.399,
          -9536.676,
          -9482.429,
          -9427.654,
          -9372.351,
          -9316.518,
          -9260.155,
          -9203.259,
          -9145.829,
          -9087.864,
          -9029.363000000001,
          -8970.323,
          -8910.743,
          -8850.622,
          -8789.958,
          -8728.75,
          -8666.996,
          -8604.694,
          -8541.843,
          -8478.440999999999,
          -8414.485999999999,
          -8349.976999999999,
          -8284.912,
          -8219.289,
          -8153.106,
          -8086.363,
          -8019.056,
          -7951.184,
          -7882.745,
          -7813.736999999999,
          -7744.159000000001,
          -7674.008000000001,
          -7603.283,
          -7531.983,
          -7460.103,
          -7387.644,
          -7314.603,
          -7240.977,
          -7166.765,
          -7091.965999999999,
          -7016.576,
          -6940.594,
          -6864.018,
          -6786.846,
          -6709.075,
          -6630.704000000001,
          -6551.731,
          -6472.153,
          -6391.969,
          -6311.177,
          -6229.774,
          -6147.759,
          -6065.129,
          -5981.882,
          -5898.017,
          -5813.531,
          -5728.423000000001,
          -5642.691,
          -5556.331999999999,
          -5469.346,
          -5381.73,
          -5293.483,
          -5204.602,
          -5115.087,
          -5024.935,
          -4934.146,
          -4842.717000000001,
          -4750.648,
          -4657.937,
          -4564.584,
          -4470.587,
          -4375.945,
          -4280.657999999999,
          -4184.726,
          -4088.147,
          -3990.923,
          -3893.053,
          -3794.5359999999996,
          -3695.375,
          -3595.5690000000004,
          -3495.1209999999996,
          -3394.031,
          -3292.301,
          -3189.934,
          -3086.9320000000002,
          -2983.2990000000004,
          -2879.038,
          -2774.153,
          -2668.6490000000003,
          -2562.531,
          -2455.806,
          -2348.481,
          -2240.564,
          -2132.062,
          -2022.987,
          -1913.349,
          -1803.16,
          -1692.433,
          -1581.184,
          -1469.4289999999999,
          -1357.1860000000001,
          -1244.475,
          -1131.318,
          -1017.7410000000001,
          -903.7689999999999,
          -789.432,
          -674.7639999999999,
          -559.8,
          -444.58,
          -329.148,
          -213.55200000000002,
          -97.845,
          17.916,
          133.666,
          249.335,
          364.845,
          480.11,
          595.038,
          709.523,
          823.454,
          936.705,
          1049.139,
          1160.603,
          1270.931,
          1379.942,
          1487.435,
          1593.1889999999999,
          1696.9660000000001,
          1798.501,
          1897.507,
          1993.675,
          2086.665,
          2176.113,
          2261.625,
          2342.784,
          2419.1420000000003,
          2490.229,
          2555.5570000000002,
          2614.618,
          2666.897,
          2711.8790000000004,
          2749.0559999999996,
          2777.9440000000004,
          2798.091,
          2809.095,
          2810.619,
          2802.3990000000003,
          2784.265,
          2756.14,
          2718.055,
          2670.1440000000002,
          2612.6420000000003,
          2545.88,
          2470.272,
          2386.302,
          2294.507,
          2195.4629999999997,
          2089.77,
          1978.033,
          1860.855,
          1738.8229999999999,
          1612.503,
          1482.43,
          1349.1070000000002,
          1213.002,
          1074.547,
          934.1339999999999,
          792.125,
          648.844,
          504.585,
          359.611,
          214.157,
          68.433,
          -77.372,
          -223.093,
          -368.583,
          -513.712,
          -658.3660000000001,
          -802.444,
          -945.8580000000001,
          -1088.531,
          -1230.394,
          -1371.389,
          -1511.52,
          -1650.578,
          -1788.691,
          -1925.77,
          -2061.788,
          -2196.723,
          -2330.554,
          -2463.266,
          -2594.846,
          -2725.282,
          -2854.5690000000004,
          -2982.7,
          -3109.671,
          -3235.48,
          -3360.1259999999997,
          -3483.6090000000004,
          -3605.9309999999996,
          -3727.095,
          -3847.103,
          -3965.962,
          -4083.6740000000004,
          -4200.246,
          -4315.684,
          -4429.9929999999995,
          -4543.182,
          -4655.258,
          -4766.226,
          -4876.096,
          -4984.875,
          -5092.571,
          -5199.192,
          -5304.746999999999,
          -5409.243,
          -5512.689,
          -5615.093000000001,
          -5716.464,
          -5816.811,
          -5916.14,
          -6014.460999999999,
          -6111.783,
          -6208.113,
          -6303.460999999999,
          -6397.831999999999,
          -6491.236999999999,
          -6583.683000000001,
          -6675.178000000001,
          -6765.729,
          -6855.345,
          -6944.034000000001,
          -7031.802,
          -7118.656999999999,
          -7204.608,
          -7289.659000000001,
          -7373.82,
          -7457.098000000001,
          -7539.5,
          -7621.031,
          -7701.7,
          -7781.513000000001,
          -7860.476,
          -7938.597,
          -8015.880999999999,
          -8092.335,
          -8167.965,
          -8242.777,
          -8316.777,
          -8389.972,
          -8462.367,
          -8533.968,
          -8604.78,
          -8674.81,
          -8744.062,
          -8812.542,
          -8880.256,
          -8947.209,
          -9013.405999999999,
          -9078.851999999999,
          -9143.551,
          -9207.51,
          -9270.733,
          -9333.224,
          -9394.989,
          -9456.030999999999,
          -9516.356,
          -9575.968,
          -9634.871,
          -9693.07,
          -9750.568000000001,
          -9807.371,
          -9863.482,
          -9918.905999999999,
          -9973.646,
          -10027.706,
          -10081.09,
          -10133.802,
          -10185.846,
          -10237.225,
          -10287.944,
          -10338.005,
          -10387.412,
          -10436.169,
          -10484.279,
          -10531.745,
          -10578.571000000002,
          -10624.76,
          -10670.315,
          -10715.239,
          -10759.536,
          -10803.208,
          -10846.258,
          -10888.69,
          -10930.506000000001,
          -10971.708999999999,
          -11012.302,
          -11052.287,
          -11091.669,
          -11130.448,
          -11168.627,
          -11206.21,
          -11243.198999999999,
          -11279.597,
          -11315.405,
          -11350.627,
          -11385.264,
          -11419.32,
          -11452.796,
          -11485.694,
          -11518.018,
          -11549.768,
          -11580.948,
          -11611.559,
          -11641.604,
          -11671.083999999999,
          -11700.002,
          -11728.36,
          -11756.159,
          -11783.402,
          -11810.09,
          -11836.225,
          -11861.81,
          -11886.845,
          -11911.333,
          -11935.276000000002,
          -11958.673999999999,
          -11981.531,
          -12003.847,
          -12025.625,
          -12046.865,
          -12067.57,
          -12087.741000000002,
          -12107.378999999999,
          -12126.486,
          -12145.063999999998,
          -12163.113000000001,
          -12180.636,
          -12197.633,
          -12214.106000000002,
          -12230.056999999999,
          -12245.487,
          -12260.396,
          -12274.787,
          -12288.66,
          -12302.017,
          -12314.858999999999,
          -12327.187,
          -12339.002,
          -12350.306,
          -12361.098999999998,
          -12371.382,
          -12381.157,
          -12390.425,
          -12399.187,
          -12407.443000000001,
          -12415.195,
          -12422.444,
          -12429.19,
          -12435.435,
          -12441.178999999998,
          -12446.423,
          -12451.168,
          -12455.416000000001,
          -12459.166000000001,
          -12462.419,
          -12465.177,
          -12467.438999999998,
          -12469.208,
          -12470.483,
          -12471.265,
          -12471.555,
          -12471.353000000001,
          -12470.661,
          -12469.478000000001,
          -12467.806,
          -12465.643999999998,
          -12462.993999999999,
          -12459.856000000002,
          -12456.231000000002,
          -12452.118999999999,
          -12447.52,
          -12442.435,
          -12436.865,
          -12430.81,
          -12424.27,
          -12417.245,
          -12409.737,
          -12401.746000000001,
          -12393.271,
          -12384.313,
          -12374.873,
          -12364.95,
          -12354.546,
          -12343.66,
          -12332.292,
          -12320.444,
          -12308.114,
          -12295.303999999998,
          -12282.013,
          -12268.242,
          -12253.99,
          -12239.258999999998,
          -12224.046999999999,
          -12208.355,
          -12192.183,
          -12175.532,
          -12158.401000000002,
          -12140.79,
          -12122.698999999999,
          -12104.128999999999,
          -12085.078000000001,
          -12065.548,
          -12045.538999999999,
          -12025.048999999999,
          -12004.079,
          -11982.63,
          -11960.7,
          -11938.288999999999,
          -11915.398000000001,
          -11892.027,
          -11868.175,
          -11843.841,
          -11819.027,
          -11793.73,
          -11767.952,
          -11741.692,
          -11714.95,
          -11687.725,
          -11660.017,
          -11631.826000000001,
          -11603.151000000002,
          -11573.993,
          -11544.348999999998,
          -11514.221000000001,
          -11483.608,
          -11452.508999999998,
          -11420.923999999999,
          -11388.851999999999,
          -11356.294,
          -11323.247,
          -11289.713,
          -11255.69,
          -11221.178,
          -11186.176000000001,
          -11150.684,
          -11114.701000000001,
          -11078.226,
          -11041.258999999998,
          -11003.798999999999,
          -10965.845,
          -10927.396999999999,
          -10888.454,
          -10849.015,
          -10809.08,
          -10768.646999999999,
          -10727.716999999999,
          -10686.287,
          -10644.358,
          -10601.928,
          -10558.996000000001,
          -10515.562,
          -10471.625,
          -10427.184000000001,
          -10382.237,
          -10336.785,
          -10290.825,
          -10244.357,
          -10197.38,
          -10149.893,
          -10101.895,
          -10053.385,
          -10004.360999999999,
          -9954.822,
          -9904.768,
          -9854.196,
          -9803.107,
          -9751.498,
          -9699.37,
          -9646.719000000001,
          -9593.546,
          -9539.848,
          -9485.625,
          -9430.875,
          -9375.596,
          -9319.788,
          -9263.449,
          -9206.578000000001,
          -9149.171999999999,
          -9091.232,
          -9032.755,
          -8973.739,
          -8914.184000000001,
          -8854.087,
          -8793.447,
          -8732.263,
          -8670.533000000001,
          -8608.255,
          -8545.428,
          -8482.05,
          -8418.119,
          -8353.634,
          -8288.591999999999,
          -8222.993,
          -8156.834,
          -8090.1140000000005,
          -8022.831,
          -7954.982,
          -7886.566999999999,
          -7817.5830000000005,
          -7748.028,
          -7677.901,
          -7607.2,
          -7535.920999999999,
          -7464.065,
          -7391.629,
          -7318.61,
          -7245.008000000001,
          -7170.819,
          -7096.0419999999995,
          -7020.675,
          -6944.715999999999,
          -6868.161999999999,
          -6791.012,
          -6713.264,
          -6634.916,
          -6555.965,
          -6476.41,
          -6396.2480000000005,
          -6315.477,
          -6234.096,
          -6152.103,
          -6069.494000000001,
          -5986.27,
          -5902.4259999999995,
          -5817.9619999999995,
          -5732.876,
          -5647.165,
          -5560.828,
          -5473.863,
          -5386.268,
          -5298.041,
          -5209.181,
          -5119.686,
          -5029.555,
          -4938.785,
          -4847.376,
          -4755.327,
          -4662.6359999999995,
          -4569.302,
          -4475.3240000000005,
          -4380.701,
          -4285.434,
          -4189.52,
          -4092.96,
          -3995.7540000000004,
          -3897.901,
          -3799.403,
          -3700.26,
          -3600.4709999999995,
          -3500.04,
          -3398.967,
          -3297.2529999999997,
          -3194.902,
          -3091.9159999999997,
          -2988.297,
          -2884.05,
          -2779.179,
          -2673.6890000000003,
          -2567.585,
          -2460.8720000000003,
          -2353.5589999999997,
          -2245.653,
          -2137.163,
          -2028.0970000000002,
          -1918.4679999999998,
          -1808.2879999999998,
          -1697.569,
          -1586.326,
          -1474.576,
          -1362.3370000000002,
          -1249.629,
          -1136.475,
          -1022.898,
          -908.925,
          -794.587,
          -679.915,
          -564.945,
          -449.718,
          -334.276,
          -218.668,
          -102.946,
          12.832,
          128.60299999999998,
          244.295,
          359.83099999999996,
          475.12800000000004,
          590.09,
          704.6160000000001,
          818.591,
          931.8919999999999,
          1044.379,
          1155.905,
          1266.302,
          1375.389,
          1482.9660000000001,
          1588.8139999999999,
          1692.694,
          1794.3429999999998,
          1893.475,
          1989.781,
          2082.922,
          2172.536,
          2258.23,
          2339.587,
          2416.161,
          2487.482,
          2553.062,
          2612.396,
          2664.967,
          2710.261,
          2747.77,
          2777.007,
          2797.52,
          2808.905,
          2810.823,
          2803.005,
          2785.2790000000005,
          2757.5640000000003,
          2719.887,
          2672.377,
          2615.2670000000003,
          2548.885,
          2473.639,
          2390.013,
          2298.541,
          2199.799,
          2094.385,
          1982.902,
          1865.957,
          1744.1370000000002,
          1618.006,
          1488.102,
          1354.9279999999999,
          1218.955,
          1080.615,
          940.302,
          798.3789999999999,
          655.1709999999999,
          510.973,
          366.04900000000004,
          220.637,
          74.946,
          -70.834,
          -216.53799999999998,
          -362.017,
          -507.14099999999996,
          -651.795,
          -795.878,
          -939.3,
          -1081.985,
          -1223.864,
          -1364.8770000000002,
          -1504.975,
          -1644.112,
          -1782.25,
          -1919.3570000000002,
          -2055.405,
          -2190.371,
          -2324.234,
          -2456.979,
          -2588.594,
          -2719.067,
          -2848.3909999999996,
          -2976.559,
          -3103.5690000000004,
          -3229.4159999999997,
          -3354.1009999999997,
          -3477.6240000000003,
          -3599.987,
          -3721.191,
          -3841.241,
          -3960.1409999999996,
          -4077.895,
          -4194.508,
          -4309.988,
          -4424.34,
          -4537.572,
          -4649.688,
          -4760.6990000000005,
          -4870.611,
          -4979.433,
          -5087.170999999999,
          -5193.835,
          -5299.431,
          -5403.97,
          -5507.4580000000005,
          -5609.905,
          -5711.318,
          -5811.706999999999,
          -5911.079000000001,
          -6009.443,
          -6106.807,
          -6203.179,
          -6298.568,
          -6392.981,
          -6486.428000000001,
          -6578.915,
          -6670.45,
          -6761.043000000001,
          -6850.7,
          -6939.43,
          -7027.2390000000005,
          -7114.135,
          -7200.126,
          -7285.219,
          -7369.420999999999,
          -7452.7390000000005,
          -7535.181,
          -7616.753000000001,
          -7697.4619999999995,
          -7777.315,
          -7856.318,
          -7934.478,
          -8011.8009999999995,
          -8088.295,
          -8163.964,
          -8238.815,
          -8312.855,
          -8386.089,
          -8458.521999999999,
          -8530.161,
          -8601.011999999999,
          -8671.08,
          -8740.371,
          -8808.89,
          -8876.642,
          -8943.633,
          -9009.868,
          -9075.351,
          -9140.089,
          -9204.085,
          -9267.345,
          -9329.874,
          -9391.676,
          -9452.755,
          -9513.117,
          -9572.766,
          -9631.706,
          -9689.942,
          -9747.476999999999,
          -9804.315999999999,
          -9860.464,
          -9915.924,
          -9970.7,
          -10024.796999999999,
          -10078.216999999999,
          -10130.965,
          -10183.045,
          -10234.46,
          -10285.214,
          -10335.31,
          -10384.753,
          -10433.545,
          -10481.690999999999,
          -10529.192,
          -10576.053,
          -10622.277,
          -10667.867,
          -10712.826000000001,
          -10757.157,
          -10800.864,
          -10843.948999999999,
          -10886.415,
          -10928.266000000001,
          -10969.503,
          -11010.13,
          -11050.15,
          -11089.566,
          -11128.378999999999,
          -11166.593,
          -11204.21,
          -11241.233,
          -11277.663999999999,
          -11313.506000000001,
          -11348.761999999999,
          -11383.433,
          -11417.521,
          -11451.031,
          -11483.962,
          -11516.319,
          -11548.103000000001,
          -11579.315,
          -11609.958999999999,
          -11640.036,
          -11669.55,
          -11698.5,
          -11726.891000000001,
          -11754.723,
          -11781.998,
          -11808.718,
          -11834.886,
          -11860.503,
          -11885.571000000002,
          -11910.091999999999,
          -11934.066,
          -11957.498,
          -11980.386,
          -12002.735,
          -12024.544,
          -12045.817,
          -12066.553,
          -12086.756000000001,
          -12106.426000000001,
          -12125.563999999998,
          -12144.173,
          -12162.253999999999,
          -12179.808,
          -12196.837,
          -12213.341999999999,
          -12229.323999999999,
          -12244.785,
          -12259.725,
          -12274.146999999999,
          -12288.051000000001,
          -12301.438999999998,
          -12314.312,
          -12326.671,
          -12338.517,
          -12349.851,
          -12360.675,
          -12370.989,
          -12380.794,
          -12390.093,
          -12398.885,
          -12407.171999999999,
          -12414.954,
          -12422.233,
          -12429.01,
          -12435.285,
          -12441.059,
          -12446.333,
          -12451.108,
          -12455.386,
          -12459.165,
          -12462.448999999999,
          -12465.236,
          -12467.528999999999,
          -12469.327,
          -12470.631000000001,
          -12471.443000000001,
          -12471.763,
          -12471.591,
          -12470.928,
          -12469.774,
          -12468.131000000001,
          -12465.999,
          -12463.378999999999,
          -12460.27,
          -12456.673999999999,
          -12452.591,
          -12448.021,
          -12442.965,
          -12437.423999999999,
          -12431.398000000001,
          -12424.886999999999,
          -12417.891000000001,
          -12410.412,
          -12402.448999999999,
          -12394.003,
          -12385.073999999999,
          -12375.662,
          -12365.768,
          -12355.392,
          -12344.535,
          -12333.196000000002,
          -12321.376,
          -12309.073999999999,
          -12296.292,
          -12283.03,
          -12269.287,
          -12255.063,
          -12240.36,
          -12225.176000000001,
          -12209.511999999999,
          -12193.368999999999,
          -12176.745,
          -12159.642,
          -12142.059,
          -12123.996000000001,
          -12105.453000000001,
          -12086.431,
          -12066.928,
          -12046.946000000002,
          -12026.483999999999,
          -12005.542,
          -11984.12,
          -11962.216999999999,
          -11939.835,
          -11916.971000000001,
          -11893.627,
          -11869.802,
          -11845.496000000001,
          -11820.708,
          -11795.438999999998,
          -11769.688999999998,
          -11743.456,
          -11716.74,
          -11689.543,
          -11661.862,
          -11633.697,
          -11605.05,
          -11575.918,
          -11546.301000000001,
          -11516.2,
          -11485.613000000001,
          -11454.541000000001,
          -11422.982,
          -11390.937,
          -11358.405,
          -11325.386,
          -11291.878,
          -11257.882,
          -11223.396,
          -11188.421,
          -11152.955,
          -11116.998,
          -11080.548999999999,
          -11043.608,
          -11006.173999999999,
          -10968.247,
          -10929.825,
          -10890.908000000001,
          -10851.495,
          -10811.586000000001,
          -10771.178999999998,
          -10730.274,
          -10688.87,
          -10646.966999999999,
          -10604.562,
          -10561.657,
          -10518.248,
          -10474.337,
          -10429.921,
          -10385,
          -10339.573,
          -10293.639000000001,
          -10247.197,
          -10200.245,
          -10152.784,
          -10104.811,
          -10056.325,
          -10007.326,
          -9957.813,
          -9907.784,
          -9857.238000000001,
          -9806.173,
          -9754.59,
          -9702.485999999999,
          -9649.86,
          -9596.712,
          -9543.039,
          -9488.841,
          -9434.115,
          -9378.860999999999,
          -9323.078000000001,
          -9266.764000000001,
          -9209.917,
          -9152.536,
          -9094.62,
          -9036.167,
          -8977.176,
          -8917.645,
          -8857.572,
          -8796.957,
          -8735.796999999999,
          -8674.091,
          -8611.837,
          -8549.034,
          -8485.68,
          -8421.773000000001,
          -8357.312,
          -8292.294,
          -8226.719000000001,
          -8160.584,
          -8093.887,
          -8026.628000000001,
          -7958.803000000001,
          -7890.411,
          -7821.451,
          -7751.919,
          -7681.816,
          -7611.137,
          -7539.882,
          -7468.049,
          -7395.6359999999995,
          -7322.64,
          -7249.061,
          -7174.895,
          -7100.141,
          -7024.797,
          -6948.86,
          -6872.329000000001,
          -6795.201999999999,
          -6717.476,
          -6639.15,
          -6560.222,
          -6480.688,
          -6400.549,
          -6319.8,
          -6238.441,
          -6156.47,
          -6073.883000000001,
          -5990.68,
          -5906.858,
          -5822.416,
          -5737.351,
          -5651.661,
          -5565.345,
          -5478.401,
          -5390.826999999999,
          -5302.621,
          -5213.781,
          -5124.307,
          -5034.196,
          -4943.447,
          -4852.058,
          -4760.028,
          -4667.356,
          -4574.042,
          -4480.083,
          -4385.48,
          -4290.231,
          -4194.335999999999,
          -4097.795,
          -4000.607,
          -3902.772,
          -3804.292,
          -3705.165,
          -3605.3940000000002,
          -3504.9790000000003,
          -3403.923,
          -3302.225,
          -3199.89,
          -3096.9190000000003,
          -2993.315,
          -2889.083,
          -2784.2259999999997,
          -2678.7490000000003,
          -2572.658,
          -2465.958,
          -2358.657,
          -2250.762,
          -2142.282,
          -2033.227,
          -1923.6070000000002,
          -1813.434,
          -1702.723,
          -1591.486,
          -1479.7420000000002,
          -1367.507,
          -1254.802,
          -1141.65,
          -1028.073,
          -914.1,
          -799.7589999999999,
          -685.0830000000001,
          -570.1080000000001,
          -454.87300000000005,
          -339.421,
          -223.8,
          -108.06299999999999,
          7.732,
          123.523,
          239.239,
          354.80300000000005,
          470.13,
          585.127,
          699.692,
          813.712,
          927.062,
          1039.605,
          1151.193,
          1261.6589999999999,
          1370.8220000000001,
          1478.484,
          1584.4260000000002,
          1688.4089999999999,
          1790.172,
          1889.43,
          1985.874,
          2079.166,
          2168.946,
          2254.822,
          2336.377,
          2413.167,
          2484.722,
          2550.556,
          2610.1620000000003,
          2663.026,
          2708.633,
          2746.474,
          2776.06,
          2796.941,
          2808.708,
          2811.02,
          2803.6059999999998,
          2786.29,
          2758.987,
          2721.72,
          2674.613,
          2617.8979999999997,
          2551.897,
          2477.0170000000003,
          2393.738,
          2302.592,
          2204.154,
          2099.021,
          1987.797,
          1871.0870000000002,
          1749.48,
          1623.5410000000002,
          1493.808,
          1360.786,
          1224.947,
          1086.723,
          946.513,
          804.677,
          661.543,
          517.408,
          372.536,
          227.165,
          81.508,
          -64.247,
          -209.93200000000002,
          -355.399,
          -500.517,
          -645.17,
          -789.257,
          -932.687,
          -1075.384,
          -1217.278,
          -1358.31,
          -1498.4279999999999,
          -1637.589,
          -1775.753,
          -1912.8870000000002,
          -2048.965,
          -2183.9610000000002,
          -2317.857,
          -2450.636,
          -2582.285,
          -2712.795,
          -2842.155,
          -2970.361,
          -3097.409,
          -3223.295,
          -3348.02,
          -3471.583,
          -3593.986,
          -3715.2309999999998,
          -3835.322,
          -3954.263,
          -4072.059,
          -4188.715,
          -4304.237,
          -4418.630999999999,
          -4531.905,
          -4644.064,
          -4755.117,
          -4865.072,
          -4973.936,
          -5081.717000000001,
          -5188.424,
          -5294.063,
          -5398.644,
          -5502.175,
          -5604.665,
          -5706.121,
          -5806.552,
          -5905.965999999999,
          -6004.371999999999,
          -6101.779,
          -6198.193,
          -6293.624,
          -6388.08,
          -6481.568,
          -6574.097,
          -6665.675,
          -6756.309,
          -6846.008000000001,
          -6934.779,
          -7022.629,
          -7109.566999999999,
          -7195.599,
          -7280.733,
          -7364.976,
          -7448.335,
          -7530.816999999999,
          -7612.429,
          -7693.179,
          -7773.071999999999,
          -7852.115,
          -7930.315,
          -8007.679,
          -8084.2119999999995,
          -8159.920999999999,
          -8234.812,
          -8308.891,
          -8382.164,
          -8454.636999999999,
          -8526.315999999999,
          -8597.205,
          -8667.312,
          -8736.642,
          -8805.2,
          -8872.99,
          -8940.02,
          -9006.293,
          -9071.815,
          -9136.59,
          -9200.625,
          -9263.923,
          -9326.489,
          -9388.329,
          -9449.446,
          -9509.845,
          -9569.532,
          -9628.509,
          -9686.782,
          -9744.354,
          -9801.231,
          -9857.415,
          -9912.912,
          -9967.725,
          -10021.858,
          -10075.315,
          -10128.1,
          -10180.216,
          -10231.667,
          -10282.457,
          -10332.589,
          -10382.068000000001,
          -10430.896,
          -10479.077,
          -10526.614,
          -10573.511,
          -10619.771,
          -10665.396,
          -10710.39,
          -10754.757,
          -10798.499,
          -10841.618999999999,
          -10884.12,
          -10926.006000000001,
          -10967.278,
          -11007.94,
          -11047.993999999999,
          -11087.444,
          -11126.292,
          -11164.541000000001,
          -11202.192,
          -11239.249,
          -11275.715,
          -11311.591,
          -11346.88,
          -11381.585,
          -11415.708,
          -11449.251,
          -11482.216999999999,
          -11514.607,
          -11546.423999999999,
          -11577.671,
          -11608.348,
          -11638.458999999999,
          -11668.005,
          -11696.989,
          -11725.413,
          -11753.278,
          -11780.586000000001,
          -11807.34,
          -11833.54,
          -11859.19,
          -11884.291000000001,
          -11908.844,
          -11932.851999999999,
          -11956.315,
          -11979.237,
          -12001.618,
          -12023.46,
          -12044.764,
          -12065.533000000001,
          -12085.768,
          -12105.47,
          -12124.641000000001,
          -12143.282,
          -12161.395,
          -12178.981000000002,
          -12196.041000000001,
          -12212.578000000001,
          -12228.591999999999,
          -12244.083999999999,
          -12259.056,
          -12273.51,
          -12287.446000000002,
          -12300.865,
          -12313.768999999998,
          -12326.159,
          -12338.037,
          -12349.402,
          -12360.257,
          -12370.601999999999,
          -12380.438999999998,
          -12389.768,
          -12398.591999999999,
          -12406.909,
          -12414.723,
          -12422.032,
          -12428.84,
          -12435.145,
          -12440.95,
          -12446.255,
          -12451.061000000002,
          -12455.368,
          -12459.178999999998,
          -12462.492,
          -12465.31,
          -12467.633,
          -12469.461000000001,
          -12470.796,
          -12471.638,
          -12471.988000000001,
          -12471.846000000001,
          -12471.213,
          -12470.089,
          -12468.476,
          -12466.374,
          -12463.783000000001,
          -12460.704,
          -12457.138,
          -12453.083999999999,
          -12448.544,
          -12443.518,
          -12438.006000000001,
          -12432.008999999998,
          -12425.528,
          -12418.562,
          -12411.112,
          -12403.178,
          -12394.761,
          -12385.862,
          -12376.479,
          -12366.614,
          -12356.267,
          -12345.438999999998,
          -12334.128999999999,
          -12322.337,
          -12310.065,
          -12297.312,
          -12284.078000000001,
          -12270.364,
          -12256.169,
          -12241.493999999999,
          -12226.339,
          -12210.704,
          -12194.589,
          -12177.993999999999,
          -12160.919,
          -12143.364,
          -12125.33,
          -12106.815,
          -12087.821000000002,
          -12068.347,
          -12048.393,
          -12027.958999999999,
          -12007.045,
          -11985.651000000002,
          -11963.777,
          -11941.421999999999,
          -11918.586000000001,
          -11895.27,
          -11871.473,
          -11847.195,
          -11822.435,
          -11797.194,
          -11771.47,
          -11745.265,
          -11718.578000000001,
          -11691.407,
          -11663.753999999999,
          -11635.617,
          -11606.997,
          -11577.892,
          -11548.303,
          -11518.229,
          -11487.67,
          -11456.624,
          -11425.093,
          -11393.076000000001,
          -11360.571000000002,
          -11327.578000000001,
          -11294.098,
          -11260.128,
          -11225.67,
          -11190.721000000001,
          -11155.282,
          -11119.351999999999,
          -11082.93,
          -11046.016000000001,
          -11008.608999999999,
          -10970.708,
          -10932.313,
          -10893.421999999999,
          -10854.036,
          -10814.153,
          -10773.773000000001,
          -10732.895,
          -10691.517,
          -10649.64,
          -10607.261999999999,
          -10564.383,
          -10521.001,
          -10477.115,
          -10432.726,
          -10387.831,
          -10342.43,
          -10296.521999999999,
          -10250.106,
          -10203.18,
          -10155.745,
          -10107.796999999999,
          -10059.338,
          -10010.365,
          -9960.878,
          -9910.874,
          -9860.354,
          -9809.315,
          -9757.757,
          -9705.679,
          -9653.079,
          -9599.956,
          -9546.308,
          -9492.135,
          -9437.435,
          -9382.207,
          -9326.449,
          -9270.16,
          -9213.338,
          -9155.982,
          -9098.091999999999,
          -9039.664,
          -8980.697,
          -8921.190999999999,
          -8861.144,
          -8800.553,
          -8739.418,
          -8677.737,
          -8615.508,
          -8552.73,
          -8489.4,
          -8425.518,
          -8361.081,
          -8296.088,
          -8230.537,
          -8164.427,
          -8097.755,
          -8030.519,
          -7962.719,
          -7894.351,
          -7825.415,
          -7755.908,
          -7685.828,
          -7615.174,
          -7543.941999999999,
          -7472.133000000001,
          -7399.744000000001,
          -7326.772,
          -7253.215999999999,
          -7179.0740000000005,
          -7104.343000000001,
          -7029.023,
          -6953.109,
          -6876.602,
          -6799.4980000000005,
          -6721.795,
          -6643.491999999999,
          -6564.5869999999995,
          -6485.076999999999,
          -6404.96,
          -6324.234,
          -6242.898,
          -6160.9490000000005,
          -6078.385,
          -5995.204000000001,
          -5911.405,
          -5826.985,
          -5741.941999999999,
          -5656.274,
          -5569.98,
          -5483.058000000001,
          -5395.505,
          -5307.321,
          -5218.503,
          -5129.049,
          -5038.96,
          -4948.231,
          -4856.863,
          -4764.854,
          -4672.2029999999995,
          -4578.909000000001,
          -4484.97,
          -4390.387,
          -4295.157999999999,
          -4199.282,
          -4102.76,
          -4005.591,
          -3907.775,
          -3809.313,
          -3710.205,
          -3610.452,
          -3510.055,
          -3409.015,
          -3307.335,
          -3205.0159999999996,
          -3102.0609999999997,
          -2998.473,
          -2894.256,
          -2789.414,
          -2683.952,
          -2577.874,
          -2471.188,
          -2363.899,
          -2256.016,
          -2147.547,
          -2038.503,
          -1928.8929999999998,
          -1818.729,
          -1708.026,
          -1596.797,
          -1485.058,
          -1372.829,
          -1260.128,
          -1146.978,
          -1033.403,
          -919.429,
          -805.086,
          -690.4069999999999,
          -575.4259999999999,
          -460.18300000000005,
          -344.722,
          -229.08900000000003,
          -113.338,
          2.475,
          118.286,
          234.02599999999998,
          349.61699999999996,
          464.975,
          580.008,
          694.613,
          808.677,
          922.078,
          1034.678,
          1146.328,
          1256.865,
          1366.106,
          1473.854,
          1579.892,
          1683.98,
          1785.86,
          1885.247,
          1981.8329999999999,
          2075.282,
          2165.232,
          2251.295,
          2333.054,
          2410.0660000000003,
          2481.863,
          2547.958,
          2607.846,
          2661.013,
          2706.942,
          2745.1259999999997,
          2775.075,
          2796.336,
          2808.4990000000003,
          2811.22,
          2804.225,
          2787.333,
          2760.4570000000003,
          2723.616,
          2676.93,
          2620.625,
          2555.02,
          2480.52,
          2397.601,
          2306.795,
          2208.674,
          2103.833,
          1992.879,
          1876.415,
          1755.029,
          1629.29,
          1499.735,
          1366.872,
          1231.172,
          1093.07,
          952.965,
          811.22,
          668.164,
          524.094,
          379.276,
          233.949,
          88.32600000000001,
          -57.402,
          -203.06900000000002,
          -348.524,
          -493.63599999999997,
          -638.288,
          -782.3789999999999,
          -925.818,
          -1068.527,
          -1210.437,
          -1351.4879999999998,
          -1492.118,
          -1630.8139999999999,
          -1769.005,
          -1906.1689999999999,
          -2042.277,
          -2177.306,
          -2311.237,
          -2444.051,
          -2575.736,
          -2706.283,
          -2835.6820000000002,
          -2963.928,
          -3091.015,
          -3216.9429999999998,
          -3341.7090000000003,
          -3465.313,
          -3587.759,
          -3709.047,
          -3829.1809999999996,
          -3948.165,
          -4066.0040000000004,
          -4182.704000000001,
          -4298.27,
          -4412.708,
          -4526.026,
          -4638.229,
          -4749.327,
          -4859.327,
          -4968.235,
          -5076.061,
          -5182.812,
          -5288.496,
          -5393.121,
          -5496.696999999999,
          -5599.231,
          -5700.731,
          -5801.206,
          -5900.665,
          -5999.115,
          -6096.566,
          -6193.024,
          -6288.499,
          -6382.999,
          -6476.531,
          -6569.103,
          -6660.724,
          -6751.401999999999,
          -6841.144,
          -6929.9580000000005,
          -7017.851,
          -7104.831,
          -7190.906,
          -7276.0830000000005,
          -7360.368,
          -7443.77,
          -7526.294,
          -7607.9490000000005,
          -7688.74,
          -7768.675,
          -7847.76,
          -7926.0019999999995,
          -8003.406999999999,
          -8079.981,
          -8155.731,
          -8230.664,
          -8304.784,
          -8378.098,
          -8450.610999999999,
          -8522.33,
          -8593.26,
          -8663.408000000001,
          -8732.778,
          -8801.375,
          -8869.206,
          -8936.275,
          -9002.588,
          -9068.15,
          -9132.965,
          -9197.039,
          -9260.376,
          -9322.981,
          -9384.86,
          -9446.016,
          -9506.454,
          -9566.179,
          -9625.195,
          -9683.506,
          -9741.117,
          -9798.032,
          -9854.255,
          -9909.79,
          -9964.64,
          -10018.811,
          -10072.306,
          -10125.128,
          -10177.282,
          -10228.77,
          -10279.598,
          -10329.768,
          -10379.283000000001,
          -10428.149,
          -10476.367,
          -10523.941,
          -10570.874,
          -10617.17,
          -10662.832,
          -10707.863000000001,
          -10752.266000000001,
          -10796.044,
          -10839.2,
          -10881.738000000001,
          -10923.659,
          -10964.966999999999,
          -11005.665,
          -11045.755,
          -11085.241000000002,
          -11124.124,
          -11162.408000000001,
          -11200.095,
          -11237.188,
          -11273.688999999998,
          -11309.6,
          -11344.923999999999,
          -11379.663999999999,
          -11413.822,
          -11447.4,
          -11480.4,
          -11512.825,
          -11544.677,
          -11575.958,
          -11606.67,
          -11636.815,
          -11666.396,
          -11695.413999999999,
          -11723.871000000001,
          -11751.77,
          -11779.113000000001,
          -11805.9,
          -11832.135,
          -11857.819,
          -11882.953000000001,
          -11907.54,
          -11931.581,
          -11955.078000000001,
          -11978.033000000001,
          -12000.447,
          -12022.323,
          -12043.661,
          -12064.463,
          -12084.73,
          -12104.465,
          -12123.669,
          -12142.343,
          -12160.489,
          -12178.108,
          -12195.201000000001,
          -12211.77,
          -12227.817,
          -12243.341,
          -12258.346000000001,
          -12272.832,
          -12286.8,
          -12300.252,
          -12313.188,
          -12325.611,
          -12337.52,
          -12348.918,
          -12359.803999999998,
          -12370.181,
          -12380.05,
          -12389.411,
          -12398.266000000001,
          -12406.615,
          -12414.46,
          -12421.802,
          -12428.64,
          -12434.976999999999,
          -12440.813,
          -12446.15,
          -12450.987,
          -12455.326000000001,
          -12459.167,
          -12462.511999999999,
          -12465.361,
          -12467.715,
          -12469.573999999999,
          -12470.94,
          -12471.812,
          -12472.193000000001,
          -12472.081,
          -12471.479,
          -12470.386,
          -12468.803999999998,
          -12466.732,
          -12464.171999999999,
          -12461.123,
          -12457.587,
          -12453.563999999998,
          -12449.053999999998,
          -12444.058,
          -12438.577,
          -12432.61,
          -12426.158000000001,
          -12419.222,
          -12411.802,
          -12403.898000000001,
          -12395.511999999999,
          -12386.642,
          -12377.288999999999,
          -12367.454,
          -12357.136,
          -12346.337,
          -12335.056999999999,
          -12323.295,
          -12311.052,
          -12298.329,
          -12285.124,
          -12271.438999999998,
          -12257.274,
          -12242.628,
          -12227.502,
          -12211.896,
          -12195.81,
          -12179.243999999999,
          -12162.198,
          -12144.671999999999,
          -12126.667,
          -12108.181,
          -12089.216,
          -12069.771,
          -12049.845,
          -12029.44,
          -12008.555,
          -11987.188999999998,
          -11965.343,
          -11943.017,
          -11920.21,
          -11896.921999999999,
          -11873.153,
          -11848.903,
          -11824.171999999999,
          -11798.958999999999,
          -11773.264,
          -11747.086000000001,
          -11720.427,
          -11693.285,
          -11665.659,
          -11637.55,
          -11608.958,
          -11579.881000000001,
          -11550.32,
          -11520.274,
          -11489.742,
          -11458.725,
          -11427.221000000001,
          -11395.231000000002,
          -11362.753999999999,
          -11329.788999999999,
          -11296.335,
          -11262.393,
          -11227.962,
          -11193.041000000001,
          -11157.628999999999,
          -11121.726,
          -11085.332,
          -11048.445,
          -11011.065,
          -10973.191,
          -10934.823,
          -10895.958999999999,
          -10856.6,
          -10816.743999999999,
          -10776.391000000001,
          -10735.538999999999,
          -10694.188999999998,
          -10652.338,
          -10609.987,
          -10567.133999999998,
          -10523.778999999999,
          -10479.92,
          -10435.556999999999,
          -10390.689,
          -10345.315,
          -10299.434000000001,
          -10253.044,
          -10206.144,
          -10158.735,
          -10110.814,
          -10062.381,
          -10013.434000000001,
          -9963.972,
          -9913.995,
          -9863.501,
          -9812.488000000001,
          -9760.957,
          -9708.904,
          -9656.33,
          -9603.233,
          -9549.610999999999,
          -9495.464,
          -9440.789,
          -9385.587,
          -9329.854,
          -9273.59,
          -9216.794,
          -9159.464,
          -9101.598,
          -9043.196,
          -8984.255,
          -8924.774,
          -8864.752,
          -8804.186,
          -8743.076,
          -8681.42,
          -8619.216,
          -8556.463,
          -8493.158000000001,
          -8429.3,
          -8364.888,
          -8299.92,
          -8234.394,
          -8168.308000000001,
          -8101.66,
          -8034.4490000000005,
          -7966.673000000001,
          -7898.33,
          -7829.418000000001,
          -7759.935,
          -7689.879,
          -7619.249,
          -7548.043000000001,
          -7476.258000000001,
          -7403.892,
          -7330.944,
          -7257.411999999999,
          -7183.294,
          -7108.5869999999995,
          -7033.289000000001,
          -6957.4,
          -6880.916,
          -6803.835,
          -6726.156,
          -6647.876,
          -6568.993,
          -6489.505999999999,
          -6409.411999999999,
          -6328.71,
          -6247.396,
          -6165.47,
          -6082.928000000001,
          -5999.77,
          -5915.993,
          -5831.595,
          -5746.5740000000005,
          -5660.928000000001,
          -5574.656,
          -5487.755,
          -5400.224,
          -5312.061,
          -5223.264,
          -5133.832,
          -5043.763,
          -4953.055,
          -4861.708,
          -4769.72,
          -4677.089,
          -4583.815,
          -4489.897,
          -4395.333,
          -4300.124,
          -4204.267,
          -4107.764,
          -4010.614,
          -3912.817,
          -3814.373,
          -3715.283,
          -3615.548,
          -3515.1679999999997,
          -3414.145,
          -3312.482,
          -3210.179,
          -3107.24,
          -3003.6679999999997,
          -2899.466,
          -2794.638,
          -2689.19,
          -2583.126,
          -2476.452,
          -2369.176,
          -2261.305,
          -2152.847,
          -2043.8120000000001,
          -1934.2120000000002,
          -1824.057,
          -1713.361,
          -1602.139,
          -1490.4070000000002,
          -1378.182,
          -1265.485,
          -1152.337,
          -1038.762,
          -924.788,
          -810.443,
          -695.7589999999999,
          -580.773,
          -465.522,
          -350.051,
          -234.405,
          -118.639,
          -2.8080000000000003,
          113.024,
          228.787,
          344.406,
          459.796,
          574.865,
          689.51,
          803.62,
          917.072,
          1029.729,
          1141.443,
          1252.05,
          1361.37,
          1469.205,
          1575.339,
          1679.5339999999999,
          1781.531,
          1881.047,
          1977.775,
          2071.38,
          2161.5,
          2247.75,
          2329.7129999999997,
          2406.947,
          2478.985,
          2545.341,
          2605.511,
          2658.98,
          2705.232,
          2743.758,
          2774.0679999999998,
          2795.7090000000003,
          2808.2670000000003,
          2811.395,
          2804.8190000000004,
          2788.3520000000003,
          2761.903,
          2725.486,
          2679.22,
          2623.325,
          2558.117,
          2483.998,
          2401.44,
          2310.973,
          2213.169,
          2108.6220000000003,
          1997.9379999999999,
          1881.72,
          1760.557,
          1635.0179999999998,
          1505.6429999999998,
          1372.9389999999999,
          1237.379,
          1099.4,
          959.4019999999999,
          817.748,
          674.7710000000001,
          530.766,
          386.00300000000004,
          240.72,
          95.133,
          -50.568999999999996,
          -196.21599999999998,
          -341.658,
          -486.76300000000003,
          -631.415,
          -775.5089999999999,
          -918.956,
          -1061.677,
          -1203.603,
          -1344.6729999999998,
          -1484.835,
          -1624.0439999999999,
          -1762.2620000000002,
          -1899.454,
          -2035.5929999999998,
          -2170.654,
          -2304.618,
          -2437.468,
          -2569.19,
          -2699.7740000000003,
          -2829.211,
          -2957.4959999999996,
          -3084.623,
          -3210.591,
          -3335.3979999999997,
          -3459.0440000000003,
          -3581.531,
          -3702.862,
          -3823.038,
          -3942.066,
          -4059.948,
          -4176.691,
          -4292.3009999999995,
          -4406.782999999999,
          -4520.145,
          -4632.394,
          -4743.536,
          -4853.58,
          -4962.532,
          -5070.402,
          -5177.197,
          -5282.9259999999995,
          -5387.596,
          -5491.215999999999,
          -5593.794,
          -5695.338000000001,
          -5795.858,
          -5895.36,
          -5993.855,
          -6091.349,
          -6187.851,
          -6283.37,
          -6377.9130000000005,
          -6471.4890000000005,
          -6564.105,
          -6655.77,
          -6746.49,
          -6836.275,
          -6925.132,
          -7013.068,
          -7100.090999999999,
          -7186.209,
          -7271.428000000001,
          -7355.755999999999,
          -7439.1990000000005,
          -7521.766,
          -7603.463000000001,
          -7684.295999999999,
          -7764.273,
          -7843.399,
          -7921.683000000001,
          -7999.129,
          -8075.745,
          -8151.536,
          -8226.509,
          -8300.67,
          -8374.025,
          -8446.58,
          -8518.34,
          -8589.311,
          -8659.498,
          -8728.908000000001,
          -8797.546,
          -8865.417,
          -8932.526,
          -8998.879,
          -9064.48,
          -9129.334,
          -9193.448,
          -9256.824,
          -9319.469000000001,
          -9381.386999999999,
          -9442.582,
          -9503.059000000001,
          -9562.822,
          -9621.877,
          -9680.226999999999,
          -9737.876,
          -9794.829,
          -9851.09,
          -9906.663,
          -9961.552,
          -10015.76,
          -10069.293,
          -10122.153,
          -10174.344000000001,
          -10225.87,
          -10276.735999999999,
          -10326.943000000001,
          -10376.496,
          -10425.398000000001,
          -10473.653,
          -10521.264,
          -10568.233999999999,
          -10614.567,
          -10660.266000000001,
          -10705.333,
          -10749.771999999999,
          -10793.587,
          -10836.778999999999,
          -10879.353000000001,
          -10921.311000000002,
          -10962.655,
          -11003.389,
          -11043.515,
          -11083.036,
          -11121.955,
          -11160.275,
          -11197.997,
          -11235.125,
          -11271.661,
          -11307.608,
          -11342.966999999999,
          -11377.742,
          -11411.935,
          -11445.548,
          -11478.583,
          -11511.043,
          -11542.93,
          -11574.245,
          -11604.992,
          -11635.171999999999,
          -11664.786,
          -11693.839,
          -11722.331,
          -11750.264,
          -11777.64,
          -11804.462,
          -11830.73,
          -11856.448,
          -11881.616000000002,
          -11906.237,
          -11930.312,
          -11953.841999999999,
          -11976.831,
          -11999.278999999999,
          -12021.187,
          -12042.558,
          -12063.393999999998,
          -12083.695,
          -12103.463,
          -12122.7,
          -12141.407,
          -12159.586000000001,
          -12177.237,
          -12194.363000000001,
          -12210.965,
          -12227.044,
          -12242.601999999999,
          -12257.639,
          -12272.158000000001,
          -12286.158000000001,
          -12299.642,
          -12312.611,
          -12325.066,
          -12337.007,
          -12348.437,
          -12359.356000000002,
          -12369.766000000001,
          -12379.666000000001,
          -12389.06,
          -12397.946000000002,
          -12406.327,
          -12414.204,
          -12421.577,
          -12428.447,
          -12434.816,
          -12440.684,
          -12446.051000000001,
          -12450.92,
          -12455.29,
          -12459.163,
          -12462.538999999999,
          -12465.419,
          -12467.803999999998,
          -12469.694,
          -12471.091,
          -12471.995,
          -12472.406,
          -12472.326000000001,
          -12471.753999999999,
          -12470.692,
          -12469.14,
          -12467.098999999998,
          -12464.569,
          -12461.551000000001,
          -12458.046,
          -12454.053,
          -12449.573999999999,
          -12444.608,
          -12439.157,
          -12433.22,
          -12426.798999999999,
          -12419.893,
          -12412.503,
          -12404.628999999999,
          -12396.271999999999,
          -12387.431999999999,
          -12378.11,
          -12368.305,
          -12358.017,
          -12347.248,
          -12335.998,
          -12324.266000000001,
          -12312.052,
          -12299.358,
          -12286.183,
          -12272.528,
          -12258.392,
          -12243.775,
          -12228.678,
          -12213.101999999999,
          -12197.045,
          -12180.508,
          -12163.491000000002,
          -12145.995,
          -12128.018,
          -12109.562,
          -12090.625,
          -12071.208999999999,
          -12051.312,
          -12030.936000000002,
          -12010.079,
          -11988.742,
          -11966.925,
          -11944.627,
          -11921.848999999998,
          -11898.59,
          -11874.848999999998,
          -11850.628,
          -11825.925,
          -11800.74,
          -11775.073,
          -11748.923999999999,
          -11722.293,
          -11695.178999999998,
          -11667.582,
          -11639.501,
          -11610.937,
          -11581.888,
          -11552.354,
          -11522.336000000001,
          -11491.832,
          -11460.843,
          -11429.367,
          -11397.405,
          -11364.955,
          -11332.018,
          -11298.591999999999,
          -11264.678,
          -11230.274,
          -11195.38,
          -11159.996000000001,
          -11124.12,
          -11087.753,
          -11050.893,
          -11013.54,
          -10975.694,
          -10937.353000000001,
          -10898.517,
          -10859.184,
          -10819.356000000002,
          -10779.028999999999,
          -10738.205,
          -10696.881000000001,
          -10655.056999999999,
          -10612.733,
          -10569.907,
          -10526.578000000001,
          -10482.746,
          -10438.41,
          -10393.568000000001,
          -10348.22,
          -10302.365,
          -10256.001,
          -10209.128,
          -10161.745,
          -10113.851,
          -10065.444,
          -10016.523000000001,
          -9967.088,
          -9917.136999999999,
          -9866.668,
          -9815.681999999999,
          -9764.176,
          -9712.15,
          -9659.601999999999,
          -9606.53,
          -9552.934000000001,
          -9498.813,
          -9444.164,
          -9388.987,
          -9333.28,
          -9277.042,
          -9220.271,
          -9162.966,
          -9105.126,
          -9046.749,
          -8987.833,
          -8928.378,
          -8868.381,
          -8807.841,
          -8746.756,
          -8685.125,
          -8622.946,
          -8560.216999999999,
          -8496.937,
          -8433.105,
          -8368.716999999999,
          -8303.774,
          -8238.271999999999,
          -8172.210999999999,
          -8105.588000000001,
          -8038.401,
          -7970.649,
          -7902.331,
          -7833.443,
          -7763.984,
          -7693.953,
          -7623.347,
          -7552.165,
          -7480.404,
          -7408.062,
          -7335.138000000001,
          -7261.63,
          -7187.535,
          -7112.852,
          -7037.578,
          -6961.7119999999995,
          -6885.251,
          -6808.194,
          -6730.5380000000005,
          -6652.281,
          -6573.422,
          -6493.9580000000005,
          -6413.887,
          -6333.206999999999,
          -6251.916,
          -6170.012,
          -6087.493,
          -6004.358,
          -5920.603,
          -5836.227,
          -5751.228,
          -5665.604,
          -5579.354,
          -5492.475,
          -5404.965999999999,
          -5316.8240000000005,
          -5228.049,
          -5138.637,
          -5048.59,
          -4957.903,
          -4866.576,
          -4774.609,
          -4681.998,
          -4588.745,
          -4494.846,
          -4400.302,
          -4305.112,
          -4209.275,
          -4112.791,
          -4015.66,
          -3917.881,
          -3819.455,
          -3720.383,
          -3620.665,
          -3520.303,
          -3419.297,
          -3317.65,
          -3215.364,
          -3112.441,
          -3008.884,
          -2904.697,
          -2799.884,
          -2694.45,
          -2588.399,
          -2481.738,
          -2374.474,
          -2266.615,
          -2158.1679999999997,
          -2049.144,
          -1939.5520000000001,
          -1829.406,
          -1718.7179999999998,
          -1607.5020000000002,
          -1495.776,
          -1383.556,
          -1270.862,
          -1157.7160000000001,
          -1044.142,
          -930.1669999999999,
          -815.819,
          -701.132,
          -586.139,
          -470.88,
          -355.399,
          -239.74099999999999,
          -123.959,
          -8.111,
          107.742,
          223.53,
          339.17699999999996,
          454.598,
          569.703,
          684.3889999999999,
          798.544,
          912.047,
          1024.762,
          1136.539,
          1247.2169999999999,
          1356.616,
          1464.5379999999998,
          1570.767,
          1675.069,
          1777.183,
          1876.829,
          1973.6989999999998,
          2067.46,
          2157.752,
          2244.189,
          2326.356,
          2403.812,
          2476.093,
          2542.71,
          2603.161,
          2656.933,
          2703.508,
          2742.3779999999997,
          2773.051,
          2795.072,
          2808.028,
          2811.566,
          2805.41,
          2789.37,
          2763.35,
          2727.362,
          2681.5190000000002,
          2626.0370000000003,
          2561.229,
          2487.493,
          2405.3,
          2315.176,
          2217.6929999999998,
          2113.4429999999998,
          2003.0320000000002,
          1887.0629999999999,
          1766.126,
          1640.7910000000002,
          1511.5970000000002,
          1379.055,
          1243.637,
          1105.7830000000001,
          965.893,
          824.3330000000001,
          681.435,
          537.498,
          392.791,
          247.554,
          102.00299999999999,
          -43.67100000000001,
          -189.298,
          -334.726,
          -479.824,
          -624.474,
          -768.571,
          -912.0260000000001,
          -1054.759,
          -1196.7,
          -1337.7879999999998,
          -1477.9720000000002,
          -1617.2060000000001,
          -1755.45,
          -1892.67,
          -2028.84,
          -2163.933,
          -2297.931,
          -2430.815,
          -2562.574,
          -2693.195,
          -2822.671,
          -2950.994,
          -3078.1609999999996,
          -3204.17,
          -3329.018,
          -3452.7059999999997,
          -3575.236,
          -3696.6090000000004,
          -3816.828,
          -3935.8990000000003,
          -4053.825,
          -4170.612,
          -4286.266,
          -4400.793,
          -4514.1990000000005,
          -4626.492,
          -4737.679,
          -4847.767,
          -4956.765,
          -5064.679,
          -5171.519,
          -5277.2919999999995,
          -5382.007,
          -5485.672,
          -5588.294,
          -5689.883000000001,
          -5790.446999999999,
          -5889.995,
          -5988.534000000001,
          -6086.071999999999,
          -6182.619000000001,
          -6278.182,
          -6372.769,
          -6466.388000000001,
          -6559.049,
          -6650.757,
          -6741.522,
          -6831.35,
          -6920.25,
          -7008.23,
          -7095.295999999999,
          -7181.456999999999,
          -7266.719,
          -7351.09,
          -7434.576,
          -7517.186,
          -7598.925,
          -7679.8,
          -7759.819,
          -7838.988,
          -7917.314,
          -7994.802,
          -8071.46,
          -8147.293000000001,
          -8222.306999999999,
          -8296.51,
          -8369.905999999999,
          -8442.502,
          -8514.302,
          -8585.314,
          -8655.543,
          -8724.994,
          -8793.671999999999,
          -8861.583,
          -8928.733,
          -8995.126,
          -9060.767,
          -9125.662,
          -9189.815,
          -9253.231,
          -9315.916,
          -9377.873,
          -9439.107,
          -9499.624,
          -9559.427,
          -9618.52,
          -9676.909,
          -9734.597,
          -9791.589,
          -9847.889000000001,
          -9903.5,
          -9958.427,
          -10012.674,
          -10066.245,
          -10119.143,
          -10171.373,
          -10222.937,
          -10273.84,
          -10324.085,
          -10373.676,
          -10422.616,
          -10470.908000000001,
          -10518.556999999999,
          -10565.563999999998,
          -10611.934,
          -10657.67,
          -10702.774,
          -10747.251,
          -10791.101999999999,
          -10834.331,
          -10876.942,
          -10918.936000000002,
          -10960.316,
          -11001.087,
          -11041.249,
          -11080.806999999999,
          -11119.761999999999,
          -11158.117,
          -11195.876,
          -11233.04,
          -11269.612,
          -11305.594,
          -11340.989,
          -11375.8,
          -11410.028,
          -11443.677,
          -11476.747,
          -11509.242,
          -11541.163999999999,
          -11572.515,
          -11603.296,
          -11633.511,
          -11663.16,
          -11692.248,
          -11720.775,
          -11748.742,
          -11776.153,
          -11803.01,
          -11829.313,
          -11855.065,
          -11880.267,
          -11904.921999999999,
          -11929.031,
          -11952.596000000001,
          -11975.618,
          -11998.1,
          -12020.043,
          -12041.448,
          -12062.317,
          -12082.652,
          -12102.453000000001,
          -12121.723999999998,
          -12140.464,
          -12158.677,
          -12176.362,
          -12193.521,
          -12210.156,
          -12226.268999999998,
          -12241.858999999999,
          -12256.93,
          -12271.481000000002,
          -12285.514,
          -12299.031,
          -12312.033000000001,
          -12324.52,
          -12336.495,
          -12347.957,
          -12358.909,
          -12369.351,
          -12379.284,
          -12388.71,
          -12397.628999999999,
          -12406.042,
          -12413.951000000001,
          -12421.356000000002,
          -12428.258999999998,
          -12434.659,
          -12440.559,
          -12445.958999999999,
          -12450.858999999999,
          -12455.261,
          -12459.166000000001,
          -12462.573,
          -12465.485,
          -12467.902,
          -12469.823999999999,
          -12471.252,
          -12472.187,
          -12472.63,
          -12472.581,
          -12472.04,
          -12471.01,
          -12469.489,
          -12467.479,
          -12464.98,
          -12461.993,
          -12458.518999999998,
          -12454.556999999999,
          -12450.108,
          -12445.173999999999,
          -12439.753,
          -12433.847,
          -12427.457,
          -12420.581,
          -12413.222,
          -12405.378999999999,
          -12397.052,
          -12388.243,
          -12378.951000000001,
          -12369.176000000001,
          -12358.919,
          -12348.18,
          -12336.96,
          -12325.258,
          -12313.075,
          -12300.41,
          -12287.265,
          -12273.64,
          -12259.534,
          -12244.947,
          -12229.88,
          -12214.333,
          -12198.306,
          -12181.798999999999,
          -12164.812,
          -12147.345,
          -12129.398000000001,
          -12110.971000000001,
          -12092.063999999998,
          -12072.677,
          -12052.81,
          -12032.463,
          -12011.635,
          -11990.328000000001,
          -11968.538999999999,
          -11946.271,
          -11923.521,
          -11900.291000000001,
          -11876.58,
          -11852.386999999999,
          -11827.713,
          -11802.556999999999,
          -11776.919,
          -11750.798999999999,
          -11724.197,
          -11697.111,
          -11669.543,
          -11641.49,
          -11612.955,
          -11583.934,
          -11554.43,
          -11524.44,
          -11493.964,
          -11463.003,
          -11431.555,
          -11399.621000000001,
          -11367.2,
          -11334.29,
          -11300.893,
          -11267.007,
          -11232.631000000001,
          -11197.765,
          -11162.409,
          -11126.561000000002,
          -11090.222,
          -11053.39,
          -11016.065,
          -10978.246000000001,
          -10939.933,
          -10901.124,
          -10861.819,
          -10822.018,
          -10781.719,
          -10740.921999999999,
          -10699.626,
          -10657.829,
          -10615.532,
          -10572.733999999999,
          -10529.431999999999,
          -10485.627,
          -10441.318000000001,
          -10396.504,
          -10351.183,
          -10305.354,
          -10259.018,
          -10212.171999999999,
          -10164.815999999999,
          -10116.948,
          -10068.568000000001,
          -10019.674,
          -9970.266,
          -9920.341,
          -9869.9,
          -9818.94,
          -9767.461,
          -9715.461,
          -9662.939,
          -9609.894,
          -9556.324,
          -9502.229,
          -9447.607,
          -9392.456,
          -9336.775,
          -9280.563,
          -9223.819,
          -9166.54,
          -9108.726,
          -9050.375,
          -8991.485,
          -8932.055,
          -8872.084,
          -8811.569,
          -8750.51,
          -8688.905,
          -8626.751,
          -8564.048,
          -8500.794,
          -8436.987,
          -8372.625,
          -8307.707,
          -8242.231,
          -8176.194,
          -8109.597,
          -8042.435,
          -7974.709,
          -7906.415,
          -7837.552,
          -7768.118,
          -7698.111999999999,
          -7627.531,
          -7556.3730000000005,
          -7484.637,
          -7412.32,
          -7339.42,
          -7265.936,
          -7191.866,
          -7117.206999999999,
          -7041.9580000000005,
          -6966.116,
          -6889.679,
          -6812.646,
          -6735.014,
          -6656.781,
          -6577.946,
          -6498.505,
          -6418.4580000000005,
          -6337.8009999999995,
          -6256.534000000001,
          -6174.653,
          -6092.158,
          -6009.045,
          -5925.313,
          -5840.96,
          -5755.984,
          -5670.383000000001,
          -5584.156,
          -5497.299,
          -5409.812,
          -5321.693,
          -5232.939,
          -5143.55,
          -5053.524,
          -4962.859,
          -4871.554,
          -4779.607,
          -4687.018,
          -4593.785,
          -4499.907,
          -4405.384,
          -4310.214,
          -4214.397,
          -4117.933,
          -4020.821,
          -3923.062,
          -3824.655,
          -3725.6020000000003,
          -3625.903,
          -3525.558,
          -3424.57,
          -3322.941,
          -3220.672,
          -3117.765,
          -3014.224,
          -2910.053,
          -2805.255,
          -2699.836,
          -2593.799,
          -2487.152,
          -2379.901,
          -2272.054,
          -2163.619,
          -2054.606,
          -1945.025,
          -1834.888,
          -1724.2079999999999,
          -1613,
          -1501.279,
          -1389.0639999999999,
          -1276.375,
          -1163.231,
          -1049.6589999999999,
          -935.684,
          -821.334,
          -706.643,
          -591.645,
          -476.37800000000004,
          -360.88699999999994,
          -245.217,
          -129.42,
          -13.554,
          102.32,
          218.132,
          333.806,
          449.259,
          564.4,
          679.127,
          793.329,
          906.883,
          1019.655,
          1131.498,
          1242.247,
          1351.725,
          1459.736,
          1566.0639999999999,
          1670.474,
          1772.7079999999999,
          1872.486,
          1969.501,
          2063.422,
          2153.889,
          2240.518,
          2322.895,
          2400.58,
          2473.1079999999997,
          2539.994,
          2600.735,
          2654.817,
          2701.725,
          2740.949,
          2771.9959999999996,
          2794.409,
          2807.7740000000003,
          2811.735,
          2806.013,
          2790.413,
          2764.8379999999997,
          2729.292,
          2683.886,
          2628.8320000000003,
          2564.438,
          2491.1,
          2409.284,
          2319.5170000000003,
          2222.366,
          2118.424,
          2008.296,
          1892.586,
          1771.8829999999998,
          1646.7579999999998,
          1517.753,
          1385.378,
          1250.109,
          1112.384,
          972.6060000000001,
          831.143,
          688.328,
          544.46,
          399.811,
          254.62099999999998,
          109.10700000000001,
          -36.538000000000004,
          -182.143,
          -327.559,
          -472.649,
          -617.297,
          -761.398,
          -904.8610000000001,
          -1047.606,
          -1189.563,
          -1330.671,
          -1470.557,
          -1610.136,
          -1748.408,
          -1885.6589999999999,
          -2021.86,
          -2156.987,
          -2291.02,
          -2423.9410000000003,
          -2555.737,
          -2686.397,
          -2815.913,
          -2944.277,
          -3071.486,
          -3197.5370000000003,
          -3322.428,
          -3446.159,
          -3568.7329999999997,
          -3690.15,
          -3810.415,
          -3929.531,
          -4047.502,
          -4164.335,
          -4280.034000000001,
          -4394.607,
          -4508.059,
          -4620.398,
          -4731.6320000000005,
          -4841.766,
          -4950.81,
          -5058.771,
          -5165.657999999999,
          -5271.477,
          -5376.238,
          -5479.9490000000005,
          -5582.618,
          -5684.254,
          -5784.8640000000005,
          -5884.456999999999,
          -5983.0419999999995,
          -6080.6269999999995,
          -6177.219,
          -6272.828,
          -6367.460999999999,
          -6461.126,
          -6553.831999999999,
          -6645.585,
          -6736.395,
          -6826.269,
          -6915.214,
          -7003.238,
          -7090.349,
          -7176.555,
          -7261.861,
          -7346.276,
          -7429.807,
          -7512.46,
          -7594.244000000001,
          -7675.1630000000005,
          -7755.226,
          -7834.438,
          -7912.807,
          -7990.339,
          -8067.039000000001,
          -8142.915,
          -8217.973,
          -8292.218,
          -8365.657,
          -8438.295,
          -8510.138,
          -8581.193000000001,
          -8651.463,
          -8720.956,
          -8789.676,
          -8857.629,
          -8924.82,
          -8991.255,
          -9056.937,
          -9121.873,
          -9186.067,
          -9249.525,
          -9312.25,
          -9374.248,
          -9435.523000000001,
          -9496.08,
          -9555.923,
          -9615.056999999999,
          -9673.485999999999,
          -9731.214,
          -9788.246,
          -9844.586,
          -9900.237,
          -9955.204,
          -10009.49,
          -10063.1,
          -10116.038,
          -10168.306,
          -10219.91,
          -10270.851999999999,
          -10321.135,
          -10370.765,
          -10419.743,
          -10468.074,
          -10515.761,
          -10562.806999999999,
          -10609.215,
          -10654.989,
          -10700.132,
          -10744.646,
          -10788.535,
          -10831.802,
          -10874.45,
          -10916.482,
          -10957.9,
          -10998.707,
          -11038.907,
          -11078.502,
          -11117.493999999999,
          -11155.886999999999,
          -11193.681999999999,
          -11230.883,
          -11267.492,
          -11303.511,
          -11338.942,
          -11373.79,
          -11408.053999999998,
          -11441.739,
          -11474.846000000001,
          -11507.377,
          -11539.335,
          -11570.721000000001,
          -11601.538999999999,
          -11631.79,
          -11661.475,
          -11690.598,
          -11719.16,
          -11747.163,
          -11774.61,
          -11801.501,
          -11827.84,
          -11853.627,
          -11878.864,
          -11903.553999999998,
          -11927.698,
          -11951.298,
          -11974.355,
          -11996.872,
          -12018.848999999998,
          -12040.288999999999,
          -12061.192,
          -12081.562,
          -12101.398000000001,
          -12120.703000000001,
          -12139.476999999999,
          -12157.723999999998,
          -12175.443000000001,
          -12192.636,
          -12209.305,
          -12225.452,
          -12241.076000000001,
          -12256.18,
          -12270.765,
          -12284.832,
          -12298.383,
          -12311.418,
          -12323.938999999998,
          -12335.947,
          -12347.442,
          -12358.427,
          -12368.902,
          -12378.868999999999,
          -12388.327,
          -12397.278999999999,
          -12405.726,
          -12413.668,
          -12421.106000000002,
          -12428.041000000001,
          -12434.473999999998,
          -12440.406,
          -12445.839,
          -12450.784,
          -12455.219,
          -12459.156,
          -12462.596000000001,
          -12465.538999999999,
          -12467.988000000001,
          -12469.942,
          -12471.402,
          -12472.368999999999,
          -12472.844,
          -12472.827,
          -12472.318000000001,
          -12471.319,
          -12469.83,
          -12467.851999999999,
          -12465.383999999998,
          -12462.428999999998,
          -12458.986,
          -12455.055,
          -12450.638,
          -12445.735,
          -12440.345,
          -12434.471000000001,
          -12428.111,
          -12421.267,
          -12413.938,
          -12406.126,
          -12397.83,
          -12389.052,
          -12379.79,
          -12370.046,
          -12359.82,
          -12349.112,
          -12337.921999999999,
          -12326.25,
          -12314.098,
          -12301.464,
          -12288.348999999998,
          -12274.753999999999,
          -12260.678,
          -12246.122,
          -12231.085,
          -12215.568000000001,
          -12199.571000000002,
          -12183.094,
          -12166.136999999999,
          -12148.7,
          -12130.782,
          -12112.385,
          -12093.508,
          -12074.151000000002,
          -12054.313,
          -12033.996000000001,
          -12013.198,
          -11991.92,
          -11970.161,
          -11947.921999999999,
          -11925.202,
          -11902.001,
          -11878.319,
          -11854.155,
          -11829.51,
          -11804.383999999998,
          -11778.775,
          -11752.684,
          -11726.11,
          -11699.053999999998,
          -11671.514,
          -11643.491000000002,
          -11614.983999999999,
          -11585.992,
          -11556.515,
          -11526.555,
          -11496.108,
          -11465.175,
          -11433.756000000001,
          -11401.85,
          -11369.457,
          -11336.577,
          -11303.207,
          -11269.348999999998,
          -11235.002,
          -11200.163999999999,
          -11164.836000000001,
          -11129.016000000001,
          -11092.705,
          -11055.901000000002,
          -11018.604,
          -10980.813,
          -10942.528,
          -10903.747,
          -10864.47,
          -10824.697,
          -10784.425,
          -10743.656,
          -10702.386999999999,
          -10660.618,
          -10618.348999999998,
          -10575.577,
          -10532.303999999998,
          -10488.526000000002,
          -10444.244,
          -10399.457,
          -10354.163,
          -10308.362,
          -10262.053,
          -10215.234,
          -10167.905,
          -10120.064,
          -10071.711,
          -10022.844000000001,
          -9973.462,
          -9923.565,
          -9873.15,
          -9822.216999999999,
          -9770.764000000001,
          -9718.791,
          -9666.296,
          -9613.277,
          -9559.734,
          -9505.665,
          -9451.069,
          -9395.945,
          -9340.29,
          -9284.105,
          -9227.386,
          -9170.134,
          -9112.346,
          -9054.02,
          -8995.157,
          -8935.753,
          -8875.806999999999,
          -8815.319,
          -8754.285,
          -8692.706,
          -8630.578000000001,
          -8567.901,
          -8504.671999999999,
          -8440.89,
          -8376.554,
          -8311.661,
          -8246.21,
          -8180.1990000000005,
          -8113.626,
          -8046.49,
          -7978.789000000001,
          -7910.52,
          -7841.682,
          -7772.273,
          -7702.2919999999995,
          -7631.735,
          -7560.602,
          -7488.891,
          -7416.598000000001,
          -7343.723000000001,
          -7270.264,
          -7196.218000000001,
          -7121.5830000000005,
          -7046.358,
          -6970.54,
          -6894.128000000001,
          -6817.118,
          -6739.51,
          -6661.3009999999995,
          -6582.49,
          -6503.073,
          -6423.049,
          -6342.416,
          -6261.172,
          -6179.315,
          -6096.842,
          -6013.753000000001,
          -5930.044,
          -5845.714,
          -5760.76,
          -5675.182,
          -5588.977,
          -5502.143,
          -5414.678000000001,
          -5326.58,
          -5237.849,
          -5148.481,
          -5058.476,
          -4967.833,
          -4876.549,
          -4784.624,
          -4692.056,
          -4598.844,
          -4504.986,
          -4410.483,
          -4315.333,
          -4219.536,
          -4123.092000000001,
          -4025.9990000000003,
          -3928.261,
          -3829.8740000000003,
          -3730.8390000000004,
          -3631.158,
          -3530.8309999999997,
          -3429.861,
          -3328.248,
          -3225.9959999999996,
          -3123.1059999999998,
          -3019.5809999999997,
          -2915.426,
          -2810.643,
          -2705.238,
          -2599.215,
          -2492.581,
          -2385.343,
          -2277.508,
          -2169.084,
          -2060.0820000000003,
          -1950.511,
          -1840.3829999999998,
          -1729.711,
          -1618.51,
          -1506.795,
          -1394.585,
          -1281.899,
          -1168.758,
          -1055.187,
          -941.211,
          -826.8589999999999,
          -712.164,
          -597.16,
          -481.88599999999997,
          -366.384,
          -250.701,
          -134.89,
          -19.005,
          96.89,
          212.726,
          328.42900000000003,
          443.914,
          559.091,
          673.8589999999999,
          788.107,
          901.7139999999999,
          1014.544,
          1126.451,
          1237.2730000000001,
          1346.8310000000001,
          1454.931,
          1561.3570000000002,
          1665.875,
          1768.229,
          1868.139,
          1965.299,
          2059.38,
          2150.0229999999997,
          2236.843,
          2319.429,
          2397.341,
          2470.116,
          2537.27,
          2598.299,
          2652.691,
          2699.93,
          2739.506,
          2770.925,
          2793.7290000000003,
          2807.5,
          2811.881,
          2806.59,
          2791.428,
          2766.2940000000003,
          2731.188,
          2686.215,
          2631.585,
          2567.6020000000003,
          2494.658,
          2413.218,
          2323.804,
          2226.9829999999997,
          2123.347,
          2013.501,
          1898.046,
          1777.576,
          1652.66,
          1523.842,
          1391.632,
          1256.509,
          1118.912,
          979.245,
          837.878,
          695.1439999999999,
          551.345,
          406.75199999999995,
          261.60900000000004,
          116.132,
          -29.485,
          -175.071,
          -320.473,
          -465.55699999999996,
          -610.203,
          -754.308,
          -897.78,
          -1040.538,
          -1182.511,
          -1323.639,
          -1463.868,
          -1603.1529999999998,
          -1741.4520000000002,
          -1878.733,
          -2014.9660000000001,
          -2150.126,
          -2284.194,
          -2417.152,
          -2548.986,
          -2679.685,
          -2809.24,
          -2937.6459999999997,
          -3064.8959999999997,
          -3190.989,
          -3315.923,
          -3439.698,
          -3562.315,
          -3683.777,
          -3804.086,
          -3923.2470000000003,
          -4041.263,
          -4158.141,
          -4273.8859999999995,
          -4388.505,
          -4502.003,
          -4614.388,
          -4725.667,
          -4835.848,
          -4944.938,
          -5052.945,
          -5159.878,
          -5265.743,
          -5370.5509999999995,
          -5474.308000000001,
          -5577.023,
          -5678.704000000001,
          -5779.36,
          -5878.999,
          -5977.63,
          -6075.26,
          -6171.898,
          -6267.552,
          -6362.23,
          -6455.941,
          -6548.691999999999,
          -6640.491,
          -6731.345,
          -6821.264,
          -6910.254,
          -6998.323,
          -7085.479,
          -7171.728,
          -7257.079000000001,
          -7341.5380000000005,
          -7425.111999999999,
          -7507.809,
          -7589.6359999999995,
          -7670.599,
          -7750.705,
          -7829.960999999999,
          -7908.3730000000005,
          -7985.946999999999,
          -8062.69,
          -8138.609,
          -8213.709,
          -8287.997,
          -8361.478000000001,
          -8434.158000000001,
          -8506.043,
          -8577.139000000001,
          -8647.452,
          -8716.985999999999,
          -8785.748,
          -8853.742,
          -8920.974,
          -8987.449,
          -9053.173,
          -9118.15,
          -9182.385,
          -9245.882,
          -9308.648000000001,
          -9370.686,
          -9432.002,
          -9492.599,
          -9552.482,
          -9611.655999999999,
          -9670.124,
          -9727.892,
          -9784.963,
          -9841.341999999999,
          -9897.033000000001,
          -9952.039,
          -10006.364,
          -10060.013,
          -10112.99,
          -10165.296999999999,
          -10216.939,
          -10267.919,
          -10318.241,
          -10367.909,
          -10416.926,
          -10465.295,
          -10513.02,
          -10560.103000000001,
          -10606.548999999999,
          -10652.361,
          -10697.541000000001,
          -10742.093,
          -10786.018999999998,
          -10829.323999999999,
          -10872.008999999998,
          -10914.077,
          -10955.533000000001,
          -10996.377,
          -11036.614,
          -11076.245,
          -11115.274,
          -11153.703000000001,
          -11191.535,
          -11228.771999999999,
          -11265.417,
          -11301.472,
          -11336.94,
          -11371.823,
          -11406.124,
          -11439.844,
          -11472.987,
          -11505.553999999998,
          -11537.546999999999,
          -11568.969,
          -11599.822,
          -11630.108,
          -11659.83,
          -11688.988000000001,
          -11717.585,
          -11745.624,
          -11773.105,
          -11800.031,
          -11826.405,
          -11852.226,
          -11877.499,
          -11902.223,
          -11926.402,
          -11950.036,
          -11973.127,
          -11995.678,
          -12017.69,
          -12039.163,
          -12060.101,
          -12080.503999999999,
          -12100.374,
          -12119.713,
          -12138.521999999999,
          -12156.802,
          -12174.553999999998,
          -12191.781,
          -12208.483999999999,
          -12224.663999999999,
          -12240.322,
          -12255.458999999999,
          -12270.077,
          -12284.178,
          -12297.761,
          -12310.829,
          -12323.383,
          -12335.423999999999,
          -12346.952,
          -12357.97,
          -12368.478000000001,
          -12378.476999999999,
          -12387.968,
          -12396.953000000001,
          -12405.431999999999,
          -12413.406,
          -12420.876,
          -12427.843,
          -12434.309,
          -12440.273000000001,
          -12445.738000000001,
          -12450.703000000001,
          -12455.169,
          -12459.138,
          -12462.61,
          -12465.586000000001,
          -12468.066,
          -12470.052,
          -12471.544,
          -12472.543,
          -12473.048999999999,
          -12473.063,
          -12472.586000000001,
          -12471.618999999999,
          -12470.161,
          -12468.214,
          -12465.778,
          -12462.854,
          -12459.442,
          -12455.543,
          -12451.157,
          -12446.284,
          -12440.926000000001,
          -12435.082,
          -12428.753,
          -12421.94,
          -12414.642,
          -12406.861,
          -12398.596000000001,
          -12389.848,
          -12380.617,
          -12370.903,
          -12360.707,
          -12350.028999999999,
          -12338.87,
          -12327.229,
          -12315.106000000002,
          -12302.503,
          -12289.418,
          -12275.853000000001,
          -12261.806999999999,
          -12247.281,
          -12232.274,
          -12216.787,
          -12200.82,
          -12184.372,
          -12167.445,
          -12150.037,
          -12132.15,
          -12113.782,
          -12094.934,
          -12075.607,
          -12055.798999999999,
          -12035.511,
          -12014.742,
          -11993.493,
          -11971.764,
          -11949.553999999998,
          -11926.863000000001,
          -11903.691,
          -11880.038,
          -11855.903,
          -11831.287,
          -11806.19,
          -11780.61,
          -11754.548,
          -11728.003,
          -11700.975,
          -11673.464,
          -11645.469,
          -11616.991000000002,
          -11588.028,
          -11558.58,
          -11528.646999999999,
          -11498.229,
          -11467.325,
          -11435.935,
          -11404.056999999999,
          -11371.692,
          -11338.84,
          -11305.499,
          -11271.669,
          -11237.348999999998,
          -11202.538999999999,
          -11167.239,
          -11131.448,
          -11095.163999999999,
          -11058.388,
          -11021.118999999999,
          -10983.356000000002,
          -10945.098,
          -10906.345,
          -10867.095,
          -10827.348999999998,
          -10787.105,
          -10746.363000000001,
          -10705.122,
          -10663.381000000001,
          -10621.138,
          -10578.393999999998,
          -10535.148000000001,
          -10491.396999999999,
          -10447.142,
          -10402.382,
          -10357.115,
          -10311.341,
          -10265.059000000001,
          -10218.267,
          -10170.965,
          -10123.151,
          -10074.824,
          -10025.984,
          -9976.629,
          -9926.758,
          -9876.37,
          -9825.463,
          -9774.037,
          -9722.09,
          -9669.621,
          -9616.629,
          -9563.113000000001,
          -9509.07,
          -9454.5,
          -9399.402,
          -9343.773000000001,
          -9287.614,
          -9230.921,
          -9173.695,
          -9115.931999999999,
          -9057.633,
          -8998.795,
          -8939.417,
          -8879.497,
          -8819.034,
          -8758.027,
          -8696.472,
          -8634.37,
          -8571.718,
          -8508.515,
          -8444.758,
          -8380.447,
          -8315.58,
          -8250.154,
          -8184.168000000001,
          -8117.62,
          -8050.509,
          -7982.8330000000005,
          -7914.589,
          -7845.776,
          -7776.392,
          -7706.435,
          -7635.903,
          -7564.794,
          -7493.107,
          -7420.839,
          -7347.9890000000005,
          -7274.554,
          -7200.531999999999,
          -7125.920999999999,
          -7050.72,
          -6974.9259999999995,
          -6898.5380000000005,
          -6821.552,
          -6743.968000000001,
          -6665.783,
          -6586.995,
          -6507.601,
          -6427.601,
          -6346.991,
          -6265.77,
          -6183.936,
          -6101.486999999999,
          -6018.42,
          -5934.734,
          -5850.427,
          -5765.496,
          -5679.94,
          -5593.757,
          -5506.945,
          -5419.503000000001,
          -5331.427,
          -5242.718,
          -5153.373,
          -5063.39,
          -4972.768,
          -4881.505,
          -4789.601,
          -4697.053,
          -4603.862,
          -4510.025,
          -4415.542,
          -4320.413,
          -4224.635,
          -4128.210999999999,
          -4031.138,
          -3933.4159999999997,
          -3835.048,
          -3736.031,
          -3636.369,
          -3536.06,
          -3435.107,
          -3333.512,
          -3231.277,
          -3128.403,
          -3024.8940000000002,
          -2920.7540000000004,
          -2815.987,
          -2710.5959999999995,
          -2604.5879999999997,
          -2497.968,
          -2390.742,
          -2282.919,
          -2174.507,
          -2065.515,
          -1955.954,
          -1845.835,
          -1735.172,
          -1623.9779999999998,
          -1512.27,
          -1400.065,
          -1287.383,
          -1174.245,
          -1060.675,
          -946.699,
          -832.345,
          -717.6460000000001,
          -602.637,
          -487.355,
          -371.844,
          -256.149,
          -140.32299999999998,
          -24.421,
          91.495,
          207.355,
          323.085,
          438.602,
          553.815,
          668.623,
          782.916,
          896.574,
          1009.461,
          1121.432,
          1232.325,
          1341.9620000000002,
          1450.149,
          1556.672,
          1661.2979999999998,
          1763.77,
          1863.8110000000001,
          1961.115,
          2055.353,
          2146.17,
          2233.18,
          2315.973,
          2394.111,
          2467.132,
          2534.551,
          2595.868,
          2650.5690000000004,
          2698.138,
          2738.0640000000003,
          2769.855,
          2793.0490000000004,
          2807.2259999999997,
          2812.0290000000005,
          2807.17,
          2792.448,
          2767.756,
          2733.093,
          2688.558,
          2634.355,
          2570.7870000000003,
          2498.242,
          2417.18,
          2328.124,
          2231.637,
          2128.311,
          2018.75,
          1903.556,
          1783.3210000000001,
          1658.618,
          1529.99,
          1397.95,
          1262.976,
          1125.51,
          985.957,
          844.687,
          702.0369999999999,
          558.309,
          413.775,
          268.67900000000003,
          123.24,
          -22.346999999999998,
          -167.912,
          -313.29900000000004,
          -458.375,
          -603.02,
          -747.128,
          -890.6080000000001,
          -1033.378,
          -1175.368,
          -1316.515,
          -1456.766,
          -1596.076,
          -1734.4029999999998,
          -1871.713,
          -2007.9779999999998,
          -2143.173,
          -2277.276,
          -2410.27,
          -2542.1420000000003,
          -2672.88,
          -2802.475,
          -2930.921,
          -3058.2140000000004,
          -3184.349,
          -3309.3259999999996,
          -3433.145,
          -3555.8059999999996,
          -3677.312,
          -3797.6659999999997,
          -3916.8720000000003,
          -4034.934,
          -4151.858,
          -4267.649,
          -4382.314,
          -4495.858,
          -4608.29,
          -4719.615,
          -4829.843,
          -4938.979,
          -5047.032999999999,
          -5154.012,
          -5259.925,
          -5364.778,
          -5468.581999999999,
          -5571.344,
          -5673.071,
          -5773.774,
          -5873.46,
          -5972.1359999999995,
          -6069.813,
          -6166.496999999999,
          -6262.196999999999,
          -6356.920999999999,
          -6450.677,
          -6543.473000000001,
          -6635.318,
          -6726.218000000001,
          -6816.182,
          -6905.217,
          -6993.331,
          -7080.531999999999,
          -7166.826,
          -7252.221,
          -7336.725,
          -7420.344,
          -7503.085,
          -7584.956,
          -7665.963000000001,
          -7746.111999999999,
          -7825.411999999999,
          -7903.866999999999,
          -7981.485,
          -8058.272,
          -8134.234,
          -8209.377,
          -8283.707,
          -8357.231,
          -8429.954,
          -8501.882,
          -8573.02,
          -8643.375,
          -8712.951,
          -8781.755,
          -8849.791,
          -8917.065,
          -8983.582,
          -9049.346,
          -9114.365,
          -9178.641,
          -9242.18,
          -9304.985999999999,
          -9367.065,
          -9428.421,
          -9489.059000000001,
          -9548.983,
          -9608.197,
          -9666.706,
          -9724.514000000001,
          -9781.625,
          -9838.044,
          -9893.774,
          -9948.819,
          -10003.185,
          -10056.873,
          -10109.889000000001,
          -10162.235,
          -10213.916,
          -10264.936,
          -10315.296999999999,
          -10365.003,
          -10414.059000000001,
          -10462.466,
          -10510.23,
          -10557.351999999999,
          -10603.836000000001,
          -10649.686000000002,
          -10694.903999999999,
          -10739.493999999999,
          -10783.458,
          -10826.8,
          -10869.523000000001,
          -10911.628999999999,
          -10953.122,
          -10994.003999999999,
          -11034.278,
          -11073.946000000002,
          -11113.011999999999,
          -11151.479,
          -11189.347,
          -11226.621000000001,
          -11263.303,
          -11299.395,
          -11334.899,
          -11369.819,
          -11404.156,
          -11437.913,
          -11471.091999999999,
          -11503.695,
          -11535.723999999998,
          -11567.181999999999,
          -11598.071000000002,
          -11628.393,
          -11658.15,
          -11687.344,
          -11715.976999999999,
          -11744.051000000001,
          -11771.568000000001,
          -11798.53,
          -11824.938,
          -11850.795,
          -11876.101999999999,
          -11900.862,
          -11925.075,
          -11948.745,
          -11971.871000000001,
          -11994.457,
          -12016.503,
          -12038.011,
          -12058.983,
          -12079.421,
          -12099.325,
          -12118.698,
          -12137.541000000001,
          -12155.855,
          -12173.642,
          -12190.903,
          -12207.64,
          -12223.854,
          -12239.545,
          -12254.716,
          -12269.368,
          -12283.502,
          -12297.12,
          -12310.221000000001,
          -12322.808,
          -12334.882,
          -12346.444,
          -12357.495,
          -12368.036,
          -12378.068000000001,
          -12387.593,
          -12396.61,
          -12405.122,
          -12413.128999999999,
          -12420.632,
          -12427.632,
          -12434.131000000001,
          -12440.128,
          -12445.625,
          -12450.622,
          -12455.121000000001,
          -12459.122,
          -12462.626,
          -12465.635,
          -12468.146999999999,
          -12470.165,
          -12471.688999999998,
          -12472.72,
          -12473.258,
          -12473.303999999998,
          -12472.858999999999,
          -12471.923999999999,
          -12470.498,
          -12468.582,
          -12466.178,
          -12463.285,
          -12459.905,
          -12456.037,
          -12451.681999999999,
          -12446.841,
          -12441.514,
          -12435.702,
          -12429.403999999999,
          -12422.622,
          -12415.355,
          -12407.605,
          -12399.371000000001,
          -12390.653,
          -12381.453000000001,
          -12371.771,
          -12361.606000000002,
          -12350.958,
          -12339.83,
          -12328.219,
          -12316.127,
          -12303.553999999998,
          -12290.5,
          -12276.965,
          -12262.95,
          -12248.454,
          -12233.476999999999,
          -12218.02,
          -12202.083,
          -12185.666000000001,
          -12168.768999999998,
          -12151.391000000001,
          -12133.533000000001,
          -12115.196000000002,
          -12096.378,
          -12077.08,
          -12057.302,
          -12037.043,
          -12016.305,
          -11995.085,
          -11973.385,
          -11951.205,
          -11928.544,
          -11905.401000000002,
          -11881.777,
          -11857.671999999999,
          -11833.086000000001,
          -11808.017,
          -11782.466,
          -11756.433,
          -11729.917,
          -11702.919,
          -11675.437,
          -11647.471000000001,
          -11619.021,
          -11590.087,
          -11560.669,
          -11530.765,
          -11500.375,
          -11469.5,
          -11438.138,
          -11406.288999999999,
          -11373.953000000001,
          -11341.128999999999,
          -11307.816,
          -11274.014,
          -11239.723,
          -11204.942,
          -11169.67,
          -11133.907,
          -11097.651000000002,
          -11060.903,
          -11023.662,
          -10985.927,
          -10947.697,
          -10908.972,
          -10869.751,
          -10830.032,
          -10789.816,
          -10749.101999999999,
          -10707.889,
          -10666.175,
          -10623.96,
          -10581.243999999999,
          -10538.025,
          -10494.302,
          -10450.074,
          -10405.341999999999,
          -10360.101999999999,
          -10314.356,
          -10268.1,
          -10221.336,
          -10174.061,
          -10126.274,
          -10077.975,
          -10029.161,
          -9979.833,
          -9929.989,
          -9879.628,
          -9828.748,
          -9777.349,
          -9725.429,
          -9672.987,
          -9620.021,
          -9566.530999999999,
          -9512.515,
          -9457.972,
          -9402.9,
          -9347.298,
          -9291.165,
          -9234.499,
          -9177.299,
          -9119.563,
          -9061.29,
          -9002.478000000001,
          -8943.126,
          -8883.232,
          -8822.795,
          -8761.814,
          -8700.285,
          -8638.209,
          -8575.583,
          -8512.405,
          -8448.675,
          -8384.389000000001,
          -8319.546999999999,
          -8254.146999999999,
          -8188.187,
          -8121.665,
          -8054.579000000001,
          -7986.928000000001,
          -7918.709,
          -7849.920999999999,
          -7780.563,
          -7710.630999999999,
          -7640.124,
          -7569.041,
          -7497.378000000001,
          -7425.135,
          -7352.31,
          -7278.899,
          -7204.901999999999,
          -7130.316,
          -7055.14,
          -6979.37,
          -6903.005999999999,
          -6826.045,
          -6748.485,
          -6670.3240000000005,
          -6591.56,
          -6512.19,
          -6432.214,
          -6351.628000000001,
          -6270.431,
          -6188.621,
          -6106.195,
          -6023.151,
          -5939.4890000000005,
          -5855.205,
          -5770.297,
          -5684.764,
          -5598.604,
          -5511.815,
          -5424.395,
          -5336.342,
          -5247.655,
          -5158.332,
          -5068.371,
          -4977.771,
          -4886.531,
          -4794.648,
          -4702.122,
          -4608.952,
          -4515.1359999999995,
          -4420.674,
          -4325.565,
          -4229.809,
          -4133.404,
          -4036.3509999999997,
          -3938.65,
          -3840.3,
          -3741.303,
          -3641.659,
          -3541.369,
          -3440.435,
          -3338.8579999999997,
          -3236.639,
          -3133.783,
          -3030.2909999999997,
          -2926.167,
          -2821.415,
          -2716.04,
          -2610.0460000000003,
          -2503.44,
          -2396.229,
          -2288.419,
          -2180.019,
          -2071.0389999999998,
          -1961.4879999999998,
          -1851.379,
          -1740.725,
          -1629.539,
          -1517.838,
          -1405.638,
          -1292.961,
          -1179.826,
          -1066.258,
          -952.2819999999999,
          -837.927,
          -723.225,
          -608.211,
          -492.92199999999997,
          -377.402,
          -261.69599999999997,
          -145.855,
          -29.936,
          86,
          201.88299999999998,
          317.64099999999996,
          433.189,
          548.437,
          663.2860000000001,
          777.625,
          891.3330000000001,
          1004.278,
          1116.313,
          1227.278,
          1336.994,
          1445.27,
          1551.891,
          1656.625,
          1759.2179999999998,
          1859.39,
          1956.84,
          2051.239,
          2142.232,
          2229.435,
          2312.439,
          2390.8070000000002,
          2464.078,
          2531.769,
          2593.3779999999997,
          2648.393,
          2696.2990000000004,
          2736.5840000000003,
          2768.7540000000004,
          2792.3459999999995,
          2806.94,
          2812.1740000000004,
          2807.757,
          2793.485,
          2769.248,
          2735.038,
          2690.9509999999996,
          2637.188,
          2574.0460000000003,
          2501.91,
          2421.238,
          2332.55,
          2236.407,
          2133.399,
          2024.131,
          1909.205,
          1789.214,
          1664.729,
          1536.297,
          1404.431,
          1269.611,
          1132.279,
          992.8430000000001,
          851.675,
          709.1110000000001,
          565.455,
          420.981,
          275.935,
          130.535,
          -15.022,
          -160.565,
          -305.938,
          -451.006,
          -595.649,
          -739.7610000000001,
          -883.2489999999999,
          -1026.032,
          -1168.038,
          -1309.2060000000001,
          -1449.9389999999999,
          -1588.816,
          -1727.172,
          -1864.513,
          -2000.8110000000001,
          -2136.04,
          -2270.18,
          -2403.212,
          -2535.123,
          -2665.902,
          -2795.538,
          -2924.027,
          -3051.362,
          -3177.5409999999997,
          -3302.563,
          -3426.426,
          -3549.133,
          -3670.6859999999997,
          -3791.086,
          -3910.3390000000004,
          -4028.448,
          -4145.419,
          -4261.2570000000005,
          -4375.969,
          -4489.562,
          -4602.041,
          -4713.414000000001,
          -4823.69,
          -4932.874,
          -5040.976,
          -5148.003,
          -5253.964,
          -5358.865,
          -5462.717,
          -5565.526,
          -5667.302,
          -5768.052,
          -5867.785,
          -5966.51,
          -6064.233,
          -6160.965,
          -6256.7119999999995,
          -6351.483,
          -6445.286999999999,
          -6538.13,
          -6630.021,
          -6720.968000000001,
          -6810.978,
          -6900.06,
          -6988.22,
          -7075.467,
          -7161.807,
          -7247.2480000000005,
          -7331.797,
          -7415.4619999999995,
          -7498.2480000000005,
          -7580.164000000001,
          -7661.215999999999,
          -7741.411,
          -7820.755,
          -7899.255,
          -7976.918000000001,
          -8053.749,
          -8129.755,
          -8204.942,
          -8279.317,
          -8352.884,
          -8425.651,
          -8497.622,
          -8568.804,
          -8639.202,
          -8708.821,
          -8777.668,
          -8845.747,
          -8913.063,
          -8979.623,
          -9045.43,
          -9110.491,
          -9174.809000000001,
          -9238.39,
          -9301.239,
          -9363.359,
          -9424.757,
          -9485.436,
          -9545.401,
          -9604.657,
          -9663.207,
          -9721.056,
          -9778.208,
          -9834.667,
          -9890.438,
          -9945.524,
          -9999.93,
          -10053.659,
          -10106.715,
          -10159.101,
          -10210.822,
          -10261.881,
          -10312.282,
          -10362.029,
          -10411.123,
          -10459.57,
          -10507.373,
          -10554.534,
          -10601.058,
          -10646.946000000002,
          -10692.203000000001,
          -10736.832,
          -10780.835,
          -10824.216,
          -10866.976999999999,
          -10909.121000000001,
          -10950.652,
          -10991.572,
          -11031.883999999998,
          -11071.591,
          -11110.695,
          -11149.198999999999,
          -11187.105,
          -11224.417,
          -11261.136,
          -11297.265,
          -11332.806999999999,
          -11367.764,
          -11402.138,
          -11435.931999999999,
          -11469.146999999999,
          -11501.787,
          -11533.854,
          -11565.348,
          -11596.274,
          -11626.632,
          -11656.426000000001,
          -11685.656,
          -11714.325,
          -11742.435,
          -11769.988000000001,
          -11796.986,
          -11823.43,
          -11849.323,
          -11874.666000000001,
          -11899.461000000001,
          -11923.71,
          -11947.415,
          -11970.577,
          -11993.198,
          -12015.278999999999,
          -12036.823,
          -12057.83,
          -12078.303,
          -12098.242,
          -12117.65,
          -12136.527,
          -12154.876,
          -12172.698,
          -12189.993999999999,
          -12206.765,
          -12223.013,
          -12238.739,
          -12253.944,
          -12268.63,
          -12282.798999999999,
          -12296.45,
          -12309.585,
          -12322.207,
          -12334.315,
          -12345.91,
          -12356.995,
          -12367.57,
          -12377.635,
          -12387.193000000001,
          -12396.243999999999,
          -12404.788999999999,
          -12412.83,
          -12420.366000000002,
          -12427.4,
          -12433.931,
          -12439.961000000001,
          -12445.491000000002,
          -12450.521,
          -12455.053,
          -12459.087,
          -12462.624,
          -12465.665,
          -12468.21,
          -12470.261,
          -12471.817,
          -12472.881000000001,
          -12473.451000000001,
          -12473.53,
          -12473.117,
          -12472.213,
          -12470.82,
          -12468.936000000002,
          -12466.563999999998,
          -12463.703000000001,
          -12460.355,
          -12456.518999999998,
          -12452.196000000002,
          -12447.386,
          -12442.091,
          -12436.31,
          -12430.044,
          -12423.293,
          -12416.058,
          -12408.339,
          -12400.136999999999,
          -12391.451000000001,
          -12382.282,
          -12372.63,
          -12362.496000000001,
          -12351.88,
          -12340.782,
          -12329.203000000001,
          -12317.142,
          -12304.6,
          -12291.576000000001,
          -12278.072,
          -12264.087,
          -12249.622,
          -12234.676000000001,
          -12219.25,
          -12203.343,
          -12186.956,
          -12170.089,
          -12152.742,
          -12134.915,
          -12116.607,
          -12097.82,
          -12078.552,
          -12058.803999999998,
          -12038.575,
          -12017.866000000002,
          -11996.677,
          -11975.007,
          -11952.856000000002,
          -11930.225,
          -11907.112,
          -11883.518,
          -11859.442,
          -11834.885,
          -11809.846000000001,
          -11784.325,
          -11758.321000000002,
          -11731.835,
          -11704.865,
          -11677.413,
          -11649.476,
          -11621.056,
          -11592.151000000002,
          -11562.761,
          -11532.886,
          -11502.526000000002,
          -11471.678999999998,
          -11440.346000000001,
          -11408.526000000002,
          -11376.219,
          -11343.423,
          -11310.139,
          -11276.366000000002,
          -11242.104,
          -11207.351,
          -11172.107,
          -11136.372,
          -11100.145,
          -11063.426000000001,
          -11026.213,
          -10988.506000000001,
          -10950.303999999998,
          -10911.607,
          -10872.413999999999,
          -10832.723999999998,
          -10792.536,
          -10751.85,
          -10710.663999999999,
          -10668.978000000001,
          -10626.791000000001,
          -10584.103000000001,
          -10540.911,
          -10497.216,
          -10453.017,
          -10408.311,
          -10363.1,
          -10317.38,
          -10271.153,
          -10224.415,
          -10177.168,
          -10129.408000000001,
          -10081.136,
          -10032.35,
          -9983.049,
          -9933.232,
          -9882.898000000001,
          -9832.046,
          -9780.673,
          -9728.78,
          -9676.365,
          -9623.426,
          -9569.963,
          -9515.974,
          -9461.457,
          -9406.412,
          -9350.837,
          -9294.73,
          -9238.09,
          -9180.917,
          -9123.207,
          -9064.96,
          -9006.175,
          -8946.849,
          -8886.982,
          -8826.571,
          -8765.615,
          -8704.113000000001,
          -8642.063,
          -8579.463,
          -8516.311,
          -8452.606,
          -8388.346,
          -8323.53,
          -8258.155999999999,
          -8192.221,
          -8125.724,
          -8058.664000000001,
          -7991.0380000000005,
          -7922.845,
          -7854.0830000000005,
          -7784.749,
          -7714.842,
          -7644.361,
          -7573.302,
          -7501.665,
          -7429.446999999999,
          -7356.646,
          -7283.2609999999995,
          -7209.2880000000005,
          -7134.727,
          -7059.575,
          -6983.83,
          -6907.491,
          -6830.554,
          -6753.018,
          -6674.880999999999,
          -6596.141,
          -6516.795999999999,
          -6436.843000000001,
          -6356.281999999999,
          -6275.108,
          -6193.321,
          -6110.919,
          -6027.899,
          -5944.26,
          -5859.999,
          -5775.115,
          -5689.605,
          -5603.468000000001,
          -5516.701999999999,
          -5429.304,
          -5341.274,
          -5252.61,
          -5163.309,
          -5073.37,
          -4982.792,
          -4891.573,
          -4799.712,
          -4707.208,
          -4614.059,
          -4520.264,
          -4425.823,
          -4330.735,
          -4234.998,
          -4138.6140000000005,
          -4041.5809999999997,
          -3943.8990000000003,
          -3845.5690000000004,
          -3746.591,
          -3646.966,
          -3546.695,
          -3445.7790000000005,
          -3344.219,
          -3242.018,
          -3139.179,
          -3035.704,
          -2931.5959999999995,
          -2826.86,
          -2721.5,
          -2615.521,
          -2508.929,
          -2401.731,
          -2293.9339999999997,
          -2185.5460000000003,
          -2076.577,
          -1967.037,
          -1856.9379999999999,
          -1746.2920000000001,
          -1635.114,
          -1523.42,
          -1411.227,
          -1298.5539999999999,
          -1185.422,
          -1071.856,
          -957.88,
          -843.5239999999999,
          -728.819,
          -613.8,
          -498.504,
          -382.974,
          -267.256,
          -151.401,
          -35.465,
          80.491,
          196.396,
          312.181,
          427.76,
          543.044,
          657.933,
          772.318,
          886.077,
          999.08,
          1111.1789999999999,
          1222.214,
          1332.011,
          1440.375,
          1547.094,
          1651.9370000000001,
          1754.649,
          1854.954,
          1952.549,
          2047.109,
          2138.278,
          2225.674,
          2308.888,
          2387.486,
          2461.007,
          2528.968,
          2590.87,
          2646.2,
          2694.442,
          2735.085,
          2767.635,
          2791.6259999999997,
          2806.636,
          2812.3,
          2808.3259999999996,
          2794.505,
          2770.723,
          2736.968,
          2693.3309999999997,
          2640.009,
          2577.294,
          2505.569,
          2425.288,
          2336.969,
          2241.172,
          2138.484,
          2029.511,
          1914.855,
          1795.108,
          1670.844,
          1542.609,
          1410.918,
          1276.253,
          1139.057,
          999.7389999999999,
          858.672,
          716.195,
          572.612,
          428.199,
          283.203,
          137.843,
          -7.684,
          -153.204,
          -298.563,
          -443.62300000000005,
          -588.264,
          -732.3789999999999,
          -875.8760000000001,
          -1018.671,
          -1160.694,
          -1301.881,
          -1442.18,
          -1581.5410000000002,
          -1719.9260000000002,
          -1857.2979999999998,
          -1993.629,
          -2128.893,
          -2263.069,
          -2396.139,
          -2528.089,
          -2658.908,
          -2788.586,
          -2917.117,
          -3044.495,
          -3170.718,
          -3295.785,
          -3419.6929999999998,
          -3542.446,
          -3664.0440000000003,
          -3784.491,
          -3903.79,
          -4021.947,
          -4138.965,
          -4254.851,
          -4369.611,
          -4483.251,
          -4595.778,
          -4707.1990000000005,
          -4817.523,
          -4926.755,
          -5034.905,
          -5141.981,
          -5247.9890000000005,
          -5352.939,
          -5456.838000000001,
          -5559.696,
          -5661.519,
          -5762.316999999999,
          -5862.098000000001,
          -5960.87,
          -6058.642,
          -6155.42,
          -6251.215,
          -6346.033,
          -6439.884,
          -6532.774,
          -6624.7119999999995,
          -6715.706,
          -6805.764,
          -6894.892,
          -6983.098000000001,
          -7070.391,
          -7156.776999999999,
          -7242.264,
          -7326.859,
          -7410.569,
          -7493.401,
          -7575.363,
          -7656.46,
          -7736.7,
          -7816.089,
          -7894.634,
          -7972.340999999999,
          -8049.215999999999,
          -8125.267,
          -8200.498,
          -8274.917,
          -8348.528,
          -8421.338,
          -8493.353000000001,
          -8564.578000000001,
          -8635.02,
          -8704.681999999999,
          -8773.572,
          -8841.694,
          -8909.053,
          -8975.655,
          -9041.505,
          -9106.608,
          -9170.968,
          -9234.591999999999,
          -9297.482,
          -9359.645,
          -9421.084,
          -9481.805,
          -9541.811,
          -9601.108,
          -9659.699,
          -9717.589,
          -9774.783000000001,
          -9831.283000000001,
          -9887.094000000001,
          -9942.221,
          -9996.667,
          -10050.436,
          -10103.532,
          -10155.959,
          -10207.72,
          -10258.819,
          -10309.26,
          -10359.046,
          -10408.18,
          -10456.667,
          -10504.508999999998,
          -10551.708999999999,
          -10598.271999999999,
          -10644.198999999999,
          -10689.495,
          -10734.163,
          -10778.204,
          -10821.624,
          -10864.423,
          -10906.606000000002,
          -10948.176000000001,
          -10989.133999999998,
          -11029.483999999999,
          -11069.228000000001,
          -11108.37,
          -11146.912,
          -11184.856000000002,
          -11222.205,
          -11258.962,
          -11295.128999999999,
          -11330.708,
          -11365.702,
          -11400.113000000001,
          -11433.944,
          -11467.196000000002,
          -11499.873,
          -11531.976,
          -11563.508,
          -11594.47,
          -11624.865,
          -11654.695,
          -11683.962,
          -11712.668,
          -11740.813999999998,
          -11768.403,
          -11795.437,
          -11821.917,
          -11847.845,
          -11873.223999999998,
          -11898.055,
          -11922.34,
          -11946.08,
          -11969.277,
          -11991.933,
          -12014.05,
          -12035.628999999999,
          -12056.671,
          -12077.178999999998,
          -12097.153,
          -12116.596000000001,
          -12135.508999999998,
          -12153.892,
          -12171.749,
          -12189.079,
          -12205.885,
          -12222.167,
          -12237.927,
          -12253.167,
          -12267.888,
          -12282.09,
          -12295.775,
          -12308.945,
          -12321.6,
          -12333.742,
          -12345.371000000001,
          -12356.49,
          -12367.098,
          -12377.197,
          -12386.788999999999,
          -12395.873,
          -12404.452,
          -12412.525,
          -12420.095,
          -12427.162,
          -12433.726,
          -12439.79,
          -12445.351999999999,
          -12450.416000000001,
          -12454.981000000002,
          -12459.046999999999,
          -12462.617,
          -12465.691,
          -12468.268999999998,
          -12470.351999999999,
          -12471.941,
          -12473.036,
          -12473.639,
          -12473.75,
          -12473.37,
          -12472.498,
          -12471.136999999999,
          -12469.286,
          -12466.945,
          -12464.117,
          -12460.8,
          -12456.996000000001,
          -12452.705,
          -12447.927,
          -12442.663,
          -12436.913999999999,
          -12430.678999999998,
          -12423.96,
          -12416.757,
          -12409.069,
          -12400.898000000001,
          -12392.243,
          -12383.105,
          -12373.485,
          -12363.382,
          -12352.796999999999,
          -12341.73,
          -12330.181,
          -12318.151000000002,
          -12305.64,
          -12292.648000000001,
          -12279.173999999999,
          -12265.22,
          -12250.785,
          -12235.87,
          -12220.473999999998,
          -12204.598,
          -12188.241000000002,
          -12171.405,
          -12154.088,
          -12136.291000000001,
          -12118.013,
          -12099.256000000001,
          -12080.018,
          -12060.3,
          -12040.101999999999,
          -12019.423,
          -11998.263,
          -11976.623,
          -11954.502,
          -11931.9,
          -11908.817,
          -11885.253,
          -11861.207,
          -11836.678999999998,
          -11811.67,
          -11786.178,
          -11760.204,
          -11733.746000000001,
          -11706.806,
          -11679.383,
          -11651.475,
          -11623.083999999999,
          -11594.208999999999,
          -11564.848,
          -11535.003,
          -11504.671,
          -11473.853000000001,
          -11442.548999999999,
          -11410.758,
          -11378.479,
          -11345.713,
          -11312.457,
          -11278.713,
          -11244.479,
          -11209.755,
          -11174.54,
          -11138.833,
          -11102.633999999998,
          -11065.943000000001,
          -11028.758999999998,
          -10991.08,
          -10952.906,
          -10914.237,
          -10875.072,
          -10835.41,
          -10795.25,
          -10754.591999999999,
          -10713.434,
          -10671.776000000002,
          -10629.617,
          -10586.956,
          -10543.792,
          -10500.125,
          -10455.953000000001,
          -10411.275,
          -10366.091,
          -10320.399,
          -10274.199,
          -10227.489,
          -10180.269,
          -10132.536,
          -10084.292,
          -10035.533000000001,
          -9986.259,
          -9936.469000000001,
          -9886.162,
          -9835.336,
          -9783.991,
          -9732.125,
          -9679.735999999999,
          -9626.825,
          -9573.388,
          -9519.425,
          -9464.936,
          -9409.917,
          -9354.368,
          -9298.288,
          -9241.675,
          -9184.528,
          -9126.844000000001,
          -9068.624,
          -9009.865,
          -8950.565,
          -8890.724,
          -8830.339,
          -8769.41,
          -8707.933,
          -8645.909,
          -8583.335,
          -8520.209,
          -8456.53,
          -8392.296,
          -8327.505,
          -8262.155999999999,
          -8196.247,
          -8129.776,
          -8062.741,
          -7995.141,
          -7926.973000000001,
          -7858.236,
          -7788.927,
          -7719.045999999999,
          -7648.59,
          -7577.556,
          -7505.944,
          -7433.751,
          -7360.975,
          -7287.6140000000005,
          -7213.666,
          -7139.13,
          -7064.0019999999995,
          -6988.281999999999,
          -6911.965999999999,
          -6835.054,
          -6757.5419999999995,
          -6679.43,
          -6600.714,
          -6521.393,
          -6441.464,
          -6360.9259999999995,
          -6279.776,
          -6198.013000000001,
          -6115.635,
          -6032.638000000001,
          -5949.022,
          -5864.785,
          -5779.923000000001,
          -5694.437,
          -5608.321999999999,
          -5521.579000000001,
          -5434.204000000001,
          -5346.196999999999,
          -5257.554,
          -5168.276,
          -5078.36,
          -4987.804,
          -4896.607,
          -4804.767,
          -4712.284000000001,
          -4619.157,
          -4525.383,
          -4430.963,
          -4335.895,
          -4240.179,
          -4143.815,
          -4046.802,
          -3949.14,
          -3850.83,
          -3751.8709999999996,
          -3652.265,
          -3552.012,
          -3451.114,
          -3349.572,
          -3247.389,
          -3144.567,
          -3041.1079999999997,
          -2937.0170000000003,
          -2832.296,
          -2726.9509999999996,
          -2620.987,
          -2514.41,
          -2407.225,
          -2299.4410000000003,
          -2191.065,
          -2082.1079999999997,
          -1972.579,
          -1862.489,
          -1751.8529999999998,
          -1640.683,
          -1528.995,
          -1416.808,
          -1304.139,
          -1191.011,
          -1077.447,
          -963.472,
          -849.1139999999999,
          -734.4069999999999,
          -619.382,
          -504.08,
          -388.541,
          -272.812,
          -156.94299999999998,
          -40.99,
          74.986,
          190.917,
          306.728,
          422.339,
          537.658,
          652.587,
          767.0169999999999,
          880.827,
          993.8860000000001,
          1106.049,
          1217.156,
          1327.031,
          1435.483,
          1542.3,
          1647.25,
          1750.082,
          1850.5179999999998,
          1948.259,
          2042.9779999999998,
          2134.323,
          2221.911,
          2305.335,
          2384.1620000000003,
          2457.9320000000002,
          2526.1639999999998,
          2588.357,
          2644.0009999999997,
          2692.58,
          2733.5809999999997,
          2766.511,
          2790.901,
          2806.327,
          2812.423,
          2808.893,
          2795.525,
          2772.199,
          2738.901,
          2695.716,
          2642.836,
          2580.552,
          2509.24,
          2429.353,
          2341.406,
          2245.9570000000003,
          2143.593,
          2034.918,
          1920.533,
          1801.0339999999999,
          1676.993,
          1548.957,
          1417.444,
          1282.935,
          1145.877,
          1006.678,
          865.715,
          723.326,
          579.818,
          435.467,
          290.52099999999996,
          145.202,
          -0.294,
          -145.792,
          -291.135,
          -436.186,
          -580.825,
          -724.943,
          -868.448,
          -1011.2560000000001,
          -1153.295,
          -1294.502,
          -1434.8239999999998,
          -1574.211,
          -1712.624,
          -1850.0279999999998,
          -1986.392,
          -2121.6910000000003,
          -2255.903,
          -2389.011,
          -2521.001,
          -2651.861,
          -2781.58,
          -2910.1540000000005,
          -3037.5759999999996,
          -3163.843,
          -3288.954,
          -3412.908,
          -3535.7070000000003,
          -3657.3509999999997,
          -3777.845,
          -3897.192,
          -4015.395,
          -4132.460999999999,
          -4248.395,
          -4363.2029999999995,
          -4476.891,
          -4589.465999999999,
          -4700.936,
          -4811.308,
          -4920.589,
          -5028.788,
          -5135.911,
          -5241.968,
          -5346.967,
          -5450.914000000001,
          -5553.82,
          -5655.691999999999,
          -5756.5380000000005,
          -5856.366999999999,
          -5955.187,
          -6053.007,
          -6149.8330000000005,
          -6245.6759999999995,
          -6340.5419999999995,
          -6434.44,
          -6527.3769999999995,
          -6619.363,
          -6710.403,
          -6800.508000000001,
          -6889.683000000001,
          -6977.936,
          -7065.276,
          -7151.7080000000005,
          -7237.241999999999,
          -7321.883000000001,
          -7405.639,
          -7488.517,
          -7570.524,
          -7651.6669999999995,
          -7731.951999999999,
          -7811.3859999999995,
          -7889.976,
          -7967.728,
          -8044.649,
          -8120.744000000001,
          -8196.02,
          -8270.483,
          -8344.138,
          -8416.993,
          -8489.052,
          -8560.321,
          -8630.806,
          -8700.511999999999,
          -8769.445,
          -8837.61,
          -8905.013,
          -8971.658000000001,
          -9037.55,
          -9102.696,
          -9167.099,
          -9230.764000000001,
          -9293.697,
          -9355.902,
          -9417.384,
          -9478.146,
          -9538.195,
          -9597.533000000001,
          -9656.166,
          -9714.097,
          -9771.332,
          -9827.873,
          -9883.726,
          -9938.893,
          -9993.38,
          -10047.19,
          -10100.327,
          -10152.794,
          -10204.595,
          -10255.735,
          -10306.215,
          -10356.041,
          -10405.216,
          -10453.742,
          -10501.623,
          -10548.863000000001,
          -10595.465,
          -10641.431999999999,
          -10686.767,
          -10731.473999999998,
          -10775.553999999998,
          -10819.013,
          -10861.851,
          -10904.073,
          -10945.681,
          -10986.677,
          -11027.066,
          -11066.848999999998,
          -11106.028999999999,
          -11144.608,
          -11182.59,
          -11219.976999999999,
          -11256.771999999999,
          -11292.976,
          -11328.593,
          -11363.625,
          -11398.073,
          -11431.941,
          -11465.231000000002,
          -11497.945,
          -11530.085,
          -11561.653999999999,
          -11592.653,
          -11623.085,
          -11652.951000000001,
          -11682.255,
          -11710.997,
          -11739.18,
          -11766.805,
          -11793.875,
          -11820.392,
          -11846.356000000002,
          -11871.771,
          -11896.638,
          -11920.958999999999,
          -11944.733999999999,
          -11967.966999999999,
          -11990.659,
          -12012.811000000002,
          -12034.426000000001,
          -12055.503999999999,
          -12076.046999999999,
          -12096.056,
          -12115.534,
          -12134.482,
          -12152.9,
          -12170.791000000001,
          -12188.157,
          -12204.997,
          -12221.313999999998,
          -12237.108999999999,
          -12252.383,
          -12267.138,
          -12281.375,
          -12295.095,
          -12308.298999999999,
          -12320.988000000001,
          -12333.163999999999,
          -12344.827,
          -12355.98,
          -12366.622,
          -12376.755,
          -12386.381000000001,
          -12395.499,
          -12404.111,
          -12412.218,
          -12419.821000000002,
          -12426.921999999999,
          -12433.518999999998,
          -12439.616000000002,
          -12445.212,
          -12450.309,
          -12454.907,
          -12459.007,
          -12462.608999999999,
          -12465.716,
          -12468.327,
          -12470.442,
          -12472.063999999998,
          -12473.193000000001,
          -12473.828000000001,
          -12473.972,
          -12473.624,
          -12472.785,
          -12471.455,
          -12469.636999999999,
          -12467.329,
          -12464.532,
          -12461.248,
          -12457.475,
          -12453.216,
          -12448.471000000001,
          -12443.239,
          -12437.521,
          -12431.319,
          -12424.631000000001,
          -12417.458999999999,
          -12409.803,
          -12401.663999999999,
          -12393.04,
          -12383.934,
          -12374.345,
          -12364.274,
          -12353.72,
          -12342.684,
          -12331.167,
          -12319.168,
          -12306.688,
          -12293.726,
          -12280.284,
          -12266.361,
          -12251.957,
          -12237.072,
          -12221.707,
          -12205.862,
          -12189.536,
          -12172.73,
          -12155.443000000001,
          -12137.677,
          -12119.43,
          -12100.703000000001,
          -12081.495,
          -12061.806999999999,
          -12041.639,
          -12020.99,
          -11999.861,
          -11978.251,
          -11956.16,
          -11933.588,
          -11910.535,
          -11887.001,
          -11862.983999999999,
          -11838.487,
          -11813.507,
          -11788.045,
          -11762.1,
          -11735.671999999999,
          -11708.761999999999,
          -11681.368,
          -11653.49,
          -11625.128,
          -11596.282,
          -11566.951000000001,
          -11537.133,
          -11506.832,
          -11476.043,
          -11444.768,
          -11413.006000000001,
          -11380.756000000001,
          -11348.018999999998,
          -11314.792,
          -11281.077,
          -11246.871000000001,
          -11212.176000000001,
          -11176.99,
          -11141.312,
          -11105.142,
          -11068.479,
          -11031.323,
          -10993.673,
          -10955.528,
          -10916.886999999999,
          -10877.751,
          -10838.117,
          -10797.985,
          -10757.355,
          -10716.225,
          -10674.595,
          -10632.464,
          -10589.831,
          -10546.696000000002,
          -10503.056,
          -10458.912,
          -10414.261999999999,
          -10369.106,
          -10323.442,
          -10277.269,
          -10230.587,
          -10183.394,
          -10135.69,
          -10087.472,
          -10038.741,
          -9989.495,
          -9939.732,
          -9889.452,
          -9838.654,
          -9787.336,
          -9735.497,
          -9683.136,
          -9630.251,
          -9576.841,
          -9522.905999999999,
          -9468.443000000001,
          -9413.451,
          -9357.929,
          -9301.876,
          -9245.29,
          -9188.169,
          -9130.513,
          -9072.319,
          -9013.586,
          -8954.313,
          -8894.498,
          -8834.14,
          -8773.237,
          -8711.787,
          -8649.789,
          -8587.241,
          -8524.141,
          -8460.488000000001,
          -8396.280999999999,
          -8331.516,
          -8266.193000000001,
          -8200.31,
          -8133.865,
          -8066.856,
          -7999.281,
          -7931.139,
          -7862.428000000001,
          -7793.145,
          -7723.289000000001,
          -7652.858,
          -7581.85,
          -7510.263000000001,
          -7438.095,
          -7365.344,
          -7292.009,
          -7218.085999999999,
          -7143.575,
          -7068.472,
          -6992.776999999999,
          -6916.486,
          -6839.599,
          -6762.111999999999,
          -6684.024,
          -6605.331999999999,
          -6526.036,
          -6446.130999999999,
          -6365.618,
          -6284.491999999999,
          -6202.753000000001,
          -6120.399,
          -6037.4259999999995,
          -5953.834,
          -5869.62,
          -5784.783,
          -5699.319,
          -5613.229,
          -5526.508000000001,
          -5439.156999999999,
          -5351.172,
          -5262.553000000001,
          -5173.298,
          -5083.404,
          -4992.87,
          -4901.696,
          -4809.879,
          -4717.418,
          -4624.312,
          -4530.56,
          -4436.161,
          -4341.115,
          -4245.42,
          -4149.076,
          -4052.0840000000003,
          -3954.442,
          -3856.152,
          -3757.2129999999997,
          -3657.6259999999997,
          -3557.393,
          -3456.513,
          -3354.99,
          -3252.825,
          -3150.0209999999997,
          -3046.58,
          -2942.505,
          -2837.801,
          -2732.472,
          -2626.5240000000003,
          -2519.9610000000002,
          -2412.79,
          -2305.02,
          -2196.657,
          -2087.712,
          -1978.194,
          -1868.116,
          -1757.489,
          -1646.3270000000002,
          -1534.648,
          -1422.467,
          -1309.8039999999999,
          -1196.68,
          -1083.118,
          -969.1439999999999,
          -854.7860000000001,
          -740.076,
          -625.048,
          -509.73900000000003,
          -394.19199999999995,
          -278.452,
          -162.569,
          -46.6,
          69.395,
          185.34900000000002,
          301.187,
          416.82800000000003,
          532.182,
          647.151,
          761.6260000000001,
          875.487,
          988.6030000000001,
          1100.83,
          1212.008,
          1321.963,
          1430.503,
          1537.418,
          1642.477,
          1745.4289999999999,
          1845.999,
          1943.886,
          2038.767,
          2130.2889999999998,
          2218.071,
          2301.709,
          2380.769,
          2454.792,
          2523.298,
          2585.7889999999998,
          2641.7529999999997,
          2690.6740000000004,
          2732.04,
          2765.357,
          2790.1540000000005,
          2806.006,
          2812.5429999999997,
          2809.467,
          2796.5609999999997,
          2773.702,
          2740.8720000000003,
          2698.15,
          2645.724,
          2583.881,
          2512.993,
          2433.511,
          2345.947,
          2250.855,
          2148.823,
          2040.454,
          1926.349,
          1807.104,
          1683.2920000000001,
          1555.461,
          1424.131,
          1289.7830000000001,
          1152.866,
          1013.79,
          872.933,
          730.6339999999999,
          587.203,
          442.916,
          298.022,
          152.744,
          7.279,
          -138.195,
          -283.522,
          -428.566,
          -573.202,
          -717.324,
          -860.837,
          -1003.658,
          -1145.714,
          -1286.942,
          -1427.759,
          -1566.703,
          -1705.146,
          -1842.5810000000001,
          -1978.979,
          -2114.314,
          -2248.565,
          -2381.7129999999997,
          -2513.743,
          -2644.6440000000002,
          -2774.407,
          -2903.025,
          -3030.492,
          -3156.805,
          -3281.962,
          -3405.9629999999997,
          -3528.809,
          -3650.5009999999997,
          -3771.0429999999997,
          -3890.438,
          -4008.691,
          -4125.806,
          -4241.789000000001,
          -4356.646,
          -4470.384,
          -4583.009,
          -4694.529,
          -4804.951,
          -4914.282,
          -5022.53,
          -5129.704000000001,
          -5235.81,
          -5340.859,
          -5444.856,
          -5547.812,
          -5649.733,
          -5750.629,
          -5850.508000000001,
          -5949.3769999999995,
          -6047.245,
          -6144.121,
          -6240.013000000001,
          -6334.928000000001,
          -6428.874,
          -6521.861,
          -6613.894,
          -6704.983,
          -6795.1359999999995,
          -6884.359,
          -6972.661,
          -7060.048000000001,
          -7146.528,
          -7232.109,
          -7316.797,
          -7400.6,
          -7483.526,
          -7565.579000000001,
          -7646.769,
          -7727.101,
          -7806.581,
          -7885.218000000001,
          -7963.016,
          -8039.982,
          -8116.1230000000005,
          -8191.444,
          -8265.953000000001,
          -8339.654,
          -8412.553,
          -8484.657,
          -8555.971,
          -8626.5,
          -8696.251,
          -8765.229,
          -8833.438,
          -8900.885,
          -8967.574,
          -9033.51,
          -9098.699,
          -9163.146,
          -9226.855,
          -9289.831,
          -9352.079,
          -9413.603000000001,
          -9474.409,
          -9534.5,
          -9593.88,
          -9652.556,
          -9710.529,
          -9767.806,
          -9824.389000000001,
          -9880.284,
          -9935.493,
          -9990.021999999999,
          -10043.873,
          -10097.051,
          -10149.56,
          -10201.402,
          -10252.582,
          -10303.104,
          -10352.971,
          -10402.186,
          -10450.752,
          -10498.673999999999,
          -10545.955,
          -10592.597,
          -10638.604,
          -10683.979,
          -10728.725,
          -10772.846000000001,
          -10816.343,
          -10859.221000000001,
          -10901.482,
          -10943.128999999999,
          -10984.165,
          -11024.593,
          -11064.415,
          -11103.633,
          -11142.252,
          -11180.273000000001,
          -11217.698,
          -11254.531,
          -11290.774,
          -11326.428999999998,
          -11361.499,
          -11395.985,
          -11429.891000000001,
          -11463.219,
          -11495.971000000001,
          -11528.149,
          -11559.755,
          -11590.791000000001,
          -11621.261,
          -11651.165,
          -11680.505,
          -11709.284,
          -11737.503999999999,
          -11765.166000000001,
          -11792.273000000001,
          -11818.826000000001,
          -11844.828000000001,
          -11870.278999999999,
          -11895.183,
          -11919.54,
          -11943.351999999999,
          -11966.621000000001,
          -11989.348999999998,
          -12011.537,
          -12033.187,
          -12054.301000000001,
          -12074.88,
          -12094.925,
          -12114.438999999998,
          -12133.421999999999,
          -12151.876,
          -12169.803,
          -12187.203000000001,
          -12204.079,
          -12220.431,
          -12236.261,
          -12251.571000000002,
          -12266.361,
          -12280.632,
          -12294.386999999999,
          -12307.625,
          -12320.348999999998,
          -12332.56,
          -12344.258,
          -12355.445,
          -12366.121000000001,
          -12376.288999999999,
          -12385.948,
          -12395.101,
          -12403.747,
          -12411.888,
          -12419.526000000002,
          -12426.659,
          -12433.291000000001,
          -12439.421999999999,
          -12445.051000000001,
          -12450.181999999999,
          -12454.813,
          -12458.946000000002,
          -12462.582,
          -12465.722,
          -12468.366000000002,
          -12470.516000000001,
          -12472.17,
          -12473.332,
          -12474,
          -12474.177,
          -12473.862,
          -12473.056,
          -12471.758999999998,
          -12469.973,
          -12467.698,
          -12464.934,
          -12461.681999999999,
          -12457.942,
          -12453.715,
          -12449.002,
          -12443.802,
          -12438.117,
          -12431.947,
          -12425.291000000001,
          -12418.151000000002,
          -12410.527,
          -12402.419,
          -12393.828000000001,
          -12384.753999999999,
          -12375.196000000002,
          -12365.157,
          -12354.633999999998,
          -12343.63,
          -12332.143999999998,
          -12320.177,
          -12307.728000000001,
          -12294.798,
          -12281.386999999999,
          -12267.495,
          -12253.122,
          -12238.268,
          -12222.934,
          -12207.12,
          -12190.825,
          -12174.05,
          -12156.794,
          -12139.059,
          -12120.841999999999,
          -12102.146,
          -12082.969,
          -12063.312,
          -12043.173999999999,
          -12022.556,
          -12001.457,
          -11979.877,
          -11957.817,
          -11935.275,
          -11912.252,
          -11888.747,
          -11864.761999999999,
          -11840.294,
          -11815.344,
          -11789.912,
          -11763.997,
          -11737.598999999998,
          -11710.718,
          -11683.354,
          -11655.506000000001,
          -11627.173,
          -11598.356000000002,
          -11569.055,
          -11539.267,
          -11508.996000000001,
          -11478.236,
          -11446.991000000002,
          -11415.258,
          -11383.037,
          -11350.329,
          -11317.131000000001,
          -11283.445,
          -11249.268999999998,
          -11214.601999999999,
          -11179.445,
          -11143.796,
          -11107.655,
          -11071.021,
          -11033.893999999998,
          -10996.271999999999,
          -10958.156,
          -10919.544,
          -10880.435,
          -10840.83,
          -10800.726999999999,
          -10760.125,
          -10719.024,
          -10677.421999999999,
          -10635.32,
          -10592.715,
          -10549.607,
          -10505.996000000001,
          -10461.88,
          -10417.258,
          -10372.13,
          -10326.494,
          -10280.349,
          -10233.695,
          -10186.53,
          -10138.853000000001,
          -10090.663,
          -10041.959,
          -9992.741,
          -9943.006,
          -9892.754,
          -9841.983,
          -9790.692,
          -9738.88,
          -9686.546,
          -9633.689,
          -9580.306999999999,
          -9526.398000000001,
          -9471.963,
          -9416.998,
          -9361.503,
          -9305.476999999999,
          -9248.918,
          -9191.824,
          -9134.194,
          -9076.027,
          -9017.321,
          -8958.075,
          -8898.287,
          -8837.955,
          -8777.079,
          -8715.655,
          -8653.684000000001,
          -8591.162,
          -8528.089,
          -8464.462,
          -8400.280999999999,
          -8335.542,
          -8270.246,
          -8204.389000000001,
          -8137.969,
          -8070.986,
          -8003.438,
          -7935.321,
          -7866.6359999999995,
          -7797.379,
          -7727.549,
          -7657.143,
          -7586.161,
          -7514.599,
          -7442.456999999999,
          -7369.732,
          -7296.420999999999,
          -7222.524,
          -7148.0380000000005,
          -7072.960999999999,
          -6997.29,
          -6921.025,
          -6844.161999999999,
          -6766.7,
          -6688.637,
          -6609.97,
          -6530.698,
          -6450.818,
          -6370.329000000001,
          -6289.228,
          -6207.513000000001,
          -6125.183000000001,
          -6042.235,
          -5958.6669999999995,
          -5874.477,
          -5789.6630000000005,
          -5704.223000000001,
          -5618.156,
          -5531.459,
          -5444.130999999999,
          -5356.17,
          -5267.5740000000005,
          -5178.340999999999,
          -5088.47,
          -4997.959,
          -4906.807,
          -4815.012,
          -4722.5740000000005,
          -4629.49,
          -4535.76,
          -4441.383,
          -4346.358,
          -4250.684,
          -4154.362,
          -4057.39,
          -3959.7690000000002,
          -3861.4990000000003,
          -3762.58,
          -3663.013,
          -3562.7990000000004,
          -3461.938,
          -3360.434,
          -3258.2870000000003,
          -3155.5009999999997,
          -3052.077,
          -2948.02,
          -2843.333,
          -2738.02,
          -2632.087,
          -2525.5389999999998,
          -2418.383,
          -2310.626,
          -2202.277,
          -2093.344,
          -1983.838,
          -1873.77,
          -1763.1529999999998,
          -1652.001,
          -1540.329,
          -1428.155,
          -1315.497,
          -1202.377,
          -1088.8210000000001,
          -974.8480000000001,
          -860.49,
          -745.778,
          -630.746,
          -515.431,
          -399.876,
          -284.125,
          -168.229,
          -52.243,
          63.771,
          179.747,
          295.612,
          411.283,
          526.672,
          641.68,
          756.2,
          870.112,
          983.285,
          1095.575,
          1206.825,
          1316.859,
          1425.4879999999998,
          1532.5020000000002,
          1637.67,
          1740.743,
          1841.445,
          1939.48,
          2034.5220000000002,
          2126.221,
          2214.199,
          2298.051,
          2377.343,
          2451.6220000000003,
          2520.404,
          2583.192,
          2639.4770000000003,
          2688.743,
          2730.4759999999997,
          2764.18,
          2789.386,
          2805.667,
          2812.6479999999997,
          2810.028,
          2797.5890000000004,
          2775.2009999999996,
          2742.84,
          2700.586,
          2648.618,
          2587.22,
          2516.761,
          2437.688,
          2350.508,
          2255.777,
          2154.0820000000003,
          2046.0220000000002,
          1932.201,
          1813.213,
          1689.632,
          1562.01,
          1430.8629999999998,
          1296.6789999999999,
          1159.905,
          1020.955,
          880.205,
          737.998,
          594.644,
          450.421,
          305.58,
          160.344,
          14.912,
          -130.539,
          -275.851,
          -420.88599999999997,
          -565.52,
          -709.645,
          -853.166,
          -996.0010000000001,
          -1138.0739999999998,
          -1279.3239999999998,
          -1419.694,
          -1559.136,
          -1697.609,
          -1835.078,
          -1971.511,
          -2106.882,
          -2241.1710000000003,
          -2374.359,
          -2506.43,
          -2637.3740000000003,
          -2767.1809999999996,
          -2895.843,
          -3023.355,
          -3149.7140000000004,
          -3274.9179999999997,
          -3398.966,
          -3521.86,
          -3643.6009999999997,
          -3764.191,
          -3883.636,
          -4001.937,
          -4119.102,
          -4235.135,
          -4350.042,
          -4463.83,
          -4576.505,
          -4688.075,
          -4798.5470000000005,
          -4907.929,
          -5016.228,
          -5123.452,
          -5229.609,
          -5334.7080000000005,
          -5438.755999999999,
          -5541.7609999999995,
          -5643.733,
          -5744.679,
          -5844.607,
          -5943.526,
          -6041.444,
          -6138.37,
          -6234.311,
          -6329.275,
          -6423.271,
          -6516.306,
          -6608.389,
          -6699.526,
          -6789.727,
          -6878.999,
          -6967.348000000001,
          -7054.783,
          -7141.311,
          -7226.94,
          -7311.6759999999995,
          -7395.526999999999,
          -7478.499,
          -7560.6,
          -7641.8369999999995,
          -7722.215999999999,
          -7801.743,
          -7880.4259999999995,
          -7958.27,
          -8035.283,
          -8111.471,
          -8186.838000000001,
          -8261.392,
          -8335.139000000001,
          -8408.084,
          -8480.233,
          -8551.591999999999,
          -8622.166,
          -8691.962,
          -8760.984,
          -8829.238000000001,
          -8896.729,
          -8963.462,
          -9029.443000000001,
          -9094.676,
          -9159.166,
          -9222.919,
          -9285.938,
          -9348.229,
          -9409.796999999999,
          -9470.646,
          -9530.779,
          -9590.203000000001,
          -9648.921,
          -9706.937,
          -9764.256,
          -9820.882,
          -9876.819,
          -9932.07,
          -9986.64,
          -10040.533000000001,
          -10093.753,
          -10146.303,
          -10198.187,
          -10249.408000000001,
          -10299.971,
          -10349.878,
          -10399.134,
          -10447.742,
          -10495.704,
          -10543.025,
          -10589.708,
          -10635.756000000001,
          -10681.171,
          -10725.957,
          -10770.118,
          -10813.655,
          -10856.573,
          -10898.873,
          -10940.56,
          -10981.635,
          -11022.101999999999,
          -11061.963,
          -11101.221000000001,
          -11139.878,
          -11177.938,
          -11215.402,
          -11252.274,
          -11288.555,
          -11324.248,
          -11359.356000000002,
          -11393.881000000001,
          -11427.825,
          -11461.191,
          -11493.981000000002,
          -11526.196000000002,
          -11557.84,
          -11588.913999999999,
          -11619.421,
          -11649.362,
          -11678.74,
          -11707.556,
          -11735.813,
          -11763.511999999999,
          -11790.656,
          -11817.246000000001,
          -11843.284,
          -11868.773000000001,
          -11893.712,
          -11918.106000000002,
          -11941.955,
          -11965.26,
          -11988.024,
          -12010.249,
          -12031.935,
          -12053.085,
          -12073.7,
          -12093.781,
          -12113.33,
          -12132.348999999998,
          -12150.839,
          -12168.801000000001,
          -12186.237,
          -12203.148000000001,
          -12219.536,
          -12235.401000000002,
          -12250.746000000001,
          -12265.571000000002,
          -12279.878,
          -12293.667,
          -12306.941,
          -12319.7,
          -12331.945,
          -12343.678,
          -12354.899,
          -12365.61,
          -12375.812,
          -12385.506000000001,
          -12394.692,
          -12403.373,
          -12411.548,
          -12419.219,
          -12426.386999999999,
          -12433.053,
          -12439.216999999999,
          -12444.881000000001,
          -12450.045,
          -12454.71,
          -12458.877,
          -12462.546,
          -12465.719,
          -12468.396999999999,
          -12470.579,
          -12472.268,
          -12473.462,
          -12474.163999999999,
          -12474.373,
          -12474.091,
          -12473.318000000001,
          -12472.053999999998,
          -12470.301000000001,
          -12468.058,
          -12465.327,
          -12462.107,
          -12458.4,
          -12454.206,
          -12449.525,
          -12444.358,
          -12438.705,
          -12432.567,
          -12425.943000000001,
          -12418.835,
          -12411.243,
          -12403.168,
          -12394.608,
          -12385.566,
          -12376.04,
          -12366.032,
          -12355.542,
          -12344.569,
          -12333.115,
          -12321.178999999998,
          -12308.761,
          -12295.862,
          -12282.483,
          -12268.622,
          -12254.28,
          -12239.458999999999,
          -12224.156,
          -12208.373,
          -12192.108999999999,
          -12175.365,
          -12158.14,
          -12140.435,
          -12122.25,
          -12103.583999999999,
          -12084.438,
          -12064.811000000002,
          -12044.704,
          -12024.116000000002,
          -12003.048,
          -11981.498,
          -11959.468,
          -11936.957,
          -11913.964,
          -11890.49,
          -11866.534,
          -11842.096000000001,
          -11817.176000000001,
          -11791.774,
          -11765.889,
          -11739.521,
          -11712.67,
          -11685.336000000001,
          -11657.517,
          -11629.215,
          -11600.428,
          -11571.155,
          -11541.398000000001,
          -11511.153999999999,
          -11480.423999999999,
          -11449.208,
          -11417.505,
          -11385.313,
          -11352.633999999998,
          -11319.466,
          -11285.809,
          -11251.661,
          -11217.024,
          -11181.896,
          -11146.276000000002,
          -11110.163,
          -11073.558,
          -11036.46,
          -10998.867,
          -10960.778999999999,
          -10922.196000000002,
          -10883.116000000002,
          -10843.54,
          -10803.465,
          -10762.892,
          -10721.819,
          -10680.246000000001,
          -10638.171,
          -10595.595,
          -10552.516000000001,
          -10508.931999999999,
          -10464.844000000001,
          -10420.251,
          -10375.15,
          -10329.543,
          -10283.426,
          -10236.8,
          -10189.663,
          -10142.014000000001,
          -10093.851999999999,
          -10045.176,
          -9995.985,
          -9946.278,
          -9896.053,
          -9845.31,
          -9794.046999999999,
          -9742.263,
          -9689.956,
          -9637.126,
          -9583.771,
          -9529.89,
          -9475.481,
          -9420.544,
          -9365.076,
          -9309.077,
          -9252.545,
          -9195.478000000001,
          -9137.875,
          -9079.735,
          -9021.056,
          -8961.837,
          -8902.075,
          -8841.77,
          -8780.92,
          -8719.524,
          -8657.579,
          -8595.083,
          -8532.037,
          -8468.437,
          -8404.280999999999,
          -8339.569,
          -8274.299,
          -8208.468,
          -8142.075,
          -8075.118,
          -8007.595,
          -7939.505,
          -7870.845,
          -7801.6140000000005,
          -7731.81,
          -7661.43,
          -7590.474,
          -7518.938,
          -7446.821,
          -7374.121,
          -7300.835999999999,
          -7226.965,
          -7152.504,
          -7077.451999999999,
          -7001.807,
          -6925.566999999999,
          -6848.729,
          -6771.293000000001,
          -6693.254,
          -6614.611999999999,
          -6535.365,
          -6455.51,
          -6375.045,
          -6293.969,
          -6212.279,
          -6129.973000000001,
          -6047.049,
          -5963.505,
          -5879.339,
          -5794.549,
          -5709.133000000001,
          -5623.09,
          -5536.4169999999995,
          -5449.111999999999,
          -5361.174,
          -5272.601,
          -5183.392,
          -5093.543,
          -5003.055,
          -4911.9259999999995,
          -4820.154,
          -4727.737,
          -4634.6759999999995,
          -4540.968,
          -4446.612,
          -4351.609,
          -4255.957,
          -4159.656,
          -4062.705,
          -3965.105,
          -3866.855,
          -3767.9570000000003,
          -3668.409,
          -3568.215,
          -3467.3740000000003,
          -3365.889,
          -3263.761,
          -3160.992,
          -3057.587,
          -2953.547,
          -2848.8759999999997,
          -2743.58,
          -2637.663,
          -2531.131,
          -2423.99,
          -2316.248,
          -2207.9120000000003,
          -2098.992,
          -1989.4979999999998,
          -1879.441,
          -1768.835,
          -1657.692,
          -1546.0279999999998,
          -1433.861,
          -1321.21,
          -1208.094,
          -1094.539,
          -980.568,
          -866.211,
          -751.497,
          -636.461,
          -521.141,
          -405.57800000000003,
          -289.817,
          -173.908,
          -57.907,
          58.126999999999995,
          174.125,
          290.015,
          405.717,
          521.14,
          636.188,
          750.752,
          864.7139999999999,
          977.944,
          1090.297,
          1201.618,
          1311.731,
          1420.4479999999999,
          1527.56,
          1632.8370000000002,
          1736.03,
          1836.865,
          1935.047,
          2030.251,
          2122.1279999999997,
          2210.301,
          2294.367,
          2373.894,
          2448.426,
          2517.485,
          2580.573,
          2637.179,
          2686.7909999999997,
          2728.8920000000003,
          2762.987,
          2788.605,
          2805.316,
          2812.745,
          2810.585,
          2798.615,
          2776.7009999999996,
          2744.816,
          2703.033,
          2651.528,
          2590.58,
          2520.554,
          2441.894,
          2355.105,
          2260.74,
          2159.384,
          2051.639,
          1938.104,
          1819.3770000000002,
          1696.031,
          1568.619,
          1437.66,
          1303.641,
          1167.013,
          1028.1889999999999,
          887.548,
          745.434,
          602.158,
          458.001,
          313.21299999999997,
          168.019,
          22.62,
          -122.807,
          -268.103,
          -413.12800000000004,
          -557.76,
          -701.8889999999999,
          -845.419,
          -988.2669999999999,
          -1130.358,
          -1271.629,
          -1412.024,
          -1551.494,
          -1689.9979999999998,
          -1827.499,
          -1963.9679999999998,
          -2099.376,
          -2233.7039999999997,
          -2366.9320000000002,
          -2499.045,
          -2630.032,
          -2759.883,
          -2888.59,
          -3016.1479999999997,
          -3142.554,
          -3267.805,
          -3391.902,
          -3514.844,
          -3636.634,
          -3757.2740000000003,
          -3876.768,
          -3995.12,
          -4112.335,
          -4228.418,
          -4343.376,
          -4457.214,
          -4569.941,
          -4681.561,
          -4792.084,
          -4901.517,
          -5009.867,
          -5117.142,
          -5223.35,
          -5328.5,
          -5432.598000000001,
          -5535.655,
          -5637.677,
          -5738.673000000001,
          -5838.651999999999,
          -5937.621999999999,
          -6035.59,
          -6132.566,
          -6228.557,
          -6323.571,
          -6417.616,
          -6510.701,
          -6602.8330000000005,
          -6694.02,
          -6784.27,
          -6873.590999999999,
          -6961.9890000000005,
          -7049.473000000001,
          -7136.049,
          -7221.726,
          -7306.5109999999995,
          -7390.409000000001,
          -7473.43,
          -7555.579000000001,
          -7636.861999999999,
          -7717.2880000000005,
          -7796.863,
          -7875.593000000001,
          -7953.484,
          -8030.544,
          -8106.778,
          -8182.191999999999,
          -8256.792,
          -8330.584,
          -8403.575,
          -8475.77,
          -8547.175,
          -8617.795,
          -8687.635,
          -8756.703000000001,
          -8825.001,
          -8892.537,
          -8959.315,
          -9025.34,
          -9090.617,
          -9155.152,
          -9218.949,
          -9282.011999999999,
          -9344.347,
          -9405.958,
          -9466.85,
          -9527.027,
          -9586.494,
          -9645.255,
          -9703.314,
          -9760.676,
          -9817.344000000001,
          -9873.323,
          -9928.617,
          -9983.229,
          -10037.164,
          -10090.426,
          -10143.018,
          -10194.943000000001,
          -10246.206,
          -10296.81,
          -10346.759,
          -10396.056,
          -10444.705,
          -10492.708,
          -10540.07,
          -10586.793,
          -10632.881000000001,
          -10678.337,
          -10723.163999999999,
          -10767.364,
          -10810.942,
          -10853.899,
          -10896.24,
          -10937.966,
          -10979.081,
          -11019.587,
          -11059.488000000001,
          -11098.785,
          -11137.481000000002,
          -11175.58,
          -11213.083,
          -11249.993999999999,
          -11286.313999999998,
          -11322.046,
          -11357.192,
          -11391.756000000001,
          -11425.738000000001,
          -11459.142,
          -11491.97,
          -11524.223999999998,
          -11555.905,
          -11587.017,
          -11617.562,
          -11647.541000000001,
          -11676.956,
          -11705.81,
          -11734.104,
          -11761.84,
          -11789.021,
          -11815.649,
          -11841.723999999998,
          -11867.249,
          -11892.226,
          -11916.656,
          -11940.541000000001,
          -11963.883,
          -11986.684,
          -12008.945,
          -12030.668,
          -12051.854,
          -12072.503999999999,
          -12092.622,
          -12112.207,
          -12131.261999999999,
          -12149.787,
          -12167.785,
          -12185.257,
          -12202.203000000001,
          -12218.626,
          -12234.527,
          -12249.908000000001,
          -12264.768,
          -12279.11,
          -12292.935,
          -12306.243,
          -12319.037,
          -12331.317,
          -12343.083999999999,
          -12354.34,
          -12365.086000000001,
          -12375.323,
          -12385.051000000001,
          -12394.271999999999,
          -12402.987,
          -12411.196000000002,
          -12418.902,
          -12426.104,
          -12432.803,
          -12439.002,
          -12444.698999999999,
          -12449.896999999999,
          -12454.596000000001,
          -12458.796,
          -12462.5,
          -12465.706,
          -12468.417,
          -12470.633,
          -12472.355,
          -12473.582,
          -12474.317,
          -12474.56,
          -12474.311000000002,
          -12473.571000000002,
          -12472.34,
          -12470.62,
          -12468.41,
          -12465.711000000001,
          -12462.525,
          -12458.85,
          -12454.688,
          -12450.04,
          -12444.905,
          -12439.285,
          -12433.178999999998,
          -12426.588,
          -12419.511999999999,
          -12411.952,
          -12403.908000000001,
          -12395.381000000001,
          -12386.37,
          -12376.877,
          -12366.901000000002,
          -12356.442,
          -12345.501,
          -12334.079,
          -12322.173999999999,
          -12309.788,
          -12296.921,
          -12283.573,
          -12269.743,
          -12255.433,
          -12240.643,
          -12225.372,
          -12209.618999999999,
          -12193.386999999999,
          -12176.673,
          -12159.48,
          -12141.806,
          -12123.651000000002,
          -12105.016000000001,
          -12085.901000000002,
          -12066.305,
          -12046.229,
          -12025.671999999999,
          -12004.633999999998,
          -11983.115,
          -11961.115,
          -11938.633999999998,
          -11915.671999999999,
          -11892.228000000001,
          -11868.302,
          -11843.895,
          -11819.005,
          -11793.633,
          -11767.778,
          -11741.44,
          -11714.618999999999,
          -11687.315,
          -11659.526000000002,
          -11631.253,
          -11602.496000000001,
          -11573.253,
          -11543.525,
          -11513.311000000002,
          -11482.611,
          -11451.423999999999,
          -11419.75,
          -11387.589,
          -11354.938999999998,
          -11321.8,
          -11288.171999999999,
          -11254.053999999998,
          -11219.446000000002,
          -11184.346000000001,
          -11148.755,
          -11112.671999999999,
          -11076.096000000001,
          -11039.027,
          -11001.463,
          -10963.403999999999,
          -10924.848999999998,
          -10885.798999999999,
          -10846.251,
          -10806.205,
          -10765.66,
          -10724.616000000002,
          -10683.071000000002,
          -10641.025,
          -10598.476999999999,
          -10555.426000000001,
          -10511.871000000001,
          -10467.812,
          -10423.246,
          -10378.174,
          -10332.594000000001,
          -10286.506,
          -10239.908000000001,
          -10192.799,
          -10145.178,
          -10097.044,
          -10048.396,
          -9999.233,
          -9949.554,
          -9899.357,
          -9848.641,
          -9797.405999999999,
          -9745.649,
          -9693.37,
          -9640.568000000001,
          -9587.24,
          -9533.386999999999,
          -9479.005,
          -9424.095,
          -9368.655,
          -9312.683,
          -9256.178,
          -9199.138,
          -9141.563,
          -9083.45,
          -9024.798,
          -8965.605,
          -8905.871,
          -8845.593,
          -8784.77,
          -8723.4,
          -8661.482,
          -8599.013,
          -8535.993,
          -8472.42,
          -8408.291,
          -8343.606,
          -8278.362,
          -8212.556999999999,
          -8146.191,
          -8079.26,
          -8011.764,
          -7943.7,
          -7875.066,
          -7805.861,
          -7736.0830000000005,
          -7665.729,
          -7594.799,
          -7523.289000000001,
          -7451.198,
          -7378.524,
          -7305.265,
          -7231.419,
          -7156.984,
          -7081.956999999999,
          -7006.338000000001,
          -6930.1230000000005,
          -6853.311,
          -6775.9,
          -6697.887,
          -6619.27,
          -6540.048000000001,
          -6460.218000000001,
          -6379.778,
          -6298.727,
          -6217.061,
          -6134.78,
          -6051.880999999999,
          -5968.361,
          -5884.22,
          -5799.455,
          -5714.063,
          -5628.044,
          -5541.395,
          -5454.1140000000005,
          -5366.2,
          -5277.651,
          -5188.465,
          -5098.64,
          -5008.175,
          -4917.069,
          -4825.32,
          -4732.9259999999995,
          -4639.888,
          -4546.202,
          -4451.869000000001,
          -4356.888,
          -4261.258,
          -4164.979,
          -4068.05,
          -3970.4709999999995,
          -3872.242,
          -3773.364,
          -3673.8379999999997,
          -3573.663,
          -3472.843,
          -3371.377,
          -3269.268,
          -3166.5190000000002,
          -3063.131,
          -2959.1090000000004,
          -2854.4570000000003,
          -2749.178,
          -2643.277,
          -2536.761,
          -2429.636,
          -2321.909,
          -2213.587,
          -2104.68,
          -1995.1989999999998,
          -1885.154,
          -1774.558,
          -1663.425,
          -1551.771,
          -1439.612,
          -1326.967,
          -1213.857,
          -1100.306,
          -986.3380000000001,
          -871.9810000000001,
          -757.2660000000001,
          -642.2280000000001,
          -526.903,
          -411.333,
          -295.562,
          -179.641,
          -63.625,
          52.426,
          168.446,
          284.362,
          400.093,
          515.55,
          630.636,
          745.2439999999999,
          859.2560000000001,
          972.5419999999999,
          1084.9589999999998,
          1196.35,
          1306.542,
          1415.3470000000002,
          1522.557,
          1627.943,
          1731.256,
          1832.226,
          1930.555,
          2025.922,
          2117.978,
          2206.349,
          2290.63,
          2370.393,
          2445.183,
          2514.521,
          2577.911,
          2634.844,
          2684.804,
          2727.28,
          2761.7709999999997,
          2787.8059999999996,
          2804.955,
          2812.837,
          2811.145,
          2799.652,
          2778.222,
          2746.82,
          2705.5170000000003,
          2654.4840000000004,
          2593.995,
          2524.411,
          2446.173,
          2359.782,
          2265.792,
          2164.784,
          2057.359,
          1944.118,
          1825.656,
          1702.5510000000002,
          1575.355,
          1444.5870000000002,
          1310.7379999999998,
          1174.258,
          1035.563,
          895.033,
          753.0139999999999,
          609.819,
          465.72900000000004,
          320.995,
          175.845,
          30.479,
          -114.92399999999999,
          -260.204,
          -405.221,
          -549.85,
          -693.9830000000001,
          -837.523,
          -980.3839999999999,
          -1122.494,
          -1263.787,
          -1404.75,
          -1543.7060000000001,
          -1682.241,
          -1819.777,
          -1956.281,
          -2091.728,
          -2226.096,
          -2359.365,
          -2491.522,
          -2622.553,
          -2752.449,
          -2881.202,
          -3008.808,
          -3135.261,
          -3260.562,
          -3384.7070000000003,
          -3507.699,
          -3629.54,
          -3750.23,
          -3869.775,
          -3988.178,
          -4105.445,
          -4221.58,
          -4336.589,
          -4450.48,
          -4563.258,
          -4674.931,
          -4785.505999999999,
          -4894.991,
          -5003.393,
          -5110.721,
          -5216.981,
          -5322.182,
          -5426.3330000000005,
          -5529.441,
          -5631.515,
          -5732.563,
          -5832.594,
          -5931.615,
          -6029.635,
          -6126.661,
          -6222.703,
          -6317.768,
          -6411.865,
          -6505,
          -6597.183000000001,
          -6688.42,
          -6778.72,
          -6868.09,
          -6956.539000000001,
          -7044.071999999999,
          -7130.698,
          -7216.424,
          -7301.258000000001,
          -7385.206,
          -7468.275,
          -7550.472,
          -7631.804,
          -7712.279,
          -7791.901,
          -7870.679,
          -7948.618,
          -8025.725,
          -8102.005999999999,
          -8177.468000000001,
          -8252.115,
          -8325.954,
          -8398.992,
          -8471.233,
          -8542.684000000001,
          -8613.35,
          -8683.237,
          -8752.35,
          -8820.694,
          -8888.276,
          -8955.099,
          -9021.169,
          -9086.492,
          -9151.071,
          -9214.912,
          -9278.02,
          -9340.4,
          -9402.055,
          -9462.991,
          -9523.212,
          -9582.723,
          -9641.528,
          -9699.63,
          -9757.035,
          -9813.747,
          -9869.769,
          -9925.106,
          -9979.761,
          -10033.739,
          -10087.043,
          -10139.677,
          -10191.644,
          -10242.95,
          -10293.596,
          -10343.586,
          -10392.925,
          -10441.615,
          -10489.66,
          -10537.063,
          -10583.828000000001,
          -10629.957,
          -10675.454,
          -10720.321000000002,
          -10764.562,
          -10808.181,
          -10851.178999999998,
          -10893.56,
          -10935.326000000001,
          -10976.481000000002,
          -11017.027,
          -11056.966999999999,
          -11096.303999999998,
          -11135.041000000001,
          -11173.178999999998,
          -11210.721000000001,
          -11247.671,
          -11284.03,
          -11319.802,
          -11354.987,
          -11389.589,
          -11423.611,
          -11457.053,
          -11489.92,
          -11522.212,
          -11553.931999999999,
          -11585.082,
          -11615.665,
          -11645.681,
          -11675.135,
          -11704.026000000002,
          -11732.358,
          -11760.133,
          -11787.351,
          -11814.016000000001,
          -11840.128,
          -11865.691,
          -11890.705,
          -11915.171999999999,
          -11939.094,
          -11962.473999999998,
          -11985.311000000002,
          -12007.608999999999,
          -12029.368,
          -12050.59,
          -12071.278,
          -12091.431999999999,
          -12111.053,
          -12130.143999999998,
          -12148.706,
          -12166.74,
          -12184.247,
          -12201.23,
          -12217.688,
          -12233.625,
          -12249.041000000001,
          -12263.937,
          -12278.313999999998,
          -12292.173999999999,
          -12305.518,
          -12318.347,
          -12330.662,
          -12342.465,
          -12353.756000000001,
          -12364.536,
          -12374.806999999999,
          -12384.57,
          -12393.826000000001,
          -12402.576000000001,
          -12410.82,
          -12418.56,
          -12425.796,
          -12432.53,
          -12438.761999999999,
          -12444.493999999999,
          -12449.726,
          -12454.458999999999,
          -12458.693000000001,
          -12462.43,
          -12465.671,
          -12468.416000000001,
          -12470.665,
          -12472.42,
          -12473.681999999999,
          -12474.45,
          -12474.726,
          -12474.51,
          -12473.803,
          -12472.606000000002,
          -12470.918,
          -12468.741000000002,
          -12466.076000000001,
          -12462.921999999999,
          -12459.28,
          -12455.152,
          -12450.536,
          -12445.434,
          -12439.846000000001,
          -12433.771999999999,
          -12427.214,
          -12420.171,
          -12412.643,
          -12404.631000000001,
          -12396.136,
          -12387.158000000001,
          -12377.696000000002,
          -12367.752,
          -12357.326000000001,
          -12346.417,
          -12335.026000000002,
          -12323.153,
          -12310.798999999999,
          -12297.964,
          -12284.646999999999,
          -12270.848999999998,
          -12256.57,
          -12241.811000000002,
          -12226.571000000002,
          -12210.85,
          -12194.649,
          -12177.966999999999,
          -12160.803999999998,
          -12143.161,
          -12125.038,
          -12106.434,
          -12087.35,
          -12067.785,
          -12047.739,
          -12027.213,
          -12006.205,
          -11984.716999999999,
          -11962.748,
          -11940.298,
          -11917.366000000002,
          -11893.952,
          -11870.056999999999,
          -11845.68,
          -11820.82,
          -11795.479,
          -11769.653999999999,
          -11743.346000000001,
          -11716.555,
          -11689.281,
          -11661.521999999999,
          -11633.278999999999,
          -11604.551000000001,
          -11575.339,
          -11545.64,
          -11515.456,
          -11484.786,
          -11453.628999999999,
          -11421.983999999999,
          -11389.851999999999,
          -11357.231000000002,
          -11324.122,
          -11290.523000000001,
          -11256.435,
          -11221.856000000002,
          -11186.786,
          -11151.223999999998,
          -11115.17,
          -11078.623,
          -11041.582,
          -11004.046999999999,
          -10966.017,
          -10927.492,
          -10888.47,
          -10848.951000000001,
          -10808.933,
          -10768.417,
          -10727.402,
          -10685.886,
          -10643.868,
          -10601.348999999998,
          -10558.326000000001,
          -10514.8,
          -10470.769,
          -10426.231,
          -10381.188,
          -10335.636,
          -10289.576,
          -10243.006,
          -10195.925,
          -10148.332,
          -10100.226,
          -10051.606,
          -10002.471,
          -9952.82,
          -9902.65,
          -9851.963,
          -9800.755,
          -9749.026,
          -9696.775,
          -9644,
          -9590.7,
          -9536.874,
          -9482.52,
          -9427.636999999999,
          -9372.225,
          -9316.28,
          -9259.802,
          -9202.79,
          -9145.241,
          -9087.155999999999,
          -9028.530999999999,
          -8969.365,
          -8909.658000000001,
          -8849.407,
          -8788.610999999999,
          -8727.268,
          -8665.376,
          -8602.935,
          -8539.940999999999,
          -8476.395,
          -8412.293,
          -8347.634,
          -8282.416,
          -8216.638,
          -8150.298000000001,
          -8083.394,
          -8015.924,
          -7947.887,
          -7879.279,
          -7810.101,
          -7740.348000000001,
          -7670.021,
          -7599.116,
          -7527.633000000001,
          -7455.568,
          -7382.92,
          -7309.686,
          -7235.866,
          -7161.456999999999,
          -7086.456,
          -7010.861999999999,
          -6934.673000000001,
          -6857.887,
          -6780.5,
          -6702.513000000001,
          -6623.922,
          -6544.725,
          -6464.920999999999,
          -6384.505999999999,
          -6303.48,
          -6221.839,
          -6139.5830000000005,
          -6056.7080000000005,
          -5973.213000000001,
          -5889.096,
          -5804.355,
          -5718.988,
          -5632.994000000001,
          -5546.369000000001,
          -5459.111999999999,
          -5371.222,
          -5282.696999999999,
          -5193.534000000001,
          -5103.734,
          -5013.292,
          -4922.21,
          -4830.484,
          -4738.113,
          -4645.097,
          -4551.435,
          -4457.124,
          -4362.166,
          -4266.558,
          -4170.3,
          -4073.393,
          -3975.835,
          -3877.6279999999997,
          -3778.7709999999997,
          -3679.265,
          -3579.111,
          -3478.3109999999997,
          -3376.865,
          -3274.775,
          -3172.045,
          -3068.676,
          -2964.673,
          -2860.038,
          -2754.776,
          -2648.893,
          -2542.393,
          -2435.283,
          -2327.57,
          -2219.263,
          -2110.37,
          -2000.902,
          -1890.87,
          -1780.286,
          -1669.1629999999998,
          -1557.5179999999998,
          -1445.3670000000002,
          -1332.729,
          -1219.625,
          -1106.078,
          -992.113,
          -877.758,
          -763.043,
          -648.002,
          -532.672,
          -417.095,
          -301.316,
          -185.38299999999998,
          -69.352,
          46.717,
          162.75799999999998,
          278.698,
          394.458,
          509.949,
          625.073,
          739.725,
          853.7860000000001,
          967.127,
          1079.606,
          1191.067,
          1301.339,
          1410.2320000000002,
          1517.5379999999998,
          1623.033,
          1726.467,
          1827.569,
          1926.045,
          2021.575,
          2113.811,
          2202.3779999999997,
          2286.875,
          2366.873,
          2441.919,
          2511.538,
          2575.23,
          2632.49,
          2682.801,
          2725.65,
          2760.538,
          2786.993,
          2804.579,
          2812.917,
          2811.6940000000004,
          2800.6809999999996,
          2779.736,
          2748.822,
          2708.002,
          2657.445,
          2597.4179999999997,
          2528.28,
          2450.466,
          2364.479,
          2270.866,
          2170.209,
          2063.107,
          1950.1629999999998,
          1831.971,
          1709.109,
          1582.13,
          1451.558,
          1317.879,
          1181.549,
          1042.984,
          902.567,
          760.645,
          617.531,
          473.50800000000004,
          328.829,
          183.72299999999998,
          38.391,
          -106.98700000000001,
          -252.25099999999998,
          -397.259,
          -541.887,
          -686.023,
          -829.572,
          -972.448,
          -1114.576,
          -1255.891,
          -1396.338,
          -1535.865,
          -1674.432,
          -1812.0020000000002,
          -1948.5420000000001,
          -2084.028,
          -2218.436,
          -2351.7470000000003,
          -2483.947,
          -2615.0229999999997,
          -2744.966,
          -2873.7659999999996,
          -3001.4190000000003,
          -3127.921,
          -3253.2709999999997,
          -3377.466,
          -3500.509,
          -3622.3990000000003,
          -3743.1409999999996,
          -3862.737,
          -3981.192,
          -4098.5109999999995,
          -4214.698,
          -4329.76,
          -4443.7029999999995,
          -4556.534000000001,
          -4668.259,
          -4778.887,
          -4888.425,
          -4996.88,
          -5104.259,
          -5210.572,
          -5315.826,
          -5420.029,
          -5523.189,
          -5625.316,
          -5726.416,
          -5826.4980000000005,
          -5925.571,
          -6023.643,
          -6120.721,
          -6216.814,
          -6311.931,
          -6406.078,
          -6499.265,
          -6591.4980000000005,
          -6682.786,
          -6773.137,
          -6862.558000000001,
          -6951.057,
          -7038.64,
          -7125.316,
          -7211.092,
          -7295.975,
          -7379.972,
          -7463.09,
          -7545.335999999999,
          -7626.717,
          -7707.24,
          -7786.911,
          -7865.736999999999,
          -7943.724,
          -8020.878000000001,
          -8097.206999999999,
          -8172.715,
          -8247.41,
          -8321.296,
          -8394.381,
          -8466.669,
          -8538.166,
          -8608.879,
          -8678.813,
          -8747.972,
          -8816.363000000001,
          -8883.99,
          -8950.858,
          -9016.974,
          -9082.341999999999,
          -9146.966,
          -9210.851999999999,
          -9274.005,
          -9336.429,
          -9398.129,
          -9459.109,
          -9519.375,
          -9578.929,
          -9637.778,
          -9695.924,
          -9753.373,
          -9810.128,
          -9866.193000000001,
          -9921.573,
          -9976.271,
          -10030.292,
          -10083.638,
          -10136.315,
          -10188.325,
          -10239.671999999999,
          -10290.360999999999,
          -10340.394,
          -10389.775,
          -10438.507,
          -10486.593,
          -10534.038,
          -10580.843,
          -10627.013,
          -10672.551000000001,
          -10717.458999999999,
          -10761.741000000002,
          -10805.4,
          -10848.438999999998,
          -10890.86,
          -10932.667,
          -10973.862,
          -11014.448999999999,
          -11054.428999999998,
          -11093.806,
          -11132.582,
          -11170.758999999998,
          -11208.341999999999,
          -11245.331,
          -11281.729,
          -11317.54,
          -11352.764,
          -11387.405,
          -11421.466,
          -11454.947,
          -11487.851999999999,
          -11520.183,
          -11551.941,
          -11583.13,
          -11613.751,
          -11643.806,
          -11673.298,
          -11702.226999999999,
          -11730.597,
          -11758.409,
          -11785.665,
          -11812.367,
          -11838.517,
          -11864.117,
          -11889.168,
          -11913.673,
          -11937.632,
          -11961.048,
          -11983.923,
          -12006.257,
          -12028.053,
          -12049.312,
          -12070.036,
          -12090.226,
          -12109.883999999998,
          -12129.011,
          -12147.608999999999,
          -12165.678999999998,
          -12183.222,
          -12200.241000000002,
          -12216.735,
          -12232.708,
          -12248.159,
          -12263.09,
          -12277.502,
          -12291.398000000001,
          -12304.777,
          -12317.641000000001,
          -12329.991000000002,
          -12341.829,
          -12353.155,
          -12363.971000000001,
          -12374.277,
          -12384.075,
          -12393.366000000002,
          -12402.15,
          -12410.428,
          -12418.203000000001,
          -12425.473,
          -12432.242,
          -12438.508,
          -12444.274,
          -12449.54,
          -12454.306999999999,
          -12458.575,
          -12462.346000000001,
          -12465.621000000001,
          -12468.399,
          -12470.681999999999,
          -12472.471000000001,
          -12473.766000000001,
          -12474.567,
          -12474.877,
          -12474.694,
          -12474.02,
          -12472.856000000002,
          -12471.202,
          -12469.058,
          -12466.426000000001,
          -12463.305,
          -12459.696000000002,
          -12455.6,
          -12451.017,
          -12445.947,
          -12440.392,
          -12434.351,
          -12427.825,
          -12420.813999999998,
          -12413.318000000001,
          -12405.339,
          -12396.876,
          -12387.93,
          -12378.501,
          -12368.589,
          -12358.194,
          -12347.318000000001,
          -12335.958,
          -12324.118,
          -12311.795,
          -12298.991000000002,
          -12285.706,
          -12271.94,
          -12257.692,
          -12242.964,
          -12227.755,
          -12212.066,
          -12195.895,
          -12179.245,
          -12162.113000000001,
          -12144.501,
          -12126.409,
          -12107.836000000001,
          -12088.782,
          -12069.248,
          -12049.233,
          -12028.738000000001,
          -12007.761,
          -11986.303,
          -11964.365,
          -11941.945,
          -11919.043,
          -11895.66,
          -11871.795,
          -11847.448999999999,
          -11822.618999999999,
          -11797.308,
          -11771.513,
          -11745.236,
          -11718.475,
          -11691.23,
          -11663.501,
          -11635.288,
          -11606.59,
          -11577.408000000001,
          -11547.739,
          -11517.585,
          -11486.944,
          -11455.817,
          -11424.202,
          -11392.098999999998,
          -11359.508,
          -11326.428,
          -11292.858,
          -11258.798999999999,
          -11224.249,
          -11189.208,
          -11153.676000000001,
          -11117.651000000002,
          -11081.133,
          -11044.121000000001,
          -11006.615,
          -10968.614,
          -10930.118,
          -10891.124,
          -10851.633999999998,
          -10811.645,
          -10771.158000000001,
          -10730.171,
          -10688.683,
          -10646.695,
          -10604.204,
          -10561.21,
          -10517.712,
          -10473.709,
          -10429.2,
          -10384.184000000001,
          -10338.661,
          -10292.628,
          -10246.086,
          -10199.033000000001,
          -10151.468,
          -10103.39,
          -10054.798,
          -10005.690999999999,
          -9956.068000000001,
          -9905.927,
          -9855.267,
          -9804.087,
          -9752.386,
          -9700.162,
          -9647.415,
          -9594.143,
          -9540.344000000001,
          -9486.018,
          -9431.162,
          -9375.777,
          -9319.86,
          -9263.409,
          -9206.424,
          -9148.903,
          -9090.844000000001,
          -9032.247,
          -8973.108,
          -8913.428,
          -8853.204,
          -8792.435,
          -8731.118,
          -8669.254,
          -8606.839,
          -8543.873,
          -8480.353000000001,
          -8416.277,
          -8351.645,
          -8286.454,
          -8220.703000000001,
          -8154.389,
          -8087.512,
          -8020.068,
          -7952.057,
          -7883.476,
          -7814.323,
          -7744.598000000001,
          -7674.297,
          -7603.419,
          -7531.960999999999,
          -7459.922,
          -7387.3,
          -7314.093000000001,
          -7240.298000000001,
          -7165.914000000001,
          -7090.939,
          -7015.371,
          -6939.206999999999,
          -6862.446,
          -6785.085,
          -6707.1230000000005,
          -6628.557,
          -6549.3859999999995,
          -6469.606,
          -6389.217,
          -6308.215,
          -6226.6,
          -6144.368,
          -6061.518,
          -5978.048000000001,
          -5893.956,
          -5809.24,
          -5723.898,
          -5637.927,
          -5551.326999999999,
          -5464.094,
          -5376.228,
          -5287.727,
          -5198.588,
          -5108.811,
          -5018.395,
          -4927.335,
          -4835.6320000000005,
          -4743.285,
          -4650.292,
          -4556.653,
          -4462.365,
          -4367.429,
          -4271.843,
          -4175.608,
          -4078.722,
          -3981.187,
          -3883.0009999999997,
          -3784.165,
          -3684.6809999999996,
          -3584.547,
          -3483.7670000000003,
          -3382.341,
          -3280.272,
          -3177.5609999999997,
          -3074.211,
          -2970.2259999999997,
          -2865.61,
          -2760.366,
          -2654.4990000000003,
          -2548.016,
          -2440.922,
          -2333.225,
          -2224.933,
          -2116.054,
          -2006.6,
          -1896.58,
          -1786.007,
          -1674.896,
          -1563.26,
          -1451.118,
          -1338.4879999999998,
          -1225.39,
          -1111.848,
          -997.8860000000001,
          -883.5319999999999,
          -768.818,
          -653.775,
          -538.442,
          -422.85900000000004,
          -307.07099999999997,
          -191.127,
          -75.082,
          41.004,
          157.066,
          273.03,
          388.81800000000004,
          504.341,
          619.503,
          734.198,
          848.307,
          961.704,
          1074.245,
          1185.776,
          1296.125,
          1405.105,
          1512.5079999999998,
          1618.11,
          1721.664,
          1822.899,
          1921.5220000000002,
          2017.213,
          2109.627,
          2198.391,
          2283.103,
          2363.337,
          2438.64,
          2508.538,
          2572.533,
          2630.119,
          2680.781,
          2724.005,
          2759.2909999999997,
          2786.1659999999997,
          2804.192,
          2812.988,
          2812.237,
          2801.7059999999997,
          2781.25,
          2750.8259999999996,
          2710.492,
          2660.414,
          2600.8520000000003,
          2532.1639999999998,
          2454.78,
          2369.198,
          2275.967,
          2175.6639999999998,
          2068.89,
          1956.245,
          1838.326,
          1715.71,
          1588.951,
          1458.575,
          1325.069,
          1188.891,
          1050.4589999999998,
          910.1560000000001,
          768.331,
          625.299,
          481.345,
          336.722,
          191.66,
          46.361999999999995,
          -98.991,
          -244.239,
          -389.23800000000006,
          -533.863,
          -678.0039999999999,
          -821.562,
          -964.452,
          -1106.599,
          -1247.937,
          -1388.41,
          -1527.967,
          -1666.566,
          -1804.17,
          -1940.7479999999998,
          -2076.2729999999997,
          -2210.721,
          -2344.075,
          -2476.319,
          -2607.44,
          -2737.429,
          -2866.277,
          -2993.978,
          -3120.53,
          -3245.929,
          -3370.1740000000004,
          -3493.268,
          -3615.21,
          -3736.0029999999997,
          -3855.652,
          -3974.159,
          -4091.53,
          -4207.77,
          -4322.884,
          -4436.88,
          -4549.764,
          -4661.543,
          -4772.224,
          -4881.815,
          -4990.323,
          -5097.755999999999,
          -5204.121,
          -5309.428000000001,
          -5413.684,
          -5516.898,
          -5619.076999999999,
          -5720.23,
          -5820.365,
          -5919.49,
          -6017.6140000000005,
          -6114.744000000001,
          -6210.889,
          -6306.058000000001,
          -6400.257,
          -6493.494000000001,
          -6585.779,
          -6677.118,
          -6767.52,
          -6856.991999999999,
          -6945.541,
          -7033.175,
          -7119.901,
          -7205.727,
          -7290.659000000001,
          -7374.706,
          -7457.874,
          -7540.169,
          -7621.599,
          -7702.170999999999,
          -7781.891,
          -7860.765,
          -7938.8009999999995,
          -8016.003000000001,
          -8092.38,
          -8167.936,
          -8242.678,
          -8316.612,
          -8389.744,
          -8462.079,
          -8533.624,
          -8604.383,
          -8674.364,
          -8743.569,
          -8812.006,
          -8879.679,
          -8946.593,
          -9012.755,
          -9078.168,
          -9142.838,
          -9206.769,
          -9269.966999999999,
          -9332.436,
          -9394.18,
          -9455.205,
          -9515.515,
          -9575.114,
          -9634.006,
          -9692.197,
          -9749.689,
          -9806.488000000001,
          -9862.596,
          -9918.02,
          -9972.761,
          -10026.825,
          -10080.214,
          -10132.933,
          -10184.985999999999,
          -10236.376,
          -10287.107,
          -10337.181999999999,
          -10386.605,
          -10435.379,
          -10483.507,
          -10530.993,
          -10577.84,
          -10624.052,
          -10669.631000000001,
          -10714.58,
          -10758.903,
          -10802.603000000001,
          -10845.681999999999,
          -10888.143999999998,
          -10929.992,
          -10971.226999999999,
          -11011.854,
          -11051.874,
          -11091.291000000001,
          -11130.107,
          -11168.323999999999,
          -11205.946000000002,
          -11242.975,
          -11279.413,
          -11315.261999999999,
          -11350.526000000002,
          -11385.207,
          -11419.306,
          -11452.826000000001,
          -11485.77,
          -11518.139,
          -11549.936000000002,
          -11581.163,
          -11611.823,
          -11641.915,
          -11671.445,
          -11700.413,
          -11728.821000000002,
          -11756.671,
          -11783.965,
          -11810.705,
          -11836.892,
          -11862.528999999999,
          -11887.618,
          -11912.159,
          -11936.156,
          -11959.608999999999,
          -11982.52,
          -12004.892,
          -12026.723999999998,
          -12048.02,
          -12068.78,
          -12089.007,
          -12108.701000000001,
          -12127.865,
          -12146.499,
          -12164.605,
          -12182.184,
          -12199.239,
          -12215.768999999998,
          -12231.777,
          -12247.264,
          -12262.231000000002,
          -12276.678999999998,
          -12290.61,
          -12304.024,
          -12316.923999999999,
          -12329.309,
          -12341.181999999999,
          -12352.543,
          -12363.393999999998,
          -12373.735,
          -12383.568000000001,
          -12392.893,
          -12401.712,
          -12410.025,
          -12417.833999999999,
          -12425.139,
          -12431.942,
          -12438.242,
          -12444.042,
          -12449.341999999999,
          -12454.143,
          -12458.446000000002,
          -12462.251,
          -12465.559,
          -12468.371000000001,
          -12470.688,
          -12472.51,
          -12473.838,
          -12474.673999999999,
          -12475.016000000001,
          -12474.867,
          -12474.226999999999,
          -12473.096000000001,
          -12471.473999999998,
          -12469.364,
          -12466.764,
          -12463.676000000001,
          -12460.1,
          -12456.037,
          -12451.486,
          -12446.45,
          -12440.927,
          -12434.918,
          -12428.425,
          -12421.446000000002,
          -12413.983,
          -12406.036,
          -12397.606000000002,
          -12388.691,
          -12379.294,
          -12369.413999999999,
          -12359.052,
          -12348.207,
          -12336.88,
          -12325.071000000002,
          -12312.78,
          -12300.008,
          -12286.753999999999,
          -12273.018999999998,
          -12258.803,
          -12244.107,
          -12228.928999999998,
          -12213.271,
          -12197.132,
          -12180.511999999999,
          -12163.412,
          -12145.831,
          -12127.77,
          -12109.228000000001,
          -12090.205,
          -12070.702,
          -12050.716999999999,
          -12030.253,
          -12009.306999999999,
          -11987.88,
          -11965.972,
          -11943.582,
          -11920.711000000001,
          -11897.358999999999,
          -11873.524,
          -11849.208,
          -11824.409,
          -11799.127,
          -11773.363000000001,
          -11747.115,
          -11720.383999999998,
          -11693.17,
          -11665.471000000001,
          -11637.288,
          -11608.62,
          -11579.466999999999,
          -11549.828000000001,
          -11519.703000000001,
          -11489.093,
          -11457.995,
          -11426.409,
          -11394.336000000001,
          -11361.774,
          -11328.723999999998,
          -11295.184,
          -11261.153999999999,
          -11226.633,
          -11191.622,
          -11156.118,
          -11120.122,
          -11083.633,
          -11046.651000000002,
          -11009.173999999999,
          -10971.202,
          -10932.733999999999,
          -10893.77,
          -10854.308,
          -10814.348,
          -10773.889,
          -10732.931,
          -10691.472,
          -10649.511999999999,
          -10607.05,
          -10564.083999999999,
          -10520.614,
          -10476.64,
          -10432.159,
          -10387.171999999999,
          -10341.677,
          -10295.673,
          -10249.159,
          -10202.134,
          -10154.597,
          -10106.546999999999,
          -10057.983,
          -10008.904,
          -9959.309000000001,
          -9909.196,
          -9858.564,
          -9807.411,
          -9755.738000000001,
          -9703.542,
          -9650.823,
          -9597.578000000001,
          -9543.806999999999,
          -9489.508,
          -9434.681,
          -9379.323,
          -9323.433,
          -9267.01,
          -9210.052,
          -9152.558,
          -9094.527,
          -9035.956,
          -8976.845,
          -8917.192,
          -8856.995,
          -8796.253,
          -8734.964,
          -8673.126,
          -8610.738000000001,
          -8547.799,
          -8484.306,
          -8420.257,
          -8355.652,
          -8290.488000000001,
          -8224.763,
          -8158.476,
          -8091.625,
          -8024.2080000000005,
          -7956.223000000001,
          -7887.669,
          -7818.543000000001,
          -7748.844,
          -7678.569,
          -7607.717,
          -7536.286,
          -7464.273,
          -7391.677,
          -7318.496,
          -7244.728,
          -7170.37,
          -7095.420999999999,
          -7019.879,
          -6943.741,
          -6867.005999999999,
          -6789.670999999999,
          -6711.734,
          -6633.194,
          -6554.048000000001,
          -6474.294,
          -6393.93,
          -6312.954000000001,
          -6231.3640000000005,
          -6149.156999999999,
          -6066.3330000000005,
          -5982.888000000001,
          -5898.821,
          -5814.13,
          -5728.812,
          -5642.866,
          -5556.29,
          -5469.0830000000005,
          -5381.241,
          -5292.764,
          -5203.65,
          -5113.898,
          -5023.504,
          -4932.469,
          -4840.79,
          -4748.465999999999,
          -4655.497,
          -4561.880999999999,
          -4467.616,
          -4372.7029999999995,
          -4277.14,
          -4180.928,
          -4084.065,
          -3986.551,
          -3888.387,
          -3789.573,
          -3690.11,
          -3589.998,
          -3489.239,
          -3387.8340000000003,
          -3285.784,
          -3183.094,
          -3079.764,
          -2975.798,
          -2871.2,
          -2765.974,
          -2660.1259999999997,
          -2553.66,
          -2446.583,
          -2338.902,
          -2230.625,
          -2121.761,
          -2012.3210000000001,
          -1902.3139999999999,
          -1791.754,
          -1680.654,
          -1569.029,
          -1456.896,
          -1344.274,
          -1231.184,
          -1117.647,
          -1003.689,
          -889.3380000000001,
          -774.6239999999999,
          -659.581,
          -544.244,
          -428.656,
          -312.86,
          -196.90599999999998,
          -80.848,
          35.254,
          151.336,
          267.324,
          383.139,
          498.694,
          613.893,
          728.63,
          842.7869999999999,
          956.238,
          1068.8410000000001,
          1180.44,
          1290.867,
          1399.933,
          1507.433,
          1613.1429999999998,
          1716.816,
          1818.184,
          1916.954,
          2012.807,
          2105.4,
          2194.361,
          2279.2889999999998,
          2359.76,
          2435.321,
          2505.5,
          2569.8,
          2627.715,
          2678.7309999999998,
          2722.333,
          2758.0209999999997,
          2785.32,
          2803.79,
          2813.0490000000004,
          2812.775,
          2802.7329999999997,
          2782.7709999999997,
          2752.843,
          2713.0029999999997,
          2663.4109999999996,
          2604.322,
          2536.09,
          2459.1420000000003,
          2373.974,
          2281.13,
          2181.188,
          2074.746,
          1962.4070000000002,
          1844.764,
          1722.398,
          1595.864,
          1465.6870000000001,
          1332.358,
          1196.335,
          1058.037,
          917.85,
          776.125,
          633.1759999999999,
          489.291,
          344.725,
          199.708,
          54.445,
          -90.884,
          -236.114,
          -381.105,
          -525.7280000000001,
          -669.873,
          -813.441,
          -956.346,
          -1098.513,
          -1239.874,
          -1380.345,
          -1519.961,
          -1658.5929999999998,
          -1796.233,
          -1932.849,
          -2068.413,
          -2202.904,
          -2336.302,
          -2468.59,
          -2599.758,
          -2729.7940000000003,
          -2858.69,
          -2986.441,
          -3113.042,
          -3238.492,
          -3362.789,
          -3485.934,
          -3607.929,
          -3728.775,
          -3848.4759999999997,
          -3967.0370000000003,
          -4084.461,
          -4200.755,
          -4315.923,
          -4429.973,
          -4542.911,
          -4654.744000000001,
          -4765.479,
          -4875.125,
          -4983.687,
          -5091.173,
          -5197.593,
          -5302.954000000001,
          -5407.264,
          -5510.531,
          -5612.764,
          -5713.97,
          -5814.158,
          -5913.3369999999995,
          -6011.514,
          -6108.696999999999,
          -6204.895,
          -6300.116,
          -6394.366999999999,
          -6487.656999999999,
          -6579.994000000001,
          -6671.385,
          -6761.838000000001,
          -6851.361999999999,
          -6939.9619999999995,
          -7027.647,
          -7114.424,
          -7200.3009999999995,
          -7285.284000000001,
          -7369.380999999999,
          -7452.599,
          -7534.944,
          -7616.424,
          -7697.045,
          -7776.814,
          -7855.738,
          -7933.821999999999,
          -8011.0740000000005,
          -8087.499,
          -8163.104,
          -8237.894,
          -8311.876,
          -8385.056,
          -8457.439,
          -8529.030999999999,
          -8599.837,
          -8669.865,
          -8739.117,
          -8807.601,
          -8875.32,
          -8942.280999999999,
          -9008.489,
          -9073.948,
          -9138.664,
          -9202.641,
          -9265.884,
          -9328.399,
          -9390.188,
          -9451.258,
          -9511.613000000001,
          -9571.257,
          -9630.193000000001,
          -9688.428,
          -9745.965,
          -9802.806999999999,
          -9858.96,
          -9914.427,
          -9969.212,
          -10023.319,
          -10076.752,
          -10129.514000000001,
          -10181.61,
          -10233.043,
          -10283.815999999999,
          -10333.934000000001,
          -10383.4,
          -10432.216,
          -10480.386,
          -10527.913999999999,
          -10574.803,
          -10621.056,
          -10666.677,
          -10711.668,
          -10756.032,
          -10799.773000000001,
          -10842.893,
          -10885.396,
          -10927.284,
          -10968.561000000002,
          -11009.228000000001,
          -11049.288999999999,
          -11088.746000000001,
          -11127.601999999999,
          -11165.858999999999,
          -11203.521,
          -11240.59,
          -11277.067,
          -11312.956,
          -11348.26,
          -11382.979,
          -11417.118,
          -11450.677,
          -11483.66,
          -11516.068000000001,
          -11547.903999999999,
          -11579.17,
          -11609.868,
          -11639.999,
          -11669.567,
          -11698.573999999999,
          -11727.018999999998,
          -11754.907,
          -11782.239,
          -11809.017,
          -11835.242,
          -11860.917,
          -11886.043,
          -11910.622,
          -11934.656,
          -11958.146,
          -11981.095,
          -12003.503,
          -12025.373,
          -12046.705,
          -12067.502,
          -12087.766000000001,
          -12107.496000000001,
          -12126.696000000002,
          -12145.367,
          -12163.508999999998,
          -12181.125,
          -12198.215,
          -12214.782,
          -12230.826000000001,
          -12246.348,
          -12261.351,
          -12275.835,
          -12289.801000000001,
          -12303.251,
          -12316.186000000002,
          -12328.607,
          -12340.515,
          -12351.911,
          -12362.796999999999,
          -12373.173,
          -12383.041000000001,
          -12392.401000000002,
          -12401.253999999999,
          -12409.601999999999,
          -12417.446000000002,
          -12424.785,
          -12431.622,
          -12437.958,
          -12443.792,
          -12449.126,
          -12453.961000000001,
          -12458.298,
          -12462.136999999999,
          -12465.479,
          -12468.325,
          -12470.675,
          -12472.531,
          -12473.893,
          -12474.761999999999,
          -12475.138,
          -12475.021999999999,
          -12474.415,
          -12473.317,
          -12471.729,
          -12469.652,
          -12467.085,
          -12464.03,
          -12460.487,
          -12456.457,
          -12451.938999999998,
          -12446.935,
          -12441.445,
          -12435.469,
          -12429.008,
          -12422.062,
          -12414.631000000001,
          -12406.716999999999,
          -12398.318000000001,
          -12389.436000000002,
          -12380.071000000002,
          -12370.223,
          -12359.893,
          -12349.08,
          -12337.785,
          -12326.007,
          -12313.748,
          -12301.008,
          -12287.786,
          -12274.083,
          -12259.898000000001,
          -12245.233,
          -12230.087,
          -12214.46,
          -12198.351999999999,
          -12181.764,
          -12164.695,
          -12147.145,
          -12129.114,
          -12110.603000000001,
          -12091.612,
          -12072.139,
          -12052.186000000002,
          -12031.752,
          -12010.837,
          -11989.44,
          -11967.563,
          -11945.205,
          -11922.365,
          -11899.042,
          -11875.238000000001,
          -11850.952,
          -11826.183,
          -11800.931999999999,
          -11775.198,
          -11748.98,
          -11722.28,
          -11695.095,
          -11667.426000000001,
          -11639.273000000001,
          -11610.635,
          -11581.511,
          -11551.902,
          -11521.806999999999,
          -11491.226,
          -11460.157,
          -11428.601,
          -11396.558,
          -11364.025,
          -11331.003999999999,
          -11297.493999999999,
          -11263.493,
          -11229.002,
          -11194.018999999998,
          -11158.545,
          -11122.578000000001,
          -11086.118999999999,
          -11049.165,
          -11011.718,
          -10973.775,
          -10935.336000000001,
          -10896.401000000002,
          -10856.968,
          -10817.037,
          -10776.607,
          -10735.677,
          -10694.247,
          -10652.315,
          -10609.881000000001,
          -10566.944,
          -10523.503,
          -10479.556999999999,
          -10435.105,
          -10390.146,
          -10344.679,
          -10298.703000000001,
          -10252.218,
          -10205.221,
          -10157.712,
          -10109.69,
          -10061.154,
          -10012.103000000001,
          -9962.535,
          -9912.45,
          -9861.846,
          -9810.721,
          -9759.076,
          -9706.908000000001,
          -9654.216999999999,
          -9601,
          -9547.256,
          -9492.985,
          -9438.185,
          -9382.854,
          -9326.992,
          -9270.596,
          -9213.666,
          -9156.2,
          -9098.196,
          -9039.653,
          -8980.569,
          -8920.943000000001,
          -8860.773000000001,
          -8800.058,
          -8738.796,
          -8676.985,
          -8614.625,
          -8551.712,
          -8488.246,
          -8424.224,
          -8359.646,
          -8294.508,
          -8228.81,
          -8162.55,
          -8095.726,
          -8028.335999999999,
          -7960.378000000001,
          -7891.851,
          -7822.751,
          -7753.078,
          -7682.83,
          -7612.004,
          -7540.599,
          -7468.611999999999,
          -7396.043000000001,
          -7322.888000000001,
          -7249.146,
          -7174.814,
          -7099.891,
          -7024.375,
          -6948.263000000001,
          -6871.553000000001,
          -6794.244000000001,
          -6716.334,
          -6637.819,
          -6558.6990000000005,
          -6478.97,
          -6398.632,
          -6317.681,
          -6236.116999999999,
          -6153.936,
          -6071.138000000001,
          -5987.718000000001,
          -5903.6759999999995,
          -5819.01,
          -5733.717,
          -5647.795999999999,
          -5561.245,
          -5474.062,
          -5386.246,
          -5297.793000000001,
          -5208.7029999999995,
          -5118.975,
          -5028.605,
          -4937.594,
          -4845.939,
          -4753.639,
          -4660.693,
          -4567.101,
          -4472.86,
          -4377.97,
          -4282.43,
          -4186.24,
          -4089.4,
          -3991.909,
          -3893.768,
          -3794.9759999999997,
          -3695.535,
          -3595.4440000000004,
          -3494.7059999999997,
          -3393.322,
          -3291.2929999999997,
          -3188.6220000000003,
          -3085.312,
          -2981.366,
          -2876.7870000000003,
          -2771.58,
          -2665.75,
          -2559.301,
          -2452.241,
          -2344.577,
          -2236.3160000000003,
          -2127.467,
          -2018.0410000000002,
          -1908.0479999999998,
          -1797.5,
          -1686.412,
          -1574.7979999999998,
          -1462.6760000000002,
          -1350.0629999999999,
          -1236.979,
          -1123.4489999999998,
          -1009.4960000000001,
          -895.148,
          -780.435,
          -665.3910000000001,
          -550.052,
          -434.458,
          -318.655,
          -202.692,
          -86.62100000000001,
          29.497,
          145.59799999999998,
          261.60900000000004,
          377.45099999999996,
          493.038,
          608.273,
          723.051,
          837.2560000000001,
          950.7610000000001,
          1063.424,
          1175.093,
          1285.596,
          1394.747,
          1502.3429999999998,
          1608.16,
          1711.9520000000002,
          1813.4520000000002,
          1912.369,
          2008.384,
          2101.155,
          2190.311,
          2275.455,
          2356.163,
          2431.982,
          2502.4410000000003,
          2567.0460000000003,
          2625.29,
          2676.659,
          2720.639,
          2756.7290000000003,
          2784.4509999999996,
          2803.368,
          2813.09,
          2813.2940000000003,
          2803.741,
          2784.276,
          2754.8459999999995,
          2715.5009999999997,
          2666.397,
          2607.784,
          2540.01,
          2463.501,
          2378.748,
          2286.2929999999997,
          2186.715,
          2080.6079999999997,
          1968.575,
          1851.2120000000002,
          1729.098,
          1602.79,
          1472.8129999999999,
          1339.662,
          1203.7939999999999,
          1065.632,
          925.562,
          783.937,
          641.073,
          497.25699999999995,
          352.74800000000005,
          207.77599999999998,
          62.547,
          -82.756,
          -227.97,
          -372.952,
          -517.5740000000001,
          -661.7230000000001,
          -805.301,
          -948.222,
          -1090.4080000000001,
          -1231.7930000000001,
          -1372.32,
          -1511.9379999999999,
          -1650.604,
          -1788.28,
          -1924.934,
          -2060.5389999999998,
          -2195.072,
          -2328.513,
          -2460.847,
          -2592.061,
          -2722.1440000000002,
          -2851.0890000000004,
          -2978.89,
          -3105.542,
          -3231.0429999999997,
          -3355.3920000000003,
          -3478.5890000000004,
          -3600.636,
          -3721.5359999999996,
          -3841.29,
          -3959.905,
          -4077.383,
          -4193.731,
          -4308.9529999999995,
          -4423.058,
          -4536.05,
          -4647.938,
          -4758.728,
          -4868.427,
          -4977.043,
          -5084.584,
          -5191.058,
          -5296.473000000001,
          -5400.8369999999995,
          -5504.158,
          -5606.444,
          -5707.704000000001,
          -5807.946,
          -5907.178000000001,
          -6005.409000000001,
          -6102.646,
          -6198.897,
          -6294.17,
          -6388.474,
          -6481.816999999999,
          -6574.205,
          -6665.648,
          -6756.153,
          -6845.728,
          -6934.379,
          -7022.116,
          -7108.944,
          -7194.871,
          -7279.905,
          -7364.052,
          -7447.32,
          -7529.717,
          -7611.246999999999,
          -7691.918000000001,
          -7771.736,
          -7850.709,
          -7928.842,
          -8006.143,
          -8082.616,
          -8158.27,
          -8233.108,
          -8307.138,
          -8380.366,
          -8452.796,
          -8524.436,
          -8595.289,
          -8665.363000000001,
          -8734.663,
          -8803.193000000001,
          -8870.96,
          -8937.966999999999,
          -9004.221,
          -9069.726,
          -9134.488000000001,
          -9198.511,
          -9261.8,
          -9324.359,
          -9386.194,
          -9447.309000000001,
          -9507.708,
          -9567.396999999999,
          -9626.378,
          -9684.657,
          -9742.238000000001,
          -9799.124,
          -9855.321,
          -9910.832,
          -9965.66,
          -10019.81,
          -10073.286,
          -10126.091999999999,
          -10178.232,
          -10229.707,
          -10280.523000000001,
          -10330.683,
          -10380.19,
          -10429.048,
          -10477.261,
          -10524.831,
          -10571.761,
          -10618.056,
          -10663.718,
          -10708.75,
          -10753.156,
          -10796.938,
          -10840.098999999998,
          -10882.643,
          -10924.572,
          -10965.889,
          -11006.596000000001,
          -11046.697,
          -11086.194,
          -11125.091,
          -11163.388,
          -11201.09,
          -11238.198999999999,
          -11274.716,
          -11310.645,
          -11345.987,
          -11380.746000000001,
          -11414.923999999999,
          -11448.521999999999,
          -11481.543,
          -11513.99,
          -11545.865,
          -11577.169,
          -11607.905,
          -11638.075,
          -11667.681,
          -11696.725,
          -11725.208999999999,
          -11753.133999999998,
          -11780.503999999999,
          -11807.319,
          -11833.582,
          -11859.294,
          -11884.458,
          -11909.073999999999,
          -11933.145,
          -11956.671999999999,
          -11979.658000000001,
          -12002.103000000001,
          -12024.01,
          -12045.378999999999,
          -12066.213,
          -12086.513,
          -12106.28,
          -12125.516000000001,
          -12144.223,
          -12162.401000000002,
          -12180.053,
          -12197.178999999998,
          -12213.782,
          -12229.861,
          -12245.42,
          -12260.458,
          -12274.976999999999,
          -12288.979,
          -12302.464,
          -12315.434,
          -12327.89,
          -12339.833,
          -12351.264,
          -12362.184,
          -12372.595,
          -12382.497,
          -12391.892,
          -12400.78,
          -12409.163,
          -12417.041000000001,
          -12424.415,
          -12431.286,
          -12437.656,
          -12443.524,
          -12448.892,
          -12453.761,
          -12458.131000000001,
          -12462.003999999999,
          -12465.38,
          -12468.258999999998,
          -12470.643,
          -12472.533000000001,
          -12473.928,
          -12474.83,
          -12475.24,
          -12475.157,
          -12474.583,
          -12473.518,
          -12471.963,
          -12469.918,
          -12467.385,
          -12464.362,
          -12460.851999999999,
          -12456.854,
          -12452.368999999999,
          -12447.396999999999,
          -12441.938999999998,
          -12435.996000000001,
          -12429.567,
          -12422.653,
          -12415.255,
          -12407.373,
          -12399.007,
          -12390.157,
          -12380.823,
          -12371.007,
          -12360.708,
          -12349.926000000001,
          -12338.663,
          -12326.917,
          -12314.688999999998,
          -12301.98,
          -12288.79,
          -12275.118,
          -12260.965,
          -12246.331,
          -12231.216,
          -12215.62,
          -12199.543,
          -12182.986,
          -12165.947,
          -12148.428,
          -12130.428999999998,
          -12111.948999999999,
          -12092.987,
          -12073.546,
          -12053.623,
          -12033.219,
          -12012.333999999999,
          -11990.969,
          -11969.122,
          -11946.794,
          -11923.983999999999,
          -11900.692,
          -11876.918,
          -11852.661,
          -11827.923,
          -11802.701000000001,
          -11776.997,
          -11750.81,
          -11724.138,
          -11696.983999999999,
          -11669.344,
          -11641.221000000001,
          -11612.612,
          -11583.518999999998,
          -11553.938999999998,
          -11523.873,
          -11493.321000000002,
          -11462.282,
          -11430.755,
          -11398.741000000002,
          -11366.238000000001,
          -11333.246000000001,
          -11299.764,
          -11265.793,
          -11231.331,
          -11196.377,
          -11160.931999999999,
          -11124.993999999999,
          -11088.563,
          -11051.638,
          -11014.219,
          -10976.305,
          -10937.895,
          -10898.988000000001,
          -10859.583999999999,
          -10819.681,
          -10779.28,
          -10738.378999999999,
          -10696.976999999999,
          -10655.073999999999,
          -10612.668,
          -10569.758999999998,
          -10526.346000000001,
          -10482.428,
          -10438.004,
          -10393.073,
          -10347.634,
          -10301.687,
          -10255.229,
          -10208.26,
          -10160.779,
          -10112.785,
          -10064.277,
          -10015.253,
          -9965.713,
          -9915.655999999999,
          -9865.079,
          -9813.982,
          -9762.364,
          -9710.224,
          -9657.56,
          -9604.37,
          -9550.654,
          -9496.411,
          -9441.638,
          -9386.335,
          -9330.499,
          -9274.131,
          -9217.228000000001,
          -9159.789,
          -9101.812,
          -9043.295,
          -8984.239,
          -8924.64,
          -8864.497,
          -8803.809000000001,
          -8742.574,
          -8680.79,
          -8618.456,
          -8555.57,
          -8492.13,
          -8428.135,
          -8363.584,
          -8298.473,
          -8232.801,
          -8166.568,
          -8099.77,
          -8032.406,
          -7964.475,
          -7895.974,
          -7826.901,
          -7757.254,
          -7687.031999999999,
          -7616.232,
          -7544.853,
          -7472.893,
          -7400.349,
          -7327.22,
          -7253.504,
          -7179.198,
          -7104.3009999999995,
          -7028.811,
          -6952.725,
          -6876.041,
          -6798.758000000001,
          -6720.871999999999,
          -6642.384,
          -6563.289000000001,
          -6483.585999999999,
          -6403.273,
          -6322.348000000001,
          -6240.809,
          -6158.653,
          -6075.88,
          -5992.485,
          -5908.468000000001,
          -5823.826999999999,
          -5738.559,
          -5652.6630000000005,
          -5566.137,
          -5478.979,
          -5391.186,
          -5302.758000000001,
          -5213.693,
          -5123.988,
          -5033.643,
          -4942.656,
          -4851.025,
          -4758.749,
          -4665.827,
          -4572.2570000000005,
          -4478.04,
          -4383.173,
          -4287.656,
          -4191.4890000000005,
          -4094.672,
          -3997.204,
          -3899.085,
          -3800.315,
          -3700.895,
          -3600.8259999999996,
          -3500.1090000000004,
          -3398.7459999999996,
          -3296.738,
          -3194.087,
          -3090.797,
          -2986.8709999999996,
          -2882.3109999999997,
          -2777.123,
          -2671.31,
          -2564.88,
          -2457.837,
          -2350.19,
          -2241.945,
          -2133.111,
          -2023.6989999999998,
          -1913.72,
          -1803.1860000000001,
          -1692.11,
          -1580.507,
          -1468.395,
          -1355.7910000000002,
          -1242.715,
          -1129.191,
          -1015.243,
          -900.8989999999999,
          -786.188,
          -671.143,
          -555.802,
          -440.205,
          -324.395,
          -208.422,
          -92.34,
          23.794,
          139.91299999999998,
          255.946,
          371.814,
          487.431,
          602.701,
          717.52,
          831.7710000000001,
          945.328,
          1058.052,
          1169.787,
          1280.365,
          1389.602,
          1497.2920000000001,
          1603.214,
          1707.1229999999998,
          1808.753,
          1907.8139999999999,
          2003.989,
          2096.936,
          2186.2870000000003,
          2271.644,
          2352.5860000000002,
          2428.66,
          2499.397,
          2564.305,
          2622.875,
          2674.595,
          2718.9509999999996,
          2755.441,
          2783.585,
          2802.945,
          2813.1290000000004,
          2813.81,
          2804.745,
          2785.776,
          2756.843,
          2717.995,
          2669.3779999999997,
          2611.241,
          2543.928,
          2467.8579999999997,
          2383.522,
          2291.459,
          2192.245,
          2086.475,
          1974.751,
          1857.668,
          1735.808,
          1609.7279999999998,
          1479.954,
          1346.9820000000002,
          1211.271,
          1073.246,
          933.294,
          791.7689999999999,
          648.99,
          505.245,
          360.79400000000004,
          215.868,
          70.67399999999999,
          -74.604,
          -219.801,
          -364.774,
          -509.394,
          -653.547,
          -797.135,
          -940.07,
          -1082.277,
          -1223.6860000000001,
          -1364.24,
          -1503.888,
          -1642.5870000000002,
          -1780.299,
          -1916.9920000000002,
          -2052.637,
          -2187.212,
          -2320.698,
          -2453.077,
          -2584.3379999999997,
          -2714.469,
          -2843.4629999999997,
          -2971.3140000000003,
          -3098.0170000000003,
          -3223.5690000000004,
          -3347.97,
          -3471.22,
          -3593.32,
          -3714.272,
          -3834.0809999999997,
          -3952.7490000000003,
          -4070.281,
          -4186.683,
          -4301.96,
          -4416.119000000001,
          -4529.166,
          -4641.109,
          -4751.9529999999995,
          -4861.707,
          -4970.377,
          -5077.973,
          -5184.502,
          -5289.971,
          -5394.389,
          -5497.764,
          -5600.105,
          -5701.419,
          -5801.715,
          -5901,
          -5999.284000000001,
          -6096.575,
          -6192.879,
          -6288.205,
          -6382.562,
          -6475.956999999999,
          -6568.398,
          -6659.893,
          -6750.45,
          -6840.076999999999,
          -6928.78,
          -7016.566999999999,
          -7103.446999999999,
          -7189.425,
          -7274.51,
          -7358.7080000000005,
          -7442.026,
          -7524.473000000001,
          -7606.053000000001,
          -7686.774,
          -7766.642,
          -7845.664000000001,
          -7923.846,
          -8001.196,
          -8077.718000000001,
          -8153.42,
          -8228.306999999999,
          -8302.385,
          -8375.661,
          -8448.139000000001,
          -8519.826,
          -8590.728000000001,
          -8660.849,
          -8730.195,
          -8798.771999999999,
          -8866.586,
          -8933.64,
          -8999.94,
          -9065.491,
          -9130.299,
          -9194.368,
          -9257.702,
          -9320.306999999999,
          -9382.187,
          -9443.347,
          -9503.791,
          -9563.524,
          -9622.55,
          -9680.874,
          -9738.499,
          -9795.429,
          -9851.67,
          -9907.224,
          -9962.096,
          -10016.29,
          -10069.81,
          -10122.658000000001,
          -10174.841,
          -10226.359,
          -10277.218,
          -10327.42,
          -10376.97,
          -10425.87,
          -10474.125,
          -10521.736,
          -10568.708999999999,
          -10615.045,
          -10660.749,
          -10705.823,
          -10750.268999999998,
          -10794.093,
          -10837.295,
          -10879.878999999999,
          -10921.848999999998,
          -10963.206,
          -11003.954,
          -11044.096000000001,
          -11083.633,
          -11122.569,
          -11160.907,
          -11198.649,
          -11235.796999999999,
          -11272.354,
          -11308.322,
          -11343.704,
          -11378.502,
          -11412.718,
          -11446.356000000002,
          -11479.416000000001,
          -11511.902,
          -11543.815,
          -11575.157,
          -11605.931999999999,
          -11636.14,
          -11665.784,
          -11694.866000000002,
          -11723.388,
          -11751.351,
          -11778.758999999998,
          -11805.612,
          -11831.912,
          -11857.662,
          -11882.862,
          -11907.516000000001,
          -11931.624,
          -11955.188,
          -11978.211000000001,
          -12000.693000000001,
          -12022.636999999999,
          -12044.043,
          -12064.913,
          -12085.249,
          -12105.053,
          -12124.325,
          -12143.068000000001,
          -12161.282,
          -12178.97,
          -12196.132,
          -12212.77,
          -12228.886,
          -12244.48,
          -12259.553,
          -12274.108,
          -12288.145,
          -12301.665,
          -12314.671,
          -12327.162,
          -12339.14,
          -12350.606000000002,
          -12361.561000000002,
          -12372.006000000001,
          -12381.943000000001,
          -12391.372,
          -12400.295,
          -12408.712,
          -12416.624,
          -12424.033000000001,
          -12430.938,
          -12437.341999999999,
          -12443.243999999999,
          -12448.646,
          -12453.548999999999,
          -12457.953000000001,
          -12461.858999999999,
          -12465.268,
          -12468.181999999999,
          -12470.598999999998,
          -12472.521999999999,
          -12473.951000000001,
          -12474.886,
          -12475.329,
          -12475.278999999999,
          -12474.738000000001,
          -12473.706,
          -12472.184,
          -12470.171999999999,
          -12467.671,
          -12464.681999999999,
          -12461.204,
          -12457.238000000001,
          -12452.786,
          -12447.847,
          -12442.421,
          -12436.51,
          -12430.113000000001,
          -12423.232,
          -12415.866000000002,
          -12408.015,
          -12399.681,
          -12390.863000000001,
          -12381.561000000002,
          -12371.777,
          -12361.508999999998,
          -12350.758999999998,
          -12339.527,
          -12327.813,
          -12315.617,
          -12302.938999999998,
          -12289.78,
          -12276.139,
          -12262.017,
          -12247.413999999999,
          -12232.33,
          -12216.766000000001,
          -12200.72,
          -12184.193000000001,
          -12167.186000000002,
          -12149.698,
          -12131.729,
          -12113.278999999999,
          -12094.348999999998,
          -12074.937,
          -12055.045,
          -12034.671999999999,
          -12013.818000000001,
          -11992.482,
          -11970.666000000001,
          -11948.368,
          -11925.588,
          -11902.326000000001,
          -11878.582,
          -11854.356000000002,
          -11829.646999999999,
          -11804.455,
          -11778.781,
          -11752.623,
          -11725.982,
          -11698.857,
          -11671.247,
          -11643.153,
          -11614.573999999999,
          -11585.51,
          -11555.96,
          -11525.923999999999,
          -11495.401000000002,
          -11464.391000000001,
          -11432.893999999998,
          -11400.908000000001,
          -11368.434,
          -11335.471000000001,
          -11302.018999999998,
          -11268.076000000001,
          -11233.643,
          -11198.719,
          -11163.302,
          -11127.393,
          -11090.991000000002,
          -11054.095,
          -11016.705,
          -10978.819,
          -10940.438,
          -10901.559,
          -10862.184,
          -10822.309,
          -10781.936000000002,
          -10741.063999999998,
          -10699.69,
          -10657.815,
          -10615.438,
          -10572.556999999999,
          -10529.171999999999,
          -10485.282,
          -10440.886999999999,
          -10395.984,
          -10350.573,
          -10304.653,
          -10258.223,
          -10211.282,
          -10163.829,
          -10115.863000000001,
          -10067.383,
          -10018.386999999999,
          -9968.874,
          -9918.844000000001,
          -9868.295,
          -9817.226,
          -9765.636,
          -9713.523000000001,
          -9660.886,
          -9607.724,
          -9554.036,
          -9499.819,
          -9445.074,
          -9389.798,
          -9333.99,
          -9277.649,
          -9220.773000000001,
          -9163.360999999999,
          -9105.411,
          -9046.921999999999,
          -8987.892,
          -8928.32,
          -8868.204,
          -8807.543,
          -8746.335,
          -8684.578000000001,
          -8622.271,
          -8559.411,
          -8495.999,
          -8432.030999999999,
          -8367.505,
          -8302.421,
          -8236.777,
          -8170.569,
          -8103.798000000001,
          -8036.460999999999,
          -7968.556,
          -7900.081,
          -7831.035,
          -7761.414000000001,
          -7691.218000000001,
          -7620.445,
          -7549.092,
          -7477.158,
          -7404.641,
          -7331.5380000000005,
          -7257.848000000001,
          -7183.568,
          -7108.696999999999,
          -7033.233,
          -6957.173000000001,
          -6880.515,
          -6803.257,
          -6725.398,
          -6646.935,
          -6567.866,
          -6488.188,
          -6407.901,
          -6327.001,
          -6245.488,
          -6163.358,
          -6080.61,
          -5997.24,
          -5913.249,
          -5828.633000000001,
          -5743.39,
          -5657.519,
          -5571.018,
          -5483.884,
          -5396.116999999999,
          -5307.714,
          -5218.673,
          -5128.9929999999995,
          -5038.6720000000005,
          -4947.709,
          -4856.102,
          -4763.85,
          -4670.952,
          -4577.407,
          -4483.213,
          -4388.369000000001,
          -4292.876,
          -4196.732,
          -4099.938,
          -4002.492,
          -3904.3959999999997,
          -3805.6490000000003,
          -3706.2509999999997,
          -3606.204,
          -3505.509,
          -3404.167,
          -3302.18,
          -3199.551,
          -3096.281,
          -2992.3740000000003,
          -2887.8340000000003,
          -2782.665,
          -2676.8720000000003,
          -2570.46,
          -2463.435,
          -2355.804,
          -2247.576,
          -2138.759,
          -2029.362,
          -1919.3970000000002,
          -1808.8770000000002,
          -1697.8129999999999,
          -1586.2220000000002,
          -1474.121,
          -1361.527,
          -1248.46,
          -1134.943,
          -1021.0010000000001,
          -906.66,
          -791.952,
          -676.908,
          -561.566,
          -445.965,
          -330.15,
          -214.168,
          -98.074,
          18.073,
          134.21,
          250.264,
          366.158,
          481.805,
          597.109,
          711.9680000000001,
          826.2639999999999,
          939.873,
          1052.655,
          1164.4569999999999,
          1275.11,
          1384.43,
          1492.214,
          1598.241,
          1702.267,
          1804.026,
          1903.231,
          1999.566,
          2092.689,
          2182.234,
          2267.805,
          2348.98,
          2425.311,
          2496.327,
          2561.538,
          2620.435,
          2672.508,
          2717.241,
          2754.133,
          2782.703,
          2802.509,
          2813.158,
          2814.32,
          2805.748,
          2787.2790000000005,
          2758.849,
          2720.5009999999997,
          2672.3779999999997,
          2614.723,
          2547.875,
          2472.25,
          2388.337,
          2296.67,
          2197.826,
          2092.3979999999997,
          1980.987,
          1864.19,
          1742.5870000000002,
          1616.737,
          1487.1689999999999,
          1354.379,
          1218.828,
          1080.941,
          941.1089999999999,
          799.687,
          656.9939999999999,
          513.321,
          368.92800000000005,
          224.049,
          78.891,
          -66.361,
          -211.542,
          -356.505,
          -501.12300000000005,
          -645.281,
          -788.8789999999999,
          -931.83,
          -1074.056,
          -1215.489,
          -1355.76,
          -1495.751,
          -1634.484,
          -1772.233,
          -1908.964,
          -2044.651,
          -2179.269,
          -2312.8,
          -2445.225,
          -2576.534,
          -2706.7140000000004,
          -2835.757,
          -2963.659,
          -3090.413,
          -3216.0170000000003,
          -3340.4709999999995,
          -3463.7740000000003,
          -3585.928,
          -3706.935,
          -3826.797,
          -3945.52,
          -4063.1079999999997,
          -4179.565,
          -4294.897,
          -4409.111,
          -4522.214,
          -4634.212,
          -4745.112,
          -4854.920999999999,
          -4963.647,
          -5071.298,
          -5177.880999999999,
          -5283.406,
          -5387.879,
          -5491.309,
          -5593.705,
          -5695.073,
          -5795.424,
          -5894.763000000001,
          -5993.102,
          -6090.446,
          -6186.804,
          -6282.184,
          -6376.594,
          -6470.0419999999995,
          -6562.536999999999,
          -6654.085,
          -6744.694,
          -6834.3730000000005,
          -6923.129,
          -7010.968000000001,
          -7097.899,
          -7183.929,
          -7269.065,
          -7353.315,
          -7436.684,
          -7519.181,
          -7600.812,
          -7681.5830000000005,
          -7761.501,
          -7840.573,
          -7918.806,
          -7996.204000000001,
          -8072.776,
          -8148.526999999999,
          -8223.463,
          -8297.59,
          -8370.914,
          -8443.440999999999,
          -8515.176,
          -8586.125,
          -8656.294,
          -8725.688,
          -8794.312,
          -8862.171999999999,
          -8929.273000000001,
          -8995.62,
          -9061.216999999999,
          -9126.071,
          -9190.186,
          -9253.567,
          -9316.216999999999,
          -9378.143,
          -9439.349,
          -9499.838,
          -9559.616,
          -9618.687,
          -9677.055,
          -9734.725,
          -9791.7,
          -9847.985,
          -9903.583,
          -9958.5,
          -10012.738000000001,
          -10066.301,
          -10119.193000000001,
          -10171.418,
          -10222.979,
          -10273.881,
          -10324.126,
          -10373.718,
          -10422.661,
          -10470.958,
          -10518.612,
          -10565.627,
          -10612.005,
          -10657.75,
          -10702.865,
          -10747.354,
          -10791.218,
          -10834.462,
          -10877.088,
          -10919.098999999998,
          -10960.497,
          -11001.286,
          -11041.468,
          -11081.045,
          -11120.021999999999,
          -11158.399,
          -11196.181,
          -11233.368999999999,
          -11269.965,
          -11305.973,
          -11341.393999999998,
          -11376.232,
          -11410.487,
          -11444.163999999999,
          -11477.263,
          -11509.788,
          -11541.74,
          -11573.121000000001,
          -11603.935,
          -11634.181999999999,
          -11663.864,
          -11692.985,
          -11721.544,
          -11749.546,
          -11776.991000000002,
          -11803.882,
          -11830.22,
          -11856.007,
          -11881.245,
          -11905.936000000002,
          -11930.082,
          -11953.683,
          -11976.743,
          -11999.261,
          -12021.241000000002,
          -12042.684,
          -12063.591,
          -12083.964,
          -12103.803999999998,
          -12123.112,
          -12141.892,
          -12160.143,
          -12177.867,
          -12195.065,
          -12211.739,
          -12227.89,
          -12243.52,
          -12258.628999999999,
          -12273.219,
          -12287.291000000001,
          -12300.847,
          -12313.888,
          -12326.413999999999,
          -12338.427,
          -12349.928,
          -12360.918,
          -12371.398000000001,
          -12381.37,
          -12390.833999999999,
          -12399.791000000001,
          -12408.242,
          -12416.188999999998,
          -12423.631000000001,
          -12430.571000000002,
          -12437.008999999998,
          -12442.945,
          -12448.381000000001,
          -12453.318000000001,
          -12457.756000000001,
          -12461.696000000002,
          -12465.139,
          -12468.086000000001,
          -12470.537,
          -12472.493,
          -12473.955,
          -12474.923999999999,
          -12475.4,
          -12475.383,
          -12474.875,
          -12473.876,
          -12472.386999999999,
          -12470.408000000001,
          -12467.94,
          -12464.983,
          -12461.538,
          -12457.605,
          -12453.185,
          -12448.278,
          -12442.885,
          -12437.006000000001,
          -12430.642,
          -12423.793,
          -12416.458999999999,
          -12408.64,
          -12400.337,
          -12391.551000000001,
          -12382.281,
          -12372.528999999999,
          -12362.293,
          -12351.575,
          -12340.374,
          -12328.691,
          -12316.527,
          -12303.88,
          -12290.752,
          -12277.143,
          -12263.052,
          -12248.48,
          -12233.427,
          -12217.893999999998,
          -12201.878999999999,
          -12185.383,
          -12168.406,
          -12150.948999999999,
          -12133.011,
          -12114.593,
          -12095.693000000001,
          -12076.312,
          -12056.451000000001,
          -12036.108,
          -12015.284,
          -11993.979,
          -11972.192,
          -11949.923999999999,
          -11927.173999999999,
          -11903.942,
          -11880.228000000001,
          -11856.032,
          -11831.353000000001,
          -11806.192,
          -11780.546999999999,
          -11754.419,
          -11727.806999999999,
          -11700.712,
          -11673.132,
          -11645.068000000001,
          -11616.518,
          -11587.483,
          -11557.963,
          -11527.956,
          -11497.463,
          -11466.483,
          -11435.015,
          -11403.058,
          -11370.614,
          -11337.68,
          -11304.256000000001,
          -11270.343,
          -11235.938,
          -11201.043,
          -11165.655,
          -11129.775,
          -11093.402,
          -11056.534,
          -11019.171999999999,
          -10981.315,
          -10942.962,
          -10904.112,
          -10864.765,
          -10824.919,
          -10784.575,
          -10743.73,
          -10702.385,
          -10660.538,
          -10618.19,
          -10575.338,
          -10531.981000000002,
          -10488.118999999999,
          -10443.752,
          -10398.877,
          -10353.494,
          -10307.601999999999,
          -10261.2,
          -10214.287,
          -10166.862,
          -10118.924,
          -10070.471,
          -10021.503,
          -9972.018,
          -9922.016,
          -9871.494,
          -9820.453000000001,
          -9768.89,
          -9716.804,
          -9664.195,
          -9611.06,
          -9557.399,
          -9503.21,
          -9448.492,
          -9393.244,
          -9337.463,
          -9281.149,
          -9224.301,
          -9166.916,
          -9108.993,
          -9050.530999999999,
          -8991.528,
          -8931.983,
          -8871.894,
          -8811.26,
          -8750.079,
          -8688.349,
          -8626.068000000001,
          -8563.235999999999,
          -8499.85,
          -8435.909,
          -8371.41,
          -8306.353000000001,
          -8240.735,
          -8174.554,
          -8107.81,
          -8040.499,
          -7972.621,
          -7904.172,
          -7835.151999999999,
          -7765.558000000001,
          -7695.389,
          -7624.642,
          -7553.316,
          -7481.408,
          -7408.9169999999995,
          -7335.84,
          -7262.1759999999995,
          -7187.923000000001,
          -7113.078,
          -7037.639,
          -6961.605,
          -6884.973000000001,
          -6807.741999999999,
          -6729.908,
          -6651.471,
          -6572.428000000001,
          -6492.776999999999,
          -6412.516,
          -6331.642,
          -6250.153,
          -6168.049,
          -6085.325,
          -6001.982,
          -5918.016,
          -5833.425,
          -5748.206999999999,
          -5662.361999999999,
          -5575.885,
          -5488.776999999999,
          -5401.035,
          -5312.656,
          -5223.64,
          -5133.985,
          -5043.689,
          -4952.75,
          -4861.168,
          -4768.941,
          -4676.067,
          -4582.545999999999,
          -4488.376,
          -4393.556,
          -4298.087,
          -4201.965999999999,
          -4105.195,
          -4007.772,
          -3909.698,
          -3810.974,
          -3711.599,
          -3611.574,
          -3510.901,
          -3409.58,
          -3307.615,
          -3205.006,
          -3101.758,
          -2997.8720000000003,
          -2893.3520000000003,
          -2788.203,
          -2682.428,
          -2576.035,
          -2469.028,
          -2361.415,
          -2253.2039999999997,
          -2144.403,
          -2035.0220000000002,
          -1925.0720000000001,
          -1814.566,
          -1703.516,
          -1591.9370000000001,
          -1479.846,
          -1367.2620000000002,
          -1254.204,
          -1140.695,
          -1026.759,
          -912.423,
          -797.7180000000001,
          -682.675,
          -567.332,
          -451.72900000000004,
          -335.908,
          -219.919,
          -103.815,
          12.345999999999998,
          128.5,
          244.575,
          360.494,
          476.16900000000004,
          591.508,
          706.4060000000001,
          820.747,
          934.4069999999999,
          1047.247,
          1159.114,
          1269.8410000000001,
          1379.244,
          1487.121,
          1593.251,
          1697.394,
          1799.283,
          1898.631,
          1995.124,
          2088.423,
          2178.1620000000003,
          2263.945,
          2345.355,
          2421.9410000000003,
          2493.236,
          2558.749,
          2617.975,
          2670.401,
          2715.512,
          2752.8059999999996,
          2781.803,
          2802.0559999999996,
          2813.171,
          2814.816,
          2806.738,
          2788.7709999999997,
          2760.848,
          2723.0029999999997,
          2675.3759999999997,
          2618.206,
          2551.827,
          2476.652,
          2393.1639999999998,
          2301.899,
          2203.427,
          2098.344,
          1987.2479999999998,
          1870.74,
          1749.3970000000002,
          1623.78,
          1494.42,
          1361.8139999999999,
          1226.424,
          1088.678,
          948.967,
          807.648,
          665.0419999999999,
          521.442,
          377.108,
          232.275,
          87.15299999999999,
          -58.073,
          -203.236,
          -348.191,
          -492.806,
          -636.969,
          -780.578,
          -923.543,
          -1065.789,
          -1207.247,
          -1347.8570000000002,
          -1487.568,
          -1626.336,
          -1764.122,
          -1900.8929999999998,
          -2036.622,
          -2171.283,
          -2304.859,
          -2437.3320000000003,
          -2568.688,
          -2698.917,
          -2828.012,
          -2955.9640000000004,
          -3082.77,
          -3208.427,
          -3332.934,
          -3456.2909999999997,
          -3578.4990000000003,
          -3699.56,
          -3819.478,
          -3938.256,
          -4055.8979999999997,
          -4172.411,
          -4287.8,
          -4402.07,
          -4515.228,
          -4627.282,
          -4738.237,
          -4848.102,
          -4956.884,
          -5064.59,
          -5171.23,
          -5276.81,
          -5381.339,
          -5484.825,
          -5587.276,
          -5688.6990000000005,
          -5789.104,
          -5888.499,
          -5986.891,
          -6084.289000000001,
          -6180.701,
          -6276.135,
          -6370.599,
          -6464.101,
          -6556.649,
          -6648.251,
          -6738.9130000000005,
          -6828.645,
          -6917.453,
          -7005.345,
          -7092.328,
          -7178.41,
          -7263.598000000001,
          -7347.898,
          -7431.319,
          -7513.866,
          -7595.548000000001,
          -7676.369000000001,
          -7756.338000000001,
          -7835.460999999999,
          -7913.743,
          -7991.191999999999,
          -8067.813,
          -8143.613,
          -8218.598,
          -8292.774,
          -8366.146999999999,
          -8438.722,
          -8510.505,
          -8581.502,
          -8651.719000000001,
          -8721.161,
          -8789.833,
          -8857.74,
          -8924.889000000001,
          -8991.282,
          -9056.927,
          -9121.827,
          -9185.988000000001,
          -9249.415,
          -9312.112,
          -9374.083,
          -9435.334,
          -9495.869,
          -9555.692,
          -9614.808,
          -9673.221,
          -9730.936,
          -9787.955,
          -9844.284,
          -9899.927,
          -9954.886999999999,
          -10009.169,
          -10062.776,
          -10115.711,
          -10167.98,
          -10219.584,
          -10270.529,
          -10320.817,
          -10370.452,
          -10419.437,
          -10467.777,
          -10515.473,
          -10562.53,
          -10608.95,
          -10654.737,
          -10699.893999999998,
          -10744.423999999999,
          -10788.33,
          -10831.615,
          -10874.282,
          -10916.333999999999,
          -10957.773000000001,
          -10998.601999999999,
          -11038.823999999999,
          -11078.443000000001,
          -11117.458999999999,
          -11155.877,
          -11193.698999999999,
          -11230.926000000001,
          -11267.562,
          -11303.61,
          -11339.071000000002,
          -11373.948,
          -11408.243,
          -11441.958,
          -11475.097,
          -11507.66,
          -11539.651000000002,
          -11571.071000000002,
          -11601.923,
          -11632.208999999999,
          -11661.928999999998,
          -11691.088,
          -11719.686000000002,
          -11747.725,
          -11775.208,
          -11802.136999999999,
          -11828.511999999999,
          -11854.337,
          -11879.613000000001,
          -11904.341,
          -11928.524,
          -11952.162,
          -11975.258,
          -11997.813999999998,
          -12019.831,
          -12041.31,
          -12062.253999999999,
          -12082.663,
          -12102.538999999999,
          -12121.883999999998,
          -12140.7,
          -12158.987,
          -12176.747,
          -12193.981000000002,
          -12210.691,
          -12226.878,
          -12242.543,
          -12257.688,
          -12272.313,
          -12286.421,
          -12300.011999999999,
          -12313.088,
          -12325.649,
          -12337.697,
          -12349.233,
          -12360.258,
          -12370.773000000001,
          -12380.778999999999,
          -12390.277,
          -12399.268999999998,
          -12407.753999999999,
          -12415.735,
          -12423.212,
          -12430.186000000002,
          -12436.658000000001,
          -12442.628999999999,
          -12448.098,
          -12453.069,
          -12457.541000000001,
          -12461.514,
          -12464.991000000002,
          -12467.971000000001,
          -12470.456,
          -12472.445,
          -12473.94,
          -12474.942,
          -12475.451000000001,
          -12475.468,
          -12474.993,
          -12474.027,
          -12472.57,
          -12470.624,
          -12468.188,
          -12465.264,
          -12461.851,
          -12457.951000000001,
          -12453.563,
          -12448.688999999998,
          -12443.328000000001,
          -12437.481000000002,
          -12431.149,
          -12424.332,
          -12417.03,
          -12409.243,
          -12400.973,
          -12392.218,
          -12382.98,
          -12373.258999999998,
          -12363.055,
          -12352.368,
          -12341.198999999999,
          -12329.546999999999,
          -12317.413999999999,
          -12304.798999999999,
          -12291.702,
          -12278.124,
          -12264.063999999998,
          -12249.523000000001,
          -12234.501,
          -12218.998,
          -12203.014,
          -12186.548999999999,
          -12169.604,
          -12152.177,
          -12134.268999999998,
          -12115.881000000001,
          -12097.011999999999,
          -12077.662,
          -12057.831,
          -12037.518,
          -12016.723999999998,
          -11995.448999999999,
          -11973.693000000001,
          -11951.455,
          -11928.735,
          -11905.533000000001,
          -11881.848999999998,
          -11857.683,
          -11833.034,
          -11807.902,
          -11782.287,
          -11756.188999999998,
          -11729.607,
          -11702.541000000001,
          -11674.99,
          -11646.955,
          -11618.435,
          -11589.43,
          -11559.938,
          -11529.961000000001,
          -11499.497,
          -11468.546,
          -11437.107,
          -11405.18,
          -11372.764,
          -11339.858999999999,
          -11306.465,
          -11272.58,
          -11238.205,
          -11203.338,
          -11167.979,
          -11132.127,
          -11095.782,
          -11058.944,
          -11021.61,
          -10983.782,
          -10945.457,
          -10906.636,
          -10867.317,
          -10827.499,
          -10787.183,
          -10746.367,
          -10705.05,
          -10663.231000000002,
          -10620.911,
          -10578.087,
          -10534.758999999998,
          -10490.925,
          -10446.585,
          -10401.738000000001,
          -10356.383,
          -10310.519,
          -10264.145,
          -10217.26,
          -10169.862,
          -10121.952,
          -10073.527,
          -10024.586,
          -9975.129,
          -9925.154,
          -9874.66,
          -9823.646,
          -9772.110999999999,
          -9720.052,
          -9667.47,
          -9614.363000000001,
          -9560.729,
          -9506.568000000001,
          -9451.877,
          -9396.655999999999,
          -9340.903,
          -9284.616,
          -9227.794,
          -9170.436,
          -9112.54,
          -9054.105,
          -8995.13,
          -8935.612,
          -8875.55,
          -8814.942,
          -8753.788,
          -8692.085,
          -8629.831,
          -8567.026,
          -8503.667,
          -8439.752,
          -8375.28,
          -8310.249,
          -8244.658000000001,
          -8178.504,
          -8111.786,
          -8044.5019999999995,
          -7976.65,
          -7908.228,
          -7839.234,
          -7769.6669999999995,
          -7699.524,
          -7628.803000000001,
          -7557.503000000001,
          -7485.621,
          -7413.156,
          -7340.106,
          -7266.468000000001,
          -7192.241,
          -7117.422,
          -7042.01,
          -6966.0019999999995,
          -6889.396,
          -6812.19,
          -6734.383000000001,
          -6655.971,
          -6576.954000000001,
          -6497.329000000001,
          -6417.093000000001,
          -6336.245,
          -6254.781999999999,
          -6172.703,
          -6090.005,
          -6006.687,
          -5922.746,
          -5838.181,
          -5752.9890000000005,
          -5667.169,
          -5580.718000000001,
          -5493.634,
          -5405.9169999999995,
          -5317.563,
          -5228.572,
          -5138.942,
          -5048.67,
          -4957.755999999999,
          -4866.1990000000005,
          -4773.996,
          -4681.147,
          -4587.649,
          -4493.503,
          -4398.708,
          -4303.262,
          -4207.165,
          -4110.417,
          -4013.018,
          -3914.967,
          -3816.265,
          -3716.913,
          -3616.91,
          -3516.259,
          -3414.961,
          -3313.0170000000003,
          -3210.43,
          -3107.202,
          -3003.337,
          -2898.8379999999997,
          -2793.708,
          -2687.953,
          -2581.5789999999997,
          -2474.591,
          -2366.996,
          -2258.802,
          -2150.0170000000003,
          -2040.6529999999998,
          -1930.7179999999998,
          -1820.226,
          -1709.1889999999999,
          -1597.624,
          -1485.545,
          -1372.971,
          -1259.922,
          -1146.421,
          -1032.492,
          -918.1610000000001,
          -803.46,
          -688.419,
          -573.076,
          -457.47,
          -341.645,
          -225.649,
          -109.53399999999999,
          6.64,
          122.81,
          238.905,
          354.847,
          470.551,
          585.923,
          700.8589999999999,
          815.2439999999999,
          928.954,
          1041.851,
          1153.782,
          1264.5819999999999,
          1374.067,
          1482.037,
          1588.27,
          1692.5279999999998,
          1794.545,
          1894.0339999999999,
          1990.685,
          2084.158,
          2174.089,
          2260.085,
          2341.726,
          2418.567,
          2490.139,
          2555.955,
          2615.507,
          2668.284,
          2713.7729999999997,
          2751.468,
          2780.89,
          2801.591,
          2813.172,
          2815.3,
          2807.717,
          2790.2529999999997,
          2762.836,
          2725.4959999999996,
          2678.367,
          2621.685,
          2555.776,
          2481.052,
          2397.992,
          2307.129,
          2209.033,
          2104.297,
          1993.52,
          1877.3010000000002,
          1756.22,
          1630.839,
          1501.6889999999999,
          1369.267,
          1234.04,
          1096.4360000000001,
          956.847,
          815.633,
          673.115,
          529.5880000000001,
          385.314,
          240.528,
          95.44200000000001,
          -49.757,
          -194.903,
          -339.848,
          -484.462,
          -628.629,
          -772.248,
          -915.2289999999999,
          -1057.495,
          -1198.9769999999999,
          -1339.616,
          -1479.359,
          -1618.161,
          -1755.984,
          -1892.795,
          -2028.566,
          -2163.271,
          -2296.8920000000003,
          -2429.4120000000003,
          -2560.817,
          -2691.095,
          -2820.241,
          -2948.244,
          -3075.1020000000003,
          -3200.813,
          -3325.373,
          -3448.784,
          -3571.047,
          -3692.163,
          -3812.136,
          -3930.969,
          -4048.6679999999997,
          -4165.237,
          -4280.682,
          -4395.008,
          -4508.222,
          -4620.331,
          -4731.343,
          -4841.264,
          -4950.102,
          -5057.865,
          -5164.56,
          -5270.196,
          -5374.781,
          -5478.321999999999,
          -5580.828,
          -5682.307,
          -5782.767,
          -5882.217,
          -5980.664000000001,
          -6078.116999999999,
          -6174.5830000000005,
          -6270.071,
          -6364.589,
          -6458.145,
          -6550.746,
          -6642.401999999999,
          -6733.116999999999,
          -6822.901999999999,
          -6911.763000000001,
          -6999.706999999999,
          -7086.743,
          -7172.876,
          -7258.116,
          -7342.468000000001,
          -7425.94,
          -7508.539000000001,
          -7590.271,
          -7671.143,
          -7751.1630000000005,
          -7830.335999999999,
          -7908.668000000001,
          -7986.1669999999995,
          -8062.838000000001,
          -8138.687,
          -8213.722,
          -8287.946,
          -8361.368,
          -8433.992,
          -8505.823,
          -8576.869,
          -8647.133,
          -8716.623,
          -8785.341999999999,
          -8853.296999999999,
          -8920.493,
          -8986.933,
          -9052.625,
          -9117.572,
          -9181.779,
          -9245.252,
          -9307.995,
          -9370.011999999999,
          -9431.309000000001,
          -9491.889000000001,
          -9551.758,
          -9610.919,
          -9669.377,
          -9727.136,
          -9784.2,
          -9840.573,
          -9896.26,
          -9951.265,
          -10005.59,
          -10059.241,
          -10112.22,
          -10164.532,
          -10216.179,
          -10267.167,
          -10317.498,
          -10367.176,
          -10416.204,
          -10464.586,
          -10512.323999999999,
          -10559.423,
          -10605.885,
          -10651.714,
          -10696.913,
          -10741.483999999999,
          -10785.431,
          -10828.758,
          -10871.466,
          -10913.559,
          -10955.038,
          -10995.908000000001,
          -11036.171,
          -11075.83,
          -11114.886999999999,
          -11153.345,
          -11191.206,
          -11228.473999999998,
          -11265.15,
          -11301.237,
          -11336.737,
          -11371.653999999999,
          -11405.988000000001,
          -11439.743,
          -11472.92,
          -11505.521999999999,
          -11537.552,
          -11569.011,
          -11599.901000000002,
          -11630.225,
          -11659.983999999999,
          -11689.181,
          -11717.817,
          -11745.893999999998,
          -11773.415,
          -11800.381000000001,
          -11826.794,
          -11852.657,
          -11877.97,
          -11902.735,
          -11926.955,
          -11950.631000000001,
          -11973.764,
          -11996.356000000002,
          -12018.41,
          -12039.926000000001,
          -12060.906,
          -12081.351999999999,
          -12101.264,
          -12120.646,
          -12139.497,
          -12157.821000000002,
          -12175.616000000002,
          -12192.886,
          -12209.632,
          -12225.854,
          -12241.555,
          -12256.735,
          -12271.396,
          -12285.538999999999,
          -12299.165,
          -12312.276000000002,
          -12324.872,
          -12336.955,
          -12348.526000000002,
          -12359.586000000001,
          -12370.135,
          -12380.176000000001,
          -12389.708999999999,
          -12398.735,
          -12407.255,
          -12415.268999999998,
          -12422.78,
          -12429.788,
          -12436.294,
          -12442.298999999999,
          -12447.803,
          -12452.806999999999,
          -12457.312,
          -12461.319,
          -12464.829,
          -12467.843,
          -12470.361,
          -12472.383,
          -12473.912,
          -12474.947,
          -12475.489,
          -12475.538,
          -12475.096000000001,
          -12474.163,
          -12472.739,
          -12470.825,
          -12468.421999999999,
          -12465.53,
          -12462.15,
          -12458.282,
          -12453.927,
          -12449.083999999999,
          -12443.756000000001,
          -12437.941,
          -12431.641000000001,
          -12424.856000000002,
          -12417.585,
          -12409.831,
          -12401.591,
          -12392.868,
          -12383.662,
          -12373.972,
          -12363.8,
          -12353.143999999998,
          -12342.007,
          -12330.386,
          -12318.284,
          -12305.7,
          -12292.635,
          -12279.087,
          -12265.059,
          -12250.548999999999,
          -12235.556999999999,
          -12220.085,
          -12204.132,
          -12187.697,
          -12170.782,
          -12153.386,
          -12135.508999999998,
          -12117.151000000002,
          -12098.313,
          -12078.993,
          -12059.191,
          -12038.909,
          -12018.146,
          -11996.901000000002,
          -11975.173999999999,
          -11952.966,
          -11930.276000000002,
          -11907.104,
          -11883.45,
          -11859.313,
          -11834.694,
          -11809.591999999999,
          -11784.006000000001,
          -11757.937,
          -11731.385,
          -11704.348,
          -11676.827,
          -11648.822,
          -11620.331,
          -11591.355,
          -11561.892,
          -11531.944,
          -11501.508999999998,
          -11470.587,
          -11439.177,
          -11407.278999999999,
          -11374.892,
          -11342.016000000001,
          -11308.65,
          -11274.794,
          -11240.448,
          -11205.608999999999,
          -11170.278999999999,
          -11134.456,
          -11098.14,
          -11061.329,
          -11024.025,
          -10986.223999999998,
          -10947.928,
          -10909.135,
          -10869.844,
          -10830.055,
          -10789.767,
          -10748.979,
          -10707.69,
          -10665.899,
          -10623.607,
          -10580.811000000002,
          -10537.511,
          -10493.705,
          -10449.393,
          -10404.574,
          -10359.246,
          -10313.41,
          -10267.064,
          -10220.206,
          -10172.837,
          -10124.953000000001,
          -10076.556,
          -10027.643,
          -9978.213,
          -9928.266,
          -9877.799,
          -9826.813,
          -9775.304,
          -9723.274,
          -9670.719000000001,
          -9617.639000000001,
          -9564.032,
          -9509.898000000001,
          -9455.235,
          -9400.04,
          -9344.314,
          -9288.054,
          -9231.26,
          -9173.929,
          -9116.06,
          -9057.652,
          -8998.703000000001,
          -8939.212,
          -8879.177,
          -8818.596,
          -8757.469000000001,
          -8695.792,
          -8633.565,
          -8570.787,
          -8507.454,
          -8443.565999999999,
          -8379.121,
          -8314.117,
          -8248.552,
          -8182.424,
          -8115.733,
          -8048.475,
          -7980.65,
          -7912.254,
          -7843.286999999999,
          -7773.746,
          -7703.629,
          -7632.935,
          -7561.661,
          -7489.806,
          -7417.366999999999,
          -7344.343000000001,
          -7270.731,
          -7196.53,
          -7121.736999999999,
          -7046.351,
          -6970.369000000001,
          -6893.789000000001,
          -6816.609,
          -6738.826999999999,
          -6660.441999999999,
          -6581.45,
          -6501.851,
          -6421.641,
          -6340.819,
          -6259.382,
          -6177.328,
          -6094.656,
          -6011.3640000000005,
          -5927.448,
          -5842.908,
          -5757.741999999999,
          -5671.946,
          -5585.523,
          -5498.465,
          -5410.772,
          -5322.444,
          -5233.478,
          -5143.872,
          -5053.626,
          -4962.736,
          -4871.2029999999995,
          -4779.024,
          -4686.1990000000005,
          -4592.726,
          -4498.604,
          -4403.833,
          -4308.412,
          -4212.339,
          -4115.615,
          -4018.239,
          -3920.211,
          -3821.532,
          -3722.203,
          -3622.223,
          -3521.595,
          -3420.3179999999998,
          -3318.3959999999997,
          -3215.8309999999997,
          -3112.6240000000003,
          -3008.7790000000005,
          -2904.301,
          -2799.192,
          -2693.4570000000003,
          -2587.1020000000003,
          -2480.132,
          -2372.556,
          -2264.379,
          -2155.612,
          -2046.264,
          -1936.345,
          -1825.868,
          -1714.845,
          -1603.293,
          -1491.226,
          -1378.6629999999998,
          -1265.625,
          -1152.132,
          -1038.21,
          -923.8860000000001,
          -809.188,
          -694.15,
          -578.808,
          -463.2,
          -347.371,
          -231.368,
          -115.244,
          0.9420000000000001,
          117.12799999999999,
          233.24200000000002,
          349.207,
          464.939,
          580.342,
          695.316,
          809.745,
          923.5039999999999,
          1036.4569999999999,
          1148.453,
          1259.3239999999998,
          1368.891,
          1476.951,
          1583.287,
          1687.658,
          1789.8020000000001,
          1889.432,
          1986.24,
          2079.887,
          2170.009,
          2256.216,
          2338.0879999999997,
          2415.183,
          2487.032,
          2553.1479999999997,
          2613.026,
          2666.156,
          2712.0209999999997,
          2750.119,
          2779.966,
          2801.114,
          2813.163,
          2815.775,
          2808.688,
          2791.7290000000003,
          2764.821,
          2727.989,
          2681.361,
          2625.1679999999997,
          2559.734,
          2485.465,
          2402.837,
          2312.379,
          2214.6620000000003,
          2110.277,
          1999.8210000000001,
          1883.896,
          1763.08,
          1637.9370000000001,
          1508.997,
          1376.764,
          1241.702,
          1104.241,
          964.7760000000001,
          823.666,
          681.238,
          537.785,
          393.57199999999995,
          248.835,
          103.786,
          -41.386,
          -186.515,
          -331.45,
          -476.06199999999995,
          -620.234,
          -763.863,
          -906.86,
          -1049.146,
          -1190.653,
          -1331.7579999999998,
          -1471.094,
          -1609.932,
          -1747.793,
          -1884.644,
          -2020.4560000000001,
          -2155.2070000000003,
          -2288.874,
          -2421.4410000000003,
          -2552.895,
          -2683.223,
          -2812.4190000000003,
          -2940.474,
          -3067.385,
          -3193.1490000000003,
          -3317.764,
          -3441.23,
          -3563.547,
          -3684.719,
          -3804.748,
          -3923.637,
          -4041.3920000000003,
          -4158.017,
          -4273.518,
          -4387.901,
          -4501.1720000000005,
          -4613.338,
          -4724.406,
          -4834.384,
          -4943.278,
          -5051.097,
          -5157.849,
          -5263.5419999999995,
          -5368.183000000001,
          -5471.78,
          -5574.342,
          -5675.876,
          -5776.392,
          -5875.897,
          -5974.399,
          -6071.906999999999,
          -6168.428000000001,
          -6263.972,
          -6358.544,
          -6452.154,
          -6544.809,
          -6636.517,
          -6727.286999999999,
          -6817.124,
          -6906.0380000000005,
          -6994.035,
          -7081.124,
          -7167.31,
          -7252.602,
          -7337.007,
          -7420.531,
          -7503.181,
          -7584.964,
          -7665.888000000001,
          -7745.9580000000005,
          -7825.181,
          -7903.563,
          -7981.111999999999,
          -8057.8330000000005,
          -8133.732,
          -8208.817,
          -8283.091,
          -8356.562,
          -8429.234,
          -8501.115,
          -8572.208,
          -8642.521,
          -8712.059000000001,
          -8780.826,
          -8848.828000000001,
          -8916.07,
          -8982.558,
          -9048.296999999999,
          -9113.291,
          -9177.546,
          -9241.065,
          -9303.854,
          -9365.917,
          -9427.26,
          -9487.886,
          -9547.8,
          -9607.006,
          -9665.509,
          -9723.313,
          -9780.421999999999,
          -9836.84,
          -9892.571,
          -9947.62,
          -10001.99,
          -10055.684000000001,
          -10108.707,
          -10161.062,
          -10212.753,
          -10263.784,
          -10314.158000000001,
          -10363.879,
          -10412.95,
          -10461.374,
          -10509.155,
          -10556.296,
          -10602.8,
          -10648.671,
          -10693.912,
          -10738.526000000002,
          -10782.515,
          -10825.882,
          -10868.631000000001,
          -10910.764,
          -10952.285,
          -10993.196000000002,
          -11033.5,
          -11073.198999999999,
          -11112.296,
          -11150.794,
          -11188.696000000002,
          -11226.003,
          -11262.719,
          -11298.846000000001,
          -11334.386,
          -11369.343,
          -11403.716,
          -11437.51,
          -11470.726999999999,
          -11503.368,
          -11535.436000000002,
          -11566.933,
          -11597.862,
          -11628.223999999998,
          -11658.021,
          -11687.256000000001,
          -11715.93,
          -11744.046,
          -11771.605,
          -11798.608999999999,
          -11825.059,
          -11850.958999999999,
          -11876.31,
          -11901.113000000001,
          -11925.37,
          -11949.083,
          -11972.253,
          -11994.883,
          -12016.973,
          -12038.526000000002,
          -12059.542,
          -12080.024,
          -12099.973,
          -12119.391000000001,
          -12138.278,
          -12156.636999999999,
          -12174.469,
          -12191.775,
          -12208.556,
          -12224.813999999998,
          -12240.551000000001,
          -12255.767,
          -12270.463,
          -12284.642,
          -12298.303,
          -12311.448999999999,
          -12324.08,
          -12336.198,
          -12347.803999999998,
          -12358.898000000001,
          -12369.482,
          -12379.558,
          -12389.125,
          -12398.185,
          -12406.739,
          -12414.788,
          -12422.333,
          -12429.375,
          -12435.915,
          -12441.953000000001,
          -12447.491000000002,
          -12452.528999999999,
          -12457.068000000001,
          -12461.108999999999,
          -12464.653,
          -12467.7,
          -12470.251,
          -12472.306999999999,
          -12473.868,
          -12474.936000000002,
          -12475.511,
          -12475.594,
          -12475.184,
          -12474.284,
          -12472.893,
          -12471.011999999999,
          -12468.641000000001,
          -12465.782,
          -12462.434,
          -12458.598999999998,
          -12454.275,
          -12449.466,
          -12444.169,
          -12438.386999999999,
          -12432.118999999999,
          -12425.365,
          -12418.126,
          -12410.403,
          -12402.196000000002,
          -12393.505,
          -12384.33,
          -12374.671999999999,
          -12364.531,
          -12353.907,
          -12342.8,
          -12331.211000000001,
          -12319.14,
          -12306.587,
          -12293.553,
          -12280.037,
          -12266.038999999999,
          -12251.56,
          -12236.6,
          -12221.159,
          -12205.236,
          -12188.833,
          -12171.948,
          -12154.582,
          -12136.736,
          -12118.408000000001,
          -12099.598999999998,
          -12080.309,
          -12060.538999999999,
          -12040.286,
          -12019.553,
          -11998.338,
          -11976.642,
          -11954.463,
          -11931.803,
          -11908.661,
          -11885.037,
          -11860.93,
          -11836.341,
          -11811.268999999998,
          -11785.713,
          -11759.673999999999,
          -11733.151000000002,
          -11706.143999999998,
          -11678.652,
          -11650.676000000001,
          -11622.214,
          -11593.267,
          -11563.833999999999,
          -11533.915,
          -11503.508999999998,
          -11472.615,
          -11441.233999999999,
          -11409.365,
          -11377.007,
          -11344.16,
          -11310.823,
          -11276.996000000001,
          -11242.678,
          -11207.868,
          -11172.567,
          -11136.773000000001,
          -11100.485,
          -11063.704,
          -11026.427,
          -10988.655,
          -10950.386999999999,
          -10911.622,
          -10872.36,
          -10832.598999999998,
          -10792.339,
          -10751.579,
          -10710.319,
          -10668.556,
          -10626.291000000001,
          -10583.523000000001,
          -10540.25,
          -10496.473,
          -10452.189,
          -10407.398000000001,
          -10362.099,
          -10316.29,
          -10269.972,
          -10223.142,
          -10175.8,
          -10127.945,
          -10079.575,
          -10030.689,
          -9981.287,
          -9931.367,
          -9880.928,
          -9829.969000000001,
          -9778.488000000001,
          -9726.485,
          -9673.957,
          -9620.904,
          -9567.325,
          -9513.218,
          -9458.582,
          -9403.415,
          -9347.716,
          -9291.483,
          -9234.716,
          -9177.412,
          -9119.57,
          -9061.189,
          -9002.268,
          -8942.803,
          -8882.795,
          -8822.242,
          -8761.141,
          -8699.491,
          -8637.291,
          -8574.539,
          -8511.233,
          -8447.372,
          -8382.954,
          -8317.976999999999,
          -8252.439,
          -8186.338000000001,
          -8119.673000000001,
          -8052.441999999999,
          -7984.643,
          -7916.274,
          -7847.3330000000005,
          -7777.818,
          -7707.728,
          -7637.06,
          -7565.813,
          -7493.984,
          -7421.571,
          -7348.5740000000005,
          -7274.988,
          -7200.813,
          -7126.047,
          -7050.688,
          -6974.732,
          -6898.178000000001,
          -6821.025,
          -6743.269,
          -6664.91,
          -6585.944,
          -6506.37,
          -6426.186,
          -6345.389,
          -6263.978,
          -6181.951,
          -6099.305,
          -6016.0380000000005,
          -5932.148,
          -5847.635,
          -5762.494000000001,
          -5676.724,
          -5590.3240000000005,
          -5503.291,
          -5415.624,
          -5327.321,
          -5238.380999999999,
          -5148.8,
          -5058.579000000001,
          -4967.714,
          -4876.206,
          -4784.052,
          -4691.252,
          -4597.803,
          -4503.706,
          -4408.959,
          -4313.562,
          -4217.514,
          -4120.813,
          -4023.461,
          -3925.4570000000003,
          -3826.802,
          -3727.4959999999996,
          -3627.539,
          -3526.933,
          -3425.679,
          -3323.78,
          -3221.236,
          -3118.051,
          -3014.228,
          -2909.77,
          -2804.6820000000002,
          -2698.967,
          -2592.632,
          -2485.6820000000002,
          -2378.124,
          -2269.966,
          -2161.216,
          -2051.885,
          -1941.9820000000002,
          -1831.52,
          -1720.5120000000002,
          -1608.973,
          -1496.9189999999999,
          -1384.368,
          -1271.34,
          -1157.857,
          -1043.943,
          -929.625,
          -814.932,
          -699.8969999999999,
          -584.556,
          -468.94699999999995,
          -353.11400000000003,
          -237.105,
          -120.973,
          -4.775,
          111.426,
          227.558,
          343.546,
          459.30400000000003,
          574.739,
          689.7489999999999,
          804.221,
          918.029,
          1031.038,
          1143.096,
          1254.04,
          1363.6860000000001,
          1471.8370000000002,
          1578.274,
          1682.759,
          1785.029,
          1884.8010000000002,
          1981.765,
          2075.585,
          2165.8979999999997,
          2252.315,
          2334.419,
          2411.768,
          2483.895,
          2550.313,
          2610.518,
          2663.9990000000003,
          2710.243,
          2748.744,
          2779.018,
          2800.616,
          2813.135,
          2816.2340000000004,
          2809.647,
          2793.196,
          2766.801,
          2730.48,
          2684.357,
          2628.659,
          2563.703,
          2489.893,
          2407.701,
          2317.653,
          2220.32,
          2116.288,
          2006.158,
          1890.529,
          1769.981,
          1645.079,
          1516.354,
          1384.31,
          1249.415,
          1112.099,
          972.7589999999999,
          831.757,
          689.419,
          546.04,
          401.88800000000003,
          257.2,
          112.189,
          -32.955999999999996,
          -178.06599999999997,
          -322.993,
          -467.602,
          -611.779,
          -755.418,
          -898.431,
          -1040.738,
          -1182.27,
          -1322.9660000000001,
          -1462.773,
          -1601.645,
          -1739.5439999999999,
          -1876.4360000000001,
          -2012.2920000000001,
          -2147.087,
          -2280.801,
          -2413.416,
          -2544.919,
          -2675.298,
          -2804.545,
          -2932.653,
          -3059.617,
          -3185.435,
          -3310.105,
          -3433.6259999999997,
          -3555.9990000000003,
          -3677.2270000000003,
          -3797.312,
          -3916.258,
          -4034.0690000000004,
          -4150.751,
          -4266.309,
          -4380.75,
          -4494.0779999999995,
          -4606.3009999999995,
          -4717.4259999999995,
          -4827.460999999999,
          -4936.413,
          -5044.289000000001,
          -5151.098,
          -5256.847,
          -5361.545,
          -5465.198,
          -5567.816999999999,
          -5669.408,
          -5769.979,
          -5869.54,
          -5968.098000000001,
          -6065.661,
          -6162.236999999999,
          -6257.835999999999,
          -6352.463000000001,
          -6446.128000000001,
          -6538.8369999999995,
          -6630.6,
          -6721.423000000001,
          -6811.314,
          -6900.281999999999,
          -6988.331999999999,
          -7075.473000000001,
          -7161.7119999999995,
          -7247.057,
          -7331.514,
          -7415.09,
          -7497.7919999999995,
          -7579.6269999999995,
          -7660.602,
          -7740.723000000001,
          -7819.996999999999,
          -7898.43,
          -7976.03,
          -8052.8009999999995,
          -8128.75,
          -8203.884,
          -8278.208,
          -8351.728000000001,
          -8424.45,
          -8496.379,
          -8567.521999999999,
          -8637.883,
          -8707.469000000001,
          -8776.284,
          -8844.334,
          -8911.624,
          -8978.159,
          -9043.945,
          -9108.987,
          -9173.288,
          -9236.853000000001,
          -9299.689,
          -9361.799,
          -9423.187,
          -9483.859,
          -9543.819,
          -9603.07,
          -9661.619,
          -9719.468,
          -9776.622,
          -9833.084,
          -9888.86,
          -9943.953000000001,
          -9998.367,
          -10052.106,
          -10105.171999999999,
          -10157.571,
          -10209.306,
          -10260.38,
          -10310.798,
          -10360.561,
          -10409.675,
          -10458.142,
          -10505.965,
          -10553.149,
          -10599.696000000002,
          -10645.608,
          -10690.891000000001,
          -10735.546999999999,
          -10779.577,
          -10822.986,
          -10865.776000000002,
          -10907.951000000001,
          -10949.513,
          -10990.464,
          -11030.809,
          -11070.548,
          -11109.686000000002,
          -11148.225,
          -11186.166000000001,
          -11223.514,
          -11260.27,
          -11296.436000000002,
          -11332.016000000001,
          -11367.011999999999,
          -11401.425,
          -11435.258,
          -11468.514,
          -11501.194,
          -11533.301000000001,
          -11564.837,
          -11595.805,
          -11626.205,
          -11656.041000000001,
          -11685.313999999998,
          -11714.026000000002,
          -11742.18,
          -11769.776000000002,
          -11796.818000000001,
          -11823.306999999999,
          -11849.243999999999,
          -11874.632,
          -11899.472,
          -11923.767,
          -11947.517,
          -11970.723999999998,
          -11993.391000000001,
          -12015.518,
          -12037.107,
          -12058.16,
          -12078.678999999998,
          -12098.663999999999,
          -12118.118,
          -12137.041000000001,
          -12155.436000000002,
          -12173.303999999998,
          -12190.646,
          -12207.463,
          -12223.756000000001,
          -12239.528,
          -12254.78,
          -12269.511999999999,
          -12283.726,
          -12297.421999999999,
          -12310.603000000001,
          -12323.268999999998,
          -12335.421999999999,
          -12347.062,
          -12358.192,
          -12368.81,
          -12378.92,
          -12388.521999999999,
          -12397.617,
          -12406.205,
          -12414.288,
          -12421.867,
          -12428.943000000001,
          -12435.517,
          -12441.589,
          -12447.16,
          -12452.232,
          -12456.805,
          -12460.878999999999,
          -12464.456,
          -12467.536,
          -12470.121000000001,
          -12472.21,
          -12473.805,
          -12474.906,
          -12475.514,
          -12475.628999999999,
          -12475.252,
          -12474.385,
          -12473.026000000002,
          -12471.178,
          -12468.84,
          -12466.013,
          -12462.697,
          -12458.893999999998,
          -12454.603000000001,
          -12449.825,
          -12444.561000000002,
          -12438.811000000002,
          -12432.573999999999,
          -12425.851999999999,
          -12418.646,
          -12410.954,
          -12402.778,
          -12394.118999999999,
          -12384.975,
          -12375.348999999998,
          -12365.239,
          -12354.646,
          -12343.571000000002,
          -12332.013,
          -12319.973,
          -12307.451000000001,
          -12294.448,
          -12280.962,
          -12266.996000000001,
          -12252.546999999999,
          -12237.618,
          -12222.208,
          -12206.316,
          -12189.943000000001,
          -12173.088,
          -12155.753,
          -12137.937,
          -12119.639,
          -12100.861,
          -12081.601,
          -12061.861,
          -12041.639,
          -12020.935,
          -11999.75,
          -11978.083999999999,
          -11955.935,
          -11933.305,
          -11910.192,
          -11886.598,
          -11862.521,
          -11837.961000000001,
          -11812.918,
          -11787.392,
          -11761.382,
          -11734.889,
          -11707.911,
          -11680.448,
          -11652.501,
          -11624.069,
          -11595.151000000002,
          -11565.747,
          -11535.857,
          -11505.48,
          -11474.615,
          -11443.263,
          -11411.423,
          -11379.093,
          -11346.275,
          -11312.966999999999,
          -11279.168,
          -11244.878999999999,
          -11210.098,
          -11174.825,
          -11139.06,
          -11102.8,
          -11066.046999999999,
          -11028.798999999999,
          -10991.055,
          -10952.815,
          -10914.079,
          -10874.845,
          -10835.112,
          -10794.88,
          -10754.148000000001,
          -10712.916000000001,
          -10671.181,
          -10628.944,
          -10586.204,
          -10542.958999999999,
          -10499.208999999999,
          -10454.953000000001,
          -10410.19,
          -10364.918,
          -10319.138,
          -10272.847,
          -10226.044,
          -10178.73,
          -10130.902,
          -10082.56,
          -10033.702,
          -9984.327,
          -9934.434000000001,
          -9884.023000000001,
          -9833.091,
          -9781.636999999999,
          -9729.661,
          -9677.161,
          -9624.135,
          -9570.583,
          -9516.503,
          -9461.894,
          -9406.755,
          -9351.082,
          -9294.877,
          -9238.136,
          -9180.859,
          -9123.045,
          -9064.690999999999,
          -9005.796,
          -8946.358,
          -8886.377,
          -8825.85,
          -8764.776,
          -8703.153,
          -8640.98,
          -8578.255,
          -8514.976,
          -8451.141,
          -8386.749,
          -8321.799,
          -8256.288,
          -8190.214,
          -8123.575,
          -8056.371,
          -7988.598000000001,
          -7920.255,
          -7851.340999999999,
          -7781.852,
          -7711.7880000000005,
          -7641.147,
          -7569.9259999999995,
          -7498.1230000000005,
          -7425.736999999999,
          -7352.766,
          -7279.206999999999,
          -7205.058000000001,
          -7130.318,
          -7054.985,
          -6979.055,
          -6902.526999999999,
          -6825.4,
          -6747.670999999999,
          -6669.3369999999995,
          -6590.398,
          -6510.85,
          -6430.691,
          -6349.920999999999,
          -6268.536,
          -6186.534000000001,
          -6103.9130000000005,
          -6020.672,
          -5936.808000000001,
          -5852.32,
          -5767.205,
          -5681.460999999999,
          -5595.0869999999995,
          -5508.079000000001,
          -5420.438,
          -5332.16,
          -5243.244000000001,
          -5153.689,
          -5063.4929999999995,
          -4972.654,
          -4881.17,
          -4789.041,
          -4696.266,
          -4602.842000000001,
          -4508.769,
          -4414.0470000000005,
          -4318.674,
          -4222.649,
          -4125.973,
          -4028.645,
          -3930.665,
          -3832.033,
          -3732.75,
          -3632.816,
          -3532.2329999999997,
          -3431.002,
          -3329.125,
          -3226.6040000000003,
          -3123.441,
          -3019.639,
          -2915.202,
          -2810.135,
          -2704.44,
          -2598.125,
          -2491.194,
          -2383.655,
          -2275.516,
          -2166.784,
          -2057.47,
          -1947.5829999999999,
          -1837.1370000000002,
          -1726.144,
          -1614.619,
          -1502.578,
          -1390.039,
          -1277.022,
          -1163.548,
          -1049.642,
          -935.331,
          -820.6439999999999,
          -705.612,
          -590.2719999999999,
          -474.662,
          -358.827,
          -242.813,
          -126.67200000000001,
          -10.463,
          105.75200000000001,
          221.90200000000002,
          337.912,
          453.69599999999997,
          569.1619999999999,
          684.2080000000001,
          798.721,
          912.577,
          1025.641,
          1137.761,
          1248.775,
          1358.501,
          1466.7420000000002,
          1573.279,
          1677.876,
          1780.271,
          1880.182,
          1977.3010000000002,
          2071.292,
          2161.795,
          2248.4210000000003,
          2330.755,
          2408.356,
          2480.758,
          2547.476,
          2608.005,
          2661.837,
          2708.4570000000003,
          2747.36,
          2778.06,
          2800.1059999999998,
          2813.093,
          2816.677,
          2810.5890000000004,
          2794.6459999999997,
          2768.763,
          2732.953,
          2687.336,
          2632.132,
          2567.656,
          2494.305,
          2412.55,
          2322.915,
          2225.965,
          2122.29,
          2012.487,
          1897.155,
          1776.8770000000002,
          1652.217,
          1523.7079999999999,
          1391.855,
          1257.128,
          1119.958,
          980.745,
          839.85,
          697.6030000000001,
          554.3,
          410.21,
          265.57099999999997,
          120.598,
          -24.52,
          -169.612,
          -314.528,
          -459.135,
          -603.316,
          -746.966,
          -889.995,
          -1032.322,
          -1173.879,
          -1314.6029999999998,
          -1454.443,
          -1593.351,
          -1731.2879999999998,
          -1868.22,
          -2004.119,
          -2138.959,
          -2272.719,
          -2405.382,
          -2536.935,
          -2667.365,
          -2796.663,
          -2924.824,
          -3051.842,
          -3177.7140000000004,
          -3302.438,
          -3426.015,
          -3548.4429999999998,
          -3669.7270000000003,
          -3789.869,
          -3908.8720000000003,
          -4026.74,
          -4143.479,
          -4259.094,
          -4373.592000000001,
          -4486.977,
          -4599.258,
          -4710.44,
          -4820.532,
          -4929.541,
          -5037.475,
          -5144.34,
          -5250.146,
          -5354.901,
          -5458.611,
          -5561.286,
          -5662.933000000001,
          -5763.561,
          -5863.178000000001,
          -5961.791,
          -6059.41,
          -6156.0419999999995,
          -6251.695,
          -6346.378000000001,
          -6440.097,
          -6532.861,
          -6624.677,
          -6715.555,
          -6805.5,
          -6894.521,
          -6982.624,
          -7069.819,
          -7156.111,
          -7241.508000000001,
          -7326.017,
          -7409.645,
          -7492.399,
          -7574.286,
          -7655.312,
          -7735.484,
          -7814.809,
          -7893.294,
          -7970.943,
          -8047.765,
          -8123.764,
          -8198.948,
          -8273.322,
          -8346.891,
          -8419.662,
          -8491.64,
          -8562.831,
          -8633.241,
          -8702.875,
          -8771.738000000001,
          -8839.836,
          -8907.174,
          -8973.757,
          -9039.59,
          -9104.678,
          -9169.026,
          -9232.639000000001,
          -9295.52,
          -9357.676,
          -9419.110999999999,
          -9479.829,
          -9539.834,
          -9599.131,
          -9657.725,
          -9715.619,
          -9772.818000000001,
          -9829.325,
          -9885.145,
          -9940.283000000001,
          -9994.741,
          -10048.524,
          -10101.634,
          -10154.077,
          -10205.855,
          -10256.972,
          -10307.433,
          -10357.239,
          -10406.396,
          -10454.905999999999,
          -10502.771999999999,
          -10549.997,
          -10596.586000000001,
          -10642.541000000001,
          -10687.866000000002,
          -10732.563,
          -10776.635,
          -10820.085,
          -10862.917,
          -10905.133,
          -10946.735,
          -10987.726999999999,
          -11028.112,
          -11067.892,
          -11107.071000000002,
          -11145.65,
          -11183.632,
          -11221.018999999998,
          -11257.815,
          -11294.021,
          -11329.64,
          -11364.675,
          -11399.127,
          -11433,
          -11466.294,
          -11499.014,
          -11531.159,
          -11562.733999999999,
          -11593.74,
          -11624.18,
          -11654.053,
          -11683.365,
          -11712.115,
          -11740.306999999999,
          -11767.941,
          -11795.021,
          -11821.546999999999,
          -11847.521999999999,
          -11872.947,
          -11897.823999999999,
          -11922.156,
          -11945.942,
          -11969.187,
          -11991.89,
          -12014.053999999998,
          -12035.68,
          -12056.77,
          -12077.325,
          -12097.347,
          -12116.837,
          -12135.796,
          -12154.226999999999,
          -12172.131000000001,
          -12189.508,
          -12206.361,
          -12222.69,
          -12238.497,
          -12253.784,
          -12268.551000000001,
          -12282.8,
          -12296.531,
          -12309.747,
          -12322.448999999999,
          -12334.636999999999,
          -12346.312,
          -12357.475,
          -12368.128999999999,
          -12378.273000000001,
          -12387.909,
          -12397.038,
          -12405.66,
          -12413.778,
          -12421.391000000001,
          -12428.501,
          -12435.108,
          -12441.213,
          -12446.818000000001,
          -12451.923,
          -12456.53,
          -12460.638,
          -12464.248,
          -12467.362,
          -12469.979,
          -12472.101999999999,
          -12473.729,
          -12474.863000000001,
          -12475.503999999999,
          -12475.652,
          -12475.308,
          -12474.473,
          -12473.146999999999,
          -12471.331,
          -12469.026000000002,
          -12466.231000000002,
          -12462.948,
          -12459.177,
          -12454.918,
          -12450.171999999999,
          -12444.94,
          -12439.221000000001,
          -12433.016000000001,
          -12426.326000000001,
          -12419.151000000002,
          -12411.491000000002,
          -12403.347,
          -12394.719,
          -12385.607,
          -12376.011,
          -12365.933,
          -12355.371000000001,
          -12344.327,
          -12332.8,
          -12320.792,
          -12308.301000000001,
          -12295.329,
          -12281.874,
          -12267.938,
          -12253.52,
          -12238.621000000001,
          -12223.241000000002,
          -12207.378999999999,
          -12191.037,
          -12174.213,
          -12156.908000000001,
          -12139.122,
          -12120.855,
          -12102.106000000002,
          -12082.877,
          -12063.166000000001,
          -12042.973999999998,
          -12022.301000000001,
          -12001.146,
          -11979.508999999998,
          -11957.391000000001,
          -11934.79,
          -11911.707,
          -11888.142,
          -11864.094,
          -11839.563999999998,
          -11814.55,
          -11789.053,
          -11763.073,
          -11736.608,
          -11709.66,
          -11682.226999999999,
          -11654.309,
          -11625.905,
          -11597.017,
          -11567.642,
          -11537.781,
          -11507.433,
          -11476.597,
          -11445.274,
          -11413.462,
          -11381.161,
          -11348.372,
          -11315.091999999999,
          -11281.322,
          -11247.061000000002,
          -11212.308,
          -11177.063,
          -11141.326000000001,
          -11105.095,
          -11068.37,
          -11031.15,
          -10993.435,
          -10955.223,
          -10916.515,
          -10877.309,
          -10837.605,
          -10797.401000000002,
          -10756.697,
          -10715.492,
          -10673.785,
          -10631.576000000001,
          -10588.864,
          -10545.646999999999,
          -10501.923999999999,
          -10457.696,
          -10412.96,
          -10367.716,
          -10321.963,
          -10275.699,
          -10228.925,
          -10181.638,
          -10133.838,
          -10085.523000000001,
          -10036.693000000001,
          -9987.345,
          -9937.48,
          -9887.096,
          -9836.190999999999,
          -9784.765,
          -9732.815999999999,
          -9680.341999999999,
          -9627.344000000001,
          -9573.819,
          -9519.766,
          -9465.184000000001,
          -9410.071,
          -9354.426,
          -9298.248,
          -9241.534,
          -9184.284,
          -9126.496,
          -9068.169,
          -9009.301,
          -8949.891,
          -8889.936,
          -8829.436,
          -8768.389000000001,
          -8706.793,
          -8644.646,
          -8581.947,
          -8518.695,
          -8454.886999999999,
          -8390.523000000001,
          -8325.598,
          -8260.113000000001,
          -8194.065999999999,
          -8127.454000000001,
          -8060.276,
          -7992.529,
          -7924.213000000001,
          -7855.325,
          -7785.863,
          -7715.826,
          -7645.21,
          -7574.016,
          -7502.24,
          -7429.88,
          -7356.936,
          -7283.403,
          -7209.28,
          -7134.566,
          -7059.258000000001,
          -6983.355,
          -6906.853,
          -6829.7519999999995,
          -6752.049,
          -6673.741,
          -6594.828,
          -6515.306,
          -6435.174,
          -6354.429,
          -6273.071,
          -6191.095,
          -6108.5,
          -6025.285,
          -5941.446999999999,
          -5856.984,
          -5771.894,
          -5686.1759999999995,
          -5599.826,
          -5512.845,
          -5425.229,
          -5336.976,
          -5248.0869999999995,
          -5158.557,
          -5068.3859999999995,
          -4977.572,
          -4886.1140000000005,
          -4794.01,
          -4701.259,
          -4607.86,
          -4513.812,
          -4419.1140000000005,
          -4323.765,
          -4227.765,
          -4131.113,
          -4033.809,
          -3935.8520000000003,
          -3837.245,
          -3737.986,
          -3638.0759999999996,
          -3537.5159999999996,
          -3436.308,
          -3334.453,
          -3231.954,
          -3128.813,
          -3025.033,
          -2920.617,
          -2815.57,
          -2709.897,
          -2603.601,
          -2496.6910000000003,
          -2389.172,
          -2281.051,
          -2172.337,
          -2063.041,
          -1953.171,
          -1842.741,
          -1731.764,
          -1620.253,
          -1508.225,
          -1395.6989999999998,
          -1282.693,
          -1169.229,
          -1055.3319999999999,
          -941.0269999999999,
          -826.345,
          -711.317,
          -595.979,
          -480.37,
          -364.532,
          -248.514,
          -132.366,
          -16.146,
          100.08200000000001,
          216.25,
          332.281,
          448.091,
          563.587,
          678.668,
          793.222,
          907.125,
          1020.242,
          1132.424,
          1243.507,
          1353.3120000000001,
          1461.641,
          1568.279,
          1672.986,
          1775.506,
          1875.556,
          1972.828,
          2066.989,
          2157.6820000000002,
          2244.516,
          2327.08,
          2404.931,
          2477.6079999999997,
          2544.625,
          2605.479,
          2659.6609999999996,
          2706.657,
          2745.962,
          2777.0890000000004,
          2799.5840000000003,
          2813.04,
          2817.111,
          2811.5229999999997,
          2796.09,
          2770.7209999999995,
          2735.426,
          2690.3179999999998,
          2635.612,
          2571.618,
          2498.732,
          2417.4179999999997,
          2328.199,
          2231.637,
          2128.32,
          2018.849,
          1903.818,
          1783.8120000000001,
          1659.3970000000002,
          1531.1070000000002,
          1399.4479999999999,
          1264.89,
          1127.868,
          988.783,
          847.9989999999999,
          705.8439999999999,
          562.619,
          418.591,
          274.002,
          129.067,
          -16.023,
          -161.096,
          -306.001,
          -450.605,
          -594.79,
          -738.45,
          -881.495,
          -1023.8430000000001,
          -1165.425,
          -1305.698,
          -1446.05,
          -1584.994,
          -1722.97,
          -1859.943,
          -1995.885,
          -2130.769,
          -2264.576,
          -2397.2889999999998,
          -2528.891,
          -2659.3720000000003,
          -2788.723,
          -2916.9359999999997,
          -3044.008,
          -3169.934,
          -3294.7140000000004,
          -3418.347,
          -3540.8320000000003,
          -3662.172,
          -3782.3709999999996,
          -3901.43,
          -4019.3559999999998,
          -4136.153,
          -4251.826,
          -4366.380999999999,
          -4479.8240000000005,
          -4592.163,
          -4703.403,
          -4813.553,
          -4922.619000000001,
          -5030.611,
          -5137.534000000001,
          -5243.397,
          -5348.209,
          -5451.976,
          -5554.7080000000005,
          -5656.411,
          -5757.096,
          -5856.769,
          -5955.439,
          -6053.1140000000005,
          -6149.8009999999995,
          -6245.51,
          -6340.246999999999,
          -6434.021,
          -6526.84,
          -6618.7119999999995,
          -6709.644,
          -6799.644,
          -6888.718000000001,
          -6976.876,
          -7064.1230000000005,
          -7150.469,
          -7235.918000000001,
          -7320.48,
          -7404.161,
          -7486.967,
          -7568.905,
          -7649.984,
          -7730.2080000000005,
          -7809.584,
          -7888.12,
          -7965.82,
          -8042.691999999999,
          -8118.741999999999,
          -8193.975,
          -8268.399,
          -8342.017,
          -8414.838,
          -8486.866,
          -8558.107,
          -8628.565,
          -8698.248,
          -8767.159,
          -8835.305,
          -8902.690999999999,
          -8969.322,
          -9035.202,
          -9100.337,
          -9164.733,
          -9228.392,
          -9291.321,
          -9353.523000000001,
          -9415.004,
          -9475.768,
          -9535.819,
          -9595.162,
          -9653.801,
          -9711.741,
          -9768.984,
          -9825.537,
          -9881.403,
          -9936.585,
          -9991.087,
          -10044.913,
          -10098.068000000001,
          -10150.554,
          -10202.376,
          -10253.537,
          -10304.041,
          -10353.891,
          -10403.09,
          -10451.643,
          -10499.552,
          -10546.821000000002,
          -10593.452,
          -10639.448999999999,
          -10684.816,
          -10729.553999999998,
          -10773.668,
          -10817.16,
          -10860.033000000001,
          -10902.29,
          -10943.933,
          -10984.966999999999,
          -11025.393,
          -11065.214,
          -11104.433,
          -11143.053,
          -11181.075,
          -11218.502,
          -11255.338,
          -11291.583999999999,
          -11327.243,
          -11362.317,
          -11396.809,
          -11430.721000000001,
          -11464.055,
          -11496.813,
          -11528.998,
          -11560.611,
          -11591.656,
          -11622.133,
          -11652.046,
          -11681.396,
          -11710.185,
          -11738.413999999999,
          -11766.086000000001,
          -11793.204,
          -11819.768,
          -11845.78,
          -11871.243,
          -11896.157,
          -11920.526000000002,
          -11944.35,
          -11967.631000000001,
          -11990.371000000001,
          -12012.572,
          -12034.233999999999,
          -12055.361,
          -12075.953000000001,
          -12096.011,
          -12115.537,
          -12134.533000000001,
          -12153,
          -12170.938999999998,
          -12188.351999999999,
          -12205.241000000002,
          -12221.606000000002,
          -12237.448,
          -12252.77,
          -12267.573,
          -12281.857,
          -12295.623,
          -12308.874,
          -12321.611,
          -12333.833999999999,
          -12345.544,
          -12356.742,
          -12367.43,
          -12377.608999999999,
          -12387.278999999999,
          -12396.442,
          -12405.098999999998,
          -12413.25,
          -12420.896999999999,
          -12428.041000000001,
          -12434.681999999999,
          -12440.822,
          -12446.445,
          -12451.583999999999,
          -12456.223,
          -12460.365,
          -12464.008999999998,
          -12467.156,
          -12469.806,
          -12471.962,
          -12473.622,
          -12474.788999999999,
          -12475.463,
          -12475.643,
          -12475.332,
          -12474.53,
          -12473.236,
          -12471.453000000001,
          -12469.18,
          -12466.417,
          -12463.166000000001,
          -12459.427,
          -12455.201000000001,
          -12450.487,
          -12445.287,
          -12439.6,
          -12433.427,
          -12426.768,
          -12419.625,
          -12411.996000000001,
          -12403.883999999998,
          -12395.287,
          -12386.206,
          -12376.642,
          -12366.595,
          -12356.063999999998,
          -12345.051000000001,
          -12333.556,
          -12321.578000000001,
          -12309.118,
          -12296.177,
          -12282.753,
          -12268.847,
          -12254.46,
          -12239.591999999999,
          -12224.242,
          -12208.411,
          -12192.098999999998,
          -12175.305,
          -12158.03,
          -12140.275,
          -12122.038,
          -12103.319,
          -12084.12,
          -12064.438999999998,
          -12044.277,
          -12023.633,
          -12002.508,
          -11980.902,
          -11958.813,
          -11936.242,
          -11913.188,
          -11889.653,
          -11865.633999999998,
          -11841.133,
          -11816.149,
          -11790.681,
          -11764.73,
          -11738.295,
          -11711.375,
          -11683.971000000001,
          -11656.082,
          -11627.708,
          -11598.848,
          -11569.503,
          -11539.669,
          -11509.351,
          -11478.544,
          -11447.249,
          -11415.466,
          -11383.194,
          -11350.433,
          -11317.181999999999,
          -11283.44,
          -11249.208,
          -11214.483,
          -11179.267,
          -11143.558,
          -11107.355,
          -11070.658000000001,
          -11033.466,
          -10995.778999999999,
          -10957.596000000001,
          -10918.916000000001,
          -10879.738000000001,
          -10840.061000000002,
          -10799.885,
          -10759.208999999999,
          -10718.032,
          -10676.354,
          -10634.171999999999,
          -10591.487,
          -10548.298,
          -10504.603000000001,
          -10460.402,
          -10415.694,
          -10370.478000000001,
          -10324.752,
          -10278.516,
          -10231.769,
          -10184.51,
          -10136.737,
          -10088.449,
          -10039.646,
          -9990.326,
          -9940.488000000001,
          -9890.131,
          -9839.253,
          -9787.854,
          -9735.931999999999,
          -9683.485999999999,
          -9630.515,
          -9577.017,
          -9522.991,
          -9468.435,
          -9413.349,
          -9357.732,
          -9301.58,
          -9244.894,
          -9187.67,
          -9129.909,
          -9071.609,
          -9012.768,
          -8953.384,
          -8893.456,
          -8832.983,
          -8771.962,
          -8710.393,
          -8648.273000000001,
          -8585.601,
          -8522.375,
          -8458.594000000001,
          -8394.256,
          -8329.358,
          -8263.899,
          -8197.878,
          -8131.293000000001,
          -8064.141,
          -7996.420999999999,
          -7928.130999999999,
          -7859.269,
          -7789.834,
          -7719.823,
          -7649.234,
          -7578.066,
          -7506.316,
          -7433.983,
          -7361.064,
          -7287.557,
          -7213.460999999999,
          -7138.773,
          -7063.491,
          -6987.6140000000005,
          -6911.139,
          -6834.063,
          -6756.3859999999995,
          -6678.105,
          -6599.217,
          -6519.721,
          -6439.615,
          -6358.897,
          -6277.564,
          -6195.6140000000005,
          -6113.045,
          -6029.855,
          -5946.043000000001,
          -5861.606,
          -5776.5419999999995,
          -5690.849,
          -5604.526,
          -5517.569,
          -5429.979,
          -5341.7519999999995,
          -5252.887,
          -5163.383,
          -5073.238,
          -4982.4490000000005,
          -4891.016,
          -4798.937,
          -4706.210999999999,
          -4612.837,
          -4518.813,
          -4424.14,
          -4328.816,
          -4232.84,
          -4136.212,
          -4038.9320000000002,
          -3941,
          -3842.4159999999997,
          -3743.18,
          -3643.2940000000003,
          -3542.757,
          -3441.572,
          -3339.74,
          -3237.263,
          -3134.145,
          -3030.386,
          -2925.993,
          -2820.967,
          -2715.3140000000003,
          -2609.0389999999998,
          -2502.1479999999997,
          -2394.649,
          -2286.547,
          -2177.8520000000003,
          -2068.573,
          -1958.72,
          -1848.307,
          -1737.345,
          -1625.849,
          -1513.835,
          -1401.3210000000001,
          -1288.326,
          -1174.873,
          -1060.985,
          -946.688,
          -832.012,
          -716.988,
          -601.653,
          -486.04400000000004,
          -370.204,
          -254.18099999999998,
          -138.026,
          -21.796999999999997,
          94.445,
          210.62900000000002,
          326.68,
          442.515,
          558.04,
          673.1560000000001,
          787.7489999999999,
          901.699,
          1014.8689999999999,
          1127.111,
          1238.263,
          1348.145,
          1456.5620000000001,
          1563.297,
          1668.114,
          1770.757,
          1870.943,
          1968.368,
          2062.698,
          2153.577,
          2240.618,
          2323.409,
          2401.509,
          2474.459,
          2541.772,
          2602.949,
          2657.4790000000003,
          2704.849,
          2744.554,
          2776.105,
          2799.048,
          2812.973,
          2817.53,
          2812.4429999999998,
          2797.5209999999997,
          2772.6679999999997,
          2737.889,
          2693.2909999999997,
          2639.086,
          2575.5789999999997,
          2503.16,
          2422.291,
          2333.492,
          2237.323,
          2134.37,
          2025.233,
          1910.5079999999998,
          1790.779,
          1666.612,
          1538.543,
          1407.0810000000001,
          1272.6960000000001,
          1135.825,
          996.87,
          856.197,
          714.137,
          570.99,
          427.027,
          282.49,
          137.594,
          -7.466,
          -152.519,
          -297.414,
          -442.014,
          -586.202,
          -729.872,
          -872.931,
          -1015.3,
          -1156.906,
          -1297.6889999999999,
          -1437.5929999999998,
          -1576.5720000000001,
          -1714.586,
          -1851.599,
          -1987.5839999999998,
          -2122.513,
          -2256.367,
          -2389.1279999999997,
          -2520.78,
          -2651.312,
          -2780.715,
          -2908.982,
          -3036.107,
          -3162.0879999999997,
          -3286.923,
          -3410.611,
          -3533.153,
          -3654.55,
          -3774.805,
          -3893.922,
          -4011.906,
          -4128.76,
          -4244.491,
          -4359.104,
          -4472.605,
          -4585.001,
          -4696.299,
          -4806.5070000000005,
          -4915.630999999999,
          -5023.68,
          -5130.662,
          -5236.582,
          -5341.451,
          -5445.276,
          -5548.064,
          -5649.825,
          -5750.566,
          -5850.295999999999,
          -5949.023,
          -6046.754,
          -6143.496999999999,
          -6239.2609999999995,
          -6334.054,
          -6427.884,
          -6520.758000000001,
          -6612.684,
          -6703.67,
          -6793.724,
          -6882.853,
          -6971.065,
          -7058.366,
          -7144.765,
          -7230.268,
          -7314.882,
          -7398.616,
          -7481.474,
          -7563.465,
          -7644.596,
          -7724.871999999999,
          -7804.3,
          -7882.8859999999995,
          -7960.638000000001,
          -8037.561,
          -8113.661,
          -8188.945,
          -8263.418,
          -8337.087,
          -8409.958,
          -8482.035,
          -8553.324,
          -8623.832,
          -8693.563,
          -8762.524,
          -8830.718,
          -8898.152,
          -8964.83,
          -9030.759,
          -9095.940999999999,
          -9160.384,
          -9224.091,
          -9287.065999999999,
          -9349.315,
          -9410.843,
          -9471.653,
          -9531.75,
          -9591.139000000001,
          -9649.824,
          -9707.809000000001,
          -9765.098,
          -9821.696,
          -9877.607,
          -9932.834,
          -9987.38,
          -10041.251,
          -10094.45,
          -10146.981,
          -10198.847,
          -10250.052,
          -10300.599,
          -10350.492,
          -10399.735,
          -10448.33,
          -10496.282,
          -10543.594,
          -10590.268,
          -10636.308,
          -10681.716,
          -10726.497,
          -10770.652,
          -10814.186000000002,
          -10857.101,
          -10899.399,
          -10941.085,
          -10982.159,
          -11022.626,
          -11062.488000000001,
          -11101.748,
          -11140.409,
          -11178.471000000001,
          -11215.938999999998,
          -11252.815,
          -11289.101,
          -11324.8,
          -11359.913999999999,
          -11394.445,
          -11428.396999999999,
          -11461.77,
          -11494.567,
          -11526.791000000001,
          -11558.444,
          -11589.528,
          -11620.043,
          -11649.995,
          -11679.383,
          -11708.21,
          -11736.478000000001,
          -11764.188999999998,
          -11791.344,
          -11817.946000000002,
          -11843.996000000001,
          -11869.496000000001,
          -11894.448,
          -11918.854,
          -11942.716,
          -11966.034,
          -11988.811000000002,
          -12011.048999999999,
          -12032.748,
          -12053.912,
          -12074.54,
          -12094.635,
          -12114.197,
          -12133.23,
          -12151.733,
          -12169.708,
          -12187.158000000001,
          -12204.082,
          -12220.483,
          -12236.361,
          -12251.719,
          -12266.556999999999,
          -12280.876,
          -12294.678,
          -12307.964,
          -12320.736,
          -12332.993999999999,
          -12344.738000000001,
          -12355.972,
          -12366.694,
          -12376.908000000001,
          -12386.613000000001,
          -12395.81,
          -12404.502,
          -12412.687,
          -12420.368999999999,
          -12427.546,
          -12434.221000000001,
          -12440.395,
          -12446.067,
          -12451.24,
          -12455.913,
          -12460.088,
          -12463.766000000001,
          -12466.946000000002,
          -12469.63,
          -12471.819,
          -12473.513,
          -12474.712,
          -12475.419,
          -12475.633,
          -12475.355,
          -12474.585,
          -12473.323999999999,
          -12471.573,
          -12469.333,
          -12466.603000000001,
          -12463.383999999998,
          -12459.678,
          -12455.483,
          -12450.802,
          -12445.633,
          -12439.978000000001,
          -12433.837,
          -12427.211000000001,
          -12420.098999999998,
          -12412.503,
          -12404.421999999999,
          -12395.856000000002,
          -12386.806999999999,
          -12377.275,
          -12367.258999999998,
          -12356.76,
          -12345.778,
          -12334.313999999998,
          -12322.367,
          -12309.938,
          -12297.028,
          -12283.635,
          -12269.76,
          -12255.403999999999,
          -12240.567,
          -12225.247,
          -12209.447,
          -12193.165,
          -12176.402,
          -12159.158000000001,
          -12141.433,
          -12123.226,
          -12104.538,
          -12085.368999999999,
          -12065.718,
          -12045.586000000001,
          -12024.972,
          -12003.877,
          -11982.301000000001,
          -11960.241000000002,
          -11937.7,
          -11914.677,
          -11891.171,
          -11867.181999999999,
          -11842.711000000001,
          -11817.756000000001,
          -11792.318000000001,
          -11766.396,
          -11739.99,
          -11713.1,
          -11685.725,
          -11657.865,
          -11629.52,
          -11600.69,
          -11571.373,
          -11541.57,
          -11511.278999999999,
          -11480.501,
          -11449.235,
          -11417.481000000002,
          -11385.238000000001,
          -11352.506000000001,
          -11319.283000000001,
          -11285.57,
          -11251.366000000002,
          -11216.671,
          -11181.483,
          -11145.802,
          -11109.627,
          -11072.958999999999,
          -11035.796,
          -10998.136999999999,
          -10959.981000000002,
          -10921.33,
          -10882.18,
          -10842.532,
          -10802.383999999998,
          -10761.736,
          -10720.587,
          -10678.936000000002,
          -10636.782,
          -10594.125,
          -10550.964,
          -10507.296999999999,
          -10463.124,
          -10418.443000000001,
          -10373.255,
          -10327.556,
          -10281.348,
          -10234.629,
          -10187.396999999999,
          -10139.652,
          -10091.392,
          -10042.616,
          -9993.323,
          -9943.513,
          -9893.183,
          -9842.333,
          -9790.961,
          -9739.065999999999,
          -9686.648000000001,
          -9633.703000000001,
          -9580.233,
          -9526.234,
          -9471.705,
          -9416.646,
          -9361.056,
          -9304.931,
          -9248.271999999999,
          -9191.076,
          -9133.341999999999,
          -9075.068000000001,
          -9016.254,
          -8956.896999999999,
          -8896.997,
          -8836.55,
          -8775.556999999999,
          -8714.014000000001,
          -8651.921,
          -8589.275,
          -8526.076,
          -8462.322,
          -8398.01,
          -8333.139000000001,
          -8267.707,
          -8201.713,
          -8135.154,
          -8068.029,
          -8000.335,
          -7932.071999999999,
          -7863.236999999999,
          -7793.828,
          -7723.843000000001,
          -7653.281,
          -7582.139,
          -7510.415,
          -7438.109,
          -7365.215999999999,
          -7291.736,
          -7217.666,
          -7143.004,
          -7067.749,
          -6991.898,
          -6915.4490000000005,
          -6838.4,
          -6760.749,
          -6682.493,
          -6603.632,
          -6524.161999999999,
          -6444.0830000000005,
          -6363.39,
          -6282.0830000000005,
          -6200.158,
          -6117.616,
          -6034.451999999999,
          -5950.665,
          -5866.254,
          -5781.215999999999,
          -5695.549,
          -5609.251,
          -5522.321,
          -5434.755999999999,
          -5346.555,
          -5257.715999999999,
          -5168.237,
          -5078.116,
          -4987.353,
          -4895.945,
          -4803.891,
          -4711.19,
          -4617.840999999999,
          -4523.842000000001,
          -4429.194,
          -4333.894,
          -4237.943,
          -4141.34,
          -4044.0840000000003,
          -3946.176,
          -3847.615,
          -3748.403,
          -3648.54,
          -3548.027,
          -3446.865,
          -3345.0559999999996,
          -3242.6020000000003,
          -3139.505,
          -3035.77,
          -2931.3979999999997,
          -2826.393,
          -2720.761,
          -2614.507,
          -2507.636,
          -2400.155,
          -2292.072,
          -2183.395,
          -2074.134,
          -1964.299,
          -1853.902,
          -1742.9560000000001,
          -1631.475,
          -1519.475,
          -1406.974,
          -1293.991,
          -1180.548,
          -1066.6689999999999,
          -952.38,
          -837.71,
          -722.69,
          -607.357,
          -491.74800000000005,
          -375.907,
          -259.879,
          -143.718,
          -27.478,
          88.77600000000001,
          204.977,
          321.04900000000004,
          436.908,
          552.462,
          667.612,
          782.2460000000001,
          896.2410000000001,
          1009.4639999999999,
          1121.767,
          1232.988,
          1342.9479999999999,
          1451.4520000000002,
          1558.2839999999999,
          1663.2120000000002,
          1765.9779999999998,
          1866.3010000000002,
          1963.878,
          2058.3779999999997,
          2149.4429999999998,
          2236.6910000000003,
          2319.708,
          2398.06,
          2471.282,
          2538.893,
          2600.3920000000003,
          2655.272,
          2703.0170000000003,
          2743.1209999999996,
          2775.098,
          2798.49,
          2812.885,
          2817.93,
          2813.345,
          2798.935,
          2774.598,
          2740.335,
          2696.25,
          2642.548,
          2579.528,
          2507.577,
          2427.155,
          2338.777,
          2243.002,
          2140.415,
          2031.614,
          1917.195,
          1797.744,
          1673.8270000000002,
          1545.9820000000002,
          1414.717,
          1280.507,
          1143.788,
          1004.965,
          864.404,
          722.44,
          579.373,
          435.475,
          290.99,
          146.135,
          1.105,
          -143.928,
          -288.81,
          -433.407,
          -577.597,
          -721.2760000000001,
          -864.3510000000001,
          -1006.7389999999999,
          -1148.369,
          -1289.18,
          -1429.116,
          -1568.13,
          -1706.182,
          -1843.237,
          -1979.264,
          -2114.239,
          -2248.14,
          -2380.948,
          -2512.65,
          -2643.2329999999997,
          -2772.688,
          -2901.008,
          -3028.188,
          -3154.224,
          -3279.114,
          -3402.8579999999997,
          -3525.455,
          -3646.909,
          -3767.222,
          -3886.397,
          -4004.438,
          -4121.35,
          -4237.138,
          -4351.809,
          -4465.3679999999995,
          -4577.823,
          -4689.18,
          -4799.446,
          -4908.628,
          -5016.735,
          -5123.773,
          -5229.752,
          -5334.678000000001,
          -5438.561,
          -5541.406999999999,
          -5643.225,
          -5744.023,
          -5843.809,
          -5942.590999999999,
          -6040.378000000001,
          -6137.178000000001,
          -6232.999,
          -6327.848000000001,
          -6421.733,
          -6514.661999999999,
          -6606.643,
          -6697.684,
          -6787.7919999999995,
          -6876.976,
          -6965.241999999999,
          -7052.597,
          -7139.049,
          -7224.606,
          -7309.274,
          -7393.06,
          -7475.971,
          -7558.014,
          -7639.196,
          -7719.524,
          -7799.004,
          -7877.642,
          -7955.445,
          -8032.419,
          -8108.57,
          -8183.905,
          -8258.428,
          -8332.146999999999,
          -8405.068000000001,
          -8477.195,
          -8548.534,
          -8619.09,
          -8688.871,
          -8757.88,
          -8826.123,
          -8893.605,
          -8960.331,
          -9026.308,
          -9091.539,
          -9156.028,
          -9219.782,
          -9282.805,
          -9345.101,
          -9406.675,
          -9467.530999999999,
          -9527.675,
          -9587.11,
          -9645.841,
          -9703.871,
          -9761.207,
          -9817.85,
          -9873.805,
          -9929.077,
          -9983.668,
          -10037.584,
          -10090.827,
          -10143.402,
          -10195.312,
          -10246.56,
          -10297.152,
          -10347.089,
          -10396.375,
          -10445.014000000001,
          -10493.008999999998,
          -10540.363000000001,
          -10587.079,
          -10633.161,
          -10678.612,
          -10723.435,
          -10767.633,
          -10811.208999999999,
          -10854.165,
          -10896.506000000001,
          -10938.233,
          -10979.348999999998,
          -11019.857,
          -11059.76,
          -11099.06,
          -11137.761,
          -11175.864,
          -11213.372,
          -11250.288,
          -11286.615,
          -11322.353000000001,
          -11357.507,
          -11392.079,
          -11426.07,
          -11459.483,
          -11492.32,
          -11524.583,
          -11556.275,
          -11587.396999999999,
          -11617.952,
          -11647.942,
          -11677.368,
          -11706.233999999999,
          -11734.54,
          -11762.288999999999,
          -11789.483,
          -11816.123,
          -11842.211000000001,
          -11867.749,
          -11892.739,
          -11917.181999999999,
          -11941.081,
          -11964.437,
          -11987.251,
          -12009.525,
          -12031.261999999999,
          -12052.462,
          -12073.126,
          -12093.257,
          -12112.857,
          -12131.925,
          -12150.465,
          -12168.476999999999,
          -12185.963,
          -12202.923,
          -12219.358999999999,
          -12235.274,
          -12250.667,
          -12265.54,
          -12279.895,
          -12293.733,
          -12307.053999999998,
          -12319.86,
          -12332.153,
          -12343.933,
          -12355.202,
          -12365.958999999999,
          -12376.207,
          -12385.947,
          -12395.178999999998,
          -12403.905,
          -12412.125,
          -12419.84,
          -12427.052,
          -12433.761,
          -12439.969,
          -12445.675,
          -12450.881000000001,
          -12455.588,
          -12459.796999999999,
          -12463.508,
          -12466.722,
          -12469.438999999998,
          -12471.661,
          -12473.388,
          -12474.621000000001,
          -12475.361,
          -12475.608,
          -12475.363000000001,
          -12474.626,
          -12473.398000000001,
          -12471.678999999998,
          -12469.471000000001,
          -12466.774,
          -12463.588,
          -12459.913999999999,
          -12455.752,
          -12451.101999999999,
          -12445.966,
          -12440.343,
          -12434.233999999999,
          -12427.64,
          -12420.56,
          -12412.995,
          -12404.946000000002,
          -12396.412,
          -12387.395,
          -12377.893,
          -12367.909,
          -12357.441,
          -12346.491000000002,
          -12335.058,
          -12323.143,
          -12310.745,
          -12297.865,
          -12284.503,
          -12270.659,
          -12256.333999999999,
          -12241.527,
          -12226.239,
          -12210.469,
          -12194.218,
          -12177.485,
          -12160.271,
          -12142.576000000001,
          -12124.4,
          -12105.743,
          -12086.604,
          -12066.983999999999,
          -12046.882,
          -12026.298,
          -12005.233,
          -11983.685,
          -11961.656,
          -11939.145,
          -11916.151000000002,
          -11892.675,
          -11868.716,
          -11844.274,
          -11819.348999999998,
          -11793.94,
          -11768.046999999999,
          -11741.671,
          -11714.811000000002,
          -11687.466,
          -11659.635,
          -11631.319,
          -11602.517,
          -11573.229,
          -11543.455,
          -11513.193000000001,
          -11482.444,
          -11451.207,
          -11419.482,
          -11387.267,
          -11354.563,
          -11321.37,
          -11287.686000000002,
          -11253.511,
          -11218.844,
          -11183.684,
          -11148.032,
          -11111.886,
          -11075.246000000001,
          -11038.111,
          -11000.48,
          -10962.353000000001,
          -10923.729,
          -10884.607,
          -10844.987,
          -10804.867,
          -10764.247,
          -10723.126,
          -10681.503,
          -10639.378,
          -10596.749,
          -10553.616000000002,
          -10509.976999999999,
          -10465.831,
          -10421.178,
          -10376.017,
          -10330.347,
          -10284.166,
          -10237.474,
          -10190.27,
          -10142.552,
          -10094.319,
          -10045.571,
          -9996.306,
          -9946.523000000001,
          -9896.221,
          -9845.398000000001,
          -9794.053,
          -9742.186,
          -9689.794,
          -9636.877,
          -9583.434000000001,
          -9529.462,
          -9474.961,
          -9419.929,
          -9364.365,
          -9308.267,
          -9251.635,
          -9194.466,
          -9136.759,
          -9078.511999999999,
          -9019.725,
          -8960.395,
          -8900.521,
          -8840.101,
          -8779.134,
          -8717.618,
          -8655.552,
          -8592.933,
          -8529.761,
          -8466.033000000001,
          -8401.747,
          -8336.903,
          -8271.498,
          -8205.53,
          -8138.9980000000005,
          -8071.899,
          -8004.232,
          -7935.996,
          -7867.187,
          -7797.804,
          -7727.846,
          -7657.31,
          -7586.195,
          -7514.496999999999,
          -7442.217,
          -7369.351,
          -7295.897,
          -7221.854,
          -7147.218000000001,
          -7071.9890000000005,
          -6996.164000000001,
          -6919.741,
          -6842.718000000001,
          -6765.093000000001,
          -6686.8640000000005,
          -6608.029,
          -6528.585999999999,
          -6448.531999999999,
          -6367.865,
          -6286.584,
          -6204.686,
          -6122.169,
          -6039.031,
          -5955.271,
          -5870.885,
          -5785.8730000000005,
          -5700.231,
          -5613.959,
          -5527.054,
          -5439.515,
          -5351.34,
          -5262.526,
          -5173.073,
          -5082.978,
          -4992.2390000000005,
          -4900.857,
          -4808.8279999999995,
          -4716.152,
          -4622.8279999999995,
          -4528.854,
          -4434.231,
          -4338.956,
          -4243.03,
          -4146.45,
          -4049.219,
          -3951.335,
          -3852.798,
          -3753.61,
          -3653.77,
          -3553.28,
          -3452.1420000000003,
          -3350.3559999999998,
          -3247.9240000000004,
          -3144.85,
          -3041.137,
          -2936.7859999999996,
          -2831.803,
          -2726.192,
          -2619.959,
          -2513.1079999999997,
          -2405.647,
          -2297.583,
          -2188.925,
          -2079.6820000000002,
          -1969.864,
          -1859.483,
          -1748.5529999999999,
          -1637.0870000000002,
          -1525.101,
          -1412.6129999999998,
          -1299.642,
          -1186.2089999999998,
          -1072.34,
          -958.059,
          -843.395,
          -728.38,
          -613.05,
          -497.44199999999995,
          -381.599,
          -265.568,
          -149.399,
          -33.15,
          83.117,
          199.334,
          315.425,
          431.30800000000005,
          546.8919999999999,
          662.076,
          776.7489999999999,
          890.79,
          1004.065,
          1116.427,
          1227.7160000000001,
          1337.753,
          1446.3429999999998,
          1553.274,
          1658.31,
          1761.1979999999999,
          1861.658,
          1959.386,
          2054.054,
          2145.306,
          2232.759,
          2316.0029999999997,
          2394.6020000000003,
          2468.097,
          2536.004,
          2597.826,
          2653.053,
          2701.172,
          2741.677,
          2774.078,
          2797.9179999999997,
          2812.783,
          2818.316,
          2814.232,
          2800.335,
          2776.5159999999996,
          2742.772,
          2699.2,
          2646.0029999999997,
          2583.473,
          2511.993,
          2432.02,
          2344.065,
          2248.687,
          2146.469,
          2038.006,
          1923.8970000000002,
          1804.727,
          1681.0620000000001,
          1553.443,
          1422.378,
          1288.345,
          1151.78,
          1013.09,
          872.6439999999999,
          730.7760000000001,
          587.79,
          443.959,
          299.528,
          154.715,
          9.716000000000001,
          -135.296,
          -280.166,
          -424.75800000000004,
          -568.951,
          -712.6389999999999,
          -855.727,
          -998.135,
          -1139.79,
          -1280.362,
          -1420.596,
          -1559.646,
          -1697.735,
          -1834.8310000000001,
          -1970.901,
          -2105.92,
          -2239.868,
          -2372.725,
          -2504.4770000000003,
          -2635.111,
          -2764.618,
          -2892.991,
          -3020.225,
          -3146.316,
          -3271.262,
          -3395.0609999999997,
          -3517.716,
          -3639.2270000000003,
          -3759.597,
          -3878.829,
          -3996.928,
          -4113.898,
          -4229.745,
          -4344.474,
          -4458.090999999999,
          -4570.604,
          -4682.019,
          -4792.343,
          -4901.584,
          -5009.749,
          -5116.845,
          -5222.8820000000005,
          -5327.866,
          -5431.806,
          -5534.71,
          -5636.585,
          -5737.44,
          -5837.284000000001,
          -5936.1230000000005,
          -6033.967,
          -6130.823,
          -6226.6990000000005,
          -6321.604,
          -6415.545,
          -6508.53,
          -6600.566,
          -6691.661999999999,
          -6781.825,
          -6871.063,
          -6959.384,
          -7046.793000000001,
          -7133.299,
          -7218.909000000001,
          -7303.63,
          -7387.47,
          -7470.434,
          -7552.53,
          -7633.764,
          -7714.144,
          -7793.677,
          -7872.366,
          -7950.221,
          -8027.246,
          -8103.448,
          -8178.8330000000005,
          -8253.407,
          -8327.176,
          -8400.146999999999,
          -8472.324,
          -8543.712,
          -8614.318000000001,
          -8684.148000000001,
          -8753.206,
          -8821.497,
          -8889.028,
          -8955.803,
          -9021.827,
          -9087.106,
          -9151.644,
          -9215.445,
          -9278.515,
          -9340.858,
          -9402.479,
          -9463.382,
          -9523.572,
          -9583.053,
          -9641.83,
          -9699.907,
          -9757.288,
          -9813.976999999999,
          -9869.976999999999,
          -9925.294,
          -9979.93,
          -10033.891,
          -10087.178,
          -10139.798,
          -10191.752,
          -10243.045,
          -10293.679,
          -10343.661,
          -10392.991,
          -10441.673,
          -10489.711000000001,
          -10537.108,
          -10583.867,
          -10629.992,
          -10675.485,
          -10720.351,
          -10764.59,
          -10808.208,
          -10851.207,
          -10893.589,
          -10935.358,
          -10976.515,
          -11017.065,
          -11057.008999999998,
          -11096.35,
          -11135.091,
          -11173.235,
          -11210.784,
          -11247.741000000002,
          -11284.107,
          -11319.886,
          -11355.08,
          -11389.692,
          -11423.723,
          -11457.175,
          -11490.052,
          -11522.354,
          -11554.085,
          -11585.247,
          -11615.841,
          -11645.868999999999,
          -11675.333999999999,
          -11704.238000000001,
          -11732.583,
          -11760.37,
          -11787.601999999999,
          -11814.28,
          -11840.406,
          -11865.982,
          -11891.01,
          -11915.491000000002,
          -11939.427,
          -11962.82,
          -11985.671999999999,
          -12007.983,
          -12029.757,
          -12050.993999999999,
          -12071.695,
          -12091.863000000001,
          -12111.499,
          -12130.604,
          -12149.18,
          -12167.229,
          -12184.75,
          -12201.747,
          -12218.219,
          -12234.169,
          -12249.598,
          -12264.507,
          -12278.898000000001,
          -12292.771,
          -12306.128,
          -12318.969,
          -12331.296999999999,
          -12343.112,
          -12354.415,
          -12365.208,
          -12375.491000000002,
          -12385.265,
          -12394.532,
          -12403.292,
          -12411.546999999999,
          -12419.296,
          -12426.543,
          -12433.286,
          -12439.527,
          -12445.268,
          -12450.508,
          -12455.249,
          -12459.491000000002,
          -12463.236,
          -12466.483,
          -12469.233999999999,
          -12471.489,
          -12473.25,
          -12474.516000000001,
          -12475.288999999999,
          -12475.568000000001,
          -12475.356000000002,
          -12474.652,
          -12473.457,
          -12471.771,
          -12469.596000000001,
          -12466.931,
          -12463.777,
          -12460.136,
          -12456.006000000001,
          -12451.389,
          -12446.285,
          -12440.694,
          -12434.617,
          -12428.055,
          -12421.007,
          -12413.473999999998,
          -12405.456,
          -12396.954,
          -12387.968,
          -12378.499,
          -12368.546,
          -12358.108999999999,
          -12347.19,
          -12335.788999999999,
          -12323.905,
          -12311.538,
          -12298.688999999998,
          -12285.358,
          -12271.545,
          -12257.251,
          -12242.475,
          -12227.216999999999,
          -12211.478000000001,
          -12195.257,
          -12178.555,
          -12161.372,
          -12143.707,
          -12125.562,
          -12106.935,
          -12087.826000000001,
          -12068.236,
          -12048.163999999999,
          -12027.61,
          -12006.575,
          -11985.058,
          -11963.058,
          -11940.577,
          -11917.613000000001,
          -11894.166000000001,
          -11870.237,
          -11845.823999999999,
          -11820.928999999998,
          -11795.55,
          -11769.687,
          -11743.34,
          -11716.508999999998,
          -11689.193000000001,
          -11661.391000000001,
          -11633.105,
          -11604.332,
          -11575.073,
          -11545.328000000001,
          -11515.095,
          -11484.375,
          -11453.167,
          -11421.47,
          -11389.285,
          -11356.608999999999,
          -11323.444,
          -11289.788999999999,
          -11255.642,
          -11221.003999999999,
          -11185.873,
          -11150.249,
          -11114.132,
          -11077.52,
          -11040.413,
          -11002.811000000002,
          -10964.712,
          -10926.116000000002,
          -10887.023000000001,
          -10847.43,
          -10807.338,
          -10766.746000000001,
          -10725.653,
          -10684.059,
          -10641.961000000001,
          -10599.36,
          -10556.255,
          -10512.643,
          -10468.526,
          -10423.901,
          -10378.767,
          -10333.124,
          -10286.971,
          -10240.306999999999,
          -10193.13,
          -10145.439,
          -10097.234,
          -10048.513,
          -9999.276,
          -9949.52,
          -9899.245,
          -9848.45,
          -9797.133,
          -9745.292,
          -9692.928,
          -9640.038,
          -9586.622,
          -9532.677,
          -9478.203000000001,
          -9423.198,
          -9367.661,
          -9311.59,
          -9254.985,
          -9197.843,
          -9140.163,
          -9081.944,
          -9023.183,
          -8963.88,
          -8904.033000000001,
          -8843.64,
          -8782.699,
          -8721.21,
          -8659.171,
          -8596.579,
          -8533.433,
          -8469.732,
          -8405.473,
          -8340.655,
          -8275.277,
          -8209.336,
          -8142.83,
          -8075.758000000001,
          -8008.118,
          -7939.906999999999,
          -7871.125,
          -7801.769,
          -7731.8369999999995,
          -7661.328,
          -7590.238,
          -7518.568,
          -7446.314,
          -7373.474,
          -7300.045999999999,
          -7226.029,
          -7151.42,
          -7076.217,
          -7000.418000000001,
          -6924.022,
          -6847.025,
          -6769.4259999999995,
          -6691.223000000001,
          -6612.414000000001,
          -6532.996999999999,
          -6452.969,
          -6372.328,
          -6291.073,
          -6209.201,
          -6126.71,
          -6043.598000000001,
          -5959.863,
          -5875.504,
          -5790.517,
          -5704.901999999999,
          -5618.655,
          -5531.776,
          -5444.263000000001,
          -5356.113,
          -5267.325,
          -5177.897,
          -5087.827,
          -4997.1140000000005,
          -4905.755999999999,
          -4813.753,
          -4721.102,
          -4627.803,
          -4533.854,
          -4439.255,
          -4344.005999999999,
          -4248.104,
          -4151.549,
          -4054.342,
          -3956.482,
          -3857.969,
          -3758.805,
          -3658.989,
          -3558.522,
          -3457.407,
          -3355.6440000000002,
          -3253.235,
          -3150.183,
          -3046.492,
          -2942.164,
          -2837.202,
          -2731.612,
          -2625.3990000000003,
          -2518.569,
          -2411.127,
          -2303.083,
          -2194.4429999999998,
          -2085.218,
          -1975.418,
          -1865.0539999999999,
          -1754.14,
          -1642.6889999999999,
          -1530.717,
          -1418.241,
          -1305.282,
          -1191.861,
          -1078.001,
          -963.7280000000001,
          -849.071,
          -734.061,
          -618.7330000000001,
          -503.126,
          -387.282,
          -271.247,
          -155.07299999999998,
          -38.815,
          77.465,
          193.69799999999998,
          309.809,
          425.716,
          541.328,
          656.545,
          771.257,
          885.3430000000001,
          998.67,
          1111.0919999999999,
          1222.448,
          1332.5610000000001,
          1441.237,
          1548.264,
          1653.4089999999999,
          1756.418,
          1857.013,
          1954.891,
          2049.7270000000003,
          2141.163,
          2228.821,
          2312.29,
          2391.137,
          2464.902,
          2533.105,
          2595.2470000000003,
          2650.82,
          2699.312,
          2740.216,
          2773.0409999999997,
          2797.328,
          2812.6620000000003,
          2818.6809999999996,
          2815.1,
          2801.7140000000004,
          2778.413,
          2745.188,
          2702.131,
          2649.438,
          2587.4,
          2516.393,
          2436.87,
          2349.341,
          2254.362,
          2152.513,
          2044.391,
          1930.5929999999998,
          1811.7060000000001,
          1688.295,
          1560.904,
          1430.0410000000002,
          1296.185,
          1159.776,
          1021.221,
          880.89,
          739.1210000000001,
          596.217,
          452.454,
          308.07599999999996,
          163.306,
          18.338,
          -126.652,
          -271.509,
          -416.095,
          -560.29,
          -703.9860000000001,
          -847.0889999999999,
          -989.5160000000001,
          -1131.194,
          -1272.058,
          -1412.057,
          -1551.141,
          -1689.269,
          -1826.405,
          -1962.5179999999998,
          -2097.583,
          -2231.576,
          -2364.482,
          -2496.283,
          -2626.969,
          -2756.5290000000005,
          -2884.955,
          -3012.243,
          -3138.388,
          -3263.389,
          -3387.245,
          -3509.9570000000003,
          -3631.525,
          -3751.952,
          -3871.242,
          -3989.3979999999997,
          -4106.427,
          -4222.332,
          -4337.119000000001,
          -4450.795,
          -4563.366,
          -4674.839,
          -4785.222,
          -4894.521,
          -5002.744000000001,
          -5109.899,
          -5215.9929999999995,
          -5321.035,
          -5425.033,
          -5527.994000000001,
          -5629.927,
          -5730.84,
          -5830.74,
          -5929.6359999999995,
          -6027.536,
          -6124.4490000000005,
          -6220.382,
          -6315.343000000001,
          -6409.339,
          -6502.38,
          -6594.471,
          -6685.6230000000005,
          -6775.840999999999,
          -6865.134,
          -6953.508000000001,
          -7040.971,
          -7127.531,
          -7213.195,
          -7297.97,
          -7381.863,
          -7464.88,
          -7547.029,
          -7628.316,
          -7708.7480000000005,
          -7788.331,
          -7867.073,
          -7944.979,
          -8022.055,
          -8098.309,
          -8173.745,
          -8248.37,
          -8322.189,
          -8395.209,
          -8467.436,
          -8538.874,
          -8609.53,
          -8679.409,
          -8748.516,
          -8816.857,
          -8884.436,
          -8951.259,
          -9017.331,
          -9082.658000000001,
          -9147.243,
          -9211.091,
          -9274.209,
          -9336.6,
          -9398.267,
          -9459.216999999999,
          -9519.454,
          -9578.982,
          -9637.804,
          -9695.927,
          -9753.354,
          -9810.088,
          -9866.134,
          -9921.496,
          -9976.177,
          -10030.181999999999,
          -10083.515,
          -10136.178,
          -10188.177,
          -10239.513,
          -10290.192,
          -10340.216999999999,
          -10389.591,
          -10438.315999999999,
          -10486.396999999999,
          -10533.837,
          -10580.64,
          -10626.806999999999,
          -10672.343,
          -10717.251,
          -10761.533000000001,
          -10805.194,
          -10848.233999999999,
          -10890.658000000001,
          -10932.468,
          -10973.667,
          -11014.257,
          -11054.242,
          -11093.625,
          -11132.407,
          -11170.591999999999,
          -11208.181,
          -11245.178999999998,
          -11281.586000000001,
          -11317.405,
          -11352.639,
          -11387.29,
          -11421.361,
          -11454.853000000001,
          -11487.768,
          -11520.11,
          -11551.88,
          -11583.081,
          -11613.714,
          -11643.782,
          -11673.286,
          -11702.229,
          -11730.612,
          -11758.437,
          -11785.707,
          -11812.423,
          -11838.587,
          -11864.2,
          -11889.266000000001,
          -11913.784,
          -11937.758,
          -11961.188999999998,
          -11984.078000000001,
          -12006.427,
          -12028.238000000001,
          -12049.511,
          -12070.25,
          -12090.454,
          -12110.127,
          -12129.268,
          -12147.88,
          -12165.965,
          -12183.521999999999,
          -12200.555,
          -12217.063999999998,
          -12233.05,
          -12248.515,
          -12263.46,
          -12277.886,
          -12291.794,
          -12305.186000000002,
          -12318.063,
          -12330.426000000001,
          -12342.276000000002,
          -12353.614,
          -12364.441,
          -12374.758999999998,
          -12384.569,
          -12393.87,
          -12402.663999999999,
          -12410.953000000001,
          -12418.737,
          -12426.018,
          -12432.795,
          -12439.071000000002,
          -12444.845,
          -12450.118999999999,
          -12454.893,
          -12459.169,
          -12462.947,
          -12466.228000000001,
          -12469.013,
          -12471.302,
          -12473.095,
          -12474.395,
          -12475.2,
          -12475.513,
          -12475.333999999999,
          -12474.663,
          -12473.5,
          -12471.847,
          -12469.705,
          -12467.073,
          -12463.952,
          -12460.341999999999,
          -12456.245,
          -12451.66,
          -12446.588,
          -12441.028999999999,
          -12434.983999999999,
          -12428.453000000001,
          -12421.437,
          -12413.936000000002,
          -12405.95,
          -12397.48,
          -12388.525,
          -12379.087,
          -12369.166000000001,
          -12358.761,
          -12347.874,
          -12336.503,
          -12324.65,
          -12312.313999999998,
          -12299.496000000001,
          -12286.196000000002,
          -12272.413999999999,
          -12258.15,
          -12243.405,
          -12228.178,
          -12212.47,
          -12196.28,
          -12179.608999999999,
          -12162.456,
          -12144.822,
          -12126.706,
          -12108.108999999999,
          -12089.03,
          -12069.47,
          -12049.428,
          -12028.903999999999,
          -12007.899,
          -11986.412,
          -11964.442,
          -11941.99,
          -11919.056,
          -11895.64,
          -11871.74,
          -11847.357,
          -11822.491000000002,
          -11797.141000000001,
          -11771.308,
          -11744.99,
          -11718.188,
          -11690.901000000002,
          -11663.128999999999,
          -11634.871000000001,
          -11606.127,
          -11576.896999999999,
          -11547.181,
          -11516.976999999999,
          -11486.287,
          -11455.107,
          -11423.44,
          -11391.283000000001,
          -11358.636,
          -11325.5,
          -11291.873,
          -11257.753999999999,
          -11223.143999999998,
          -11188.042,
          -11152.446000000002,
          -11116.357,
          -11079.774,
          -11042.696000000002,
          -11005.122,
          -10967.051000000001,
          -10928.483,
          -10889.418,
          -10849.853000000001,
          -10809.79,
          -10769.226,
          -10728.16,
          -10686.593,
          -10644.523000000001,
          -10601.95,
          -10558.872,
          -10515.288999999999,
          -10471.199,
          -10426.601999999999,
          -10381.496,
          -10335.881,
          -10289.755,
          -10243.118,
          -10195.969000000001,
          -10148.305,
          -10100.128,
          -10051.434000000001,
          -10002.224,
          -9952.496,
          -9902.248,
          -9851.48,
          -9800.19,
          -9748.377,
          -9696.039,
          -9643.177,
          -9589.787,
          -9535.87,
          -9481.423,
          -9426.445,
          -9370.934000000001,
          -9314.891,
          -9258.312,
          -9201.197,
          -9143.544,
          -9085.351,
          -9026.617,
          -8967.341,
          -8907.52,
          -8847.154,
          -8786.241,
          -8724.778,
          -8662.765,
          -8600.2,
          -8537.082,
          -8473.407,
          -8409.175,
          -8344.383,
          -8279.030999999999,
          -8213.116,
          -8146.637,
          -8079.590999999999,
          -8011.977,
          -7943.793000000001,
          -7875.0380000000005,
          -7805.7080000000005,
          -7735.803000000001,
          -7665.32,
          -7594.257,
          -7522.613,
          -7450.385,
          -7377.571,
          -7304.169,
          -7230.178000000001,
          -7155.595,
          -7080.418000000001,
          -7004.646,
          -6928.276,
          -6851.306,
          -6773.733,
          -6695.556,
          -6616.773,
          -6537.380999999999,
          -6457.379,
          -6376.764,
          -6295.535,
          -6213.689,
          -6131.224,
          -6048.138000000001,
          -5964.43,
          -5880.096,
          -5795.135,
          -5709.545,
          -5623.3240000000005,
          -5536.471,
          -5448.983,
          -5360.858,
          -5272.095,
          -5182.693,
          -5092.649,
          -5001.960999999999,
          -4910.629,
          -4818.651,
          -4726.025,
          -4632.751,
          -4538.827,
          -4444.252,
          -4349.027,
          -4253.149,
          -4156.619000000001,
          -4059.437,
          -3961.6009999999997,
          -3863.112,
          -3763.972,
          -3664.179,
          -3563.736,
          -3462.6440000000002,
          -3360.9040000000005,
          -3258.518,
          -3155.489,
          -3051.8190000000004,
          -2947.513,
          -2842.573,
          -2737.0040000000004,
          -2630.812,
          -2524.002,
          -2416.58,
          -2308.555,
          -2199.9339999999997,
          -2090.7270000000003,
          -1980.945,
          -1870.598,
          -1759.6989999999998,
          -1648.263,
          -1536.305,
          -1423.8429999999998,
          -1310.896,
          -1197.486,
          -1083.635,
          -969.3710000000001,
          -854.72,
          -739.716,
          -624.391,
          -508.786,
          -392.941,
          -276.902,
          -160.722,
          -44.455,
          71.836,
          188.085,
          304.215,
          420.145,
          535.785,
          651.035,
          765.7860000000001,
          879.916,
          993.294,
          1105.774,
          1217.197,
          1327.385,
          1436.1470000000002,
          1543.269,
          1648.521,
          1751.651,
          1852.379,
          1950.4070000000002,
          2045.408,
          2137.028,
          2224.889,
          2308.5820000000003,
          2387.674,
          2461.708,
          2530.205,
          2592.666,
          2648.585,
          2697.448,
          2738.7490000000003,
          2771.9970000000003,
          2796.73,
          2812.53,
          2819.0370000000003,
          2815.9559999999997,
          2803.083,
          2780.3,
          2747.595,
          2705.053,
          2652.867,
          2591.321,
          2520.7889999999998,
          2441.719,
          2354.619,
          2260.04,
          2158.564,
          2050.786,
          1937.3020000000001,
          1818.7,
          1695.547,
          1568.384,
          1437.727,
          1304.05,
          1167.799,
          1029.38,
          889.1669999999999,
          747.497,
          604.677,
          460.983,
          316.66200000000003,
          171.935,
          27,
          -117.96700000000001,
          -262.81,
          -407.39099999999996,
          -551.587,
          -695.291,
          -838.408,
          -980.8530000000001,
          -1122.5539999999999,
          -1263.448,
          -1403.4779999999998,
          -1542.5970000000002,
          -1680.7620000000002,
          -1817.9379999999999,
          -1954.094,
          -2089.203,
          -2223.243,
          -2356.197,
          -2488.047,
          -2618.784,
          -2748.3959999999997,
          -2876.8759999999997,
          -3004.218,
          -3130.4179999999997,
          -3255.474,
          -3379.386,
          -3502.155,
          -3623.78,
          -3744.264,
          -3863.612,
          -3981.8259999999996,
          -4098.913,
          -4214.876,
          -4329.722,
          -4443.456,
          -4556.085999999999,
          -4667.617,
          -4778.059,
          -4887.417,
          -4995.698,
          -5102.911,
          -5209.063,
          -5314.1630000000005,
          -5418.22,
          -5521.2390000000005,
          -5623.229,
          -5724.1990000000005,
          -5824.156,
          -5923.11,
          -6021.066999999999,
          -6118.036,
          -6214.026,
          -6309.043000000001,
          -6403.095,
          -6496.191,
          -6588.339,
          -6679.545,
          -6769.819,
          -6859.166,
          -6947.595,
          -7035.113,
          -7121.727,
          -7207.445,
          -7292.273,
          -7376.219,
          -7459.29,
          -7541.491999999999,
          -7622.831,
          -7703.316,
          -7782.951999999999,
          -7861.745,
          -7939.701999999999,
          -8016.83,
          -8093.1359999999995,
          -8168.6230000000005,
          -8243.298,
          -8317.169,
          -8390.239,
          -8462.515,
          -8534.004,
          -8604.709,
          -8674.638,
          -8743.794,
          -8812.184000000001,
          -8879.812,
          -8946.684000000001,
          -9012.804,
          -9078.179,
          -9142.812,
          -9206.708,
          -9269.874,
          -9332.311,
          -9394.026,
          -9455.023000000001,
          -9515.306999999999,
          -9574.881,
          -9633.75,
          -9691.919,
          -9749.391,
          -9806.171999999999,
          -9862.263,
          -9917.67,
          -9972.396999999999,
          -10026.447,
          -10079.824,
          -10132.532,
          -10184.575,
          -10235.956,
          -10286.679,
          -10336.748,
          -10386.166,
          -10434.935,
          -10483.059000000001,
          -10530.543,
          -10577.388,
          -10623.598999999998,
          -10669.177,
          -10714.128,
          -10758.453000000001,
          -10802.155,
          -10845.238000000001,
          -10887.703000000001,
          -10929.555,
          -10970.796,
          -11011.428,
          -11051.455,
          -11090.878,
          -11129.702,
          -11167.927,
          -11205.558,
          -11242.596000000001,
          -11279.044,
          -11314.903,
          -11350.178,
          -11384.868999999999,
          -11418.979,
          -11452.511,
          -11485.466,
          -11517.848,
          -11549.657,
          -11580.896999999999,
          -11611.57,
          -11641.677,
          -11671.22,
          -11700.201000000001,
          -11728.623,
          -11756.487,
          -11783.795,
          -11810.548999999999,
          -11836.751,
          -11862.403,
          -11887.506000000001,
          -11912.063,
          -11936.073999999999,
          -11959.543,
          -11982.469,
          -12004.856000000002,
          -12026.703000000001,
          -12048.014,
          -12068.788999999999,
          -12089.031,
          -12108.74,
          -12127.918,
          -12146.567,
          -12164.688,
          -12182.282,
          -12199.35,
          -12215.896,
          -12231.918,
          -12247.419,
          -12262.4,
          -12276.861,
          -12290.805,
          -12304.233,
          -12317.145,
          -12329.543,
          -12341.428,
          -12352.802,
          -12363.663999999999,
          -12374.017,
          -12383.861,
          -12393.197,
          -12402.027,
          -12410.35,
          -12418.169,
          -12425.483999999999,
          -12432.295,
          -12438.605,
          -12444.413,
          -12449.721000000001,
          -12454.53,
          -12458.84,
          -12462.651000000002,
          -12465.966,
          -12468.784,
          -12471.107,
          -12472.934,
          -12474.267,
          -12475.106000000002,
          -12475.452,
          -12475.305,
          -12474.667,
          -12473.538,
          -12471.918,
          -12469.808,
          -12467.208999999999,
          -12464.12,
          -12460.543,
          -12456.478000000001,
          -12451.926000000001,
          -12446.886,
          -12441.358999999999,
          -12435.347,
          -12428.848,
          -12421.864,
          -12414.395,
          -12406.441,
          -12398.002,
          -12389.08,
          -12379.673,
          -12369.784,
          -12359.411,
          -12348.553999999998,
          -12337.215,
          -12325.393,
          -12313.089,
          -12300.302,
          -12287.033000000001,
          -12273.282,
          -12259.05,
          -12244.335,
          -12229.139,
          -12213.461000000001,
          -12197.303,
          -12180.662,
          -12163.54,
          -12145.936000000002,
          -12127.851,
          -12109.284,
          -12090.236,
          -12070.706,
          -12050.694,
          -12030.201000000001,
          -12009.225,
          -11987.768,
          -11965.828000000001,
          -11943.407,
          -11920.503,
          -11897.116000000002,
          -11873.246000000001,
          -11848.893,
          -11824.056999999999,
          -11798.736,
          -11772.931999999999,
          -11746.643999999998,
          -11719.871000000001,
          -11692.614,
          -11664.871000000001,
          -11636.642,
          -11607.928,
          -11578.726999999999,
          -11549.04,
          -11518.866000000002,
          -11488.204,
          -11457.053999999998,
          -11425.415,
          -11393.287,
          -11360.669,
          -11327.561000000002,
          -11293.963,
          -11259.873,
          -11225.292,
          -11190.218,
          -11154.651000000002,
          -11118.591,
          -11082.036,
          -11044.986,
          -11007.44,
          -10969.398000000001,
          -10930.858999999999,
          -10891.821000000002,
          -10852.285,
          -10812.25,
          -10771.714,
          -10730.677,
          -10689.138,
          -10647.096000000001,
          -10604.55,
          -10561.5,
          -10517.945,
          -10473.883,
          -10429.314,
          -10384.235,
          -10338.648000000001,
          -10292.55,
          -10245.940999999999,
          -10198.819,
          -10151.183,
          -10103.033000000001,
          -10054.367,
          -10005.184000000001,
          -9955.484,
          -9905.263,
          -9854.523000000001,
          -9803.26,
          -9751.474,
          -9699.164,
          -9646.329,
          -9592.966999999999,
          -9539.076,
          -9484.655999999999,
          -9429.706,
          -9374.223,
          -9318.206,
          -9261.655,
          -9204.567,
          -9146.940999999999,
          -9088.775,
          -9030.068000000001,
          -8970.819,
          -8911.025,
          -8850.686,
          -8789.799,
          -8728.364,
          -8666.377,
          -8603.839,
          -8540.747,
          -8477.099,
          -8412.894,
          -8348.129,
          -8282.804,
          -8216.916,
          -8150.463000000001,
          -8083.444,
          -8015.857,
          -7947.7,
          -7878.97,
          -7809.6669999999995,
          -7739.789000000001,
          -7669.331999999999,
          -7598.295999999999,
          -7526.678000000001,
          -7454.477,
          -7381.689,
          -7308.314,
          -7234.349,
          -7159.793000000001,
          -7084.643,
          -7008.897,
          -6932.553000000001,
          -6855.609,
          -6778.063,
          -6699.911999999999,
          -6621.155,
          -6541.79,
          -6461.814,
          -6381.225,
          -6300.022,
          -6218.201999999999,
          -6135.763000000001,
          -6052.704000000001,
          -5969.021,
          -5884.713000000001,
          -5799.778,
          -5714.214,
          -5628.02,
          -5541.191999999999,
          -5453.73,
          -5365.630999999999,
          -5276.894,
          -5187.516,
          -5097.498,
          -5006.837,
          -4915.53,
          -4823.577,
          -4730.977,
          -4637.728,
          -4543.829000000001,
          -4449.28,
          -4354.079000000001,
          -4258.226,
          -4161.721,
          -4064.563,
          -3966.752,
          -3868.2870000000003,
          -3769.171,
          -3669.402,
          -3568.9829999999997,
          -3467.914,
          -3366.197,
          -3263.835,
          -3160.828,
          -3057.1809999999996,
          -2952.897,
          -2847.9790000000003,
          -2742.4320000000002,
          -2636.26,
          -2529.471,
          -2422.07,
          -2314.064,
          -2205.462,
          -2096.274,
          -1986.509,
          -1876.18,
          -1765.297,
          -1653.876,
          -1541.933,
          -1429.485,
          -1316.5510000000002,
          -1203.152,
          -1089.3110000000001,
          -975.055,
          -860.4119999999999,
          -745.413,
          -630.092,
          -514.488,
          -398.642,
          -282.601,
          -166.415,
          -50.14,
          66.163,
          182.42700000000002,
          298.57599999999996,
          414.529,
          530.197,
          645.479,
          760.268,
          874.443,
          987.872,
          1100.411,
          1211.899,
          1322.1629999999998,
          1431.009,
          1538.2279999999998,
          1643.5870000000002,
          1746.8370000000002,
          1847.7,
          1945.878,
          2041.045,
          2132.849,
          2220.9139999999998,
          2304.8320000000003,
          2384.17,
          2458.475,
          2527.2670000000003,
          2590.049,
          2646.315,
          2695.551,
          2737.252,
          2770.926,
          2796.1090000000004,
          2812.381,
          2819.377,
          2816.803,
          2804.447,
          2782.188,
          2750.008,
          2707.988,
          2656.3140000000003,
          2595.268,
          2525.217,
          2446.606,
          2359.9410000000003,
          2265.769,
          2164.672,
          2057.243,
          1944.078,
          1825.766,
          1702.875,
          1575.9460000000001,
          1445.497,
          1312.004,
          1175.914,
          1037.635,
          897.541,
          755.9730000000001,
          613.239,
          469.616,
          325.35200000000003,
          180.67,
          35.769,
          -109.175,
          -254.003,
          -398.577,
          -542.773,
          -686.485,
          -829.6139999999999,
          -972.078,
          -1113.803,
          -1254.563,
          -1394.785,
          -1533.9389999999999,
          -1672.141,
          -1809.358,
          -1945.557,
          -2080.7110000000002,
          -2214.798,
          -2347.8,
          -2479.701,
          -2610.489,
          -2740.1540000000005,
          -2868.687,
          -2996.0840000000003,
          -3122.3390000000004,
          -3247.452,
          -3371.421,
          -3494.2459999999996,
          -3615.929,
          -3736.472,
          -3855.8779999999997,
          -3974.151,
          -4091.296,
          -4207.319,
          -4322.223,
          -4436.017,
          -4548.706,
          -4660.295999999999,
          -4770.7970000000005,
          -4880.214,
          -4988.554,
          -5095.826,
          -5202.038,
          -5307.196999999999,
          -5411.311,
          -5514.389,
          -5616.437,
          -5717.465999999999,
          -5817.481,
          -5916.491999999999,
          -6014.507,
          -6111.534000000001,
          -6207.581,
          -6302.654,
          -6396.763000000001,
          -6489.916,
          -6582.12,
          -6673.382,
          -6763.7119999999995,
          -6853.115,
          -6941.599,
          -7029.172,
          -7115.840999999999,
          -7201.613,
          -7286.495,
          -7370.496,
          -7453.62,
          -7535.876,
          -7617.269,
          -7697.806,
          -7777.495,
          -7856.340999999999,
          -7934.351,
          -8011.531,
          -8087.888000000001,
          -8163.427,
          -8238.154,
          -8312.076,
          -8385.197,
          -8457.524,
          -8529.063,
          -8599.819,
          -8669.798,
          -8739.004,
          -8807.443000000001,
          -8875.121,
          -8942.042,
          -9008.211,
          -9073.635,
          -9138.315999999999,
          -9202.261,
          -9265.474,
          -9327.96,
          -9389.723,
          -9450.767,
          -9511.098,
          -9570.719000000001,
          -9629.635,
          -9687.851,
          -9745.37,
          -9802.197,
          -9858.334,
          -9913.787,
          -9968.56,
          -10022.655,
          -10076.078000000001,
          -10128.832,
          -10180.92,
          -10232.346,
          -10283.113000000001,
          -10333.226,
          -10382.688,
          -10431.502,
          -10479.67,
          -10527.197,
          -10574.086000000001,
          -10620.34,
          -10665.963,
          -10710.956,
          -10755.323999999999,
          -10799.069,
          -10842.195,
          -10884.703000000001,
          -10926.597,
          -10967.88,
          -11008.553999999998,
          -11048.623,
          -11088.088,
          -11126.953000000001,
          -11165.22,
          -11202.892,
          -11239.971000000001,
          -11276.46,
          -11312.361,
          -11347.675,
          -11382.407,
          -11416.558,
          -11450.13,
          -11483.126,
          -11515.546999999999,
          -11547.396999999999,
          -11578.676000000001,
          -11609.388,
          -11639.534,
          -11669.116000000002,
          -11698.136999999999,
          -11726.598,
          -11754.501,
          -11781.848,
          -11808.642,
          -11834.883,
          -11860.573,
          -11885.715,
          -11910.309,
          -11934.358999999999,
          -11957.865,
          -11980.829,
          -12003.253,
          -12025.139,
          -12046.487,
          -12067.301000000001,
          -12087.58,
          -12107.326000000001,
          -12126.541000000001,
          -12145.226999999999,
          -12163.385,
          -12181.016000000001,
          -12198.121000000001,
          -12214.702,
          -12230.761,
          -12246.298,
          -12261.316,
          -12275.813999999998,
          -12289.794,
          -12303.258,
          -12316.206,
          -12328.64,
          -12340.56,
          -12351.969,
          -12362.867,
          -12373.255,
          -12383.133999999998,
          -12392.506000000001,
          -12401.37,
          -12409.729,
          -12417.583,
          -12424.931999999999,
          -12431.778999999999,
          -12438.123,
          -12443.966,
          -12449.308,
          -12454.151000000002,
          -12458.495,
          -12462.341,
          -12465.69,
          -12468.542,
          -12470.898000000001,
          -12472.758999999998,
          -12474.126,
          -12474.999,
          -12475.378,
          -12475.265,
          -12474.661,
          -12473.565,
          -12471.978000000001,
          -12469.901000000002,
          -12467.335,
          -12464.28,
          -12460.736,
          -12456.704,
          -12452.184,
          -12447.177,
          -12441.683,
          -12435.703000000001,
          -12429.236,
          -12422.285,
          -12414.848,
          -12406.926000000001,
          -12398.52,
          -12389.63,
          -12380.256000000001,
          -12370.398000000001,
          -12360.056,
          -12349.232,
          -12337.923999999999,
          -12326.133999999998,
          -12313.861,
          -12301.106000000002,
          -12287.868999999999,
          -12274.149,
          -12259.948,
          -12245.265,
          -12230.101,
          -12214.454,
          -12198.326000000001,
          -12181.716,
          -12164.625,
          -12147.052,
          -12128.997,
          -12110.461000000001,
          -12091.444,
          -12071.945,
          -12051.964,
          -12031.501,
          -12010.556,
          -11989.13,
          -11967.221000000001,
          -11944.829,
          -11921.955,
          -11898.598,
          -11874.758,
          -11850.435,
          -11825.628999999999,
          -11800.338,
          -11774.563999999998,
          -11748.306,
          -11721.563,
          -11694.336000000001,
          -11666.623,
          -11638.423999999999,
          -11609.739,
          -11580.568000000001,
          -11550.91,
          -11520.765,
          -11490.132,
          -11459.011,
          -11427.401000000002,
          -11395.302,
          -11362.714,
          -11329.636,
          -11296.067,
          -11262.007,
          -11227.454,
          -11192.409,
          -11156.871000000001,
          -11120.839,
          -11084.313,
          -11047.292,
          -11009.775,
          -10971.761,
          -10933.25,
          -10894.242,
          -10854.735,
          -10814.728000000001,
          -10774.22,
          -10733.212,
          -10691.701000000001,
          -10649.687,
          -10607.17,
          -10564.148000000001,
          -10520.621000000001,
          -10476.587,
          -10432.046,
          -10386.996,
          -10341.437,
          -10295.367,
          -10248.786,
          -10201.692,
          -10154.084,
          -10105.962,
          -10057.324,
          -10008.169,
          -9958.495,
          -9908.303,
          -9857.59,
          -9806.356,
          -9754.598,
          -9702.315,
          -9649.508,
          -9596.173,
          -9542.31,
          -9487.918,
          -9432.995,
          -9377.539,
          -9321.55,
          -9265.026,
          -9207.966,
          -9150.367,
          -9092.228000000001,
          -9033.549,
          -8974.327,
          -8914.56,
          -8854.248,
          -8793.389000000001,
          -8731.981,
          -8670.021999999999,
          -8607.511,
          -8544.446,
          -8480.825,
          -8416.646999999999,
          -8351.909,
          -8286.610999999999,
          -8220.75,
          -8154.3240000000005,
          -8087.331999999999,
          -8019.772,
          -7951.642,
          -7882.94,
          -7813.664000000001,
          -7743.812,
          -7673.382,
          -7602.3730000000005,
          -7530.781999999999,
          -7458.607,
          -7385.846,
          -7312.4980000000005,
          -7238.56,
          -7164.031,
          -7088.908,
          -7013.189,
          -6936.871,
          -6859.954000000001,
          -6782.434,
          -6704.31,
          -6625.58,
          -6546.241,
          -6466.2919999999995,
          -6385.73,
          -6304.554,
          -6222.76,
          -6140.348000000001,
          -6057.314,
          -5973.658,
          -5889.3769999999995,
          -5804.468000000001,
          -5718.93,
          -5632.762,
          -5545.960999999999,
          -5458.525,
          -5370.453,
          -5281.741999999999,
          -5192.391,
          -5102.398,
          -5011.762,
          -4920.481,
          -4828.554,
          -4735.979,
          -4642.7570000000005,
          -4548.884,
          -4454.36,
          -4359.184,
          -4263.357,
          -4166.876,
          -4069.743,
          -3971.9559999999997,
          -3873.5170000000003,
          -3774.426,
          -3674.6820000000002,
          -3574.2859999999996,
          -3473.242,
          -3371.548,
          -3269.2090000000003,
          -3166.2259999999997,
          -3062.6009999999997,
          -2958.3390000000004,
          -2853.4440000000004,
          -2747.9190000000003,
          -2641.7690000000002,
          -2535.001,
          -2427.62,
          -2319.634,
          -2211.052,
          -2101.883,
          -1992.136,
          -1881.8229999999999,
          -1770.9579999999999,
          -1659.5539999999999,
          -1547.626,
          -1435.191,
          -1322.27,
          -1208.883,
          -1095.052,
          -980.805,
          -866.169,
          -751.176,
          -635.859,
          -520.257,
          -404.411,
          -288.367,
          -172.176,
          -55.891999999999996,
          60.422,
          176.7,
          292.868,
          408.845,
          524.54,
          639.855,
          754.682,
          868.9010000000001,
          982.3810000000001,
          1094.978,
          1206.5339999999999,
          1316.8729999999998,
          1425.8039999999999,
          1533.119,
          1638.5870000000002,
          1741.957,
          1842.955,
          1941.2839999999999,
          2036.618,
          2128.609,
          2216.879,
          2301.022,
          2380.61,
          2455.187,
          2524.276,
          2587.382,
          2643.998,
          2693.612,
          2735.717,
          2769.82,
          2795.4570000000003,
          2812.2059999999997,
          2819.698,
          2817.636,
          2805.803,
          2784.075,
          2752.427,
          2710.937,
          2659.783,
          2599.243,
          2529.68,
          2451.5370000000003,
          2365.312,
          2271.555,
          2170.843,
          2063.769,
          1950.931,
          1832.914,
          1710.29,
          1583.6,
          1453.3629999999998,
          1320.058,
          1184.132,
          1045.995,
          906.025,
          764.562,
          621.915,
          478.36400000000003,
          334.159,
          189.523,
          44.657,
          -100.262,
          -245.074,
          -389.64099999999996,
          -533.8380000000001,
          -677.556,
          -820.698,
          -963.18,
          -1104.928,
          -1245.877,
          -1385.97,
          -1525.158,
          -1663.399,
          -1800.656,
          -1936.8970000000002,
          -2072.097,
          -2206.232,
          -2339.283,
          -2471.235,
          -2602.075,
          -2731.7929999999997,
          -2860.381,
          -2987.833,
          -3114.145,
          -3239.3140000000003,
          -3363.34,
          -3486.224,
          -3607.965,
          -3728.566,
          -3848.031,
          -3966.364,
          -4083.5690000000004,
          -4199.651,
          -4314.616,
          -4428.469,
          -4541.218,
          -4652.869000000001,
          -4763.43,
          -4872.906,
          -4981.306,
          -5088.638,
          -5194.909000000001,
          -5300.128000000001,
          -5404.302,
          -5507.439,
          -5609.545999999999,
          -5710.633000000001,
          -5810.7080000000005,
          -5909.778,
          -6007.851,
          -6104.936,
          -6201.04,
          -6296.170999999999,
          -6390.338000000001,
          -6483.548000000001,
          -6575.809,
          -6667.128000000001,
          -6757.514,
          -6846.973000000001,
          -6935.513000000001,
          -7023.142,
          -7109.866999999999,
          -7195.695,
          -7280.632,
          -7364.687,
          -7447.866,
          -7530.175,
          -7611.6230000000005,
          -7692.215,
          -7771.956999999999,
          -7850.857,
          -7928.92,
          -8006.153,
          -8082.561,
          -8158.153,
          -8232.933,
          -8306.905999999999,
          -8380.079,
          -8452.458,
          -8524.048,
          -8594.854,
          -8664.883,
          -8734.141,
          -8802.63,
          -8870.358,
          -8937.329,
          -9003.548,
          -9069.021,
          -9133.751,
          -9197.745,
          -9261.007,
          -9323.542,
          -9385.353000000001,
          -9446.445,
          -9506.824,
          -9566.493,
          -9625.457,
          -9683.719000000001,
          -9741.286,
          -9798.159,
          -9854.344000000001,
          -9909.843,
          -9964.662,
          -10018.804,
          -10072.273000000001,
          -10125.072,
          -10177.205,
          -10228.677,
          -10279.491,
          -10329.649,
          -10379.155,
          -10428.013,
          -10476.226,
          -10523.798,
          -10570.731000000002,
          -10617.028999999999,
          -10662.695,
          -10707.733,
          -10752.143999999998,
          -10795.931999999999,
          -10839.101,
          -10881.652,
          -10923.589,
          -10964.915,
          -11005.632,
          -11045.743,
          -11085.251,
          -11124.158000000001,
          -11162.466999999999,
          -11200.181,
          -11237.301000000001,
          -11273.831,
          -11309.773000000001,
          -11345.128999999999,
          -11379.902,
          -11414.094,
          -11447.707,
          -11480.743999999999,
          -11513.206,
          -11545.096000000001,
          -11576.416000000001,
          -11607.168,
          -11637.354,
          -11666.976,
          -11696.037,
          -11724.537,
          -11752.48,
          -11779.867,
          -11806.698999999999,
          -11832.979,
          -11858.708999999999,
          -11883.889,
          -11908.523000000001,
          -11932.611,
          -11956.155,
          -11979.158000000001,
          -12001.62,
          -12023.544,
          -12044.931,
          -12065.782,
          -12086.098999999998,
          -12105.883,
          -12125.136,
          -12143.858999999999,
          -12162.053999999998,
          -12179.722,
          -12196.865,
          -12213.483,
          -12229.579,
          -12245.153,
          -12260.207,
          -12274.742,
          -12288.758,
          -12302.258,
          -12315.243,
          -12327.713,
          -12339.67,
          -12351.115,
          -12362.048,
          -12372.472,
          -12382.386999999999,
          -12391.794,
          -12400.695,
          -12409.089,
          -12416.978000000001,
          -12424.362,
          -12431.243999999999,
          -12437.623,
          -12443.501,
          -12448.878999999999,
          -12453.756000000001,
          -12458.135,
          -12462.015,
          -12465.399,
          -12468.285,
          -12470.676000000001,
          -12472.571000000002,
          -12473.972,
          -12474.878999999999,
          -12475.292,
          -12475.214,
          -12474.643,
          -12473.58,
          -12472.027,
          -12469.983999999999,
          -12467.451000000001,
          -12464.43,
          -12460.919,
          -12456.92,
          -12452.433,
          -12447.458999999999,
          -12441.999,
          -12436.051000000001,
          -12429.618,
          -12422.698999999999,
          -12415.295,
          -12407.406,
          -12399.032,
          -12390.175,
          -12380.833,
          -12371.008,
          -12360.698,
          -12349.906,
          -12338.631000000001,
          -12326.872,
          -12314.632,
          -12301.908000000001,
          -12288.703000000001,
          -12275.015,
          -12260.846000000001,
          -12246.195,
          -12231.062,
          -12215.447,
          -12199.35,
          -12182.771999999999,
          -12165.712,
          -12148.17,
          -12130.146999999999,
          -12111.642,
          -12092.656,
          -12073.187,
          -12053.237,
          -12032.805,
          -12011.892,
          -11990.496000000001,
          -11968.618,
          -11946.257,
          -11923.413,
          -11900.087,
          -11876.277,
          -11851.985,
          -11827.208999999999,
          -11801.948999999999,
          -11776.205,
          -11749.976999999999,
          -11723.264,
          -11696.067,
          -11668.383999999998,
          -11640.215,
          -11611.56,
          -11582.419,
          -11552.791000000001,
          -11522.675,
          -11492.072,
          -11460.981000000002,
          -11429.401000000002,
          -11397.332,
          -11364.773000000001,
          -11331.725,
          -11298.185,
          -11264.153999999999,
          -11229.631000000001,
          -11194.615,
          -11159.106000000002,
          -11123.103000000001,
          -11086.606000000002,
          -11049.614,
          -11012.126,
          -10974.142,
          -10935.66,
          -10896.681,
          -10857.202,
          -10817.223999999998,
          -10776.745,
          -10735.765,
          -10694.284,
          -10652.298999999999,
          -10609.81,
          -10566.817,
          -10523.318000000001,
          -10479.313,
          -10434.8,
          -10389.779,
          -10344.248,
          -10298.207,
          -10251.654,
          -10204.588,
          -10157.009,
          -10108.915,
          -10060.305,
          -10011.178,
          -9961.533000000001,
          -9911.368,
          -9860.684000000001,
          -9809.476999999999,
          -9757.747,
          -9705.493,
          -9652.713,
          -9599.405999999999,
          -9545.572,
          -9491.207,
          -9436.312,
          -9380.884,
          -9324.923,
          -9268.427,
          -9211.394,
          -9153.823,
          -9095.712,
          -9037.06,
          -8977.866,
          -8918.127,
          -8857.843,
          -8797.011,
          -8735.63,
          -8673.699,
          -8611.215,
          -8548.178,
          -8484.585,
          -8420.434000000001,
          -8355.724,
          -8290.453000000001,
          -8224.619,
          -8158.221,
          -8091.255999999999,
          -8023.723000000001,
          -7955.62,
          -7886.946,
          -7817.696999999999,
          -7747.8730000000005,
          -7677.47,
          -7606.488,
          -7534.924,
          -7462.776,
          -7390.043000000001,
          -7316.722,
          -7242.811,
          -7168.309,
          -7093.213000000001,
          -7017.521,
          -6941.23,
          -6864.34,
          -6786.847,
          -6708.75,
          -6630.047,
          -6550.735,
          -6470.813,
          -6390.278,
          -6309.129,
          -6227.363,
          -6144.977,
          -6061.97,
          -5978.340999999999,
          -5894.085999999999,
          -5809.204000000001,
          -5723.693,
          -5637.552,
          -5550.776999999999,
          -5463.368,
          -5375.321999999999,
          -5286.638000000001,
          -5197.313,
          -5107.346,
          -5016.737,
          -4925.482,
          -4833.581,
          -4741.032999999999,
          -4647.835999999999,
          -4553.9890000000005,
          -4459.491,
          -4364.340999999999,
          -4268.539000000001,
          -4172.085,
          -4074.9770000000003,
          -3977.215,
          -3878.801,
          -3779.735,
          -3680.015,
          -3579.645,
          -3478.6240000000003,
          -3376.955,
          -3274.64,
          -3171.68,
          -3068.079,
          -2963.84,
          -2858.967,
          -2753.4640000000004,
          -2647.337,
          -2540.589,
          -2433.23,
          -2325.265,
          -2216.702,
          -2107.552,
          -1997.8239999999998,
          -1887.529,
          -1776.681,
          -1665.293,
          -1553.38,
          -1440.961,
          -1328.0520000000001,
          -1214.677,
          -1100.858,
          -986.62,
          -871.992,
          -757.005,
          -641.692,
          -526.092,
          -410.246,
          -294.2,
          -178.00400000000002,
          -61.711999999999996,
          54.614,
          170.907,
          287.093,
          403.092,
          518.815,
          634.1619999999999,
          749.0269999999999,
          863.291,
          976.822,
          1089.478,
          1201.1,
          1311.515,
          1420.533,
          1527.944,
          1633.521,
          1737.0120000000002,
          1838.146,
          1936.6270000000002,
          2032.129,
          2124.3070000000002,
          2212.783,
          2297.155,
          2376.994,
          2451.846,
          2521.235,
          2584.667,
          2641.636,
          2691.631,
          2734.1440000000002,
          2768.6809999999996,
          2794.777,
          2812.008,
          2820.002,
          2818.458,
          2807.156,
          2785.965,
          2754.857,
          2713.9040000000005,
          2663.278,
          2603.2529999999997,
          2534.187,
          2456.518,
          2370.743,
          2277.407,
          2177.0879999999997,
          2070.377,
          1957.87,
          1840.155,
          1717.8029999999999,
          1591.358,
          1461.338,
          1328.224,
          1192.4660000000001,
          1054.476,
          914.6310000000001,
          773.2760000000001,
          630.719,
          487.24300000000005,
          343.098,
          198.51,
          53.68,
          -91.212,
          -236.00799999999998,
          -380.56699999999995,
          -524.764,
          -668.488,
          -811.643,
          -954.143,
          -1095.914,
          -1236.891,
          -1377.015,
          -1516.239,
          -1654.5179999999998,
          -1791.816,
          -1928.101,
          -2063.347,
          -2197.529,
          -2330.63,
          -2462.633,
          -2593.526,
          -2723.298,
          -2851.941,
          -2979.449,
          -3105.817,
          -3231.0440000000003,
          -3355.1290000000004,
          -3478.071,
          -3599.8709999999996,
          -3720.532,
          -3840.0570000000002,
          -3958.45,
          -4075.716,
          -4191.858,
          -4306.884,
          -4420.798,
          -4533.607,
          -4645.319,
          -4755.941,
          -4865.478,
          -4973.939,
          -5081.332,
          -5187.663,
          -5292.943,
          -5397.177,
          -5500.3730000000005,
          -5602.541,
          -5703.688,
          -5803.821999999999,
          -5902.951999999999,
          -6001.084,
          -6098.228,
          -6194.39,
          -6289.58,
          -6383.805,
          -6477.0740000000005,
          -6569.393,
          -6660.77,
          -6751.2119999999995,
          -6840.728,
          -6929.326,
          -7017.0109999999995,
          -7103.793000000001,
          -7189.6759999999995,
          -7274.67,
          -7358.78,
          -7442.014,
          -7524.379,
          -7605.882,
          -7686.528,
          -7766.325,
          -7845.278,
          -7923.395,
          -8000.682,
          -8077.144,
          -8152.789000000001,
          -8227.622,
          -8301.648000000001,
          -8374.873,
          -8447.304,
          -8518.946,
          -8589.804,
          -8659.885,
          -8729.193000000001,
          -8797.734,
          -8865.513,
          -8932.534,
          -8998.804,
          -9064.327,
          -9129.107,
          -9193.151,
          -9256.462,
          -9319.046,
          -9380.905999999999,
          -9442.048,
          -9502.475,
          -9562.192,
          -9621.204,
          -9679.515,
          -9737.129,
          -9794.05,
          -9850.282,
          -9905.829,
          -9960.695,
          -10014.884,
          -10068.399,
          -10121.245,
          -10173.425,
          -10224.943000000001,
          -10275.802,
          -10326.006,
          -10375.558,
          -10424.461,
          -10472.72,
          -10520.336000000001,
          -10567.313999999998,
          -10613.657,
          -10659.368,
          -10704.45,
          -10748.905,
          -10792.738000000001,
          -10835.95,
          -10878.545,
          -10920.526000000002,
          -10961.895,
          -11002.655,
          -11042.809,
          -11082.36,
          -11121.31,
          -11159.662,
          -11197.418,
          -11234.581,
          -11271.153,
          -11307.136999999999,
          -11342.535,
          -11377.348999999998,
          -11411.583,
          -11445.237,
          -11478.315,
          -11510.819,
          -11542.75,
          -11574.111,
          -11604.903,
          -11635.13,
          -11664.793,
          -11693.893,
          -11722.434,
          -11750.417,
          -11777.844,
          -11804.716,
          -11831.036,
          -11856.805,
          -11882.025,
          -11906.698,
          -11930.825,
          -11954.409,
          -11977.45,
          -11999.951000000001,
          -12021.913999999999,
          -12043.339,
          -12064.229,
          -12084.583999999999,
          -12104.407,
          -12123.698,
          -12142.458999999999,
          -12160.692,
          -12178.398000000001,
          -12195.578000000001,
          -12212.233999999999,
          -12228.367,
          -12243.979,
          -12259.07,
          -12273.642,
          -12287.696000000002,
          -12301.233,
          -12314.253999999999,
          -12326.761,
          -12338.753999999999,
          -12350.236,
          -12361.206,
          -12371.666000000001,
          -12381.617,
          -12391.06,
          -12399.997,
          -12408.427,
          -12416.351999999999,
          -12423.771999999999,
          -12430.69,
          -12437.105,
          -12443.018,
          -12448.431,
          -12453.344,
          -12457.757,
          -12461.673,
          -12465.091,
          -12468.013,
          -12470.438999999998,
          -12472.368999999999,
          -12473.803999999998,
          -12474.745,
          -12475.194,
          -12475.149,
          -12474.613000000001,
          -12473.585,
          -12472.066,
          -12470.056,
          -12467.558,
          -12464.57,
          -12461.093,
          -12457.128,
          -12452.675,
          -12447.735,
          -12442.306999999999,
          -12436.393999999998,
          -12429.993999999999,
          -12423.108,
          -12415.737,
          -12407.881000000001,
          -12399.541000000001,
          -12390.716,
          -12381.408000000001,
          -12371.615,
          -12361.338,
          -12350.579,
          -12339.336000000001,
          -12327.61,
          -12315.402,
          -12302.711000000001,
          -12289.538,
          -12275.883,
          -12261.745,
          -12247.126,
          -12232.026000000002,
          -12216.443000000001,
          -12200.378,
          -12183.831,
          -12166.803,
          -12149.293,
          -12131.302,
          -12112.829,
          -12093.874,
          -12074.437,
          -12054.518999999998,
          -12034.118999999999,
          -12013.236,
          -11991.871000000001,
          -11970.024,
          -11947.694,
          -11924.882,
          -11901.586000000001,
          -11877.808,
          -11853.546999999999,
          -11828.802,
          -11803.573,
          -11777.86,
          -11751.662,
          -11724.98,
          -11697.812,
          -11670.16,
          -11642.021,
          -11613.396999999999,
          -11584.286,
          -11554.688,
          -11524.603000000001,
          -11494.031,
          -11462.97,
          -11431.42,
          -11399.381000000001,
          -11366.851999999999,
          -11333.833,
          -11300.323,
          -11266.321000000002,
          -11231.828000000001,
          -11196.841999999999,
          -11161.363000000001,
          -11125.39,
          -11088.923,
          -11051.961000000001,
          -11014.502,
          -10976.546999999999,
          -10938.095,
          -10899.143999999998,
          -10859.695,
          -10819.746000000001,
          -10779.296999999999,
          -10738.347,
          -10696.893999999998,
          -10654.938999999998,
          -10612.479,
          -10569.515,
          -10526.045,
          -10482.069,
          -10437.585,
          -10392.591999999999,
          -10347.09,
          -10301.077,
          -10254.553,
          -10207.517,
          -10159.966999999999,
          -10111.902,
          -10063.32,
          -10014.222,
          -9964.605,
          -9914.469000000001,
          -9863.813,
          -9812.634,
          -9760.933,
          -9708.707,
          -9655.956,
          -9602.678,
          -9548.872,
          -9494.536,
          -9439.669,
          -9384.269,
          -9328.336,
          -9271.868,
          -9214.863000000001,
          -9157.32,
          -9099.238000000001,
          -9040.614,
          -8981.448,
          -8921.737,
          -8861.481,
          -8800.677,
          -8739.325,
          -8677.421,
          -8614.965,
          -8551.955,
          -8488.39,
          -8424.268,
          -8359.586,
          -8294.343,
          -8228.537,
          -8162.166,
          -8095.229,
          -8027.724,
          -7959.649,
          -7891.0019999999995,
          -7821.781999999999,
          -7751.985,
          -7681.61,
          -7610.655,
          -7539.119000000001,
          -7466.999,
          -7394.294,
          -7321,
          -7247.116999999999,
          -7172.642,
          -7097.5740000000005,
          -7021.909000000001,
          -6945.646,
          -6868.783,
          -6791.318,
          -6713.249,
          -6634.573,
          -6555.289000000001,
          -6475.394,
          -6394.8859999999995,
          -6313.765,
          -6232.025,
          -6149.6669999999995,
          -6066.688,
          -5983.085999999999,
          -5898.858,
          -5814.004,
          -5728.52,
          -5642.406,
          -5555.659000000001,
          -5468.276,
          -5380.257,
          -5291.599,
          -5202.302,
          -5112.362,
          -5021.779,
          -4930.5509999999995,
          -4838.678,
          -4746.156,
          -4652.985,
          -4559.164000000001,
          -4464.693,
          -4369.569,
          -4273.793,
          -4177.365,
          -4080.283,
          -3982.548,
          -3884.159,
          -3785.117,
          -3685.423,
          -3585.078,
          -3484.0820000000003,
          -3382.437,
          -3280.147,
          -3177.212,
          -3073.634,
          -2969.4190000000003,
          -2864.5690000000004,
          -2759.0879999999997,
          -2652.9829999999997,
          -2546.258,
          -2438.919,
          -2330.975,
          -2222.4339999999997,
          -2113.304,
          -2003.595,
          -1893.318,
          -1782.487,
          -1671.116,
          -1559.219,
          -1446.8129999999999,
          -1333.9189999999999,
          -1220.556,
          -1106.748,
          -992.5210000000001,
          -877.9010000000001,
          -762.92,
          -647.613,
          -532.015,
          -416.17,
          -300.121,
          -183.92,
          -67.62,
          48.716,
          165.024,
          281.22900000000004,
          397.251,
          513.001,
          628.381,
          743.285,
          857.5930000000001,
          971.176,
          1083.891,
          1195.58,
          1306.0710000000001,
          1415.175,
          1522.684,
          1628.369,
          1731.984,
          1833.256,
          1931.889,
          2027.5620000000001,
          2119.928,
          2208.612,
          2293.215,
          2373.3070000000002,
          2448.437,
          2518.13,
          2581.8920000000003,
          2639.219,
          2689.6,
          2732.525,
          2767.502,
          2794.0640000000003,
          2811.784,
          2820.2859999999996,
          2819.2690000000002,
          2808.505,
          2787.861,
          2757.301,
          2716.893,
          2666.8059999999996,
          2607.304,
          2538.745,
          2461.56,
          2376.243,
          2283.3379999999997,
          2183.4210000000003,
          2077.08,
          1964.912,
          1847.506,
          1725.432,
          1599.237,
          1469.4389999999999,
          1336.5220000000002,
          1200.937,
          1063.097,
          923.3810000000001,
          782.135,
          639.673,
          496.273,
          352.191,
          207.65200000000002,
          62.86,
          -82.005,
          -226.78400000000002,
          -371.334,
          -515.53,
          -659.26,
          -802.427,
          -944.946,
          -1086.74,
          -1228.008,
          -1367.9,
          -1507.1589999999999,
          -1645.476,
          -1782.816,
          -1919.146,
          -2054.438,
          -2188.669,
          -2321.82,
          -2453.875,
          -2584.821,
          -2714.6479999999997,
          -2843.347,
          -2970.9109999999996,
          -3097.3379999999997,
          -3222.6240000000003,
          -3346.7670000000003,
          -3469.7690000000002,
          -3591.6290000000004,
          -3712.35,
          -3831.937,
          -3950.3909999999996,
          -4067.718,
          -4183.920999999999,
          -4299.009,
          -4412.985,
          -4525.857,
          -4637.63,
          -4748.313,
          -4857.912,
          -4966.436,
          -5073.89,
          -5180.282999999999,
          -5285.6230000000005,
          -5389.918000000001,
          -5493.177,
          -5595.406,
          -5696.613,
          -5796.808000000001,
          -5895.996999999999,
          -5994.19,
          -6091.394,
          -6187.616999999999,
          -6282.866,
          -6377.151,
          -6470.478,
          -6562.855,
          -6654.291,
          -6744.7919999999995,
          -6834.366999999999,
          -6923.022,
          -7010.764,
          -7097.603,
          -7183.544,
          -7268.595,
          -7352.762,
          -7436.052,
          -7518.473000000001,
          -7600.031,
          -7680.733,
          -7760.585,
          -7839.594,
          -7917.766,
          -7995.107,
          -8071.624,
          -8147.321999999999,
          -8222.209,
          -8296.289,
          -8369.567,
          -8442.051,
          -8513.746,
          -8584.657,
          -8654.79,
          -8724.151,
          -8792.744,
          -8860.574,
          -8927.646999999999,
          -8993.968,
          -9059.541,
          -9124.373,
          -9188.468,
          -9251.829,
          -9314.463,
          -9376.373,
          -9437.564,
          -9498.041,
          -9557.806999999999,
          -9616.869,
          -9675.229,
          -9732.892,
          -9789.860999999999,
          -9846.141,
          -9901.735999999999,
          -9956.649,
          -10010.886,
          -10064.449,
          -10117.343,
          -10169.57,
          -10221.134,
          -10272.04,
          -10322.29,
          -10371.888,
          -10420.838,
          -10469.142,
          -10516.805,
          -10563.829,
          -10610.218,
          -10655.973999999998,
          -10701.1,
          -10745.601,
          -10789.478000000001,
          -10832.733999999999,
          -10875.374,
          -10917.399,
          -10958.813,
          -10999.617,
          -11039.815,
          -11079.409,
          -11118.403,
          -11156.798,
          -11194.597,
          -11231.803,
          -11268.419,
          -11304.445,
          -11339.886,
          -11374.743,
          -11409.018999999998,
          -11442.715,
          -11475.835,
          -11508.38,
          -11540.353000000001,
          -11571.755,
          -11602.59,
          -11632.858,
          -11662.562,
          -11691.704,
          -11720.286,
          -11748.309,
          -11775.776000000002,
          -11802.688999999998,
          -11829.048999999999,
          -11854.858,
          -11880.118,
          -11904.831,
          -11928.999,
          -11952.623,
          -11975.704,
          -11998.243999999999,
          -12020.246000000001,
          -12041.71,
          -12062.639,
          -12083.033000000001,
          -12102.895,
          -12122.225,
          -12141.025,
          -12159.296999999999,
          -12177.041000000001,
          -12194.26,
          -12210.954,
          -12227.125,
          -12242.774,
          -12257.903,
          -12272.513,
          -12286.605,
          -12300.18,
          -12313.239,
          -12325.783000000001,
          -12337.813999999998,
          -12349.332,
          -12360.339,
          -12370.837,
          -12380.823999999999,
          -12390.303999999998,
          -12399.277,
          -12407.743999999999,
          -12415.705,
          -12423.163,
          -12430.116000000002,
          -12436.567,
          -12442.517,
          -12447.966,
          -12452.913999999999,
          -12457.364,
          -12461.315,
          -12464.768999999998,
          -12467.726999999999,
          -12470.188,
          -12472.153,
          -12473.624,
          -12474.6,
          -12475.083,
          -12475.073999999999,
          -12474.572,
          -12473.579,
          -12472.095,
          -12470.12,
          -12467.656,
          -12464.703000000001,
          -12461.261,
          -12457.33,
          -12452.911,
          -12448.005,
          -12442.612,
          -12436.732,
          -12430.366000000002,
          -12423.514,
          -12416.178,
          -12408.356000000002,
          -12400.048999999999,
          -12391.258,
          -12381.982,
          -12372.223,
          -12361.98,
          -12351.253,
          -12340.044,
          -12328.351,
          -12316.176000000001,
          -12303.518,
          -12290.378,
          -12276.756000000001,
          -12262.652,
          -12248.065,
          -12232.996000000001,
          -12217.446000000002,
          -12201.413999999999,
          -12184.9,
          -12167.903999999999,
          -12150.426000000001,
          -12132.466999999999,
          -12114.026000000002,
          -12095.103000000001,
          -12075.698999999999,
          -12055.812,
          -12035.444,
          -12014.593,
          -11993.26,
          -11971.444,
          -11949.146,
          -11926.365,
          -11903.101,
          -11879.355,
          -11855.125,
          -11830.411,
          -11805.213,
          -11779.532,
          -11753.365,
          -11726.714,
          -11699.578000000001,
          -11671.956,
          -11643.848999999998,
          -11615.255,
          -11586.175,
          -11556.608,
          -11526.553999999998,
          -11496.011999999999,
          -11464.982,
          -11433.463,
          -11401.454,
          -11368.956,
          -11335.966999999999,
          -11302.487,
          -11268.516000000001,
          -11234.053,
          -11199.098,
          -11163.649,
          -11127.706,
          -11091.268999999998,
          -11054.337,
          -11016.909,
          -10978.983,
          -10940.561000000002,
          -10901.64,
          -10862.221000000001,
          -10822.302,
          -10781.882,
          -10740.962,
          -10699.538999999999,
          -10657.613000000001,
          -10615.183,
          -10572.249,
          -10528.808,
          -10484.860999999999,
          -10440.407,
          -10395.444,
          -10349.971,
          -10303.988000000001,
          -10257.493,
          -10210.485,
          -10162.965,
          -10114.929,
          -10066.376,
          -10017.306999999999,
          -9967.72,
          -9917.613000000001,
          -9866.985,
          -9815.836,
          -9764.163,
          -9711.966,
          -9659.244,
          -9605.995,
          -9552.218,
          -9497.911,
          -9443.072,
          -9387.702,
          -9331.796999999999,
          -9275.358,
          -9218.381,
          -9160.867,
          -9102.814,
          -9044.219000000001,
          -8985.081,
          -8925.399,
          -8865.171,
          -8804.396,
          -8743.072,
          -8681.197,
          -8618.769,
          -8555.788,
          -8492.251,
          -8428.157,
          -8363.504,
          -8298.289,
          -8232.511,
          -8166.169,
          -8099.26,
          -8031.784000000001,
          -7963.736999999999,
          -7895.118,
          -7825.9259999999995,
          -7756.156999999999,
          -7685.81,
          -7614.884,
          -7543.376,
          -7471.284000000001,
          -7398.607,
          -7325.340999999999,
          -7251.486,
          -7177.04,
          -7101.999,
          -7026.363,
          -6950.128000000001,
          -6873.293000000001,
          -6795.856,
          -6717.814,
          -6639.1669999999995,
          -6559.91,
          -6480.043000000001,
          -6399.564,
          -6318.47,
          -6236.758000000001,
          -6154.428000000001,
          -6071.477,
          -5987.901999999999,
          -5903.701999999999,
          -5818.875,
          -5733.42,
          -5647.3330000000005,
          -5560.613,
          -5473.258000000001,
          -5385.267,
          -5296.637,
          -5207.366,
          -5117.454000000001,
          -5026.899,
          -4935.698,
          -4843.852,
          -4751.357,
          -4658.213,
          -4564.419,
          -4469.975,
          -4374.878,
          -4279.129,
          -4182.726,
          -4085.671,
          -3987.962,
          -3889.599,
          -3790.583,
          -3690.915,
          -3590.595,
          -3489.625,
          -3388.005,
          -3285.739,
          -3182.829,
          -3079.276,
          -2975.0840000000003,
          -2870.258,
          -2764.8,
          -2658.718,
          -2552.015,
          -2444.699,
          -2336.776,
          -2228.255,
          -2119.145,
          -2009.4560000000001,
          -1899.1979999999999,
          -1788.385,
          -1677.031,
          -1565.15,
          -1452.76,
          -1339.88,
          -1226.53,
          -1112.733,
          -998.5160000000001,
          -883.904,
          -768.931,
          -653.628,
          -538.033,
          -422.18800000000005,
          -306.137,
          -189.93099999999998,
          -73.624,
          42.723,
          159.045,
          275.269,
          391.31300000000005,
          507.091,
          622.504,
          737.446,
          851.8,
          965.434,
          1078.208,
          1189.965,
          1300.5330000000001,
          1409.725,
          1517.332,
          1623.128,
          1726.8670000000002,
          1828.277,
          1927.065,
          2022.9089999999999,
          2115.466,
          2204.362,
          2289.197,
          2369.5460000000003,
          2444.9570000000003,
          2514.956,
          2579.053,
          2636.741,
          2687.512,
          2730.855,
          2766.278,
          2793.312,
          2811.526,
          2820.546,
          2820.0609999999997,
          2809.844,
          2789.755,
          2759.752,
          2719.9,
          2670.3590000000004,
          2611.391,
          2543.347,
          2466.654,
          2381.806,
          2289.34,
          2189.831,
          2083.868,
          1972.047,
          1854.9560000000001,
          1733.1670000000001,
          1607.2279999999998,
          1477.658,
          1344.942,
          1209.5330000000001,
          1071.847,
          932.2639999999999,
          791.1310000000001,
          648.764,
          505.444,
          361.426,
          216.93900000000002,
          72.186,
          -72.652,
          -217.412,
          -361.95300000000003,
          -506.147,
          -649.883,
          -793.062,
          -935.5989999999999,
          -1077.4160000000002,
          -1218.448,
          -1358.636,
          -1497.93,
          -1636.287,
          -1773.668,
          -1910.043,
          -2045.382,
          -2179.6620000000003,
          -2312.864,
          -2444.972,
          -2575.972,
          -2705.8540000000003,
          -2834.6090000000004,
          -2962.232,
          -3088.716,
          -3214.062,
          -3338.265,
          -3461.327,
          -3583.2490000000003,
          -3704.032,
          -3823.68,
          -3942.196,
          -4059.585,
          -4175.851,
          -4291.001,
          -4405.041,
          -4517.975,
          -4629.811,
          -4740.557,
          -4850.218,
          -4958.805,
          -5066.322,
          -5172.777,
          -5278.18,
          -5382.536999999999,
          -5485.857,
          -5588.148,
          -5689.418000000001,
          -5789.674,
          -5888.925,
          -5987.179,
          -6084.444,
          -6180.727,
          -6276.036999999999,
          -6370.380999999999,
          -6463.768,
          -6556.206,
          -6647.701,
          -6738.262,
          -6827.895,
          -6916.609,
          -7004.41,
          -7091.307,
          -7177.306,
          -7262.414000000001,
          -7346.639,
          -7429.986,
          -7512.464,
          -7594.079000000001,
          -7674.838000000001,
          -7754.746,
          -7833.811,
          -7912.0380000000005,
          -7989.435,
          -8066.005999999999,
          -8141.76,
          -8216.701,
          -8290.835,
          -8364.168,
          -8436.706,
          -8508.455,
          -8579.419,
          -8649.605,
          -8719.019,
          -8787.665,
          -8855.546999999999,
          -8922.673,
          -8989.046,
          -9054.671,
          -9119.554,
          -9183.7,
          -9247.113000000001,
          -9309.798,
          -9371.758,
          -9433,
          -9493.527,
          -9553.344000000001,
          -9612.455,
          -9670.865,
          -9728.577,
          -9785.595,
          -9841.924,
          -9897.568000000001,
          -9952.530999999999,
          -10006.815999999999,
          -10060.427,
          -10113.369,
          -10165.644,
          -10217.256,
          -10268.209,
          -10318.506,
          -10368.151,
          -10417.148000000001,
          -10465.499,
          -10513.208999999999,
          -10560.278999999999,
          -10606.714,
          -10652.516000000001,
          -10697.688,
          -10742.233999999999,
          -10786.157,
          -10829.458999999999,
          -10872.143,
          -10914.214,
          -10955.671999999999,
          -10996.521,
          -11036.764,
          -11076.402,
          -11115.44,
          -11153.878999999999,
          -11191.722,
          -11228.972,
          -11265.631000000001,
          -11301.701000000001,
          -11337.185,
          -11372.085,
          -11406.403999999999,
          -11440.143,
          -11473.306,
          -11505.893,
          -11537.908000000001,
          -11569.353000000001,
          -11600.23,
          -11630.54,
          -11660.286,
          -11689.469,
          -11718.093,
          -11746.157,
          -11773.666000000001,
          -11800.62,
          -11827.021,
          -11852.871000000001,
          -11878.171999999999,
          -11902.926000000001,
          -11927.133999999998,
          -11950.798,
          -11973.919,
          -11996.5,
          -12018.542,
          -12040.046,
          -12061.014,
          -12081.448,
          -12101.35,
          -12120.719,
          -12139.559,
          -12157.868999999999,
          -12175.653,
          -12192.911,
          -12209.643999999998,
          -12225.854,
          -12241.541000000001,
          -12256.708999999999,
          -12271.357,
          -12285.487,
          -12299.1,
          -12312.197,
          -12324.778999999999,
          -12336.848,
          -12348.403999999999,
          -12359.448999999999,
          -12369.983999999999,
          -12380.008999999998,
          -12389.527,
          -12398.536,
          -12407.04,
          -12415.038999999999,
          -12422.533000000001,
          -12429.524,
          -12436.011999999999,
          -12441.998,
          -12447.483,
          -12452.469,
          -12456.955,
          -12460.942,
          -12464.431999999999,
          -12467.426000000001,
          -12469.923,
          -12471.923999999999,
          -12473.431,
          -12474.443000000001,
          -12474.962,
          -12474.988000000001,
          -12474.521999999999,
          -12473.563999999998,
          -12472.115,
          -12470.176000000001,
          -12467.747,
          -12464.829,
          -12461.421999999999,
          -12457.526000000002,
          -12453.142,
          -12448.27,
          -12442.912,
          -12437.067,
          -12430.735,
          -12423.918,
          -12416.615,
          -12408.828000000001,
          -12400.555,
          -12391.798,
          -12382.556,
          -12372.831,
          -12362.622,
          -12351.928999999998,
          -12340.753,
          -12329.095,
          -12316.953000000001,
          -12304.329,
          -12291.222,
          -12277.633,
          -12263.562,
          -12249.008999999998,
          -12233.973,
          -12218.456,
          -12202.457,
          -12185.976,
          -12169.013,
          -12151.568000000001,
          -12133.641000000001,
          -12115.233,
          -12096.343,
          -12076.971000000001,
          -12057.117,
          -12036.781,
          -12015.963,
          -11994.662,
          -11972.878999999999,
          -11950.613000000001,
          -11927.864,
          -11904.632,
          -11880.917,
          -11856.719,
          -11832.038,
          -11806.872,
          -11781.222,
          -11755.087,
          -11728.468,
          -11701.363000000001,
          -11673.773000000001,
          -11645.697,
          -11617.135,
          -11588.086000000001,
          -11558.551000000001,
          -11528.528,
          -11498.017,
          -11467.018,
          -11435.53,
          -11403.552,
          -11371.085,
          -11338.127,
          -11304.678999999998,
          -11270.738000000001,
          -11236.306,
          -11201.381000000001,
          -11165.963,
          -11130.051000000001,
          -11093.645,
          -11056.743,
          -11019.345,
          -10981.451000000001,
          -10943.059,
          -10904.168,
          -10864.778999999999,
          -10824.891000000001,
          -10784.501,
          -10743.612,
          -10702.219,
          -10660.323,
          -10617.923999999999,
          -10575.018999999998,
          -10531.608999999999,
          -10487.692,
          -10443.267,
          -10398.334,
          -10352.891,
          -10306.938,
          -10260.473,
          -10213.495,
          -10166.004,
          -10117.998,
          -10069.476,
          -10020.436,
          -9970.878,
          -9920.801,
          -9870.203000000001,
          -9819.083,
          -9767.44,
          -9715.273000000001,
          -9662.58,
          -9609.36,
          -9555.612,
          -9501.334,
          -9446.525,
          -9391.184000000001,
          -9335.308,
          -9278.898000000001,
          -9221.952,
          -9164.466999999999,
          -9106.442,
          -9047.876,
          -8988.767,
          -8929.114,
          -8868.916,
          -8808.169,
          -8746.874,
          -8685.028,
          -8622.63,
          -8559.678,
          -8496.17,
          -8432.104,
          -8367.48,
          -8302.294,
          -8236.545,
          -8170.232,
          -8103.352,
          -8035.904,
          -7967.887,
          -7899.295999999999,
          -7830.132,
          -7760.392,
          -7690.0740000000005,
          -7619.177,
          -7547.696999999999,
          -7475.634,
          -7402.986,
          -7329.75,
          -7255.923000000001,
          -7181.505,
          -7106.493,
          -7030.884,
          -6954.678000000001,
          -6877.871999999999,
          -6800.464,
          -6722.451,
          -6643.831999999999,
          -6564.604,
          -6484.765,
          -6404.314,
          -6323.2480000000005,
          -6241.565,
          -6159.264,
          -6076.340999999999,
          -5992.795,
          -5908.6230000000005,
          -5823.825,
          -5738.397,
          -5652.338000000001,
          -5565.646,
          -5478.32,
          -5390.357,
          -5301.755,
          -5212.512,
          -5122.628,
          -5032.1,
          -4940.927,
          -4849.108,
          -4756.641,
          -4663.525,
          -4569.759,
          -4475.342000000001,
          -4380.272,
          -4284.55,
          -4188.175,
          -4091.1459999999997,
          -3993.4640000000004,
          -3895.1279999999997,
          -3796.139,
          -3696.4970000000003,
          -3596.203,
          -3495.258,
          -3393.664,
          -3291.4240000000004,
          -3188.538,
          -3085.01,
          -2980.843,
          -2876.0409999999997,
          -2770.607,
          -2664.548,
          -2557.868,
          -2450.575,
          -2342.674,
          -2234.174,
          -2125.085,
          -2015.415,
          -1905.1770000000001,
          -1794.3829999999998,
          -1683.046,
          -1571.182,
          -1458.808,
          -1345.942,
          -1232.606,
          -1118.8210000000001,
          -1004.613,
          -890.0110000000001,
          -775.044,
          -659.7460000000001,
          -544.155,
          -428.31,
          -312.258,
          -196.047,
          -79.733,
          36.625,
          152.96200000000002,
          269.204,
          385.27099999999996,
          501.07599999999996,
          616.5219999999999,
          731.503,
          845.9010000000001,
          959.5880000000001,
          1072.422,
          1184.248,
          1294.893,
          1404.172,
          1511.879,
          1617.787,
          1721.651,
          1823.201,
          1922.145,
          2018.164,
          2110.9139999999998,
          2200.0229999999997,
          2285.094,
          2365.702,
          2441.3979999999997,
          2511.709,
          2576.144,
          2634.2,
          2685.366,
          2729.134,
          2765.009,
          2792.5209999999997,
          2811.239,
          2820.784,
          2820.842,
          2811.1809999999996,
          2791.656,
          2762.223,
          2722.935,
          2673.952,
          2615.529,
          2548.011,
          2471.823,
          2387.452,
          2295.436,
          2196.345,
          2090.77,
          1979.3039999999999,
          1862.537,
          1741.04,
          1615.3629999999998,
          1486.026,
          1353.5179999999998,
          1218.29,
          1080.763,
          941.316,
          800.3,
          658.0319999999999,
          514.793,
          370.842,
          226.408,
          81.696,
          -63.111999999999995,
          -207.85299999999998,
          -352.38300000000004,
          -496.575,
          -640.316,
          -783.508,
          -926.062,
          -1067.903,
          -1208.962,
          -1349.182,
          -1488.5120000000002,
          -1626.908,
          -1764.3329999999999,
          -1900.7520000000002,
          -2036.139,
          -2170.469,
          -2303.723,
          -2435.885,
          -2566.94,
          -2696.8779999999997,
          -2825.69,
          -2953.3720000000003,
          -3079.9159999999997,
          -3205.321,
          -3329.585,
          -3452.71,
          -3574.6929999999998,
          -3695.539,
          -3815.2490000000003,
          -3933.829,
          -4051.281,
          -4167.612,
          -4282.825,
          -4396.928,
          -4509.9259999999995,
          -4621.827,
          -4732.6359999999995,
          -4842.362,
          -4951.0109999999995,
          -5058.593,
          -5165.112,
          -5270.578,
          -5374.999,
          -5478.382,
          -5580.736999999999,
          -5682.069,
          -5782.388000000001,
          -5881.701,
          -5980.017,
          -6077.344,
          -6173.69,
          -6269.061,
          -6363.467,
          -6456.916,
          -6549.414000000001,
          -6640.97,
          -6731.59,
          -6821.284000000001,
          -6910.057,
          -6997.919,
          -7084.875,
          -7170.933000000001,
          -7256.1,
          -7340.383000000001,
          -7423.789000000001,
          -7506.326,
          -7587.9980000000005,
          -7668.814,
          -7748.779,
          -7827.901,
          -7906.185,
          -7983.639,
          -8060.267,
          -8136.076999999999,
          -8211.073,
          -8285.263,
          -8358.651,
          -8431.245,
          -8503.048,
          -8574.067,
          -8644.306999999999,
          -8713.775,
          -8782.474,
          -8850.41,
          -8917.589,
          -8984.015,
          -9049.694,
          -9114.629,
          -9178.827,
          -9242.292,
          -9305.029,
          -9367.042,
          -9428.335,
          -9488.913,
          -9548.780999999999,
          -9607.943000000001,
          -9666.403,
          -9724.165,
          -9781.234,
          -9837.614,
          -9893.306999999999,
          -9948.319,
          -10002.653,
          -10056.314,
          -10109.304,
          -10161.628,
          -10213.289,
          -10264.291,
          -10314.636,
          -10364.33,
          -10413.374,
          -10461.773000000001,
          -10509.53,
          -10556.648000000001,
          -10603.128999999999,
          -10648.978000000001,
          -10694.197,
          -10738.79,
          -10782.758999999998,
          -10826.107,
          -10868.838,
          -10910.955,
          -10952.458,
          -10993.353000000001,
          -11033.64,
          -11073.323999999999,
          -11112.407,
          -11150.891000000001,
          -11188.778999999999,
          -11226.073999999999,
          -11262.777,
          -11298.891000000001,
          -11334.419,
          -11369.363000000001,
          -11403.726,
          -11437.508999999998,
          -11470.715,
          -11503.347,
          -11535.405,
          -11566.893,
          -11597.812,
          -11628.165,
          -11657.953000000001,
          -11687.178999999998,
          -11715.845,
          -11743.952,
          -11771.503,
          -11798.499,
          -11824.942,
          -11850.833999999999,
          -11876.176000000001,
          -11900.971000000001,
          -11925.22,
          -11948.926000000001,
          -11972.088,
          -11994.71,
          -12016.793,
          -12038.338,
          -12059.347,
          -12079.821000000002,
          -12099.763,
          -12119.171999999999,
          -12138.052,
          -12156.402,
          -12174.226,
          -12191.524,
          -12208.296999999999,
          -12224.546,
          -12240.273000000001,
          -12255.48,
          -12270.167,
          -12284.336000000001,
          -12297.988000000001,
          -12311.124,
          -12323.745,
          -12335.853000000001,
          -12347.447,
          -12358.531,
          -12369.104,
          -12379.167,
          -12388.723,
          -12397.771,
          -12406.312,
          -12414.348999999998,
          -12421.881000000001,
          -12428.909,
          -12435.434,
          -12441.458,
          -12446.981000000002,
          -12452.003,
          -12456.526000000002,
          -12460.551000000001,
          -12464.078000000001,
          -12467.108,
          -12469.642,
          -12471.68,
          -12473.223,
          -12474.271999999999,
          -12474.827,
          -12474.89,
          -12474.46,
          -12473.538,
          -12472.125,
          -12470.222,
          -12467.829,
          -12464.946000000002,
          -12461.575,
          -12457.714,
          -12453.366000000002,
          -12448.53,
          -12443.207,
          -12437.396999999999,
          -12431.101,
          -12424.318000000001,
          -12417.051000000001,
          -12409.298,
          -12401.061000000002,
          -12392.338,
          -12383.131000000001,
          -12373.44,
          -12363.266000000001,
          -12352.608,
          -12341.466,
          -12329.841999999999,
          -12317.735,
          -12305.145,
          -12292.073,
          -12278.518,
          -12264.48,
          -12249.961000000001,
          -12234.958999999999,
          -12219.475,
          -12203.51,
          -12187.062,
          -12170.133,
          -12152.722,
          -12134.83,
          -12116.455,
          -12097.598,
          -12078.258999999998,
          -12058.438,
          -12038.133999999998,
          -12017.348999999998,
          -11996.081,
          -11974.331,
          -11952.098,
          -11929.383,
          -11906.184,
          -11882.501,
          -11858.335,
          -11833.686000000002,
          -11808.552,
          -11782.935,
          -11756.832,
          -11730.246000000001,
          -11703.173999999999,
          -11675.616000000002,
          -11647.572,
          -11619.042,
          -11590.026000000002,
          -11560.521999999999,
          -11530.531,
          -11500.051000000001,
          -11469.083999999999,
          -11437.627,
          -11405.681,
          -11373.246000000001,
          -11340.32,
          -11306.903,
          -11272.995,
          -11238.594,
          -11203.701000000001,
          -11168.313999999998,
          -11132.433,
          -11096.056999999999,
          -11059.187,
          -11021.82,
          -10983.957,
          -10945.596000000001,
          -10906.737,
          -10867.378999999999,
          -10827.521,
          -10787.163,
          -10746.303,
          -10704.941,
          -10663.076000000001,
          -10620.707,
          -10577.833999999999,
          -10534.454,
          -10490.567,
          -10446.173,
          -10401.271,
          -10355.858,
          -10309.935,
          -10263.501,
          -10216.554,
          -10169.093,
          -10121.117,
          -10072.625,
          -10023.615,
          -9974.088,
          -9924.04,
          -9873.472,
          -9822.383,
          -9770.77,
          -9718.633,
          -9665.97,
          -9612.78,
          -9559.062,
          -9504.814,
          -9450.035,
          -9394.723,
          -9338.878,
          -9282.498,
          -9225.581,
          -9168.126,
          -9110.131,
          -9051.594000000001,
          -8992.515,
          -8932.892,
          -8872.723,
          -8812.006,
          -8750.74,
          -8688.924,
          -8626.555,
          -8563.633,
          -8500.155,
          -8436.119,
          -8371.523000000001,
          -8306.367,
          -8240.648000000001,
          -8174.3640000000005,
          -8107.513000000001,
          -8040.095,
          -7972.107,
          -7903.545999999999,
          -7834.411,
          -7764.7,
          -7694.411999999999,
          -7623.543000000001,
          -7552.093000000001,
          -7480.06,
          -7407.441,
          -7334.233,
          -7260.436,
          -7186.047,
          -7111.064,
          -7035.485,
          -6959.308000000001,
          -6882.531,
          -6805.151999999999,
          -6727.168000000001,
          -6648.578,
          -6569.379,
          -6489.57,
          -6409.147,
          -6328.11,
          -6246.456999999999,
          -6164.184,
          -6081.29,
          -5997.773,
          -5913.63,
          -5828.86,
          -5743.460999999999,
          -5657.431,
          -5570.769,
          -5483.471,
          -5395.536,
          -5306.963000000001,
          -5217.749,
          -5127.893,
          -5037.394,
          -4946.249,
          -4854.458,
          -4762.019,
          -4668.932,
          -4575.194,
          -4480.804,
          -4385.763,
          -4290.068,
          -4193.721,
          -4096.719,
          -3999.065,
          -3900.756,
          -3801.7940000000003,
          -3702.178,
          -3601.9109999999996,
          -3500.993,
          -3399.425,
          -3297.211,
          -3194.3509999999997,
          -3090.848,
          -2986.7059999999997,
          -2881.928,
          -2776.5190000000002,
          -2670.4840000000004,
          -2563.828,
          -2456.5570000000002,
          -2348.679,
          -2240.201,
          -2131.133,
          -2021.484,
          -1911.265,
          -1800.49,
          -1689.171,
          -1577.3239999999998,
          -1464.9660000000001,
          -1352.116,
          -1238.7930000000001,
          -1125.02,
          -1010.823,
          -896.23,
          -781.2710000000001,
          -665.9780000000001,
          -550.39,
          -434.54699999999997,
          -318.493,
          -202.278,
          -85.956,
          30.413,
          146.764,
          263.024,
          379.11400000000003,
          494.94699999999995,
          610.4259999999999,
          725.446,
          839.8889999999999,
          953.6289999999999,
          1066.5230000000001,
          1178.4180000000001,
          1289.143,
          1398.511,
          1506.318,
          1612.339,
          1716.33,
          1818.0220000000002,
          1917.124,
          2013.319,
          2106.265,
          2195.59,
          2280.9,
          2361.771,
          2437.755,
          2508.382,
          2573.161,
          2631.5890000000004,
          2683.156,
          2727.355,
          2763.69,
          2791.688,
          2810.9179999999997,
          2820.9959999999996,
          2821.6059999999998,
          2812.511,
          2793.562,
          2764.7070000000003,
          2725.9959999999996,
          2677.5820000000003,
          2619.714,
          2552.734,
          2477.061,
          2393.179,
          2301.6220000000003,
          2202.96,
          2097.782,
          1986.68,
          1870.244,
          1749.047,
          1623.639,
          1494.543,
          1362.247,
          1227.2060000000001,
          1089.8410000000001,
          950.535,
          809.64,
          667.4730000000001,
          524.319,
          380.43699999999995,
          236.058,
          91.38799999999999,
          -53.388999999999996,
          -198.109,
          -342.62800000000004,
          -486.81699999999995,
          -630.563,
          -773.7660000000001,
          -916.3380000000001,
          -1058.202,
          -1199.3039999999999,
          -1339.5410000000002,
          -1478.908,
          -1617.344,
          -1754.8110000000001,
          -1891.276,
          -2026.711,
          -2161.091,
          -2294.3979999999997,
          -2426.614,
          -2557.725,
          -2687.72,
          -2816.592,
          -2944.333,
          -3070.937,
          -3196.4040000000005,
          -3320.73,
          -3443.917,
          -3565.9640000000004,
          -3686.873,
          -3806.6479999999997,
          -3925.2909999999997,
          -4042.808,
          -4159.2029999999995,
          -4274.482,
          -4388.649,
          -4501.713,
          -4613.679,
          -4724.554,
          -4834.344,
          -4943.059,
          -5050.705,
          -5157.29,
          -5262.82,
          -5367.306,
          -5470.753000000001,
          -5573.172,
          -5674.568,
          -5774.951,
          -5874.328,
          -5972.7080000000005,
          -6070.098000000001,
          -6166.505999999999,
          -6261.941,
          -6356.409000000001,
          -6449.92,
          -6542.481,
          -6634.098000000001,
          -6724.78,
          -6814.535,
          -6903.37,
          -6991.2919999999995,
          -7078.309,
          -7164.427,
          -7249.654,
          -7333.996,
          -7417.4619999999995,
          -7500.057,
          -7581.789000000001,
          -7662.664000000001,
          -7742.687,
          -7821.866999999999,
          -7900.209,
          -7977.721,
          -8054.406,
          -8130.273,
          -8205.326,
          -8279.572,
          -8353.017,
          -8425.667,
          -8497.526,
          -8568.6,
          -8638.896,
          -8708.418,
          -8777.171999999999,
          -8845.163,
          -8912.396999999999,
          -8978.877,
          -9044.609,
          -9109.598,
          -9173.85,
          -9237.368,
          -9300.158000000001,
          -9362.223,
          -9423.569,
          -9484.199,
          -9544.119,
          -9603.333,
          -9661.844000000001,
          -9719.658000000001,
          -9776.778,
          -9833.209,
          -9888.953000000001,
          -9944.016,
          -9998.4,
          -10052.110999999999,
          -10105.151,
          -10157.525,
          -10209.235,
          -10260.286,
          -10310.681,
          -10360.423,
          -10409.516,
          -10457.964,
          -10505.768999999998,
          -10552.935,
          -10599.465,
          -10645.362,
          -10690.628999999999,
          -10735.268999999998,
          -10779.285,
          -10822.681,
          -10865.458999999999,
          -10907.622,
          -10949.171999999999,
          -10990.113000000001,
          -11030.447,
          -11070.177,
          -11109.306,
          -11147.836000000001,
          -11185.768999999998,
          -11223.11,
          -11259.858,
          -11296.017,
          -11331.59,
          -11366.579,
          -11400.987,
          -11434.813999999998,
          -11468.065,
          -11500.741000000002,
          -11532.843,
          -11564.375,
          -11595.338,
          -11625.733999999999,
          -11655.566,
          -11684.836000000001,
          -11713.544,
          -11741.695,
          -11769.288,
          -11796.327,
          -11822.813,
          -11848.747,
          -11874.132,
          -11898.97,
          -11923.261,
          -11947.008,
          -11970.213,
          -11992.876,
          -12015.001,
          -12036.588,
          -12057.638,
          -12078.153,
          -12098.136,
          -12117.586000000001,
          -12136.507,
          -12154.898000000001,
          -12172.761999999999,
          -12190.101,
          -12206.913999999999,
          -12223.204,
          -12238.971000000001,
          -12254.218,
          -12268.945,
          -12283.153999999999,
          -12296.845,
          -12310.021,
          -12322.681999999999,
          -12334.829,
          -12346.463,
          -12357.586000000001,
          -12368.198,
          -12378.3,
          -12387.893999999998,
          -12396.981000000002,
          -12405.561000000002,
          -12413.636999999999,
          -12421.207,
          -12428.274,
          -12434.837,
          -12440.899,
          -12446.46,
          -12451.52,
          -12456.081,
          -12460.143,
          -12463.708,
          -12466.776000000002,
          -12469.347,
          -12471.423,
          -12473.003,
          -12474.089,
          -12474.681999999999,
          -12474.781,
          -12474.388,
          -12473.503,
          -12472.127,
          -12470.26,
          -12467.903999999999,
          -12465.058,
          -12461.723,
          -12457.899,
          -12453.587,
          -12448.787,
          -12443.5,
          -12437.726,
          -12431.465,
          -12424.719,
          -12417.487,
          -12409.77,
          -12401.568000000001,
          -12392.881000000001,
          -12383.71,
          -12374.053999999998,
          -12363.915,
          -12353.292,
          -12342.186000000002,
          -12330.596000000001,
          -12318.524,
          -12305.969,
          -12292.931999999999,
          -12279.411,
          -12265.409,
          -12250.923999999999,
          -12235.957,
          -12220.507,
          -12204.576000000001,
          -12188.163,
          -12171.268,
          -12153.891000000001,
          -12136.033000000001,
          -12117.692,
          -12098.868999999999,
          -12079.563999999998,
          -12059.776000000002,
          -12039.507,
          -12018.755,
          -11997.521,
          -11975.803999999998,
          -11953.605,
          -11930.923,
          -11907.757,
          -11884.108,
          -11859.976,
          -11835.36,
          -11810.258999999998,
          -11784.675,
          -11758.605,
          -11732.051000000001,
          -11705.011999999999,
          -11677.488000000001,
          -11649.476999999999,
          -11620.979,
          -11591.995,
          -11562.524,
          -11532.565,
          -11502.118999999999,
          -11471.184,
          -11439.76,
          -11407.846000000001,
          -11375.443000000001,
          -11342.548999999999,
          -11309.165,
          -11275.288,
          -11240.92,
          -11206.058,
          -11170.703000000001,
          -11134.854,
          -11098.511,
          -11061.671999999999,
          -11024.337,
          -10986.506000000001,
          -10948.177,
          -10909.348999999998,
          -10870.023000000001,
          -10830.196000000002,
          -10789.868999999999,
          -10749.041000000001,
          -10707.71,
          -10665.877,
          -10623.54,
          -10580.697,
          -10537.348999999998,
          -10493.493999999999,
          -10449.131,
          -10404.259,
          -10358.878,
          -10312.985999999999,
          -10266.583,
          -10219.666,
          -10172.237,
          -10124.292,
          -10075.83,
          -10026.851999999999,
          -9977.355,
          -9927.339,
          -9876.801,
          -9825.742,
          -9774.16,
          -9722.054,
          -9669.421999999999,
          -9616.263,
          -9562.576,
          -9508.358,
          -9453.61,
          -9398.329,
          -9342.514000000001,
          -9286.164,
          -9229.277,
          -9171.851999999999,
          -9113.888,
          -9055.382,
          -8996.333,
          -8936.74,
          -8876.601999999999,
          -8815.915,
          -8754.68,
          -8692.894,
          -8630.556,
          -8567.663,
          -8504.215,
          -8440.209,
          -8375.643,
          -8310.517,
          -8244.828000000001,
          -8178.5740000000005,
          -8111.755,
          -8044.366,
          -7976.406999999999,
          -7907.876,
          -7838.771,
          -7769.090999999999,
          -7698.831999999999,
          -7627.994000000001,
          -7556.5740000000005,
          -7484.57,
          -7411.981,
          -7338.803000000001,
          -7265.036,
          -7190.6759999999995,
          -7115.723000000001,
          -7040.174,
          -6964.026999999999,
          -6887.28,
          -6809.93,
          -6731.976,
          -6653.416,
          -6574.246,
          -6494.465999999999,
          -6414.0740000000005,
          -6333.066999999999,
          -6251.443,
          -6169.1990000000005,
          -6086.335,
          -6002.847,
          -5918.734,
          -5833.993,
          -5748.624,
          -5662.624,
          -5575.99,
          -5488.722,
          -5400.816,
          -5312.272,
          -5223.088,
          -5133.2609999999995,
          -5042.791,
          -4951.675,
          -4859.913,
          -4767.503,
          -4674.444,
          -4580.735,
          -4486.374,
          -4391.361,
          -4295.695,
          -4199.376,
          -4102.402,
          -4004.775,
          -3906.494,
          -3807.56,
          -3707.972,
          -3607.732,
          -3506.841,
          -3405.3,
          -3303.112,
          -3200.278,
          -3096.801,
          -2992.685,
          -2887.933,
          -2782.5490000000004,
          -2676.538,
          -2569.905,
          -2462.658,
          -2354.802,
          -2246.347,
          -2137.301,
          -2027.6729999999998,
          -1917.474,
          -1806.7179999999998,
          -1695.418,
          -1583.589,
          -1471.247,
          -1358.411,
          -1245.103,
          -1131.343,
          -1017.158,
          -902.574,
          -787.622,
          -672.336,
          -556.751,
          -440.909,
          -324.85400000000004,
          -208.635,
          -92.306,
          24.074,
          140.44,
          256.719,
          372.832,
          488.69300000000004,
          604.205,
          719.265,
          833.7539999999999,
          947.547,
          1060.503,
          1172.468,
          1283.272,
          1392.73,
          1500.639,
          1606.774,
          1710.894,
          1812.729,
          1911.9920000000002,
          2008.365,
          2101.509,
          2191.055,
          2276.607,
          2357.745,
          2434.021,
          2504.967,
          2570.095,
          2628.901,
          2680.8759999999997,
          2725.512,
          2762.313,
          2790.8059999999996,
          2810.5559999999996,
          2821.176,
          2822.348,
          2813.829,
          2795.465,
          2767.2,
          2729.077,
          2681.243,
          2623.9429999999998,
          2557.511,
          2482.363,
          2398.981,
          2307.895,
          2209.6710000000003,
          2104.897,
          1994.1689999999999,
          1878.0729999999999,
          1757.183,
          1632.0520000000001,
          1503.201,
          1371.124,
          1236.275,
          1099.077,
          959.916,
          819.145,
          677.082,
          534.015,
          390.205,
          245.88299999999998,
          101.257,
          -43.488,
          -188.18599999999998,
          -332.69300000000004,
          -476.879,
          -620.629,
          -763.8430000000001,
          -906.432,
          -1048.318,
          -1189.434,
          -1329.72,
          -1469.1229999999998,
          -1607.599,
          -1745.109,
          -1881.621,
          -2017.105,
          -2151.536,
          -2284.896,
          -2417.167,
          -2548.335,
          -2678.388,
          -2807.3190000000004,
          -2935.119,
          -3061.7870000000003,
          -3187.315,
          -3311.705,
          -3434.954,
          -3557.066,
          -3678.04,
          -3797.88,
          -3916.5890000000004,
          -4034.172,
          -4150.633,
          -4265.977,
          -4380.210999999999,
          -4493.340999999999,
          -4605.373,
          -4716.314,
          -4826.170999999999,
          -4934.952,
          -5042.664000000001,
          -5149.314,
          -5254.911,
          -5359.4619999999995,
          -5462.976,
          -5565.459,
          -5666.920999999999,
          -5767.368,
          -5866.811,
          -5965.255,
          -6062.709,
          -6159.182,
          -6254.68,
          -6349.213000000001,
          -6442.786999999999,
          -6535.41,
          -6627.09,
          -6717.835,
          -6807.653,
          -6896.55,
          -6984.534000000001,
          -7071.611999999999,
          -7157.7919999999995,
          -7243.08,
          -7327.484,
          -7411.01,
          -7493.665,
          -7575.456,
          -7656.391,
          -7736.475,
          -7815.713000000001,
          -7894.1140000000005,
          -7971.684,
          -8048.428000000001,
          -8124.353,
          -8199.464,
          -8273.768,
          -8347.27,
          -8419.976,
          -8491.892,
          -8563.024,
          -8633.376,
          -8702.954,
          -8771.764000000001,
          -8839.81,
          -8907.099,
          -8973.635,
          -9039.421999999999,
          -9104.466,
          -9168.771999999999,
          -9232.344000000001,
          -9295.187,
          -9357.306,
          -9418.706,
          -9479.39,
          -9539.363000000001,
          -9598.629,
          -9657.194,
          -9715.06,
          -9772.232,
          -9828.714,
          -9884.51,
          -9939.624,
          -9994.06,
          -10047.822,
          -10100.913,
          -10153.338,
          -10205.098,
          -10256.199,
          -10306.644,
          -10356.436,
          -10405.58,
          -10454.077,
          -10501.931,
          -10549.146,
          -10595.725,
          -10641.67,
          -10686.985,
          -10731.673999999999,
          -10775.739,
          -10819.183,
          -10862.008999999998,
          -10904.219,
          -10945.817,
          -10986.805,
          -11027.186000000002,
          -11066.963,
          -11106.139,
          -11144.716,
          -11182.696000000002,
          -11220.082,
          -11256.877,
          -11293.082,
          -11328.701000000001,
          -11363.736,
          -11398.188999999998,
          -11432.062,
          -11465.358,
          -11498.078000000001,
          -11530.226,
          -11561.802,
          -11592.81,
          -11623.252,
          -11653.128,
          -11682.442,
          -11711.194,
          -11739.388,
          -11767.026000000002,
          -11794.108,
          -11820.636999999999,
          -11846.615,
          -11872.044,
          -11896.923999999999,
          -11921.258999999998,
          -11945.048999999999,
          -11968.296,
          -11991.002,
          -12013.168,
          -12034.796999999999,
          -12055.89,
          -12076.448,
          -12096.472,
          -12115.965,
          -12134.927,
          -12153.36,
          -12171.265,
          -12188.645,
          -12205.499,
          -12221.83,
          -12237.639,
          -12252.927,
          -12267.695,
          -12281.944,
          -12295.676000000001,
          -12308.892,
          -12321.593,
          -12333.78,
          -12345.454,
          -12356.617,
          -12367.268999999998,
          -12377.412,
          -12387.045,
          -12396.171999999999,
          -12404.791000000001,
          -12412.905,
          -12420.515,
          -12427.62,
          -12434.223999999998,
          -12440.325,
          -12445.923999999999,
          -12451.023000000001,
          -12455.623,
          -12459.723999999998,
          -12463.327,
          -12466.431999999999,
          -12469.042,
          -12471.156,
          -12472.774,
          -12473.899,
          -12474.528999999999,
          -12474.666000000001,
          -12474.311000000002,
          -12473.464,
          -12472.125,
          -12470.296,
          -12467.976999999999,
          -12465.168,
          -12461.87,
          -12458.083,
          -12453.808,
          -12449.045,
          -12443.794,
          -12438.056999999999,
          -12431.833999999999,
          -12425.124,
          -12417.928999999998,
          -12410.248,
          -12402.082,
          -12393.431,
          -12384.296,
          -12374.677,
          -12364.573,
          -12353.986,
          -12342.916000000001,
          -12331.363000000001,
          -12319.326000000001,
          -12306.806999999999,
          -12293.803999999998,
          -12280.319,
          -12266.351999999999,
          -12251.902,
          -12236.97,
          -12221.556999999999,
          -12205.661,
          -12189.283000000001,
          -12172.423,
          -12155.081,
          -12137.257,
          -12118.95,
          -12100.162,
          -12080.892,
          -12061.139,
          -12040.903999999999,
          -12020.187,
          -11998.988000000001,
          -11977.305,
          -11955.14,
          -11932.491000000002,
          -11909.36,
          -11885.745,
          -11861.646,
          -11837.063999999998,
          -11811.998,
          -11786.447,
          -11760.412,
          -11733.892,
          -11706.886,
          -11679.393999999998,
          -11651.417,
          -11622.953000000001,
          -11594.002,
          -11564.565,
          -11534.639,
          -11504.226,
          -11473.323999999999,
          -11441.934,
          -11410.053,
          -11377.683,
          -11344.822,
          -11311.47,
          -11277.626,
          -11243.291000000001,
          -11208.462,
          -11173.14,
          -11137.323999999999,
          -11101.013,
          -11064.206,
          -11026.903999999999,
          -10989.105,
          -10950.808,
          -10912.013,
          -10872.719,
          -10832.925,
          -10792.631000000001,
          -10751.833999999999,
          -10710.536,
          -10668.733999999999,
          -10626.428999999998,
          -10583.618,
          -10540.302,
          -10496.479,
          -10452.149,
          -10407.309000000001,
          -10361.959,
          -10316.099,
          -10269.726999999999,
          -10222.843,
          -10175.444,
          -10127.530999999999,
          -10079.101,
          -10030.155,
          -9980.69,
          -9930.705,
          -9880.199,
          -9829.171,
          -9777.621,
          -9725.545,
          -9672.944,
          -9619.815999999999,
          -9566.16,
          -9511.974,
          -9457.257,
          -9402.007,
          -9346.223,
          -9289.904,
          -9233.049,
          -9175.655,
          -9117.722,
          -9059.247,
          -9000.23,
          -8940.668,
          -8880.56,
          -8819.904,
          -8758.7,
          -8696.945,
          -8634.638,
          -8571.776,
          -8508.358,
          -8444.383,
          -8379.849,
          -8314.753,
          -8249.095,
          -8182.871999999999,
          -8116.0830000000005,
          -8048.725,
          -7980.797,
          -7912.297,
          -7843.223000000001,
          -7773.571999999999,
          -7703.344,
          -7632.536999999999,
          -7561.148,
          -7489.175,
          -7416.616,
          -7343.469,
          -7269.732,
          -7195.403,
          -7120.48,
          -7044.9619999999995,
          -6968.845,
          -6892.129,
          -6814.809,
          -6736.8859999999995,
          -6658.356,
          -6579.217,
          -6499.467,
          -6419.105,
          -6338.129,
          -6256.535,
          -6174.321999999999,
          -6091.486999999999,
          -6008.03,
          -5923.946999999999,
          -5839.236999999999,
          -5753.898,
          -5667.928000000001,
          -5581.3240000000005,
          -5494.085,
          -5406.21,
          -5317.695,
          -5228.541,
          -5138.745,
          -5048.304,
          -4957.219,
          -4865.486,
          -4773.106,
          -4680.076,
          -4586.396,
          -4492.065,
          -4397.081,
          -4301.444,
          -4205.154,
          -4108.209,
          -4010.611,
          -3912.3579999999997,
          -3813.452,
          -3713.893,
          -3613.6809999999996,
          -3512.817,
          -3411.304,
          -3309.143,
          -3206.336,
          -3102.886,
          -2998.796,
          -2894.07,
          -2788.711,
          -2682.725,
          -2576.117,
          -2468.894,
          -2361.062,
          -2252.63,
          -2143.606,
          -2034,
          -1923.8220000000001,
          -1813.086,
          -1701.805,
          -1589.994,
          -1477.6689999999999,
          -1364.849,
          -1251.555,
          -1137.809,
          -1023.635,
          -909.061,
          -794.118,
          -678.837,
          -563.257,
          -447.416,
          -331.36,
          -215.137,
          -98.8,
          17.59,
          133.97,
          250.268,
          366.404,
          482.293,
          597.84,
          712.938,
          827.475,
          941.322,
          1054.34,
          1166.375,
          1277.26,
          1386.81,
          1494.8220000000001,
          1601.0739999999998,
          1705.3239999999998,
          1807.305,
          1906.731,
          2003.286,
          2096.631,
          2186.4,
          2272.199,
          2353.6079999999997,
          2430.1820000000002,
          2501.4539999999997,
          2566.936,
          2626.127,
          2678.5170000000003,
          2723.599,
          2760.875,
          2789.873,
          2810.152,
          2821.3259999999996,
          2823.072,
          2815.1420000000003,
          2797.377,
          2769.7140000000004,
          2732.192,
          2684.952,
          2628.2329999999997,
          2562.364,
          2487.756,
          2404.886,
          2314.283,
          2216.51,
          2112.153,
          2001.808,
          1886.0610000000001,
          1765.489,
          1640.642,
          1512.045,
          1380.193,
          1245.542,
          1108.517,
          969.505,
          828.862,
          686.9069999999999,
          543.931,
          400.195,
          255.93200000000002,
          111.352,
          -33.359,
          -178.03400000000002,
          -322.528,
          -466.71,
          -610.4630000000001,
          -753.688,
          -896.295,
          -1038.204,
          -1179.348,
          -1319.6670000000001,
          -1459.1070000000002,
          -1597.624,
          -1735.1779999999999,
          -1871.737,
          -2007.271,
          -2141.755,
          -2275.169,
          -2407.495,
          -2538.722,
          -2668.8340000000003,
          -2797.825,
          -2925.688,
          -3052.4179999999997,
          -3178.01,
          -3302.4640000000004,
          -3425.778,
          -3547.9559999999997,
          -3668.9959999999996,
          -3788.902,
          -3907.678,
          -4025.328,
          -4141.856,
          -4257.268,
          -4371.57,
          -4484.768,
          -4596.867,
          -4707.876,
          -4817.8,
          -4926.649,
          -5034.429,
          -5141.146,
          -5246.81,
          -5351.429,
          -5455.01,
          -5557.56,
          -5659.088000000001,
          -5759.602,
          -5859.111,
          -5957.621999999999,
          -6055.142,
          -6151.679,
          -6247.243,
          -6341.840999999999,
          -6435.48,
          -6528.168000000001,
          -6619.9130000000005,
          -6710.722,
          -6800.603,
          -6889.564,
          -6977.611,
          -7064.7519999999995,
          -7150.994000000001,
          -7236.345,
          -7320.811,
          -7404.399,
          -7487.116,
          -7568.969,
          -7649.964,
          -7730.109,
          -7809.408,
          -7887.869000000001,
          -7965.499,
          -8042.303000000001,
          -8118.286999999999,
          -8193.458,
          -8267.82,
          -8341.381,
          -8414.145,
          -8486.12,
          -8557.309000000001,
          -8627.719000000001,
          -8697.355,
          -8766.221,
          -8834.325,
          -8901.67,
          -8968.261999999999,
          -9034.105,
          -9099.205,
          -9163.565999999999,
          -9227.194,
          -9290.091999999999,
          -9352.266,
          -9413.721,
          -9474.459,
          -9534.485999999999,
          -9593.806999999999,
          -9652.425,
          -9710.345,
          -9767.57,
          -9824.105,
          -9879.954,
          -9935.121,
          -9989.609,
          -10043.424,
          -10096.567,
          -10149.043,
          -10200.856,
          -10252.008,
          -10302.504,
          -10352.347,
          -10401.541,
          -10450.089,
          -10497.993999999999,
          -10545.258999999998,
          -10591.888,
          -10637.883,
          -10683.248,
          -10727.986,
          -10772.101,
          -10815.594,
          -10858.468,
          -10900.726999999999,
          -10942.374,
          -10983.41,
          -11023.84,
          -11063.665,
          -11102.889,
          -11141.513,
          -11179.541000000001,
          -11216.973999999998,
          -11253.816,
          -11290.069,
          -11325.733999999999,
          -11360.816,
          -11395.316,
          -11429.236,
          -11462.577,
          -11495.344,
          -11527.537,
          -11559.16,
          -11590.213,
          -11620.7,
          -11650.622,
          -11679.98,
          -11708.778999999999,
          -11737.018,
          -11764.7,
          -11791.827,
          -11818.4,
          -11844.423,
          -11869.896,
          -11894.82,
          -11919.198,
          -11943.032,
          -11966.323,
          -11989.073,
          -12011.283000000001,
          -12032.955,
          -12054.091,
          -12074.692,
          -12094.758999999998,
          -12114.294,
          -12133.298999999999,
          -12151.774,
          -12169.722,
          -12187.143999999998,
          -12204.04,
          -12220.413999999999,
          -12236.265,
          -12251.594,
          -12266.403,
          -12280.694,
          -12294.468,
          -12307.725,
          -12320.466999999999,
          -12332.695,
          -12344.411,
          -12355.614,
          -12366.306999999999,
          -12376.49,
          -12386.165,
          -12395.331,
          -12403.991000000002,
          -12412.146,
          -12419.795,
          -12426.941,
          -12433.583999999999,
          -12439.725,
          -12445.364,
          -12450.503,
          -12455.142,
          -12459.282,
          -12462.923999999999,
          -12466.069,
          -12468.718,
          -12470.871000000001,
          -12472.528999999999,
          -12473.692,
          -12474.361,
          -12474.536,
          -12474.22,
          -12473.411,
          -12472.111,
          -12470.32,
          -12468.038999999999,
          -12465.268,
          -12462.008,
          -12458.258999999998,
          -12454.021999999999,
          -12449.296,
          -12444.083999999999,
          -12438.383999999998,
          -12432.198,
          -12425.526000000002,
          -12418.368,
          -12410.723999999998,
          -12402.596000000001,
          -12393.982,
          -12384.883999999998,
          -12375.301000000001,
          -12365.235,
          -12354.684,
          -12343.651000000002,
          -12332.133999999998,
          -12320.133999999998,
          -12307.651000000002,
          -12294.685,
          -12281.236,
          -12267.305,
          -12252.892,
          -12237.996000000001,
          -12222.618,
          -12206.758,
          -12190.416000000001,
          -12173.591999999999,
          -12156.285,
          -12138.497,
          -12120.226,
          -12101.473,
          -12082.238000000001,
          -12062.521,
          -12042.321000000002,
          -12021.64,
          -12000.475,
          -11978.828000000001,
          -11956.697,
          -11934.083999999999,
          -11910.987,
          -11887.407,
          -11863.343,
          -11838.796,
          -11813.764,
          -11788.248,
          -11762.247,
          -11735.761,
          -11708.79,
          -11681.333,
          -11653.39,
          -11624.96,
          -11596.043,
          -11566.64,
          -11536.748,
          -11506.368999999999,
          -11475.502,
          -11444.145,
          -11412.298,
          -11379.961000000001,
          -11347.133999999998,
          -11313.816,
          -11280.006000000001,
          -11245.704,
          -11210.909,
          -11175.62,
          -11139.838,
          -11103.56,
          -11066.787,
          -11029.518,
          -10991.751,
          -10953.488000000001,
          -10914.726,
          -10875.465,
          -10835.705,
          -10795.443000000001,
          -10754.68,
          -10713.413999999999,
          -10671.645,
          -10629.372,
          -10586.595,
          -10543.311000000002,
          -10499.521,
          -10455.223,
          -10410.416,
          -10365.099,
          -10319.271,
          -10272.931999999999,
          -10226.08,
          -10178.714,
          -10130.832,
          -10082.436,
          -10033.521,
          -9984.088,
          -9934.136,
          -9883.662,
          -9832.667,
          -9781.148000000001,
          -9729.105,
          -9676.536,
          -9623.44,
          -9569.815999999999,
          -9515.662,
          -9460.976999999999,
          -9405.76,
          -9350.008,
          -9293.721,
          -9236.896999999999,
          -9179.535,
          -9121.633,
          -9063.19,
          -9004.204,
          -8944.675,
          -8884.599,
          -8823.975,
          -8762.802,
          -8701.078000000001,
          -8638.802,
          -8575.973,
          -8512.587,
          -8448.643,
          -8384.14,
          -8319.076,
          -8253.449,
          -8187.258000000001,
          -8120.5,
          -8053.174,
          -7985.276999999999,
          -7916.809,
          -7847.766,
          -7778.147,
          -7707.951,
          -7637.174,
          -7565.816,
          -7493.874,
          -7421.347,
          -7348.231,
          -7274.526,
          -7200.228,
          -7125.3369999999995,
          -7049.85,
          -6973.764,
          -6897.079000000001,
          -6819.791,
          -6741.898,
          -6663.399,
          -6584.2919999999995,
          -6504.573,
          -6424.241999999999,
          -6343.297,
          -6261.734,
          -6179.552,
          -6096.749,
          -6013.321999999999,
          -5929.27,
          -5844.590999999999,
          -5759.283,
          -5673.343000000001,
          -5586.771,
          -5499.563,
          -5411.718000000001,
          -5323.234,
          -5234.111,
          -5144.345,
          -5053.935,
          -4962.879,
          -4871.177,
          -4778.827,
          -4685.827,
          -4592.178,
          -4497.876,
          -4402.923,
          -4307.315,
          -4211.055,
          -4114.14,
          -4016.571,
          -3918.348,
          -3819.4709999999995,
          -3719.94,
          -3619.756,
          -3518.921,
          -3417.4359999999997,
          -3315.303,
          -3212.5240000000003,
          -3109.1009999999997,
          -3005.038,
          -2900.3379999999997,
          -2795.005,
          -2689.045,
          -2582.4629999999997,
          -2475.265,
          -2367.4570000000003,
          -2259.048,
          -2150.047,
          -2040.463,
          -1930.307,
          -1819.592,
          -1708.3310000000001,
          -1596.5379999999998,
          -1484.231,
          -1371.4270000000001,
          -1258.1480000000001,
          -1144.415,
          -1030.253,
          -915.689,
          -800.7539999999999,
          -685.48,
          -569.904,
          -454.065,
          -338.00800000000004,
          -221.78099999999998,
          -105.43799999999999,
          10.963,
          127.35799999999999,
          243.674,
          359.834,
          475.75199999999995,
          591.3330000000001,
          706.472,
          821.056,
          934.957,
          1048.037,
          1160.144,
          1271.112,
          1380.754,
          1488.872,
          1595.2420000000002,
          1699.6229999999998,
          1801.754,
          1901.344,
          1998.0839999999998,
          2091.634,
          2181.629,
          2267.678,
          2349.363,
          2426.24,
          2497.842,
          2563.685,
          2623.2659999999996,
          2676.079,
          2721.613,
          2759.373,
          2788.883,
          2809.703,
          2821.441,
          2823.7709999999997,
          2816.441,
          2799.2859999999996,
          2772.238,
          2735.3309999999997,
          2688.698,
          2632.572,
          2567.279,
          2493.223,
          2410.8779999999997,
          2320.768,
          2223.4570000000003,
          2119.529,
          2009.5770000000002,
          1894.1889999999999,
          1773.941,
          1649.386,
          1521.0510000000002,
          1389.4289999999999,
          1254.982,
          1118.136,
          979.278,
          838.7660000000001,
          696.924,
          554.0409999999999,
          410.38199999999995,
          266.181,
          121.649,
          -23.026,
          -167.678,
          -312.158,
          -456.334,
          -600.091,
          -743.326,
          -885.95,
          -1027.883,
          -1169.066,
          -1309.407,
          -1448.884,
          -1587.443,
          -1725.043,
          -1861.649,
          -1997.233,
          -2131.77,
          -2265.24,
          -2397.623,
          -2528.907,
          -2659.08,
          -2788.134,
          -2916.059,
          -3042.8520000000003,
          -3168.509,
          -3293.0290000000005,
          -3416.41,
          -3538.6540000000005,
          -3659.761,
          -3779.736,
          -3898.58,
          -4016.297,
          -4132.894,
          -4248.375,
          -4362.746,
          -4476.012,
          -4588.18,
          -4699.259,
          -4809.253,
          -4918.17,
          -5026.018,
          -5132.805,
          -5238.538,
          -5343.225,
          -5446.8730000000005,
          -5549.493,
          -5651.089,
          -5751.670999999999,
          -5851.246,
          -5949.8240000000005,
          -6047.411999999999,
          -6144.017,
          -6239.647,
          -6334.311,
          -6428.017,
          -6520.77,
          -6612.58,
          -6703.455,
          -6793.401,
          -6882.427,
          -6970.5380000000005,
          -7057.744000000001,
          -7144.05,
          -7229.465,
          -7313.994000000001,
          -7397.645,
          -7480.425,
          -7562.34,
          -7643.398,
          -7723.604,
          -7802.965999999999,
          -7881.488,
          -7959.179,
          -8036.044,
          -8112.089,
          -8187.32,
          -8261.742,
          -8335.363000000001,
          -8408.188,
          -8480.221,
          -8551.469000000001,
          -8621.938,
          -8691.632,
          -8760.556999999999,
          -8828.718,
          -8896.122,
          -8962.771,
          -9028.671,
          -9093.828000000001,
          -9158.246,
          -9221.93,
          -9284.885,
          -9347.115,
          -9408.625,
          -9469.419,
          -9529.501,
          -9588.878,
          -9647.55,
          -9705.525,
          -9762.804,
          -9819.394,
          -9875.296,
          -9930.517,
          -9985.06,
          -10038.927,
          -10092.123,
          -10144.652,
          -10196.517,
          -10247.722,
          -10298.27,
          -10348.166,
          -10397.412,
          -10446.011,
          -10493.966999999999,
          -10541.284,
          -10587.964,
          -10634.01,
          -10679.426000000001,
          -10724.215,
          -10768.378999999999,
          -10811.921999999999,
          -10854.846000000001,
          -10897.155,
          -10938.851,
          -10979.938,
          -11020.417,
          -11060.291000000001,
          -11099.563,
          -11138.236,
          -11176.312,
          -11213.794,
          -11250.684,
          -11286.985,
          -11322.698999999999,
          -11357.828000000001,
          -11392.375,
          -11426.341999999999,
          -11459.731000000002,
          -11492.545,
          -11524.786,
          -11556.455,
          -11587.555,
          -11618.088,
          -11648.056,
          -11677.46,
          -11706.305,
          -11734.59,
          -11762.318000000001,
          -11789.49,
          -11816.108999999999,
          -11842.177,
          -11867.694,
          -11892.663999999999,
          -11917.088,
          -11940.966,
          -11964.302,
          -11987.096000000001,
          -12009.35,
          -12031.067,
          -12052.246000000001,
          -12072.891000000001,
          -12093.002,
          -12112.581,
          -12131.63,
          -12150.149,
          -12168.14,
          -12185.605,
          -12202.544,
          -12218.96,
          -12234.853000000001,
          -12250.226,
          -12265.078000000001,
          -12279.411,
          -12293.226999999999,
          -12306.527,
          -12319.311000000002,
          -12331.581,
          -12343.338,
          -12354.583999999999,
          -12365.318000000001,
          -12375.543,
          -12385.258999999998,
          -12394.466999999999,
          -12403.168,
          -12411.363000000001,
          -12419.053999999998,
          -12426.24,
          -12432.923999999999,
          -12439.106000000002,
          -12444.785,
          -12449.965,
          -12454.643999999998,
          -12458.825,
          -12462.507,
          -12465.692,
          -12468.38,
          -12470.573,
          -12472.271,
          -12473.473,
          -12474.181999999999,
          -12474.396999999999,
          -12474.12,
          -12473.35,
          -12472.09,
          -12470.338,
          -12468.096000000001,
          -12465.364,
          -12462.142,
          -12458.431999999999,
          -12454.233,
          -12449.546999999999,
          -12444.373,
          -12438.711000000001,
          -12432.563999999998,
          -12425.93,
          -12418.81,
          -12411.204,
          -12403.113000000001,
          -12394.537,
          -12385.476999999999,
          -12375.931999999999,
          -12365.903,
          -12355.39,
          -12344.393999999998,
          -12332.915,
          -12320.952,
          -12308.506000000001,
          -12295.577,
          -12282.166000000001,
          -12268.271999999999,
          -12253.895,
          -12239.037,
          -12223.696000000002,
          -12207.872,
          -12191.567,
          -12174.778999999999,
          -12157.508999999998,
          -12139.757,
          -12121.521999999999,
          -12102.806,
          -12083.607,
          -12063.926000000001,
          -12043.763,
          -12023.117,
          -12001.988000000001,
          -11980.376,
          -11958.282,
          -11935.704,
          -11912.643,
          -11889.098,
          -11865.07,
          -11840.558,
          -11815.562,
          -11790.081,
          -11764.115,
          -11737.665,
          -11710.728000000001,
          -11683.306,
          -11655.398000000001,
          -11627.003999999999,
          -11598.123,
          -11568.753999999999,
          -11538.896999999999,
          -11508.552,
          -11477.719,
          -11446.396999999999,
          -11414.583999999999,
          -11382.282,
          -11349.49,
          -11316.206,
          -11282.431,
          -11248.163,
          -11213.402,
          -11178.146999999999,
          -11142.398000000001,
          -11106.155,
          -11069.417,
          -11032.181,
          -10994.448999999999,
          -10956.219,
          -10917.491000000002,
          -10878.264,
          -10838.537,
          -10798.309,
          -10757.579,
          -10716.348,
          -10674.613000000001,
          -10632.374,
          -10589.628999999999,
          -10546.378999999999,
          -10502.622,
          -10458.357,
          -10413.583,
          -10368.3,
          -10322.506,
          -10276.2,
          -10229.381,
          -10182.048,
          -10134.2,
          -10085.835,
          -10036.954,
          -9987.554,
          -9937.635,
          -9887.194,
          -9836.232,
          -9784.746,
          -9732.735999999999,
          -9680.199,
          -9627.136,
          -9573.544,
          -9519.423,
          -9464.771,
          -9409.586,
          -9353.867,
          -9297.612,
          -9240.821,
          -9183.491,
          -9125.622,
          -9067.211,
          -9008.258,
          -8948.761,
          -8888.716999999999,
          -8828.126,
          -8766.985,
          -8705.294,
          -8643.05,
          -8580.253,
          -8516.899,
          -8452.988000000001,
          -8388.517,
          -8323.485,
          -8257.891,
          -8191.731,
          -8125.005,
          -8057.710999999999,
          -7989.847,
          -7921.411,
          -7852.4,
          -7782.813,
          -7712.649,
          -7641.904,
          -7570.578,
          -7498.668000000001,
          -7426.173000000001,
          -7353.09,
          -7279.416,
          -7205.151,
          -7130.291,
          -7054.835999999999,
          -6978.781999999999,
          -6902.129,
          -6824.8730000000005,
          -6747.012,
          -6668.545,
          -6589.469,
          -6509.781999999999,
          -6429.483,
          -6348.569,
          -6267.0380000000005,
          -6184.888000000001,
          -6102.116,
          -6018.721,
          -5934.701,
          -5850.053000000001,
          -5764.776999999999,
          -5678.869000000001,
          -5592.328,
          -5505.151,
          -5417.338000000001,
          -5328.885,
          -5239.793,
          -5150.058,
          -5059.679,
          -4968.655,
          -4876.984,
          -4784.665,
          -4691.696,
          -4598.077,
          -4503.807,
          -4408.883,
          -4313.306,
          -4217.076,
          -4120.191,
          -4022.652,
          -3924.4590000000003,
          -3825.611,
          -3726.11,
          -3625.9559999999997,
          -3525.15,
          -3423.6929999999998,
          -3321.5890000000004,
          -3218.8379999999997,
          -3115.4429999999998,
          -3011.407,
          -2906.735,
          -2801.429,
          -2695.495,
          -2588.938,
          -2481.765,
          -2373.9829999999997,
          -2265.598,
          -2156.62,
          -2047.058,
          -1936.924,
          -1826.23,
          -1714.989,
          -1603.2160000000001,
          -1490.9260000000002,
          -1378.14,
          -1264.876,
          -1151.157,
          -1037.007,
          -922.454,
          -807.5269999999999,
          -692.26,
          -576.688,
          -460.851,
          -344.793,
          -228.563,
          -112.212,
          4.2,
          120.60799999999999,
          236.94400000000002,
          353.12800000000004,
          469.074,
          584.69,
          699.87,
          814.5010000000001,
          928.457,
          1041.6019999999999,
          1153.782,
          1264.8319999999999,
          1374.569,
          1482.7920000000001,
          1589.2820000000002,
          1693.7979999999998,
          1796.078,
          1895.836,
          1992.763,
          2086.52,
          2176.745,
          2263.048,
          2345.012,
          2422.196,
          2494.134,
          2560.342,
          2620.32,
          2673.5609999999997,
          2719.5559999999996,
          2757.8070000000002,
          2787.8379999999997,
          2809.2059999999997,
          2821.518,
          2824.442,
          2817.722,
          2801.188,
          2774.768,
          2738.486,
          2692.472,
          2636.952,
          2572.246,
          2498.754,
          2416.945,
          2327.341,
          2230.5029999999997,
          2127.013,
          2017.464,
          1902.443,
          1782.529,
          1658.274,
          1530.207,
          1398.8220000000001,
          1264.585,
          1127.921,
          989.222,
          848.846,
          707.1189999999999,
          564.3340000000001,
          420.754,
          276.616,
          132.134,
          -12.504000000000001,
          -157.13,
          -301.595,
          -445.765,
          -589.525,
          -732.77,
          -875.4110000000001,
          -1017.367,
          -1158.568,
          -1298.953,
          -1438.4679999999998,
          -1577.068,
          -1714.713,
          -1851.368,
          -1987.003,
          -2121.594,
          -2255.119,
          -2387.561,
          -2518.905,
          -2649.139,
          -2778.255,
          -2906.244,
          -3033.1020000000003,
          -3158.824,
          -3283.4109999999996,
          -3406.86,
          -3529.171,
          -3650.347,
          -3770.39,
          -3889.303,
          -4007.091,
          -4123.7570000000005,
          -4239.308,
          -4353.749,
          -4467.085,
          -4579.3240000000005,
          -4690.472,
          -4800.536,
          -4909.524,
          -5017.442,
          -5124.299,
          -5230.102,
          -5334.858,
          -5438.576999999999,
          -5541.265,
          -5642.931,
          -5743.581999999999,
          -5843.226,
          -5941.871999999999,
          -6039.529,
          -6136.201999999999,
          -6231.9,
          -6326.630999999999,
          -6420.404,
          -6513.225,
          -6605.102,
          -6696.043000000001,
          -6786.055,
          -6875.147,
          -6963.3240000000005,
          -7050.595,
          -7136.967,
          -7222.446,
          -7307.04,
          -7390.755,
          -7473.599,
          -7555.578,
          -7636.7,
          -7716.969,
          -7796.393,
          -7874.979,
          -7952.731,
          -8029.658,
          -8105.765,
          -8181.058000000001,
          -8255.541,
          -8329.223,
          -8402.108,
          -8474.202,
          -8545.511,
          -8616.039,
          -8685.792,
          -8754.777,
          -8822.998,
          -8890.46,
          -8957.167,
          -9023.126,
          -9088.341,
          -9152.817,
          -9216.559000000001,
          -9279.571,
          -9341.858,
          -9403.425,
          -9464.275,
          -9524.414,
          -9583.846,
          -9642.575,
          -9700.605,
          -9757.94,
          -9814.585,
          -9870.543,
          -9925.818000000001,
          -9980.415,
          -10034.337,
          -10087.587,
          -10140.17,
          -10192.089,
          -10243.347,
          -10293.949,
          -10343.898000000001,
          -10393.196,
          -10441.848,
          -10489.857,
          -10537.225,
          -10583.957,
          -10630.056,
          -10675.524,
          -10720.364,
          -10764.579,
          -10808.173,
          -10851.148000000001,
          -10893.508,
          -10935.255,
          -10976.392,
          -11016.921,
          -11056.845,
          -11096.167,
          -11134.89,
          -11173.015,
          -11210.546,
          -11247.486,
          -11283.836000000001,
          -11319.598999999998,
          -11354.776000000002,
          -11389.372,
          -11423.386999999999,
          -11456.825,
          -11489.687,
          -11521.975,
          -11553.692,
          -11584.839,
          -11615.419,
          -11645.435,
          -11674.886999999999,
          -11703.778,
          -11732.11,
          -11759.885,
          -11787.103000000001,
          -11813.768999999998,
          -11839.882,
          -11865.446000000002,
          -11890.462,
          -11914.931,
          -11938.855,
          -11962.236,
          -11985.076000000001,
          -12007.376,
          -12029.136999999999,
          -12050.361,
          -12071.051000000001,
          -12091.207,
          -12110.831,
          -12129.923999999999,
          -12148.487,
          -12166.521999999999,
          -12184.031,
          -12201.014,
          -12217.473999999998,
          -12233.411,
          -12248.827,
          -12263.723,
          -12278.1,
          -12291.958999999999,
          -12305.301000000001,
          -12318.128,
          -12330.441,
          -12342.241000000002,
          -12353.528999999999,
          -12364.306,
          -12374.573,
          -12384.331,
          -12393.582,
          -12402.325,
          -12410.562,
          -12418.294,
          -12425.523000000001,
          -12432.248,
          -12438.471000000001,
          -12444.192,
          -12449.413,
          -12454.133999999998,
          -12458.355,
          -12462.079,
          -12465.305,
          -12468.034,
          -12470.267,
          -12472.005,
          -12473.249,
          -12473.998,
          -12474.253,
          -12474.016000000001,
          -12473.287,
          -12472.066,
          -12470.354,
          -12468.152,
          -12465.46,
          -12462.278,
          -12458.607,
          -12454.448,
          -12449.801000000001,
          -12444.666000000001,
          -12439.044,
          -12432.935,
          -12426.34,
          -12419.258999999998,
          -12411.693000000001,
          -12403.64,
          -12395.103000000001,
          -12386.081,
          -12376.575,
          -12366.585,
          -12356.11,
          -12345.152,
          -12333.711000000001,
          -12321.787,
          -12309.378999999999,
          -12296.488000000001,
          -12283.114,
          -12269.258,
          -12254.919,
          -12240.098,
          -12224.795,
          -12209.008999999998,
          -12192.741000000002,
          -12175.99,
          -12158.757,
          -12141.042,
          -12122.845,
          -12104.166000000001,
          -12085.003999999999,
          -12065.36,
          -12045.233999999999,
          -12024.624,
          -12003.532,
          -11981.957,
          -11959.899,
          -11937.358,
          -11914.333,
          -11890.825,
          -11866.833,
          -11842.358,
          -11817.398000000001,
          -11791.953000000001,
          -11766.023000000001,
          -11739.608,
          -11712.708,
          -11685.322,
          -11657.45,
          -11629.091,
          -11600.246000000001,
          -11570.912,
          -11541.091,
          -11510.782,
          -11479.983999999999,
          -11448.697,
          -11416.921,
          -11384.653999999999,
          -11351.896999999999,
          -11318.648000000001,
          -11284.908000000001,
          -11250.675,
          -11215.948999999999,
          -11180.729,
          -11145.015,
          -11108.806999999999,
          -11072.103000000001,
          -11034.903,
          -10997.206,
          -10959.011999999999,
          -10920.318000000001,
          -10881.125,
          -10841.431999999999,
          -10801.239,
          -10760.544,
          -10719.346000000001,
          -10677.646999999999,
          -10635.442,
          -10592.731000000002,
          -10549.515,
          -10505.793,
          -10461.562,
          -10416.822,
          -10371.573,
          -10325.813,
          -10279.541,
          -10232.756,
          -10185.457,
          -10137.643,
          -10089.312,
          -10040.464,
          -9991.098,
          -9941.213,
          -9890.806,
          -9839.877,
          -9788.425,
          -9736.448,
          -9683.946,
          -9630.916,
          -9577.358,
          -9523.27,
          -9468.651,
          -9413.5,
          -9357.814,
          -9301.593,
          -9244.835,
          -9187.539,
          -9129.703000000001,
          -9071.326,
          -9012.405999999999,
          -8952.942,
          -8892.931,
          -8832.373,
          -8771.266,
          -8709.608,
          -8647.398000000001,
          -8584.633,
          -8521.312,
          -8457.434000000001,
          -8392.996,
          -8327.998,
          -8262.436,
          -8196.31,
          -8129.616999999999,
          -8062.356,
          -7994.525,
          -7926.121,
          -7857.143,
          -7787.59,
          -7717.4580000000005,
          -7646.746999999999,
          -7575.454000000001,
          -7503.576999999999,
          -7431.1140000000005,
          -7358.063,
          -7284.423000000001,
          -7210.19,
          -7135.3640000000005,
          -7059.941,
          -6983.92,
          -6907.299,
          -6830.075,
          -6752.246999999999,
          -6673.814,
          -6594.771,
          -6515.116999999999,
          -6434.85,
          -6353.968000000001,
          -6272.469,
          -6190.352,
          -6107.613,
          -6024.251,
          -5940.263000000001,
          -5855.648,
          -5770.404,
          -5684.528,
          -5598.019,
          -5510.875,
          -5423.094,
          -5334.674,
          -5245.613,
          -5155.91,
          -5065.564,
          -4974.572,
          -4882.933,
          -4790.645,
          -4697.708,
          -4604.121,
          -4509.8820000000005,
          -4414.99,
          -4319.444,
          -4223.245,
          -4126.391,
          -4028.883,
          -3930.7209999999995,
          -3831.903,
          -3732.4320000000002,
          -3632.308,
          -3531.532,
          -3430.1059999999998,
          -3328.031,
          -3225.308,
          -3121.942,
          -3017.935,
          -2913.29,
          -2808.012,
          -2702.105,
          -2595.576,
          -2488.428,
          -2380.6710000000003,
          -2272.311,
          -2163.357,
          -2053.819,
          -1943.7079999999999,
          -1833.036,
          -1721.815,
          -1610.0610000000001,
          -1497.79,
          -1385.021,
          -1271.7730000000001,
          -1158.068,
          -1043.932,
          -929.39,
          -814.4730000000001,
          -699.212,
          -583.645,
          -467.81,
          -351.751,
          -235.517,
          -119.16,
          -2.737,
          113.686,
          230.041,
          346.24800000000005,
          462.224,
          577.874,
          693.095,
          807.775,
          921.788,
          1034.997,
          1147.251,
          1258.385,
          1368.2179999999998,
          1476.549,
          1583.161,
          1687.8129999999999,
          1790.246,
          1890.175,
          1987.2920000000001,
          2081.26,
          2171.719,
          2258.281,
          2340.53,
          2418.026,
          2490.3070000000002,
          2556.887,
          2617.271,
          2670.948,
          2717.4120000000003,
          2756.165,
          2786.7270000000003,
          2808.656,
          2821.554,
          2825.085,
          2818.99,
          2803.092,
          2777.3140000000003,
          2741.673,
          2696.2940000000003,
          2641.395,
          2577.292,
          2504.379,
          2423.121,
          2334.038,
          2237.686,
          2134.646,
          2025.5120000000002,
          1910.87,
          1791.299,
          1667.3529999999998,
          1539.5620000000001,
          1408.424,
          1274.403,
          1137.928,
          999.393,
          859.158,
          717.55,
          574.865,
          431.36699999999996,
          287.296,
          142.866,
          -1.734,
          -146.333,
          -290.781,
          -434.945,
          -578.707,
          -721.962,
          -864.62,
          -1006.5989999999999,
          -1147.828,
          -1288.247,
          -1427.8010000000002,
          -1566.444,
          -1704.134,
          -1840.838,
          -1976.525,
          -2111.17,
          -2244.7529999999997,
          -2377.254,
          -2508.658,
          -2638.9559999999997,
          -2768.135,
          -2896.1890000000003,
          -3023.113,
          -3148.9040000000005,
          -3273.558,
          -3397.075,
          -3519.4559999999997,
          -3640.703,
          -3760.816,
          -3879.8,
          -3997.659,
          -4114.397,
          -4230.019,
          -4344.532,
          -4457.94,
          -4570.25,
          -4681.47,
          -4791.606,
          -4900.666,
          -5008.656,
          -5115.584,
          -5221.459,
          -5326.286999999999,
          -5430.076,
          -5532.835999999999,
          -5634.571999999999,
          -5735.293000000001,
          -5835.008000000001,
          -5933.725,
          -6031.451,
          -6128.193,
          -6223.960999999999,
          -6318.762,
          -6412.604,
          -6505.493,
          -6597.438,
          -6688.448,
          -6778.528,
          -6867.687,
          -6955.931,
          -7043.269,
          -7129.706999999999,
          -7215.253000000001,
          -7299.9130000000005,
          -7383.694,
          -7466.604,
          -7548.649,
          -7629.834,
          -7710.168000000001,
          -7789.656999999999,
          -7868.307,
          -7946.1230000000005,
          -8023.1140000000005,
          -8099.283,
          -8174.638000000001,
          -8249.185,
          -8322.93,
          -8395.877,
          -8468.032,
          -8539.402,
          -8609.992,
          -8679.806999999999,
          -8748.851999999999,
          -8817.133,
          -8884.655,
          -8951.423,
          -9017.442,
          -9082.716,
          -9147.251,
          -9211.051,
          -9274.122,
          -9336.468,
          -9398.093,
          -9459.001,
          -9519.198,
          -9578.687,
          -9637.473,
          -9695.56,
          -9752.952,
          -9809.653,
          -9865.668,
          -9920.999,
          -9975.651,
          -10029.629,
          -10082.935,
          -10135.573,
          -10187.546,
          -10238.86,
          -10289.516,
          -10339.519,
          -10388.872,
          -10437.578000000001,
          -10485.64,
          -10533.062,
          -10579.847,
          -10625.999,
          -10671.518999999998,
          -10716.412,
          -10760.68,
          -10804.326000000001,
          -10847.354,
          -10889.765,
          -10931.565,
          -10972.753,
          -11013.333,
          -11053.308,
          -11092.681,
          -11131.455,
          -11169.631000000001,
          -11207.213,
          -11244.203000000001,
          -11280.603000000001,
          -11316.415,
          -11351.643,
          -11386.288,
          -11420.353000000001,
          -11453.84,
          -11486.751,
          -11519.088,
          -11550.853000000001,
          -11582.048999999999,
          -11612.678,
          -11642.743,
          -11672.243,
          -11701.181999999999,
          -11729.561000000002,
          -11757.383,
          -11784.65,
          -11811.362,
          -11837.524,
          -11863.135,
          -11888.197,
          -11912.713,
          -11936.684,
          -11960.112,
          -11982.998,
          -12005.344,
          -12027.152,
          -12048.421999999999,
          -12069.158000000001,
          -12089.358999999999,
          -12109.028,
          -12128.166000000001,
          -12146.775,
          -12164.856000000002,
          -12182.41,
          -12199.438999999998,
          -12215.943000000001,
          -12231.925,
          -12247.385,
          -12262.325,
          -12276.746000000001,
          -12290.649,
          -12304.036,
          -12316.907,
          -12329.264,
          -12341.108,
          -12352.438999999998,
          -12363.26,
          -12373.57,
          -12383.372,
          -12392.665,
          -12401.452,
          -12409.732,
          -12417.507,
          -12424.778,
          -12431.546,
          -12437.811000000002,
          -12443.575,
          -12448.838,
          -12453.601,
          -12457.865,
          -12461.63,
          -12464.898000000001,
          -12467.669,
          -12469.944,
          -12471.723,
          -12473.008,
          -12473.798,
          -12474.095,
          -12473.899,
          -12473.211000000001,
          -12472.031,
          -12470.36,
          -12468.198999999999,
          -12465.546999999999,
          -12462.406,
          -12458.775,
          -12454.656,
          -12450.048999999999,
          -12444.955,
          -12439.373,
          -12433.305,
          -12426.749,
          -12419.708,
          -12412.181,
          -12404.169,
          -12395.671,
          -12386.688999999998,
          -12377.222,
          -12367.271,
          -12356.836000000001,
          -12345.917,
          -12334.515,
          -12322.628999999999,
          -12310.26,
          -12297.408000000001,
          -12284.073,
          -12270.256000000001,
          -12255.956,
          -12241.173,
          -12225.908000000001,
          -12210.16,
          -12193.93,
          -12177.218,
          -12160.023000000001,
          -12142.346000000001,
          -12124.188,
          -12105.546999999999,
          -12086.421999999999,
          -12066.816,
          -12046.726999999999,
          -12026.155,
          -12005.101,
          -11983.563,
          -11961.543,
          -11939.04,
          -11916.052,
          -11892.581,
          -11868.626,
          -11844.188,
          -11819.264,
          -11793.857,
          -11767.964,
          -11741.586000000001,
          -11714.723,
          -11687.373,
          -11659.538,
          -11631.215,
          -11602.406,
          -11573.11,
          -11543.323999999999,
          -11513.052,
          -11482.291000000001,
          -11451.04,
          -11419.3,
          -11387.069,
          -11354.347,
          -11321.133999999998,
          -11287.43,
          -11253.233,
          -11218.544,
          -11183.36,
          -11147.681999999999,
          -11111.508999999998,
          -11074.84,
          -11037.676000000001,
          -11000.014,
          -10961.855,
          -10923.197,
          -10884.038999999999,
          -10844.382,
          -10804.223999999998,
          -10763.563999999998,
          -10722.402,
          -10680.737,
          -10638.567,
          -10595.892,
          -10552.711000000001,
          -10509.023000000001,
          -10464.827,
          -10420.123,
          -10374.908000000001,
          -10329.183,
          -10282.946,
          -10236.196,
          -10188.931,
          -10141.152,
          -10092.856,
          -10044.043,
          -9994.711,
          -9944.86,
          -9894.488000000001,
          -9843.594000000001,
          -9792.176,
          -9740.234,
          -9687.765,
          -9634.77,
          -9581.247,
          -9527.193000000001,
          -9472.608,
          -9417.491,
          -9361.839,
          -9305.652,
          -9248.928,
          -9191.666,
          -9133.864,
          -9075.521999999999,
          -9016.636,
          -8957.205,
          -8897.228000000001,
          -8836.704,
          -8775.631,
          -8714.007,
          -8651.831,
          -8589.1,
          -8525.813,
          -8461.969000000001,
          -8397.565,
          -8332.6,
          -8267.073,
          -8200.979,
          -8134.321,
          -8067.093000000001,
          -7999.295,
          -7930.925,
          -7861.981,
          -7792.460999999999,
          -7722.3640000000005,
          -7651.686,
          -7580.427,
          -7508.5830000000005,
          -7436.153,
          -7363.1359999999995,
          -7289.529,
          -7215.331,
          -7140.536999999999,
          -7065.148,
          -6989.161,
          -6912.573,
          -6835.383000000001,
          -6757.588000000001,
          -6679.188,
          -6600.178000000001,
          -6520.558000000001,
          -6440.3240000000005,
          -6359.476,
          -6278.0109999999995,
          -6195.9259999999995,
          -6113.221,
          -6029.892,
          -5945.937,
          -5861.355,
          -5776.144,
          -5690.302,
          -5603.826,
          -5516.714,
          -5428.965999999999,
          -5340.579000000001,
          -5251.5509999999995,
          -5161.8820000000005,
          -5071.568,
          -4980.608,
          -4889.001,
          -4796.746,
          -4703.842000000001,
          -4610.286,
          -4516.08,
          -4421.22,
          -4325.706,
          -4229.539000000001,
          -4132.717000000001,
          -4035.24,
          -3937.1090000000004,
          -3838.323,
          -3738.883,
          -3638.789,
          -3538.0440000000003,
          -3436.6479999999997,
          -3334.6020000000003,
          -3231.91,
          -3128.573,
          -3024.594,
          -2919.978,
          -2814.728,
          -2708.849,
          -2602.347,
          -2495.226,
          -2387.495,
          -2279.16,
          -2170.231,
          -2060.717,
          -1950.629,
          -1839.979,
          -1728.779,
          -1617.045,
          -1504.793,
          -1392.0420000000001,
          -1278.81,
          -1165.12,
          -1050.997,
          -936.466,
          -821.559,
          -706.305,
          -590.743,
          -474.91,
          -358.851,
          -242.613,
          -126.249,
          -9.816,
          106.62299999999999,
          222.99599999999998,
          339.228,
          455.233,
          570.918,
          686.182,
          800.91,
          914.98,
          1028.255,
          1140.5839999999998,
          1251.803,
          1361.733,
          1470.1729999999998,
          1576.908,
          1681.6989999999998,
          1784.2879999999998,
          1884.389,
          1981.6979999999999,
          2075.881,
          2166.577,
          2253.4,
          2335.938,
          2413.751,
          2486.379,
          2553.337,
          2614.131,
          2668.2509999999997,
          2715.192,
          2754.453,
          2785.555,
          2808.052,
          2821.546,
          2825.6940000000004,
          2820.2340000000004,
          2804.9840000000004,
          2779.8590000000004,
          2744.8709999999996,
          2700.137,
          2645.873,
          2582.385,
          2510.063,
          2429.368,
          2340.8160000000003,
          2244.9610000000002,
          2142.383,
          2033.674,
          1919.42,
          1800.201,
          1676.5720000000001,
          1549.065,
          1418.1789999999999,
          1284.38,
          1148.099,
          1009.732,
          869.6419999999999,
          728.1569999999999,
          585.575,
          442.163,
          298.161,
          153.785,
          9.226,
          -135.345,
          -279.776,
          -423.93300000000005,
          -567.696,
          -710.96,
          -853.6339999999999,
          -995.637,
          -1136.799,
          -1277.347,
          -1416.9389999999999,
          -1555.625,
          -1693.362,
          -1830.116,
          -1965.855,
          -2100.556,
          -2234.197,
          -2366.757,
          -2498.224,
          -2628.5840000000003,
          -2757.829,
          -2885.949,
          -3012.941,
          -3138.7990000000004,
          -3263.522,
          -3387.1090000000004,
          -3509.5609999999997,
          -3630.8779999999997,
          -3751.063,
          -3870.119,
          -3988.05,
          -4104.86,
          -4220.555,
          -4335.14,
          -4448.622,
          -4561.005999999999,
          -4672.298,
          -4782.508,
          -4891.64,
          -4999.7029999999995,
          -5106.704000000001,
          -5212.652,
          -5317.552,
          -5421.414000000001,
          -5524.245,
          -5626.053000000001,
          -5726.847,
          -5826.634,
          -5925.420999999999,
          -6023.219,
          -6120.031999999999,
          -6215.87,
          -6310.741,
          -6404.653,
          -6497.611999999999,
          -6589.6269999999995,
          -6680.706,
          -6770.855,
          -6860.0830000000005,
          -6948.396,
          -7035.802,
          -7122.308000000001,
          -7207.920999999999,
          -7292.648,
          -7376.496,
          -7459.472,
          -7541.584,
          -7622.835999999999,
          -7703.235,
          -7782.789000000001,
          -7861.504,
          -7939.3859999999995,
          -8016.441,
          -8092.675,
          -8168.094,
          -8242.704,
          -8316.511999999999,
          -8389.521999999999,
          -8461.741,
          -8533.173,
          -8603.826,
          -8673.703000000001,
          -8742.81,
          -8811.152,
          -8878.735,
          -8945.564,
          -9011.644,
          -9076.979,
          -9141.574,
          -9205.434000000001,
          -9268.565,
          -9330.97,
          -9392.654,
          -9453.622,
          -9513.877,
          -9573.424,
          -9632.269,
          -9690.414,
          -9747.864,
          -9804.623,
          -9860.694,
          -9916.083,
          -9970.792,
          -10024.825,
          -10078.188,
          -10130.882,
          -10182.912,
          -10234.280999999999,
          -10284.993,
          -10335.051,
          -10384.459,
          -10433.22,
          -10481.337,
          -10528.813,
          -10575.653,
          -10621.858,
          -10667.433,
          -10712.378999999999,
          -10756.701000000001,
          -10800.4,
          -10843.481000000002,
          -10885.945,
          -10927.796999999999,
          -10969.037,
          -11009.67,
          -11049.698,
          -11089.123,
          -11127.948,
          -11166.176000000001,
          -11203.809,
          -11240.85,
          -11277.301000000001,
          -11313.163999999999,
          -11348.443000000001,
          -11383.139,
          -11417.253999999999,
          -11450.791000000001,
          -11483.752,
          -11516.139,
          -11547.954,
          -11579.2,
          -11609.878,
          -11639.992,
          -11669.541000000001,
          -11698.528999999999,
          -11726.957,
          -11754.828000000001,
          -11782.143,
          -11808.903999999999,
          -11835.113000000001,
          -11860.771999999999,
          -11885.883,
          -11910.446000000002,
          -11934.465,
          -11957.94,
          -11980.873,
          -12003.267,
          -12025.121000000001,
          -12046.438999999998,
          -12067.221000000001,
          -12087.469,
          -12107.184,
          -12126.368999999999,
          -12145.024,
          -12163.15,
          -12180.751,
          -12197.825,
          -12214.375,
          -12230.403,
          -12245.908000000001,
          -12260.893,
          -12275.36,
          -12289.308,
          -12302.74,
          -12315.656,
          -12328.058,
          -12339.946000000002,
          -12351.322,
          -12362.186000000002,
          -12372.541000000001,
          -12382.386999999999,
          -12391.725,
          -12400.555,
          -12408.878999999999,
          -12416.697,
          -12424.011999999999,
          -12430.823999999999,
          -12437.131000000001,
          -12442.938999999998,
          -12448.245,
          -12453.051000000001,
          -12457.358,
          -12461.166000000001,
          -12464.476,
          -12467.29,
          -12469.607,
          -12471.428999999998,
          -12472.756000000001,
          -12473.589,
          -12473.928,
          -12473.774,
          -12473.127,
          -12471.989,
          -12470.36,
          -12468.241000000002,
          -12465.63,
          -12462.53,
          -12458.941,
          -12454.864,
          -12450.298,
          -12445.245,
          -12439.703000000001,
          -12433.676000000001,
          -12427.162,
          -12420.161,
          -12412.675,
          -12404.703000000001,
          -12396.245,
          -12387.303,
          -12377.877,
          -12367.966,
          -12357.572,
          -12346.693000000001,
          -12335.33,
          -12323.483999999999,
          -12311.155,
          -12298.341999999999,
          -12285.048,
          -12271.27,
          -12257.008999999998,
          -12242.266000000001,
          -12227.04,
          -12211.331,
          -12195.14,
          -12178.466999999999,
          -12161.312,
          -12143.673999999999,
          -12125.553999999998,
          -12106.951000000001,
          -12087.866000000002,
          -12068.298,
          -12048.247,
          -12027.714,
          -12006.698999999999,
          -11985.2,
          -11963.216999999999,
          -11940.752,
          -11917.803,
          -11894.37,
          -11870.453000000001,
          -11846.052,
          -11821.167,
          -11795.796999999999,
          -11769.942,
          -11743.601999999999,
          -11716.776000000002,
          -11689.464,
          -11661.666000000001,
          -11633.381000000001,
          -11604.608999999999,
          -11575.35,
          -11545.603000000001,
          -11515.367,
          -11484.642,
          -11453.428999999998,
          -11421.726,
          -11389.532,
          -11356.848,
          -11323.671999999999,
          -11290.003999999999,
          -11255.843,
          -11221.19,
          -11186.043,
          -11150.402,
          -11114.266000000001,
          -11077.633999999998,
          -11040.505,
          -11002.88,
          -10964.756000000001,
          -10926.135,
          -10887.014,
          -10847.393,
          -10807.271,
          -10766.646999999999,
          -10725.521,
          -10683.891000000001,
          -10641.758,
          -10599.118999999999,
          -10555.973999999998,
          -10512.322,
          -10468.162,
          -10423.493,
          -10378.314,
          -10332.624,
          -10286.421999999999,
          -10239.708,
          -10192.479,
          -10144.735999999999,
          -10096.475,
          -10047.697,
          -9998.401,
          -9948.585,
          -9898.248,
          -9847.389000000001,
          -9796.007,
          -9744.1,
          -9691.667,
          -9638.707,
          -9585.218,
          -9531.2,
          -9476.65,
          -9421.568000000001,
          -9365.951,
          -9309.799,
          -9253.11,
          -9195.883,
          -9138.116,
          -9079.809000000001,
          -9020.957,
          -8961.562,
          -8901.62,
          -8841.13,
          -8780.091999999999,
          -8718.503,
          -8656.360999999999,
          -8593.665,
          -8530.413,
          -8466.603000000001,
          -8402.234,
          -8337.304,
          -8271.811,
          -8205.753,
          -8139.128000000001,
          -8071.935,
          -8004.172,
          -7935.8369999999995,
          -7866.927,
          -7797.441999999999,
          -7727.379,
          -7656.735,
          -7585.51,
          -7513.701,
          -7441.306,
          -7368.3240000000005,
          -7294.751,
          -7220.585999999999,
          -7145.826999999999,
          -7070.472,
          -6994.519,
          -6917.965,
          -6840.81,
          -6763.05,
          -6684.683000000001,
          -6605.7080000000005,
          -6526.121999999999,
          -6445.922,
          -6365.109,
          -6283.678000000001,
          -6201.6269999999995,
          -6118.955,
          -6035.66,
          -5951.74,
          -5867.191999999999,
          -5782.015,
          -5696.206,
          -5609.764,
          -5522.686,
          -5434.972,
          -5346.619000000001,
          -5257.625,
          -5167.9890000000005,
          -5077.708,
          -4986.782,
          -4895.209,
          -4802.988,
          -4710.116,
          -4616.594,
          -4522.42,
          -4427.593,
          -4332.113,
          -4235.978,
          -4139.188,
          -4041.744,
          -3943.6440000000002,
          -3844.8909999999996,
          -3745.4829999999997,
          -3645.421,
          -3544.7059999999997,
          -3443.341,
          -3341.3259999999996,
          -3238.664,
          -3135.3579999999997,
          -3031.409,
          -2926.822,
          -2821.6009999999997,
          -2715.75,
          -2609.275,
          -2502.1820000000002,
          -2394.478,
          -2286.169,
          -2177.265,
          -2067.776,
          -1957.711,
          -1847.0839999999998,
          -1735.9070000000002,
          -1624.194,
          -1511.9620000000002,
          -1399.2279999999998,
          -1286.013,
          -1172.339,
          -1058.229,
          -943.711,
          -828.813,
          -713.567,
          -598.01,
          -482.18,
          -366.12,
          -249.87900000000002,
          -133.50799999999998,
          -17.064,
          99.389,
          215.782,
          332.038,
          448.07199999999995,
          563.794,
          679.0989999999999,
          793.878,
          908.005,
          1021.346,
          1133.751,
          1245.058,
          1355.085,
          1463.6370000000002,
          1570.497,
          1675.4279999999999,
          1778.174,
          1878.4520000000002,
          1975.957,
          2070.357,
          2161.294,
          2248.383,
          2331.215,
          2409.35,
          2482.33,
          2549.673,
          2610.884,
          2665.4559999999997,
          2712.881,
          2752.66,
          2784.313,
          2807.39,
          2821.489,
          2826.268,
          2821.4559999999997,
          2806.866,
          2782.408,
          2748.0879999999997,
          2704.0159999999996,
          2650.4,
          2587.541,
          2515.825,
          2435.708,
          2347.701,
          2252.356,
          2150.252,
          2041.9779999999998,
          1928.1229999999998,
          1809.266,
          1685.964,
          1558.7479999999998,
          1428.121,
          1294.5510000000002,
          1158.47,
          1020.2769999999999,
          880.337,
          738.98,
          596.504,
          453.18,
          309.249,
          164.929,
          20.412,
          -124.12899999999999,
          -268.54200000000003,
          -412.69,
          -556.4540000000001,
          -699.727,
          -842.418,
          -984.442,
          -1125.73,
          -1266.2169999999999,
          -1405.848,
          -1544.576,
          -1682.361,
          -1819.165,
          -1954.9589999999998,
          -2089.716,
          -2223.4139999999998,
          -2356.0370000000003,
          -2487.5660000000003,
          -2617.99,
          -2747.301,
          -2875.489,
          -3002.5490000000004,
          -3128.4770000000003,
          -3253.2709999999997,
          -3376.929,
          -3499.453,
          -3620.843,
          -3741.1,
          -3860.23,
          -3978.235,
          -4095.119,
          -4210.888,
          -4325.548,
          -4439.104,
          -4551.562,
          -4662.929,
          -4773.213,
          -4882.42,
          -4990.557,
          -5097.633,
          -5203.654,
          -5308.628000000001,
          -5412.564,
          -5515.469,
          -5617.351,
          -5718.218000000001,
          -5818.076999999999,
          -5916.939,
          -6014.808000000001,
          -6111.694,
          -6207.604,
          -6302.547,
          -6396.53,
          -6489.561,
          -6581.647,
          -6672.795999999999,
          -6763.016,
          -6852.313,
          -6940.696999999999,
          -7028.172,
          -7114.746999999999,
          -7200.429,
          -7285.225,
          -7369.142,
          -7452.186,
          -7534.3640000000005,
          -7615.684,
          -7696.151,
          -7775.772,
          -7854.553000000001,
          -7932.501,
          -8009.621999999999,
          -8085.922,
          -8161.406,
          -8236.082,
          -8309.954,
          -8383.029,
          -8455.312,
          -8526.808,
          -8597.524,
          -8667.464,
          -8736.635,
          -8805.04,
          -8872.686,
          -8939.576,
          -9005.718,
          -9071.115,
          -9135.771999999999,
          -9199.694,
          -9262.885,
          -9325.351,
          -9387.096,
          -9448.123,
          -9508.438,
          -9568.046,
          -9626.949,
          -9685.154,
          -9742.663,
          -9799.48,
          -9855.61,
          -9911.056999999999,
          -9965.825,
          -10019.916,
          -10073.336,
          -10126.087,
          -10178.174,
          -10229.6,
          -10280.369,
          -10330.484,
          -10379.948,
          -10428.764000000001,
          -10476.937,
          -10524.47,
          -10571.365,
          -10617.625,
          -10663.253999999999,
          -10708.255,
          -10752.632,
          -10796.385,
          -10839.52,
          -10882.038999999999,
          -10923.944,
          -10965.238000000001,
          -11005.923999999999,
          -11046.005,
          -11085.483999999999,
          -11124.362,
          -11162.643,
          -11200.328000000001,
          -11237.421,
          -11273.923999999999,
          -11309.84,
          -11345.17,
          -11379.918,
          -11414.083999999999,
          -11447.671999999999,
          -11480.684,
          -11513.122,
          -11544.989,
          -11576.285,
          -11607.014,
          -11637.177,
          -11666.776000000002,
          -11695.813999999998,
          -11724.293,
          -11752.214,
          -11779.578000000001,
          -11806.389,
          -11832.646999999999,
          -11858.355,
          -11883.514,
          -11908.127,
          -11932.194,
          -11955.718,
          -11978.698999999999,
          -12001.14,
          -12023.043,
          -12044.409,
          -12065.239,
          -12085.535,
          -12105.298,
          -12124.528999999999,
          -12143.231000000002,
          -12161.405,
          -12179.052,
          -12196.173999999999,
          -12212.771,
          -12228.844,
          -12244.396999999999,
          -12259.428,
          -12273.94,
          -12287.935,
          -12301.412,
          -12314.374,
          -12326.822,
          -12338.755,
          -12350.177,
          -12361.087,
          -12371.486,
          -12381.377,
          -12390.76,
          -12399.635,
          -12408.003999999999,
          -12415.867,
          -12423.226,
          -12430.082,
          -12436.435,
          -12442.286,
          -12447.636,
          -12452.486,
          -12456.837,
          -12460.688999999998,
          -12464.043,
          -12466.9,
          -12469.261,
          -12471.126,
          -12472.496000000001,
          -12473.372,
          -12473.753999999999,
          -12473.643,
          -12473.038999999999,
          -12471.944,
          -12470.357,
          -12468.28,
          -12465.712,
          -12462.655,
          -12459.108,
          -12455.073,
          -12450.548999999999,
          -12445.537,
          -12440.038999999999,
          -12434.053,
          -12427.58,
          -12420.621000000001,
          -12413.176000000001,
          -12405.245,
          -12396.829,
          -12387.928999999998,
          -12378.544,
          -12368.673999999999,
          -12358.32,
          -12347.482,
          -12336.16,
          -12324.355,
          -12312.066,
          -12299.295,
          -12286.04,
          -12272.303,
          -12258.082,
          -12243.378999999999,
          -12228.193000000001,
          -12212.525,
          -12196.374,
          -12179.74,
          -12162.625,
          -12145.027,
          -12126.947,
          -12108.383,
          -12089.337,
          -12069.809,
          -12049.798,
          -12029.303999999998,
          -12008.328000000001,
          -11986.868,
          -11964.925,
          -11942.498,
          -11919.588,
          -11896.194,
          -11872.316,
          -11847.954,
          -11823.108,
          -11797.776000000002,
          -11771.96,
          -11745.658000000001,
          -11718.87,
          -11691.597,
          -11663.837,
          -11635.591,
          -11606.857,
          -11577.636,
          -11547.927,
          -11517.729,
          -11487.043,
          -11455.867,
          -11424.202,
          -11392.046,
          -11359.399,
          -11326.261,
          -11292.631000000001,
          -11258.508,
          -11223.892,
          -11188.783000000001,
          -11153.178999999998,
          -11117.08,
          -11080.485,
          -11043.393999999998,
          -11005.806,
          -10967.719,
          -10929.135,
          -10890.051000000001,
          -10850.466999999999,
          -10810.382,
          -10769.795,
          -10728.706,
          -10687.113000000001,
          -10645.016000000001,
          -10602.413999999999,
          -10559.306,
          -10515.691,
          -10471.567,
          -10426.935,
          -10381.792,
          -10336.139000000001,
          -10289.974,
          -10243.295,
          -10196.103000000001,
          -10148.396,
          -10100.171999999999,
          -10051.43,
          -10002.17,
          -9952.39,
          -9902.09,
          -9851.267,
          -9799.921,
          -9748.05,
          -9695.653,
          -9642.729,
          -9589.276,
          -9535.293,
          -9480.78,
          -9425.733,
          -9370.153,
          -9314.037,
          -9257.384,
          -9200.192,
          -9142.461,
          -9084.189,
          -9025.373,
          -8966.013,
          -8906.107,
          -8845.653,
          -8784.651,
          -8723.097,
          -8660.991,
          -8598.33,
          -8535.114,
          -8471.339,
          -8407.006,
          -8342.110999999999,
          -8276.654,
          -8210.631,
          -8144.0419999999995,
          -8076.884,
          -8009.156,
          -7940.856,
          -7871.983,
          -7802.533,
          -7732.505,
          -7661.896,
          -7590.706,
          -7518.933000000001,
          -7446.573,
          -7373.626,
          -7300.088000000001,
          -7225.959,
          -7151.235,
          -7075.915,
          -6999.996999999999,
          -6923.479,
          -6846.359,
          -6768.634,
          -6690.302,
          -6611.361999999999,
          -6531.811,
          -6451.647,
          -6370.868,
          -6289.472,
          -6207.456,
          -6124.819,
          -6041.559,
          -5957.674,
          -5873.161,
          -5788.019,
          -5702.245,
          -5615.8369999999995,
          -5528.794,
          -5441.115,
          -5352.795999999999,
          -5263.8369999999995,
          -5174.235,
          -5083.9890000000005,
          -4993.097,
          -4901.558,
          -4809.371,
          -4716.534000000001,
          -4623.045999999999,
          -4528.905,
          -4434.112,
          -4338.666,
          -4242.564,
          -4145.808,
          -4048.397,
          -3950.33,
          -3851.6090000000004,
          -3752.2340000000004,
          -3652.204,
          -3551.522,
          -3450.188,
          -3348.205,
          -3245.575,
          -3142.2990000000004,
          -3038.381,
          -2933.824,
          -2828.632,
          -2722.8109999999997,
          -2616.365,
          -2509.3,
          -2401.623,
          -2293.341,
          -2184.464,
          -2074.999,
          -1964.9589999999998,
          -1854.355,
          -1743.201,
          -1631.509,
          -1519.297,
          -1406.582,
          -1293.385,
          -1179.726,
          -1065.631,
          -951.125,
          -836.237,
          -720.9989999999999,
          -605.447,
          -489.62,
          -373.561,
          -257.316,
          -140.938,
          -24.484,
          91.984,
          208.396,
          324.676,
          440.741,
          556.498,
          671.847,
          786.675,
          900.8610000000001,
          1014.2689999999999,
          1126.752,
          1238.146,
          1348.274,
          1456.9379999999999,
          1563.925,
          1668.999,
          1771.905,
          1872.361,
          1970.065,
          2064.686,
          2155.868,
          2243.228,
          2326.357,
          2404.82,
          2478.158,
          2545.893,
          2607.528,
          2662.558,
          2710.4770000000003,
          2750.783,
          2782.9959999999996,
          2806.664,
          2821.381,
          2826.802,
          2822.65,
          2808.735,
          2784.958,
          2751.32,
          2707.9240000000004,
          2654.97,
          2592.757,
          2521.661,
          2442.135,
          2354.686,
          2259.865,
          2158.2470000000003,
          2050.4210000000003,
          1936.976,
          1818.49,
          1695.523,
          1568.608,
          1438.2479999999998,
          1304.913,
          1169.038,
          1031.025,
          891.238,
          750.013,
          607.6469999999999,
          464.414,
          320.558,
          176.296,
          31.823,
          -112.68700000000001,
          -257.08,
          -401.219,
          -544.9830000000001,
          -688.265,
          -830.972,
          -973.0189999999999,
          -1114.336,
          -1254.858,
          -1394.5279999999998,
          -1533.3010000000002,
          -1671.1329999999998,
          -1807.989,
          -1943.8370000000002,
          -2078.651,
          -2212.409,
          -2345.093,
          -2476.687,
          -2607.177,
          -2736.555,
          -2864.812,
          -2991.941,
          -3117.94,
          -3242.8059999999996,
          -3366.5370000000003,
          -3489.134,
          -3610.598,
          -3730.93,
          -3850.134,
          -3968.2140000000004,
          -4085.1740000000004,
          -4201.018,
          -4315.754,
          -4429.3859999999995,
          -4541.92,
          -4653.363,
          -4763.723,
          -4873.005999999999,
          -4981.219,
          -5088.371,
          -5194.467000000001,
          -5299.517,
          -5403.528,
          -5506.508000000001,
          -5608.465,
          -5709.406999999999,
          -5809.340999999999,
          -5908.276,
          -6006.22,
          -6103.179,
          -6199.1630000000005,
          -6294.18,
          -6388.235,
          -6481.339,
          -6573.496999999999,
          -6664.719,
          -6755.01,
          -6844.379,
          -6932.834,
          -7020.38,
          -7107.026,
          -7192.778,
          -7277.644,
          -7361.63,
          -7444.744000000001,
          -7526.991,
          -7608.38,
          -7688.915,
          -7768.604,
          -7847.453,
          -7925.469,
          -8002.658,
          -8079.024,
          -8154.575,
          -8229.317,
          -8303.255,
          -8376.396,
          -8448.745,
          -8520.306,
          -8591.087,
          -8661.091,
          -8730.326,
          -8798.796,
          -8866.505,
          -8933.46,
          -8999.664,
          -9065.124,
          -9129.844000000001,
          -9193.828000000001,
          -9257.082,
          -9319.609,
          -9381.416,
          -9442.505,
          -9502.881,
          -9562.549,
          -9621.514000000001,
          -9679.779,
          -9737.348,
          -9794.225,
          -9850.415,
          -9905.921,
          -9960.748,
          -10014.898000000001,
          -10068.377,
          -10121.187,
          -10173.332,
          -10224.815999999999,
          -10275.643,
          -10325.815,
          -10375.336,
          -10424.21,
          -10472.439,
          -10520.028999999999,
          -10566.98,
          -10613.296999999999,
          -10658.982,
          -10704.04,
          -10748.471000000001,
          -10792.281,
          -10835.471000000001,
          -10878.045,
          -10920.005,
          -10961.354,
          -11002.094,
          -11042.229,
          -11081.761999999999,
          -11120.694,
          -11159.028999999999,
          -11196.768,
          -11233.913999999999,
          -11270.47,
          -11306.438999999998,
          -11341.822,
          -11376.622,
          -11410.841,
          -11444.482,
          -11477.546,
          -11510.036,
          -11541.954,
          -11573.302,
          -11604.082,
          -11634.296999999999,
          -11663.947,
          -11693.036,
          -11721.566,
          -11749.537,
          -11776.952,
          -11803.813,
          -11830.122,
          -11855.878999999999,
          -11881.089,
          -11905.751,
          -11929.868,
          -11953.441,
          -11976.472,
          -11998.962,
          -12020.913999999999,
          -12042.328000000001,
          -12063.207,
          -12083.551000000001,
          -12103.363000000001,
          -12122.643,
          -12141.393999999998,
          -12159.615,
          -12177.31,
          -12194.479,
          -12211.124,
          -12227.245,
          -12242.845,
          -12257.923999999999,
          -12272.483,
          -12286.524,
          -12300.048999999999,
          -12313.056999999999,
          -12325.552,
          -12337.532,
          -12349,
          -12359.956,
          -12370.402,
          -12380.338,
          -12389.767,
          -12398.688,
          -12407.103000000001,
          -12415.011999999999,
          -12422.416000000001,
          -12429.317,
          -12435.715,
          -12441.611,
          -12447.007,
          -12451.902,
          -12456.296999999999,
          -12460.193000000001,
          -12463.591999999999,
          -12466.493999999999,
          -12468.899,
          -12470.808,
          -12472.223,
          -12473.142,
          -12473.568000000001,
          -12473.501,
          -12472.941,
          -12471.889,
          -12470.346000000001,
          -12468.313,
          -12465.788,
          -12462.774,
          -12459.27,
          -12455.278,
          -12450.796999999999,
          -12445.828000000001,
          -12440.372,
          -12434.428999999998,
          -12427.999,
          -12421.082,
          -12413.68,
          -12405.791000000001,
          -12397.418,
          -12388.559,
          -12379.216,
          -12369.388,
          -12359.076000000001,
          -12348.28,
          -12337,
          -12325.236,
          -12312.989,
          -12300.258999999998,
          -12287.046,
          -12273.348999999998,
          -12259.17,
          -12244.508,
          -12229.363000000001,
          -12213.736,
          -12197.626,
          -12181.034,
          -12163.958999999999,
          -12146.401000000002,
          -12128.361,
          -12109.839,
          -12090.833,
          -12071.346000000001,
          -12051.375,
          -12030.921,
          -12009.985,
          -11988.565,
          -11966.661,
          -11944.275,
          -11921.405,
          -11898.051000000001,
          -11874.213,
          -11849.89,
          -11825.083,
          -11799.791000000001,
          -11774.014,
          -11747.752,
          -11721.003999999999,
          -11693.77,
          -11666.048999999999,
          -11637.841999999999,
          -11609.146999999999,
          -11579.965,
          -11550.294,
          -11520.136,
          -11489.488000000001,
          -11458.351,
          -11426.723999999998,
          -11394.607,
          -11361.999,
          -11328.899,
          -11295.308,
          -11261.223999999998,
          -11226.646,
          -11191.575,
          -11156.008999999998,
          -11119.948,
          -11083.392,
          -11046.339,
          -11008.788999999999,
          -10970.741000000002,
          -10932.194,
          -10893.148000000001,
          -10853.601999999999,
          -10813.553999999998,
          -10773.005,
          -10731.954,
          -10690.399,
          -10648.34,
          -10605.775,
          -10562.704,
          -10519.126,
          -10475.04,
          -10430.446,
          -10385.341,
          -10339.725,
          -10293.597,
          -10246.956,
          -10199.801,
          -10152.13,
          -10103.944,
          -10055.24,
          -10006.017,
          -9956.274,
          -9906.01,
          -9855.224,
          -9803.915,
          -9752.081,
          -9699.721,
          -9646.834,
          -9593.418,
          -9539.472,
          -9484.995,
          -9429.985,
          -9374.440999999999,
          -9318.362,
          -9261.746,
          -9204.591,
          -9146.896,
          -9088.66,
          -9029.881,
          -8970.558,
          -8910.689,
          -8850.271999999999,
          -8789.305,
          -8727.788,
          -8665.716999999999,
          -8603.094000000001,
          -8539.914,
          -8476.176,
          -8411.879,
          -8347.02,
          -8281.598,
          -8215.612,
          -8149.06,
          -8081.939,
          -8014.246999999999,
          -7945.983,
          -7877.145,
          -7807.731,
          -7737.7390000000005,
          -7667.168000000001,
          -7596.014,
          -7524.276,
          -7451.953,
          -7379.041,
          -7305.54,
          -7231.446999999999,
          -7156.759,
          -7081.476,
          -7005.594,
          -6929.111,
          -6852.026999999999,
          -6774.339,
          -6696.043000000001,
          -6617.138000000001,
          -6537.6230000000005,
          -6457.495,
          -6376.7519999999995,
          -6295.392,
          -6213.411999999999,
          -6130.811,
          -6047.585999999999,
          -5963.736999999999,
          -5879.26,
          -5794.153,
          -5708.415,
          -5622.043000000001,
          -5535.036,
          -5447.392,
          -5359.109,
          -5270.185,
          -5180.6179999999995,
          -5090.407,
          -4999.55,
          -4908.0470000000005,
          -4815.895,
          -4723.092000000001,
          -4629.639,
          -4535.532999999999,
          -4440.775,
          -4345.363,
          -4249.295999999999,
          -4152.5740000000005,
          -4055.196,
          -3957.164,
          -3858.4759999999997,
          -3759.134,
          -3659.138,
          -3558.489,
          -3457.188,
          -3355.237,
          -3252.638,
          -3149.3940000000002,
          -3045.507,
          -2940.9809999999998,
          -2835.82,
          -2730.0290000000005,
          -2623.613,
          -2516.576,
          -2408.927,
          -2300.673,
          -2191.822,
          -2082.384,
          -1972.37,
          -1861.79,
          -1750.658,
          -1638.9879999999998,
          -1526.797,
          -1414.102,
          -1300.923,
          -1187.281,
          -1073.2,
          -958.706,
          -843.828,
          -728.5989999999999,
          -613.053,
          -497.22900000000004,
          -381.17,
          -264.922,
          -148.53799999999998,
          -32.073,
          84.40899999999999,
          200.84099999999998,
          317.14599999999996,
          433.241,
          549.035,
          664.427,
          779.306,
          893.551,
          1007.0269999999999,
          1119.588,
          1231.0710000000001,
          1341.3,
          1450.079,
          1557.195,
          1662.414,
          1765.4820000000002,
          1866.119,
          1964.024,
          2058.869,
          2150.3,
          2237.935,
          2321.367,
          2400.1620000000003,
          2473.864,
          2541.996,
          2604.062,
          2659.559,
          2707.9790000000003,
          2748.821,
          2781.6020000000003,
          2805.8709999999996,
          2821.218,
          2827.292,
          2823.813,
          2810.585,
          2787.5029999999997,
          2754.5609999999997,
          2711.8540000000003,
          2659.579,
          2598.024,
          2527.563,
          2448.6420000000003,
          2361.765,
          2267.48,
          2166.36,
          2058.994,
          1945.969,
          1827.865,
          1705.2420000000002,
          1578.636,
          1448.549,
          1315.4560000000001,
          1179.7939999999999,
          1041.965,
          902.3380000000001,
          761.247,
          618.996,
          475.858,
          332.077,
          187.87599999999998,
          43.449,
          -101.029,
          -245.40099999999998,
          -389.529,
          -533.293,
          -676.5830000000001,
          -819.306,
          -961.377,
          -1102.463,
          -1243.279,
          -1382.989,
          -1521.807,
          -1659.6870000000001,
          -1796.595,
          -1932.4979999999998,
          -2067.371,
          -2201.19,
          -2333.937,
          -2465.596,
          -2596.153,
          -2725.599,
          -2853.925,
          -2981.1259999999997,
          -3107.197,
          -3232.136,
          -3355.941,
          -3478.612,
          -3600.151,
          -3720.559,
          -3839.8390000000004,
          -3957.995,
          -4075.033,
          -4190.954000000001,
          -4305.767,
          -4419.476,
          -4532.088,
          -4643.608,
          -4754.045,
          -4863.406,
          -4971.696,
          -5078.924,
          -5185.099,
          -5290.226,
          -5394.313,
          -5497.37,
          -5599.404,
          -5700.420999999999,
          -5800.431,
          -5899.441999999999,
          -5997.460999999999,
          -6094.496,
          -6190.555,
          -6285.646,
          -6379.776,
          -6472.953,
          -6565.186,
          -6656.481,
          -6746.845,
          -6836.286999999999,
          -6924.814,
          -7012.433000000001,
          -7099.15,
          -7184.974,
          -7269.911,
          -7353.969,
          -7437.153,
          -7519.471,
          -7600.929,
          -7681.535,
          -7761.293000000001,
          -7840.210999999999,
          -7918.295999999999,
          -7995.553000000001,
          -8071.986999999999,
          -8147.607,
          -8222.416,
          -8296.421999999999,
          -8369.63,
          -8442.045,
          -8513.673,
          -8584.519,
          -8654.591,
          -8723.891,
          -8792.425,
          -8860.2,
          -8927.219000000001,
          -8993.489,
          -9059.011999999999,
          -9123.796,
          -9187.843,
          -9251.161,
          -9313.752,
          -9375.62,
          -9436.771999999999,
          -9497.211,
          -9556.940999999999,
          -9615.968,
          -9674.294,
          -9731.924,
          -9788.862,
          -9845.113000000001,
          -9900.68,
          -9955.567,
          -10009.777,
          -10063.315,
          -10116.185,
          -10168.39,
          -10219.933,
          -10270.818000000001,
          -10321.049,
          -10370.629,
          -10419.561,
          -10467.849,
          -10515.496000000001,
          -10562.505,
          -10608.878999999999,
          -10654.622,
          -10699.736,
          -10744.225,
          -10788.091,
          -10831.337,
          -10873.966999999999,
          -10915.983,
          -10957.388,
          -10998.184,
          -11038.375,
          -11077.962,
          -11116.948999999999,
          -11155.338,
          -11193.132,
          -11230.333,
          -11266.944,
          -11302.966,
          -11338.403,
          -11373.257,
          -11407.53,
          -11441.223999999998,
          -11474.341,
          -11506.883999999998,
          -11538.854,
          -11570.255,
          -11601.088,
          -11631.355,
          -11661.058,
          -11690.198999999999,
          -11718.78,
          -11746.802,
          -11774.268999999998,
          -11801.181999999999,
          -11827.542,
          -11853.351,
          -11878.611,
          -11903.323,
          -11927.491000000002,
          -11951.114,
          -11974.196000000002,
          -11996.737,
          -12018.738000000001,
          -12040.202,
          -12061.13,
          -12081.524,
          -12101.386,
          -12120.715,
          -12139.515,
          -12157.785,
          -12175.528999999999,
          -12192.747,
          -12209.44,
          -12225.61,
          -12241.258,
          -12256.385,
          -12270.993,
          -12285.082,
          -12298.653999999999,
          -12311.71,
          -12324.252,
          -12336.28,
          -12347.795,
          -12358.798,
          -12369.291000000001,
          -12379.275,
          -12388.75,
          -12397.718,
          -12406.178999999998,
          -12414.135,
          -12421.585,
          -12428.532,
          -12434.988000000001,
          -12440.93,
          -12446.371000000001,
          -12451.311000000002,
          -12455.752,
          -12459.693000000001,
          -12463.136999999999,
          -12466.083,
          -12468.533000000001,
          -12470.487,
          -12471.946000000002,
          -12472.91,
          -12473.38,
          -12473.357,
          -12472.841999999999,
          -12471.833999999999,
          -12470.335,
          -12468.345,
          -12465.864,
          -12462.893,
          -12459.433,
          -12455.483999999999,
          -12451.046999999999,
          -12446.121000000001,
          -12440.708,
          -12434.808,
          -12428.421,
          -12421.546999999999,
          -12414.187,
          -12406.341999999999,
          -12398.011,
          -12389.195,
          -12379.893999999998,
          -12370.108999999999,
          -12359.839,
          -12349.085,
          -12337.847,
          -12326.125,
          -12313.92,
          -12301.232,
          -12288.06,
          -12274.405,
          -12260.268,
          -12245.646999999999,
          -12230.544,
          -12214.958,
          -12198.889,
          -12182.338,
          -12165.305,
          -12147.788,
          -12129.788999999999,
          -12111.306999999999,
          -12092.341999999999,
          -12072.895,
          -12052.966,
          -12032.553,
          -12011.656,
          -11990.277,
          -11968.413999999999,
          -11946.068000000001,
          -11923.238000000001,
          -11899.923999999999,
          -11876.126,
          -11851.844,
          -11827.076000000001,
          -11801.823999999999,
          -11776.087,
          -11749.864,
          -11723.156,
          -11695.962,
          -11668.281,
          -11640.113000000001,
          -11611.458,
          -11582.315,
          -11552.684,
          -11522.565,
          -11491.957,
          -11460.858999999999,
          -11429.271,
          -11397.193000000001,
          -11364.623,
          -11331.563,
          -11298.01,
          -11263.965,
          -11229.427,
          -11194.393999999998,
          -11158.867,
          -11122.845,
          -11086.327,
          -11049.312,
          -11011.801000000001,
          -10973.791000000001,
          -10935.283000000001,
          -10896.275,
          -10856.767,
          -10816.758,
          -10776.247,
          -10735.233999999999,
          -10693.718,
          -10651.696000000002,
          -10609.17,
          -10566.136999999999,
          -10522.597,
          -10478.549,
          -10433.992,
          -10388.925,
          -10343.347,
          -10297.257,
          -10250.653,
          -10203.536,
          -10155.903,
          -10107.754,
          -10059.088,
          -10009.902,
          -9960.197,
          -9909.971,
          -9859.222,
          -9807.95,
          -9756.154,
          -9703.831,
          -9650.981,
          -9597.603000000001,
          -9543.694,
          -9489.254,
          -9434.282,
          -9378.775,
          -9322.733,
          -9266.154,
          -9209.036,
          -9151.379,
          -9093.18,
          -9034.438,
          -8975.152,
          -8915.32,
          -8854.94,
          -8794.01,
          -8732.529,
          -8670.496,
          -8607.909,
          -8544.767,
          -8481.065999999999,
          -8416.805,
          -8351.984,
          -8286.599,
          -8220.65,
          -8154.134,
          -8087.05,
          -8019.395,
          -7951.168000000001,
          -7882.366999999999,
          -7812.9890000000005,
          -7743.035,
          -7672.5,
          -7601.383000000001,
          -7529.682,
          -7457.395,
          -7384.52,
          -7311.056,
          -7236.999,
          -7162.348000000001,
          -7087.101,
          -7011.255999999999,
          -6934.81,
          -6857.763000000001,
          -6780.111,
          -6701.852,
          -6622.984,
          -6543.505,
          -6463.4130000000005,
          -6382.706999999999,
          -6301.384,
          -6219.44,
          -6136.876,
          -6053.688,
          -5969.874,
          -5885.434,
          -5800.3640000000005,
          -5714.661999999999,
          -5628.326,
          -5541.355,
          -5453.746999999999,
          -5365.501,
          -5276.613,
          -5187.082,
          -5096.907,
          -5006.085999999999,
          -4914.619000000001,
          -4822.503,
          -4729.736,
          -4636.318,
          -4542.248,
          -4447.525,
          -4352.148,
          -4256.116,
          -4159.429,
          -4062.086,
          -3964.0879999999997,
          -3865.4359999999997,
          -3766.1279999999997,
          -3666.165,
          -3565.55,
          -3464.282,
          -3362.365,
          -3259.7990000000004,
          -3156.587,
          -3052.7329999999997,
          -2948.238,
          -2843.1079999999997,
          -2737.348,
          -2630.962,
          -2523.955,
          -2416.335,
          -2308.109,
          -2199.286,
          -2089.875,
          -1979.886,
          -1869.3310000000001,
          -1758.223,
          -1646.576,
          -1534.406,
          -1421.731,
          -1308.5710000000001,
          -1194.9460000000001,
          -1080.88,
          -966.4,
          -851.533,
          -736.313,
          -620.774,
          -504.95300000000003,
          -388.895,
          -272.645,
          -156.254,
          -39.779,
          76.718,
          193.169,
          309.498,
          425.62300000000005,
          541.453,
          656.888,
          771.818,
          886.122,
          999.6669999999999,
          1112.307,
          1223.879,
          1334.21,
          1443.104,
          1550.349,
          1655.714,
          1758.945,
          1859.765,
          1957.874,
          2052.945,
          2144.625,
          2232.5370000000003,
          2316.274,
          2395.405,
          2469.474,
          2538.006,
          2600.506,
          2656.472,
          2705.397,
          2746.78,
          2780.136,
          2805.011,
          2820.994,
          2827.7290000000003,
          2824.9320000000002,
          2812.401,
          2790.0240000000003,
          2757.788,
          2715.784,
          2664.199,
          2603.315,
          2533.5029999999997,
          2455.2,
          2368.909,
          2275.1710000000003,
          2174.561,
          2067.663,
          1955.068,
          1837.3529999999998,
          1715.0810000000001,
          1588.789,
          1458.9820000000002,
          1326.135,
          1190.6889999999999,
          1053.047,
          913.581,
          772.627,
          630.492,
          487.449,
          343.74699999999996,
          199.606,
          55.225,
          -89.219,
          -233.57,
          -377.689,
          -521.452,
          -664.7510000000001,
          -807.49,
          -949.585,
          -1090.96,
          -1231.552,
          -1371.3029999999999,
          -1510.1660000000002,
          -1648.096,
          -1785.056,
          -1921.016,
          -2055.949,
          -2189.8289999999997,
          -2322.64,
          -2454.365,
          -2584.991,
          -2714.506,
          -2842.9040000000005,
          -2970.177,
          -3096.322,
          -3221.335,
          -3345.216,
          -3467.962,
          -3589.577,
          -3710.063,
          -3829.421,
          -3947.655,
          -4064.77,
          -4180.77,
          -4295.661,
          -4409.4490000000005,
          -4522.139,
          -4633.738,
          -4744.254,
          -4853.693,
          -4962.062,
          -5069.369000000001,
          -5175.621,
          -5280.826,
          -5384.991999999999,
          -5488.1269999999995,
          -5590.238,
          -5691.3330000000005,
          -5791.42,
          -5890.508000000001,
          -5988.603,
          -6085.714,
          -6181.849,
          -6277.016,
          -6371.221,
          -6464.472,
          -6556.779,
          -6648.149,
          -6738.5869999999995,
          -6828.103,
          -6916.703,
          -7004.396,
          -7091.186,
          -7177.081999999999,
          -7262.092,
          -7346.222,
          -7429.477,
          -7511.866999999999,
          -7593.397,
          -7674.071999999999,
          -7753.901,
          -7832.89,
          -7911.044,
          -7988.37,
          -8064.874,
          -8140.562,
          -8215.44,
          -8289.514000000001,
          -8362.789,
          -8435.271999999999,
          -8506.968,
          -8577.882,
          -8648.019,
          -8717.385,
          -8785.985999999999,
          -8853.827,
          -8920.911,
          -8987.246,
          -9052.835,
          -9117.683,
          -9181.795,
          -9245.176,
          -9307.831,
          -9369.764000000001,
          -9430.979,
          -9491.48,
          -9551.273000000001,
          -9610.362,
          -9668.751,
          -9726.443000000001,
          -9783.443000000001,
          -9839.755,
          -9895.383,
          -9950.331,
          -10004.603000000001,
          -10058.201,
          -10111.131,
          -10163.396,
          -10214.999,
          -10265.944,
          -10316.234,
          -10365.873,
          -10414.864,
          -10463.211,
          -10510.916000000001,
          -10557.983,
          -10604.415,
          -10650.215,
          -10695.386999999999,
          -10739.933,
          -10783.857,
          -10827.16,
          -10869.846000000001,
          -10911.918,
          -10953.38,
          -10994.232,
          -11034.478000000001,
          -11074.122,
          -11113.163999999999,
          -11151.608999999999,
          -11189.458,
          -11226.714,
          -11263.378999999999,
          -11299.456,
          -11334.948,
          -11369.856000000002,
          -11404.181999999999,
          -11437.93,
          -11471.101,
          -11503.697,
          -11535.722,
          -11567.176000000001,
          -11598.061000000002,
          -11628.381000000001,
          -11658.136,
          -11687.329,
          -11715.963,
          -11744.038,
          -11771.556999999999,
          -11798.521,
          -11824.931999999999,
          -11850.792,
          -11876.104,
          -11900.868,
          -11925.087,
          -11948.761,
          -11971.893,
          -11994.483999999999,
          -12016.537,
          -12038.051000000001,
          -12059.03,
          -12079.473,
          -12099.383999999998,
          -12118.763,
          -12137.613000000001,
          -12155.933,
          -12173.726,
          -12190.993,
          -12207.735,
          -12223.953000000001,
          -12239.65,
          -12254.826000000001,
          -12269.482,
          -12283.62,
          -12297.24,
          -12310.344,
          -12322.934,
          -12335.008999999998,
          -12346.572,
          -12357.624,
          -12368.163999999999,
          -12378.195,
          -12387.716999999999,
          -12396.732,
          -12405.24,
          -12413.243,
          -12420.741000000002,
          -12427.733999999999,
          -12434.225,
          -12440.213,
          -12445.701000000001,
          -12450.688,
          -12455.175,
          -12459.163,
          -12462.653,
          -12465.646,
          -12468.141000000001,
          -12470.142,
          -12471.646999999999,
          -12472.657,
          -12473.171999999999,
          -12473.195,
          -12472.725,
          -12471.761999999999,
          -12470.308,
          -12468.364,
          -12465.928,
          -12463.002,
          -12459.587,
          -12455.683,
          -12451.29,
          -12446.409,
          -12441.041000000001,
          -12435.185,
          -12428.841999999999,
          -12422.013,
          -12414.697,
          -12406.896,
          -12398.608999999999,
          -12389.837,
          -12380.579,
          -12370.837,
          -12360.611,
          -12349.9,
          -12338.706,
          -12327.028,
          -12314.866000000002,
          -12302.221000000001,
          -12289.091999999999,
          -12275.48,
          -12261.385,
          -12246.808,
          -12231.748,
          -12216.204,
          -12200.178,
          -12183.669,
          -12166.678,
          -12149.204,
          -12131.247,
          -12112.808,
          -12093.885,
          -12074.48,
          -12054.591999999999,
          -12034.221000000001,
          -12013.366000000002,
          -11992.028,
          -11970.208,
          -11947.903,
          -11925.115,
          -11901.841999999999,
          -11878.086000000001,
          -11853.845,
          -11829.118999999999,
          -11803.908000000001,
          -11778.212,
          -11752.031,
          -11725.363000000001,
          -11698.208999999999,
          -11670.569,
          -11642.443000000001,
          -11613.828000000001,
          -11584.726,
          -11555.136,
          -11525.056999999999,
          -11494.489,
          -11463.431,
          -11431.883999999998,
          -11399.847,
          -11367.318000000001,
          -11334.296999999999,
          -11300.785,
          -11266.778999999999,
          -11232.28,
          -11197.288,
          -11161.801000000001,
          -11125.819,
          -11089.341,
          -11052.366000000002,
          -11014.895,
          -10976.925,
          -10938.456,
          -10899.488000000001,
          -10860.02,
          -10820.05,
          -10779.579,
          -10738.605,
          -10697.128,
          -10655.146,
          -10612.658000000001,
          -10569.665,
          -10526.163999999999,
          -10482.155,
          -10437.636999999999,
          -10392.61,
          -10347.071,
          -10301.019,
          -10254.455,
          -10207.376,
          -10159.782,
          -10111.671999999999,
          -10063.045,
          -10013.898000000001,
          -9964.232,
          -9914.044,
          -9863.334,
          -9812.101,
          -9760.343,
          -9708.059000000001,
          -9655.248,
          -9601.908000000001,
          -9548.038,
          -9493.636999999999,
          -9438.703000000001,
          -9383.235,
          -9327.231,
          -9270.69,
          -9213.610999999999,
          -9155.991,
          -9097.831,
          -9039.128,
          -8979.88,
          -8920.085,
          -8859.743,
          -8798.851999999999,
          -8737.41,
          -8675.416,
          -8612.867,
          -8549.761,
          -8486.098,
          -8421.876,
          -8357.093,
          -8291.747,
          -8225.836,
          -8159.358,
          -8092.311,
          -8024.695,
          -7956.505999999999,
          -7887.743,
          -7818.404,
          -7748.486,
          -7677.9890000000005,
          -7606.91,
          -7535.2480000000005,
          -7462.999,
          -7390.161999999999,
          -7316.735,
          -7242.715999999999,
          -7168.104,
          -7092.895,
          -7017.088000000001,
          -6940.68,
          -6863.67,
          -6786.055,
          -6707.834,
          -6629.005,
          -6549.564,
          -6469.51,
          -6388.840999999999,
          -6307.554,
          -6225.649,
          -6143.1230000000005,
          -6059.973000000001,
          -5976.196999999999,
          -5891.794,
          -5806.762,
          -5721.097,
          -5634.799,
          -5547.866,
          -5460.295,
          -5372.085999999999,
          -5283.235,
          -5193.742,
          -5103.604,
          -5012.82,
          -4921.39,
          -4829.311,
          -4736.581,
          -4643.2,
          -4549.166,
          -4454.48,
          -4359.139,
          -4263.144,
          -4166.4929999999995,
          -4069.1859999999997,
          -3971.225,
          -3872.607,
          -3773.3340000000003,
          -3673.407,
          -3572.8259999999996,
          -3471.594,
          -3369.71,
          -3267.178,
          -3164,
          -3060.178,
          -2955.717,
          -2850.62,
          -2744.8909999999996,
          -2638.5359999999996,
          -2531.56,
          -2423.97,
          -2315.774,
          -2206.979,
          -2097.596,
          -1987.6329999999998,
          -1877.104,
          -1766.02,
          -1654.3970000000002,
          -1542.25,
          -1429.5970000000002,
          -1316.455,
          -1202.848,
          -1088.798,
          -974.332,
          -859.4780000000001,
          -744.2669999999999,
          -628.735,
          -512.919,
          -396.861,
          -280.60900000000004,
          -164.21200000000002,
          -47.727,
          68.78399999999999,
          185.25400000000002,
          301.608,
          417.764,
          533.631,
          649.11,
          764.092,
          878.456,
          992.071,
          1104.79,
          1216.454,
          1326.888,
          1435.9,
          1543.277,
          1648.7910000000002,
          1752.1879999999999,
          1853.195,
          1951.5120000000002,
          2046.8139999999999,
          2138.751,
          2226.946,
          2310.995,
          2390.469,
          2464.9139999999998,
          2533.856,
          2596.802,
          2653.25,
          2702.6940000000004,
          2744.631,
          2778.577,
          2804.0759999999996,
          2820.711,
          2828.1259999999997,
          2826.03,
          2814.2140000000004,
          2792.562,
          2761.053,
          2719.7690000000002,
          2668.893,
          2608.699,
          2539.552,
          2461.885,
          2376.195,
          2283.022,
          2182.936,
          2076.5229999999997,
          1964.372,
          1847.06,
          1725.152,
          1599.1860000000001,
          1469.6689999999999,
          1337.079,
          1201.858,
          1064.412,
          925.115,
          784.306,
          642.2919999999999,
          499.35,
          355.72900000000004,
          211.653,
          67.322,
          -77.086,
          -221.41400000000002,
          -365.522,
          -509.283,
          -652.59,
          -795.345,
          -937.4630000000001,
          -1078.868,
          -1219.495,
          -1359.2879999999998,
          -1498.1960000000001,
          -1636.1760000000002,
          -1773.191,
          -1909.2079999999999,
          -2044.2,
          -2178.144,
          -2311.02,
          -2442.813,
          -2573.508,
          -2703.095,
          -2831.565,
          -2958.9120000000003,
          -3085.132,
          -3210.222,
          -3334.178,
          -3457.0029999999997,
          -3578.697,
          -3699.261,
          -3818.698,
          -3937.012,
          -4054.2070000000003,
          -4170.287,
          -4285.258,
          -4399.127,
          -4511.898,
          -4623.5779999999995,
          -4734.174,
          -4843.693,
          -4952.143,
          -5059.53,
          -5165.862,
          -5271.148,
          -5375.394,
          -5478.608,
          -5580.798000000001,
          -5681.973000000001,
          -5782.139,
          -5881.305,
          -5979.479,
          -6076.669,
          -6172.882,
          -6268.126,
          -6362.409000000001,
          -6455.738,
          -6548.1230000000005,
          -6639.569,
          -6730.0830000000005,
          -6819.675,
          -6908.351,
          -6996.118,
          -7082.983,
          -7168.954000000001,
          -7254.0380000000005,
          -7338.241999999999,
          -7421.571,
          -7504.034000000001,
          -7585.6359999999995,
          -7666.384,
          -7746.285,
          -7825.346,
          -7903.571999999999,
          -7980.969,
          -8057.544,
          -8133.303000000001,
          -8208.252,
          -8282.395,
          -8355.74,
          -8428.292,
          -8500.056999999999,
          -8571.04,
          -8641.246,
          -8710.68,
          -8779.349,
          -8847.257,
          -8914.409,
          -8980.81,
          -9046.466,
          -9111.381,
          -9175.559000000001,
          -9239.006,
          -9301.726,
          -9363.724,
          -9425.005,
          -9485.571,
          -9545.429,
          -9604.581,
          -9663.034,
          -9720.79,
          -9777.854,
          -9834.229,
          -9889.92,
          -9944.93,
          -9999.265,
          -10052.925,
          -10105.917,
          -10158.244,
          -10209.908000000001,
          -10260.914,
          -10311.265,
          -10360.965,
          -10410.017,
          -10458.424,
          -10506.188999999998,
          -10553.316,
          -10599.808,
          -10645.667,
          -10690.899,
          -10735.503999999999,
          -10779.486,
          -10822.848,
          -10865.591999999999,
          -10907.723,
          -10949.242,
          -10990.152,
          -11030.456,
          -11070.157,
          -11109.256000000001,
          -11147.758,
          -11185.663999999999,
          -11222.976,
          -11259.698,
          -11295.831,
          -11331.378999999999,
          -11366.343,
          -11400.725,
          -11434.528,
          -11467.753999999999,
          -11500.405,
          -11532.485,
          -11563.993999999999,
          -11594.934,
          -11625.308,
          -11655.117,
          -11684.365,
          -11713.052,
          -11741.181,
          -11768.753,
          -11795.771,
          -11822.235,
          -11848.149,
          -11873.513,
          -11898.33,
          -11922.601,
          -11946.328000000001,
          -11969.511999999999,
          -11992.156,
          -12014.26,
          -12035.827,
          -12056.857,
          -12077.351999999999,
          -12097.313999999998,
          -12116.743999999999,
          -12135.645,
          -12154.016000000001,
          -12171.86,
          -12189.177,
          -12205.97,
          -12222.239,
          -12237.986,
          -12253.212,
          -12267.919,
          -12282.106000000002,
          -12295.776000000002,
          -12308.93,
          -12321.569,
          -12333.693000000001,
          -12345.306,
          -12356.406,
          -12366.996000000001,
          -12377.075,
          -12386.646,
          -12395.71,
          -12404.266000000001,
          -12412.317,
          -12419.863000000001,
          -12426.905,
          -12433.444,
          -12439.48,
          -12445.016000000001,
          -12450.05,
          -12454.585,
          -12458.62,
          -12462.158000000001,
          -12465.197,
          -12467.74,
          -12469.788,
          -12471.339,
          -12472.396,
          -12472.958999999999,
          -12473.028,
          -12472.604,
          -12471.688,
          -12470.28,
          -12468.382,
          -12465.992,
          -12463.113000000001,
          -12459.743,
          -12455.885,
          -12451.537,
          -12446.702,
          -12441.378999999999,
          -12435.569,
          -12429.271,
          -12422.487,
          -12415.216,
          -12407.46,
          -12399.218,
          -12390.491000000002,
          -12381.278,
          -12371.581,
          -12361.399,
          -12350.733,
          -12339.583,
          -12327.948999999999,
          -12315.831,
          -12303.23,
          -12290.146,
          -12276.578000000001,
          -12262.527,
          -12247.993,
          -12232.976,
          -12217.476999999999,
          -12201.493999999999,
          -12185.028999999999,
          -12168.08,
          -12150.65,
          -12132.736,
          -12114.34,
          -12095.461000000001,
          -12076.098999999998,
          -12056.253,
          -12035.925,
          -12015.113000000001,
          -11993.818000000001,
          -11972.04,
          -11949.778,
          -11927.032,
          -11903.802,
          -11880.088,
          -11855.889,
          -11831.206,
          -11806.037,
          -11780.383,
          -11754.243,
          -11727.618,
          -11700.506000000001,
          -11672.908000000001,
          -11644.823,
          -11616.25,
          -11587.19,
          -11557.641000000001,
          -11527.603000000001,
          -11497.077,
          -11466.061000000002,
          -11434.555,
          -11402.559,
          -11370.071000000002,
          -11337.091999999999,
          -11303.62,
          -11269.656,
          -11235.198,
          -11200.247,
          -11164.801000000001,
          -11128.86,
          -11092.421999999999,
          -11055.488000000001,
          -11018.056999999999,
          -10980.128,
          -10941.7,
          -10902.773000000001,
          -10863.345,
          -10823.415,
          -10782.983999999999,
          -10742.051000000001,
          -10700.614,
          -10658.673,
          -10616.225,
          -10573.271999999999,
          -10529.811000000002,
          -10485.841999999999,
          -10441.365,
          -10396.377,
          -10350.878,
          -10304.867,
          -10258.341999999999,
          -10211.304,
          -10163.749,
          -10115.679,
          -10067.091,
          -10017.985,
          -9968.358,
          -9918.21,
          -9867.54,
          -9816.346,
          -9764.628,
          -9712.383,
          -9659.612,
          -9606.311,
          -9552.48,
          -9498.119,
          -9443.224,
          -9387.796,
          -9331.831,
          -9275.329,
          -9218.289,
          -9160.71,
          -9102.589,
          -9043.925,
          -8984.716,
          -8924.961,
          -8864.658000000001,
          -8803.806,
          -8742.403,
          -8680.448,
          -8617.938,
          -8554.872,
          -8491.248,
          -8427.065,
          -8362.32,
          -8297.013,
          -8231.141,
          -8164.701999999999,
          -8097.695,
          -8030.116999999999,
          -7961.968000000001,
          -7893.243,
          -7823.943,
          -7754.065,
          -7683.607,
          -7612.566999999999,
          -7540.943,
          -7468.733,
          -7395.935,
          -7322.547,
          -7248.566999999999,
          -7173.993,
          -7098.8240000000005,
          -7023.055,
          -6946.686,
          -6869.715,
          -6792.139,
          -6713.956999999999,
          -6635.166,
          -6555.764,
          -6475.749,
          -6395.119000000001,
          -6313.871,
          -6232.005,
          -6149.517,
          -6066.405,
          -5982.668000000001,
          -5898.304,
          -5813.31,
          -5727.684,
          -5641.425,
          -5554.53,
          -5466.996999999999,
          -5378.826,
          -5290.014,
          -5200.559,
          -5110.459,
          -5019.714,
          -4928.321,
          -4836.28,
          -4743.588,
          -4650.245,
          -4556.249,
          -4461.6,
          -4366.295999999999,
          -4270.338,
          -4173.724,
          -4076.455,
          -3978.53,
          -3879.949,
          -3780.712,
          -3680.821,
          -3580.276,
          -3479.079,
          -3377.2309999999998,
          -3274.7329999999997,
          -3171.59,
          -3067.802,
          -2963.3740000000003,
          -2858.31,
          -2752.614,
          -2646.2909999999997,
          -2539.346,
          -2431.7870000000003,
          -2323.621,
          -2214.856,
          -2105.501,
          -1995.566,
          -1885.0629999999999,
          -1774.005,
          -1662.406,
          -1550.2820000000002,
          -1437.65,
          -1324.529,
          -1210.94,
          -1096.906,
          -982.455,
          -867.613,
          -752.4119999999999,
          -636.887,
          -521.076,
          -405.02,
          -288.765,
          -172.362,
          -55.867,
          60.656000000000006,
          177.146,
          293.525,
          409.711,
          525.616,
          641.14,
          756.174,
          870.5989999999999,
          984.284,
          1097.085,
          1208.8419999999999,
          1319.381,
          1428.511,
          1536.024,
          1641.6889999999999,
          1745.256,
          1846.451,
          1944.979,
          2040.516,
          2132.7129999999997,
          2221.196,
          2305.562,
          2385.385,
          2460.212,
          2529.57,
          2592.969,
          2649.908,
          2699.8779999999997,
          2742.38,
          2776.927,
          2803.059,
          2820.36,
          2828.466,
          2827.083,
          2815.9970000000003,
          2795.083,
          2764.315,
          2723.768,
          2673.616,
          2614.129,
          2545.6620000000003,
          2468.645,
          2383.571,
          2290.976,
          2191.429,
          2085.513,
          1973.816,
          1856.9189999999999,
          1735.385,
          1609.754,
          1480.536,
          1348.21,
          1213.221,
          1075.9769999999999,
          936.8539999999999,
          796.193,
          654.304,
          511.466,
          367.931,
          223.923,
          79.643,
          -64.72800000000001,
          -209.032,
          -353.126,
          -496.88599999999997,
          -640.2,
          -782.97,
          -925.11,
          -1066.594,
          -1207.21,
          -1347.0439999999999,
          -1485.9979999999998,
          -1624.0279999999998,
          -1761.098,
          -1897.1729999999998,
          -2032.226,
          -2166.234,
          -2299.177,
          -2431.038,
          -2561.804,
          -2691.4629999999997,
          -2820.007,
          -2947.43,
          -3073.725,
          -3198.8920000000003,
          -3322.928,
          -3445.8309999999997,
          -3567.605,
          -3688.2490000000003,
          -3807.7659999999996,
          -3926.1620000000003,
          -4043.438,
          -4159.6,
          -4274.653,
          -4388.603,
          -4501.456,
          -4613.219,
          -4723.897,
          -4833.498,
          -4942.03,
          -5049.499,
          -5155.913,
          -5261.28,
          -5365.607,
          -5468.901999999999,
          -5571.174,
          -5672.429,
          -5772.675,
          -5871.922,
          -5970.1759999999995,
          -6067.445,
          -6163.738,
          -6259.061,
          -6353.422,
          -6446.831,
          -6539.293000000001,
          -6630.816,
          -6721.409000000001,
          -6811.078,
          -6899.831,
          -6987.674,
          -7074.616999999999,
          -7160.6630000000005,
          -7245.821999999999,
          -7330.101,
          -7413.505999999999,
          -7496.043000000001,
          -7577.719,
          -7658.5419999999995,
          -7738.517,
          -7817.65,
          -7895.948,
          -7973.419,
          -8050.066,
          -8125.897,
          -8200.916,
          -8275.132,
          -8348.548,
          -8421.171,
          -8493.006,
          -8564.059000000001,
          -8634.335,
          -8703.839,
          -8772.576,
          -8840.554,
          -8907.774,
          -8974.244,
          -9039.966999999999,
          -9104.949,
          -9169.196,
          -9232.71,
          -9295.497,
          -9357.561,
          -9418.908000000001,
          -9479.54,
          -9539.464,
          -9598.681999999999,
          -9657.2,
          -9715.021,
          -9772.149,
          -9828.589,
          -9884.344000000001,
          -9939.419,
          -9993.815999999999,
          -10047.54,
          -10100.595,
          -10152.985,
          -10204.712,
          -10255.78,
          -10306.194,
          -10355.955,
          -10405.069,
          -10453.537,
          -10501.364,
          -10548.552,
          -10595.105,
          -10641.025,
          -10686.317,
          -10730.982,
          -10775.023000000001,
          -10818.445,
          -10861.25,
          -10903.44,
          -10945.017,
          -10985.986,
          -11026.348999999998,
          -11066.108,
          -11105.266000000001,
          -11143.826000000001,
          -11181.788999999999,
          -11219.16,
          -11255.938999999998,
          -11292.13,
          -11327.733999999999,
          -11362.755,
          -11397.193000000001,
          -11431.053,
          -11464.336000000001,
          -11497.044,
          -11529.178999999998,
          -11560.743,
          -11591.739,
          -11622.169,
          -11652.034,
          -11681.337,
          -11710.079,
          -11738.261999999999,
          -11765.889,
          -11792.961000000001,
          -11819.481000000002,
          -11845.448,
          -11870.866000000002,
          -11895.737,
          -11920.061000000002,
          -11943.841999999999,
          -11967.08,
          -11989.777,
          -12011.934,
          -12033.553,
          -12054.636,
          -12075.184,
          -12095.198999999999,
          -12114.681999999999,
          -12133.633999999998,
          -12152.056999999999,
          -12169.953000000001,
          -12187.322,
          -12204.167,
          -12220.487,
          -12236.285,
          -12251.562,
          -12266.319,
          -12280.558,
          -12294.278999999999,
          -12307.483999999999,
          -12320.173,
          -12332.348,
          -12344.011,
          -12355.162,
          -12365.801000000001,
          -12375.931,
          -12385.551000000001,
          -12394.663999999999,
          -12403.27,
          -12411.371000000001,
          -12418.966,
          -12426.056999999999,
          -12432.645,
          -12438.73,
          -12444.313999999998,
          -12449.396999999999,
          -12453.98,
          -12458.065,
          -12461.65,
          -12464.738000000001,
          -12467.329,
          -12469.425,
          -12471.024,
          -12472.128999999999,
          -12472.739,
          -12472.856000000002,
          -12472.479,
          -12471.611,
          -12470.25,
          -12468.399,
          -12466.056999999999,
          -12463.223999999998,
          -12459.901000000002,
          -12456.09,
          -12451.79,
          -12447.001,
          -12441.723999999998,
          -12435.96,
          -12429.708,
          -12422.97,
          -12415.746000000001,
          -12408.035,
          -12399.84,
          -12391.158000000001,
          -12381.991000000002,
          -12372.339,
          -12362.203000000001,
          -12351.582,
          -12340.478000000001,
          -12328.889,
          -12316.817,
          -12304.26,
          -12291.221000000001,
          -12277.698,
          -12263.692,
          -12249.203000000001,
          -12234.231000000002,
          -12218.776000000002,
          -12202.838,
          -12186.417,
          -12169.513,
          -12152.127,
          -12134.258,
          -12115.905,
          -12097.07,
          -12077.751,
          -12057.95,
          -12037.665,
          -12016.898000000001,
          -11995.646999999999,
          -11973.912,
          -11951.693000000001,
          -11928.991000000002,
          -11905.805,
          -11882.133999999998,
          -11857.978000000001,
          -11833.338,
          -11808.212,
          -11782.601,
          -11756.503999999999,
          -11729.921999999999,
          -11702.853000000001,
          -11675.298,
          -11647.255,
          -11618.725,
          -11589.707,
          -11560.201000000001,
          -11530.207,
          -11499.722,
          -11468.749,
          -11437.285,
          -11405.331,
          -11372.885,
          -11339.948999999999,
          -11306.518999999998,
          -11272.597,
          -11238.181,
          -11203.271999999999,
          -11167.867,
          -11131.968,
          -11095.572,
          -11058.68,
          -11021.291000000001,
          -10983.403,
          -10945.017,
          -10906.131000000001,
          -10866.745,
          -10826.857,
          -10786.468,
          -10745.575,
          -10704.178999999998,
          -10662.278999999999,
          -10619.873,
          -10576.961000000001,
          -10533.542,
          -10489.614,
          -10445.177,
          -10400.23,
          -10354.771999999999,
          -10308.802,
          -10262.319,
          -10215.321,
          -10167.806999999999,
          -10119.778,
          -10071.231,
          -10022.165,
          -9972.579,
          -9922.471,
          -9871.841999999999,
          -9820.689,
          -9769.011,
          -9716.806999999999,
          -9664.076,
          -9610.815999999999,
          -9557.026,
          -9502.704,
          -9447.85,
          -9392.461,
          -9336.538,
          -9280.077,
          -9223.077,
          -9165.537,
          -9107.457,
          -9048.833,
          -8989.664,
          -8929.949,
          -8869.687,
          -8808.875,
          -8747.511999999999,
          -8685.597,
          -8623.127,
          -8560.101,
          -8496.518,
          -8432.375,
          -8367.671,
          -8302.403,
          -8236.571,
          -8170.172,
          -8103.204000000001,
          -8035.6669999999995,
          -7967.557,
          -7898.8730000000005,
          -7829.613,
          -7759.774,
          -7689.356,
          -7618.356,
          -7546.772,
          -7474.602,
          -7401.844,
          -7328.496,
          -7254.557,
          -7180.023,
          -7104.892,
          -7029.164000000001,
          -6952.834,
          -6875.903,
          -6798.368,
          -6720.225,
          -6641.474,
          -6562.111,
          -6482.1359999999995,
          -6401.545999999999,
          -6320.338000000001,
          -6238.5109999999995,
          -6156.063,
          -6072.991,
          -5989.294,
          -5904.969,
          -5820.014,
          -5734.428000000001,
          -5648.2080000000005,
          -5561.352,
          -5473.86,
          -5385.728,
          -5296.955,
          -5207.539000000001,
          -5117.479,
          -5026.773,
          -4935.419,
          -4843.416,
          -4750.763,
          -4657.459,
          -4563.501,
          -4468.89,
          -4373.625,
          -4277.705,
          -4181.129,
          -4083.8979999999997,
          -3986.01,
          -3887.466,
          -3788.2670000000003,
          -3688.413,
          -3587.905,
          -3486.743,
          -3384.9309999999996,
          -3282.47,
          -3179.362,
          -3075.6090000000004,
          -2971.216,
          -2866.185,
          -2760.5229999999997,
          -2654.2329999999997,
          -2547.321,
          -2439.7929999999997,
          -2331.658,
          -2222.923,
          -2113.597,
          -2003.69,
          -1893.215,
          -1782.183,
          -1670.609,
          -1558.5079999999998,
          -1445.898,
          -1332.7979999999998,
          -1219.2269999999999,
          -1105.211,
          -990.7739999999999,
          -875.944,
          -760.7539999999999,
          -645.237,
          -529.43,
          -413.376,
          -297.119,
          -180.71099999999998,
          -64.206,
          52.333999999999996,
          168.843,
          285.247,
          401.465,
          517.408,
          632.977,
          748.064,
          862.551,
          976.308,
          1089.191,
          1201.042,
          1311.6879999999999,
          1420.9389999999999,
          1528.588,
          1634.4070000000002,
          1738.145,
          1839.533,
          1938.275,
          2034.05,
          2126.511,
          2215.286,
          2299.974,
          2380.15,
          2455.365,
          2525.146,
          2589.005,
          2646.441,
          2696.947,
          2740.022,
          2775.178,
          2801.955,
          2819.9320000000002,
          2828.742,
          2828.086,
          2817.743,
          2797.5820000000003,
          2767.57,
          2727.7740000000003,
          2678.361,
          2619.594,
          2551.823,
          2475.471,
          2391.027,
          2299.024,
          2200.027,
          2094.621,
          1983.391,
          1866.9189999999999,
          1745.769,
          1620.4820000000002,
          1491.5710000000001,
          1359.516,
          1224.765,
          1087.729,
          948.785,
          808.278,
          666.518,
          523.7869999999999,
          380.34,
          236.40200000000002,
          92.176,
          -52.157,
          -196.43400000000003,
          -340.515,
          -484.27099999999996,
          -627.592,
          -770.377,
          -912.54,
          -1054.006,
          -1194.7060000000001,
          -1334.5810000000001,
          -1473.582,
          -1611.664,
          -1748.789,
          -1884.9229999999998,
          -2020.0379999999998,
          -2154.111,
          -2287.121,
          -2419.052,
          -2549.89,
          -2679.6220000000003,
          -2808.241,
          -2935.74,
          -3062.113,
          -3187.3579999999997,
          -3311.474,
          -3434.4570000000003,
          -3556.312,
          -3677.038,
          -3796.637,
          -3915.115,
          -4032.474,
          -4148.719,
          -4263.856,
          -4377.889,
          -4490.825,
          -4602.670999999999,
          -4713.432,
          -4823.117,
          -4931.732,
          -5039.284000000001,
          -5145.782,
          -5251.232,
          -5355.641,
          -5459.019,
          -5561.3730000000005,
          -5662.71,
          -5763.039000000001,
          -5862.366999999999,
          -5960.701999999999,
          -6058.052,
          -6154.4259999999995,
          -6249.829000000001,
          -6344.271,
          -6437.759,
          -6530.3009999999995,
          -6621.904,
          -6712.575,
          -6802.323,
          -6891.154,
          -6979.075,
          -7066.095,
          -7152.219,
          -7237.455,
          -7321.81,
          -7405.291,
          -7487.904,
          -7569.656,
          -7650.554,
          -7730.603,
          -7809.811,
          -7888.184,
          -7965.728,
          -8042.4490000000005,
          -8118.353,
          -8193.445,
          -8267.734,
          -8341.222,
          -8413.917,
          -8485.824,
          -8556.948,
          -8627.294,
          -8696.869,
          -8765.677,
          -8833.724,
          -8901.015,
          -8967.554,
          -9033.347,
          -9098.398000000001,
          -9162.713,
          -9226.295,
          -9289.15,
          -9351.282,
          -9412.696,
          -9473.396,
          -9533.386,
          -9592.671,
          -9651.255,
          -9709.143,
          -9766.337,
          -9822.841999999999,
          -9878.663,
          -9933.802,
          -9988.264000000001,
          -10042.053,
          -10095.171999999999,
          -10147.626,
          -10199.417,
          -10250.549,
          -10301.025,
          -10350.85,
          -10400.026,
          -10448.558,
          -10496.447,
          -10543.697,
          -10590.311000000002,
          -10636.294,
          -10681.646999999999,
          -10726.373,
          -10770.476,
          -10813.958,
          -10856.823,
          -10899.073999999999,
          -10940.712,
          -10981.741000000002,
          -11022.163,
          -11061.981000000002,
          -11101.198999999999,
          -11139.818000000001,
          -11177.841,
          -11215.268999999998,
          -11252.108,
          -11288.357,
          -11324.018999999998,
          -11359.098,
          -11393.594,
          -11427.511999999999,
          -11460.851999999999,
          -11493.617,
          -11525.809,
          -11557.431,
          -11588.483,
          -11618.969,
          -11648.89,
          -11678.25,
          -11707.048,
          -11735.287,
          -11762.97,
          -11790.097,
          -11816.671999999999,
          -11842.695,
          -11868.168,
          -11893.093,
          -11917.473,
          -11941.308,
          -11964.6,
          -11987.351,
          -12009.562,
          -12031.235,
          -12052.372,
          -12072.973999999998,
          -12093.042,
          -12112.578000000001,
          -12131.583,
          -12150.06,
          -12168.008,
          -12185.431,
          -12202.328000000001,
          -12218.701000000001,
          -12234.551000000001,
          -12249.88,
          -12264.688999999998,
          -12278.98,
          -12292.753,
          -12306.008999999998,
          -12318.75,
          -12330.976999999999,
          -12342.69,
          -12353.892,
          -12364.583,
          -12374.763,
          -12384.435,
          -12393.598,
          -12402.255,
          -12410.405,
          -12418.051000000001,
          -12425.192,
          -12431.83,
          -12437.965,
          -12443.598999999998,
          -12448.731000000002,
          -12453.364,
          -12457.498,
          -12461.133,
          -12464.271,
          -12466.911,
          -12469.055,
          -12470.704,
          -12471.857,
          -12472.516000000001,
          -12472.681,
          -12472.353000000001,
          -12471.533000000001,
          -12470.221000000001,
          -12468.417,
          -12466.123,
          -12463.338,
          -12460.063,
          -12456.3,
          -12452.046999999999,
          -12447.306,
          -12442.077,
          -12436.36,
          -12430.155,
          -12423.464,
          -12416.287,
          -12408.624,
          -12400.475,
          -12391.84,
          -12382.719,
          -12373.114,
          -12363.024,
          -12352.45,
          -12341.392,
          -12329.85,
          -12317.823,
          -12305.313,
          -12292.32,
          -12278.843,
          -12264.883,
          -12250.44,
          -12235.513,
          -12220.103000000001,
          -12204.211000000001,
          -12187.835,
          -12170.976999999999,
          -12153.636,
          -12135.812,
          -12117.503999999999,
          -12098.714,
          -12079.441,
          -12059.684,
          -12039.444,
          -12018.722,
          -11997.515,
          -11975.825,
          -11953.651000000002,
          -11930.993,
          -11907.851,
          -11884.223999999998,
          -11860.113000000001,
          -11835.517,
          -11810.435,
          -11784.868,
          -11758.815,
          -11732.277,
          -11705.252,
          -11677.74,
          -11649.741000000002,
          -11621.255,
          -11592.281,
          -11562.818000000001,
          -11532.867,
          -11502.426000000001,
          -11471.496000000001,
          -11440.076000000001,
          -11408.163999999999,
          -11375.761999999999,
          -11342.868,
          -11309.482,
          -11275.603000000001,
          -11241.23,
          -11206.363000000001,
          -11171.002,
          -11135.145,
          -11098.793,
          -11061.943000000001,
          -11024.596000000001,
          -10986.751,
          -10948.408000000001,
          -10909.565,
          -10870.221000000001,
          -10830.375,
          -10790.028,
          -10749.178,
          -10707.825,
          -10665.966999999999,
          -10623.603000000001,
          -10580.733,
          -10537.356000000002,
          -10493.471000000001,
          -10449.076,
          -10404.171,
          -10358.755,
          -10312.826,
          -10266.384,
          -10219.429,
          -10171.958,
          -10123.97,
          -10075.464,
          -10026.44,
          -9976.895,
          -9926.83,
          -9876.242,
          -9825.131,
          -9773.495,
          -9721.332,
          -9668.642,
          -9615.424,
          -9561.676,
          -9507.395,
          -9452.582,
          -9397.235,
          -9341.351999999999,
          -9284.933,
          -9227.975,
          -9170.476999999999,
          -9112.437,
          -9053.854,
          -8994.726999999999,
          -8935.054,
          -8874.832,
          -8814.062,
          -8752.74,
          -8690.865,
          -8628.437,
          -8565.452,
          -8501.91,
          -8437.808,
          -8373.145,
          -8307.919,
          -8242.128,
          -8175.77,
          -8108.844,
          -8041.347,
          -7973.278,
          -7904.635,
          -7835.416,
          -7765.619000000001,
          -7695.241,
          -7624.281999999999,
          -7552.74,
          -7480.611,
          -7407.893,
          -7334.585999999999,
          -7260.687,
          -7186.194,
          -7111.105,
          -7035.4169999999995,
          -6959.129,
          -6882.2390000000005,
          -6804.743,
          -6726.642,
          -6647.932,
          -6568.61,
          -6488.6759999999995,
          -6408.126,
          -6326.96,
          -6245.173000000001,
          -6162.766,
          -6079.734,
          -5996.076999999999,
          -5911.793000000001,
          -5826.879,
          -5741.3330000000005,
          -5655.154,
          -5568.339,
          -5480.887,
          -5392.795,
          -5304.062,
          -5214.687,
          -5124.667,
          -5034.001,
          -4942.687,
          -4850.724,
          -4758.111,
          -4664.847,
          -4570.929,
          -4476.358,
          -4381.1320000000005,
          -4285.251,
          -4188.714,
          -4091.5209999999997,
          -3993.672,
          -3895.167,
          -3796.006,
          -3696.19,
          -3595.719,
          -3494.595,
          -3392.82,
          -3290.3959999999997,
          -3187.324,
          -3083.607,
          -2979.2490000000003,
          -2874.2540000000004,
          -2768.6259999999997,
          -2662.369,
          -2555.49,
          -2447.995,
          -2339.8920000000003,
          -2231.188,
          -2121.8920000000003,
          -2012.014,
          -1901.567,
          -1790.5620000000001,
          -1679.014,
          -1566.9370000000001,
          -1454.35,
          -1341.271,
          -1227.72,
          -1113.721,
          -999.3,
          -884.4839999999999,
          -769.304,
          -653.795,
          -537.993,
          -421.94,
          -305.682,
          -189.268,
          -72.753,
          43.802,
          160.33,
          276.76,
          393.009,
          508.98900000000003,
          624.604,
          739.745,
          854.296,
          968.125,
          1081.0910000000001,
          1193.038,
          1303.792,
          1413.1660000000002,
          1520.954,
          1626.9279999999999,
          1730.8410000000001,
          1832.424,
          1931.384,
          2027.4,
          2120.13,
          2209.201,
          2294.217,
          2374.7529999999997,
          2450.361,
          2520.572,
          2584.899,
          2642.84,
          2693.8909999999996,
          2737.55,
          2773.327,
          2800.76,
          2819.425,
          2828.953,
          2829.0370000000003,
          2819.452,
          2800.059,
          2770.8190000000004,
          2731.7909999999997,
          2683.134,
          2625.1040000000003,
          2558.045,
          2482.374,
          2398.577,
          2307.18,
          2208.749,
          2103.865,
          1993.115,
          1877.079,
          1756.3229999999999,
          1631.391,
          1502.796,
          1371.021,
          1236.515,
          1099.693,
          960.933,
          820.584,
          678.9580000000001,
          536.339,
          392.98199999999997,
          249.11599999999999,
          104.946,
          -39.346,
          -183.59599999999998,
          -327.66200000000003,
          -471.414,
          -614.74,
          -757.54,
          -899.727,
          -1041.222,
          -1181.958,
          -1321.876,
          -1460.924,
          -1599.058,
          -1736.2379999999998,
          -1872.432,
          -2007.611,
          -2141.749,
          -2274.828,
          -2406.83,
          -2537.74,
          -2667.548,
          -2796.243,
          -2923.8190000000004,
          -3050.272,
          -3175.597,
          -3299.7929999999997,
          -3422.8590000000004,
          -3544.795,
          -3665.605,
          -3785.288,
          -3903.85,
          -4021.2929999999997,
          -4137.622,
          -4252.843,
          -4366.962,
          -4479.983,
          -4591.914000000001,
          -4702.76,
          -4812.53,
          -4921.23,
          -5028.867,
          -5135.4490000000005,
          -5240.983,
          -5345.477,
          -5448.939,
          -5551.3769999999995,
          -5652.798000000001,
          -5753.21,
          -5852.621,
          -5951.039000000001,
          -6048.472,
          -6144.928000000001,
          -6240.4130000000005,
          -6334.937,
          -6428.505999999999,
          -6521.129,
          -6612.812,
          -6703.564,
          -6793.392,
          -6882.302,
          -6970.303000000001,
          -7057.401999999999,
          -7143.605,
          -7228.919,
          -7313.352,
          -7396.91,
          -7479.601,
          -7561.429,
          -7642.404,
          -7722.53,
          -7801.814,
          -7880.263000000001,
          -7957.882,
          -8034.678000000001,
          -8110.656,
          -8185.8240000000005,
          -8260.186,
          -8333.747,
          -8406.515,
          -8478.495,
          -8549.692,
          -8620.110999999999,
          -8689.758,
          -8758.638,
          -8826.756,
          -8894.118,
          -8960.726999999999,
          -9026.591,
          -9091.713,
          -9156.097,
          -9219.749,
          -9282.674,
          -9344.875,
          -9406.357,
          -9467.125,
          -9527.184000000001,
          -9586.537,
          -9645.189,
          -9703.143,
          -9760.404,
          -9816.976999999999,
          -9872.864,
          -9928.069,
          -9982.597,
          -10036.452,
          -10089.638,
          -10142.155999999999,
          -10194.011999999999,
          -10245.209,
          -10295.75,
          -10345.639000000001,
          -10394.879,
          -10443.474,
          -10491.427,
          -10538.74,
          -10585.418,
          -10631.463,
          -10676.878,
          -10721.667,
          -10765.832,
          -10809.377,
          -10852.303999999998,
          -10894.615,
          -10936.315,
          -10977.406,
          -11017.889,
          -11057.768,
          -11097.046,
          -11135.725,
          -11173.808,
          -11211.296999999999,
          -11248.194,
          -11284.502,
          -11320.225,
          -11355.363000000001,
          -11389.918,
          -11423.893999999998,
          -11457.293,
          -11490.116000000002,
          -11522.367,
          -11554.046,
          -11585.157,
          -11615.7,
          -11645.678999999998,
          -11675.096000000001,
          -11703.951000000001,
          -11732.247,
          -11759.986,
          -11787.17,
          -11813.801000000001,
          -11839.881000000001,
          -11865.41,
          -11890.392,
          -11914.827,
          -11938.716999999999,
          -11962.065,
          -11984.872,
          -12007.138,
          -12028.866000000002,
          -12050.056999999999,
          -12070.713,
          -12090.836000000001,
          -12110.427,
          -12129.487,
          -12148.017,
          -12166.02,
          -12183.496000000001,
          -12200.447,
          -12216.873,
          -12232.777,
          -12248.16,
          -12263.021999999999,
          -12277.365,
          -12291.191,
          -12304.5,
          -12317.294,
          -12329.573,
          -12341.338,
          -12352.591999999999,
          -12363.335,
          -12373.567,
          -12383.291000000001,
          -12392.506000000001,
          -12401.214,
          -12409.416000000001,
          -12417.113000000001,
          -12424.306,
          -12430.995,
          -12437.181,
          -12442.865,
          -12448.048,
          -12452.732,
          -12456.916000000001,
          -12460.601999999999,
          -12463.788999999999,
          -12466.48,
          -12468.673999999999,
          -12470.372,
          -12471.576000000001,
          -12472.284,
          -12472.499,
          -12472.22,
          -12471.448999999999,
          -12470.187,
          -12468.431999999999,
          -12466.187,
          -12463.451000000001,
          -12460.225,
          -12456.51,
          -12452.306999999999,
          -12447.614,
          -12442.433,
          -12436.765,
          -12430.608999999999,
          -12423.966,
          -12416.836000000001,
          -12409.221000000001,
          -12401.12,
          -12392.533000000001,
          -12383.46,
          -12373.903,
          -12363.861,
          -12353.333999999999,
          -12342.323,
          -12330.828000000001,
          -12318.848999999998,
          -12306.386,
          -12293.438999999998,
          -12280.008999999998,
          -12266.096000000001,
          -12251.698999999999,
          -12236.819,
          -12221.456,
          -12205.61,
          -12189.281,
          -12172.469,
          -12155.173999999999,
          -12137.396999999999,
          -12119.135,
          -12100.391000000001,
          -12081.163999999999,
          -12061.453000000001,
          -12041.26,
          -12020.582,
          -11999.421,
          -11977.777,
          -11955.648000000001,
          -11933.035,
          -11909.938999999998,
          -11886.357,
          -11862.291000000001,
          -11837.74,
          -11812.704,
          -11787.181999999999,
          -11761.175,
          -11734.681,
          -11707.701000000001,
          -11680.233999999999,
          -11652.278999999999,
          -11623.838,
          -11594.908000000001,
          -11565.49,
          -11535.583999999999,
          -11505.187,
          -11474.301000000001,
          -11442.925,
          -11411.059,
          -11378.701000000001,
          -11345.851,
          -11312.508,
          -11278.673,
          -11244.344,
          -11209.521999999999,
          -11174.204,
          -11138.392,
          -11102.083,
          -11065.277,
          -11027.973999999998,
          -10990.171999999999,
          -10951.872,
          -10913.072,
          -10873.771999999999,
          -10833.97,
          -10793.666000000001,
          -10752.858999999999,
          -10711.548999999999,
          -10669.735,
          -10627.413999999999,
          -10584.587,
          -10541.253,
          -10497.411,
          -10453.06,
          -10408.197,
          -10362.824,
          -10316.939,
          -10270.54,
          -10223.627,
          -10176.199,
          -10128.254,
          -10079.791,
          -10030.809000000001,
          -9981.306999999999,
          -9931.284,
          -9880.739,
          -9829.671,
          -9778.077,
          -9725.957,
          -9673.31,
          -9620.134,
          -9566.428,
          -9512.190999999999,
          -9457.42,
          -9402.115,
          -9346.275,
          -9289.898000000001,
          -9232.982,
          -9175.527,
          -9117.529,
          -9058.988000000001,
          -8999.904,
          -8940.273000000001,
          -8880.094000000001,
          -8819.365,
          -8758.085,
          -8696.253,
          -8633.867,
          -8570.925,
          -8507.425,
          -8443.365,
          -8378.743,
          -8313.56,
          -8247.811,
          -8181.495,
          -8114.611,
          -8047.156,
          -7979.129,
          -7910.528,
          -7841.351,
          -7771.596,
          -7701.2609999999995,
          -7630.344,
          -7558.843000000001,
          -7486.755999999999,
          -7414.081,
          -7340.816,
          -7266.959,
          -7192.507,
          -7117.46,
          -7041.815,
          -6965.569,
          -6888.72,
          -6811.267,
          -6733.206999999999,
          -6654.539000000001,
          -6575.259,
          -6495.366,
          -6414.859,
          -6333.734,
          -6251.99,
          -6169.624,
          -6086.634,
          -6003.019,
          -5918.776,
          -5833.904,
          -5748.4,
          -5662.262,
          -5575.4890000000005,
          -5488.079000000001,
          -5400.028,
          -5311.3369999999995,
          -5222.002,
          -5132.024,
          -5041.399,
          -4950.126,
          -4858.204000000001,
          -4765.6320000000005,
          -4672.409000000001,
          -4578.532,
          -4484.001,
          -4388.815,
          -4292.974,
          -4196.478,
          -4099.325,
          -4001.515,
          -3903.05,
          -3803.928,
          -3704.151,
          -3603.719,
          -3502.633,
          -3400.8959999999997,
          -3298.509,
          -3195.475,
          -3091.795,
          -2987.474,
          -2882.515,
          -2776.922,
          -2670.7,
          -2563.855,
          -2456.393,
          -2348.322,
          -2239.65,
          -2130.385,
          -2020.537,
          -1910.119,
          -1799.142,
          -1687.62,
          -1575.568,
          -1463.005,
          -1349.9470000000001,
          -1236.4160000000002,
          -1122.4360000000001,
          -1008.0310000000001,
          -893.2289999999999,
          -778.06,
          -662.559,
          -546.763,
          -430.712,
          -314.452,
          -198.033,
          -81.508,
          35.061,
          151.61,
          268.064,
          384.345,
          500.36400000000003,
          616.025,
          731.221,
          845.835,
          959.738,
          1072.789,
          1184.8319999999999,
          1295.697,
          1405.195,
          1513.1229999999998,
          1619.255,
          1723.346,
          1825.1270000000002,
          1924.307,
          2020.569,
          2113.571,
          2202.9429999999998,
          2288.291,
          2369.192,
          2445.2,
          2515.848,
          2580.649,
          2639.1040000000003,
          2690.708,
          2734.96,
          2771.367,
          2799.468,
          2818.835,
          2829.092,
          2829.93,
          2821.117,
          2802.508,
          2774.055,
          2735.81,
          2687.926,
          2630.6490000000003,
          2564.3179999999998,
          2489.345,
          2406.208,
          2315.4339999999997,
          2217.5820000000003,
          2113.234,
          2002.976,
          1887.388,
          1767.0379999999998,
          1642.469,
          1514.1979999999999,
          1382.711,
          1248.4569999999999,
          1111.855,
          973.2860000000001,
          833.1,
          691.6110000000001,
          549.107,
          405.844,
          262.05400000000003,
          117.941,
          -26.308000000000003,
          -170.53,
          -314.579,
          -458.32599999999996,
          -601.658,
          -744.472,
          -886.682,
          -1028.345,
          -1168.979,
          -1308.94,
          -1448.036,
          -1586.2220000000002,
          -1723.4589999999998,
          -1859.714,
          -1994.9560000000001,
          -2129.1620000000003,
          -2262.31,
          -2394.384,
          -2525.368,
          -2655.252,
          -2784.0240000000003,
          -2911.68,
          -3038.2129999999997,
          -3163.619,
          -3287.8979999999997,
          -3411.047,
          -3533.067,
          -3653.961,
          -3773.7290000000003,
          -3892.3759999999997,
          -4009.905,
          -4126.321,
          -4241.628,
          -4355.833,
          -4468.941,
          -4580.958,
          -4691.891,
          -4801.747,
          -4910.534000000001,
          -5018.2570000000005,
          -5124.925,
          -5230.545,
          -5335.125,
          -5438.673000000001,
          -5541.196,
          -5642.701999999999,
          -5743.1990000000005,
          -5842.694,
          -5941.196999999999,
          -6038.714,
          -6135.253000000001,
          -6230.821999999999,
          -6325.429,
          -6419.081,
          -6511.786,
          -6603.552,
          -6694.3859999999995,
          -6784.295,
          -6873.286,
          -6961.366999999999,
          -7048.547,
          -7134.83,
          -7220.224,
          -7304.736999999999,
          -7388.374,
          -7471.142,
          -7553.05,
          -7634.102,
          -7714.306,
          -7793.6669999999995,
          -7872.193,
          -7949.889,
          -8026.7609999999995,
          -8102.815,
          -8178.058000000001,
          -8252.495,
          -8326.132,
          -8398.974,
          -8471.028,
          -8542.299,
          -8612.792,
          -8682.511999999999,
          -8751.466,
          -8819.655999999999,
          -8887.09,
          -8953.771999999999,
          -9019.707,
          -9084.9,
          -9149.356,
          -9213.079,
          -9276.074,
          -9338.345,
          -9399.898000000001,
          -9460.735999999999,
          -9520.863000000001,
          -9580.286,
          -9639.006,
          -9697.029,
          -9754.359,
          -9810.999,
          -9866.954,
          -9922.226999999999,
          -9976.822,
          -10030.744,
          -10083.996,
          -10136.581,
          -10188.503,
          -10239.766,
          -10290.373,
          -10340.328000000001,
          -10389.633,
          -10438.292,
          -10486.31,
          -10533.688,
          -10580.43,
          -10626.538999999999,
          -10672.018,
          -10716.87,
          -10761.098999999998,
          -10804.707,
          -10847.697,
          -10890.071000000002,
          -10931.833,
          -10972.986,
          -11013.53,
          -11053.471000000001,
          -11092.811000000002,
          -11131.552,
          -11169.696000000002,
          -11207.245,
          -11244.204,
          -11280.573,
          -11316.356000000002,
          -11351.553,
          -11386.169,
          -11420.205,
          -11453.663,
          -11486.546,
          -11518.856000000002,
          -11550.594,
          -11581.764,
          -11612.367,
          -11642.403999999999,
          -11671.878,
          -11700.792,
          -11729.146,
          -11756.944,
          -11784.186000000002,
          -11810.874,
          -11837.01,
          -11862.597,
          -11887.635,
          -11912.128,
          -11936.075,
          -11959.479,
          -11982.341,
          -12004.663999999999,
          -12026.448999999999,
          -12047.696000000002,
          -12068.408000000001,
          -12088.586000000001,
          -12108.232,
          -12127.347,
          -12145.933,
          -12163.991000000002,
          -12181.521,
          -12198.527,
          -12215.008,
          -12230.966999999999,
          -12246.403,
          -12261.32,
          -12275.716999999999,
          -12289.596000000001,
          -12302.958999999999,
          -12315.806,
          -12328.139,
          -12339.958,
          -12351.265,
          -12362.061000000002,
          -12372.347,
          -12382.123,
          -12391.391000000001,
          -12400.152,
          -12408.406,
          -12416.156,
          -12423.4,
          -12430.141000000001,
          -12436.378999999999,
          -12442.115,
          -12447.35,
          -12452.085,
          -12456.321000000002,
          -12460.058,
          -12463.296999999999,
          -12466.038,
          -12468.284,
          -12470.033000000001,
          -12471.287,
          -12472.046,
          -12472.312,
          -12472.083999999999,
          -12471.363000000001,
          -12470.151000000002,
          -12468.447,
          -12466.251,
          -12463.566,
          -12460.39,
          -12456.723999999998,
          -12452.57,
          -12447.927,
          -12442.796,
          -12437.176000000001,
          -12431.07,
          -12424.476,
          -12417.396,
          -12409.829,
          -12401.777,
          -12393.239,
          -12384.215,
          -12374.706,
          -12364.713,
          -12354.235,
          -12343.271999999999,
          -12331.825,
          -12319.893999999998,
          -12307.479,
          -12294.581,
          -12281.198999999999,
          -12267.333,
          -12252.983999999999,
          -12238.151000000002,
          -12222.836000000001,
          -12207.038,
          -12190.756000000001,
          -12173.992,
          -12156.743999999999,
          -12139.013,
          -12120.798999999999,
          -12102.101999999999,
          -12082.921999999999,
          -12063.258,
          -12043.111,
          -12022.48,
          -12001.366000000002,
          -11979.768,
          -11957.686000000002,
          -11935.12,
          -11912.069,
          -11888.534,
          -11864.514,
          -11840.01,
          -11815.02,
          -11789.544,
          -11763.582,
          -11737.133999999998,
          -11710.2,
          -11682.778,
          -11654.87,
          -11626.473999999998,
          -11597.59,
          -11568.216999999999,
          -11538.356000000002,
          -11508.006000000001,
          -11477.165,
          -11445.833999999999,
          -11414.013,
          -11381.7,
          -11348.895,
          -11315.598,
          -11281.808,
          -11247.524,
          -11212.746000000001,
          -11177.473999999998,
          -11141.705,
          -11105.441,
          -11068.681,
          -11031.421999999999,
          -10993.665,
          -10955.409,
          -10916.653999999999,
          -10877.398000000001,
          -10837.641000000001,
          -10797.382,
          -10756.618999999999,
          -10715.353000000001,
          -10673.582,
          -10631.306,
          -10588.524,
          -10545.233999999999,
          -10501.436000000002,
          -10457.128,
          -10412.31,
          -10366.982,
          -10321.14,
          -10274.785,
          -10227.916,
          -10180.530999999999,
          -10132.63,
          -10084.211,
          -10035.273000000001,
          -9985.815,
          -9935.836,
          -9885.335,
          -9834.31,
          -9782.76,
          -9730.684000000001,
          -9678.08,
          -9624.947,
          -9571.285,
          -9517.091,
          -9462.364,
          -9407.103000000001,
          -9351.306,
          -9294.972,
          -9238.1,
          -9180.687,
          -9122.733,
          -9064.235999999999,
          -9005.194,
          -8945.607,
          -8885.471,
          -8824.785,
          -8763.549,
          -8701.76,
          -8639.417,
          -8576.518,
          -8513.061,
          -8449.044,
          -8384.466,
          -8319.326,
          -8253.62,
          -8187.347,
          -8120.505999999999,
          -8053.095,
          -7985.111,
          -7916.553000000001,
          -7847.419,
          -7777.706999999999,
          -7707.415,
          -7636.541,
          -7565.0830000000005,
          -7493.039000000001,
          -7420.406999999999,
          -7347.185,
          -7273.371999999999,
          -7198.963000000001,
          -7123.959,
          -7048.356,
          -6972.153,
          -6895.347,
          -6817.938,
          -6739.920999999999,
          -6661.295,
          -6582.059,
          -6502.209,
          -6421.744000000001,
          -6340.661999999999,
          -6258.96,
          -6176.637,
          -6093.691,
          -6010.119000000001,
          -5925.919,
          -5841.089,
          -5755.628000000001,
          -5669.533,
          -5582.802,
          -5495.434,
          -5407.4259999999995,
          -5318.776999999999,
          -5229.485,
          -5139.549,
          -5048.965999999999,
          -4957.735,
          -4865.855,
          -4773.326,
          -4680.143,
          -4586.308,
          -4491.819,
          -4396.675,
          -4300.876,
          -4204.42,
          -4107.308,
          -4009.539,
          -3911.114,
          -3812.032,
          -3712.295,
          -3611.903,
          -3510.857,
          -3409.159,
          -3306.81,
          -3203.8140000000003,
          -3100.172,
          -2995.888,
          -2890.965,
          -2785.409,
          -2679.223,
          -2572.413,
          -2464.986,
          -2356.948,
          -2248.308,
          -2139.075,
          -2029.259,
          -1918.87,
          -1807.921,
          -1696.4260000000002,
          -1584.401,
          -1471.861,
          -1358.826,
          -1245.316,
          -1131.355,
          -1016.966,
          -902.178,
          -787.0210000000001,
          -671.529,
          -555.739,
          -439.69,
          -323.42900000000003,
          -207.00400000000002,
          -90.47,
          26.114,
          142.68200000000002,
          259.163,
          375.476,
          491.534,
          607.241,
          722.492,
          837.171,
          951.148,
          1064.2839999999999,
          1176.4260000000002,
          1287.402,
          1397.027,
          1505.0970000000002,
          1611.389,
          1715.66,
          1817.641,
          1917.045,
          2013.556,
          2106.834,
          2196.511,
          2282.195,
          2363.466,
          2439.88,
          2510.971,
          2576.254,
          2635.23,
          2687.397,
          2732.2490000000003,
          2769.298,
          2798.077,
          2818.156,
          2829.155,
          2830.76,
          2822.7329999999997,
          2804.921,
          2777.27,
          2739.824,
          2692.728,
          2636.22,
          2570.632,
          2496.3720000000003,
          2413.911,
          2323.772,
          2226.515,
          2122.715,
          2012.961,
          1897.832,
          1777.8970000000002,
          1653.7020000000002,
          1525.764,
          1394.5720000000001,
          1260.578,
          1124.202,
          985.83,
          845.81,
          704.4639999999999,
          562.078,
          418.912,
          275.199,
          131.14700000000002,
          -13.057,
          -157.249,
          -301.281,
          -445.023,
          -588.359,
          -731.188,
          -873.419,
          -1014.9739999999999,
          -1155.7839999999999,
          -1295.787,
          -1434.932,
          -1573.172,
          -1710.4660000000001,
          -1846.781,
          -1982.089,
          -2116.363,
          -2249.5820000000003,
          -2381.728,
          -2512.788,
          -2642.748,
          -2771.6,
          -2899.335,
          -3025.95,
          -3151.4390000000003,
          -3275.801,
          -3399.035,
          -3521.14,
          -3642.12,
          -3761.974,
          -3880.708,
          -3998.324,
          -4114.827,
          -4230.222,
          -4344.515,
          -4457.71,
          -4569.816,
          -4680.837,
          -4790.781,
          -4899.655,
          -5007.465999999999,
          -5114.221,
          -5219.929,
          -5324.596,
          -5428.231,
          -5530.840999999999,
          -5632.433000000001,
          -5733.016,
          -5832.598000000001,
          -5931.186,
          -6028.789000000001,
          -6125.4130000000005,
          -6221.066,
          -6315.758000000001,
          -6409.494000000001,
          -6502.283,
          -6594.132,
          -6685.049,
          -6775.041,
          -6864.115,
          -6952.279,
          -7039.539000000001,
          -7125.903,
          -7211.379,
          -7295.972,
          -7379.69,
          -7462.539000000001,
          -7544.525,
          -7625.656999999999,
          -7705.939,
          -7785.38,
          -7863.983,
          -7941.757,
          -8018.706999999999,
          -8094.838000000001,
          -8170.158,
          -8244.671,
          -8318.385,
          -8391.303,
          -8463.431999999999,
          -8534.779,
          -8605.346,
          -8675.141,
          -8744.168,
          -8812.433,
          -8879.94,
          -8946.696,
          -9012.704,
          -9077.969000000001,
          -9142.497,
          -9206.292,
          -9269.359,
          -9331.702,
          -9393.325,
          -9454.234,
          -9514.431999999999,
          -9573.925,
          -9632.716,
          -9690.808,
          -9748.207,
          -9804.917,
          -9860.94,
          -9916.282,
          -9970.946,
          -10024.936,
          -10078.255,
          -10130.908000000001,
          -10182.896999999999,
          -10234.226999999999,
          -10284.901,
          -10334.921999999999,
          -10384.294,
          -10433.02,
          -10481.103000000001,
          -10528.546999999999,
          -10575.354,
          -10621.528,
          -10667.072,
          -10711.99,
          -10756.282,
          -10799.954,
          -10843.008,
          -10885.446000000002,
          -10927.271999999999,
          -10968.487,
          -11009.096000000001,
          -11049.1,
          -11088.502,
          -11127.305,
          -11165.511,
          -11203.123,
          -11240.143999999998,
          -11276.575,
          -11312.418,
          -11347.678,
          -11382.354,
          -11416.451000000001,
          -11449.97,
          -11482.913999999999,
          -11515.284,
          -11547.082,
          -11578.312,
          -11608.973999999998,
          -11639.071000000002,
          -11668.605,
          -11697.578000000001,
          -11725.991000000002,
          -11753.848,
          -11781.148000000001,
          -11807.895,
          -11834.09,
          -11859.733999999999,
          -11884.831,
          -11909.381000000001,
          -11933.386,
          -11956.847,
          -11979.767,
          -12002.148000000001,
          -12023.989,
          -12045.293,
          -12066.062,
          -12086.296999999999,
          -12105.999,
          -12125.171,
          -12143.813,
          -12161.926000000001,
          -12179.513,
          -12196.573999999999,
          -12213.111,
          -12229.125,
          -12244.617,
          -12259.589,
          -12274.041000000001,
          -12287.975,
          -12301.392,
          -12314.294,
          -12326.681999999999,
          -12338.555,
          -12349.916000000001,
          -12360.766000000001,
          -12371.106000000002,
          -12380.936000000002,
          -12390.258,
          -12399.072,
          -12407.38,
          -12415.181999999999,
          -12422.48,
          -12429.274,
          -12435.565,
          -12441.354,
          -12446.642,
          -12451.43,
          -12455.718,
          -12459.507,
          -12462.798,
          -12465.591999999999,
          -12467.889,
          -12469.691,
          -12470.996000000001,
          -12471.806999999999,
          -12472.124,
          -12471.948,
          -12471.278999999999,
          -12470.117,
          -12468.464,
          -12466.32,
          -12463.685,
          -12460.56,
          -12456.946000000002,
          -12452.841999999999,
          -12448.25,
          -12443.169,
          -12437.6,
          -12431.543,
          -12425,
          -12417.97,
          -12410.453000000001,
          -12402.451000000001,
          -12393.962,
          -12384.988000000001,
          -12375.528999999999,
          -12365.585,
          -12355.157,
          -12344.243,
          -12332.845,
          -12320.963,
          -12308.598,
          -12295.749,
          -12282.415,
          -12268.598,
          -12254.298,
          -12239.514,
          -12224.247,
          -12208.498,
          -12192.265,
          -12175.548,
          -12158.348999999998,
          -12140.666000000001,
          -12122.5,
          -12103.851999999999,
          -12084.719,
          -12065.103000000001,
          -12045.003999999999,
          -12024.421,
          -12003.354,
          -11981.803999999998,
          -11959.768999999998,
          -11937.251,
          -11914.248,
          -11890.76,
          -11866.787,
          -11842.33,
          -11817.386999999999,
          -11791.958,
          -11766.043,
          -11739.642,
          -11712.755,
          -11685.38,
          -11657.518999999998,
          -11629.17,
          -11600.332,
          -11571.006000000001,
          -11541.191,
          -11510.886999999999,
          -11480.093,
          -11448.809,
          -11417.033000000001,
          -11384.766000000001,
          -11352.008,
          -11318.757,
          -11285.013,
          -11250.775,
          -11216.043,
          -11180.816,
          -11145.094,
          -11108.876,
          -11072.161,
          -11034.948,
          -10997.237,
          -10959.027,
          -10920.317,
          -10881.107,
          -10841.395,
          -10801.181,
          -10760.464,
          -10719.243,
          -10677.518,
          -10635.287,
          -10592.55,
          -10549.305,
          -10505.552,
          -10461.289,
          -10416.517,
          -10371.233,
          -10325.437,
          -10279.127,
          -10232.302,
          -10184.963,
          -10137.106,
          -10088.732,
          -10039.84,
          -9990.426,
          -9940.492,
          -9890.035,
          -9839.055,
          -9787.55,
          -9735.518,
          -9682.959,
          -9629.872,
          -9576.254,
          -9522.104,
          -9467.421999999999,
          -9412.205,
          -9356.453000000001,
          -9300.163,
          -9243.336,
          -9185.968,
          -9128.058,
          -9069.605,
          -9010.608,
          -8951.065,
          -8890.974,
          -8830.333,
          -8769.141,
          -8707.396,
          -8645.097,
          -8582.243,
          -8518.83,
          -8454.858,
          -8390.324,
          -8325.226999999999,
          -8259.565999999999,
          -8193.338,
          -8126.541,
          -8059.174,
          -7991.234,
          -7922.721,
          -7853.630999999999,
          -7783.963000000001,
          -7713.715,
          -7642.8859999999995,
          -7571.472,
          -7499.473000000001,
          -7426.885,
          -7353.706999999999,
          -7279.937,
          -7205.5740000000005,
          -7130.613,
          -7055.055,
          -6978.896,
          -6902.134,
          -6824.769,
          -6746.795999999999,
          -6668.214,
          -6589.022,
          -6509.217,
          -6428.795999999999,
          -6347.758000000001,
          -6266.1,
          -6183.821,
          -6100.919,
          -6017.391,
          -5933.235,
          -5848.4490000000005,
          -5763.031999999999,
          -5676.981,
          -5590.294,
          -5502.969,
          -5415.005,
          -5326.399,
          -5237.151,
          -5147.259,
          -5056.719,
          -4965.532,
          -4873.696,
          -4781.209,
          -4688.069,
          -4594.277,
          -4499.831,
          -4404.73,
          -4308.972,
          -4212.559,
          -4115.4890000000005,
          -4017.762,
          -3919.3790000000004,
          -3820.3379999999997,
          -3720.6420000000003,
          -3620.2909999999997,
          -3519.2859999999996,
          -3417.6279999999997,
          -3315.3190000000004,
          -3212.362,
          -3108.759,
          -3004.514,
          -2899.6290000000004,
          -2794.11,
          -2687.961,
          -2581.187,
          -2473.795,
          -2365.792,
          -2257.186,
          -2147.985,
          -2038.201,
          -1927.8429999999998,
          -1816.9229999999998,
          -1705.4560000000001,
          -1593.4579999999999,
          -1480.943,
          -1367.932,
          -1254.443,
          -1140.501,
          -1026.13,
          -911.357,
          -796.212,
          -680.73,
          -564.945,
          -448.9,
          -332.63800000000003,
          -216.208,
          -99.664,
          16.934,
          133.52200000000002,
          250.028,
          366.374,
          482.471,
          598.226,
          713.5319999999999,
          828.2760000000001,
          942.329,
          1055.55,
          1167.79,
          1278.88,
          1388.632,
          1496.8470000000002,
          1603.3020000000001,
          1707.755,
          1809.94,
          1909.5720000000001,
          2006.335,
          2099.894,
          2189.881,
          2275.907,
          2357.555,
          2434.381,
          2505.922,
          2571.695,
          2631.202,
          2683.94,
          2729.405,
          2767.107,
          2796.5759999999996,
          2817.38,
          2829.136,
          2831.5240000000003,
          2824.298,
          2807.302,
          2780.4709999999995,
          2743.842,
          2697.551,
          2641.8309999999997,
          2577.005,
          2503.475,
          2421.7070000000003,
          2332.222,
          2235.573,
          2132.337,
          2023.101,
          1908.445,
          1788.9370000000001,
          1665.126,
          1537.5320000000002,
          1406.6429999999998,
          1272.917,
          1136.774,
          998.6039999999999,
          858.757,
          717.558,
          575.294,
          432.22900000000004,
          288.597,
          144.608,
          0.45,
          -143.711,
          -287.724,
          -431.46,
          -574.8009999999999,
          -717.643,
          -859.8969999999999,
          -1001.4830000000001,
          -1142.33,
          -1282.376,
          -1421.569,
          -1559.862,
          -1697.2160000000001,
          -1833.594,
          -1968.967,
          -2103.31,
          -2236.601,
          -2368.822,
          -2499.9570000000003,
          -2629.9959999999996,
          -2758.929,
          -2886.7459999999996,
          -3013.4440000000004,
          -3139.0170000000003,
          -3263.465,
          -3386.784,
          -3508.9770000000003,
          -3630.0440000000003,
          -3749.986,
          -3868.808,
          -3986.513,
          -4103.106,
          -4218.59,
          -4332.972,
          -4446.258,
          -4558.452,
          -4669.563,
          -4779.597,
          -4888.56,
          -4996.46,
          -5103.305,
          -5209.102,
          -5313.859,
          -5417.581,
          -5520.28,
          -5621.960999999999,
          -5722.630999999999,
          -5822.3009999999995,
          -5920.977,
          -6018.666,
          -6115.3769999999995,
          -6211.116999999999,
          -6305.894,
          -6399.717,
          -6492.590999999999,
          -6584.525,
          -6675.526999999999,
          -6765.603,
          -6854.76,
          -6943.008000000001,
          -7030.352,
          -7116.799,
          -7202.357,
          -7287.031999999999,
          -7370.831999999999,
          -7453.763000000001,
          -7535.831,
          -7617.043000000001,
          -7697.406,
          -7776.9259999999995,
          -7855.609,
          -7933.4619999999995,
          -8010.491,
          -8086.701,
          -8162.1,
          -8236.690999999999,
          -8310.482,
          -8383.478000000001,
          -8455.684000000001,
          -8527.106,
          -8597.75,
          -8667.621,
          -8736.724,
          -8805.064,
          -8872.646,
          -8939.476999999999,
          -9005.559000000001,
          -9070.898000000001,
          -9135.5,
          -9199.369,
          -9262.508,
          -9324.924,
          -9386.62,
          -9447.601,
          -9507.871,
          -9567.435,
          -9626.296999999999,
          -9684.461,
          -9741.931,
          -9798.71,
          -9854.804,
          -9910.216,
          -9964.95,
          -10019.009,
          -10072.398000000001,
          -10125.119,
          -10177.177,
          -10228.576,
          -10279.318000000001,
          -10329.405999999999,
          -10378.845,
          -10427.638,
          -10475.789,
          -10523.298999999999,
          -10570.173,
          -10616.413999999999,
          -10662.024,
          -10707.007,
          -10751.366000000002,
          -10795.103000000001,
          -10838.222,
          -10880.726,
          -10922.616000000002,
          -10963.896,
          -11004.569,
          -11044.636999999999,
          -11084.103000000001,
          -11122.97,
          -11161.239,
          -11198.913999999999,
          -11235.998,
          -11272.492,
          -11308.398000000001,
          -11343.72,
          -11378.458999999999,
          -11412.618,
          -11446.198999999999,
          -11479.204,
          -11511.635,
          -11543.496000000001,
          -11574.786,
          -11605.508999999998,
          -11635.667,
          -11665.261,
          -11694.294,
          -11722.768,
          -11750.684,
          -11778.045,
          -11804.851,
          -11831.106000000002,
          -11856.81,
          -11881.966,
          -11906.575,
          -11930.638,
          -11954.159,
          -11977.138,
          -11999.576000000001,
          -12021.475,
          -12042.838,
          -12063.665,
          -12083.957,
          -12103.716999999999,
          -12122.946000000002,
          -12141.645,
          -12159.815,
          -12177.458999999999,
          -12194.577,
          -12211.171,
          -12227.241000000002,
          -12242.79,
          -12257.818000000001,
          -12272.326000000001,
          -12286.317,
          -12299.79,
          -12312.747,
          -12325.19,
          -12337.118999999999,
          -12348.536,
          -12359.441,
          -12369.835,
          -12379.72,
          -12389.096000000001,
          -12397.966,
          -12406.328000000001,
          -12414.185,
          -12421.537,
          -12428.385,
          -12434.731000000002,
          -12440.573999999999,
          -12445.915,
          -12450.757,
          -12455.098,
          -12458.941,
          -12462.286,
          -12465.132,
          -12467.483,
          -12469.337,
          -12470.696000000002,
          -12471.56,
          -12471.928999999998,
          -12471.805,
          -12471.188,
          -12470.079,
          -12468.479,
          -12466.386999999999,
          -12463.803999999998,
          -12460.731000000002,
          -12457.168,
          -12453.116000000002,
          -12448.576000000001,
          -12443.546,
          -12438.028999999999,
          -12432.024,
          -12425.532,
          -12418.553,
          -12411.087,
          -12403.135,
          -12394.698,
          -12385.775,
          -12376.367,
          -12366.473,
          -12356.094,
          -12345.231000000002,
          -12333.883999999998,
          -12322.052,
          -12309.737,
          -12296.937,
          -12283.653999999999,
          -12269.886999999999,
          -12255.636999999999,
          -12240.903,
          -12225.686000000002,
          -12209.986,
          -12193.802,
          -12177.135,
          -12159.985,
          -12142.351999999999,
          -12124.235,
          -12105.635,
          -12086.552,
          -12066.985,
          -12046.934,
          -12026.4,
          -12005.382,
          -11983.881000000001,
          -11961.895,
          -11939.423999999999,
          -11916.47,
          -11893.031,
          -11869.107,
          -11844.697,
          -11819.802,
          -11794.421999999999,
          -11768.555,
          -11742.202,
          -11715.363000000001,
          -11688.036,
          -11660.222,
          -11631.921,
          -11603.131000000001,
          -11573.853000000001,
          -11544.085,
          -11513.828000000001,
          -11483.082,
          -11451.845,
          -11420.117,
          -11387.898000000001,
          -11355.186000000002,
          -11321.982,
          -11288.286,
          -11254.095,
          -11219.41,
          -11184.231000000002,
          -11148.555,
          -11112.383999999998,
          -11075.716,
          -11038.55,
          -11000.885,
          -10962.722,
          -10924.059,
          -10884.895,
          -10845.23,
          -10805.062,
          -10764.392,
          -10723.218,
          -10681.538999999999,
          -10639.354,
          -10596.663,
          -10553.465,
          -10509.758,
          -10465.542,
          -10420.815,
          -10375.578000000001,
          -10329.827,
          -10283.564,
          -10236.786,
          -10189.492,
          -10141.681999999999,
          -10093.354,
          -10044.507,
          -9995.139000000001,
          -9945.251,
          -9894.84,
          -9843.905999999999,
          -9792.446,
          -9740.46,
          -9687.947,
          -9634.905,
          -9581.333,
          -9527.229,
          -9472.591999999999,
          -9417.421999999999,
          -9361.715,
          -9305.472,
          -9248.689,
          -9191.367,
          -9133.503,
          -9075.096,
          -9016.144,
          -8956.646,
          -8896.6,
          -8836.005,
          -8774.858,
          -8713.16,
          -8650.905999999999,
          -8588.097,
          -8524.729,
          -8460.803,
          -8396.315,
          -8331.264000000001,
          -8265.646999999999,
          -8199.465,
          -8132.714,
          -8065.392,
          -7997.4980000000005,
          -7929.03,
          -7859.986,
          -7790.363,
          -7720.161,
          -7649.376,
          -7578.007,
          -7506.053000000001,
          -7433.5109999999995,
          -7360.379,
          -7286.654,
          -7212.335999999999,
          -7137.420999999999,
          -7061.908,
          -6985.795,
          -6909.079000000001,
          -6831.758000000001,
          -6753.831,
          -6675.295,
          -6596.147,
          -6516.387,
          -6436.0109999999995,
          -6355.019,
          -6273.406999999999,
          -6191.173000000001,
          -6108.316,
          -6024.8330000000005,
          -5940.722,
          -5855.981,
          -5770.609,
          -5684.603,
          -5597.960999999999,
          -5510.681,
          -5422.762,
          -5334.201999999999,
          -5244.9980000000005,
          -5155.15,
          -5064.655,
          -4973.512,
          -4881.721,
          -4789.278,
          -4696.182,
          -4602.434,
          -4508.032,
          -4412.975,
          -4317.2609999999995,
          -4220.891,
          -4123.865,
          -4026.1809999999996,
          -3927.84,
          -3828.843,
          -3729.1890000000003,
          -3628.8790000000004,
          -3527.915,
          -3426.298,
          -3324.031,
          -3221.115,
          -3117.552,
          -3013.345,
          -2908.5,
          -2803.0190000000002,
          -2696.908,
          -2590.1710000000003,
          -2482.8160000000003,
          -2374.848,
          -2266.277,
          -2157.11,
          -2047.3570000000002,
          -1937.031,
          -1826.142,
          -1714.704,
          -1602.733,
          -1490.244,
          -1377.256,
          -1263.7910000000002,
          -1149.869,
          -1035.515,
          -920.757,
          -805.6260000000001,
          -690.153,
          -574.375,
          -458.334,
          -342.07099999999997,
          -225.636,
          -109.083,
          7.53,
          124.137,
          240.669,
          357.04699999999997,
          473.185,
          588.987,
          704.35,
          819.159,
          933.289,
          1046.6,
          1158.941,
          1270.145,
          1380.0279999999998,
          1488.389,
          1595.0079999999998,
          1699.646,
          1802.039,
          1901.9,
          1998.92,
          2092.762,
          2183.064,
          2269.438,
          2351.467,
          2428.7110000000002,
          2500.708,
          2566.978,
          2627.0229999999997,
          2680.341,
          2726.428,
          2764.792,
          2794.962,
          2816.5040000000004,
          2829.0290000000005,
          2832.2129999999997,
          2825.804,
          2809.637,
          2783.6409999999996,
          2747.844,
          2702.375,
          2647.4590000000003,
          2583.411,
          2510.627,
          2429.569,
          2340.751,
          2244.726,
          2142.0679999999998,
          2033.362,
          1919.19,
          1800.12,
          1676.704,
          1549.461,
          1418.884,
          1285.433,
          1149.53,
          1011.567,
          871.8989999999999,
          730.8510000000001,
          588.7130000000001,
          445.75199999999995,
          302.203,
          158.279,
          14.169,
          -129.958,
          -273.952,
          -417.68,
          -561.025,
          -703.8810000000001,
          -846.1569999999999,
          -987.6519999999999,
          -1128.657,
          -1268.747,
          -1407.99,
          -1546.3370000000002,
          -1683.75,
          -1820.191,
          -1955.631,
          -2090.044,
          -2223.408,
          -2355.7039999999997,
          -2486.917,
          -2617.036,
          -2746.05,
          -2873.95,
          -3000.732,
          -3126.3909999999996,
          -3250.925,
          -3374.3320000000003,
          -3496.613,
          -3617.7690000000002,
          -3737.801,
          -3856.7129999999997,
          -3974.508,
          -4091.191,
          -4206.766,
          -4321.2390000000005,
          -4434.616,
          -4546.901,
          -4658.103,
          -4768.228,
          -4877.282,
          -4985.273,
          -5092.209,
          -5198.096,
          -5302.943,
          -5406.755999999999,
          -5509.544,
          -5611.315,
          -5712.075,
          -5811.8330000000005,
          -5910.598000000001,
          -6008.375,
          -6105.175,
          -6201.003000000001,
          -6295.866999999999,
          -6389.776999999999,
          -6482.738,
          -6574.759,
          -6665.846,
          -6756.008000000001,
          -6845.251,
          -6933.584,
          -7021.012,
          -7107.543000000001,
          -7193.186,
          -7277.944,
          -7361.826999999999,
          -7444.84,
          -7526.991,
          -7608.285,
          -7688.73,
          -7768.331,
          -7847.095,
          -7925.029,
          -8002.138000000001,
          -8078.428000000001,
          -8153.906,
          -8228.577,
          -8302.446,
          -8375.521,
          -8447.805,
          -8519.305,
          -8590.026,
          -8659.974,
          -8729.154,
          -8797.571,
          -8865.229,
          -8932.135,
          -8998.293,
          -9063.708,
          -9128.384,
          -9192.328000000001,
          -9255.541,
          -9318.030999999999,
          -9379.801,
          -9440.855,
          -9501.199,
          -9560.835,
          -9619.769,
          -9678.005,
          -9735.546999999999,
          -9792.398000000001,
          -9848.564,
          -9904.046999999999,
          -9958.851,
          -10012.981,
          -10066.44,
          -10119.231,
          -10171.359,
          -10222.827,
          -10273.638,
          -10323.796,
          -10373.303,
          -10422.165,
          -10470.383,
          -10517.962,
          -10564.903999999999,
          -10611.211000000001,
          -10656.889,
          -10701.938999999998,
          -10746.365,
          -10790.168,
          -10833.353000000001,
          -10875.923,
          -10917.878999999999,
          -10959.225,
          -10999.963,
          -11040.096000000001,
          -11079.627,
          -11118.559,
          -11156.893,
          -11194.632,
          -11231.78,
          -11268.338,
          -11304.308,
          -11339.693000000001,
          -11374.495,
          -11408.718,
          -11442.361,
          -11475.428999999998,
          -11507.923,
          -11539.846000000001,
          -11571.198,
          -11601.983,
          -11632.203000000001,
          -11661.858999999999,
          -11690.953000000001,
          -11719.488000000001,
          -11747.466,
          -11774.886999999999,
          -11801.753999999999,
          -11828.069,
          -11853.833999999999,
          -11879.05,
          -11903.719,
          -11927.841999999999,
          -11951.421999999999,
          -11974.461000000001,
          -11996.958,
          -12018.917,
          -12040.338,
          -12061.223999999998,
          -12081.576000000001,
          -12101.393999999998,
          -12120.681,
          -12139.438999999998,
          -12157.667,
          -12175.368999999999,
          -12192.545,
          -12209.196000000002,
          -12225.323999999999,
          -12240.93,
          -12256.015,
          -12270.581,
          -12284.628,
          -12298.158000000001,
          -12311.173,
          -12323.671999999999,
          -12335.658000000001,
          -12347.13,
          -12358.091,
          -12368.542,
          -12378.483,
          -12387.915,
          -12396.84,
          -12405.258,
          -12413.17,
          -12420.577,
          -12427.481000000002,
          -12433.881000000001,
          -12439.778999999999,
          -12445.176000000001,
          -12450.072,
          -12454.468,
          -12458.365,
          -12461.764,
          -12464.665,
          -12467.069,
          -12468.978000000001,
          -12470.391000000001,
          -12471.308,
          -12471.731000000002,
          -12471.661,
          -12471.098,
          -12470.042,
          -12468.493999999999,
          -12466.456,
          -12463.926000000001,
          -12460.906,
          -12457.396,
          -12453.396,
          -12448.908000000001,
          -12443.931999999999,
          -12438.466,
          -12432.514,
          -12426.073999999999,
          -12419.148000000001,
          -12411.733999999999,
          -12403.833999999999,
          -12395.448,
          -12386.577,
          -12377.22,
          -12367.378,
          -12357.051000000001,
          -12346.24,
          -12334.943000000001,
          -12323.163,
          -12310.899,
          -12298.15,
          -12284.918,
          -12271.202,
          -12257.002,
          -12242.32,
          -12227.153,
          -12211.503,
          -12195.37,
          -12178.753,
          -12161.653999999999,
          -12144.071000000002,
          -12126.003999999999,
          -12107.454,
          -12088.421,
          -12068.903999999999,
          -12048.903999999999,
          -12028.42,
          -12007.451000000001,
          -11985.999,
          -11964.063,
          -11941.643,
          -11918.738000000001,
          -11895.347,
          -11871.472,
          -11847.112,
          -11822.266000000001,
          -11796.935,
          -11771.118,
          -11744.813999999998,
          -11718.023000000001,
          -11690.745,
          -11662.98,
          -11634.728000000001,
          -11605.987,
          -11576.757,
          -11547.038,
          -11516.83,
          -11486.132,
          -11454.943000000001,
          -11423.264,
          -11391.093,
          -11358.43,
          -11325.274,
          -11291.626,
          -11257.483,
          -11222.846000000001,
          -11187.715,
          -11152.087,
          -11115.964,
          -11079.343,
          -11042.225,
          -11004.608,
          -10966.492,
          -10927.877,
          -10888.761,
          -10849.143,
          -10809.024,
          -10768.401000000002,
          -10727.274,
          -10685.643,
          -10643.506000000001,
          -10600.862,
          -10557.711000000001,
          -10514.051000000001,
          -10469.883,
          -10425.203000000001,
          -10380.011999999999,
          -10334.309000000001,
          -10288.093,
          -10241.362,
          -10194.116,
          -10146.351999999999,
          -10098.071,
          -10049.271,
          -9999.951,
          -9950.109,
          -9899.746,
          -9848.858,
          -9797.445,
          -9745.506,
          -9693.04,
          -9640.045,
          -9586.519,
          -9532.462,
          -9477.873,
          -9422.748,
          -9367.088,
          -9310.891,
          -9254.155999999999,
          -9196.88,
          -9139.063,
          -9080.702,
          -9021.796999999999,
          -8962.346,
          -8902.347,
          -8841.798,
          -8780.698,
          -8719.046,
          -8656.839,
          -8594.076,
          -8530.756,
          -8466.875,
          -8402.433,
          -8337.429,
          -8271.86,
          -8205.723,
          -8139.018,
          -8071.743,
          -8003.896,
          -7935.474,
          -7866.476,
          -7796.9,
          -7726.745,
          -7656.007,
          -7584.685,
          -7512.776999999999,
          -7440.281,
          -7367.196,
          -7293.517,
          -7219.245,
          -7144.3769999999995,
          -7068.91,
          -6992.843000000001,
          -6916.174,
          -6838.899,
          -6761.018,
          -6682.529,
          -6603.428000000001,
          -6523.714,
          -6443.385,
          -6362.439,
          -6280.8730000000005,
          -6198.686,
          -6115.875,
          -6032.438,
          -5948.374,
          -5863.679,
          -5778.352,
          -5692.392,
          -5605.795999999999,
          -5518.563,
          -5430.69,
          -5342.175,
          -5253.018,
          -5163.215,
          -5072.766,
          -4981.669,
          -4889.923,
          -4797.525,
          -4704.476,
          -4610.773,
          -4516.416,
          -4421.403,
          -4325.734,
          -4229.409000000001,
          -4132.4259999999995,
          -4034.7859999999996,
          -3936.489,
          -3837.535,
          -3737.9240000000004,
          -3637.658,
          -3536.737,
          -3435.163,
          -3332.937,
          -3230.062,
          -3126.54,
          -3022.375,
          -2917.5690000000004,
          -2812.1279999999997,
          -2706.055,
          -2599.356,
          -2492.038,
          -2384.107,
          -2275.571,
          -2166.439,
          -2056.72,
          -1946.425,
          -1835.568,
          -1724.16,
          -1612.2160000000001,
          -1499.754,
          -1386.7920000000001,
          -1273.349,
          -1159.448,
          -1045.113,
          -930.3710000000001,
          -815.252,
          -699.79,
          -584.02,
          -467.981,
          -351.719,
          -235.27900000000002,
          -118.71700000000001,
          -2.09,
          114.538,
          231.09599999999998,
          347.506,
          463.684,
          579.534,
          694.954,
          809.83,
          924.0369999999999,
          1037.437,
          1149.88,
          1261.2,
          1371.214,
          1479.723,
          1586.509,
          1691.3339999999998,
          1793.9360000000001,
          1894.031,
          1991.31,
          2085.44,
          2176.062,
          2262.785,
          2345.201,
          2422.869,
          2495.33,
          2562.1020000000003,
          2622.6929999999998,
          2676.598,
          2723.316,
          2762.3520000000003,
          2793.235,
          2815.525,
          2828.8309999999997,
          2832.823,
          2827.244,
          2811.921,
          2786.775,
          2751.827,
          2707.195,
          2653.099,
          2589.846,
          2517.823,
          2437.49,
          2349.354,
          2253.967,
          2151.9,
          2043.7379999999998,
          1930.0620000000001,
          1811.443,
          1688.43,
          1561.5479999999998,
          1431.2920000000001,
          1298.123,
          1162.4660000000001,
          1024.7169999999999,
          885.2330000000001,
          744.3389999999999,
          602.3330000000001,
          459.47900000000004,
          316.01599999999996,
          172.15900000000002,
          28.099,
          -115.994,
          -259.967,
          -403.686,
          -547.033,
          -689.9019999999999,
          -832.201,
          -973.846,
          -1114.768,
          -1254.902,
          -1394.195,
          -1532.598,
          -1670.07,
          -1806.575,
          -1942.082,
          -2076.5660000000003,
          -2210.004,
          -2342.376,
          -2473.669,
          -2603.868,
          -2732.9640000000004,
          -2860.949,
          -2987.817,
          -3113.563,
          -3238.184,
          -3361.6809999999996,
          -3484.051,
          -3605.296,
          -3725.42,
          -3844.423,
          -3962.31,
          -4079.0840000000003,
          -4194.752,
          -4309.317,
          -4422.786,
          -4535.164000000001,
          -4646.459,
          -4756.6759999999995,
          -4865.822,
          -4973.905,
          -5080.933,
          -5186.912,
          -5291.851,
          -5395.755,
          -5498.635,
          -5600.496,
          -5701.347,
          -5801.196999999999,
          -5900.05,
          -5997.918000000001,
          -6094.807,
          -6190.724,
          -6285.677,
          -6379.675,
          -6472.724,
          -6564.8330000000005,
          -6656.008000000001,
          -6746.257,
          -6835.5869999999995,
          -6924.005999999999,
          -7011.52,
          -7098.137,
          -7183.8640000000005,
          -7268.706999999999,
          -7352.674,
          -7435.772,
          -7518.005999999999,
          -7599.384,
          -7679.911999999999,
          -7759.595,
          -7838.441999999999,
          -7916.4580000000005,
          -7993.648,
          -8070.02,
          -8145.578,
          -8220.329,
          -8294.278,
          -8367.433,
          -8439.796999999999,
          -8511.376,
          -8582.176,
          -8652.202,
          -8721.46,
          -8789.954,
          -8857.690999999999,
          -8924.673,
          -8990.908000000001,
          -9056.399,
          -9121.152,
          -9185.17,
          -9248.46,
          -9311.025,
          -9372.869,
          -9433.998,
          -9494.415,
          -9554.126,
          -9613.134,
          -9671.443000000001,
          -9729.058,
          -9785.982,
          -9842.22,
          -9897.775,
          -9952.651,
          -10006.853000000001,
          -10060.383,
          -10113.245,
          -10165.444,
          -10216.983,
          -10267.864,
          -10318.091999999999,
          -10367.67,
          -10416.601,
          -10464.888,
          -10512.535,
          -10559.546,
          -10605.923,
          -10651.669,
          -10696.786,
          -10741.28,
          -10785.151000000002,
          -10828.403999999999,
          -10871.04,
          -10913.063,
          -10954.476,
          -10995.281,
          -11035.48,
          -11075.077,
          -11114.075,
          -11152.475,
          -11190.28,
          -11227.492,
          -11264.114,
          -11300.149,
          -11335.598999999998,
          -11370.466,
          -11404.752,
          -11438.46,
          -11471.591999999999,
          -11504.15,
          -11536.135,
          -11567.551000000001,
          -11598.399,
          -11628.681999999999,
          -11658.4,
          -11687.556999999999,
          -11716.155,
          -11744.194,
          -11771.677,
          -11798.606000000002,
          -11824.983,
          -11850.809,
          -11876.087,
          -11900.816,
          -11925.001,
          -11948.641000000001,
          -11971.74,
          -11994.298,
          -12016.317,
          -12037.798999999999,
          -12058.743999999999,
          -12079.156,
          -12099.034,
          -12118.381000000001,
          -12137.198,
          -12155.485,
          -12173.246000000001,
          -12190.481000000002,
          -12207.191,
          -12223.378,
          -12239.042,
          -12254.186000000002,
          -12268.81,
          -12282.915,
          -12296.503,
          -12309.575,
          -12322.131000000001,
          -12334.173999999999,
          -12345.705,
          -12356.723,
          -12367.231000000002,
          -12377.228000000001,
          -12386.718,
          -12395.698999999999,
          -12404.173999999999,
          -12412.142,
          -12419.606000000002,
          -12426.566,
          -12433.021999999999,
          -12438.976,
          -12444.428999999998,
          -12449.38,
          -12453.832,
          -12457.785,
          -12461.239,
          -12464.195,
          -12466.655,
          -12468.618,
          -12470.086000000001,
          -12471.058,
          -12471.536,
          -12471.52,
          -12471.011999999999,
          -12470.01,
          -12468.517,
          -12466.532,
          -12464.056999999999,
          -12461.09,
          -12457.633999999998,
          -12453.688999999998,
          -12449.253999999999,
          -12444.331,
          -12438.919,
          -12433.02,
          -12426.633999999998,
          -12419.76,
          -12412.4,
          -12404.553,
          -12396.22,
          -12387.402,
          -12378.098,
          -12368.308,
          -12358.034,
          -12347.275,
          -12336.031,
          -12324.303,
          -12312.091,
          -12299.393999999998,
          -12286.214,
          -12272.55,
          -12258.402,
          -12243.771,
          -12228.656,
          -12213.058,
          -12196.976,
          -12180.411,
          -12163.363000000001,
          -12145.831,
          -12127.816,
          -12109.317,
          -12090.335,
          -12070.868999999999,
          -12050.92,
          -12030.486,
          -12009.569,
          -11988.167,
          -11966.282,
          -11943.912,
          -11921.056999999999,
          -11897.718,
          -11873.893,
          -11849.583,
          -11824.787,
          -11799.506000000001,
          -11773.739,
          -11747.485,
          -11720.745,
          -11693.517,
          -11665.802,
          -11637.598999999998,
          -11608.908000000001,
          -11579.728000000001,
          -11550.058,
          -11519.9,
          -11489.252,
          -11458.113000000001,
          -11426.482,
          -11394.36,
          -11361.747,
          -11328.641000000001,
          -11295.041000000001,
          -11260.948,
          -11226.36,
          -11191.278,
          -11155.7,
          -11119.625,
          -11083.053,
          -11045.983999999999,
          -11008.416000000001,
          -10970.348999999998,
          -10931.783000000001,
          -10892.715,
          -10853.146999999999,
          -10813.075,
          -10772.501,
          -10731.423,
          -10689.841,
          -10647.752,
          -10605.157,
          -10562.053999999998,
          -10518.443000000001,
          -10474.323,
          -10429.692,
          -10384.549,
          -10338.894,
          -10292.726,
          -10246.044,
          -10198.845,
          -10151.13,
          -10102.896999999999,
          -10054.145,
          -10004.873,
          -9955.08,
          -9904.764000000001,
          -9853.924,
          -9802.559000000001,
          -9750.669,
          -9698.25,
          -9645.303,
          -9591.825,
          -9537.815999999999,
          -9483.275,
          -9428.198,
          -9372.586,
          -9316.437,
          -9259.749,
          -9202.521999999999,
          -9144.752,
          -9086.439,
          -9027.582,
          -8968.179,
          -8908.226999999999,
          -8847.726,
          -8786.674,
          -8725.069,
          -8662.91,
          -8600.195,
          -8536.923,
          -8473.09,
          -8408.696,
          -8343.739,
          -8278.216999999999,
          -8212.129,
          -8145.472,
          -8078.244000000001,
          -8010.445,
          -7942.071,
          -7873.12,
          -7803.592,
          -7733.484,
          -7662.794,
          -7591.52,
          -7519.659000000001,
          -7447.2119999999995,
          -7374.174,
          -7300.543000000001,
          -7226.318,
          -7151.4980000000005,
          -7076.079000000001,
          -7000.059,
          -6923.438,
          -6846.210999999999,
          -6768.378000000001,
          -6689.936,
          -6610.883000000001,
          -6531.217,
          -6450.935,
          -6370.036999999999,
          -6288.518,
          -6206.378000000001,
          -6123.615,
          -6040.226,
          -5956.209,
          -5871.562,
          -5786.283,
          -5700.37,
          -5613.821,
          -5526.635,
          -5438.809,
          -5350.342,
          -5261.231,
          -5171.476,
          -5081.0740000000005,
          -4990.023,
          -4898.3240000000005,
          -4805.973,
          -4712.97,
          -4619.313,
          -4525.002,
          -4430.036,
          -4334.413,
          -4238.133,
          -4141.196,
          -4043.6020000000003,
          -3945.35,
          -3846.44,
          -3746.8740000000003,
          -3646.652,
          -3545.775,
          -3444.244,
          -3342.062,
          -3239.2290000000003,
          -3135.75,
          -3031.625,
          -2926.861,
          -2821.46,
          -2715.427,
          -2608.768,
          -2501.488,
          -2393.595,
          -2285.095,
          -2175.998,
          -2066.314,
          -1956.0529999999999,
          -1845.227,
          -1733.85,
          -1621.935,
          -1509.501,
          -1396.5639999999999,
          -1283.145,
          -1169.265,
          -1054.9489999999998,
          -940.2239999999999,
          -825.1189999999999,
          -709.668,
          -593.905,
          -477.871,
          -361.608,
          -245.165,
          -128.593,
          -11.952,
          104.696,
          221.28,
          337.723,
          453.941,
          569.84,
          685.318,
          800.2610000000001,
          914.546,
          1028.037,
          1140.5819999999999,
          1252.02,
          1362.1670000000001,
          1470.826,
          1577.7820000000002,
          1682.797,
          1785.611,
          1885.942,
          1983.485,
          2077.907,
          2168.851,
          2255.9320000000002,
          2338.739,
          2416.8379999999997,
          2489.7670000000003,
          2557.051,
          2618.195,
          2672.698,
          2720.0559999999996,
          2759.775,
          2791.381,
          2814.4320000000002,
          2828.533,
          2833.349,
          2828.615,
          2814.152,
          2789.873,
          2755.79,
          2712.014,
          2658.755,
          2596.313,
          2525.07,
          2445.478,
          2358.042,
          2263.308,
          2161.847,
          2054.242,
          1941.075,
          1822.9170000000001,
          1700.32,
          1573.809,
          1443.8829999999998,
          1311.004,
          1175.601,
          1038.072,
          898.7760000000001,
          758.043,
          616.1709999999999,
          473.42800000000005,
          330.05400000000003,
          186.267,
          42.25899999999999,
          -101.79700000000001,
          -245.748,
          -389.458,
          -532.807,
          -675.689,
          -818.0089999999999,
          -959.685,
          -1100.644,
          -1240.823,
          -1380.1660000000002,
          -1518.624,
          -1656.1570000000002,
          -1792.727,
          -1928.3020000000001,
          -2062.8579999999997,
          -2196.371,
          -2328.821,
          -2460.194,
          -2590.475,
          -2719.655,
          -2847.725,
          -2974.68,
          -3100.514,
          -3225.225,
          -3348.812,
          -3471.2729999999997,
          -3592.6079999999997,
          -3712.824,
          -3831.92,
          -3949.9,
          -4066.768,
          -4182.529,
          -4297.188,
          -4410.751,
          -4523.223,
          -4634.611,
          -4744.923,
          -4854.163,
          -4962.340999999999,
          -5069.462,
          -5175.535,
          -5280.566,
          -5384.564,
          -5487.536,
          -5589.4890000000005,
          -5690.433000000001,
          -5790.374,
          -5889.319,
          -5987.279,
          -6084.258000000001,
          -6180.266,
          -6275.31,
          -6369.397,
          -6462.536999999999,
          -6554.734,
          -6645.9980000000005,
          -6736.335,
          -6825.753000000001,
          -6914.26,
          -7001.861999999999,
          -7088.566,
          -7174.38,
          -7259.309,
          -7343.361999999999,
          -7426.545,
          -7508.8640000000005,
          -7590.326999999999,
          -7670.938,
          -7750.706999999999,
          -7829.637,
          -7907.735,
          -7985.009,
          -8061.463000000001,
          -8137.103,
          -8211.937,
          -8285.966999999999,
          -8359.202,
          -8431.646999999999,
          -8503.306999999999,
          -8574.187,
          -8644.293,
          -8713.63,
          -8782.203000000001,
          -8850.018,
          -8917.079,
          -8983.391,
          -9048.961,
          -9113.79,
          -9177.886,
          -9241.252,
          -9303.894,
          -9365.814,
          -9427.019,
          -9487.511,
          -9547.296999999999,
          -9606.38,
          -9664.764000000001,
          -9722.453000000001,
          -9779.451,
          -9835.763,
          -9891.391,
          -9946.34,
          -10000.615,
          -10054.216999999999,
          -10107.152,
          -10159.423,
          -10211.033000000001,
          -10261.985999999999,
          -10312.285,
          -10361.934000000001,
          -10410.936,
          -10459.294,
          -10507.011999999999,
          -10554.091999999999,
          -10600.538,
          -10646.353000000001,
          -10691.541000000001,
          -10736.103000000001,
          -10780.043,
          -10823.364,
          -10866.069,
          -10908.161,
          -10949.641000000001,
          -10990.513,
          -11030.78,
          -11070.444,
          -11109.508,
          -11147.975,
          -11185.846000000001,
          -11223.125,
          -11259.813999999998,
          -11295.915,
          -11331.431,
          -11366.363000000001,
          -11400.715,
          -11434.488000000001,
          -11467.684,
          -11500.306,
          -11532.357,
          -11563.837,
          -11594.749,
          -11625.095,
          -11654.878,
          -11684.098999999998,
          -11712.758999999998,
          -11740.862,
          -11768.408000000001,
          -11795.4,
          -11821.84,
          -11847.728000000001,
          -11873.068000000001,
          -11897.86,
          -11922.107,
          -11945.809,
          -11968.969,
          -11991.589,
          -12013.67,
          -12035.213,
          -12056.219,
          -12076.691,
          -12096.63,
          -12116.037,
          -12134.913999999999,
          -12153.263,
          -12171.083999999999,
          -12188.378,
          -12205.148000000001,
          -12221.393999999998,
          -12237.118,
          -12252.321000000002,
          -12267.003999999999,
          -12281.169,
          -12294.816,
          -12307.947,
          -12320.562,
          -12332.663999999999,
          -12344.253,
          -12355.329,
          -12365.895,
          -12375.951000000001,
          -12385.498,
          -12394.537,
          -12403.07,
          -12411.096000000001,
          -12418.616000000002,
          -12425.633,
          -12432.146999999999,
          -12438.158000000001,
          -12443.668,
          -12448.676000000001,
          -12453.185,
          -12457.194,
          -12460.704,
          -12463.716999999999,
          -12466.233,
          -12468.252,
          -12469.776000000002,
          -12470.803999999998,
          -12471.338,
          -12471.378,
          -12470.923999999999,
          -12469.978000000001,
          -12468.541000000001,
          -12466.611,
          -12464.191,
          -12461.278999999999,
          -12457.878,
          -12453.988000000001,
          -12449.608,
          -12444.739,
          -12439.382,
          -12433.537,
          -12427.205,
          -12420.386,
          -12413.08,
          -12405.287,
          -12397.008,
          -12388.243,
          -12378.993,
          -12369.258,
          -12359.037,
          -12348.331,
          -12337.141000000001,
          -12325.466,
          -12313.306999999999,
          -12300.663999999999,
          -12287.537,
          -12273.926000000001,
          -12259.832,
          -12245.253,
          -12230.191,
          -12214.645,
          -12198.616000000002,
          -12182.104,
          -12165.108,
          -12147.628,
          -12129.666000000001,
          -12111.219,
          -12092.288999999999,
          -12072.875,
          -12052.978000000001,
          -12032.596000000001,
          -12011.731000000002,
          -11990.381000000001,
          -11968.546999999999,
          -11946.229,
          -11923.426000000001,
          -11900.138,
          -11876.365,
          -11852.106000000002,
          -11827.363000000001,
          -11802.133,
          -11776.416000000001,
          -11750.214,
          -11723.524,
          -11696.348,
          -11668.684,
          -11640.531,
          -11611.891000000001,
          -11582.761999999999,
          -11553.143999999998,
          -11523.036,
          -11492.438,
          -11461.348999999998,
          -11429.77,
          -11397.698999999999,
          -11365.136,
          -11332.08,
          -11298.53,
          -11264.488000000001,
          -11229.95,
          -11194.918,
          -11159.39,
          -11123.365,
          -11086.844,
          -11049.825,
          -11012.306999999999,
          -10974.29,
          -10935.773000000001,
          -10896.756000000001,
          -10857.237,
          -10817.216,
          -10776.691,
          -10735.662,
          -10694.128999999999,
          -10652.09,
          -10609.545,
          -10566.492,
          -10522.93,
          -10478.859,
          -10434.278,
          -10389.185,
          -10343.58,
          -10297.461,
          -10250.827,
          -10203.678,
          -10156.013,
          -10107.829,
          -10059.126,
          -10009.904,
          -9960.16,
          -9909.893,
          -9859.103000000001,
          -9807.787,
          -9755.945,
          -9703.576,
          -9650.678,
          -9597.249,
          -9543.289,
          -9488.796999999999,
          -9433.77,
          -9378.207,
          -9322.106,
          -9265.468,
          -9208.289,
          -9150.568000000001,
          -9092.304,
          -9033.496,
          -8974.142,
          -8914.239,
          -8853.787,
          -8792.784,
          -8731.228000000001,
          -8669.118,
          -8606.452,
          -8543.228000000001,
          -8479.444,
          -8415.099,
          -8350.190999999999,
          -8284.719000000001,
          -8218.679,
          -8152.071,
          -8084.892,
          -8017.141,
          -7948.816,
          -7879.915,
          -7810.435,
          -7740.376,
          -7669.735,
          -7598.51,
          -7526.698,
          -7454.299,
          -7381.31,
          -7307.729,
          -7233.553000000001,
          -7158.781,
          -7083.411999999999,
          -7007.441,
          -6930.868,
          -6853.69,
          -6775.906,
          -6697.513000000001,
          -6618.508000000001,
          -6538.891,
          -6458.659000000001,
          -6377.809,
          -6296.339,
          -6214.2480000000005,
          -6131.533,
          -6048.193,
          -5964.224,
          -5879.626,
          -5794.395,
          -5708.531999999999,
          -5622.031999999999,
          -5534.894,
          -5447.116,
          -5358.698,
          -5269.635,
          -5179.928,
          -5089.5740000000005,
          -4998.572,
          -4906.92,
          -4814.617,
          -4721.662,
          -4628.053,
          -4533.789000000001,
          -4438.869000000001,
          -4343.294,
          -4247.061,
          -4150.17,
          -4052.623,
          -3954.417,
          -3855.554,
          -3756.033,
          -3655.857,
          -3555.025,
          -3453.538,
          -3351.3990000000003,
          -3248.61,
          -3145.1740000000004,
          -3041.093,
          -2936.3709999999996,
          -2831.011,
          -2725.0190000000002,
          -2618.4,
          -2511.159,
          -2403.304,
          -2294.842,
          -2185.782,
          -2076.133,
          -1965.906,
          -1855.114,
          -1743.7679999999998,
          -1631.8829999999998,
          -1519.477,
          -1406.566,
          -1293.172,
          -1179.3139999999999,
          -1065.018,
          -950.31,
          -835.22,
          -719.78,
          -604.025,
          -487.995,
          -371.733,
          -255.285,
          -138.705,
          -22.049,
          94.618,
          211.229,
          327.705,
          443.964,
          559.9119999999999,
          675.448,
          790.459,
          904.823,
          1018.405,
          1131.055,
          1242.611,
          1352.8929999999998,
          1461.7060000000001,
          1568.8329999999999,
          1674.039,
          1777.068,
          1877.639,
          1975.4479999999999,
          2070.167,
          2161.438,
          2248.88,
          2332.084,
          2410.618,
          2484.024,
          2551.826,
          2613.531,
          2668.64,
          2716.647,
          2757.058,
          2789.3990000000003,
          2813.223,
          2828.132,
          2833.784,
          2829.908,
          2816.32,
          2792.9240000000004,
          2759.722,
          2716.8179999999998,
          2664.413,
          2602.799,
          2532.353,
          2453.518,
          2366.797,
          2272.732,
          2171.891,
          2064.857,
          1952.2120000000002,
          1834.527,
          1712.355,
          1586.225,
          1456.6370000000002,
          1324.056,
          1188.914,
          1051.611,
          912.51,
          771.942,
          630.2080000000001,
          487.57800000000003,
          344.29699999999997,
          200.582,
          56.629,
          -87.389,
          -231.31599999999997,
          -375.01599999999996,
          -518.367,
          -661.26,
          -803.6010000000001,
          -945.5930000000001,
          -1086.3039999999999,
          -1226.528,
          -1365.921,
          -1504.4360000000001,
          -1642.03,
          -1778.665,
          -1914.31,
          -2048.939,
          -2182.527,
          -2315.056,
          -2446.51,
          -2576.874,
          -2706.14,
          -2834.297,
          -2961.34,
          -3087.263,
          -3212.065,
          -3335.743,
          -3458.296,
          -3579.7270000000003,
          -3700.0359999999996,
          -3819.2259999999997,
          -3937.301,
          -4054.263,
          -4170.12,
          -4284.874,
          -4398.532,
          -4511.1,
          -4622.584,
          -4732.99,
          -4842.326,
          -4950.599,
          -5057.814,
          -5163.982,
          -5269.108,
          -5373.201,
          -5476.267,
          -5578.314,
          -5679.351,
          -5779.385,
          -5878.424,
          -5976.476,
          -6073.547,
          -6169.647,
          -6264.783,
          -6358.9619999999995,
          -6452.191999999999,
          -6544.48,
          -6635.834,
          -6726.2609999999995,
          -6815.769,
          -6904.3640000000005,
          -6992.055,
          -7078.847,
          -7164.749,
          -7249.766,
          -7333.906,
          -7417.1759999999995,
          -7499.581,
          -7581.129,
          -7661.826,
          -7741.68,
          -7820.695,
          -7898.878000000001,
          -7976.236,
          -8052.773,
          -8128.496999999999,
          -8203.413,
          -8277.527,
          -8350.844000000001,
          -8423.371,
          -8495.112,
          -8566.073,
          -8636.26,
          -8705.677,
          -8774.331,
          -8842.226,
          -8909.366,
          -8975.758,
          -9041.405,
          -9106.314,
          -9170.488000000001,
          -9233.931999999999,
          -9296.651,
          -9358.648000000001,
          -9419.93,
          -9480.499,
          -9540.360999999999,
          -9599.52,
          -9657.98,
          -9715.744,
          -9772.817,
          -9829.204,
          -9884.905999999999,
          -9939.93,
          -9994.279,
          -10047.955,
          -10100.963,
          -10153.306999999999,
          -10204.99,
          -10256.015,
          -10306.386999999999,
          -10356.108,
          -10405.181,
          -10453.610999999999,
          -10501.4,
          -10548.552,
          -10595.069,
          -10640.954,
          -10686.212,
          -10730.845,
          -10774.855,
          -10818.245,
          -10861.018999999998,
          -10903.18,
          -10944.729,
          -10985.67,
          -11026.005,
          -11065.738000000001,
          -11104.87,
          -11143.405,
          -11181.344,
          -11218.69,
          -11255.446000000002,
          -11291.614,
          -11327.196000000002,
          -11362.195,
          -11396.613000000001,
          -11430.452,
          -11463.714,
          -11496.402,
          -11528.518,
          -11560.063999999998,
          -11591.041000000001,
          -11621.453000000001,
          -11651.3,
          -11680.586000000001,
          -11709.311000000002,
          -11737.476999999999,
          -11765.088,
          -11792.143999999998,
          -11818.646999999999,
          -11844.598999999998,
          -11870.002,
          -11894.857,
          -11919.167,
          -11942.933,
          -11966.155,
          -11988.838,
          -12010.981000000002,
          -12032.586000000001,
          -12053.653999999999,
          -12074.188,
          -12094.188999999998,
          -12113.658000000001,
          -12132.596000000001,
          -12151.006000000001,
          -12168.888,
          -12186.243,
          -12203.073999999999,
          -12219.381000000001,
          -12235.166000000001,
          -12250.428999999998,
          -12265.171999999999,
          -12279.396999999999,
          -12293.104,
          -12306.295,
          -12318.97,
          -12331.131000000001,
          -12342.778999999999,
          -12353.916000000001,
          -12364.54,
          -12374.655,
          -12384.261,
          -12393.358999999999,
          -12401.95,
          -12410.035,
          -12417.614,
          -12424.69,
          -12431.261999999999,
          -12437.331,
          -12442.898000000001,
          -12447.964,
          -12452.53,
          -12456.597,
          -12460.165,
          -12463.235,
          -12465.808,
          -12467.885,
          -12469.465,
          -12470.551000000001,
          -12471.141000000001,
          -12471.238000000001,
          -12470.841,
          -12469.951000000001,
          -12468.57,
          -12466.697,
          -12464.333,
          -12461.476999999999,
          -12458.132,
          -12454.296999999999,
          -12449.973,
          -12445.16,
          -12439.858999999999,
          -12434.069,
          -12427.793,
          -12421.028999999999,
          -12413.778,
          -12406.04,
          -12397.816,
          -12389.106000000002,
          -12379.911,
          -12370.23,
          -12360.063999999998,
          -12349.412,
          -12338.277,
          -12326.657,
          -12314.552,
          -12301.963,
          -12288.89,
          -12275.333,
          -12261.293,
          -12246.768,
          -12231.76,
          -12216.268,
          -12200.293,
          -12183.833999999999,
          -12166.891000000001,
          -12149.465,
          -12131.555,
          -12113.162,
          -12094.286,
          -12074.925,
          -12055.08,
          -12034.752,
          -12013.938999999998,
          -11992.642,
          -11970.861,
          -11948.596000000001,
          -11925.845,
          -11902.61,
          -11878.889,
          -11854.683,
          -11829.992,
          -11804.813999999998,
          -11779.15,
          -11753,
          -11726.363000000001,
          -11699.238000000001,
          -11671.626,
          -11643.526000000002,
          -11614.937,
          -11585.86,
          -11556.294,
          -11526.238000000001,
          -11495.691,
          -11464.653999999999,
          -11433.127,
          -11401.107,
          -11368.595,
          -11335.591,
          -11302.093,
          -11268.101999999999,
          -11233.616000000002,
          -11198.635,
          -11163.157,
          -11127.184,
          -11090.714,
          -11053.746000000001,
          -11016.278999999999,
          -10978.313,
          -10939.848,
          -10900.881000000001,
          -10861.413,
          -10821.443000000001,
          -10780.969,
          -10739.991000000002,
          -10698.51,
          -10656.521999999999,
          -10614.027,
          -10571.024,
          -10527.514,
          -10483.494,
          -10438.962,
          -10393.92,
          -10348.365,
          -10302.296999999999,
          -10255.713,
          -10208.615,
          -10161,
          -10112.867,
          -10064.215,
          -10015.042,
          -9965.348,
          -9915.132,
          -9864.392,
          -9813.126,
          -9761.335,
          -9709.016,
          -9656.168,
          -9602.789,
          -9548.88,
          -9494.437,
          -9439.46,
          -9383.948,
          -9327.896999999999,
          -9271.308,
          -9214.18,
          -9156.51,
          -9098.296,
          -9039.538,
          -8980.233,
          -8920.381,
          -8859.979,
          -8799.025,
          -8737.52,
          -8675.46,
          -8612.844000000001,
          -8549.669,
          -8485.936,
          -8421.641,
          -8356.783000000001,
          -8291.360999999999,
          -8225.371,
          -8158.813,
          -8091.684,
          -8023.984,
          -7955.709,
          -7886.857,
          -7817.428000000001,
          -7747.418000000001,
          -7676.826999999999,
          -7605.651999999999,
          -7533.891,
          -7461.5419999999995,
          -7388.602,
          -7315.071,
          -7240.945,
          -7166.224,
          -7090.904,
          -7014.983,
          -6938.46,
          -6861.3330000000005,
          -6783.599,
          -6705.255,
          -6626.3009999999995,
          -6546.734,
          -6466.55,
          -6385.751,
          -6304.331,
          -6222.29,
          -6139.626,
          -6056.334,
          -5972.416,
          -5887.868,
          -5802.686,
          -5716.8730000000005,
          -5630.422,
          -5543.3330000000005,
          -5455.606,
          -5367.236,
          -5278.224,
          -5188.566,
          -5098.2609999999995,
          -5007.308,
          -4915.705,
          -4823.451,
          -4730.544,
          -4636.984,
          -4542.769,
          -4447.898,
          -4352.37,
          -4256.185,
          -4159.342000000001,
          -4061.842,
          -3963.684,
          -3864.868,
          -3765.3940000000002,
          -3665.264,
          -3564.4770000000003,
          -3463.0370000000003,
          -3360.9429999999998,
          -3258.2,
          -3154.8070000000002,
          -3050.77,
          -2946.091,
          -2840.7740000000003,
          -2734.823,
          -2628.244,
          -2521.044,
          -2413.229,
          -2304.806,
          -2195.783,
          -2086.17,
          -1975.9779999999998,
          -1865.219,
          -1753.905,
          -1642.0520000000001,
          -1529.674,
          -1416.7910000000002,
          -1303.421,
          -1189.586,
          -1075.3110000000001,
          -960.62,
          -845.545,
          -730.1160000000001,
          -614.37,
          -498.344,
          -382.082,
          -265.63,
          -149.041,
          -32.372,
          84.316,
          200.952,
          317.462,
          433.76199999999994,
          549.759,
          665.3539999999999,
          780.434,
          894.8789999999999,
          1008.552,
          1121.308,
          1232.985,
          1343.4029999999998,
          1452.369,
          1559.6689999999999,
          1665.0710000000001,
          1768.316,
          1869.13,
          1967.2089999999998,
          2062.2270000000003,
          2153.8289999999997,
          2241.637,
          2325.243,
          2404.217,
          2478.104,
          2546.43,
          2608.7039999999997,
          2664.4240000000004,
          2713.0890000000004,
          2754.202,
          2787.2859999999996,
          2811.8940000000002,
          2827.62,
          2834.1209999999996,
          2831.118,
          2818.4179999999997,
          2795.9190000000003,
          2763.613,
          2721.597,
          2670.0609999999997,
          2609.292,
          2539.657,
          2461.596,
          2375.604,
          2282.222,
          2182.015,
          2075.565,
          1963.454,
          1846.253,
          1724.517,
          1598.7779999999998,
          1469.535,
          1337.26,
          1202.387,
          1065.316,
          926.414,
          786.0160000000001,
          644.425,
          501.913,
          358.727,
          215.088,
          71.191,
          -72.78699999999999,
          -216.68900000000002,
          -360.37699999999995,
          -503.728,
          -646.633,
          -788.9960000000001,
          -930.732,
          -1071.767,
          -1212.0339999999999,
          -1351.479,
          -1490.05,
          -1627.705,
          -1764.4070000000002,
          -1900.122,
          -2034.8239999999998,
          -2168.488,
          -2301.097,
          -2432.632,
          -2563.0820000000003,
          -2692.4320000000002,
          -2820.677,
          -2947.81,
          -3073.824,
          -3198.717,
          -3322.488,
          -3445.136,
          -3566.66,
          -3687.0640000000003,
          -3806.35,
          -3924.52,
          -4041.579,
          -4157.531,
          -4272.3820000000005,
          -4386.137,
          -4498.8009999999995,
          -4610.380999999999,
          -4720.885,
          -4830.317,
          -4938.686,
          -5045.998,
          -5152.262,
          -5257.484,
          -5361.672,
          -5464.834,
          -5566.977,
          -5668.108,
          -5768.236,
          -5867.37,
          -5965.515,
          -6062.681,
          -6158.874,
          -6254.102,
          -6348.374,
          -6441.695,
          -6534.075,
          -6625.521,
          -6716.04,
          -6805.638000000001,
          -6894.3240000000005,
          -6982.104,
          -7068.985,
          -7154.976,
          -7240.081999999999,
          -7324.31,
          -7407.6669999999995,
          -7490.161,
          -7571.797,
          -7652.581999999999,
          -7732.521,
          -7811.621999999999,
          -7889.89,
          -7967.3330000000005,
          -8043.956,
          -8119.765,
          -8194.764000000001,
          -8268.962,
          -8342.362,
          -8414.972,
          -8486.796,
          -8557.84,
          -8628.108,
          -8697.608,
          -8766.341999999999,
          -8834.318000000001,
          -8901.539,
          -8968.011,
          -9033.738000000001,
          -9098.726999999999,
          -9162.979,
          -9226.503,
          -9289.3,
          -9351.377,
          -9412.735999999999,
          -9473.383,
          -9533.323,
          -9592.558,
          -9651.095,
          -9708.936,
          -9766.086,
          -9822.548,
          -9878.326,
          -9933.425,
          -9987.849,
          -10041.6,
          -10094.681999999999,
          -10147.101,
          -10198.858,
          -10249.957,
          -10300.401,
          -10350.195,
          -10399.341999999999,
          -10447.844000000001,
          -10495.706,
          -10542.93,
          -10589.518999999998,
          -10635.476,
          -10680.805,
          -10725.508,
          -10769.59,
          -10813.051000000001,
          -10855.896,
          -10898.126,
          -10939.745,
          -10980.756000000001,
          -11021.161,
          -11060.963,
          -11100.163999999999,
          -11138.768,
          -11176.775,
          -11214.191,
          -11251.015,
          -11287.25,
          -11322.9,
          -11357.966,
          -11392.452,
          -11426.358999999999,
          -11459.688,
          -11492.444,
          -11524.625,
          -11556.238000000001,
          -11587.282,
          -11617.758,
          -11647.671999999999,
          -11677.023000000001,
          -11705.813999999998,
          -11734.046,
          -11761.721000000001,
          -11788.841999999999,
          -11815.41,
          -11841.427,
          -11866.895,
          -11891.813999999998,
          -11916.188,
          -11940.017,
          -11963.305,
          -11986.05,
          -12008.256000000001,
          -12029.925,
          -12051.056999999999,
          -12071.653999999999,
          -12091.716999999999,
          -12111.249,
          -12130.25,
          -12148.722,
          -12166.666000000001,
          -12184.083999999999,
          -12200.976,
          -12217.345,
          -12233.192,
          -12248.516000000001,
          -12263.321000000002,
          -12277.607,
          -12291.375,
          -12304.626,
          -12317.362,
          -12329.583999999999,
          -12341.293,
          -12352.489,
          -12363.175,
          -12373.35,
          -12383.016000000001,
          -12392.173999999999,
          -12400.823999999999,
          -12408.968,
          -12416.608,
          -12423.742,
          -12430.373,
          -12436.502,
          -12442.128,
          -12447.253,
          -12451.878,
          -12456.003,
          -12459.63,
          -12462.758,
          -12465.39,
          -12467.524,
          -12469.163999999999,
          -12470.306999999999,
          -12470.955,
          -12471.11,
          -12470.771,
          -12469.938999999998,
          -12468.614,
          -12466.798999999999,
          -12464.492,
          -12461.694,
          -12458.406,
          -12454.628,
          -12450.36,
          -12445.604,
          -12440.358999999999,
          -12434.627,
          -12428.407,
          -12421.698999999999,
          -12414.503999999999,
          -12406.822,
          -12398.655,
          -12390.001,
          -12380.862,
          -12371.236,
          -12361.126,
          -12350.531,
          -12339.45,
          -12327.886,
          -12315.837,
          -12303.303,
          -12290.285,
          -12276.784,
          -12262.798,
          -12248.328000000001,
          -12233.375,
          -12217.938999999998,
          -12202.017,
          -12185.613000000001,
          -12168.726,
          -12151.354,
          -12133.499,
          -12115.16,
          -12096.338,
          -12077.032,
          -12057.242,
          -12036.966999999999,
          -12016.208999999999,
          -11994.966,
          -11973.239,
          -11951.027,
          -11928.331,
          -11905.149,
          -11881.482,
          -11857.329,
          -11832.692,
          -11807.568000000001,
          -11781.957,
          -11755.86,
          -11729.276000000002,
          -11702.204,
          -11674.646,
          -11646.598999999998,
          -11618.063999999998,
          -11589.038999999999,
          -11559.526000000002,
          -11529.521999999999,
          -11499.03,
          -11468.046,
          -11436.571000000002,
          -11404.604,
          -11372.143999999998,
          -11339.193000000001,
          -11305.748,
          -11271.808,
          -11237.376,
          -11202.447,
          -11167.021999999999,
          -11131.101,
          -11094.683,
          -11057.767,
          -11020.353000000001,
          -10982.44,
          -10944.026000000002,
          -10905.111,
          -10865.695,
          -10825.778,
          -10785.356000000002,
          -10744.43,
          -10703,
          -10661.063999999998,
          -10618.621000000001,
          -10575.67,
          -10532.211000000001,
          -10488.243,
          -10443.764000000001,
          -10398.773000000001,
          -10353.27,
          -10307.253,
          -10260.722,
          -10213.676,
          -10166.112,
          -10118.03,
          -10069.43,
          -10020.308,
          -9970.666,
          -9920.502,
          -9869.813,
          -9818.6,
          -9766.859,
          -9714.591999999999,
          -9661.796,
          -9608.468,
          -9554.61,
          -9500.219000000001,
          -9445.293,
          -9389.832,
          -9333.834,
          -9277.296999999999,
          -9220.219000000001,
          -9162.6,
          -9104.438,
          -9045.73,
          -8986.478000000001,
          -8926.677,
          -8866.326,
          -8805.425,
          -8743.97,
          -8681.962,
          -8619.396999999999,
          -8556.274,
          -8492.591999999999,
          -8428.349,
          -8363.542,
          -8298.171,
          -8232.232,
          -8165.725,
          -8098.648,
          -8030.9980000000005,
          -7962.774,
          -7893.975,
          -7824.597,
          -7754.639,
          -7684.1,
          -7612.976,
          -7541.266,
          -7468.968000000001,
          -7396.079000000001,
          -7322.6,
          -7248.526,
          -7173.855,
          -7098.5869999999995,
          -7022.718000000001,
          -6946.246,
          -6869.17,
          -6791.488,
          -6713.195,
          -6634.2919999999995,
          -6554.776,
          -6474.646,
          -6393.897,
          -6312.528,
          -6230.539000000001,
          -6147.925,
          -6064.685,
          -5980.818,
          -5896.32,
          -5811.191,
          -5725.428000000001,
          -5639.029,
          -5551.991999999999,
          -5464.315,
          -5375.996,
          -5287.034000000001,
          -5197.4259999999995,
          -5107.173,
          -5016.27,
          -4924.718,
          -4832.514,
          -4739.657999999999,
          -4646.147,
          -4551.982,
          -4457.16,
          -4361.683,
          -4265.5470000000005,
          -4168.753,
          -4071.302,
          -3973.1929999999998,
          -3874.425,
          -3774.998,
          -3674.9159999999997,
          -3574.177,
          -3472.784,
          -3370.737,
          -3268.039,
          -3164.692,
          -3060.699,
          -2956.065,
          -2850.792,
          -2744.885,
          -2638.349,
          -2531.189,
          -2423.4139999999998,
          -2315.03,
          -2206.047,
          -2096.471,
          -1986.315,
          -1875.5910000000001,
          -1764.309,
          -1652.4879999999998,
          -1540.14,
          -1427.285,
          -1313.941,
          -1200.13,
          -1085.875,
          -971.203,
          -856.1439999999999,
          -740.727,
          -624.99,
          -508.969,
          -392.707,
          -276.252,
          -159.655,
          -42.972,
          73.737,
          190.399,
          306.943,
          423.284,
          539.332,
          654.986,
          770.1360000000001,
          884.66,
          998.428,
          1111.2910000000002,
          1223.09,
          1333.6470000000002,
          1442.769,
          1550.245,
          1655.8429999999998,
          1759.3110000000001,
          1860.37,
          1958.724,
          2054.045,
          2145.984,
          2234.1620000000003,
          2318.176,
          2397.597,
          2471.974,
          2540.8320000000003,
          2603.6820000000002,
          2660.026,
          2709.3590000000004,
          2751.1859999999997,
          2785.026,
          2810.43,
          2826.991,
          2834.355,
          2832.242,
          2820.448,
          2798.863,
          2767.473,
          2726.363,
          2675.717,
          2615.811,
          2547.006,
          2469.737,
          2384.494,
          2291.812,
          2192.256,
          2086.405,
          1974.8410000000001,
          1858.138,
          1736.851,
          1611.513,
          1482.628,
          1350.6670000000001,
          1216.068,
          1079.236,
          940.541,
          800.318,
          658.8739999999999,
          516.485,
          373.398,
          229.83599999999998,
          85.99799999999999,
          -57.938,
          -201.81400000000002,
          -345.49,
          -488.841,
          -631.756,
          -774.1389999999999,
          -915.905,
          -1056.9769999999999,
          -1197.2910000000002,
          -1336.787,
          -1475.4160000000002,
          -1613.1329999999998,
          -1749.901,
          -1885.6879999999999,
          -2020.464,
          -2154.2070000000003,
          -2286.896,
          -2418.515,
          -2549.05,
          -2678.488,
          -2806.823,
          -2934.046,
          -3060.151,
          -3185.139,
          -3309.0029999999997,
          -3431.7459999999996,
          -3553.367,
          -3673.867,
          -3793.2490000000003,
          -3911.5170000000003,
          -4028.675,
          -4144.725,
          -4259.673,
          -4373.526,
          -4486.289000000001,
          -4597.968,
          -4708.569,
          -4818.1,
          -4926.567,
          -5033.977,
          -5140.338,
          -5245.658,
          -5349.943,
          -5453.201999999999,
          -5555.441999999999,
          -5656.67,
          -5756.895,
          -5856.124,
          -5954.365,
          -6051.626,
          -6147.914000000001,
          -6243.236,
          -6337.601,
          -6431.017,
          -6523.49,
          -6615.028,
          -6705.639,
          -6795.33,
          -6884.107,
          -6971.979,
          -7058.951999999999,
          -7145.033,
          -7230.229,
          -7314.547,
          -7397.994000000001,
          -7480.576999999999,
          -7562.3009999999995,
          -7643.174,
          -7723.201,
          -7802.389,
          -7880.745,
          -7958.274,
          -8034.983,
          -8110.878000000001,
          -8185.963000000001,
          -8260.246,
          -8333.732,
          -8406.426,
          -8478.334,
          -8549.461,
          -8619.813,
          -8689.395,
          -8758.213,
          -8826.271,
          -8893.574,
          -8960.128,
          -9025.937,
          -9091.005,
          -9155.339,
          -9218.943000000001,
          -9281.82,
          -9343.976,
          -9405.415,
          -9466.142,
          -9526.16,
          -9585.474,
          -9644.089,
          -9702.008,
          -9759.234,
          -9815.774,
          -9871.629,
          -9926.805,
          -9981.304,
          -10035.132,
          -10088.291,
          -10140.784,
          -10192.616,
          -10243.79,
          -10294.31,
          -10344.178,
          -10393.399,
          -10441.975,
          -10489.91,
          -10537.207,
          -10583.868999999999,
          -10629.9,
          -10675.301000000001,
          -10720.077,
          -10764.23,
          -10807.764,
          -10850.68,
          -10892.982,
          -10934.671999999999,
          -10975.753999999999,
          -11016.23,
          -11056.101999999999,
          -11095.374,
          -11134.048,
          -11172.125,
          -11209.608999999999,
          -11246.503,
          -11282.808,
          -11318.527,
          -11353.662,
          -11388.216999999999,
          -11422.192,
          -11455.589,
          -11488.412,
          -11520.662,
          -11552.341999999999,
          -11583.453000000001,
          -11613.998,
          -11643.978000000001,
          -11673.396,
          -11702.253,
          -11730.552,
          -11758.294,
          -11785.481000000002,
          -11812.115,
          -11838.197,
          -11863.73,
          -11888.715,
          -11913.155,
          -11937.048999999999,
          -11960.401000000002,
          -11983.211000000001,
          -12005.482,
          -12027.215,
          -12048.411,
          -12069.072,
          -12089.2,
          -12108.796,
          -12127.86,
          -12146.396,
          -12164.403,
          -12181.883999999998,
          -12198.84,
          -12215.271,
          -12231.18,
          -12246.568000000001,
          -12261.435,
          -12275.783000000001,
          -12289.614,
          -12302.927,
          -12315.725,
          -12328.008999999998,
          -12339.778999999999,
          -12351.037,
          -12361.784,
          -12372.02,
          -12381.747,
          -12390.966,
          -12399.677,
          -12407.883,
          -12415.583,
          -12422.778,
          -12429.469,
          -12435.657,
          -12441.344,
          -12446.528999999999,
          -12451.214,
          -12455.399,
          -12459.085,
          -12462.274,
          -12464.964,
          -12467.158000000001,
          -12468.856000000002,
          -12470.058,
          -12470.766000000001,
          -12470.98,
          -12470.7,
          -12469.927,
          -12468.661,
          -12466.903999999999,
          -12464.655,
          -12461.916000000001,
          -12458.686000000002,
          -12454.966,
          -12450.756000000001,
          -12446.058,
          -12440.871000000001,
          -12435.196000000002,
          -12429.034,
          -12422.383,
          -12415.246000000001,
          -12407.622,
          -12399.511999999999,
          -12390.915,
          -12381.832,
          -12372.264,
          -12362.211000000001,
          -12351.671999999999,
          -12340.649,
          -12329.14,
          -12317.148000000001,
          -12304.671,
          -12291.708999999999,
          -12278.264,
          -12264.333999999999,
          -12249.921,
          -12235.024,
          -12219.643,
          -12203.778,
          -12187.43,
          -12170.598,
          -12153.282,
          -12135.483,
          -12117.198999999999,
          -12098.431999999999,
          -12079.181,
          -12059.447,
          -12039.228000000001,
          -12018.524,
          -11997.337,
          -11975.665,
          -11953.508,
          -11930.867,
          -11907.74,
          -11884.127,
          -11860.03,
          -11835.447,
          -11810.377,
          -11784.821000000002,
          -11758.778999999999,
          -11732.249,
          -11705.233,
          -11677.728000000001,
          -11649.735,
          -11621.253999999999,
          -11592.284,
          -11562.825,
          -11532.876,
          -11502.437,
          -11471.506000000001,
          -11440.085,
          -11408.173,
          -11375.768,
          -11342.868999999999,
          -11309.478000000001,
          -11275.593,
          -11241.213,
          -11206.338,
          -11170.966999999999,
          -11135.1,
          -11098.735,
          -11061.873,
          -11024.511999999999,
          -10986.652,
          -10948.291000000001,
          -10909.431,
          -10870.068000000001,
          -10830.203000000001,
          -10789.833999999999,
          -10748.962,
          -10707.585,
          -10665.702,
          -10623.312,
          -10580.413999999999,
          -10537.008999999998,
          -10493.093,
          -10448.667,
          -10403.729,
          -10358.279,
          -10312.315999999999,
          -10265.838,
          -10218.843,
          -10171.332,
          -10123.304,
          -10074.756,
          -10025.688,
          -9976.098,
          -9925.985999999999,
          -9875.351,
          -9824.19,
          -9772.502,
          -9720.287,
          -9667.543,
          -9614.27,
          -9560.464,
          -9506.125,
          -9451.252,
          -9395.843,
          -9339.898000000001,
          -9283.413,
          -9226.388,
          -9168.821,
          -9110.712,
          -9052.058,
          -8992.857,
          -8933.108,
          -8872.811,
          -8811.962,
          -8750.561,
          -8688.605,
          -8626.091999999999,
          -8563.021999999999,
          -8499.392,
          -8435.202,
          -8370.448,
          -8305.128,
          -8239.243,
          -8172.789000000001,
          -8105.764,
          -8038.1669999999995,
          -7969.996,
          -7901.249,
          -7831.924,
          -7762.018,
          -7691.53,
          -7620.459,
          -7548.802,
          -7476.557,
          -7403.722,
          -7330.294,
          -7256.273,
          -7181.655,
          -7106.439,
          -7030.6230000000005,
          -6954.204000000001,
          -6877.18,
          -6799.55,
          -6721.31,
          -6642.46,
          -6562.996999999999,
          -6482.918000000001,
          -6402.222,
          -6320.906,
          -6238.969,
          -6156.406999999999,
          -6073.221,
          -5989.406,
          -5904.960999999999,
          -5819.884,
          -5734.173000000001,
          -5647.826,
          -5560.840999999999,
          -5473.215999999999,
          -5384.95,
          -5296.039000000001,
          -5206.484,
          -5116.282,
          -5025.431,
          -4933.93,
          -4841.778,
          -4748.973,
          -4655.514,
          -4561.399,
          -4466.629,
          -4371.202,
          -4275.117,
          -4178.373,
          -4080.972,
          -3982.9120000000003,
          -3884.1929999999998,
          -3784.817,
          -3684.783,
          -3584.093,
          -3482.7470000000003,
          -3380.7470000000003,
          -3278.097,
          -3174.797,
          -3070.85,
          -2966.261,
          -2861.032,
          -2755.1690000000003,
          -2648.676,
          -2541.5589999999997,
          -2433.826,
          -2325.482,
          -2216.5370000000003,
          -2107,
          -1996.881,
          -1886.192,
          -1774.945,
          -1663.156,
          -1550.839,
          -1438.0120000000002,
          -1324.694,
          -1210.907,
          -1096.674,
          -982.0219999999999,
          -866.9780000000001,
          -751.575,
          -635.846,
          -519.831,
          -403.57,
          -287.112,
          -170.50599999999997,
          -53.808,
          62.92,
          179.61,
          296.187,
          412.57,
          528.668,
          644.382,
          759.6030000000001,
          874.21,
          988.072,
          1101.0430000000001,
          1212.965,
          1323.662,
          1432.942,
          1540.5970000000002,
          1646.394,
          1750.0839999999998,
          1851.3929999999998,
          1950.023,
          2045.651,
          2137.93,
          2226.4829999999997,
          2310.91,
          2390.784,
          2465.655,
          2535.051,
          2598.486,
          2655.4590000000003,
          2705.468,
          2748.0170000000003,
          2782.6240000000003,
          2808.836,
          2826.24,
          2834.4809999999998,
          2833.27,
          2822.3959999999997,
          2801.741,
          2771.281,
          2731.093,
          2681.3509999999997,
          2622.325,
          2554.368,
          2477.906,
          2393.426,
          2301.46,
          2202.5679999999998,
          2097.331,
          1986.3270000000002,
          1870.1329999999998,
          1749.306,
          1624.379,
          1495.859,
          1364.221,
          1229.905,
          1093.319,
          954.834,
          814.7919999999999,
          673.5,
          531.236,
          388.251,
          244.769,
          100.993,
          -42.898999999999994,
          -186.747,
          -330.409,
          -473.75800000000004,
          -616.684,
          -759.0880000000001,
          -900.9789999999999,
          -1041.993,
          -1182.351,
          -1321.899,
          -1460.585,
          -1598.366,
          -1735.201,
          -1871.059,
          -2005.912,
          -2139.7329999999997,
          -2272.504,
          -2404.2070000000003,
          -2534.828,
          -2664.355,
          -2792.78,
          -2920.095,
          -3046.2940000000003,
          -3171.375,
          -3295.336,
          -3418.175,
          -3539.893,
          -3660.491,
          -3779.972,
          -3898.3379999999997,
          -4015.594,
          -4131.7429999999995,
          -4246.792,
          -4360.744000000001,
          -4473.606,
          -4585.385,
          -4696.085,
          -4805.715999999999,
          -4914.282,
          -5021.792,
          -5128.252,
          -5233.67,
          -5338.054,
          -5441.411,
          -5543.749,
          -5645.075,
          -5745.397,
          -5844.723000000001,
          -5943.061,
          -6040.418000000001,
          -6136.802,
          -6232.221,
          -6326.681,
          -6420.191999999999,
          -6512.76,
          -6604.392,
          -6695.097,
          -6784.880999999999,
          -6873.751,
          -6961.715999999999,
          -7048.78,
          -7134.953,
          -7220.241,
          -7304.65,
          -7388.188,
          -7470.86,
          -7552.674,
          -7633.637,
          -7713.753000000001,
          -7793.03,
          -7871.474,
          -7949.090999999999,
          -8025.887,
          -8101.869000000001,
          -8177.041,
          -8251.41,
          -8324.982,
          -8397.761,
          -8469.755,
          -8540.966999999999,
          -8611.403,
          -8681.07,
          -8749.971,
          -8818.112,
          -8885.498,
          -8952.135,
          -9018.026,
          -9083.177,
          -9147.593,
          -9211.278,
          -9274.235999999999,
          -9336.473,
          -9397.992,
          -9458.799,
          -9518.896999999999,
          -9578.291,
          -9636.984,
          -9694.982,
          -9752.287,
          -9808.905,
          -9864.839,
          -9920.091999999999,
          -9974.669,
          -10028.573,
          -10081.809000000001,
          -10134.379,
          -10186.287,
          -10237.537,
          -10288.133,
          -10338.076,
          -10387.372,
          -10436.024,
          -10484.033000000001,
          -10531.405,
          -10578.141000000001,
          -10624.245,
          -10669.721000000001,
          -10714.57,
          -10758.796,
          -10802.403,
          -10845.391000000001,
          -10887.766000000001,
          -10929.528999999999,
          -10970.683,
          -11011.23,
          -11051.173999999999,
          -11090.517,
          -11129.261999999999,
          -11167.41,
          -11204.965,
          -11241.928999999998,
          -11278.305,
          -11314.094,
          -11349.298999999999,
          -11383.921999999999,
          -11417.966999999999,
          -11451.434,
          -11484.325,
          -11516.643999999998,
          -11548.393,
          -11579.573,
          -11610.185,
          -11640.233999999999,
          -11669.72,
          -11698.645,
          -11727.01,
          -11754.82,
          -11782.073999999999,
          -11808.775,
          -11834.923999999999,
          -11860.524,
          -11885.575,
          -11910.081,
          -11934.042,
          -11957.458999999999,
          -11980.335,
          -12002.671999999999,
          -12024.47,
          -12045.732,
          -12066.458,
          -12086.651000000002,
          -12106.311000000002,
          -12125.441,
          -12144.04,
          -12162.112,
          -12179.657,
          -12196.677,
          -12213.173,
          -12229.145,
          -12244.596000000001,
          -12259.527,
          -12273.938999999998,
          -12287.832,
          -12301.208999999999,
          -12314.07,
          -12326.417,
          -12338.249,
          -12349.57,
          -12360.378999999999,
          -12370.677,
          -12380.466999999999,
          -12389.748,
          -12398.521,
          -12406.788,
          -12414.548999999999,
          -12421.806,
          -12428.558,
          -12434.808,
          -12440.556,
          -12445.802,
          -12450.548,
          -12454.794,
          -12458.541000000001,
          -12461.79,
          -12464.541000000001,
          -12466.795,
          -12468.553,
          -12469.816,
          -12470.583999999999,
          -12470.857,
          -12470.636999999999,
          -12469.923999999999,
          -12468.718,
          -12467.02,
          -12464.83,
          -12462.15,
          -12458.98,
          -12455.319,
          -12451.168,
          -12446.528999999999,
          -12441.401000000002,
          -12435.785,
          -12429.681,
          -12423.089,
          -12416.01,
          -12408.444,
          -12400.392,
          -12391.854,
          -12382.829,
          -12373.319,
          -12363.323,
          -12352.843,
          -12341.877,
          -12330.426000000001,
          -12318.491000000002,
          -12306.072,
          -12293.168,
          -12279.78,
          -12265.907,
          -12251.551000000001,
          -12236.711000000001,
          -12221.388,
          -12205.58,
          -12189.288,
          -12172.513,
          -12155.253999999999,
          -12137.511,
          -12119.285,
          -12100.573999999999,
          -12081.378999999999,
          -12061.701000000001,
          -12041.538999999999,
          -12020.891000000001,
          -11999.76,
          -11978.143999999998,
          -11956.043,
          -11933.458,
          -11910.386999999999,
          -11886.831,
          -11862.788999999999,
          -11838.261999999999,
          -11813.248,
          -11787.748,
          -11761.76,
          -11735.287,
          -11708.325,
          -11680.876,
          -11652.938999999998,
          -11624.513,
          -11595.598,
          -11566.194,
          -11536.301000000001,
          -11505.916000000001,
          -11475.041000000001,
          -11443.675,
          -11411.817,
          -11379.466999999999,
          -11346.624,
          -11313.287,
          -11279.457,
          -11245.132,
          -11210.312,
          -11174.995,
          -11139.181999999999,
          -11102.873,
          -11066.065,
          -11028.758999999998,
          -10990.953000000001,
          -10952.646999999999,
          -10913.84,
          -10874.532,
          -10834.722,
          -10794.408000000001,
          -10753.59,
          -10712.267,
          -10670.438999999998,
          -10628.103000000001,
          -10585.258999999998,
          -10541.908000000001,
          -10498.046,
          -10453.674,
          -10408.791,
          -10363.394,
          -10317.485,
          -10271.061,
          -10224.121,
          -10176.664,
          -10128.689,
          -10080.195,
          -10031.181,
          -9981.645,
          -9931.587,
          -9881.005,
          -9829.898000000001,
          -9778.265,
          -9726.103000000001,
          -9673.413,
          -9620.193000000001,
          -9566.440999999999,
          -9512.155999999999,
          -9457.337,
          -9401.982,
          -9346.09,
          -9289.659,
          -9232.688,
          -9175.175,
          -9117.119,
          -9058.519,
          -8999.372,
          -8939.677,
          -8879.433,
          -8818.638,
          -8757.29,
          -8695.388,
          -8632.929,
          -8569.912,
          -8506.336,
          -8442.199,
          -8377.499,
          -8312.234,
          -8246.401,
          -8180.001,
          -8113.03,
          -8045.486999999999,
          -7977.369000000001,
          -7908.6759999999995,
          -7839.405,
          -7769.553000000001,
          -7699.119000000001,
          -7628.102,
          -7556.4980000000005,
          -7484.307,
          -7411.525,
          -7338.151999999999,
          -7264.184,
          -7189.62,
          -7114.456999999999,
          -7038.695,
          -6962.33,
          -6885.36,
          -6807.783,
          -6729.598000000001,
          -6650.8009999999995,
          -6571.391,
          -6491.366,
          -6410.724,
          -6329.4619999999995,
          -6247.578,
          -6165.071,
          -6081.937,
          -5998.1759999999995,
          -5913.785,
          -5828.7609999999995,
          -5743.103,
          -5656.81,
          -5569.878000000001,
          -5482.307,
          -5394.093000000001,
          -5305.236,
          -5215.734,
          -5125.585,
          -5034.787,
          -4943.339,
          -4851.2390000000005,
          -4758.486,
          -4665.079000000001,
          -4571.018,
          -4476.299,
          -4380.923,
          -4284.89,
          -4188.198,
          -4090.848,
          -3992.8379999999997,
          -3894.17,
          -3794.844,
          -3694.86,
          -3594.218,
          -3492.922,
          -3390.972,
          -3288.369,
          -3185.116,
          -3081.217,
          -2976.6740000000004,
          -2871.491,
          -2765.672,
          -2659.223,
          -2552.15,
          -2444.459,
          -2336.157,
          -2227.252,
          -2117.754,
          -2007.6729999999998,
          -1897.02,
          -1785.807,
          -1674.0510000000002,
          -1561.765,
          -1448.967,
          -1335.6770000000001,
          -1221.914,
          -1107.704,
          -993.071,
          -878.044,
          -762.653,
          -646.934,
          -530.924,
          -414.665,
          -298.203,
          -181.58900000000003,
          -64.877,
          51.871,
          168.588,
          285.2,
          401.625,
          517.774,
          633.548,
          748.84,
          863.53,
          977.488,
          1090.568,
          1202.615,
          1313.453,
          1422.8929999999998,
          1530.727,
          1636.726,
          1740.641,
          1842.2020000000002,
          1941.112,
          2037.05,
          2129.672,
          2218.604,
          2303.447,
          2383.779,
          2459.149,
          2529.089,
          2593.113,
          2650.723,
          2701.4159999999997,
          2744.696,
          2780.077,
          2807.1059999999998,
          2825.366,
          2834.494,
          2834.197,
          2824.256,
          2804.5440000000003,
          2775.028,
          2735.777,
          2686.9559999999997,
          2628.8259999999996,
          2561.73,
          2486.091,
          2402.39,
          2311.154,
          2212.9410000000003,
          2108.3289999999997,
          1997.899,
          1882.225,
          1761.8670000000002,
          1637.361,
          1509.215,
          1377.908,
          1243.882,
          1107.548,
          969.2810000000001,
          829.424,
          688.2869999999999,
          546.153,
          403.273,
          259.876,
          116.163,
          -27.683000000000003,
          -171.502,
          -315.14799999999997,
          -458.495,
          -601.431,
          -743.855,
          -885.679,
          -1026.827,
          -1167.23,
          -1306.83,
          -1445.5729999999999,
          -1583.4170000000001,
          -1720.3210000000001,
          -1856.251,
          -1991.1789999999999,
          -2125.08,
          -2257.933,
          -2389.721,
          -2520.429,
          -2650.046,
          -2778.562,
          -2905.97,
          -3032.263,
          -3157.44,
          -3281.4970000000003,
          -3404.434,
          -3526.25,
          -3646.946,
          -3766.527,
          -3884.993,
          -4002.349,
          -4118.598,
          -4233.747,
          -4347.8,
          -4460.763,
          -4572.642,
          -4683.444,
          -4793.175,
          -4901.840999999999,
          -5009.452,
          -5116.012,
          -5221.53,
          -5326.014,
          -5429.47,
          -5531.906999999999,
          -5633.3330000000005,
          -5733.753000000001,
          -5833.178000000001,
          -5931.613,
          -6029.068,
          -6125.549,
          -6221.064,
          -6315.621999999999,
          -6409.228,
          -6501.892,
          -6593.62,
          -6684.419,
          -6774.297,
          -6863.262,
          -6951.32,
          -7038.478,
          -7124.744000000001,
          -7210.124,
          -7294.626,
          -7378.255,
          -7461.018,
          -7542.924,
          -7623.977,
          -7704.183000000001,
          -7783.55,
          -7862.0830000000005,
          -7939.789000000001,
          -8016.674,
          -8092.744000000001,
          -8168.004,
          -8242.46,
          -8316.119,
          -8388.985,
          -8461.064,
          -8532.363000000001,
          -8602.885,
          -8672.636,
          -8741.623,
          -8809.848,
          -8877.318000000001,
          -8944.039,
          -9010.013,
          -9075.247,
          -9139.746,
          -9203.513,
          -9266.553,
          -9328.872,
          -9390.473,
          -9451.360999999999,
          -9511.54,
          -9571.014000000001,
          -9629.788,
          -9687.865,
          -9745.25,
          -9801.947,
          -9857.96,
          -9913.292,
          -9967.947,
          -10021.929,
          -10075.243,
          -10127.89,
          -10179.876,
          -10231.203000000001,
          -10281.875,
          -10331.895,
          -10381.267,
          -10429.995,
          -10478.08,
          -10525.527,
          -10572.338,
          -10618.518,
          -10664.068000000001,
          -10708.991000000002,
          -10753.292,
          -10796.972,
          -10840.035,
          -10882.482,
          -10924.318000000001,
          -10965.545,
          -11006.166000000001,
          -11046.183,
          -11085.598,
          -11124.413999999999,
          -11162.635,
          -11200.261999999999,
          -11237.296999999999,
          -11273.743999999999,
          -11309.604,
          -11344.88,
          -11379.573999999999,
          -11413.688999999998,
          -11447.226,
          -11480.188,
          -11512.577,
          -11544.395,
          -11575.643999999998,
          -11606.326000000001,
          -11636.444,
          -11665.998,
          -11694.991000000002,
          -11723.426000000001,
          -11751.303999999998,
          -11778.626,
          -11805.395,
          -11831.612,
          -11857.28,
          -11882.399,
          -11906.971000000001,
          -11930.999,
          -11954.483999999999,
          -11977.427,
          -11999.83,
          -12021.694,
          -12043.021999999999,
          -12063.815,
          -12084.073999999999,
          -12103.8,
          -12122.995,
          -12141.661,
          -12159.798,
          -12177.408000000001,
          -12194.493,
          -12211.053999999998,
          -12227.091,
          -12242.607,
          -12257.601999999999,
          -12272.078000000001,
          -12286.036,
          -12299.476,
          -12312.402,
          -12324.812,
          -12336.708,
          -12348.091999999999,
          -12358.965,
          -12369.327,
          -12379.178999999998,
          -12388.523000000001,
          -12397.358999999999,
          -12405.688999999998,
          -12413.513,
          -12420.832,
          -12427.646999999999,
          -12433.958999999999,
          -12439.768999999998,
          -12445.078000000001,
          -12449.886,
          -12454.193000000001,
          -12458.002,
          -12461.312,
          -12464.125,
          -12466.441,
          -12468.26,
          -12469.583999999999,
          -12470.412,
          -12470.747,
          -12470.588,
          -12469.935,
          -12468.79,
          -12467.153,
          -12465.024,
          -12462.403999999999,
          -12459.293,
          -12455.693000000001,
          -12451.601999999999,
          -12447.023000000001,
          -12441.955,
          -12436.399,
          -12430.354,
          -12423.822,
          -12416.802,
          -12409.296,
          -12401.303,
          -12392.823999999999,
          -12383.858999999999,
          -12374.407,
          -12364.471000000001,
          -12354.048999999999,
          -12343.142,
          -12331.75,
          -12319.874,
          -12307.513,
          -12294.668,
          -12281.338,
          -12267.524,
          -12253.226,
          -12238.444,
          -12223.178999999998,
          -12207.428999999998,
          -12191.195,
          -12174.478000000001,
          -12157.277,
          -12139.591999999999,
          -12121.423,
          -12102.77,
          -12083.633,
          -12064.011999999999,
          -12043.907,
          -12023.317,
          -12002.243999999999,
          -11980.685,
          -11958.641000000001,
          -11936.112,
          -11913.098999999998,
          -11889.6,
          -11865.615,
          -11841.143999999998,
          -11816.187,
          -11790.743999999999,
          -11764.813999999998,
          -11738.396999999999,
          -11711.492,
          -11684.098999999998,
          -11656.218,
          -11627.848999999998,
          -11598.991000000002,
          -11569.643,
          -11539.805,
          -11509.476999999999,
          -11478.659,
          -11447.348999999998,
          -11415.546999999999,
          -11383.252,
          -11350.466,
          -11317.185,
          -11283.411,
          -11249.141000000001,
          -11214.377,
          -11179.117,
          -11143.36,
          -11107.106000000002,
          -11070.353000000001,
          -11033.103000000001,
          -10995.353000000001,
          -10957.103000000001,
          -10918.351,
          -10879.098999999998,
          -10839.344,
          -10799.085,
          -10758.323,
          -10717.056,
          -10675.282,
          -10633.002,
          -10590.214,
          -10546.917,
          -10503.111,
          -10458.795,
          -10413.966,
          -10368.625,
          -10322.771,
          -10276.402,
          -10229.517,
          -10182.115,
          -10134.195,
          -10085.757,
          -10036.798,
          -9987.317,
          -9937.314,
          -9886.787,
          -9835.735,
          -9784.157,
          -9732.051,
          -9679.415,
          -9626.25,
          -9572.554,
          -9518.324,
          -9463.559000000001,
          -9408.259,
          -9352.421999999999,
          -9296.046,
          -9239.13,
          -9181.671999999999,
          -9123.671,
          -9065.126,
          -9006.034,
          -8946.394,
          -8886.205,
          -8825.465,
          -8764.171999999999,
          -8702.325,
          -8639.921,
          -8576.959,
          -8513.438,
          -8449.356,
          -8384.711,
          -8319.501,
          -8253.723,
          -8187.378000000001,
          -8120.4619999999995,
          -8052.974,
          -7984.911,
          -7916.273,
          -7847.057,
          -7777.26,
          -7706.880999999999,
          -7635.919,
          -7564.371,
          -7492.234,
          -7419.508000000001,
          -7346.189,
          -7272.276999999999,
          -7197.768,
          -7122.66,
          -7046.953,
          -6970.643,
          -6893.728,
          -6816.206,
          -6738.076,
          -6659.334,
          -6579.98,
          -6500.009,
          -6419.422,
          -6338.215,
          -6256.387,
          -6173.934,
          -6090.856,
          -6007.149,
          -5922.813,
          -5837.844,
          -5752.241,
          -5666.0019999999995,
          -5579.125,
          -5491.608,
          -5403.4490000000005,
          -5314.647,
          -5225.1990000000005,
          -5135.104,
          -5044.36,
          -4952.965999999999,
          -4860.920999999999,
          -4768.221,
          -4674.8679999999995,
          -4580.859,
          -4486.194,
          -4390.872,
          -4294.891,
          -4198.252,
          -4100.954000000001,
          -4002.9959999999996,
          -3904.38,
          -3805.105,
          -3705.172,
          -3604.5809999999997,
          -3503.335,
          -3401.435,
          -3298.881,
          -3195.678,
          -3091.8259999999996,
          -2987.33,
          -2882.1940000000004,
          -2776.422,
          -2670.018,
          -2562.989,
          -2455.342,
          -2347.0820000000003,
          -2238.218,
          -2128.76,
          -2018.717,
          -1908.102,
          -1796.925,
          -1685.203,
          -1572.9489999999998,
          -1460.181,
          -1346.918,
          -1233.182,
          -1118.994,
          -1004.3810000000001,
          -889.3710000000001,
          -773.9939999999999,
          -658.285,
          -542.281,
          -426.024,
          -309.559,
          -192.93599999999998,
          -76.21,
          40.559,
          157.30200000000002,
          273.948,
          390.416,
          506.61699999999996,
          622.452,
          737.816,
          852.59,
          966.6439999999999,
          1079.835,
          1192.008,
          1302.988,
          1412.5910000000001,
          1520.606,
          1626.809,
          1730.9520000000002,
          1832.7679999999998,
          1931.96,
          2028.213,
          2121.1820000000002,
          2210.4970000000003,
          2295.762,
          2376.5570000000002,
          2452.433,
          2522.923,
          2587.545,
          2645.8,
          2697.1859999999997,
          2741.205,
          2777.3720000000003,
          2805.2290000000003,
          2824.3579999999997,
          2834.388,
          2835.0190000000002,
          2826.026,
          2807.2740000000003,
          2778.72,
          2740.423,
          2692.54,
          2635.323,
          2569.1079999999997,
          2494.31,
          2411.405,
          2320.9139999999998,
          2223.396,
          2119.425,
          2009.582,
          1894.442,
          1774.565,
          1650.4920000000002,
          1522.73,
          1391.7620000000002,
          1258.0339999999999,
          1121.9589999999998,
          983.915,
          844.2489999999999,
          703.273,
          561.2719999999999,
          418.501,
          275.19,
          131.543,
          -12.255,
          -156.042,
          -299.672,
          -443.01599999999996,
          -585.96,
          -728.403,
          -870.257,
          -1011.442,
          -1151.89,
          -1291.542,
          -1430.344,
          -1568.2520000000002,
          -1705.224,
          -1841.227,
          -1976.2320000000002,
          -2110.214,
          -2243.15,
          -2375.025,
          -2505.821,
          -2635.526,
          -2764.134,
          -2891.636,
          -3018.025,
          -3143.2990000000004,
          -3267.453,
          -3390.489,
          -3512.4040000000005,
          -3633.202,
          -3752.883,
          -3871.45,
          -3988.907,
          -4105.259,
          -4220.51,
          -4334.665,
          -4447.73,
          -4559.712,
          -4670.615,
          -4780.448,
          -4889.217000000001,
          -4996.929,
          -5103.590999999999,
          -5209.210999999999,
          -5313.795,
          -5417.353,
          -5519.89,
          -5621.416,
          -5721.937,
          -5821.460999999999,
          -5919.996,
          -6017.55,
          -6114.129,
          -6209.743,
          -6304.398,
          -6398.102,
          -6490.863,
          -6582.687,
          -6673.5830000000005,
          -6763.558000000001,
          -6852.618,
          -6940.77,
          -7028.024,
          -7114.384,
          -7199.857,
          -7284.451999999999,
          -7368.174,
          -7451.031,
          -7533.028,
          -7614.172,
          -7694.47,
          -7773.928000000001,
          -7852.553000000001,
          -7930.349,
          -8007.323,
          -8083.483,
          -8158.831999999999,
          -8233.377,
          -8307.124,
          -8380.078000000001,
          -8452.244,
          -8523.63,
          -8594.239,
          -8664.077,
          -8733.149,
          -8801.461,
          -8869.017,
          -8935.821,
          -9001.881,
          -9067.199,
          -9131.780999999999,
          -9195.632,
          -9258.756,
          -9321.157,
          -9382.841,
          -9443.811,
          -9504.072,
          -9563.628,
          -9622.483,
          -9680.641,
          -9738.107,
          -9794.885,
          -9850.976999999999,
          -9906.389000000001,
          -9961.124,
          -10015.186,
          -10068.578000000001,
          -10121.304,
          -10173.369,
          -10224.774,
          -10275.523000000001,
          -10325.621,
          -10375.071,
          -10423.876,
          -10472.038,
          -10519.561000000002,
          -10566.448999999999,
          -10612.704,
          -10658.33,
          -10703.329,
          -10747.705,
          -10791.46,
          -10834.597,
          -10877.12,
          -10919.03,
          -10960.331,
          -11001.026000000002,
          -11041.116000000002,
          -11080.605,
          -11119.493999999999,
          -11157.788,
          -11195.487,
          -11232.595,
          -11269.114,
          -11305.046,
          -11340.395,
          -11375.16,
          -11409.346000000001,
          -11442.955,
          -11475.988000000001,
          -11508.448,
          -11540.336000000001,
          -11571.656,
          -11602.408000000001,
          -11632.596000000001,
          -11662.221000000001,
          -11691.285,
          -11719.788999999999,
          -11747.735,
          -11775.127,
          -11801.965,
          -11828.251,
          -11853.987,
          -11879.173999999999,
          -11903.815,
          -11927.911,
          -11951.464,
          -11974.473999999998,
          -11996.946000000002,
          -12018.878,
          -12040.273000000001,
          -12061.132,
          -12081.458,
          -12101.251,
          -12120.513,
          -12139.246000000001,
          -12157.448999999999,
          -12175.126,
          -12192.277,
          -12208.903,
          -12225.007,
          -12240.588,
          -12255.649,
          -12270.19,
          -12284.213,
          -12297.719,
          -12310.708999999999,
          -12323.184,
          -12335.145,
          -12346.594,
          -12357.531,
          -12367.958,
          -12377.874,
          -12387.282,
          -12396.181999999999,
          -12404.576000000001,
          -12412.464,
          -12419.847,
          -12426.725,
          -12433.1,
          -12438.973,
          -12444.345,
          -12449.216,
          -12453.586000000001,
          -12457.458,
          -12460.831,
          -12463.706,
          -12466.083999999999,
          -12467.966,
          -12469.351,
          -12470.243,
          -12470.639,
          -12470.542,
          -12469.951000000001,
          -12468.868,
          -12467.292,
          -12465.223999999998,
          -12462.666000000001,
          -12459.617,
          -12456.077,
          -12452.048,
          -12447.528999999999,
          -12442.521999999999,
          -12437.027,
          -12431.043,
          -12424.571000000002,
          -12417.612,
          -12410.167,
          -12402.233999999999,
          -12393.815,
          -12384.91,
          -12375.518999999998,
          -12365.643,
          -12355.281,
          -12344.434,
          -12333.101999999999,
          -12321.286,
          -12308.983999999999,
          -12296.198,
          -12282.928,
          -12269.173999999999,
          -12254.935,
          -12240.213,
          -12225.006000000001,
          -12209.315,
          -12193.141000000001,
          -12176.483,
          -12159.34,
          -12141.714,
          -12123.604,
          -12105.01,
          -12085.931999999999,
          -12066.368999999999,
          -12046.323,
          -12025.792,
          -12004.776000000002,
          -11983.275,
          -11961.29,
          -11938.82,
          -11915.864,
          -11892.423,
          -11868.496000000001,
          -11844.083999999999,
          -11819.185,
          -11793.798999999999,
          -11767.927,
          -11741.567,
          -11714.72,
          -11687.385,
          -11659.562,
          -11631.25,
          -11602.448999999999,
          -11573.159,
          -11543.378999999999,
          -11513.108999999999,
          -11482.348,
          -11451.095,
          -11419.35,
          -11387.113000000001,
          -11354.383,
          -11321.16,
          -11287.442,
          -11253.23,
          -11218.521999999999,
          -11183.319,
          -11147.618999999999,
          -11111.421999999999,
          -11074.726999999999,
          -11037.533000000001,
          -10999.84,
          -10961.646,
          -10922.952,
          -10883.756000000001,
          -10844.056999999999,
          -10803.856000000002,
          -10763.15,
          -10721.938999999998,
          -10680.222,
          -10637.998,
          -10595.267,
          -10552.027,
          -10508.277,
          -10464.017,
          -10419.245,
          -10373.96,
          -10328.162,
          -10281.85,
          -10235.021,
          -10187.675,
          -10139.812,
          -10091.43,
          -10042.527,
          -9993.103000000001,
          -9943.155999999999,
          -9892.686,
          -9841.69,
          -9790.167,
          -9738.118,
          -9685.539,
          -9632.43,
          -9578.789,
          -9524.615,
          -9469.907,
          -9414.663,
          -9358.882,
          -9302.562,
          -9245.703000000001,
          -9188.301,
          -9130.356,
          -9071.866,
          -9012.831,
          -8953.247,
          -8893.115,
          -8832.431,
          -8771.194,
          -8709.402,
          -8647.055,
          -8584.15,
          -8520.685,
          -8456.659,
          -8392.069,
          -8326.915,
          -8261.195,
          -8194.905,
          -8128.045,
          -8060.613,
          -7992.607,
          -7924.025,
          -7854.8640000000005,
          -7785.124,
          -7714.802,
          -7643.896,
          -7572.404,
          -7500.3240000000005,
          -7427.654,
          -7354.391,
          -7280.535,
          -7206.0830000000005,
          -7131.031,
          -7055.38,
          -6979.126,
          -6902.268,
          -6824.802,
          -6746.728,
          -6668.043000000001,
          -6588.745,
          -6508.831,
          -6428.3,
          -6347.149,
          -6265.376,
          -6182.98,
          -6099.9580000000005,
          -6016.307,
          -5932.026999999999,
          -5847.1140000000005,
          -5761.566999999999,
          -5675.384,
          -5588.563,
          -5501.102,
          -5412.9980000000005,
          -5324.2519999999995,
          -5234.859,
          -5144.82,
          -5054.1320000000005,
          -4962.793,
          -4870.802,
          -4778.157999999999,
          -4684.86,
          -4590.906,
          -4496.295,
          -4401.027,
          -4305.1,
          -4208.514,
          -4111.27,
          -4013.366,
          -3914.802,
          -3815.579,
          -3715.699,
          -3615.16,
          -3513.966,
          -3412.116,
          -3309.612,
          -3206.458,
          -3102.656,
          -2998.2090000000003,
          -2893.12,
          -2787.395,
          -2681.038,
          -2574.054,
          -2466.45,
          -2358.234,
          -2249.413,
          -2139.996,
          -2029.993,
          -1919.415,
          -1808.275,
          -1696.5870000000002,
          -1584.3670000000002,
          -1471.63,
          -1358.395,
          -1244.685,
          -1130.521,
          -1015.929,
          -900.936,
          -785.573,
          -669.8739999999999,
          -553.877,
          -437.621,
          -321.154,
          -204.52200000000002,
          -87.78299999999999,
          29.006,
          145.776,
          262.457,
          378.968,
          495.22,
          611.117,
          726.553,
          841.4110000000001,
          955.563,
          1068.865,
          1181.165,
          1292.29,
          1402.056,
          1510.255,
          1616.664,
          1721.0379999999998,
          1823.109,
          1922.588,
          2019.158,
          2112.4770000000003,
          2202.18,
          2287.871,
          2369.132,
          2445.519,
          2516.5660000000003,
          2581.791,
          2640.697,
          2692.784,
          2737.551,
          2774.513,
          2803.21,
          2823.216,
          2834.16,
          2835.732,
          2827.7009999999996,
          2809.923,
          2782.3459999999995,
          2745.02,
          2698.092,
          2641.804,
          2576.486,
          2502.545,
          2420.451,
          2330.724,
          2233.9139999999998,
          2130.598,
          2021.355,
          1906.761,
          1787.378,
          1663.746,
          1536.378,
          1405.759,
          1272.337,
          1136.528,
          998.7130000000001,
          859.243,
          718.433,
          576.569,
          433.91,
          290.688,
          147.11,
          3.361,
          -140.393,
          -284.005,
          -427.344,
          -570.2959999999999,
          -712.758,
          -854.6410000000001,
          -995.862,
          -1136.356,
          -1276.0610000000001,
          -1414.922,
          -1552.8929999999998,
          -1689.934,
          -1826.0120000000002,
          -1961.094,
          -2095.157,
          -2228.178,
          -2360.139,
          -2491.026,
          -2620.825,
          -2749.527,
          -2877.1240000000003,
          -3003.61,
          -3128.982,
          -3253.235,
          -3376.37,
          -3498.386,
          -3619.285,
          -3739.0679999999998,
          -3857.738,
          -3975.298,
          -4091.7529999999997,
          -4207.107,
          -4321.366,
          -4434.534000000001,
          -4546.619000000001,
          -4657.626,
          -4767.562,
          -4876.435,
          -4984.25,
          -5091.015,
          -5196.737,
          -5301.424,
          -5405.084,
          -5507.723000000001,
          -5609.35,
          -5709.972,
          -5809.597,
          -5908.233,
          -6005.887,
          -6102.566,
          -6198.279,
          -6293.033,
          -6386.835999999999,
          -6479.695,
          -6571.616999999999,
          -6662.61,
          -6752.682,
          -6841.839,
          -6930.088000000001,
          -7017.437,
          -7103.892,
          -7189.460999999999,
          -7274.15,
          -7357.967,
          -7440.916,
          -7523.007,
          -7604.244000000001,
          -7684.635,
          -7764.185,
          -7842.901,
          -7920.7880000000005,
          -7997.854,
          -8074.104,
          -8149.543000000001,
          -8224.177,
          -8298.014000000001,
          -8371.056999999999,
          -8443.312,
          -8514.786,
          -8585.483,
          -8655.409,
          -8724.568000000001,
          -8792.966,
          -8860.608,
          -8927.499,
          -8993.644,
          -9059.048,
          -9123.715,
          -9187.65,
          -9250.859,
          -9313.344000000001,
          -9375.110999999999,
          -9436.164,
          -9496.509,
          -9556.146999999999,
          -9615.085,
          -9673.325,
          -9730.873,
          -9787.732,
          -9843.905999999999,
          -9899.398000000001,
          -9954.214,
          -10008.356,
          -10061.828000000001,
          -10114.634,
          -10166.777,
          -10218.261999999999,
          -10269.09,
          -10319.267,
          -10368.795,
          -10417.677,
          -10465.918,
          -10513.518,
          -10560.483,
          -10606.816,
          -10652.518,
          -10697.594,
          -10742.046,
          -10785.877,
          -10829.09,
          -10871.688,
          -10913.673999999999,
          -10955.05,
          -10995.819,
          -11035.983999999999,
          -11075.546999999999,
          -11114.511,
          -11152.878,
          -11190.652,
          -11227.833,
          -11264.425,
          -11300.431,
          -11335.851999999999,
          -11370.69,
          -11404.948999999999,
          -11438.628999999999,
          -11471.735,
          -11504.266000000001,
          -11536.226,
          -11567.617,
          -11598.441,
          -11628.7,
          -11658.396,
          -11687.53,
          -11716.105,
          -11744.122,
          -11771.583,
          -11798.492,
          -11824.847,
          -11850.653,
          -11875.91,
          -11900.62,
          -11924.785,
          -11948.407,
          -11971.486,
          -11994.026000000002,
          -12016.027,
          -12037.49,
          -12058.418,
          -12078.811000000002,
          -12098.671999999999,
          -12118.002,
          -12136.802,
          -12155.073,
          -12172.817,
          -12190.035,
          -12206.728000000001,
          -12222.898000000001,
          -12238.546999999999,
          -12253.673999999999,
          -12268.281,
          -12282.371000000001,
          -12295.943000000001,
          -12308.999,
          -12321.538999999999,
          -12333.566,
          -12345.081,
          -12356.083,
          -12366.575,
          -12376.556999999999,
          -12386.03,
          -12394.995,
          -12403.453000000001,
          -12411.406,
          -12418.853000000001,
          -12425.796,
          -12432.235,
          -12438.173,
          -12443.608999999999,
          -12448.543,
          -12452.978000000001,
          -12456.913,
          -12460.348999999998,
          -12463.288,
          -12465.73,
          -12467.675,
          -12469.124,
          -12470.078000000001,
          -12470.537,
          -12470.503,
          -12469.975,
          -12468.954,
          -12467.441,
          -12465.436000000002,
          -12462.938999999998,
          -12459.953000000001,
          -12456.476,
          -12452.508,
          -12448.052,
          -12443.106000000002,
          -12437.673,
          -12431.751,
          -12425.341,
          -12418.443000000001,
          -12411.059,
          -12403.188,
          -12394.83,
          -12385.986,
          -12376.656,
          -12366.841,
          -12356.54,
          -12345.753999999999,
          -12334.483,
          -12322.726999999999,
          -12310.486,
          -12297.761,
          -12284.551000000001,
          -12270.857,
          -12256.678999999998,
          -12242.016000000001,
          -12226.87,
          -12211.239,
          -12195.125,
          -12178.527,
          -12161.445,
          -12143.878,
          -12125.828000000001,
          -12107.293,
          -12088.274,
          -12068.771999999999,
          -12048.785,
          -12028.313,
          -12007.356000000002,
          -11985.915,
          -11963.989,
          -11941.578000000001,
          -11918.681999999999,
          -11895.3,
          -11871.431999999999,
          -11847.078000000001,
          -11822.238000000001,
          -11796.912,
          -11771.098,
          -11744.796999999999,
          -11718.008999999998,
          -11690.732,
          -11662.968,
          -11634.715,
          -11605.972,
          -11576.74,
          -11547.018,
          -11516.806,
          -11486.103000000001,
          -11454.909,
          -11423.222,
          -11391.043,
          -11358.372,
          -11325.207,
          -11291.546999999999,
          -11257.393,
          -11222.743,
          -11187.598,
          -11151.956,
          -11115.817,
          -11079.18,
          -11042.044,
          -11004.408000000001,
          -10966.271999999999,
          -10927.636,
          -10888.498,
          -10848.857,
          -10808.712,
          -10768.063999999998,
          -10726.91,
          -10685.251,
          -10643.085,
          -10600.411,
          -10557.228000000001,
          -10513.536,
          -10469.333,
          -10424.619,
          -10379.392,
          -10333.651,
          -10287.396,
          -10240.625,
          -10193.337,
          -10145.530999999999,
          -10097.205,
          -10048.36,
          -9998.993,
          -9949.104,
          -9898.69,
          -9847.751,
          -9796.286,
          -9744.294,
          -9691.771999999999,
          -9638.721,
          -9585.136999999999,
          -9531.021,
          -9476.37,
          -9421.183,
          -9365.459,
          -9309.197,
          -9252.394,
          -9195.049,
          -9137.162,
          -9078.73,
          -9019.751,
          -8960.224,
          -8900.148000000001,
          -8839.521999999999,
          -8778.341999999999,
          -8716.608,
          -8654.318000000001,
          -8591.47,
          -8528.062,
          -8464.093,
          -8399.562,
          -8334.464,
          -8268.801,
          -8202.569,
          -8135.767,
          -8068.392,
          -8000.441999999999,
          -7931.918000000001,
          -7862.815,
          -7793.132,
          -7722.866999999999,
          -7652.018,
          -7580.5830000000005,
          -7508.56,
          -7435.948,
          -7362.743,
          -7288.943,
          -7214.548000000001,
          -7139.555,
          -7063.960999999999,
          -6987.764,
          -6910.9619999999995,
          -6833.555,
          -6755.5380000000005,
          -6676.91,
          -6597.669,
          -6517.812,
          -6437.338000000001,
          -6356.245,
          -6274.529,
          -6192.19,
          -6109.225,
          -6025.632,
          -5941.408,
          -5856.552,
          -5771.063,
          -5684.937,
          -5598.173000000001,
          -5510.768,
          -5422.722,
          -5334.031,
          -5244.696,
          -5154.713,
          -5064.08,
          -4972.798,
          -4880.863,
          -4788.275,
          -4695.032,
          -4601.134,
          -4506.579000000001,
          -4411.365,
          -4315.4929999999995,
          -4218.963,
          -4121.773,
          -4023.923,
          -3925.413,
          -3826.244,
          -3726.417,
          -3625.9309999999996,
          -3524.788,
          -3422.989,
          -3320.538,
          -3217.434,
          -3113.6820000000002,
          -3009.284,
          -2904.245,
          -2798.567,
          -2692.257,
          -2585.32,
          -2477.761,
          -2369.589,
          -2260.81,
          -2151.4339999999997,
          -2041.471,
          -1930.932,
          -1819.83,
          -1708.1770000000001,
          -1595.99,
          -1483.2839999999999,
          -1370.079,
          -1256.395,
          -1142.255,
          -1027.684,
          -912.71,
          -797.3610000000001,
          -681.673,
          -565.682,
          -449.42900000000003,
          -332.959,
          -216.31900000000002,
          -99.566,
          17.243,
          134.04,
          250.75599999999997,
          367.309,
          483.61400000000003,
          599.573,
          715.082,
          830.025,
          944.275,
          1057.69,
          1170.118,
          1281.389,
          1391.317,
          1499.701,
          1606.318,
          1710.9229999999998,
          1813.253,
          1913.019,
          2009.908,
          2103.581,
          2193.673,
          2279.7929999999997,
          2361.5229999999997,
          2438.425,
          2510.032,
          2575.864,
          2635.427,
          2688.219,
          2733.74,
          2771.5040000000004,
          2801.046,
          2821.9390000000003,
          2833.804,
          2836.327,
          2829.2690000000002,
          2812.475,
          2785.887,
          2749.5429999999997,
          2703.583,
          2648.237,
          2583.83,
          2510.76,
          2429.491,
          2340.538,
          2244.451,
          2141.802,
          2033.171,
          1919.1329999999998,
          1800.253,
          1677.0720000000001,
          1550.1070000000002,
          1419.844,
          1286.734,
          1151.197,
          1013.617,
          874.3480000000001,
          733.707,
          591.985,
          449.44199999999995,
          306.311,
          162.804,
          19.107,
          -124.61200000000001,
          -268.204,
          -411.538,
          -554.497,
          -696.977,
          -838.887,
          -980.1469999999999,
          -1120.685,
          -1260.442,
          -1399.362,
          -1537.398,
          -1674.5079999999998,
          -1810.66,
          -1945.82,
          -2079.964,
          -2213.07,
          -2345.119,
          -2476.096,
          -2605.987,
          -2734.783,
          -2862.4759999999997,
          -2989.06,
          -3114.53,
          -3238.883,
          -3362.119,
          -3484.238,
          -3605.238,
          -3725.1240000000003,
          -3843.897,
          -3961.5609999999997,
          -4078.119,
          -4193.577,
          -4307.941,
          -4421.214,
          -4533.403,
          -4644.514,
          -4754.555,
          -4863.531,
          -4971.45,
          -5078.318,
          -5184.145,
          -5288.935,
          -5392.696999999999,
          -5495.44,
          -5597.169,
          -5697.893,
          -5797.62,
          -5896.357,
          -5994.111999999999,
          -6090.893,
          -6186.706,
          -6281.56,
          -6375.4619999999995,
          -6468.42,
          -6560.441,
          -6651.531999999999,
          -6741.701999999999,
          -6830.956,
          -6919.302,
          -7006.7480000000005,
          -7093.3,
          -7178.965,
          -7263.749,
          -7347.66,
          -7430.705,
          -7512.89,
          -7594.221,
          -7674.705,
          -7754.347,
          -7833.156,
          -7911.1359999999995,
          -7988.293000000001,
          -8064.634,
          -8140.164000000001,
          -8214.89,
          -8288.815999999999,
          -8361.949,
          -8434.294,
          -8505.856,
          -8576.642,
          -8646.655999999999,
          -8715.903,
          -8784.389000000001,
          -8852.118,
          -8919.096,
          -8985.328000000001,
          -9050.818000000001,
          -9115.571,
          -9179.591999999999,
          -9242.885,
          -9305.455,
          -9367.306999999999,
          -9428.445,
          -9488.872,
          -9548.594000000001,
          -9607.615,
          -9665.938,
          -9723.569,
          -9780.509,
          -9836.765,
          -9892.34,
          -9947.237,
          -10001.459,
          -10055.013,
          -10107.899,
          -10160.123,
          -10211.688,
          -10262.596,
          -10312.851999999999,
          -10362.459,
          -10411.42,
          -10459.738000000001,
          -10507.418,
          -10554.461000000001,
          -10600.871000000001,
          -10646.651000000002,
          -10691.803999999998,
          -10736.333,
          -10780.242,
          -10823.531,
          -10866.206,
          -10908.267,
          -10949.719,
          -10990.563999999998,
          -11030.803999999998,
          -11070.442,
          -11109.481000000002,
          -11147.923999999999,
          -11185.771,
          -11223.027,
          -11259.693000000001,
          -11295.773000000001,
          -11331.268,
          -11366.18,
          -11400.511,
          -11434.265,
          -11467.443000000001,
          -11500.048,
          -11532.08,
          -11563.543,
          -11594.44,
          -11624.77,
          -11654.537,
          -11683.743,
          -11712.389,
          -11740.478000000001,
          -11768.01,
          -11794.989,
          -11821.415,
          -11847.291000000001,
          -11872.618999999999,
          -11897.4,
          -11921.635,
          -11945.326000000001,
          -11968.475,
          -11991.083999999999,
          -12013.153999999999,
          -12034.687,
          -12055.683,
          -12076.146,
          -12096.076000000001,
          -12115.473999999998,
          -12134.341999999999,
          -12152.681,
          -12170.493,
          -12187.778999999999,
          -12204.54,
          -12220.778,
          -12236.493999999999,
          -12251.688,
          -12266.363000000001,
          -12280.52,
          -12294.159,
          -12307.281,
          -12319.889,
          -12331.982,
          -12343.563,
          -12354.632,
          -12365.188999999998,
          -12375.237,
          -12384.776000000002,
          -12393.806999999999,
          -12402.331,
          -12410.348999999998,
          -12417.862,
          -12424.871000000001,
          -12431.375,
          -12437.378,
          -12442.878,
          -12447.878,
          -12452.377,
          -12456.377,
          -12459.878,
          -12462.881000000001,
          -12465.386999999999,
          -12467.396,
          -12468.909,
          -12469.927,
          -12470.451000000001,
          -12470.48,
          -12470.016000000001,
          -12469.059,
          -12467.608999999999,
          -12465.667,
          -12463.233999999999,
          -12460.31,
          -12456.896,
          -12452.992,
          -12448.598,
          -12443.716,
          -12438.345,
          -12432.486,
          -12426.138,
          -12419.303,
          -12411.981000000002,
          -12404.171999999999,
          -12395.877,
          -12387.096000000001,
          -12377.828000000001,
          -12368.073999999999,
          -12357.835,
          -12347.111,
          -12335.901000000002,
          -12324.207,
          -12312.028,
          -12299.364,
          -12286.215,
          -12272.583,
          -12258.466,
          -12243.865,
          -12228.778999999999,
          -12213.21,
          -12197.156,
          -12180.618999999999,
          -12163.598,
          -12146.091999999999,
          -12128.103000000001,
          -12109.628999999999,
          -12090.67,
          -12071.228000000001,
          -12051.301000000001,
          -12030.89,
          -12009.993999999999,
          -11988.613000000001,
          -11966.747,
          -11944.396999999999,
          -11921.56,
          -11898.238000000001,
          -11874.43,
          -11850.136,
          -11825.356000000002,
          -11800.09,
          -11774.336000000001,
          -11748.095,
          -11721.366000000002,
          -11694.15,
          -11666.445,
          -11638.251,
          -11609.568000000001,
          -11580.396,
          -11550.733,
          -11520.581,
          -11489.937,
          -11458.802,
          -11427.175,
          -11395.055,
          -11362.442,
          -11329.336000000001,
          -11295.736,
          -11261.641000000001,
          -11227.05,
          -11191.964,
          -11156.381000000001,
          -11120.301000000001,
          -11083.723,
          -11046.645,
          -11009.069,
          -10970.991000000002,
          -10932.413999999999,
          -10893.333999999999,
          -10853.752,
          -10813.667,
          -10773.077,
          -10731.982,
          -10690.382,
          -10648.274,
          -10605.658000000001,
          -10562.534,
          -10518.901000000002,
          -10474.757,
          -10430.101,
          -10384.933,
          -10339.25,
          -10293.053,
          -10246.341,
          -10199.110999999999,
          -10151.364,
          -10103.097,
          -10054.309000000001,
          -10005.001,
          -9955.17,
          -9904.815,
          -9853.935,
          -9802.528,
          -9750.594000000001,
          -9698.131,
          -9645.138,
          -9591.613000000001,
          -9537.554,
          -9482.962,
          -9427.833,
          -9372.168,
          -9315.964,
          -9259.219000000001,
          -9201.933,
          -9144.104,
          -9085.73,
          -9026.81,
          -8967.341999999999,
          -8907.324,
          -8846.756,
          -8785.635,
          -8723.959,
          -8661.726999999999,
          -8598.938,
          -8535.588,
          -8471.678,
          -8407.205,
          -8342.166,
          -8276.561,
          -8210.386999999999,
          -8143.643,
          -8076.326999999999,
          -8008.436,
          -7939.97,
          -7870.9259999999995,
          -7801.3009999999995,
          -7731.095,
          -7660.305,
          -7588.928000000001,
          -7516.964,
          -7444.41,
          -7371.264,
          -7297.523,
          -7223.186,
          -7148.251,
          -7072.715999999999,
          -6996.578,
          -6919.835,
          -6842.486,
          -6764.528,
          -6685.9580000000005,
          -6606.776,
          -6526.978,
          -6446.562,
          -6365.526999999999,
          -6283.87,
          -6201.589,
          -6118.683000000001,
          -6035.148,
          -5950.983,
          -5866.185,
          -5780.754,
          -5694.686,
          -5607.98,
          -5520.634,
          -5432.646,
          -5344.013000000001,
          -5254.735,
          -5164.81,
          -5074.235,
          -4983.01,
          -4891.133,
          -4798.602,
          -4705.416,
          -4611.575,
          -4517.076,
          -4421.919,
          -4326.104,
          -4229.629,
          -4132.495,
          -4034.7,
          -3936.2459999999996,
          -3837.131,
          -3737.3579999999997,
          -3636.926,
          -3535.837,
          -3434.091,
          -3331.692,
          -3228.64,
          -3124.9390000000003,
          -3020.592,
          -2915.6020000000003,
          -2809.974,
          -2703.712,
          -2596.822,
          -2489.3089999999997,
          -2381.1820000000002,
          -2272.447,
          -2163.114,
          -2053.192,
          -1942.693,
          -1831.629,
          -1720.013,
          -1607.859,
          -1495.1860000000001,
          -1382.011,
          -1268.355,
          -1154.239,
          -1039.69,
          -924.7339999999999,
          -809.4010000000001,
          -693.7239999999999,
          -577.74,
          -461.49,
          -345.017,
          -228.37,
          -111.603,
          5.224,
          122.04799999999999,
          238.798,
          355.395,
          471.75199999999995,
          587.774,
          703.357,
          818.385,
          932.7330000000001,
          1046.262,
          1158.818,
          1270.236,
          1380.33,
          1488.9,
          1595.726,
          1700.565,
          1803.1570000000002,
          1903.213,
          2000.424,
          2094.453,
          2184.938,
          2271.491,
          2353.697,
          2431.118,
          2503.29,
          2569.737,
          2629.9629999999997,
          2683.468,
          2729.752,
          2768.327,
          2798.725,
          2820.515,
          2833.315,
          2836.802,
          2830.73,
          2814.937,
          2789.353,
          2754.009,
          2709.032,
          2654.6479999999997,
          2591.1679999999997,
          2518.986,
          2438.5589999999997,
          2350.397,
          2255.048,
          2153.081,
          2045.076,
          1931.608,
          1813.2420000000002,
          1690.524,
          1563.971,
          1434.0720000000001,
          1301.282,
          1166.024,
          1028.687,
          889.623,
          749.1569999999999,
          607.58,
          465.156,
          322.121,
          178.687,
          35.045,
          -108.63799999999999,
          -252.21,
          -395.537,
          -538.503,
          -681,
          -822.939,
          -964.235,
          -1104.819,
          -1244.628,
          -1383.606,
          -1521.707,
          -1658.888,
          -1795.114,
          -1930.354,
          -2064.58,
          -2197.772,
          -2329.909,
          -2460.9770000000003,
          -2590.962,
          -2719.8540000000003,
          -2847.6440000000002,
          -2974.3259999999996,
          -3099.8959999999997,
          -3224.3509999999997,
          -3347.6890000000003,
          -3469.91,
          -3591.015,
          -3711.0040000000004,
          -3829.882,
          -3947.65,
          -4064.315,
          -4179.879,
          -4294.347,
          -4407.726,
          -4520.02,
          -4631.238,
          -4741.383,
          -4850.465,
          -4958.49,
          -5065.464,
          -5171.394,
          -5276.29,
          -5380.156,
          -5483.0019999999995,
          -5584.835999999999,
          -5685.664000000001,
          -5785.493,
          -5884.3330000000005,
          -5982.19,
          -6079.071999999999,
          -6174.988,
          -6269.943,
          -6363.946,
          -6457.004,
          -6549.125,
          -6640.316,
          -6730.585,
          -6819.937,
          -6908.382,
          -6995.9259999999995,
          -7082.575,
          -7168.335999999999,
          -7253.218000000001,
          -7337.225,
          -7420.365,
          -7502.646,
          -7584.071999999999,
          -7664.65,
          -7744.387,
          -7823.289000000001,
          -7901.361999999999,
          -7978.611999999999,
          -8055.045999999999,
          -8130.668000000001,
          -8205.485999999999,
          -8279.503,
          -8352.726999999999,
          -8425.162,
          -8496.815,
          -8567.69,
          -8637.793,
          -8707.129,
          -8775.703000000001,
          -8843.521,
          -8910.588,
          -8976.907,
          -9042.484,
          -9107.324,
          -9171.431,
          -9234.81,
          -9297.466,
          -9359.404,
          -9420.627,
          -9481.139000000001,
          -9540.946,
          -9600.05,
          -9658.458,
          -9716.171999999999,
          -9773.196,
          -9829.535,
          -9885.192,
          -9940.171,
          -9994.476999999999,
          -10048.110999999999,
          -10101.079,
          -10153.384,
          -10205.029,
          -10256.018,
          -10306.355,
          -10356.042,
          -10405.082,
          -10453.48,
          -10501.239,
          -10548.361,
          -10594.851,
          -10640.708999999999,
          -10685.94,
          -10730.546999999999,
          -10774.533000000001,
          -10817.901000000002,
          -10860.652,
          -10902.791000000001,
          -10944.32,
          -10985.241000000002,
          -11025.558,
          -11065.273000000001,
          -11104.386999999999,
          -11142.905,
          -11180.828000000001,
          -11218.159,
          -11254.901000000002,
          -11291.053999999998,
          -11326.624,
          -11361.61,
          -11396.017,
          -11429.845,
          -11463.096000000001,
          -11495.774,
          -11527.88,
          -11559.417,
          -11590.386,
          -11620.788999999999,
          -11650.628999999999,
          -11679.907,
          -11708.625,
          -11736.786,
          -11764.39,
          -11791.441,
          -11817.938999999998,
          -11843.886999999999,
          -11869.285,
          -11894.136,
          -11918.442,
          -11942.204,
          -11965.423999999999,
          -11988.104,
          -12010.243999999999,
          -12031.846000000001,
          -12052.913,
          -12073.445,
          -12093.445,
          -12112.912,
          -12131.848999999998,
          -12150.258,
          -12168.139,
          -12185.493,
          -12202.323,
          -12218.628999999999,
          -12234.413,
          -12249.676000000001,
          -12264.42,
          -12278.643999999998,
          -12292.351,
          -12305.542,
          -12318.216,
          -12330.377,
          -12342.025,
          -12353.161,
          -12363.786,
          -12373.9,
          -12383.506000000001,
          -12392.604,
          -12401.195,
          -12409.278999999999,
          -12416.858,
          -12423.931999999999,
          -12430.503,
          -12436.572,
          -12442.138,
          -12447.204,
          -12451.768999999998,
          -12455.833999999999,
          -12459.4,
          -12462.469,
          -12465.04,
          -12467.114,
          -12468.692,
          -12469.775,
          -12470.363000000001,
          -12470.457,
          -12470.056999999999,
          -12469.165,
          -12467.778999999999,
          -12465.902,
          -12463.533000000001,
          -12460.673,
          -12457.323,
          -12453.483,
          -12449.153,
          -12444.333999999999,
          -12439.027,
          -12433.231000000002,
          -12426.947,
          -12420.176000000001,
          -12412.917,
          -12405.171,
          -12396.938999999998,
          -12388.22,
          -12379.016000000001,
          -12369.325,
          -12359.148000000001,
          -12348.486,
          -12337.34,
          -12325.708,
          -12313.591,
          -12300.99,
          -12287.903,
          -12274.333,
          -12260.278999999999,
          -12245.74,
          -12230.716999999999,
          -12215.208999999999,
          -12199.216999999999,
          -12182.741000000002,
          -12165.782,
          -12148.338,
          -12130.41,
          -12111.998,
          -12093.101,
          -12073.72,
          -12053.855,
          -12033.505,
          -12012.67,
          -11991.351,
          -11969.546,
          -11947.256000000001,
          -11924.481000000002,
          -11901.22,
          -11877.473,
          -11853.24,
          -11828.521,
          -11803.313999999998,
          -11777.622,
          -11751.441,
          -11724.774,
          -11697.618,
          -11669.973,
          -11641.84,
          -11613.216999999999,
          -11584.105,
          -11554.503999999999,
          -11524.411,
          -11493.827,
          -11462.752,
          -11431.186000000002,
          -11399.126,
          -11366.573999999999,
          -11333.527,
          -11299.987,
          -11265.952,
          -11231.421999999999,
          -11196.396,
          -11160.873,
          -11124.851999999999,
          -11088.333,
          -11051.316,
          -11013.798999999999,
          -10975.782,
          -10937.264,
          -10898.243999999999,
          -10858.722,
          -10818.696000000002,
          -10778.166000000001,
          -10737.131000000001,
          -10695.59,
          -10653.542,
          -10610.986,
          -10567.921999999999,
          -10524.348,
          -10480.263,
          -10435.666,
          -10390.556999999999,
          -10344.934000000001,
          -10298.796999999999,
          -10252.144,
          -10204.974,
          -10157.286,
          -10109.078000000001,
          -10060.351,
          -10011.101,
          -9961.33,
          -9911.034,
          -9860.213,
          -9808.866,
          -9756.991,
          -9704.587,
          -9651.653,
          -9598.187,
          -9544.188,
          -9489.655,
          -9434.586,
          -9378.98,
          -9322.836,
          -9266.15,
          -9208.923,
          -9151.154,
          -9092.839,
          -9033.978000000001,
          -8974.57,
          -8914.610999999999,
          -8854.101999999999,
          -8793.041,
          -8731.424,
          -8669.252,
          -8606.521999999999,
          -8543.232,
          -8479.381,
          -8414.966999999999,
          -8349.988000000001,
          -8284.442,
          -8218.328000000001,
          -8151.644,
          -8084.387,
          -8016.556,
          -7948.149,
          -7879.164000000001,
          -7809.599,
          -7739.451999999999,
          -7668.722,
          -7597.405,
          -7525.5,
          -7453.005,
          -7379.919,
          -7306.236999999999,
          -7231.96,
          -7157.085,
          -7081.609,
          -7005.531,
          -6928.848000000001,
          -6851.558000000001,
          -6773.659000000001,
          -6695.149,
          -6616.026,
          -6536.2880000000005,
          -6455.932,
          -6374.956,
          -6293.359,
          -6211.138000000001,
          -6128.291,
          -6044.815,
          -5960.709,
          -5875.972,
          -5790.599,
          -5704.59,
          -5617.943,
          -5530.656,
          -5442.727,
          -5354.154,
          -5264.935,
          -5175.068,
          -5084.552,
          -4993.385,
          -4901.566,
          -4809.093,
          -4715.965999999999,
          -4622.182,
          -4527.741,
          -4432.642,
          -4336.883,
          -4240.465999999999,
          -4143.388,
          -4045.6490000000003,
          -3947.2509999999997,
          -3848.192,
          -3748.474,
          -3648.0959999999995,
          -3547.062,
          -3445.37,
          -3343.0240000000003,
          -3240.026,
          -3136.3759999999997,
          -3032.0809999999997,
          -2927.1420000000003,
          -2821.563,
          -2715.35,
          -2608.507,
          -2501.042,
          -2392.9610000000002,
          -2284.271,
          -2174.981,
          -2065.1020000000003,
          -1954.6429999999998,
          -1843.6170000000002,
          -1732.0379999999998,
          -1619.9189999999999,
          -1507.279,
          -1394.134,
          -1280.506,
          -1166.4160000000002,
          -1051.889,
          -936.951,
          -821.6339999999999,
          -705.9689999999999,
          -589.993,
          -473.746,
          -357.27099999999996,
          -240.61599999999999,
          -123.836,
          -6.9879999999999995,
          109.86399999999999,
          226.649,
          343.288,
          459.69800000000004,
          575.7819999999999,
          691.438,
          806.553,
          920.9989999999999,
          1034.642,
          1147.328,
          1258.893,
          1369.1529999999998,
          1477.911,
          1584.9460000000001,
          1690.021,
          1792.874,
          1893.2220000000002,
          1990.756,
          2085.143,
          2176.0229999999997,
          2263.011,
          2345.694,
          2423.636,
          2496.3779999999997,
          2563.4410000000003,
          2624.3340000000003,
          2678.5559999999996,
          2725.6079999999997,
          2764.998,
          2796.258,
          2818.953,
          2832.6940000000004,
          2837.1540000000005,
          2832.078,
          2817.2940000000003,
          2792.7259999999997,
          2758.3920000000003,
          2714.4120000000003,
          2661,
          2598.462,
          2527.18,
          2447.609,
          2360.252,
          2265.652,
          2164.379,
          2057.011,
          1944.1229999999998,
          1826.283,
          1704.036,
          1577.9029999999998,
          1448.376,
          1315.914,
          1180.942,
          1043.851,
          904.9989999999999,
          764.712,
          623.284,
          480.98199999999997,
          338.045,
          194.687,
          51.101000000000006,
          -92.54299999999999,
          -236.093,
          -379.413,
          -522.383,
          -664.898,
          -806.867,
          -948.196,
          -1088.825,
          -1228.6860000000001,
          -1367.724,
          -1505.889,
          -1643.141,
          -1779.442,
          -1914.76,
          -2049.07,
          -2182.348,
          -2314.574,
          -2445.734,
          -2575.813,
          -2704.801,
          -2832.6890000000003,
          -2959.47,
          -3085.1409999999996,
          -3209.697,
          -3333.138,
          -3455.4629999999997,
          -3576.672,
          -3696.7659999999996,
          -3815.7490000000003,
          -3933.6240000000003,
          -4050.3940000000002,
          -4166.064,
          -4280.639,
          -4394.124,
          -4506.525,
          -4617.849,
          -4728.102,
          -4837.289000000001,
          -4945.42,
          -5052.5,
          -5158.536,
          -5263.536999999999,
          -5367.509,
          -5470.46,
          -5572.398,
          -5673.33,
          -5773.263000000001,
          -5872.206999999999,
          -5970.1669999999995,
          -6067.151999999999,
          -6163.17,
          -6258.227,
          -6352.331,
          -6445.491,
          -6537.713000000001,
          -6629.004,
          -6719.371999999999,
          -6808.8240000000005,
          -6897.368,
          -6985.01,
          -7071.758000000001,
          -7157.616999999999,
          -7242.596,
          -7326.701,
          -7409.937,
          -7492.313,
          -7573.835,
          -7654.509,
          -7734.340999999999,
          -7813.3369999999995,
          -7891.504,
          -7968.848000000001,
          -8045.374,
          -8121.09,
          -8196,
          -8270.109,
          -8343.424,
          -8415.951,
          -8487.695,
          -8558.66,
          -8628.854,
          -8698.279,
          -8766.943000000001,
          -8834.85,
          -8902.005,
          -8968.412,
          -9034.077,
          -9099.004,
          -9163.199,
          -9226.665,
          -9289.408000000001,
          -9351.431,
          -9412.74,
          -9473.339,
          -9533.23,
          -9592.42,
          -9650.912,
          -9708.71,
          -9765.818000000001,
          -9822.24,
          -9877.981,
          -9933.044,
          -9987.431999999999,
          -10041.149,
          -10094.199,
          -10146.586,
          -10198.312,
          -10249.383,
          -10299.8,
          -10349.568000000001,
          -10398.689,
          -10447.167,
          -10495.006000000001,
          -10542.208,
          -10588.777,
          -10634.715,
          -10680.025,
          -10724.71,
          -10768.775,
          -10812.22,
          -10855.05,
          -10897.266000000001,
          -10938.873,
          -10979.871000000001,
          -11020.265,
          -11060.056999999999,
          -11099.248,
          -11137.841,
          -11175.84,
          -11213.247,
          -11250.063999999998,
          -11286.294,
          -11321.938,
          -11357,
          -11391.481000000002,
          -11425.383999999998,
          -11458.71,
          -11491.462,
          -11523.642,
          -11555.253,
          -11586.296,
          -11616.773000000001,
          -11646.685,
          -11676.037,
          -11704.828000000001,
          -11733.062,
          -11760.739,
          -11787.861,
          -11814.431,
          -11840.451000000001,
          -11865.921999999999,
          -11890.845,
          -11915.223,
          -11939.056,
          -11962.347,
          -11985.097,
          -12007.308,
          -12028.982,
          -12050.118999999999,
          -12070.721000000001,
          -12090.791000000001,
          -12110.329,
          -12129.336000000001,
          -12147.813999999998,
          -12165.765,
          -12183.188999999998,
          -12200.088,
          -12216.464,
          -12232.317,
          -12247.649,
          -12262.461000000001,
          -12276.753999999999,
          -12290.528999999999,
          -12303.788,
          -12316.532,
          -12328.761,
          -12340.476999999999,
          -12351.68,
          -12362.373,
          -12372.555,
          -12382.229,
          -12391.393999999998,
          -12400.052,
          -12408.203000000001,
          -12415.963,
          -12423.097,
          -12429.726999999999,
          -12435.855,
          -12441.48,
          -12446.605,
          -12451.228000000001,
          -12455.351999999999,
          -12458.976999999999,
          -12462.104,
          -12464.733999999999,
          -12466.866000000002,
          -12468.502,
          -12469.643,
          -12470.288999999999,
          -12470.441,
          -12470.098999999998,
          -12469.264,
          -12467.936000000002,
          -12466.116000000002,
          -12463.803999999998,
          -12461.002,
          -12457.708999999999,
          -12453.926000000001,
          -12449.653,
          -12444.891000000001,
          -12439.641000000001,
          -12433.902,
          -12427.675,
          -12420.96,
          -12413.758,
          -12406.068000000001,
          -12397.892,
          -12389.23,
          -12380.082,
          -12370.447,
          -12360.327,
          -12349.722,
          -12338.631000000001,
          -12327.053999999998,
          -12314.993,
          -12302.448,
          -12289.418,
          -12275.903,
          -12261.903,
          -12247.42,
          -12232.452,
          -12217,
          -12201.063999999998,
          -12184.643999999998,
          -12167.739,
          -12150.351,
          -12132.478000000001,
          -12114.121000000001,
          -12095.278999999999,
          -12075.953000000001,
          -12056.143,
          -12035.848,
          -12015.068000000001,
          -11993.803,
          -11972.053,
          -11949.819,
          -11927.098,
          -11903.892,
          -11880.198999999999,
          -11856.021,
          -11831.356000000002,
          -11806.205,
          -11780.567,
          -11754.441,
          -11727.827,
          -11700.725,
          -11673.135,
          -11645.056999999999,
          -11616.489,
          -11587.431999999999,
          -11557.883,
          -11527.845,
          -11497.316,
          -11466.296,
          -11434.783000000001,
          -11402.778,
          -11370.28,
          -11337.288,
          -11303.802,
          -11269.821000000002,
          -11235.345,
          -11200.373,
          -11164.903999999999,
          -11128.938,
          -11092.473,
          -11055.51,
          -11018.046999999999,
          -10980.083999999999,
          -10941.62,
          -10902.655,
          -10863.186000000002,
          -10823.215,
          -10782.739,
          -10741.758,
          -10700.271999999999,
          -10658.278,
          -10615.776000000002,
          -10572.766000000001,
          -10529.246000000001,
          -10485.216,
          -10440.674,
          -10395.619,
          -10350.051,
          -10303.968,
          -10257.369,
          -10210.253,
          -10162.62,
          -10114.466999999999,
          -10065.793,
          -10016.599,
          -9966.882,
          -9916.641,
          -9865.875,
          -9814.582,
          -9762.761999999999,
          -9710.413,
          -9657.533000000001,
          -9604.123,
          -9550.179,
          -9495.701,
          -9440.687,
          -9385.135,
          -9329.045,
          -9272.416,
          -9215.244,
          -9157.53,
          -9099.27,
          -9040.464,
          -8981.110999999999,
          -8921.209,
          -8860.755,
          -8799.749,
          -8738.188,
          -8676.071,
          -8613.396999999999,
          -8550.163,
          -8486.368,
          -8422.01,
          -8357.087,
          -8291.597,
          -8225.54,
          -8158.911999999999,
          -8091.710999999999,
          -8023.936,
          -7955.585999999999,
          -7886.656999999999,
          -7817.149,
          -7747.059,
          -7676.385,
          -7605.125,
          -7533.276999999999,
          -7460.84,
          -7387.81,
          -7314.186,
          -7239.965999999999,
          -7165.148,
          -7089.73,
          -7013.709,
          -6937.084,
          -6859.851,
          -6782.01,
          -6703.558000000001,
          -6624.493,
          -6544.813,
          -6464.515,
          -6383.597,
          -6302.058000000001,
          -6219.895,
          -6137.106,
          -6053.689,
          -5969.641,
          -5884.9619999999995,
          -5799.649,
          -5713.6990000000005,
          -5627.11,
          -5539.880999999999,
          -5452.0109999999995,
          -5363.496,
          -5274.335999999999,
          -5184.527,
          -5094.071,
          -5002.963,
          -4911.2029999999995,
          -4818.789000000001,
          -4725.72,
          -4631.994000000001,
          -4537.612,
          -4442.571,
          -4346.872,
          -4250.512,
          -4153.492,
          -4055.812,
          -3957.4709999999995,
          -3858.47,
          -3758.809,
          -3658.489,
          -3557.511,
          -3455.8759999999997,
          -3353.585,
          -3250.6420000000003,
          -3147.0490000000004,
          -3042.808,
          -2937.923,
          -2832.3979999999997,
          -2726.238,
          -2619.447,
          -2512.034,
          -2404.002,
          -2295.362,
          -2186.12,
          -2076.288,
          -1965.875,
          -1854.894,
          -1743.358,
          -1631.281,
          -1518.6789999999999,
          -1405.5720000000001,
          -1291.979,
          -1177.922,
          -1063.425,
          -948.515,
          -833.221,
          -717.576,
          -601.616,
          -485.381,
          -368.914,
          -252.262,
          -135.47899999999998,
          -18.621,
          98.24600000000001,
          215.054,
          331.725,
          448.17400000000004,
          564.307,
          680.0239999999999,
          795.21,
          909.742,
          1023.4830000000001,
          1136.2839999999999,
          1247.979,
          1358.39,
          1467.317,
          1574.545,
          1679.8370000000002,
          1782.933,
          1883.5539999999999,
          1981.391,
          2076.116,
          2167.369,
          2254.77,
          2337.907,
          2416.348,
          2489.634,
          2557.291,
          2618.826,
          2673.739,
          2721.533,
          2761.7129999999997,
          2793.809,
          2817.382,
          2832.039,
          2837.445,
          2833.3390000000004,
          2819.54,
          2795.962,
          2762.615,
          2719.607,
          2667.1440000000002,
          2605.5229999999997,
          2535.12,
          2456.383,
          2369.8089999999997,
          2275.939,
          2175.34,
          2068.589,
          1956.263,
          1838.9279999999999,
          1717.134,
          1591.404,
          1462.233,
          1330.08,
          1195.376,
          1058.516,
          919.8589999999999,
          779.735,
          638.441,
          496.24699999999996,
          353.39300000000003,
          210.097,
          66.553,
          -77.066,
          -220.606,
          -363.93,
          -506.917,
          -649.46,
          -791.4630000000001,
          -932.8439999999999,
          -1073.527,
          -1213.451,
          -1352.557,
          -1490.796,
          -1628.126,
          -1764.51,
          -1899.915,
          -2034.315,
          -2167.686,
          -2300.008,
          -2431.265,
          -2561.444,
          -2690.534,
          -2818.5240000000003,
          -2945.41,
          -3071.1859999999997,
          -3195.849,
          -3319.3959999999997,
          -3441.828,
          -3563.1440000000002,
          -3683.347,
          -3802.4390000000003,
          -3920.421,
          -4037.3,
          -4153.0779999999995,
          -4267.7609999999995,
          -4381.355,
          -4493.8640000000005,
          -4605.295999999999,
          -4715.656,
          -4824.951,
          -4933.188,
          -5040.374,
          -5146.516,
          -5251.6230000000005,
          -5355.7,
          -5458.755999999999,
          -5560.798000000001,
          -5661.834,
          -5761.871,
          -5860.916,
          -5958.979,
          -6056.066,
          -6152.184,
          -6247.342,
          -6341.547,
          -6434.806,
          -6527.126,
          -6618.517,
          -6708.983,
          -6798.531999999999,
          -6887.173000000001,
          -6974.911,
          -7061.754,
          -7147.709,
          -7232.783,
          -7316.981,
          -7400.312,
          -7482.781,
          -7564.395,
          -7645.16,
          -7725.084,
          -7804.172,
          -7882.43,
          -7959.863,
          -8036.48,
          -8112.284000000001,
          -8187.283,
          -8261.48,
          -8334.883,
          -8407.498,
          -8479.328000000001,
          -8550.38,
          -8620.659,
          -8690.171,
          -8758.92,
          -8826.911,
          -8894.149,
          -8960.641,
          -9026.389000000001,
          -9091.4,
          -9155.677,
          -9219.225,
          -9282.05,
          -9344.154,
          -9405.544,
          -9466.223,
          -9526.195,
          -9585.465,
          -9644.036,
          -9701.913,
          -9759.1,
          -9815.601,
          -9871.419,
          -9926.559000000001,
          -9981.025,
          -10034.819,
          -10087.946,
          -10140.409,
          -10192.212,
          -10243.358,
          -10293.851,
          -10343.695,
          -10392.891,
          -10441.443000000001,
          -10489.356000000002,
          -10536.632,
          -10583.274,
          -10629.285,
          -10674.668,
          -10719.427,
          -10763.563999999998,
          -10807.082,
          -10849.983999999999,
          -10892.271999999999,
          -10933.95,
          -10975.02,
          -11015.483999999999,
          -11055.346000000001,
          -11094.608,
          -11133.271999999999,
          -11171.341999999999,
          -11208.818000000001,
          -11245.705,
          -11282.003,
          -11317.716999999999,
          -11352.847,
          -11387.396999999999,
          -11421.368,
          -11454.761999999999,
          -11487.582,
          -11519.83,
          -11551.508,
          -11582.618,
          -11613.162,
          -11643.142,
          -11672.56,
          -11701.418,
          -11729.716999999999,
          -11757.461000000001,
          -11784.649,
          -11811.285,
          -11837.37,
          -11862.906,
          -11887.893999999998,
          -11912.337,
          -11936.235,
          -11959.59,
          -11982.405,
          -12004.681,
          -12026.418,
          -12047.618999999999,
          -12068.285,
          -12088.418,
          -12108.02,
          -12127.09,
          -12145.632,
          -12163.645,
          -12181.132,
          -12198.094,
          -12214.532,
          -12230.447,
          -12245.841999999999,
          -12260.716,
          -12275.071000000002,
          -12288.908000000001,
          -12302.228000000001,
          -12315.033000000001,
          -12327.323999999999,
          -12339.1,
          -12350.365,
          -12361.118999999999,
          -12371.362,
          -12381.096000000001,
          -12390.322,
          -12399.04,
          -12407.252,
          -12414.958,
          -12422.159,
          -12428.857,
          -12435.052,
          -12440.745,
          -12445.937,
          -12450.627,
          -12454.818000000001,
          -12458.51,
          -12461.704,
          -12464.4,
          -12466.598999999998,
          -12468.301000000001,
          -12469.508999999998,
          -12470.221000000001,
          -12470.438999999998,
          -12470.163,
          -12469.393999999998,
          -12468.132,
          -12466.378,
          -12464.132,
          -12461.395,
          -12458.168,
          -12454.45,
          -12450.242,
          -12445.546,
          -12440.36,
          -12434.686000000002,
          -12428.524,
          -12421.874,
          -12414.737,
          -12407.112,
          -12399.001,
          -12390.403,
          -12381.319,
          -12371.749,
          -12361.693000000001,
          -12351.152,
          -12340.125,
          -12328.613000000001,
          -12316.616000000002,
          -12304.133999999998,
          -12291.168,
          -12277.716999999999,
          -12263.781,
          -12249.361,
          -12234.457,
          -12219.069,
          -12203.196000000002,
          -12186.84,
          -12169.998,
          -12152.673,
          -12134.863000000001,
          -12116.569,
          -12097.791000000001,
          -12078.528,
          -12058.781,
          -12038.548999999999,
          -12017.832,
          -11996.628999999999,
          -11974.942,
          -11952.77,
          -11930.112,
          -11906.968,
          -11883.339,
          -11859.223,
          -11834.621000000001,
          -11809.532,
          -11783.956,
          -11757.892,
          -11731.341,
          -11704.301000000001,
          -11676.773000000001,
          -11648.757,
          -11620.251,
          -11591.255,
          -11561.77,
          -11531.793,
          -11501.326000000001,
          -11470.368,
          -11438.917,
          -11406.973999999998,
          -11374.537,
          -11341.607,
          -11308.183,
          -11274.264,
          -11239.848999999998,
          -11204.938999999998,
          -11169.531,
          -11133.627,
          -11097.223999999998,
          -11060.322,
          -11022.921,
          -10985.02,
          -10946.617,
          -10907.713,
          -10868.306,
          -10828.396,
          -10787.981000000002,
          -10747.062,
          -10705.636999999999,
          -10663.704,
          -10621.264,
          -10578.315,
          -10534.856000000002,
          -10490.886999999999,
          -10446.405999999999,
          -10401.413,
          -10355.905999999999,
          -10309.884,
          -10263.346,
          -10216.292,
          -10168.719000000001,
          -10120.628,
          -10072.015,
          -10022.882,
          -9973.226,
          -9923.046,
          -9872.341,
          -9821.11,
          -9769.351,
          -9717.063,
          -9664.245,
          -9610.895,
          -9557.011999999999,
          -9502.596,
          -9447.643,
          -9392.153,
          -9336.124,
          -9279.555,
          -9222.445,
          -9164.792,
          -9106.594000000001,
          -9047.85,
          -8988.556999999999,
          -8928.716,
          -8868.323,
          -8807.378,
          -8745.879,
          -8683.824,
          -8621.211,
          -8558.038,
          -8494.304,
          -8430.007,
          -8365.146,
          -8299.718,
          -8233.721,
          -8167.154,
          -8100.015,
          -8032.302,
          -7964.013000000001,
          -7895.146,
          -7825.6990000000005,
          -7755.67,
          -7685.058000000001,
          -7613.86,
          -7542.073,
          -7469.696999999999,
          -7396.728,
          -7323.166,
          -7249.008000000001,
          -7174.2519999999995,
          -7098.895,
          -7022.936,
          -6946.371,
          -6869.201,
          -6791.422,
          -6713.031,
          -6634.026999999999,
          -6554.408,
          -6474.172,
          -6393.316,
          -6311.838000000001,
          -6229.736999999999,
          -6147.009,
          -6063.653,
          -5979.668000000001,
          -5895.05,
          -5809.797,
          -5723.908,
          -5637.380999999999,
          -5550.213000000001,
          -5462.404,
          -5373.9490000000005,
          -5284.85,
          -5195.103,
          -5104.707,
          -5013.659000000001,
          -4921.959,
          -4829.605,
          -4736.596,
          -4642.931,
          -4548.608,
          -4453.627,
          -4357.985,
          -4261.685,
          -4164.724,
          -4067.1009999999997,
          -3968.8179999999998,
          -3869.875,
          -3770.2709999999997,
          -3670.008,
          -3569.086,
          -3467.506,
          -3365.2709999999997,
          -3262.383,
          -3158.844,
          -3054.656,
          -2949.823,
          -2844.349,
          -2738.24,
          -2631.5,
          -2524.134,
          -2416.151,
          -2307.5570000000002,
          -2198.361,
          -2088.572,
          -1978.201,
          -1867.26,
          -1755.761,
          -1643.721,
          -1531.154,
          -1418.079,
          -1304.515,
          -1190.485,
          -1076.011,
          -961.12,
          -845.8439999999999,
          -730.212,
          -614.261,
          -498.03,
          -381.561,
          -264.903,
          -148.106,
          -31.23,
          85.664,
          202.50599999999997,
          319.22,
          435.721,
          551.9169999999999,
          667.7080000000001,
          782.98,
          897.6110000000001,
          1011.466,
          1124.397,
          1236.241,
          1346.819,
          1455.9360000000001,
          1563.375,
          1668.9029999999998,
          1772.264,
          1873.1779999999999,
          1971.3410000000001,
          2066.427,
          2158.08,
          2245.919,
          2329.538,
          2408.505,
          2482.366,
          2550.645,
          2612.855,
          2668.495,
          2717.065,
          2758.072,
          2791.0429999999997,
          2815.534,
          2831.1479999999997,
          2837.545,
          2834.453,
          2821.6859999999997,
          2799.1459999999997,
          2766.8340000000003,
          2724.848,
          2673.385,
          2612.732,
          2543.258,
          2465.403,
          2379.66,
          2286.567,
          2186.687,
          2080.596,
          1968.872,
          1852.0839999999998,
          1730.781,
          1605.489,
          1476.704,
          1344.894,
          1210.488,
          1073.886,
          935.45,
          795.513,
          654.377,
          512.312,
          369.56199999999995,
          226.347,
          82.863,
          -60.714,
          -204.229,
          -347.54400000000004,
          -490.534,
          -633.0930000000001,
          -775.122,
          -916.539,
          -1057.268,
          -1197.243,
          -1336.408,
          -1474.713,
          -1612.114,
          -1748.5729999999999,
          -1884.059,
          -2018.543,
          -2152.001,
          -2284.415,
          -2415.765,
          -2546.0389999999998,
          -2675.2259999999997,
          -2803.316,
          -2930.303,
          -3056.1820000000002,
          -3180.948,
          -3304.6,
          -3427.137,
          -3548.56,
          -3668.869,
          -3788.0679999999998,
          -3906.159,
          -4023.145,
          -4139.032,
          -4253.823,
          -4367.525,
          -4480.143,
          -4591.683,
          -4702.151,
          -4811.555,
          -4919.9,
          -5027.193,
          -5133.444,
          -5238.657,
          -5342.840999999999,
          -5446.004,
          -5548.151999999999,
          -5649.294,
          -5749.437,
          -5848.588000000001,
          -5946.755,
          -6043.946999999999,
          -6140.169,
          -6235.43,
          -6329.7390000000005,
          -6423.101,
          -6515.524,
          -6607.016,
          -6697.584,
          -6787.235,
          -6875.976,
          -6963.815,
          -7050.758000000001,
          -7136.812,
          -7221.984,
          -7306.281999999999,
          -7389.710999999999,
          -7472.276999999999,
          -7553.9890000000005,
          -7634.852,
          -7714.871999999999,
          -7794.055,
          -7872.408,
          -7949.938,
          -8026.648,
          -8102.547,
          -8177.639,
          -8251.931,
          -8325.427,
          -8398.134,
          -8470.056999999999,
          -8541.201,
          -8611.572,
          -8681.175,
          -8750.014000000001,
          -8818.096,
          -8885.425,
          -8952.005,
          -9017.843,
          -9082.943000000001,
          -9147.309000000001,
          -9210.946,
          -9273.858,
          -9336.05,
          -9397.528,
          -9458.293,
          -9518.351999999999,
          -9577.708,
          -9636.365,
          -9694.328000000001,
          -9751.601,
          -9808.187,
          -9864.09,
          -9919.315,
          -9973.864,
          -10027.742,
          -10080.952,
          -10133.499,
          -10185.385,
          -10236.614,
          -10287.19,
          -10337.114,
          -10386.392,
          -10435.027,
          -10483.021999999999,
          -10530.378999999999,
          -10577.101,
          -10623.193000000001,
          -10668.657,
          -10713.496000000001,
          -10757.712,
          -10801.309,
          -10844.29,
          -10886.658000000001,
          -10928.413999999999,
          -10969.563,
          -11010.106000000002,
          -11050.045,
          -11089.385,
          -11128.128,
          -11166.275,
          -11203.829,
          -11240.792,
          -11277.168,
          -11312.958,
          -11348.165,
          -11382.79,
          -11416.837,
          -11450.306999999999,
          -11483.203000000001,
          -11515.527,
          -11547.28,
          -11578.465,
          -11609.083,
          -11639.138,
          -11668.63,
          -11697.563,
          -11725.936000000002,
          -11753.753999999999,
          -11781.016000000001,
          -11807.725,
          -11833.883,
          -11859.493,
          -11884.553999999998,
          -11909.069,
          -11933.04,
          -11956.468,
          -11979.355,
          -12001.703000000001,
          -12023.513,
          -12044.786,
          -12065.524,
          -12085.728000000001,
          -12105.401000000002,
          -12124.543,
          -12143.155,
          -12161.24,
          -12178.798,
          -12195.83,
          -12212.339,
          -12228.325,
          -12243.788999999999,
          -12258.733,
          -12273.158000000001,
          -12287.065,
          -12300.455,
          -12313.33,
          -12325.69,
          -12337.536,
          -12348.87,
          -12359.693000000001,
          -12370.005,
          -12379.808,
          -12389.103000000001,
          -12397.89,
          -12406.17,
          -12413.944,
          -12421.214,
          -12427.98,
          -12434.243,
          -12440.003,
          -12445.261999999999,
          -12450.021,
          -12454.28,
          -12458.038999999999,
          -12461.3,
          -12464.063999999998,
          -12466.33,
          -12468.098999999998,
          -12469.373,
          -12470.153,
          -12470.437,
          -12470.228000000001,
          -12469.526000000002,
          -12468.33,
          -12466.642,
          -12464.463,
          -12461.792,
          -12458.631000000001,
          -12454.979,
          -12450.838,
          -12446.207,
          -12441.087,
          -12435.479,
          -12429.382,
          -12422.798,
          -12415.726,
          -12408.166000000001,
          -12400.12,
          -12391.587,
          -12382.569,
          -12373.063999999998,
          -12363.073,
          -12352.597,
          -12341.633999999998,
          -12330.187,
          -12318.255,
          -12305.838,
          -12292.936000000002,
          -12279.55,
          -12265.678999999998,
          -12251.323,
          -12236.483,
          -12221.158000000001,
          -12205.35,
          -12189.056999999999,
          -12172.28,
          -12155.018,
          -12137.271999999999,
          -12119.042,
          -12100.327,
          -12081.128,
          -12061.445,
          -12041.276000000002,
          -12020.623,
          -11999.483999999999,
          -11977.86,
          -11955.751,
          -11933.157,
          -11910.077,
          -11886.51,
          -11862.458,
          -11837.918,
          -11812.892,
          -11787.378999999999,
          -11761.378999999999,
          -11734.89,
          -11707.913,
          -11680.448,
          -11652.495,
          -11624.052,
          -11595.118999999999,
          -11565.696000000002,
          -11535.783000000001,
          -11505.378,
          -11474.481000000002,
          -11443.093,
          -11411.213,
          -11378.839,
          -11345.971000000001,
          -11312.61,
          -11278.753,
          -11244.4,
          -11209.552,
          -11174.207,
          -11138.364,
          -11102.024,
          -11065.184,
          -11027.845,
          -10990.006000000001,
          -10951.666000000001,
          -10912.823999999999,
          -10873.479,
          -10833.631000000001,
          -10793.278,
          -10752.421,
          -10711.058,
          -10669.187,
          -10626.809,
          -10583.923,
          -10540.526000000002,
          -10496.618,
          -10452.199,
          -10407.268,
          -10361.823,
          -10315.863000000001,
          -10269.386999999999,
          -10222.394,
          -10174.884,
          -10126.854,
          -10078.304,
          -10029.233,
          -9979.638,
          -9929.52,
          -9878.877,
          -9827.708,
          -9776.011,
          -9723.785,
          -9671.029,
          -9617.74,
          -9563.919,
          -9509.564,
          -9454.674,
          -9399.245,
          -9343.278,
          -9286.771,
          -9229.723,
          -9172.132,
          -9113.996,
          -9055.314,
          -8996.083,
          -8936.304,
          -8875.973,
          -8815.09,
          -8753.653,
          -8691.66,
          -8629.109,
          -8565.998,
          -8502.326,
          -8438.091,
          -8373.292,
          -8307.926,
          -8241.992,
          -8175.486999999999,
          -8108.41,
          -8040.759,
          -7972.531999999999,
          -7903.727,
          -7834.342,
          -7764.375,
          -7693.825,
          -7622.689,
          -7550.965,
          -7478.651,
          -7405.745,
          -7332.245,
          -7258.149,
          -7183.455,
          -7108.161,
          -7032.263000000001,
          -6955.7609999999995,
          -6878.653,
          -6800.936,
          -6722.608,
          -6643.666,
          -6564.109,
          -6483.936,
          -6403.142,
          -6321.726,
          -6239.687,
          -6157.021,
          -6073.728,
          -5989.804,
          -5905.2480000000005,
          -5820.057,
          -5734.23,
          -5647.765,
          -5560.659000000001,
          -5472.911,
          -5384.519,
          -5295.481,
          -5205.795,
          -5115.46,
          -5024.474,
          -4932.834,
          -4840.541,
          -4747.593,
          -4653.988,
          -4559.726,
          -4464.804,
          -4369.223,
          -4272.982,
          -4176.08,
          -4078.5159999999996,
          -3980.292,
          -3881.407,
          -3781.861,
          -3681.655,
          -3580.79,
          -3479.2659999999996,
          -3377.087,
          -3274.2540000000004,
          -3170.7690000000002,
          -3066.635,
          -2961.855,
          -2856.434,
          -2750.3759999999997,
          -2643.6859999999997,
          -2536.369,
          -2428.4339999999997,
          -2319.887,
          -2210.736,
          -2100.992,
          -1990.6629999999998,
          -1879.763,
          -1768.3029999999999,
          -1656.3,
          -1543.7679999999998,
          -1430.725,
          -1317.191,
          -1203.187,
          -1088.737,
          -973.868,
          -858.6080000000001,
          -742.9889999999999,
          -627.047,
          -510.82,
          -394.35,
          -277.685,
          -160.877,
          -43.981,
          72.939,
          189.815,
          306.57099999999997,
          423.124,
          539.383,
          655.247,
          770.605,
          885.335,
          999.305,
          1112.366,
          1224.358,
          1335.1029999999998,
          1444.408,
          1552.058,
          1657.8229999999999,
          1761.4479999999999,
          1862.655,
          1961.145,
          2056.592,
          2148.643,
          2236.9210000000003,
          2321.021,
          2400.515,
          2474.949,
          2543.853,
          2606.737,
          2663.103,
          2712.4509999999996,
          2754.2859999999996,
          2788.132,
          2813.545,
          2830.12,
          2837.509,
          2835.437,
          2823.7070000000003,
          2802.212,
          2770.941,
          2729.985,
          2679.53,
          2619.853,
          2551.317,
          2474.353,
          2389.451,
          2297.144,
          2197.992,
          2092.571,
          1981.4589999999998,
          1865.223,
          1744.418,
          1619.5710000000001,
          1491.182,
          1359.719,
          1225.617,
          1089.278,
          951.068,
          811.322,
          670.346,
          528.413,
          385.769,
          242.638,
          99.21600000000001,
          -44.317,
          -187.80599999999998,
          -331.10900000000004,
          -474.1,
          -616.672,
          -758.743,
          -900.179,
          -1040.952,
          -1180.979,
          -1320.204,
          -1458.5739999999998,
          -1596.045,
          -1732.58,
          -1868.146,
          -2002.714,
          -2136.26,
          -2268.764,
          -2400.2070000000003,
          -2530.577,
          -2659.862,
          -2788.052,
          -2915.14,
          -3041.1209999999996,
          -3165.991,
          -3289.7470000000003,
          -3412.3909999999996,
          -3533.92,
          -3654.336,
          -3773.6420000000003,
          -3891.841,
          -4008.9359999999997,
          -4124.931,
          -4239.831,
          -4353.642,
          -4466.3679999999995,
          -4578.017,
          -4688.593,
          -4798.105,
          -4906.559,
          -5013.960999999999,
          -5120.319,
          -5225.641,
          -5329.932,
          -5433.201,
          -5535.456999999999,
          -5636.705,
          -5736.953,
          -5836.21,
          -5934.483,
          -6031.779,
          -6128.106,
          -6223.472,
          -6317.884,
          -6411.349,
          -6503.875,
          -6595.469,
          -6686.139,
          -6775.891,
          -6864.734,
          -6952.673000000001,
          -7039.715999999999,
          -7125.87,
          -7211.142,
          -7295.5380000000005,
          -7379.065,
          -7461.73,
          -7543.54,
          -7624.5,
          -7704.616,
          -7783.896,
          -7862.345,
          -7939.97,
          -8016.776,
          -8092.769,
          -8167.956,
          -8242.341,
          -8315.931,
          -8388.731,
          -8460.746,
          -8531.983,
          -8602.445,
          -8672.139000000001,
          -8741.07,
          -8809.243,
          -8876.663,
          -8943.333,
          -9009.261,
          -9074.45,
          -9138.905,
          -9202.63,
          -9265.631,
          -9327.911,
          -9389.476,
          -9450.329,
          -9510.475,
          -9569.917,
          -9628.661,
          -9686.71,
          -9744.068000000001,
          -9800.74,
          -9856.728000000001,
          -9912.037,
          -9966.671,
          -10020.634,
          -10073.928,
          -10126.558,
          -10178.527,
          -10229.839,
          -10280.497,
          -10330.505,
          -10379.865,
          -10428.581,
          -10476.657,
          -10524.096000000001,
          -10570.9,
          -10617.072,
          -10662.617,
          -10707.536,
          -10751.833,
          -10795.51,
          -10838.571000000002,
          -10881.017,
          -10922.853000000001,
          -10964.081,
          -11004.702,
          -11044.721000000001,
          -11084.139,
          -11122.958999999999,
          -11161.183,
          -11198.815,
          -11235.856000000002,
          -11272.31,
          -11308.176000000001,
          -11343.46,
          -11378.162,
          -11412.285,
          -11445.832,
          -11478.803999999998,
          -11511.203000000001,
          -11543.031,
          -11574.291000000001,
          -11604.985,
          -11635.115,
          -11664.681999999999,
          -11693.688,
          -11722.136,
          -11750.028,
          -11777.365,
          -11804.148000000001,
          -11830.38,
          -11856.062,
          -11881.197,
          -11905.786,
          -11929.83,
          -11953.331,
          -11976.291000000001,
          -11998.711000000001,
          -12020.593,
          -12041.938,
          -12062.749,
          -12083.025,
          -12102.77,
          -12121.983,
          -12140.667,
          -12158.823,
          -12176.452,
          -12193.556,
          -12210.135,
          -12226.192,
          -12241.726999999999,
          -12256.741000000002,
          -12271.237,
          -12285.214,
          -12298.675,
          -12311.618999999999,
          -12324.048999999999,
          -12335.965,
          -12347.368999999999,
          -12358.261,
          -12368.642,
          -12378.515,
          -12387.878,
          -12396.733,
          -12405.083,
          -12412.926000000001,
          -12420.265,
          -12427.098999999998,
          -12433.431,
          -12439.26,
          -12444.587,
          -12449.413,
          -12453.74,
          -12457.567,
          -12460.896,
          -12463.726999999999,
          -12466.061000000002,
          -12467.898000000001,
          -12469.239,
          -12470.086000000001,
          -12470.438,
          -12470.296,
          -12469.66,
          -12468.531,
          -12466.91,
          -12464.796999999999,
          -12462.193000000001,
          -12459.098999999998,
          -12455.514,
          -12451.438999999998,
          -12446.874,
          -12441.82,
          -12436.278,
          -12430.247,
          -12423.729,
          -12416.723,
          -12409.229,
          -12401.249,
          -12392.782,
          -12383.828000000001,
          -12374.388,
          -12364.463,
          -12354.052,
          -12343.155,
          -12331.773000000001,
          -12319.905,
          -12307.553,
          -12294.716,
          -12281.395,
          -12267.589,
          -12253.298,
          -12238.521999999999,
          -12223.261999999999,
          -12207.518,
          -12191.29,
          -12174.577,
          -12157.38,
          -12139.698999999999,
          -12121.533000000001,
          -12102.882,
          -12083.747,
          -12064.127,
          -12044.023000000001,
          -12023.433,
          -12002.358999999999,
          -11980.798999999999,
          -11958.753999999999,
          -11936.223,
          -11913.206,
          -11889.703000000001,
          -11865.714,
          -11841.239,
          -11816.277,
          -11790.827,
          -11764.889,
          -11738.464,
          -11711.551000000001,
          -11684.15,
          -11656.258999999998,
          -11627.878999999999,
          -11599.01,
          -11569.65,
          -11539.798999999999,
          -11509.458,
          -11478.625,
          -11447.298999999999,
          -11415.481000000002,
          -11383.17,
          -11350.365,
          -11317.066,
          -11283.273000000001,
          -11248.983,
          -11214.198,
          -11178.915,
          -11143.135,
          -11106.858,
          -11070.081,
          -11032.805,
          -10995.028,
          -10956.751,
          -10917.971000000001,
          -10878.688999999998,
          -10838.903,
          -10798.613000000001,
          -10757.819,
          -10716.518,
          -10674.71,
          -10632.393999999998,
          -10589.569,
          -10546.235,
          -10502.39,
          -10458.034,
          -10413.165,
          -10367.783000000001,
          -10321.885,
          -10275.471,
          -10228.541,
          -10181.093,
          -10133.125,
          -10084.638,
          -10035.629,
          -9986.097,
          -9936.041,
          -9885.46,
          -9834.353000000001,
          -9782.718,
          -9730.554,
          -9677.86,
          -9624.635,
          -9570.877,
          -9516.584,
          -9461.755,
          -9406.389000000001,
          -9350.485,
          -9294.04,
          -9237.055,
          -9179.526,
          -9121.452,
          -9062.832,
          -9003.664,
          -8943.947,
          -8883.679,
          -8822.859,
          -8761.484,
          -8699.553,
          -8637.064,
          -8574.016,
          -8510.407,
          -8446.234,
          -8381.498,
          -8316.194,
          -8250.322,
          -8183.88,
          -8116.865,
          -8049.276999999999,
          -7981.113,
          -7912.371,
          -7843.049,
          -7773.145,
          -7702.656999999999,
          -7631.584,
          -7559.922,
          -7487.670999999999,
          -7414.826999999999,
          -7341.39,
          -7267.357,
          -7192.726,
          -7117.494000000001,
          -7041.659000000001,
          -6965.22,
          -6888.175,
          -6810.52,
          -6732.255,
          -6653.376,
          -6573.882,
          -6493.77,
          -6413.039000000001,
          -6331.687,
          -6249.71,
          -6167.107,
          -6083.876,
          -6000.014,
          -5915.521,
          -5830.393,
          -5744.628000000001,
          -5658.225,
          -5571.181,
          -5483.495,
          -5395.165,
          -5306.189,
          -5216.565,
          -5126.292,
          -5035.366,
          -4943.789000000001,
          -4851.557,
          -4758.67,
          -4665.125,
          -4570.923,
          -4476.063,
          -4380.542,
          -4284.36,
          -4187.517,
          -4090.014,
          -3991.849,
          -3893.022,
          -3793.534,
          -3693.385,
          -3592.577,
          -3491.111,
          -3388.988,
          -3286.21,
          -3182.78,
          -3078.7,
          -2973.973,
          -2868.605,
          -2762.599,
          -2655.9590000000003,
          -2548.692,
          -2440.805,
          -2332.305,
          -2223.2,
          -2113.5,
          -2003.214,
          -1892.355,
          -1780.935,
          -1668.9679999999998,
          -1556.471,
          -1443.461,
          -1329.9560000000001,
          -1215.98,
          -1101.5539999999999,
          -986.706,
          -871.4630000000001,
          -755.8580000000001,
          -639.925,
          -523.702,
          -407.23199999999997,
          -290.561,
          -173.74,
          -56.826,
          60.12,
          177.03,
          293.829,
          410.43300000000005,
          526.754,
          642.691,
          758.135,
          872.9639999999999,
          987.047,
          1100.238,
          1212.377,
          1323.2879999999998,
          1432.781,
          1540.642,
          1646.642,
          1750.529,
          1852.03,
          1950.845,
          2046.65,
          2139.097,
          2227.812,
          2312.391,
          2392.41,
          2467.417,
          2536.942,
          2600.498,
          2657.5879999999997,
          2707.711,
          2750.3720000000003,
          2785.093,
          2811.425,
          2828.9590000000003,
          2837.342,
          2836.29,
          2825.598,
          2805.15,
          2774.925,
          2735.002,
          2685.559,
          2626.865,
          2559.2729999999997,
          2483.2070000000003,
          2399.153,
          2307.639,
          2209.222,
          2104.478,
          1993.983,
          1878.309,
          1758.0079999999998,
          1633.612,
          1505.6229999999998,
          1374.5120000000002,
          1240.718,
          1104.647,
          966.666,
          827.117,
          686.304,
          544.505,
          401.971,
          258.925,
          115.569,
          -27.919,
          -171.38,
          -314.67,
          -457.663,
          -600.249,
          -742.329,
          -883.815,
          -1024.63,
          -1164.7089999999998,
          -1303.991,
          -1442.4260000000002,
          -1579.967,
          -1716.578,
          -1852.223,
          -1986.875,
          -2120.507,
          -2253.101,
          -2384.637,
          -2515.103,
          -2644.485,
          -2772.7740000000003,
          -2899.9629999999997,
          -3026.046,
          -3151.02,
          -3274.881,
          -3397.63,
          -3519.265,
          -3639.788,
          -3759.202,
          -3877.509,
          -3994.711,
          -4110.815,
          -4225.8240000000005,
          -4339.7429999999995,
          -4452.5779999999995,
          -4564.335,
          -4675.02,
          -4784.641,
          -4893.2029999999995,
          -5000.712,
          -5107.178,
          -5212.607,
          -5317.005999999999,
          -5420.382,
          -5522.745,
          -5624.099,
          -5724.453,
          -5823.816,
          -5922.194,
          -6019.595,
          -6116.026999999999,
          -6211.496999999999,
          -6306.012,
          -6399.58,
          -6492.209,
          -6583.906,
          -6674.677,
          -6764.531,
          -6853.475,
          -6941.515,
          -7028.658,
          -7114.911999999999,
          -7200.283,
          -7284.779,
          -7368.404,
          -7451.1669999999995,
          -7533.0740000000005,
          -7614.130999999999,
          -7694.345,
          -7773.721,
          -7852.266,
          -7929.986999999999,
          -8006.888000000001,
          -8082.976,
          -8158.257,
          -8232.735999999999,
          -8306.42,
          -8379.312,
          -8451.421,
          -8522.75,
          -8593.304,
          -8663.09,
          -8732.112,
          -8800.376,
          -8867.886,
          -8934.646999999999,
          -9000.664,
          -9065.942,
          -9130.487,
          -9194.301,
          -9257.39,
          -9319.758,
          -9381.411,
          -9442.351,
          -9502.584,
          -9562.113000000001,
          -9620.943000000001,
          -9679.079,
          -9736.523000000001,
          -9793.28,
          -9849.353000000001,
          -9904.747,
          -9959.466,
          -10013.513,
          -10066.891,
          -10119.605,
          -10171.657,
          -10223.053,
          -10273.794,
          -10323.884,
          -10373.326,
          -10422.125,
          -10470.283000000001,
          -10517.803,
          -10564.688,
          -10610.942,
          -10656.567,
          -10701.567,
          -10745.944,
          -10789.702,
          -10832.841999999999,
          -10875.368,
          -10917.283000000001,
          -10958.59,
          -10999.291000000001,
          -11039.388,
          -11078.883999999998,
          -11117.783000000001,
          -11156.085,
          -11193.795,
          -11230.913999999999,
          -11267.444,
          -11303.388,
          -11338.748,
          -11373.527,
          -11407.726999999999,
          -11441.35,
          -11474.398000000001,
          -11506.873,
          -11538.778,
          -11570.113000000001,
          -11600.883,
          -11631.088,
          -11660.73,
          -11689.811000000002,
          -11718.333999999999,
          -11746.3,
          -11773.711000000001,
          -11800.569,
          -11826.874,
          -11852.631000000001,
          -11877.839,
          -11902.501,
          -11926.618,
          -11950.192,
          -11973.225,
          -11995.719,
          -12017.673999999999,
          -12039.091,
          -12059.973999999998,
          -12080.322,
          -12100.139,
          -12119.423999999999,
          -12138.18,
          -12156.408000000001,
          -12174.108,
          -12191.283000000001,
          -12207.934,
          -12224.062,
          -12239.668,
          -12254.753999999999,
          -12269.32,
          -12283.368,
          -12296.899,
          -12309.913,
          -12322.413,
          -12334.399,
          -12345.873,
          -12356.835,
          -12367.287,
          -12377.228000000001,
          -12386.661,
          -12395.586000000001,
          -12404.003999999999,
          -12411.917,
          -12419.325,
          -12426.228000000001,
          -12432.628,
          -12438.526000000002,
          -12443.921,
          -12448.816,
          -12453.211000000001,
          -12457.107,
          -12460.503999999999,
          -12463.403,
          -12465.805,
          -12467.71,
          -12469.118999999999,
          -12470.033000000001,
          -12470.452,
          -12470.378,
          -12469.809,
          -12468.748,
          -12467.194,
          -12465.148000000001,
          -12462.611,
          -12459.583,
          -12456.065,
          -12452.056999999999,
          -12447.559,
          -12442.572,
          -12437.096000000001,
          -12431.131000000001,
          -12424.678999999998,
          -12417.739,
          -12410.312,
          -12402.398000000001,
          -12393.997,
          -12385.108999999999,
          -12375.735,
          -12365.875,
          -12355.53,
          -12344.698999999999,
          -12333.383,
          -12321.581,
          -12309.294,
          -12296.521999999999,
          -12283.266000000001,
          -12269.525,
          -12255.298999999999,
          -12240.589,
          -12225.395,
          -12209.716,
          -12193.552,
          -12176.903999999999,
          -12159.771999999999,
          -12142.155,
          -12124.053,
          -12105.468,
          -12086.396999999999,
          -12066.841999999999,
          -12046.802,
          -12026.277,
          -12005.266000000001,
          -11983.771,
          -11961.79,
          -11939.323,
          -11916.371000000001,
          -11892.931999999999,
          -11869.007,
          -11844.596000000001,
          -11819.697,
          -11794.311000000002,
          -11768.438,
          -11742.077,
          -11715.228000000001,
          -11687.89,
          -11660.063,
          -11631.746000000001,
          -11602.94,
          -11573.643999999998,
          -11543.857,
          -11513.58,
          -11482.81,
          -11451.548,
          -11419.794,
          -11387.546,
          -11354.805,
          -11321.569,
          -11287.839,
          -11253.613000000001,
          -11218.891000000001,
          -11183.671,
          -11147.954,
          -11111.74,
          -11075.026000000002,
          -11037.813,
          -11000.1,
          -10961.886,
          -10923.169,
          -10883.95,
          -10844.226999999999,
          -10804,
          -10763.268999999998,
          -10722.031,
          -10680.286,
          -10638.033000000001,
          -10595.271,
          -10552,
          -10508.218,
          -10463.925,
          -10419.119,
          -10373.799,
          -10327.965,
          -10281.615,
          -10234.747,
          -10187.360999999999,
          -10139.457,
          -10091.032,
          -10042.086,
          -9992.617,
          -9942.625,
          -9892.107,
          -9841.062,
          -9789.49,
          -9737.389000000001,
          -9684.758,
          -9631.596,
          -9577.901,
          -9523.67,
          -9468.904,
          -9413.601999999999,
          -9357.76,
          -9301.379,
          -9244.456,
          -9186.99,
          -9128.979,
          -9070.421999999999,
          -9011.317,
          -8951.663,
          -8891.458,
          -8830.701,
          -8769.389000000001,
          -8707.521,
          -8645.095,
          -8582.11,
          -8518.564,
          -8454.455,
          -8389.780999999999,
          -8324.541,
          -8258.732,
          -8192.353000000001,
          -8125.401999999999,
          -8057.8769999999995,
          -7989.776,
          -7921.097,
          -7851.8369999999995,
          -7781.996999999999,
          -7711.573,
          -7640.563,
          -7568.965,
          -7496.776,
          -7423.996,
          -7350.621999999999,
          -7276.651999999999,
          -7202.084,
          -7126.916,
          -7051.145,
          -6974.769,
          -6897.786999999999,
          -6820.195,
          -6741.993,
          -6663.178000000001,
          -6583.7480000000005,
          -6503.6990000000005,
          -6423.031,
          -6341.741,
          -6259.828,
          -6177.2880000000005,
          -6094.12,
          -6010.321999999999,
          -5925.891,
          -5840.826,
          -5755.124,
          -5668.784000000001,
          -5581.803000000001,
          -5494.18,
          -5405.911999999999,
          -5316.9980000000005,
          -5227.437,
          -5137.226,
          -5046.363,
          -4954.847,
          -4862.677,
          -4769.851,
          -4676.369000000001,
          -4582.228,
          -4487.428,
          -4391.967000000001,
          -4295.846,
          -4199.064,
          -4101.62,
          -4003.514,
          -3904.7459999999996,
          -3805.317,
          -3705.2270000000003,
          -3604.4759999999997,
          -3503.0679999999998,
          -3401.0009999999997,
          -3298.2790000000005,
          -3194.9040000000005,
          -3090.8779999999997,
          -2986.2059999999997,
          -2880.8909999999996,
          -2774.9359999999997,
          -2668.348,
          -2561.131,
          -2453.2929999999997,
          -2344.84,
          -2235.782,
          -2126.126,
          -2015.884,
          -1905.065,
          -1793.685,
          -1681.756,
          -1569.2939999999999,
          -1456.317,
          -1342.8429999999998,
          -1228.894,
          -1114.493,
          -999.665,
          -884.44,
          -768.8480000000001,
          -652.925,
          -536.707,
          -420.236,
          -303.559,
          -186.727,
          -69.794,
          47.178000000000004,
          164.12099999999998,
          280.962,
          397.61800000000005,
          514.001,
          630.01,
          745.539,
          860.467,
          974.663,
          1087.983,
          1200.269,
          1311.346,
          1421.026,
          1529.0970000000002,
          1635.332,
          1739.4820000000002,
          1841.274,
          1940.412,
          2036.575,
          2129.419,
          2218.569,
          2303.627,
          2384.169,
          2459.7470000000003,
          2529.8920000000003,
          2594.119,
          2651.933,
          2702.83,
          2746.3179999999998,
          2781.914,
          2809.165,
          2827.6609999999996,
          2837.039,
          2837.011,
          2827.36,
          2807.9629999999997,
          2778.788,
          2739.905,
          2691.4829999999997,
          2633.778,
          2567.137,
          2491.979,
          2408.78,
          2318.067,
          2220.394,
          2116.335,
          2006.4660000000001,
          1891.36,
          1771.57,
          1647.631,
          1520.0479999999998,
          1389.297,
          1255.816,
          1120.017,
          982.27,
          842.92,
          702.2739999999999,
          560.613,
          418.191,
          275.23400000000004,
          131.944,
          -11.497,
          -154.92700000000002,
          -298.203,
          -441.19599999999997,
          -583.794,
          -725.8969999999999,
          -867.416,
          -1008.2739999999999,
          -1148.403,
          -1287.743,
          -1426.241,
          -1563.852,
          -1700.537,
          -1836.2620000000002,
          -1970.997,
          -2104.717,
          -2237.4,
          -2369.029,
          -2499.59,
          -2629.0690000000004,
          -2757.458,
          -2884.748,
          -3010.933,
          -3136.01,
          -3259.9770000000003,
          -3382.8309999999997,
          -3504.572,
          -3625.203,
          -3744.724,
          -3863.138,
          -3980.449,
          -4096.661,
          -4211.779,
          -4325.806,
          -4438.751,
          -4550.617,
          -4661.41,
          -4771.139,
          -4879.81,
          -4987.428,
          -5094.002,
          -5199.539000000001,
          -5304.045,
          -5407.529,
          -5509.996999999999,
          -5611.4580000000005,
          -5711.92,
          -5811.388000000001,
          -5909.871,
          -6007.3769999999995,
          -6103.914000000001,
          -6199.486999999999,
          -6294.107,
          -6387.779,
          -6480.5109999999995,
          -6572.309,
          -6663.183000000001,
          -6753.139,
          -6842.184,
          -6930.325,
          -7017.569,
          -7103.923000000001,
          -7189.394,
          -7273.986999999999,
          -7357.7119999999995,
          -7440.573,
          -7522.578,
          -7603.732,
          -7684.043000000001,
          -7763.516,
          -7842.158,
          -7919.973000000001,
          -7996.97,
          -8073.153,
          -8148.529,
          -8223.101999999999,
          -8296.88,
          -8369.866,
          -8442.067,
          -8513.488000000001,
          -8584.136,
          -8654.013,
          -8723.127,
          -8791.481,
          -8859.082,
          -8925.934000000001,
          -8992.041,
          -9057.409,
          -9122.042,
          -9185.946,
          -9249.124,
          -9311.58,
          -9373.32,
          -9434.348,
          -9494.669,
          -9554.285,
          -9613.202,
          -9671.423,
          -9728.953000000001,
          -9785.796,
          -9841.955,
          -9897.435,
          -9952.238000000001,
          -10006.369,
          -10059.832,
          -10112.63,
          -10164.766,
          -10216.245,
          -10267.069,
          -10317.242,
          -10366.767,
          -10415.649,
          -10463.888,
          -10511.49,
          -10558.456,
          -10604.792,
          -10650.498,
          -10695.579,
          -10740.037,
          -10783.875,
          -10827.095,
          -10869.701000000001,
          -10911.696000000002,
          -10953.082,
          -10993.862,
          -11034.038,
          -11073.613000000001,
          -11112.59,
          -11150.971000000001,
          -11188.758999999998,
          -11225.955,
          -11262.563,
          -11298.585,
          -11334.021999999999,
          -11368.878,
          -11403.155,
          -11436.855,
          -11469.979,
          -11502.531,
          -11534.511,
          -11565.923,
          -11596.768,
          -11627.048,
          -11656.766000000001,
          -11685.923,
          -11714.52,
          -11742.561000000002,
          -11770.046,
          -11796.979,
          -11823.358999999999,
          -11849.19,
          -11874.472,
          -11899.208,
          -11923.398000000001,
          -11947.046,
          -11970.153,
          -11992.719,
          -12014.747,
          -12036.238000000001,
          -12057.193000000001,
          -12077.614,
          -12097.503,
          -12116.861,
          -12135.688999999998,
          -12153.988000000001,
          -12171.761,
          -12189.007,
          -12205.729,
          -12221.928999999998,
          -12237.606000000002,
          -12252.763,
          -12267.4,
          -12281.518999999998,
          -12295.121000000001,
          -12308.206,
          -12320.776000000002,
          -12332.833,
          -12344.377,
          -12355.409,
          -12365.93,
          -12375.942,
          -12385.445,
          -12394.438999999998,
          -12402.927,
          -12410.909,
          -12418.386,
          -12425.358999999999,
          -12431.828000000001,
          -12437.795,
          -12443.258999999998,
          -12448.223,
          -12452.687,
          -12456.651000000002,
          -12460.116000000002,
          -12463.083999999999,
          -12465.553999999998,
          -12467.527,
          -12469.003999999999,
          -12469.986,
          -12470.473,
          -12470.466,
          -12469.966,
          -12468.972,
          -12467.486,
          -12465.507,
          -12463.038,
          -12460.077,
          -12456.626,
          -12452.685,
          -12448.253999999999,
          -12443.333999999999,
          -12437.923999999999,
          -12432.027,
          -12425.641000000001,
          -12418.768,
          -12411.407,
          -12403.56,
          -12395.225,
          -12386.403,
          -12377.096000000001,
          -12367.302,
          -12357.023000000001,
          -12346.258,
          -12335.007,
          -12323.271999999999,
          -12311.051000000001,
          -12298.344,
          -12285.153999999999,
          -12271.478000000001,
          -12257.318000000001,
          -12242.673999999999,
          -12227.545,
          -12211.931,
          -12195.833,
          -12179.25,
          -12162.183,
          -12144.631000000001,
          -12126.595,
          -12108.073999999999,
          -12089.069,
          -12069.578000000001,
          -12049.603000000001,
          -12029.143,
          -12008.197,
          -11986.766000000001,
          -11964.85,
          -11942.448,
          -11919.56,
          -11896.186000000002,
          -11872.326000000001,
          -11847.978000000001,
          -11823.143999999998,
          -11797.823,
          -11772.014,
          -11745.716999999999,
          -11718.931999999999,
          -11691.658000000001,
          -11663.896,
          -11635.643,
          -11606.901000000002,
          -11577.669,
          -11547.946000000002,
          -11517.733,
          -11487.027,
          -11455.829,
          -11424.138,
          -11391.954,
          -11359.277,
          -11326.105,
          -11292.438999999998,
          -11258.276000000002,
          -11223.618,
          -11188.462,
          -11152.809,
          -11116.658000000001,
          -11080.008,
          -11042.858999999999,
          -11005.208999999999,
          -10967.058,
          -10928.405,
          -10889.25,
          -10849.591,
          -10809.427,
          -10768.758999999998,
          -10727.585,
          -10685.903,
          -10643.714,
          -10601.016000000001,
          -10557.808,
          -10514.09,
          -10469.86,
          -10425.117,
          -10379.860999999999,
          -10334.089,
          -10287.803,
          -10240.998,
          -10193.676,
          -10145.835,
          -10097.474,
          -10048.591,
          -9999.185,
          -9949.256,
          -9898.802,
          -9847.821,
          -9796.312,
          -9744.275,
          -9691.707,
          -9638.608,
          -9584.976,
          -9530.809000000001,
          -9476.107,
          -9420.868,
          -9365.089,
          -9308.771,
          -9251.912,
          -9194.509,
          -9136.562,
          -9078.068000000001,
          -9019.027,
          -8959.436,
          -8899.295,
          -8838.601,
          -8777.351999999999,
          -8715.548,
          -8653.186,
          -8590.264000000001,
          -8526.780999999999,
          -8462.735999999999,
          -8398.126,
          -8332.949,
          -8267.204,
          -8200.889000000001,
          -8134.001,
          -8066.539000000001,
          -7998.5019999999995,
          -7929.887,
          -7860.691999999999,
          -7790.915,
          -7720.554,
          -7649.607,
          -7578.073,
          -7505.9490000000005,
          -7433.233,
          -7359.923000000001,
          -7286.017,
          -7211.512,
          -7136.406999999999,
          -7060.7,
          -6984.388000000001,
          -6907.47,
          -6829.941999999999,
          -6751.804,
          -6673.052,
          -6593.685,
          -6513.7,
          -6433.096,
          -6351.87,
          -6270.02,
          -6187.544,
          -6104.439,
          -6020.705,
          -5936.338000000001,
          -5851.335999999999,
          -5765.696999999999,
          -5679.42,
          -5592.5019999999995,
          -5504.941999999999,
          -5416.738,
          -5327.887,
          -5238.388,
          -5148.2390000000005,
          -5057.439,
          -4965.986,
          -4873.878,
          -4781.1140000000005,
          -4687.693,
          -4593.6140000000005,
          -4498.875,
          -4403.476,
          -4307.416,
          -4210.694,
          -4113.31,
          -4015.263,
          -3916.555,
          -3817.185,
          -3717.153,
          -3616.461,
          -3515.1090000000004,
          -3413.099,
          -3310.434,
          -3207.115,
          -3103.1440000000002,
          -2998.526,
          -2893.263,
          -2787.361,
          -2680.824,
          -2573.658,
          -2465.869,
          -2357.464,
          -2248.451,
          -2138.84,
          -2028.641,
          -1917.865,
          -1806.525,
          -1694.634,
          -1582.2079999999999,
          -1469.263,
          -1355.82,
          -1241.8980000000001,
          -1127.522,
          -1012.716,
          -897.5089999999999,
          -781.931,
          -666.0169999999999,
          -549.804,
          -433.333,
          -316.65,
          -199.80599999999998,
          -82.855,
          34.141999999999996,
          151.119,
          268.001,
          384.709,
          501.152,
          617.235,
          732.8480000000001,
          847.8739999999999,
          962.183,
          1075.631,
          1188.0639999999999,
          1299.307,
          1409.172,
          1517.4520000000002,
          1623.921,
          1728.3310000000001,
          1830.4129999999998,
          1929.874,
          2026.395,
          2119.632,
          2209.216,
          2294.75,
          2375.813,
          2451.959,
          2522.722,
          2587.618,
          2646.152,
          2697.823,
          2742.133,
          2778.6009999999997,
          2806.7709999999997,
          2826.2259999999997,
          2836.6,
          2837.593,
          2828.985,
          2810.64,
          2782.5190000000002,
          2744.68,
          2697.28,
          2640.57,
          2574.886,
          2500.64,
          2418.303,
          2328.3979999999997,
          2231.475,
          2128.107,
          2018.871,
          1904.338,
          1785.066,
          1661.59,
          1534.418,
          1404.029,
          1270.868,
          1135.343,
          997.835,
          858.686,
          718.211,
          576.692,
          434.384,
          291.517,
          148.295,
          4.904,
          -138.494,
          -281.754,
          -424.745,
          -567.354,
          -709.9630000000001,
          -851.03,
          -991.93,
          -1132.108,
          -1271.504,
          -1410.066,
          -1547.747,
          -1684.506,
          -1820.309,
          -1955.126,
          -2088.933,
          -2221.706,
          -2353.427,
          -2484.083,
          -2613.659,
          -2742.147,
          -2869.5370000000003,
          -2995.825,
          -3121.006,
          -3245.0759999999996,
          -3368.035,
          -3489.883,
          -3610.62,
          -3730.2490000000003,
          -3848.7709999999997,
          -3966.19,
          -4082.51,
          -4197.736,
          -4311.873,
          -4424.925,
          -4536.9,
          -4647.803,
          -4757.64,
          -4866.418,
          -4974.145,
          -5080.827,
          -5186.471,
          -5291.084,
          -5394.675,
          -5497.251,
          -5598.818,
          -5699.385,
          -5798.959,
          -5897.548000000001,
          -5995.159000000001,
          -6091.8,
          -6187.478,
          -6282.201,
          -6375.976,
          -6468.811,
          -6560.713000000001,
          -6651.689,
          -6741.746,
          -6830.892,
          -6919.134,
          -7006.478,
          -7092.932,
          -7178.5019999999995,
          -7263.195,
          -7347.019,
          -7429.978,
          -7512.08,
          -7593.331999999999,
          -7673.74,
          -7753.31,
          -7832.047,
          -7909.9580000000005,
          -7987.0509999999995,
          -8063.329000000001,
          -8138.799,
          -8213.466,
          -8287.337,
          -8360.417,
          -8432.711,
          -8504.226,
          -8574.965,
          -8644.933,
          -8714.139000000001,
          -8782.585,
          -8850.276,
          -8917.218,
          -8983.415,
          -9048.873,
          -9113.596,
          -9177.588,
          -9240.855,
          -9303.399,
          -9365.228000000001,
          -9426.344000000001,
          -9486.751,
          -9546.455,
          -9605.458,
          -9663.766,
          -9721.382,
          -9778.311,
          -9834.555,
          -9890.119,
          -9945.008,
          -9999.224,
          -10052.771,
          -10105.653,
          -10157.873,
          -10209.435,
          -10260.341999999999,
          -10310.599,
          -10360.207,
          -10409.171,
          -10457.493,
          -10505.176000000001,
          -10552.223999999998,
          -10598.641000000001,
          -10644.428,
          -10689.59,
          -10734.128,
          -10778.046,
          -10821.347,
          -10864.033000000001,
          -10906.108,
          -10947.573999999999,
          -10988.433,
          -11028.687,
          -11068.341,
          -11107.396999999999,
          -11145.857,
          -11183.723,
          -11220.997,
          -11257.681999999999,
          -11293.782,
          -11329.296999999999,
          -11364.23,
          -11398.583999999999,
          -11432.36,
          -11465.561000000002,
          -11498.188,
          -11530.245,
          -11561.733,
          -11592.653999999999,
          -11623.011,
          -11652.803999999998,
          -11682.036,
          -11710.708999999999,
          -11738.823999999999,
          -11766.383999999998,
          -11793.391000000001,
          -11819.846000000001,
          -11845.751,
          -11871.108,
          -11895.917,
          -11920.181999999999,
          -11943.903,
          -11967.083,
          -11989.723,
          -12011.823999999999,
          -12033.386999999999,
          -12054.415,
          -12074.909,
          -12094.871000000001,
          -12114.301000000001,
          -12133.201000000001,
          -12151.573,
          -12169.418,
          -12186.736,
          -12203.53,
          -12219.801000000001,
          -12235.55,
          -12250.778,
          -12265.486,
          -12279.676000000001,
          -12293.348,
          -12306.503999999999,
          -12319.146,
          -12331.273000000001,
          -12342.888,
          -12353.99,
          -12364.582,
          -12374.663999999999,
          -12384.236,
          -12393.301000000001,
          -12401.858,
          -12409.91,
          -12417.456,
          -12424.499,
          -12431.037,
          -12437.073,
          -12442.607,
          -12447.639,
          -12452.171999999999,
          -12456.205,
          -12459.739,
          -12462.775,
          -12465.313999999998,
          -12467.355,
          -12468.901000000002,
          -12469.951000000001,
          -12470.506000000001,
          -12470.568000000001,
          -12470.135,
          -12469.208999999999,
          -12467.791000000001,
          -12465.88,
          -12463.478000000001,
          -12460.585,
          -12457.201000000001,
          -12453.327,
          -12448.964,
          -12444.111,
          -12438.768,
          -12432.938,
          -12426.618999999999,
          -12419.813,
          -12412.518999999998,
          -12404.738000000001,
          -12396.47,
          -12387.715,
          -12378.473999999998,
          -12368.747,
          -12358.534,
          -12347.835,
          -12336.651000000002,
          -12324.981000000002,
          -12312.827,
          -12300.187,
          -12287.062,
          -12273.452,
          -12259.358,
          -12244.778999999999,
          -12229.716,
          -12214.168,
          -12198.135,
          -12181.618,
          -12164.616000000002,
          -12147.13,
          -12129.159,
          -12110.703000000001,
          -12091.763,
          -12072.338,
          -12052.428,
          -12032.033000000001,
          -12011.153,
          -11989.787,
          -11967.935,
          -11945.598,
          -11922.776000000002,
          -11899.466,
          -11875.671,
          -11851.388,
          -11826.618,
          -11801.362,
          -11775.617,
          -11749.385,
          -11722.665,
          -11695.456,
          -11667.757,
          -11639.57,
          -11610.892,
          -11581.723999999998,
          -11552.066,
          -11521.916000000001,
          -11491.275,
          -11460.142,
          -11428.516000000001,
          -11396.396,
          -11363.783000000001,
          -11330.675,
          -11297.072,
          -11262.973999999998,
          -11228.378999999999,
          -11193.288,
          -11157.7,
          -11121.612,
          -11085.026000000002,
          -11047.94,
          -11010.355,
          -10972.268,
          -10933.678999999998,
          -10894.588,
          -10854.992,
          -10814.893,
          -10774.288,
          -10733.177,
          -10691.56,
          -10649.434,
          -10606.8,
          -10563.656,
          -10520.001,
          -10475.835,
          -10431.155999999999,
          -10385.963,
          -10340.256,
          -10294.033000000001,
          -10247.293,
          -10200.034,
          -10152.256,
          -10103.959,
          -10055.14,
          -10005.798,
          -9955.933,
          -9905.542,
          -9854.625,
          -9803.18,
          -9751.206,
          -9698.702,
          -9645.667,
          -9592.098,
          -9537.996,
          -9483.357,
          -9428.181999999999,
          -9372.466999999999,
          -9316.212,
          -9259.417,
          -9202.078000000001,
          -9144.195,
          -9085.765,
          -9026.788,
          -8967.261,
          -8907.183,
          -8846.553,
          -8785.368,
          -8723.628,
          -8661.33,
          -8598.472,
          -8535.053,
          -8471.072,
          -8406.526,
          -8341.413,
          -8275.732,
          -8209.48,
          -8142.656,
          -8075.259,
          -8007.286,
          -7938.735,
          -7869.604,
          -7799.891,
          -7729.594,
          -7658.710999999999,
          -7587.241,
          -7515.181,
          -7442.529,
          -7369.283,
          -7295.441,
          -7221.001,
          -7145.96,
          -7070.316999999999,
          -6994.069,
          -6917.215,
          -6839.7519999999995,
          -6761.677,
          -6682.9890000000005,
          -6603.686,
          -6523.766,
          -6443.226,
          -6362.064,
          -6280.278,
          -6197.865,
          -6114.825,
          -6031.154,
          -5946.851,
          -5861.9130000000005,
          -5776.338000000001,
          -5690.124,
          -5603.27,
          -5515.774,
          -5427.632,
          -5338.845,
          -5249.408,
          -5159.323,
          -5068.585,
          -4977.195,
          -4885.15,
          -4792.448,
          -4699.09,
          -4605.072,
          -4510.394,
          -4415.057,
          -4319.058,
          -4222.397,
          -4125.073,
          -4027.087,
          -3928.438,
          -3829.127,
          -3729.1540000000005,
          -3628.52,
          -3527.2259999999997,
          -3425.2729999999997,
          -3322.665,
          -3219.401,
          -3115.486,
          -3010.922,
          -2905.712,
          -2799.863,
          -2693.3779999999997,
          -2586.262,
          -2478.522,
          -2370.165,
          -2261.199,
          -2151.634,
          -2041.4779999999998,
          -1930.744,
          -1819.444,
          -1707.5910000000001,
          -1595.2,
          -1482.289,
          -1368.876,
          -1254.983,
          -1140.631,
          -1025.847,
          -910.6569999999999,
          -795.0939999999999,
          -679.189,
          -562.981,
          -446.51099999999997,
          -329.82300000000004,
          -212.967,
          -95.99799999999999,
          21.024,
          138.034,
          254.958,
          371.716,
          488.22,
          604.375,
          720.072,
          835.196,
          949.617,
          1063.193,
          1175.77,
          1287.178,
          1397.227,
          1505.714,
          1612.4160000000002,
          1717.086,
          1819.457,
          1919.2379999999998,
          2016.1129999999998,
          2109.742,
          2199.757,
          2285.765,
          2367.346,
          2444.058,
          2515.437,
          2580.999,
          2640.25,
          2692.69,
          2737.821,
          2775.159,
          2804.245,
          2824.658,
          2836.025,
          2838.0409999999997,
          2830.4759999999997,
          2813.185,
          2786.118,
          2749.325,
          2702.952,
          2647.241,
          2582.52,
          2509.192,
          2427.724,
          2338.632,
          2242.467,
          2139.7960000000003,
          2031.1979999999999,
          1917.245,
          1798.496,
          1675.489,
          1548.735,
          1418.713,
          1285.873,
          1150.629,
          1013.362,
          874.42,
          734.117,
          592.742,
          450.551,
          307.777,
          164.627,
          21.285999999999998,
          -122.07799999999999,
          -265.32,
          -408.30800000000005,
          -550.927,
          -693.073,
          -834.655,
          -975.595,
          -1115.822,
          -1255.274,
          -1393.898,
          -1531.6470000000002,
          -1668.48,
          -1804.361,
          -1939.261,
          -2073.153,
          -2206.015,
          -2337.8289999999997,
          -2468.5789999999997,
          -2598.252,
          -2726.837,
          -2854.328,
          -2980.718,
          -3106.002,
          -3230.176,
          -3353.241,
          -3475.195,
          -3596.038,
          -3715.7729999999997,
          -3834.403,
          -3951.9309999999996,
          -4068.3590000000004,
          -4183.693,
          -4297.938,
          -4411.099,
          -4523.181,
          -4634.193,
          -4744.139,
          -4853.025,
          -4960.859,
          -5067.649,
          -5173.401,
          -5278.121999999999,
          -5381.819,
          -5484.5019999999995,
          -5586.1759999999995,
          -5686.848000000001,
          -5786.528,
          -5885.222,
          -5982.938,
          -6079.684,
          -6175.465999999999,
          -6270.2919999999995,
          -6364.170999999999,
          -6457.109,
          -6549.111999999999,
          -6640.19,
          -6730.35,
          -6819.597,
          -6907.939,
          -6995.383000000001,
          -7081.937,
          -7167.607,
          -7252.4,
          -7336.321,
          -7419.379,
          -7501.579000000001,
          -7582.928000000001,
          -7663.433000000001,
          -7743.098000000001,
          -7821.932,
          -7899.94,
          -7977.1269999999995,
          -8053.5,
          -8129.065,
          -8203.826,
          -8277.791,
          -8350.964,
          -8423.351,
          -8494.957,
          -8565.789,
          -8635.85,
          -8705.146999999999,
          -8773.684000000001,
          -8841.465,
          -8908.498,
          -8974.785,
          -9040.333,
          -9105.145,
          -9169.226999999999,
          -9232.581,
          -9295.215,
          -9357.131,
          -9418.335,
          -9478.83,
          -9538.62,
          -9597.71,
          -9656.104,
          -9713.806999999999,
          -9770.821,
          -9827.152,
          -9882.801,
          -9937.774,
          -9992.075,
          -10045.706,
          -10098.671999999999,
          -10150.976999999999,
          -10202.622,
          -10253.612,
          -10303.951,
          -10353.642,
          -10402.688,
          -10451.093,
          -10498.858,
          -10545.988000000001,
          -10592.486,
          -10638.355,
          -10683.597,
          -10728.216999999999,
          -10772.215,
          -10815.597,
          -10858.363000000001,
          -10900.517,
          -10942.062,
          -10983,
          -11023.335,
          -11063.068000000001,
          -11102.202,
          -11140.74,
          -11178.684,
          -11216.037,
          -11252.8,
          -11288.976999999999,
          -11324.57,
          -11359.581,
          -11394.011,
          -11427.864,
          -11461.142,
          -11493.846000000001,
          -11525.979,
          -11557.544,
          -11588.54,
          -11618.972,
          -11648.84,
          -11678.148000000001,
          -11706.896,
          -11735.087,
          -11762.722,
          -11789.803,
          -11816.333,
          -11842.312,
          -11867.743,
          -11892.627,
          -11916.966,
          -11940.761,
          -11964.015,
          -11986.726999999999,
          -12008.901000000002,
          -12030.538,
          -12051.64,
          -12072.207,
          -12092.241000000002,
          -12111.743999999999,
          -12130.716,
          -12149.16,
          -12167.077,
          -12184.466999999999,
          -12201.333999999999,
          -12217.676000000001,
          -12233.497,
          -12248.796,
          -12263.576000000001,
          -12277.837,
          -12291.581,
          -12304.808,
          -12317.52,
          -12329.718,
          -12341.403,
          -12352.576000000001,
          -12363.238000000001,
          -12373.39,
          -12383.033000000001,
          -12392.168,
          -12400.795,
          -12408.917,
          -12416.533000000001,
          -12423.645,
          -12430.253,
          -12436.358,
          -12441.961000000001,
          -12447.063,
          -12451.665,
          -12455.767,
          -12459.37,
          -12462.475,
          -12465.083,
          -12467.193000000001,
          -12468.806999999999,
          -12469.925,
          -12470.548999999999,
          -12470.678999999998,
          -12470.313999999998,
          -12469.457,
          -12468.106000000002,
          -12466.263,
          -12463.928999999998,
          -12461.104,
          -12457.788,
          -12453.981000000002,
          -12449.685,
          -12444.9,
          -12439.625,
          -12433.862,
          -12427.611,
          -12420.871000000001,
          -12413.643999999998,
          -12405.93,
          -12397.729,
          -12389.041000000001,
          -12379.867,
          -12370.207,
          -12360.06,
          -12349.427,
          -12338.31,
          -12326.707,
          -12314.618,
          -12302.045,
          -12288.986,
          -12275.443000000001,
          -12261.413999999999,
          -12246.902,
          -12231.903999999999,
          -12216.421999999999,
          -12200.456,
          -12184.003999999999,
          -12167.069,
          -12149.648000000001,
          -12131.743,
          -12113.353000000001,
          -12094.478000000001,
          -12075.118,
          -12055.274,
          -12034.944,
          -12014.128999999999,
          -11992.829,
          -11971.043,
          -11948.771,
          -11926.013,
          -11902.768999999998,
          -11879.038,
          -11854.821000000002,
          -11830.117,
          -11804.925,
          -11779.246000000001,
          -11753.079,
          -11726.423,
          -11699.278,
          -11671.645,
          -11643.521999999999,
          -11614.909,
          -11585.806,
          -11556.213,
          -11526.127,
          -11495.55,
          -11464.481000000002,
          -11432.92,
          -11400.865,
          -11368.316,
          -11335.273000000001,
          -11301.735,
          -11267.701000000001,
          -11233.17,
          -11198.143,
          -11162.618999999999,
          -11126.596000000001,
          -11090.075,
          -11053.053999999998,
          -11015.532,
          -10977.51,
          -10938.985,
          -10899.957,
          -10860.426000000001,
          -10820.391000000001,
          -10779.851,
          -10738.803999999998,
          -10697.251,
          -10655.188999999998,
          -10612.618999999999,
          -10569.538999999999,
          -10525.948999999999,
          -10481.847,
          -10437.232,
          -10392.103000000001,
          -10346.46,
          -10300.301,
          -10253.625,
          -10206.43,
          -10158.716999999999,
          -10110.483,
          -10061.728000000001,
          -10012.451,
          -9962.649,
          -9912.322,
          -9861.469000000001,
          -9810.088,
          -9758.179,
          -9705.739,
          -9652.768,
          -9599.263,
          -9545.225,
          -9490.65,
          -9435.538,
          -9379.888,
          -9323.698,
          -9266.966999999999,
          -9209.692,
          -9151.873,
          -9093.508,
          -9034.594000000001,
          -8975.131,
          -8915.118,
          -8854.552,
          -8793.431999999999,
          -8731.756,
          -8669.521999999999,
          -8606.728000000001,
          -8543.374,
          -8479.457,
          -8414.975,
          -8349.926,
          -8284.31,
          -8218.123,
          -8151.3640000000005,
          -8084.03,
          -8016.121,
          -7947.634,
          -7878.568,
          -7808.919,
          -7738.687,
          -7667.869000000001,
          -7596.463000000001,
          -7524.467,
          -7451.88,
          -7378.698,
          -7304.920999999999,
          -7230.545,
          -7155.568,
          -7079.99,
          -7003.806,
          -6927.017,
          -6849.618,
          -6771.608,
          -6692.985,
          -6613.746999999999,
          -6533.89,
          -6453.414000000001,
          -6372.316999999999,
          -6290.595,
          -6208.246999999999,
          -6125.271,
          -6041.664000000001,
          -5957.424,
          -5872.55,
          -5787.04,
          -5700.89,
          -5614.1,
          -5526.6669999999995,
          -5438.589,
          -5349.865,
          -5260.493,
          -5170.47,
          -5079.795999999999,
          -4988.468,
          -4896.485,
          -4803.846,
          -4710.55,
          -4616.595,
          -4521.979,
          -4426.7029999999995,
          -4330.765,
          -4234.165,
          -4136.902,
          -4038.9770000000003,
          -3940.388,
          -3841.137,
          -3741.222,
          -3640.647,
          -3539.4109999999996,
          -3437.5159999999996,
          -3334.9640000000004,
          -3231.756,
          -3127.8959999999997,
          -3023.386,
          -2918.2309999999998,
          -2812.434,
          -2706.0009999999997,
          -2598.936,
          -2491.246,
          -2382.937,
          -2274.018,
          -2164.498,
          -2054.386,
          -1943.694,
          -1832.433,
          -1720.618,
          -1608.263,
          -1495.386,
          -1382.004,
          -1268.139,
          -1153.812,
          -1039.05,
          -923.878,
          -808.329,
          -692.434,
          -576.231,
          -459.76099999999997,
          -343.06800000000004,
          -226.201,
          -109.214,
          7.832999999999999,
          124.875,
          241.84,
          358.649,
          475.214,
          591.439,
          707.22,
          822.44,
          936.9730000000001,
          1050.677,
          1163.3980000000001,
          1274.969,
          1385.203,
          1493.8970000000002,
          1600.83,
          1705.7579999999998,
          1808.4160000000002,
          1908.515,
          2005.743,
          2099.762,
          2190.205,
          2276.6839999999997,
          2358.78,
          2436.055,
          2508.044,
          2574.268,
          2634.2329999999997,
          2687.438,
          2733.386,
          2771.591,
          2801.59,
          2822.9570000000003,
          2835.316,
          2838.353,
          2831.829,
          2815.592,
          2789.5809999999997,
          2753.835,
          2708.493,
          2653.783,
          2590.027,
          2517.6220000000003,
          2437.027,
          2348.755,
          2253.351,
          2151.383,
          2043.43,
          1930.0620000000001,
          1811.842,
          1689.307,
          1562.974,
          1433.325,
          1300.8110000000001,
          1165.8519999999999,
          1028.829,
          890.096,
          749.97,
          608.741,
          466.66900000000004,
          323.99,
          180.91299999999998,
          37.626,
          -105.704,
          -248.926,
          -391.91,
          -534.536,
          -676.702,
          -818.315,
          -959.294,
          -1099.568,
          -1239.076,
          -1377.7620000000002,
          -1515.578,
          -1652.484,
          -1788.442,
          -1923.4229999999998,
          -2057.401,
          -2190.351,
          -2322.256,
          -2453.1,
          -2582.87,
          -2711.553,
          -2839.1440000000002,
          -2965.635,
          -3091.022,
          -3215.3,
          -3338.469,
          -3460.528,
          -3581.478,
          -3701.32,
          -3820.0570000000002,
          -3937.692,
          -4054.228,
          -4169.67,
          -4284.023,
          -4397.293,
          -4509.483,
          -4620.603,
          -4730.656,
          -4839.651,
          -4947.593,
          -5054.49,
          -5160.349,
          -5265.177,
          -5368.981,
          -5471.77,
          -5573.55,
          -5674.328,
          -5774.113,
          -5872.911999999999,
          -5970.733,
          -6067.5830000000005,
          -6163.469,
          -6258.399,
          -6352.38,
          -6445.420999999999,
          -6537.526999999999,
          -6628.706999999999,
          -6718.967,
          -6808.315,
          -6896.758000000001,
          -6984.302,
          -7070.956,
          -7156.725,
          -7241.616999999999,
          -7325.637,
          -7408.7919999999995,
          -7491.09,
          -7572.536999999999,
          -7653.138000000001,
          -7732.9,
          -7811.829000000001,
          -7889.933000000001,
          -7967.215,
          -8043.683000000001,
          -8119.342,
          -8194.197,
          -8268.255,
          -8341.521999999999,
          -8414.002,
          -8485.701,
          -8556.624,
          -8626.777,
          -8696.165,
          -8764.793,
          -8832.665,
          -8899.788,
          -8966.166,
          -9031.803,
          -9096.702,
          -9160.873,
          -9224.315999999999,
          -9287.038,
          -9349.042,
          -9410.333,
          -9470.915,
          -9530.793,
          -9589.97,
          -9648.45,
          -9706.238000000001,
          -9763.339,
          -9819.754,
          -9875.489,
          -9930.548,
          -9984.933,
          -10038.648000000001,
          -10091.698,
          -10144.086,
          -10195.815,
          -10246.889000000001,
          -10297.312,
          -10347.085,
          -10396.213,
          -10444.699,
          -10492.546999999999,
          -10539.758999999998,
          -10586.339,
          -10632.288999999999,
          -10677.612,
          -10722.312,
          -10766.391000000001,
          -10809.851999999999,
          -10852.698,
          -10894.933,
          -10936.558,
          -10977.575,
          -11017.989,
          -11057.801000000001,
          -11097.014,
          -11135.63,
          -11173.652,
          -11211.083,
          -11247.925,
          -11284.18,
          -11319.85,
          -11354.938,
          -11389.445,
          -11423.375,
          -11456.73,
          -11489.511,
          -11521.72,
          -11553.361,
          -11584.433,
          -11614.941,
          -11644.886,
          -11674.268,
          -11703.091999999999,
          -11731.358,
          -11759.068000000001,
          -11786.223999999998,
          -11812.829,
          -11838.882,
          -11864.386999999999,
          -11889.345,
          -11913.758,
          -11937.627,
          -11960.954,
          -11983.741000000002,
          -12005.989,
          -12027.698999999999,
          -12048.873,
          -12069.513,
          -12089.62,
          -12109.195,
          -12128.241000000002,
          -12146.757,
          -12164.746000000001,
          -12182.208999999999,
          -12199.148000000001,
          -12215.562,
          -12231.454,
          -12246.825,
          -12261.676000000001,
          -12276.008999999998,
          -12289.823999999999,
          -12303.122,
          -12315.906,
          -12328.175,
          -12339.93,
          -12351.173999999999,
          -12361.906,
          -12372.128999999999,
          -12381.841999999999,
          -12391.046999999999,
          -12399.745,
          -12407.937,
          -12415.623,
          -12422.803999999998,
          -12429.482,
          -12435.656,
          -12441.329,
          -12446.501,
          -12451.171999999999,
          -12455.343,
          -12459.016000000001,
          -12462.188999999998,
          -12464.866000000002,
          -12467.045,
          -12468.726999999999,
          -12469.915,
          -12470.607,
          -12470.805,
          -12470.508999999998,
          -12469.719,
          -12468.437,
          -12466.662,
          -12464.396,
          -12461.639,
          -12458.391000000001,
          -12454.652,
          -12450.423999999999,
          -12445.706,
          -12440.499,
          -12434.803999999998,
          -12428.618999999999,
          -12421.947,
          -12414.787,
          -12407.14,
          -12399.006000000001,
          -12390.386,
          -12381.278999999999,
          -12371.685,
          -12361.606000000002,
          -12351.04,
          -12339.989,
          -12328.452,
          -12316.43,
          -12303.923,
          -12290.931,
          -12277.455,
          -12263.493,
          -12249.046,
          -12234.115,
          -12218.698999999999,
          -12202.798999999999,
          -12186.413,
          -12169.543,
          -12152.188999999998,
          -12134.35,
          -12116.026000000002,
          -12097.216999999999,
          -12077.923,
          -12058.143999999998,
          -12037.88,
          -12017.131000000001,
          -11995.896,
          -11974.175,
          -11951.969,
          -11929.277,
          -11906.098,
          -11882.433,
          -11858.281,
          -11833.642,
          -11808.515,
          -11782.901000000002,
          -11756.798999999999,
          -11730.208,
          -11703.128999999999,
          -11675.561000000002,
          -11647.503,
          -11618.955,
          -11589.917,
          -11560.389,
          -11530.368,
          -11499.856000000002,
          -11468.851999999999,
          -11437.355,
          -11405.365,
          -11372.881000000001,
          -11339.903,
          -11306.428999999998,
          -11272.46,
          -11237.993999999999,
          -11203.032,
          -11167.572,
          -11131.614,
          -11095.157,
          -11058.201000000001,
          -11020.743999999999,
          -10982.786,
          -10944.325,
          -10905.362,
          -10865.896,
          -10825.925,
          -10785.448999999999,
          -10744.466999999999,
          -10702.979,
          -10660.982,
          -10618.476,
          -10575.461000000001,
          -10531.935,
          -10487.896,
          -10443.346,
          -10398.282,
          -10352.703000000001,
          -10306.608,
          -10259.997,
          -10212.867,
          -10165.218,
          -10117.049,
          -10068.358,
          -10019.144,
          -9969.407,
          -9919.145,
          -9868.357,
          -9817.04,
          -9765.195,
          -9712.82,
          -9659.913,
          -9606.473,
          -9552.498,
          -9497.988000000001,
          -9442.942,
          -9387.356,
          -9331.23,
          -9274.563,
          -9217.353000000001,
          -9159.598,
          -9101.296999999999,
          -9042.448,
          -8983.05,
          -8923.101999999999,
          -8862.6,
          -8801.544,
          -8739.933,
          -8677.763,
          -8615.034,
          -8551.745,
          -8487.892,
          -8423.475,
          -8358.491,
          -8292.939,
          -8226.817,
          -8160.121999999999,
          -8092.854,
          -8025.01,
          -7956.588000000001,
          -7887.585999999999,
          -7818.0019999999995,
          -7747.835,
          -7677.081999999999,
          -7605.74,
          -7533.809,
          -7461.286999999999,
          -7388.17,
          -7314.456999999999,
          -7240.146,
          -7165.235,
          -7089.721,
          -7013.602,
          -6936.8769999999995,
          -6859.543000000001,
          -6781.598000000001,
          -6703.04,
          -6623.866,
          -6544.075,
          -6463.664000000001,
          -6382.63,
          -6300.973000000001,
          -6218.69,
          -6135.778,
          -6052.236,
          -5968.061,
          -5883.251,
          -5797.805,
          -5711.719,
          -5624.993,
          -5537.624,
          -5449.611,
          -5360.95,
          -5271.641,
          -5181.682,
          -5091.071,
          -4999.807,
          -4907.887,
          -4815.311,
          -4722.0779999999995,
          -4628.184,
          -4533.630999999999,
          -4438.417,
          -4342.541,
          -4246.002,
          -4148.8,
          -4050.935,
          -3952.406,
          -3853.2140000000004,
          -3753.36,
          -3652.843,
          -3551.665,
          -3449.828,
          -3347.333,
          -3244.1820000000002,
          -3140.377,
          -3035.922,
          -2930.821,
          -2825.077,
          -2718.696,
          -2611.681,
          -2504.041,
          -2395.781,
          -2286.908,
          -2177.4339999999997,
          -2067.366,
          -1956.7160000000001,
          -1845.496,
          -1733.72,
          -1621.401,
          -1508.557,
          -1395.2060000000001,
          -1281.369,
          -1167.068,
          -1052.327,
          -937.174,
          -821.6389999999999,
          -705.755,
          -589.558,
          -473.088,
          -356.39,
          -239.512,
          -122.508,
          -5.437,
          111.63799999999999,
          228.643,
          345.50199999999995,
          462.12699999999995,
          578.424,
          694.288,
          809.605,
          924.247,
          1038.077,
          1150.942,
          1262.6760000000002,
          1373.0929999999998,
          1481.9920000000002,
          1589.155,
          1694.339,
          1797.2820000000002,
          1897.6979999999999,
          1995.277,
          2089.6820000000002,
          2180.551,
          2267.498,
          2350.107,
          2427.9410000000003,
          2500.5389999999998,
          2567.422,
          2628.097,
          2682.065,
          2728.827,
          2767.8959999999997,
          2798.805,
          2821.125,
          2834.473,
          2838.5290000000005,
          2833.047,
          2817.864,
          2792.91,
          2758.215,
          2713.9040000000005,
          2660.202,
          2597.416,
          2525.939,
          2446.223,
          2358.775,
          2264.139,
          2162.881,
          2055.577,
          1942.8010000000002,
          1825.114,
          1703.059,
          1577.152,
          1447.88,
          1315.6970000000001,
          1181.026,
          1044.251,
          905.73,
          765.784,
          624.7040000000001,
          482.754,
          340.17199999999997,
          197.17,
          53.938,
          -89.355,
          -232.55700000000002,
          -375.534,
          -518.1669999999999,
          -660.202,
          -801.993,
          -943.0110000000001,
          -1083.3319999999999,
          -1222.894,
          -1361.641,
          -1499.524,
          -1636.5020000000002,
          -1772.537,
          -1907.6,
          -2041.662,
          -2174.701,
          -2306.697,
          -2437.634,
          -2567.499,
          -2696.281,
          -2823.972,
          -2950.563,
          -3076.052,
          -3200.434,
          -3323.708,
          -3445.8720000000003,
          -3566.927,
          -3686.8759999999997,
          -3805.72,
          -3923.462,
          -4040.1059999999998,
          -4155.656,
          -4270.117,
          -4383.4929999999995,
          -4495.793,
          -4607.02,
          -4717.182,
          -4826.284000000001,
          -4934.333,
          -5041.338,
          -5147.304,
          -5252.2390000000005,
          -5356.15,
          -5459.044,
          -5560.93,
          -5661.815,
          -5761.705,
          -5860.609,
          -5958.534000000001,
          -6055.488,
          -6151.478,
          -6246.5109999999995,
          -6340.595,
          -6433.738,
          -6525.946999999999,
          -6617.228,
          -6707.59,
          -6797.039000000001,
          -6885.581999999999,
          -6973.227,
          -7059.98,
          -7145.848000000001,
          -7230.838000000001,
          -7314.956,
          -7398.21,
          -7480.606,
          -7562.149,
          -7642.846,
          -7722.705,
          -7801.731,
          -7879.93,
          -7957.307,
          -8033.869000000001,
          -8109.621999999999,
          -8184.571999999999,
          -8258.724,
          -8332.083,
          -8404.655999999999,
          -8476.447,
          -8547.463,
          -8617.707,
          -8687.187,
          -8755.905999999999,
          -8823.869,
          -8891.082,
          -8957.549,
          -9023.276,
          -9088.266,
          -9152.525,
          -9216.058,
          -9278.868,
          -9340.96,
          -9402.338,
          -9463.008,
          -9522.972,
          -9582.235999999999,
          -9640.803,
          -9698.677,
          -9755.863000000001,
          -9812.364,
          -9868.184000000001,
          -9923.327,
          -9977.796999999999,
          -10031.597,
          -10084.731,
          -10137.202,
          -10189.015,
          -10240.171999999999,
          -10290.678,
          -10340.534,
          -10389.745,
          -10438.313,
          -10486.242,
          -10533.536,
          -10580.197,
          -10626.228000000001,
          -10671.633,
          -10716.413999999999,
          -10760.573,
          -10804.114,
          -10847.041000000001,
          -10889.355,
          -10931.059,
          -10972.157,
          -11012.65,
          -11052.541000000001,
          -11091.832,
          -11130.527,
          -11168.628,
          -11206.136999999999,
          -11243.056,
          -11279.389,
          -11315.136999999999,
          -11350.302,
          -11384.886999999999,
          -11418.893999999998,
          -11452.325,
          -11485.181999999999,
          -11517.469,
          -11549.185,
          -11580.333999999999,
          -11610.917,
          -11640.938,
          -11670.396,
          -11699.295,
          -11727.636,
          -11755.421999999999,
          -11782.653,
          -11809.332,
          -11835.46,
          -11861.038999999999,
          -11886.072,
          -11910.559,
          -11934.502,
          -11957.903,
          -11980.763,
          -12003.085,
          -12024.868,
          -12046.116000000002,
          -12066.828000000001,
          -12087.008,
          -12106.657,
          -12125.775,
          -12144.364,
          -12162.425,
          -12179.961000000001,
          -12196.971000000001,
          -12213.457,
          -12229.421,
          -12244.864,
          -12259.787,
          -12274.191,
          -12288.078000000001,
          -12301.448,
          -12314.302,
          -12326.642,
          -12338.469,
          -12349.783000000001,
          -12360.586000000001,
          -12370.878999999999,
          -12380.663,
          -12389.938999999998,
          -12398.707,
          -12406.969,
          -12414.725,
          -12421.976,
          -12428.723999999998,
          -12434.968,
          -12440.711000000001,
          -12445.952,
          -12450.692,
          -12454.933,
          -12458.675,
          -12461.918,
          -12464.663,
          -12466.911,
          -12468.663,
          -12469.919,
          -12470.68,
          -12470.946000000002,
          -12470.719,
          -12469.998,
          -12468.784,
          -12467.078000000001,
          -12464.88,
          -12462.191,
          -12459.011,
          -12455.34,
          -12451.18,
          -12446.53,
          -12441.391000000001,
          -12435.763,
          -12429.646,
          -12423.042,
          -12415.948999999999,
          -12408.37,
          -12400.303,
          -12391.75,
          -12382.71,
          -12373.184,
          -12363.171,
          -12352.673,
          -12341.688999999998,
          -12330.219,
          -12318.264,
          -12305.823999999999,
          -12292.898000000001,
          -12279.488000000001,
          -12265.593,
          -12251.213,
          -12236.348999999998,
          -12220.999,
          -12205.165,
          -12188.846000000001,
          -12172.042,
          -12154.753999999999,
          -12136.981000000002,
          -12118.723,
          -12099.98,
          -12080.753,
          -12061.04,
          -12040.841999999999,
          -12020.158000000001,
          -11998.989,
          -11977.333999999999,
          -11955.194,
          -11932.567,
          -11909.454,
          -11885.855,
          -11861.768,
          -11837.195,
          -11812.133999999998,
          -11786.585,
          -11760.548,
          -11734.023000000001,
          -11707.008999999998,
          -11679.507,
          -11651.514,
          -11623.032,
          -11594.059,
          -11564.596000000001,
          -11534.641000000001,
          -11504.194,
          -11473.253999999999,
          -11441.823,
          -11409.898000000001,
          -11377.479,
          -11344.566,
          -11311.157,
          -11277.253,
          -11242.853000000001,
          -11207.956,
          -11172.561000000002,
          -11136.667,
          -11100.275,
          -11063.383999999998,
          -11025.992,
          -10988.098,
          -10949.703000000001,
          -10910.805,
          -10871.403999999999,
          -10831.498,
          -10791.086000000001,
          -10750.169,
          -10708.745,
          -10666.813,
          -10624.372,
          -10581.421999999999,
          -10537.961000000001,
          -10493.988000000001,
          -10449.502,
          -10404.502,
          -10358.988000000001,
          -10312.958,
          -10266.411,
          -10219.346,
          -10171.761999999999,
          -10123.658000000001,
          -10075.032,
          -10025.883,
          -9976.211,
          -9926.013,
          -9875.289,
          -9824.038,
          -9772.257,
          -9719.947,
          -9667.105,
          -9613.73,
          -9559.82,
          -9505.375,
          -9450.392,
          -9394.872,
          -9338.811,
          -9282.209,
          -9225.063,
          -9167.374,
          -9109.138,
          -9050.354,
          -8991.02,
          -8931.136,
          -8870.7,
          -8809.709,
          -8748.163,
          -8686.058,
          -8623.394,
          -8560.169,
          -8496.382,
          -8432.03,
          -8367.110999999999,
          -8301.624,
          -8235.567,
          -8168.938,
          -8101.734,
          -8033.955,
          -7965.598000000001,
          -7896.661,
          -7827.143,
          -7757.04,
          -7686.352,
          -7615.076999999999,
          -7543.210999999999,
          -7470.753000000001,
          -7397.701,
          -7324.054,
          -7249.808000000001,
          -7174.9619999999995,
          -7099.513000000001,
          -7023.46,
          -6946.8,
          -6869.531,
          -6791.651,
          -6713.156999999999,
          -6634.049,
          -6554.323,
          -6473.977,
          -6393.009,
          -6311.4169999999995,
          -6229.198,
          -6146.351,
          -6062.874,
          -5978.764,
          -5894.019,
          -5808.637,
          -5722.616,
          -5635.954000000001,
          -5548.649,
          -5460.7,
          -5372.104,
          -5282.86,
          -5192.965,
          -5102.417,
          -5011.215999999999,
          -4919.36,
          -4826.847,
          -4733.6759999999995,
          -4639.846,
          -4545.356,
          -4450.204000000001,
          -4354.39,
          -4257.912,
          -4160.771,
          -4062.967,
          -3964.4990000000003,
          -3865.367,
          -3765.573,
          -3665.115,
          -3563.9959999999996,
          -3462.216,
          -3359.778,
          -3256.684,
          -3152.935,
          -3048.5359999999996,
          -2943.489,
          -2837.798,
          -2731.468,
          -2624.505,
          -2516.9139999999998,
          -2408.703,
          -2299.879,
          -2190.45,
          -2080.427,
          -1969.819,
          -1858.639,
          -1746.901,
          -1634.619,
          -1521.809,
          -1408.49,
          -1294.681,
          -1180.406,
          -1065.687,
          -950.553,
          -835.0319999999999,
          -719.158,
          -602.966,
          -486.49800000000005,
          -369.795,
          -252.907,
          -135.885,
          -18.79,
          98.316,
          215.362,
          332.27,
          448.955,
          565.322,
          681.268,
          796.68,
          911.433,
          1025.389,
          1138.397,
          1250.2910000000002,
          1360.89,
          1469.994,
          1577.385,
          1682.8239999999998,
          1786.0510000000002,
          1886.781,
          1984.7079999999999,
          2079.499,
          2170.7929999999997,
          2258.205,
          2341.324,
          2419.715,
          2492.9179999999997,
          2560.4570000000003,
          2621.8390000000004,
          2676.567,
          2724.14,
          2764.07,
          2795.887,
          2819.158,
          2833.495,
          2838.57,
          2834.13,
          2820.002,
          2796.1079999999997,
          2762.466,
          2719.192,
          2666.4990000000003,
          2604.69,
          2534.145,
          2455.314,
          2368.698,
          2274.8360000000002,
          2174.294,
          2067.647,
          1955.4679999999998,
          1838.3210000000001,
          1716.75,
          1591.274,
          1462.3829999999998,
          1330.537,
          1196.156,
          1059.635,
          921.329,
          781.565,
          640.637,
          498.81300000000005,
          356.33,
          213.405,
          70.23,
          -73.024,
          -216.204,
          -359.17400000000004,
          -501.81300000000005,
          -644.015,
          -785.685,
          -926.74,
          -1067.108,
          -1206.723,
          -1345.53,
          -1483.479,
          -1620.529,
          -1756.641,
          -1891.7839999999999,
          -2025.93,
          -2159.0570000000002,
          -2291.144,
          -2422.175,
          -2552.135,
          -2681.014,
          -2808.804,
          -2935.4970000000003,
          -3061.0879999999997,
          -3185.573,
          -3308.95,
          -3431.22,
          -3552.382,
          -3672.437,
          -3791.387,
          -3909.237,
          -4025.988,
          -4141.645,
          -4256.214,
          -4369.6990000000005,
          -4482.107,
          -4593.441,
          -4703.71,
          -4812.92,
          -4921.0779999999995,
          -5028.189,
          -5134.262,
          -5239.304,
          -5343.321999999999,
          -5446.323,
          -5548.314,
          -5649.304,
          -5749.299,
          -5848.308000000001,
          -5946.338000000001,
          -6043.396,
          -6139.4890000000005,
          -6234.626,
          -6328.813,
          -6422.059,
          -6514.369000000001,
          -6605.7519999999995,
          -6696.215,
          -6785.765,
          -6874.409000000001,
          -6962.154,
          -7049.005999999999,
          -7134.973000000001,
          -7220.062,
          -7304.279,
          -7387.630999999999,
          -7470.1230000000005,
          -7551.763000000001,
          -7632.558000000001,
          -7712.513000000001,
          -7791.635,
          -7869.929,
          -7947.401,
          -8024.058000000001,
          -8099.906,
          -8174.9490000000005,
          -8249.195,
          -8322.646999999999,
          -8395.312,
          -8467.196,
          -8538.304,
          -8608.641,
          -8678.211,
          -8747.021,
          -8815.075,
          -8882.378,
          -8948.935,
          -9014.751,
          -9079.831,
          -9144.179,
          -9207.8,
          -9270.698,
          -9332.878,
          -9394.344000000001,
          -9455.101,
          -9515.153,
          -9574.503,
          -9633.155999999999,
          -9691.117,
          -9748.388,
          -9804.975,
          -9860.88,
          -9916.108,
          -9970.662,
          -10024.546999999999,
          -10077.765,
          -10130.321,
          -10182.216999999999,
          -10233.458,
          -10284.046,
          -10333.984,
          -10383.278,
          -10431.929,
          -10479.94,
          -10527.316,
          -10574.059,
          -10620.171,
          -10665.657,
          -10710.518,
          -10754.758,
          -10798.38,
          -10841.386999999999,
          -10883.781,
          -10925.565,
          -10966.742,
          -11007.313999999998,
          -11047.284,
          -11086.653999999999,
          -11125.428,
          -11163.607,
          -11201.195,
          -11238.193000000001,
          -11274.603000000001,
          -11310.428,
          -11345.671,
          -11380.333,
          -11414.417,
          -11447.925,
          -11480.86,
          -11513.223,
          -11545.016000000001,
          -11576.241000000002,
          -11606.9,
          -11636.996000000001,
          -11666.53,
          -11695.505,
          -11723.921999999999,
          -11751.782,
          -11779.089,
          -11805.843,
          -11832.045,
          -11857.698999999999,
          -11882.806,
          -11907.367,
          -11931.385,
          -11954.86,
          -11977.794,
          -12000.188999999998,
          -12022.046,
          -12043.367,
          -12064.153,
          -12084.406,
          -12104.128,
          -12123.319,
          -12141.981000000002,
          -12160.115,
          -12177.723,
          -12194.805,
          -12211.364,
          -12227.4,
          -12242.915,
          -12257.91,
          -12272.385,
          -12286.344,
          -12299.785,
          -12312.711000000001,
          -12325.122,
          -12337.02,
          -12348.405,
          -12359.278999999999,
          -12369.643,
          -12379.498,
          -12388.844,
          -12397.683,
          -12406.015,
          -12413.841999999999,
          -12421.163999999999,
          -12427.981000000002,
          -12434.295,
          -12440.108,
          -12445.419,
          -12450.229,
          -12454.538999999999,
          -12458.351,
          -12461.663,
          -12464.478000000001,
          -12466.795,
          -12468.616000000002,
          -12469.941,
          -12470.771,
          -12471.107,
          -12470.948,
          -12470.296,
          -12469.151000000002,
          -12467.513,
          -12465.383,
          -12462.763,
          -12459.651000000002,
          -12456.048999999999,
          -12451.957,
          -12447.375,
          -12442.303999999998,
          -12436.743999999999,
          -12430.695,
          -12424.159,
          -12417.133999999998,
          -12409.622,
          -12401.623,
          -12393.138,
          -12384.165,
          -12374.706,
          -12364.761,
          -12354.33,
          -12343.413,
          -12332.011,
          -12320.123,
          -12307.75,
          -12294.891000000001,
          -12281.548,
          -12267.72,
          -12253.407,
          -12238.608999999999,
          -12223.327,
          -12207.559,
          -12191.306,
          -12174.569,
          -12157.348,
          -12139.641000000001,
          -12121.45,
          -12102.774,
          -12083.612,
          -12063.966,
          -12043.833999999999,
          -12023.216999999999,
          -12002.114,
          -11980.525,
          -11958.451000000001,
          -11935.89,
          -11912.843,
          -11889.31,
          -11865.29,
          -11840.782,
          -11815.787,
          -11790.303999999998,
          -11764.333,
          -11737.874,
          -11710.926000000001,
          -11683.489,
          -11655.562,
          -11627.145,
          -11598.238000000001,
          -11568.84,
          -11538.951000000001,
          -11508.57,
          -11477.696000000002,
          -11446.33,
          -11414.47,
          -11382.117,
          -11349.268999999998,
          -11315.926000000001,
          -11282.088,
          -11247.753,
          -11212.921,
          -11177.591,
          -11141.763,
          -11105.437,
          -11068.61,
          -11031.284,
          -10993.456,
          -10955.126,
          -10916.293,
          -10876.957,
          -10837.116000000002,
          -10796.77,
          -10755.918,
          -10714.559,
          -10672.692,
          -10630.317,
          -10587.431,
          -10544.035,
          -10500.128,
          -10455.707,
          -10410.773000000001,
          -10365.323,
          -10319.359,
          -10272.877,
          -10225.877,
          -10178.358,
          -10130.319,
          -10081.759,
          -10032.675,
          -9983.068000000001,
          -9932.935,
          -9882.276,
          -9831.09,
          -9779.375,
          -9727.13,
          -9674.353000000001,
          -9621.043,
          -9567.199,
          -9512.819,
          -9457.902,
          -9402.446,
          -9346.451,
          -9289.914,
          -9232.834,
          -9175.21,
          -9117.039,
          -9058.321,
          -8999.053,
          -8939.234,
          -8878.863000000001,
          -8817.937,
          -8756.456,
          -8694.418,
          -8631.819,
          -8568.66,
          -8504.938,
          -8440.651,
          -8375.798,
          -8310.376,
          -8244.385,
          -8177.821,
          -8110.683000000001,
          -8042.969,
          -7974.68,
          -7905.808000000001,
          -7836.355,
          -7766.319,
          -7695.696,
          -7624.486,
          -7552.686,
          -7480.294,
          -7407.309,
          -7333.726,
          -7259.545999999999,
          -7184.765,
          -7109.382,
          -7033.395,
          -6956.8009999999995,
          -6879.598000000001,
          -6801.783,
          -6723.355,
          -6644.312,
          -6564.651999999999,
          -6484.371,
          -6403.469,
          -6321.941999999999,
          -6239.789000000001,
          -6157.008000000001,
          -6073.596,
          -5989.5509999999995,
          -5904.871,
          -5819.554,
          -5733.599,
          -5647.0019999999995,
          -5559.763000000001,
          -5471.878000000001,
          -5383.347,
          -5294.166,
          -5204.335,
          -5113.852,
          -5022.715999999999,
          -4930.924,
          -4838.475,
          -4745.367,
          -4651.6,
          -4557.1720000000005,
          -4462.083,
          -4366.331,
          -4269.916,
          -4172.838,
          -4075.095,
          -3976.688,
          -3877.616,
          -3777.881,
          -3677.4829999999997,
          -3576.423,
          -3474.702,
          -3372.322,
          -3269.285,
          -3165.593,
          -3061.2490000000003,
          -2956.256,
          -2850.619,
          -2744.342,
          -2637.4309999999996,
          -2529.891,
          -2421.729,
          -2312.952,
          -2203.569,
          -2093.59,
          -1983.025,
          -1871.8870000000002,
          -1760.1879999999999,
          -1647.942,
          -1535.1670000000001,
          -1421.88,
          -1308.1,
          -1193.85,
          -1079.154,
          -964.038,
          -848.533,
          -732.67,
          -616.485,
          -500.01800000000003,
          -383.311,
          -266.41200000000003,
          -149.374,
          -32.255,
          84.883,
          201.968,
          318.925,
          435.66900000000004,
          552.106,
          668.135,
          783.6419999999999,
          898.5039999999999,
          1012.584,
          1125.734,
          1237.789,
          1348.569,
          1457.876,
          1565.495,
          1671.1870000000001,
          1774.6970000000001,
          1875.7420000000002,
          1974.016,
          2069.19,
          2160.907,
          2248.783,
          2332.411,
          2411.356,
          2485.163,
          2553.357,
          2615.446,
          2670.9309999999996,
          2719.3140000000003,
          2760.1040000000003,
          2792.829,
          2817.051,
          2832.3779999999997,
          2838.474,
          2835.078,
          2822.009,
          2799.179,
          2766.594,
          2724.363,
          2672.687,
          2611.86,
          2542.257,
          2464.319,
          2378.541,
          2285.462,
          2185.644,
          2079.66,
          1968.086,
          1851.486,
          1730.405,
          1605.3670000000002,
          1476.864,
          1345.3570000000002,
          1211.2730000000001,
          1075.008,
          936.922,
          797.3430000000001,
          656.571,
          514.873,
          372.49199999999996,
          229.646,
          86.53,
          -56.684,
          -199.84099999999998,
          -342.80199999999996,
          -485.44599999999997,
          -627.664,
          -769.362,
          -910.454,
          -1050.867,
          -1190.535,
          -1329.402,
          -1467.418,
          -1604.539,
          -1740.7279999999998,
          -1875.951,
          -2010.181,
          -2143.396,
          -2275.573,
          -2406.697,
          -2536.7529999999997,
          -2665.73,
          -2793.619,
          -2920.413,
          -3046.1059999999998,
          -3170.6940000000004,
          -3294.177,
          -3416.552,
          -3537.82,
          -3657.9809999999998,
          -3777.038,
          -3894.995,
          -4011.8540000000003,
          -4127.62,
          -4242.295999999999,
          -4355.889,
          -4468.404,
          -4579.848,
          -4690.224,
          -4799.542,
          -4907.807,
          -5015.026,
          -5121.206,
          -5226.354,
          -5330.479,
          -5433.585999999999,
          -5535.684,
          -5636.78,
          -5736.880999999999,
          -5835.994000000001,
          -5934.128000000001,
          -6031.29,
          -6127.488,
          -6222.728,
          -6317.018,
          -6410.366,
          -6502.779,
          -6594.264,
          -6684.829000000001,
          -6774.479,
          -6863.223000000001,
          -6951.068,
          -7038.02,
          -7124.0869999999995,
          -7209.274,
          -7293.589,
          -7377.039000000001,
          -7459.63,
          -7541.368,
          -7622.259,
          -7702.311,
          -7781.528,
          -7859.9169999999995,
          -7937.485,
          -8014.236999999999,
          -8090.179,
          -8165.316999999999,
          -8239.655,
          -8313.201,
          -8385.959,
          -8457.936,
          -8529.136,
          -8599.564,
          -8669.226,
          -8738.126,
          -8806.271,
          -8873.665,
          -8940.312,
          -9006.218,
          -9071.386999999999,
          -9135.824,
          -9199.533000000001,
          -9262.52,
          -9324.788,
          -9386.341999999999,
          -9447.187,
          -9507.325,
          -9566.763,
          -9625.503,
          -9683.549,
          -9740.905999999999,
          -9797.579,
          -9853.57,
          -9908.883,
          -9963.521999999999,
          -10017.491,
          -10070.793,
          -10123.431999999999,
          -10175.412,
          -10226.735999999999,
          -10277.408000000001,
          -10327.43,
          -10376.806,
          -10425.539,
          -10473.632,
          -10521.09,
          -10567.913999999999,
          -10614.108,
          -10659.675,
          -10704.618,
          -10748.938999999998,
          -10792.641000000001,
          -10835.728000000001,
          -10878.202,
          -10920.066,
          -10961.322,
          -11001.973999999998,
          -11042.024,
          -11081.473,
          -11120.326000000001,
          -11158.583999999999,
          -11196.249,
          -11233.325,
          -11269.813,
          -11305.716999999999,
          -11341.037,
          -11375.777,
          -11409.938999999998,
          -11443.524,
          -11476.535,
          -11508.973999999998,
          -11540.843,
          -11572.145,
          -11602.881000000001,
          -11633.053,
          -11662.663999999999,
          -11691.714,
          -11720.206,
          -11748.141000000001,
          -11775.523000000001,
          -11802.351999999999,
          -11828.63,
          -11854.358999999999,
          -11879.541000000001,
          -11904.176000000001,
          -11928.268,
          -11951.817,
          -11974.823999999999,
          -11997.293,
          -12019.225,
          -12040.618999999999,
          -12061.479,
          -12081.806,
          -12101.6,
          -12120.864,
          -12139.598999999998,
          -12157.806,
          -12175.486,
          -12192.641000000001,
          -12209.271999999999,
          -12225.381000000001,
          -12240.968,
          -12256.035,
          -12270.583,
          -12284.613000000001,
          -12298.126,
          -12311.123,
          -12323.605,
          -12335.575,
          -12347.032,
          -12357.976999999999,
          -12368.412,
          -12378.338,
          -12387.755,
          -12396.663999999999,
          -12405.067,
          -12412.963,
          -12420.355,
          -12427.243,
          -12433.628,
          -12439.511,
          -12444.892,
          -12449.771999999999,
          -12454.152,
          -12458.033000000001,
          -12461.415,
          -12464.298999999999,
          -12466.686000000002,
          -12468.577,
          -12469.971000000001,
          -12470.87,
          -12471.275,
          -12471.186000000002,
          -12470.601999999999,
          -12469.526000000002,
          -12467.958,
          -12465.896999999999,
          -12463.345,
          -12460.301000000001,
          -12456.767,
          -12452.743999999999,
          -12448.23,
          -12443.228000000001,
          -12437.736,
          -12431.756000000001,
          -12425.287,
          -12418.331,
          -12410.886999999999,
          -12402.956,
          -12394.537,
          -12385.633,
          -12376.242,
          -12366.364,
          -12356.001,
          -12345.152,
          -12333.817,
          -12321.996000000001,
          -12309.69,
          -12296.899,
          -12283.623,
          -12269.862,
          -12255.616000000002,
          -12240.885,
          -12225.67,
          -12209.969,
          -12193.784,
          -12177.114,
          -12159.958999999999,
          -12142.319,
          -12124.194,
          -12105.583999999999,
          -12086.49,
          -12066.91,
          -12046.845,
          -12026.294,
          -12005.258,
          -11983.736,
          -11961.728000000001,
          -11939.233999999999,
          -11916.253,
          -11892.786,
          -11868.831,
          -11844.39,
          -11819.461000000001,
          -11794.045,
          -11768.14,
          -11741.747,
          -11714.865,
          -11687.493999999999,
          -11659.633,
          -11631.282,
          -11602.441,
          -11573.108999999999,
          -11543.285,
          -11512.97,
          -11482.163,
          -11450.863000000001,
          -11419.069,
          -11386.781,
          -11353.999,
          -11320.721000000001,
          -11286.948,
          -11252.678999999998,
          -11217.913,
          -11182.649,
          -11146.886999999999,
          -11110.626,
          -11073.866000000002,
          -11036.604,
          -10998.841999999999,
          -10960.577,
          -10921.81,
          -10882.538999999999,
          -10842.764,
          -10802.483999999999,
          -10761.698,
          -10720.405,
          -10678.603000000001,
          -10636.293,
          -10593.473999999998,
          -10550.143,
          -10506.3,
          -10461.945,
          -10417.076,
          -10371.693000000001,
          -10325.794,
          -10279.378,
          -10232.444,
          -10184.99,
          -10137.016,
          -10088.521,
          -10039.503,
          -9989.961,
          -9939.895,
          -9889.302,
          -9838.181,
          -9786.530999999999,
          -9734.351999999999,
          -9681.64,
          -9628.396,
          -9574.617,
          -9520.303,
          -9465.452,
          -9410.062,
          -9354.132,
          -9297.661,
          -9240.646,
          -9183.087,
          -9124.982,
          -9066.329,
          -9007.127,
          -8947.375,
          -8887.069,
          -8826.21,
          -8764.795,
          -8702.822,
          -8640.289,
          -8577.196,
          -8513.54,
          -8449.319,
          -8384.530999999999,
          -8319.175,
          -8253.25,
          -8186.7519999999995,
          -8119.68,
          -8052.033,
          -7983.808000000001,
          -7915.0019999999995,
          -7845.615,
          -7775.644,
          -7705.088000000001,
          -7633.944,
          -7562.21,
          -7489.884,
          -7416.965,
          -7343.448,
          -7269.334,
          -7194.619000000001,
          -7119.303000000001,
          -7043.380999999999,
          -6966.853,
          -6889.715999999999,
          -6811.968000000001,
          -6733.606,
          -6654.628000000001,
          -6575.034000000001,
          -6494.819,
          -6413.983,
          -6332.522,
          -6250.435,
          -6167.72,
          -6084.3730000000005,
          -6000.394,
          -5915.779,
          -5830.528,
          -5744.638000000001,
          -5658.107,
          -5570.933000000001,
          -5483.113,
          -5394.647,
          -5305.531,
          -5215.765,
          -5125.347,
          -5034.274,
          -4942.5470000000005,
          -4850.162,
          -4757.1179999999995,
          -4663.415,
          -4569.05,
          -4474.024,
          -4378.335,
          -4281.982,
          -4184.965999999999,
          -4087.285,
          -3988.9390000000003,
          -3889.928,
          -3790.2540000000004,
          -3689.9159999999997,
          -3588.915,
          -3487.2529999999997,
          -3384.9309999999996,
          -3281.9509999999996,
          -3178.316,
          -3074.027,
          -2969.0890000000004,
          -2863.506,
          -2757.283,
          -2650.423,
          -2542.9339999999997,
          -2434.821,
          -2326.093,
          -2216.757,
          -2106.823,
          -1996.3010000000002,
          -1885.204,
          -1773.5439999999999,
          -1661.336,
          -1548.595,
          -1435.34,
          -1321.59,
          -1207.366,
          -1092.693,
          -977.596,
          -862.107,
          -746.255,
          -630.076,
          -513.611,
          -396.9,
          -279.991,
          -162.937,
          -45.795,
          71.374,
          188.49900000000002,
          305.504,
          422.306,
          538.813,
          654.922,
          770.5239999999999,
          885.4939999999999,
          999.698,
          1112.989,
          1225.204,
          1336.164,
          1445.6729999999998,
          1553.517,
          1659.4620000000002,
          1763.2520000000002,
          1864.609,
          1963.229,
          2058.784,
          2150.9210000000003,
          2239.259,
          2323.3920000000003,
          2402.889,
          2477.297,
          2546.141,
          2608.933,
          2665.1740000000004,
          2714.364,
          2756.011,
          2789.6420000000003,
          2814.813,
          2831.127,
          2838.244,
          2835.893,
          2823.883,
          2802.118,
          2770.594,
          2729.409,
          2678.755,
          2618.916,
          2550.26,
          2473.22,
          2388.288,
          2295.999,
          2196.91,
          2091.597,
          1980.6329999999998,
          1864.585,
          1744.0020000000002,
          1619.4070000000002,
          1491.295,
          1360.1329999999998,
          1226.351,
          1090.346,
          952.4830000000001,
          813.0930000000001,
          672.4780000000001,
          530.909,
          388.63300000000004,
          245.868,
          102.811,
          -40.361,
          -183.49200000000002,
          -326.444,
          -469.091,
          -611.3430000000001,
          -753.05,
          -894.178,
          -1034.635,
          -1174.356,
          -1313.283,
          -1451.364,
          -1588.556,
          -1724.8210000000001,
          -1860.124,
          -1994.4389999999999,
          -2127.741,
          -2260.009,
          -2391.226,
          -2521.3779999999997,
          -2650.4509999999996,
          -2778.44,
          -2905.3340000000003,
          -3031.13,
          -3155.822,
          -3279.408,
          -3401.888,
          -3523.261,
          -3643.53,
          -3762.6940000000004,
          -3880.758,
          -3997.724,
          -4113.597,
          -4228.3820000000005,
          -4342.084,
          -4454.707,
          -4566.258,
          -4676.742,
          -4786.168,
          -4894.54,
          -5001.867,
          -5108.155,
          -5213.41,
          -5317.64,
          -5420.854,
          -5523.058000000001,
          -5624.259,
          -5724.465999999999,
          -5823.684,
          -5921.923000000001,
          -6019.189,
          -6115.49,
          -6210.834,
          -6305.228,
          -6398.678000000001,
          -6491.193,
          -6582.779,
          -6673.445,
          -6763.196999999999,
          -6852.0419999999995,
          -6939.986999999999,
          -7027.0380000000005,
          -7113.204000000001,
          -7198.491,
          -7282.905,
          -7366.453,
          -7449.141,
          -7530.976,
          -7611.963000000001,
          -7692.111,
          -7771.425,
          -7849.91,
          -7927.573,
          -8004.42,
          -8080.456,
          -8155.687,
          -8230.12,
          -8303.759,
          -8376.61,
          -8448.679,
          -8519.971,
          -8590.492,
          -8660.245,
          -8729.235999999999,
          -8797.472,
          -8864.956,
          -8931.693000000001,
          -8997.689,
          -9062.947,
          -9127.474,
          -9191.271999999999,
          -9254.346,
          -9316.702,
          -9378.344000000001,
          -9439.276,
          -9499.502,
          -9559.026,
          -9617.853000000001,
          -9675.985999999999,
          -9733.429,
          -9790.186,
          -9846.261999999999,
          -9901.661,
          -9956.385,
          -10010.438,
          -10063.825,
          -10116.549,
          -10168.613000000001,
          -10220.02,
          -10270.774,
          -10320.879,
          -10370.337,
          -10419.153,
          -10467.329,
          -10514.868999999999,
          -10561.775,
          -10608.05,
          -10653.698,
          -10698.721000000001,
          -10743.123,
          -10786.906,
          -10830.073999999999,
          -10872.628,
          -10914.572,
          -10955.908000000001,
          -10996.639,
          -11036.768,
          -11076.296999999999,
          -11115.228000000001,
          -11153.563999999998,
          -11191.309,
          -11228.463,
          -11265.028999999999,
          -11301.011,
          -11336.409,
          -11371.226,
          -11405.465,
          -11439.128,
          -11472.215,
          -11504.731000000002,
          -11536.678,
          -11568.056,
          -11598.868,
          -11629.116000000002,
          -11658.803,
          -11687.928999999998,
          -11716.497,
          -11744.508,
          -11771.965,
          -11798.868,
          -11825.221000000001,
          -11851.025,
          -11876.281,
          -11900.992,
          -11925.158000000001,
          -11948.781,
          -11971.864,
          -11994.407,
          -12016.411,
          -12037.88,
          -12058.813,
          -12079.212,
          -12099.08,
          -12118.417,
          -12137.225,
          -12155.505,
          -12173.258,
          -12190.486,
          -12207.19,
          -12223.371000000001,
          -12239.03,
          -12254.169,
          -12268.788999999999,
          -12282.89,
          -12296.475,
          -12309.545,
          -12322.098999999998,
          -12334.14,
          -12345.668,
          -12356.685,
          -12367.191,
          -12377.188,
          -12386.676000000001,
          -12395.655,
          -12404.128999999999,
          -12412.096000000001,
          -12419.559,
          -12426.518,
          -12432.973,
          -12438.926000000001,
          -12444.377,
          -12449.328000000001,
          -12453.778,
          -12457.728000000001,
          -12461.18,
          -12464.133999999998,
          -12466.59,
          -12468.55,
          -12470.015,
          -12470.983,
          -12471.457,
          -12471.437,
          -12470.923,
          -12469.916000000001,
          -12468.416000000001,
          -12466.425,
          -12463.941,
          -12460.966,
          -12457.501,
          -12453.546,
          -12449.101,
          -12444.167,
          -12438.743999999999,
          -12432.832,
          -12426.431999999999,
          -12419.544,
          -12412.168,
          -12404.305,
          -12395.955,
          -12387.118,
          -12377.794,
          -12367.985,
          -12357.688999999998,
          -12346.908000000001,
          -12335.64,
          -12323.888,
          -12311.649,
          -12298.926000000001,
          -12285.718,
          -12272.024,
          -12257.845,
          -12243.181,
          -12228.033000000001,
          -12212.399,
          -12196.281,
          -12179.678,
          -12162.591,
          -12145.018,
          -12126.96,
          -12108.418,
          -12089.39,
          -12069.877,
          -12049.878999999999,
          -12029.393999999998,
          -12008.425,
          -11986.969,
          -11965.028,
          -11942.6,
          -11919.686000000002,
          -11896.285,
          -11872.398000000001,
          -11848.023000000001,
          -11823.161,
          -11797.811000000002,
          -11771.972,
          -11745.645,
          -11718.829,
          -11691.524,
          -11663.73,
          -11635.445,
          -11606.67,
          -11577.405,
          -11547.648000000001,
          -11517.399,
          -11486.657,
          -11455.423,
          -11423.695,
          -11391.473999999998,
          -11358.757,
          -11325.546,
          -11291.839,
          -11257.636,
          -11222.936000000002,
          -11187.738000000001,
          -11152.042,
          -11115.847,
          -11079.152,
          -11041.957,
          -11004.26,
          -10966.062,
          -10927.36,
          -10888.155,
          -10848.446000000002,
          -10808.231000000002,
          -10767.511,
          -10726.284,
          -10684.548,
          -10642.303999999998,
          -10599.55,
          -10556.285,
          -10512.508999999998,
          -10468.22,
          -10423.417,
          -10378.099,
          -10332.265,
          -10285.915,
          -10239.046,
          -10191.659,
          -10143.751,
          -10095.322,
          -10046.37,
          -9996.894,
          -9946.893,
          -9896.366,
          -9845.311,
          -9793.726999999999,
          -9741.613000000001,
          -9688.968,
          -9635.79,
          -9582.077,
          -9527.829,
          -9473.044,
          -9417.72,
          -9361.856,
          -9305.451,
          -9248.502,
          -9191.009,
          -9132.97,
          -9074.383,
          -9015.248,
          -8955.561,
          -8895.322,
          -8834.528,
          -8773.179,
          -8711.271999999999,
          -8648.806,
          -8585.779,
          -8522.188,
          -8458.034,
          -8393.313,
          -8328.024,
          -8262.164,
          -8195.733,
          -8128.727,
          -8061.146,
          -7992.986999999999,
          -7924.2480000000005,
          -7854.927,
          -7785.023,
          -7714.533,
          -7643.455,
          -7571.7880000000005,
          -7499.528,
          -7426.675,
          -7353.226,
          -7279.178000000001,
          -7204.53,
          -7129.279,
          -7053.424,
          -6976.9619999999995,
          -6899.891,
          -6822.209,
          -6743.914000000001,
          -6665.004,
          -6585.475,
          -6505.326999999999,
          -6424.556,
          -6343.161999999999,
          -6261.141,
          -6178.491,
          -6095.210999999999,
          -6011.298000000001,
          -5926.75,
          -5841.565,
          -5755.741,
          -5669.275,
          -5582.166,
          -5494.411999999999,
          -5406.0109999999995,
          -5316.960999999999,
          -5227.26,
          -5136.907,
          -5045.899,
          -4954.236,
          -4861.915,
          -4768.936,
          -4675.295999999999,
          -4580.996,
          -4486.032999999999,
          -4390.407,
          -4294.1179999999995,
          -4197.164000000001,
          -4099.545,
          -4001.261,
          -3902.3109999999997,
          -3802.697,
          -3702.4190000000003,
          -3601.4790000000003,
          -3499.8759999999997,
          -3397.612,
          -3294.69,
          -3191.112,
          -3086.88,
          -2981.9970000000003,
          -2876.468,
          -2770.298,
          -2663.491,
          -2556.053,
          -2447.99,
          -2339.31,
          -2230.021,
          -2120.133,
          -2009.655,
          -1898.599,
          -1786.9779999999998,
          -1674.808,
          -1562.102,
          -1448.879,
          -1335.1589999999999,
          -1220.962,
          -1106.312,
          -991.2360000000001,
          -875.762,
          -759.922,
          -643.751,
          -527.2869999999999,
          -410.57199999999995,
          -293.655,
          -176.585,
          -59.419,
          57.78,
          174.94299999999998,
          291.996,
          408.856,
          525.431,
          641.621,
          757.316,
          872.3939999999999,
          986.722,
          1100.153,
          1212.526,
          1323.664,
          1433.374,
          1541.443,
          1647.639,
          1751.7079999999999,
          1853.375,
          1952.3370000000002,
          2048.272,
          2140.826,
          2229.624,
          2314.26,
          2394.3070000000002,
          2469.313,
          2538.806,
          2602.298,
          2659.2909999999997,
          2709.2859999999996,
          2751.788,
          2786.322,
          2812.442,
          2829.743,
          2837.881,
          2836.574,
          2825.625,
          2804.928,
          2774.467,
          2734.3320000000003,
          2684.704,
          2625.8579999999997,
          2558.154,
          2482.02,
          2397.94,
          2306.446,
          2208.094,
          2103.458,
          1993.111,
          1877.622,
          1757.5410000000002,
          1633.394,
          1505.68,
          1374.8670000000002,
          1241.39,
          1105.649,
          968.012,
          828.814,
          688.3589999999999,
          546.923,
          404.75300000000004,
          262.07099999999997,
          119.07700000000001,
          -24.052,
          -167.158,
          -310.098,
          -452.74800000000005,
          -594.997,
          -736.747,
          -877.91,
          -1018.4119999999999,
          -1158.185,
          -1297.171,
          -1435.317,
          -1572.58,
          -1708.92,
          -1844.3029999999999,
          -1978.7020000000002,
          -2112.091,
          -2244.449,
          -2375.759,
          -2506.006,
          -2635.177,
          -2763.265,
          -2890.26,
          -3016.157,
          -3140.953,
          -3264.6440000000002,
          -3387.228,
          -3508.708,
          -3629.0820000000003,
          -3748.3540000000003,
          -3866.525,
          -3983.599,
          -4099.58,
          -4214.473,
          -4328.282,
          -4441.013,
          -4552.6720000000005,
          -4663.265,
          -4772.798,
          -4881.278,
          -4988.712,
          -5095.107,
          -5200.469,
          -5304.806,
          -5408.1269999999995,
          -5510.436,
          -5611.743,
          -5712.055,
          -5811.378000000001,
          -5909.722,
          -6007.092,
          -6103.496999999999,
          -6198.945,
          -6293.441,
          -6386.994000000001,
          -6479.611,
          -6571.3,
          -6662.066999999999,
          -6751.92,
          -6840.865,
          -6928.91,
          -7016.062,
          -7102.326999999999,
          -7187.7119999999995,
          -7272.224,
          -7355.87,
          -7438.656,
          -7520.588000000001,
          -7601.673000000001,
          -7681.9169999999995,
          -7761.326,
          -7839.906999999999,
          -7917.666,
          -7994.607,
          -8070.738,
          -8146.063,
          -8220.589,
          -8294.322,
          -8367.266,
          -8439.428,
          -8510.812,
          -8581.423,
          -8651.268,
          -8720.351,
          -8788.677,
          -8856.252,
          -8923.079,
          -8989.165,
          -9054.513,
          -9119.127,
          -9183.014000000001,
          -9246.177,
          -9308.622,
          -9370.351,
          -9431.371,
          -9491.684000000001,
          -9551.295,
          -9610.208,
          -9668.426,
          -9725.956,
          -9782.799,
          -9838.961,
          -9894.444,
          -9949.253,
          -10003.392,
          -10056.863000000001,
          -10109.67,
          -10161.817,
          -10213.308,
          -10264.146,
          -10314.334,
          -10363.875,
          -10412.774,
          -10461.032,
          -10508.653999999999,
          -10555.641000000001,
          -10601.998,
          -10647.726999999999,
          -10692.832,
          -10737.315,
          -10781.178,
          -10824.426000000001,
          -10867.061000000002,
          -10909.085,
          -10950.501,
          -10991.311000000002,
          -11031.518999999998,
          -11071.127,
          -11110.136999999999,
          -11148.553,
          -11186.375,
          -11223.608,
          -11260.253,
          -11296.312,
          -11331.788,
          -11366.683,
          -11400.999,
          -11434.738000000001,
          -11467.903999999999,
          -11500.497,
          -11532.52,
          -11563.975,
          -11594.863000000001,
          -11625.188,
          -11654.95,
          -11684.152,
          -11712.796,
          -11740.883,
          -11768.415,
          -11795.393999999998,
          -11821.822,
          -11847.701000000001,
          -11873.032,
          -11897.817,
          -11922.056999999999,
          -11945.755,
          -11968.912,
          -11991.528999999999,
          -12013.608,
          -12035.15,
          -12056.157,
          -12076.63,
          -12096.571000000002,
          -12115.982,
          -12134.863000000001,
          -12153.216,
          -12171.042,
          -12188.341999999999,
          -12205.118999999999,
          -12221.373,
          -12237.104,
          -12252.315,
          -12267.007,
          -12281.181,
          -12294.838,
          -12307.979,
          -12320.605,
          -12332.718,
          -12344.317,
          -12355.406,
          -12365.983,
          -12376.051000000001,
          -12385.61,
          -12394.661,
          -12403.205,
          -12411.243999999999,
          -12418.777,
          -12425.806,
          -12432.332,
          -12438.356000000002,
          -12443.877,
          -12448.898000000001,
          -12453.418,
          -12457.438999999998,
          -12460.961000000001,
          -12463.983999999999,
          -12466.511,
          -12468.54,
          -12470.073999999999,
          -12471.112,
          -12471.656,
          -12471.705,
          -12471.26,
          -12470.323,
          -12468.892,
          -12466.97,
          -12464.555,
          -12461.65,
          -12458.253,
          -12454.367,
          -12449.991000000002,
          -12445.125,
          -12439.771,
          -12433.927,
          -12427.596000000001,
          -12420.776000000002,
          -12413.469,
          -12405.673999999999,
          -12397.392,
          -12388.623,
          -12379.368,
          -12369.626,
          -12359.399,
          -12348.685,
          -12337.486,
          -12325.801000000001,
          -12313.631000000001,
          -12300.975,
          -12287.833999999999,
          -12274.208,
          -12260.097,
          -12245.501,
          -12230.42,
          -12214.854,
          -12198.803,
          -12182.268,
          -12165.247,
          -12147.742,
          -12129.751,
          -12111.276000000002,
          -12092.315,
          -12072.868999999999,
          -12052.938,
          -12032.521,
          -12011.618,
          -11990.229,
          -11968.355,
          -11945.993999999999,
          -11923.146999999999,
          -11899.813,
          -11875.993,
          -11851.685,
          -11826.889,
          -11801.606000000002,
          -11775.833999999999,
          -11749.573999999999,
          -11722.823999999999,
          -11695.586000000001,
          -11667.858,
          -11639.64,
          -11610.931999999999,
          -11581.732,
          -11552.042,
          -11521.858999999999,
          -11491.184,
          -11460.016000000001,
          -11428.355,
          -11396.2,
          -11363.55,
          -11330.406,
          -11296.765,
          -11262.628,
          -11227.993,
          -11192.862,
          -11157.232,
          -11121.103000000001,
          -11084.475,
          -11047.346000000001,
          -11009.716,
          -10971.583,
          -10932.948,
          -10893.81,
          -10854.167,
          -10814.018,
          -10773.364,
          -10732.202,
          -10690.533000000001,
          -10648.355,
          -10605.667,
          -10562.469,
          -10518.758999999998,
          -10474.536,
          -10429.799,
          -10384.548,
          -10338.78,
          -10292.496,
          -10245.693000000001,
          -10198.372,
          -10150.530999999999,
          -10102.168,
          -10053.282,
          -10003.872,
          -9953.938,
          -9903.476999999999,
          -9852.489,
          -9800.971,
          -9748.923,
          -9696.344000000001,
          -9643.232,
          -9589.586,
          -9535.404,
          -9480.685,
          -9425.428,
          -9369.63,
          -9313.291,
          -9256.409,
          -9198.983,
          -9141.01,
          -9082.49,
          -9023.42,
          -8963.8,
          -8903.628,
          -8842.901,
          -8781.618,
          -8719.778,
          -8657.379,
          -8594.418,
          -8530.895,
          -8466.806,
          -8402.152,
          -8336.929,
          -8271.136,
          -8204.771999999999,
          -8137.8330000000005,
          -8070.319,
          -8002.227,
          -7933.555,
          -7864.3009999999995,
          -7794.463000000001,
          -7724.04,
          -7653.029,
          -7581.428000000001,
          -7509.236,
          -7436.4490000000005,
          -7363.066999999999,
          -7289.085999999999,
          -7214.505,
          -7139.321999999999,
          -7063.533,
          -6987.138000000001,
          -6910.134,
          -6832.519,
          -6754.291,
          -6675.446999999999,
          -6595.985,
          -6515.904,
          -6435.201,
          -6353.8730000000005,
          -6271.918000000001,
          -6189.335,
          -6106.121,
          -6022.275,
          -5937.793000000001,
          -5852.675,
          -5766.9169999999995,
          -5680.518,
          -5593.475,
          -5505.786999999999,
          -5417.451,
          -5328.467,
          -5238.832,
          -5148.544,
          -5057.602,
          -4966.004,
          -4873.749,
          -4780.834,
          -4687.259,
          -4593.023,
          -4498.124,
          -4402.562,
          -4306.335,
          -4209.444,
          -4111.888,
          -4013.6659999999997,
          -3914.7790000000005,
          -3815.2270000000003,
          -3715.01,
          -3614.1290000000004,
          -3512.585,
          -3410.38,
          -3307.5170000000003,
          -3203.9959999999996,
          -3099.821,
          -2994.995,
          -2889.5209999999997,
          -2783.405,
          -2676.651,
          -2569.263,
          -2461.251,
          -2352.62,
          -2243.3779999999997,
          -2133.536,
          -2023.102,
          -1912.089,
          -1800.509,
          -1688.376,
          -1575.7060000000001,
          -1462.516,
          -1348.826,
          -1234.656,
          -1120.03,
          -1004.9739999999999,
          -889.5169999999999,
          -773.689,
          -657.525,
          -541.064,
          -424.347,
          -307.421,
          -190.33599999999998,
          -73.148,
          44.08,
          161.282,
          278.382,
          395.29900000000004,
          511.94199999999995,
          628.212,
          744,
          859.184,
          973.635,
          1087.204,
          1199.734,
          1311.0510000000002,
          1420.96,
          1529.253,
          1635.6979999999999,
          1740.045,
          1842.02,
          1941.325,
          2037.6370000000002,
          2130.6079999999997,
          2219.862,
          2305.001,
          2385.595,
          2461.197,
          2531.337,
          2595.527,
          2653.272,
          2704.07,
          2747.426,
          2782.863,
          2809.9320000000002,
          2828.2209999999995,
          2837.38,
          2837.12,
          2827.237,
          2807.611,
          2778.22,
          2739.14,
          2690.545,
          2632.7009999999996,
          2565.9570000000003,
          2490.736,
          2407.5170000000003,
          2316.827,
          2219.221,
          2115.269,
          2005.5479999999998,
          1890.625,
          1771.0520000000001,
          1647.359,
          1520.049,
          1389.59,
          1256.423,
          1120.95,
          983.543,
          844.54,
          704.2489999999999,
          562.948,
          420.88699999999994,
          278.29,
          135.359,
          -7.725,
          -150.803,
          -293.731,
          -436.38300000000004,
          -578.646,
          -720.421,
          -861.62,
          -1002.166,
          -1141.991,
          -1281.035,
          -1419.246,
          -1556.579,
          -1692.995,
          -1828.4579999999999,
          -1962.941,
          -2096.4179999999997,
          -2228.866,
          -2360.269,
          -2490.611,
          -2619.881,
          -2748.0679999999998,
          -2875.164,
          -3001.163,
          -3126.062,
          -3249.8579999999997,
          -3372.548,
          -3494.134,
          -3614.615,
          -3733.993,
          -3852.272,
          -3969.454,
          -4085.5440000000003,
          -4200.545,
          -4314.462,
          -4427.3009999999995,
          -4539.068,
          -4649.77,
          -4759.411,
          -4867.999,
          -4975.54,
          -5082.042,
          -5187.512,
          -5291.956999999999,
          -5395.384,
          -5497.8,
          -5599.2119999999995,
          -5699.629,
          -5799.058000000001,
          -5897.507,
          -5994.982,
          -6091.491,
          -6187.041,
          -6281.641,
          -6375.297,
          -6468.017,
          -6559.808000000001,
          -6650.6759999999995,
          -6740.63,
          -6829.6759999999995,
          -6917.821,
          -7005.073,
          -7091.438,
          -7176.922,
          -7261.533,
          -7345.276999999999,
          -7428.161,
          -7510.19,
          -7591.371999999999,
          -7671.713000000001,
          -7751.218000000001,
          -7829.895,
          -7907.749,
          -7984.785,
          -8061.01,
          -8136.43,
          -8211.05,
          -8284.876,
          -8357.913,
          -8430.168,
          -8501.644,
          -8572.348,
          -8642.284,
          -8711.458,
          -8779.875,
          -8847.54,
          -8914.458,
          -8980.633,
          -9046.071,
          -9110.775,
          -9174.75,
          -9238.002,
          -9300.535,
          -9362.353000000001,
          -9423.459,
          -9483.86,
          -9543.558,
          -9602.558,
          -9660.863000000001,
          -9718.478000000001,
          -9775.408000000001,
          -9831.655,
          -9887.223,
          -9942.117,
          -9996.34,
          -10049.896,
          -10102.787,
          -10155.018,
          -10206.593,
          -10257.514000000001,
          -10307.785,
          -10357.41,
          -10406.391,
          -10454.731,
          -10502.435,
          -10549.505,
          -10595.943000000001,
          -10641.753,
          -10686.938999999998,
          -10731.503,
          -10775.448,
          -10818.776000000002,
          -10861.491000000002,
          -10903.595,
          -10945.091,
          -10985.981000000002,
          -11026.268,
          -11065.956,
          -11105.045,
          -11143.538999999999,
          -11181.441,
          -11218.752,
          -11255.475,
          -11291.612,
          -11327.166000000001,
          -11362.139,
          -11396.533000000001,
          -11430.348999999998,
          -11463.591999999999,
          -11496.261999999999,
          -11528.362,
          -11559.893999999998,
          -11590.858999999999,
          -11621.26,
          -11651.098,
          -11680.376,
          -11709.096000000001,
          -11737.258999999998,
          -11764.866000000002,
          -11791.921,
          -11818.423999999999,
          -11844.378,
          -11869.784,
          -11894.643999999998,
          -11918.958999999999,
          -11942.731000000002,
          -11965.962,
          -11988.653999999999,
          -12010.806999999999,
          -12032.423,
          -12053.503,
          -12074.05,
          -12094.065,
          -12113.548999999999,
          -12132.503999999999,
          -12150.93,
          -12168.829,
          -12186.203000000001,
          -12203.052,
          -12219.378,
          -12235.183,
          -12250.466,
          -12265.23,
          -12279.476,
          -12293.205,
          -12306.419,
          -12319.117,
          -12331.301000000001,
          -12342.973,
          -12354.132,
          -12364.781,
          -12374.921,
          -12384.551000000001,
          -12393.673,
          -12402.288,
          -12410.398000000001,
          -12418.002,
          -12425.101999999999,
          -12431.698999999999,
          -12437.793,
          -12443.385,
          -12448.476,
          -12453.067,
          -12457.158000000001,
          -12460.75,
          -12463.844,
          -12466.44,
          -12468.54,
          -12470.143,
          -12471.252,
          -12471.865,
          -12471.983,
          -12471.608,
          -12470.74,
          -12469.378999999999,
          -12467.526000000002,
          -12465.181,
          -12462.344,
          -12459.017,
          -12455.2,
          -12450.893,
          -12446.096000000001,
          -12440.81,
          -12435.036,
          -12428.773000000001,
          -12422.021999999999,
          -12414.783000000001,
          -12407.056999999999,
          -12398.844,
          -12390.143999999998,
          -12380.957,
          -12371.284,
          -12361.124,
          -12350.478000000001,
          -12339.347,
          -12327.731000000002,
          -12315.628,
          -12303.041000000001,
          -12289.968,
          -12276.41,
          -12262.367,
          -12247.838,
          -12232.825,
          -12217.327,
          -12201.344,
          -12184.876,
          -12167.923,
          -12150.485,
          -12132.562,
          -12114.153999999999,
          -12095.261,
          -12075.882,
          -12056.018,
          -12035.669,
          -12014.833999999999,
          -11993.511999999999,
          -11971.705,
          -11949.412,
          -11926.632,
          -11903.365,
          -11879.61,
          -11855.368999999999,
          -11830.641000000001,
          -11805.425,
          -11779.72,
          -11753.527,
          -11726.845,
          -11699.673,
          -11672.013,
          -11643.861,
          -11615.22,
          -11586.087,
          -11556.464,
          -11526.348,
          -11495.739,
          -11464.638,
          -11433.043,
          -11400.955,
          -11368.372,
          -11335.294,
          -11301.72,
          -11267.65,
          -11233.083,
          -11198.018,
          -11162.455,
          -11126.393,
          -11089.831,
          -11052.768,
          -11015.204,
          -10977.138,
          -10938.57,
          -10899.498,
          -10859.921999999999,
          -10819.84,
          -10779.252,
          -10738.158000000001,
          -10696.555,
          -10654.444,
          -10611.823,
          -10568.691,
          -10525.046999999999,
          -10480.89,
          -10436.22,
          -10391.035,
          -10345.335,
          -10299.117,
          -10252.382,
          -10205.127,
          -10157.351999999999,
          -10109.056,
          -10060.237,
          -10010.894,
          -9961.026,
          -9910.632,
          -9859.71,
          -9808.259,
          -9756.278,
          -9703.766,
          -9650.72,
          -9597.141,
          -9543.026,
          -9488.374,
          -9433.184000000001,
          -9377.453000000001,
          -9321.181,
          -9264.366,
          -9207.007,
          -9149.101,
          -9090.646999999999,
          -9031.645,
          -8972.091999999999,
          -8911.985999999999,
          -8851.326,
          -8790.110999999999,
          -8728.338,
          -8666.006,
          -8603.112,
          -8539.655999999999,
          -8475.635,
          -8411.046999999999,
          -8345.892,
          -8280.166,
          -8213.869,
          -8146.9980000000005,
          -8079.5509999999995,
          -8011.526,
          -7942.920999999999,
          -7873.735,
          -7803.965,
          -7733.609,
          -7662.666,
          -7591.132,
          -7519.007,
          -7446.2880000000005,
          -7372.973000000001,
          -7299.059,
          -7224.545999999999,
          -7149.43,
          -7073.709,
          -6997.382,
          -6920.445,
          -6842.898,
          -6764.736999999999,
          -6685.96,
          -6606.566,
          -6526.552,
          -6445.916,
          -6364.655,
          -6282.769,
          -6200.253000000001,
          -6117.107,
          -6033.326999999999,
          -5948.911999999999,
          -5863.86,
          -5778.169,
          -5691.8369999999995,
          -5604.861,
          -5517.24,
          -5428.971,
          -5340.054,
          -5250.485,
          -5160.263,
          -5069.387,
          -4977.855,
          -4885.664000000001,
          -4792.815,
          -4699.306,
          -4605.134,
          -4510.3,
          -4414.803,
          -4318.64,
          -4221.813,
          -4124.32,
          -4026.1609999999996,
          -3927.336,
          -3827.845,
          -3727.69,
          -3626.87,
          -3525.387,
          -3423.242,
          -3320.438,
          -3216.975,
          -3112.857,
          -3008.087,
          -2902.6690000000003,
          -2796.6079999999997,
          -2689.907,
          -2582.573,
          -2474.611,
          -2366.03,
          -2256.837,
          -2147.041,
          -2036.652,
          -1925.682,
          -1814.1429999999998,
          -1702.0479999999998,
          -1589.414,
          -1476.2579999999998,
          -1362.599,
          -1248.4569999999999,
          -1133.856,
          -1018.821,
          -903.3810000000001,
          -787.566,
          -671.4110000000001,
          -554.953,
          -438.23400000000004,
          -321.3,
          -204.201,
          -86.992,
          30.266,
          147.505,
          264.651,
          381.624,
          498.335,
          614.683,
          730.563,
          845.8530000000001,
          960.425,
          1074.133,
          1186.82,
          1298.312,
          1408.42,
          1516.935,
          1623.629,
          1728.2520000000002,
          1830.535,
          1930.18,
          2026.869,
          2120.255,
          2209.966,
          2295.603,
          2376.744,
          2452.942,
          2523.7270000000003,
          2588.615,
          2647.11,
          2698.711,
          2742.923,
          2779.264,
          2807.281,
          2826.5609999999997,
          2836.745,
          2837.5359999999996,
          2828.722,
          2810.1740000000004,
          2781.8590000000004,
          2743.843,
          2696.289,
          2639.455,
          2573.681,
          2499.382,
          2417.034,
          2327.157,
          2230.305,
          2127.047,
          2017.96,
          1903.611,
          1784.555,
          1661.3239999999998,
          1534.4229999999998,
          1404.325,
          1271.472,
          1136.272,
          999.1,
          860.296,
          720.171,
          579.008,
          437.05699999999996,
          294.547,
          151.68200000000002,
          8.644,
          -134.405,
          -277.32,
          -419.973,
          -562.438,
          -704.049,
          -845.283,
          -985.872,
          -1125.748,
          -1264.851,
          -1403.128,
          -1540.5320000000002,
          -1677.023,
          -1812.567,
          -1947.134,
          -2080.698,
          -2213.237,
          -2344.734,
          -2475.172,
          -2604.54,
          -2732.827,
          -2860.025,
          -2986.127,
          -3111.13,
          -3235.03,
          -3357.827,
          -3479.5190000000002,
          -3600.1079999999997,
          -3719.594,
          -3837.98,
          -3955.2709999999997,
          -4071.469,
          -4186.579000000001,
          -4300.605,
          -4413.554,
          -4525.429,
          -4636.2390000000005,
          -4745.9890000000005,
          -4854.686,
          -4962.335999999999,
          -5068.946,
          -5174.523,
          -5279.075,
          -5382.608,
          -5485.130999999999,
          -5586.651,
          -5687.174,
          -5786.7080000000005,
          -5885.262,
          -5982.842,
          -6079.455,
          -6175.11,
          -6269.814,
          -6363.573,
          -6456.396,
          -6548.2880000000005,
          -6639.259,
          -6729.315,
          -6818.4619999999995,
          -6906.7080000000005,
          -6994.06,
          -7080.525,
          -7166.109,
          -7250.818,
          -7334.661,
          -7417.642,
          -7499.77,
          -7581.049,
          -7661.486999999999,
          -7741.089,
          -7819.861,
          -7897.81,
          -7974.941999999999,
          -8051.263000000001,
          -8126.776999999999,
          -8201.492,
          -8275.411,
          -8348.542,
          -8420.889000000001,
          -8492.458,
          -8563.254,
          -8633.282,
          -8702.548,
          -8771.056,
          -8838.812,
          -8905.82,
          -8972.086,
          -9037.613000000001,
          -9102.407,
          -9166.471,
          -9229.812,
          -9292.433,
          -9354.339,
          -9415.534,
          -9476.021,
          -9535.806999999999,
          -9594.893,
          -9653.285,
          -9710.987,
          -9768.002,
          -9824.335,
          -9879.989,
          -9934.969000000001,
          -9989.276,
          -10042.917,
          -10095.893,
          -10148.208,
          -10199.867,
          -10250.871,
          -10301.225,
          -10350.933,
          -10399.997,
          -10448.42,
          -10496.206,
          -10543.358,
          -10589.878,
          -10635.771,
          -10681.038,
          -10725.683,
          -10769.708,
          -10813.117,
          -10855.912,
          -10898.097,
          -10939.673,
          -10980.643,
          -11021.01,
          -11060.777,
          -11099.946000000002,
          -11138.518999999998,
          -11176.499,
          -11213.889,
          -11250.69,
          -11286.906,
          -11322.538,
          -11357.589,
          -11392.06,
          -11425.955,
          -11459.275,
          -11492.023000000001,
          -11524.198999999999,
          -11555.808,
          -11586.848999999998,
          -11617.326000000001,
          -11647.241000000002,
          -11676.595,
          -11705.391000000001,
          -11733.628999999999,
          -11761.313,
          -11788.443000000001,
          -11815.021999999999,
          -11841.052,
          -11866.533000000001,
          -11891.468,
          -11915.858,
          -11939.704,
          -11963.01,
          -11985.775,
          -12008.002,
          -12029.693000000001,
          -12050.848,
          -12071.469,
          -12091.558,
          -12111.115,
          -12130.143,
          -12148.642,
          -12166.615,
          -12184.061000000002,
          -12200.983,
          -12217.382,
          -12233.26,
          -12248.616000000002,
          -12263.453000000001,
          -12277.771999999999,
          -12291.573,
          -12304.858,
          -12317.628999999999,
          -12329.885,
          -12341.628,
          -12352.86,
          -12363.58,
          -12373.791000000001,
          -12383.492,
          -12392.686000000002,
          -12401.373,
          -12409.553999999998,
          -12417.229,
          -12424.4,
          -12431.068000000001,
          -12437.233,
          -12442.895,
          -12448.056999999999,
          -12452.718,
          -12456.88,
          -12460.542,
          -12463.706,
          -12466.373,
          -12468.542,
          -12470.216,
          -12471.393999999998,
          -12472.077,
          -12472.266000000001,
          -12471.96,
          -12471.162,
          -12469.87,
          -12468.086000000001,
          -12465.811000000002,
          -12463.044,
          -12459.786,
          -12456.037,
          -12451.8,
          -12447.072,
          -12441.855,
          -12436.15,
          -12429.956,
          -12423.274,
          -12416.104,
          -12408.446000000002,
          -12400.302,
          -12391.67,
          -12382.552,
          -12372.947,
          -12362.856000000002,
          -12352.278,
          -12341.215,
          -12329.667,
          -12317.633,
          -12305.113000000001,
          -12292.108999999999,
          -12278.618,
          -12264.643,
          -12250.183,
          -12235.238000000001,
          -12219.808,
          -12203.893,
          -12187.492,
          -12170.607,
          -12153.237,
          -12135.381000000001,
          -12117.041000000001,
          -12098.215,
          -12078.903999999999,
          -12059.108,
          -12038.826000000001,
          -12018.058,
          -11996.803999999998,
          -11975.063999999998,
          -11952.838,
          -11930.125,
          -11906.925,
          -11883.239,
          -11859.065,
          -11834.403,
          -11809.253999999999,
          -11783.617,
          -11757.49,
          -11730.876,
          -11703.771,
          -11676.177,
          -11648.093,
          -11619.518999999998,
          -11590.453000000001,
          -11560.896,
          -11530.847,
          -11500.306,
          -11469.271,
          -11437.743999999999,
          -11405.722,
          -11373.206,
          -11340.195,
          -11306.688,
          -11272.684,
          -11238.184,
          -11203.186000000002,
          -11167.688999999998,
          -11131.694,
          -11095.198999999999,
          -11058.203000000001,
          -11020.706,
          -10982.707,
          -10944.205,
          -10905.2,
          -10865.69,
          -10825.675,
          -10785.153999999999,
          -10744.126,
          -10702.591999999999,
          -10660.546999999999,
          -10617.993,
          -10574.927,
          -10531.351,
          -10487.261,
          -10442.658000000001,
          -10397.54,
          -10351.905999999999,
          -10305.755,
          -10259.086,
          -10211.898000000001,
          -10164.189,
          -10115.96,
          -10067.208,
          -10017.931999999999,
          -9968.131,
          -9917.803,
          -9866.949,
          -9815.565,
          -9763.651,
          -9711.206,
          -9658.226999999999,
          -9604.715,
          -9550.667,
          -9496.082,
          -9440.958,
          -9385.294,
          -9329.089,
          -9272.341,
          -9215.049,
          -9157.21,
          -9098.824,
          -9039.889000000001,
          -8980.403,
          -8920.365,
          -8859.771999999999,
          -8798.624,
          -8736.918,
          -8674.653,
          -8611.827,
          -8548.438,
          -8484.484,
          -8419.964,
          -8354.876,
          -8289.218,
          -8222.988000000001,
          -8156.184,
          -8088.804,
          -8020.847,
          -7952.31,
          -7883.191,
          -7813.488,
          -7743.2,
          -7672.325,
          -7600.859,
          -7528.8009999999995,
          -7456.149,
          -7382.901,
          -7309.056,
          -7234.61,
          -7159.561,
          -7083.908,
          -7007.649,
          -6930.78,
          -6853.3,
          -6775.206999999999,
          -6696.4980000000005,
          -6617.170999999999,
          -6537.225,
          -6456.656,
          -6375.463000000001,
          -6293.643,
          -6211.195,
          -6128.116,
          -6044.404,
          -5960.057,
          -5875.071999999999,
          -5789.448,
          -5703.183000000001,
          -5616.274,
          -5528.72,
          -5440.518,
          -5351.666,
          -5262.164000000001,
          -5172.008,
          -5081.198,
          -4989.732,
          -4897.608,
          -4804.8240000000005,
          -4711.38,
          -4617.274,
          -4522.504,
          -4427.071,
          -4330.973,
          -4234.21,
          -4136.78,
          -4038.684,
          -3939.922,
          -3840.493,
          -3740.3990000000003,
          -3639.6409999999996,
          -3538.218,
          -3436.133,
          -3333.388,
          -3229.9840000000004,
          -3125.9240000000004,
          -3021.211,
          -2915.849,
          -2809.842,
          -2703.195,
          -2595.9120000000003,
          -2488.002,
          -2379.471,
          -2270.326,
          -2160.577,
          -2050.2329999999997,
          -1939.306,
          -1827.808,
          -1715.753,
          -1603.156,
          -1490.0339999999999,
          -1376.406,
          -1262.292,
          -1147.7160000000001,
          -1032.703,
          -917.279,
          -801.477,
          -685.331,
          -568.877,
          -452.156,
          -335.214,
          -218.101,
          -100.87200000000001,
          16.414,
          133.689,
          250.882,
          367.91,
          484.686,
          601.113,
          717.082,
          832.477,
          947.169,
          1061.014,
          1173.856,
          1285.5230000000001,
          1395.828,
          1504.5629999999999,
          1611.5020000000002,
          1716.401,
          1818.9879999999998,
          1918.97,
          2016.0320000000002,
          2109.83,
          2199.992,
          2286.126,
          2367.8089999999997,
          2444.597,
          2516.0229999999997,
          2581.604,
          2640.844,
          2693.244,
          2738.305,
          2775.545,
          2804.508,
          2824.775,
          2835.98,
          2837.821,
          2830.074,
          2812.6020000000003,
          2785.363,
          2748.4120000000003,
          2701.902,
          2646.0809999999997,
          2581.28,
          2507.909,
          2426.435,
          2337.377,
          2241.285,
          2138.728,
          2030.2779999999998,
          1916.509,
          1797.975,
          1675.2089999999998,
          1548.7220000000002,
          1418.989,
          1286.455,
          1151.532,
          1014.597,
          875.995,
          736.04,
          595.016,
          453.17800000000005,
          310.757,
          167.96,
          24.969,
          -118.04899999999999,
          -260.95,
          -403.602,
          -545.891,
          -687.715,
          -828.982,
          -969.6139999999999,
          -1109.5410000000002,
          -1248.702,
          -1387.0439999999999,
          -1524.5179999999998,
          -1661.085,
          -1796.7079999999999,
          -1931.359,
          -2065.011,
          -2197.64,
          -2329.229,
          -2459.764,
          -2589.229,
          -2717.615,
          -2844.914,
          -2971.12,
          -3096.2259999999997,
          -3220.2309999999998,
          -3343.133,
          -3464.9320000000002,
          -3585.6279999999997,
          -3705.222,
          -3823.717,
          -3941.115,
          -4057.421,
          -4172.639,
          -4286.774,
          -4399.832,
          -4511.816,
          -4622.735,
          -4732.593,
          -4841.398,
          -4949.155,
          -5055.873,
          -5161.558,
          -5266.217,
          -5369.858,
          -5472.488,
          -5574.113,
          -5674.741999999999,
          -5774.382,
          -5873.041,
          -5970.725,
          -6067.443,
          -6163.201999999999,
          -6258.009,
          -6351.871999999999,
          -6444.797,
          -6536.793000000001,
          -6627.865,
          -6718.022,
          -6807.27,
          -6895.616,
          -6983.069,
          -7069.633000000001,
          -7155.316,
          -7240.125,
          -7324.066,
          -7407.146,
          -7489.371,
          -7570.746999999999,
          -7651.281,
          -7730.98,
          -7809.848000000001,
          -7887.893,
          -7965.12,
          -8041.535,
          -8117.144,
          -8191.953,
          -8265.966,
          -8339.19,
          -8411.629,
          -8483.291,
          -8554.179,
          -8624.299,
          -8693.657,
          -8762.256,
          -8830.101999999999,
          -8897.201,
          -8963.556,
          -9029.173,
          -9094.056,
          -9158.21,
          -9221.639000000001,
          -9284.349,
          -9346.343,
          -9407.625,
          -9468.2,
          -9528.073,
          -9587.246,
          -9645.725,
          -9703.513,
          -9760.615,
          -9817.033000000001,
          -9872.771999999999,
          -9927.836,
          -9982.229,
          -10035.954,
          -10089.014000000001,
          -10141.414,
          -10193.155999999999,
          -10244.244,
          -10294.681999999999,
          -10344.473,
          -10393.619,
          -10442.125,
          -10489.993,
          -10537.226,
          -10583.829,
          -10629.803,
          -10675.152,
          -10719.878,
          -10763.983999999999,
          -10807.473999999998,
          -10850.35,
          -10892.615,
          -10934.271,
          -10975.321000000002,
          -11015.768,
          -11055.614,
          -11094.861,
          -11133.513,
          -11171.573,
          -11209.041000000001,
          -11245.921,
          -11282.215,
          -11317.925,
          -11353.053999999998,
          -11387.603000000001,
          -11421.576000000001,
          -11454.973,
          -11487.798,
          -11520.051000000001,
          -11551.737,
          -11582.855,
          -11613.409,
          -11643.4,
          -11672.83,
          -11701.701000000001,
          -11730.016000000001,
          -11757.775,
          -11784.981000000002,
          -11811.636,
          -11837.74,
          -11863.296999999999,
          -11888.306,
          -11912.771,
          -11936.693000000001,
          -11960.073,
          -11982.913,
          -12005.215,
          -12026.98,
          -12048.208,
          -12068.903,
          -12089.065,
          -12108.696000000002,
          -12127.798,
          -12146.371000000001,
          -12164.416000000001,
          -12181.936000000002,
          -12198.931999999999,
          -12215.403999999999,
          -12231.354,
          -12246.783000000001,
          -12261.693000000001,
          -12276.083999999999,
          -12289.958,
          -12303.315,
          -12316.157,
          -12328.485,
          -12340.3,
          -12351.604,
          -12362.396,
          -12372.678,
          -12382.452,
          -12391.716999999999,
          -12400.475,
          -12408.726999999999,
          -12416.473999999998,
          -12423.716,
          -12430.455,
          -12436.69,
          -12442.423999999999,
          -12447.656,
          -12452.388,
          -12456.62,
          -12460.351999999999,
          -12463.587,
          -12466.323999999999,
          -12468.563999999998,
          -12470.308,
          -12471.556,
          -12472.309,
          -12472.568000000001,
          -12472.332,
          -12471.603000000001,
          -12470.381000000001,
          -12468.667,
          -12466.461000000001,
          -12463.764,
          -12460.576000000001,
          -12456.896999999999,
          -12452.728000000001,
          -12448.069,
          -12442.921999999999,
          -12437.285,
          -12431.16,
          -12424.546999999999,
          -12417.446000000002,
          -12409.858,
          -12401.782,
          -12393.219,
          -12384.17,
          -12374.633999999998,
          -12364.611,
          -12354.103000000001,
          -12343.108,
          -12331.628,
          -12319.663,
          -12307.211000000001,
          -12294.274,
          -12280.851999999999,
          -12266.945,
          -12252.553,
          -12237.676000000001,
          -12222.313999999998,
          -12206.466999999999,
          -12190.135,
          -12173.318000000001,
          -12156.016000000001,
          -12138.228000000001,
          -12119.956,
          -12101.198,
          -12081.955,
          -12062.226,
          -12042.011999999999,
          -12021.311000000002,
          -12000.125,
          -11978.452,
          -11956.294,
          -11933.649,
          -11910.517,
          -11886.898000000001,
          -11862.792,
          -11838.198,
          -11813.116000000002,
          -11787.546,
          -11761.487,
          -11734.94,
          -11707.903,
          -11680.376,
          -11652.358999999999,
          -11623.851999999999,
          -11594.853000000001,
          -11565.363000000001,
          -11535.382,
          -11504.908000000001,
          -11473.941,
          -11442.48,
          -11410.526000000002,
          -11378.077,
          -11345.133,
          -11311.693000000001,
          -11277.757,
          -11243.323999999999,
          -11208.393,
          -11172.964,
          -11137.035,
          -11100.607,
          -11063.678999999998,
          -11026.249,
          -10988.317,
          -10949.883,
          -10910.944,
          -10871.501,
          -10831.553999999998,
          -10791.1,
          -10750.139,
          -10708.67,
          -10666.693000000001,
          -10624.206,
          -10581.208,
          -10537.698,
          -10493.675,
          -10449.139000000001,
          -10404.089,
          -10358.521999999999,
          -10312.438,
          -10265.837,
          -10218.716,
          -10171.075,
          -10122.912,
          -10074.226999999999,
          -10025.019,
          -9975.285,
          -9925.025,
          -9874.237,
          -9822.921,
          -9771.074,
          -9718.697,
          -9665.786,
          -9612.341,
          -9558.36,
          -9503.843,
          -9448.786,
          -9393.19,
          -9337.052,
          -9280.372,
          -9223.146999999999,
          -9165.376,
          -9107.058,
          -9048.19,
          -8988.771999999999,
          -8928.801,
          -8868.277,
          -8807.196,
          -8745.558,
          -8683.360999999999,
          -8620.603000000001,
          -8557.282,
          -8493.396,
          -8428.943000000001,
          -8363.923,
          -8298.333,
          -8232.171,
          -8165.435,
          -8098.124,
          -8030.234,
          -7961.765,
          -7892.715,
          -7823.08,
          -7752.861,
          -7682.053000000001,
          -7610.655,
          -7538.666,
          -7466.081999999999,
          -7392.903,
          -7319.125,
          -7244.7480000000005,
          -7169.768,
          -7094.183000000001,
          -7017.991,
          -6941.191,
          -6863.779,
          -6785.754,
          -6707.1140000000005,
          -6627.856,
          -6547.977,
          -6467.477,
          -6386.351,
          -6304.6,
          -6222.22,
          -6139.209,
          -6055.565,
          -5971.286,
          -5886.369000000001,
          -5800.813,
          -5714.616,
          -5627.775,
          -5540.2880000000005,
          -5452.154,
          -5363.369000000001,
          -5273.934,
          -5183.845,
          -5093.102,
          -5001.7029999999995,
          -4909.645,
          -4816.928,
          -4723.55,
          -4629.51,
          -4534.806,
          -4439.438,
          -4343.405,
          -4246.706,
          -4149.340999999999,
          -4051.309,
          -3952.61,
          -3853.245,
          -3753.2129999999997,
          -3652.5159999999996,
          -3551.155,
          -3449.131,
          -3346.446,
          -3243.1009999999997,
          -3139.099,
          -3034.4440000000004,
          -2929.139,
          -2823.188,
          -2716.595,
          -2609.367,
          -2501.509,
          -2393.029,
          -2283.933,
          -2174.231,
          -2063.933,
          -1953.05,
          -1841.594,
          -1729.579,
          -1617.02,
          -1503.933,
          -1390.3370000000002,
          -1276.252,
          -1161.702,
          -1046.711,
          -931.306,
          -815.5189999999999,
          -699.382,
          -582.933,
          -466.212,
          -349.264,
          -232.138,
          -114.889,
          2.425,
          119.736,
          236.97299999999998,
          354.056,
          470.897,
          587.401,
          703.46,
          818.959,
          933.77,
          1047.75,
          1160.746,
          1272.588,
          1383.0870000000002,
          1492.0410000000002,
          1599.227,
          1704.398,
          1807.289,
          1907.608,
          2005.0420000000001,
          2099.25,
          2189.865,
          2276.494,
          2358.718,
          2436.097,
          2508.1639999999998,
          2574.437,
          2634.4240000000004,
          2687.623,
          2733.5359999999996,
          2771.678,
          2801.5890000000004,
          2822.847,
          2835.078,
          2837.974,
          2831.302,
          2814.915,
          2788.761,
          2752.884,
          2707.428,
          2652.63,
          2588.815,
          2516.382,
          2435.795,
          2347.5679999999998,
          2252.2470000000003,
          2150.399,
          2042.599,
          1929.4189999999999,
          1811.414,
          1689.124,
          1563.057,
          1433.695,
          1301.487,
          1166.844,
          1030.151,
          891.7560000000001,
          751.9739999999999,
          611.0930000000001,
          469.371,
          327.04200000000003,
          184.313,
          41.372,
          -101.616,
          -244.50099999999998,
          -387.153,
          -529.4540000000001,
          -671.3,
          -812.602,
          -953.2769999999999,
          -1093.256,
          -1232.476,
          -1370.882,
          -1508.4270000000001,
          -1645.069,
          -1780.773,
          -1915.5079999999998,
          -2049.2470000000003,
          -2181.968,
          -2313.652,
          -2444.283,
          -2573.847,
          -2702.333,
          -2829.7340000000004,
          -2956.042,
          -3081.2540000000004,
          -3205.365,
          -3328.3740000000003,
          -3450.28,
          -3571.0840000000003,
          -3690.7859999999996,
          -3809.389,
          -3926.897,
          -4043.312,
          -4158.64,
          -4272.885,
          -4386.052,
          -4498.146,
          -4609.174,
          -4719.14,
          -4828.054,
          -4935.920999999999,
          -5042.747,
          -5148.541,
          -5253.308000000001,
          -5357.056,
          -5459.793000000001,
          -5561.526,
          -5662.2609999999995,
          -5762.007,
          -5860.772,
          -5958.562,
          -6055.385,
          -6151.249,
          -6246.16,
          -6340.126,
          -6433.155,
          -6525.253000000001,
          -6616.428000000001,
          -6706.687,
          -6796.036999999999,
          -6884.484,
          -6972.036999999999,
          -7058.701999999999,
          -7144.485,
          -7229.393,
          -7313.433000000001,
          -7396.611,
          -7478.934,
          -7560.408,
          -7641.04,
          -7720.835999999999,
          -7799.8009999999995,
          -7877.941999999999,
          -7955.264,
          -8031.775,
          -8107.478,
          -8182.380999999999,
          -8256.488000000001,
          -8329.805,
          -8402.339,
          -8474.093,
          -8545.074,
          -8615.287,
          -8684.735999999999,
          -8753.427,
          -8821.364,
          -8888.554,
          -8954.999,
          -9020.706,
          -9085.678,
          -9149.921999999999,
          -9213.440999999999,
          -9276.239,
          -9338.321,
          -9399.692,
          -9460.355,
          -9520.315,
          -9579.575,
          -9638.141,
          -9696.016,
          -9753.203000000001,
          -9809.707,
          -9865.533000000001,
          -9920.681999999999,
          -9975.16,
          -10028.97,
          -10082.115,
          -10134.599,
          -10186.425,
          -10237.597,
          -10288.119,
          -10337.992,
          -10387.222,
          -10435.81,
          -10483.761,
          -10531.077,
          -10577.761,
          -10623.817,
          -10669.248,
          -10714.055,
          -10758.243,
          -10801.813999999998,
          -10844.77,
          -10887.115,
          -10928.851999999999,
          -10969.982,
          -11010.508999999998,
          -11050.435,
          -11089.761999999999,
          -11128.493,
          -11166.631000000001,
          -11204.178999999998,
          -11241.136999999999,
          -11277.51,
          -11313.298,
          -11348.505,
          -11383.132,
          -11417.181999999999,
          -11450.657,
          -11483.559,
          -11515.891000000001,
          -11547.653,
          -11578.848,
          -11609.478000000001,
          -11639.546,
          -11669.053,
          -11698.001,
          -11726.391000000001,
          -11754.226999999999,
          -11781.508,
          -11808.238000000001,
          -11834.418,
          -11860.05,
          -11885.135,
          -11909.675,
          -11933.671999999999,
          -11957.127,
          -11980.041000000001,
          -12002.417,
          -12024.256000000001,
          -12045.559,
          -12066.328000000001,
          -12086.563999999998,
          -12106.268999999998,
          -12125.445,
          -12144.091,
          -12162.21,
          -12179.803999999998,
          -12196.872,
          -12213.417,
          -12229.441,
          -12244.943000000001,
          -12259.925,
          -12274.389,
          -12288.335,
          -12301.765,
          -12314.678999999998,
          -12327.079,
          -12338.966999999999,
          -12350.341999999999,
          -12361.207,
          -12371.561000000002,
          -12381.406,
          -12390.743,
          -12399.573,
          -12407.896,
          -12415.714,
          -12423.027,
          -12429.837,
          -12436.143999999998,
          -12441.948,
          -12447.252,
          -12452.053999999998,
          -12456.357,
          -12460.16,
          -12463.465,
          -12466.273000000001,
          -12468.583,
          -12470.396999999999,
          -12471.716,
          -12472.538999999999,
          -12472.867,
          -12472.702,
          -12472.043,
          -12470.891000000001,
          -12469.247,
          -12467.111,
          -12464.483,
          -12461.364,
          -12457.755,
          -12453.655,
          -12449.066,
          -12443.988000000001,
          -12438.421,
          -12432.365,
          -12425.821000000002,
          -12418.788999999999,
          -12411.27,
          -12403.263,
          -12394.768999999998,
          -12385.788,
          -12376.321000000002,
          -12366.367,
          -12355.927,
          -12345.002,
          -12333.59,
          -12321.693000000001,
          -12309.31,
          -12296.441,
          -12283.088,
          -12269.249,
          -12254.926000000001,
          -12240.117,
          -12224.823,
          -12209.044,
          -12192.78,
          -12176.031,
          -12158.796999999999,
          -12141.077,
          -12122.873,
          -12104.183,
          -12085.008,
          -12065.347,
          -12045.2,
          -12024.568000000001,
          -12003.45,
          -11981.845,
          -11959.753999999999,
          -11937.176000000001,
          -11914.112,
          -11890.561000000002,
          -11866.521999999999,
          -11841.996000000001,
          -11816.981000000002,
          -11791.479,
          -11765.488000000001,
          -11739.008,
          -11712.038,
          -11684.579,
          -11656.63,
          -11628.19,
          -11599.258999999998,
          -11569.837,
          -11539.923,
          -11509.516000000001,
          -11478.616000000002,
          -11447.223,
          -11415.336000000001,
          -11382.954,
          -11350.077,
          -11316.705,
          -11282.836000000001,
          -11248.47,
          -11213.606000000002,
          -11178.243999999999,
          -11142.383,
          -11106.023000000001,
          -11069.161,
          -11031.798999999999,
          -10993.934,
          -10955.567,
          -10916.696000000002,
          -10877.32,
          -10837.44,
          -10797.053,
          -10756.16,
          -10714.758,
          -10672.848,
          -10630.428,
          -10587.497,
          -10544.055,
          -10500.1,
          -10455.631,
          -10410.648000000001,
          -10365.148000000001,
          -10319.132,
          -10272.598,
          -10225.545,
          -10177.971,
          -10129.876,
          -10081.258,
          -10032.117,
          -9982.45,
          -9932.258,
          -9881.538,
          -9830.289,
          -9778.51,
          -9726.2,
          -9673.356,
          -9619.979,
          -9566.065999999999,
          -9511.616,
          -9456.628,
          -9401.099,
          -9345.03,
          -9288.417,
          -9231.259,
          -9173.556,
          -9115.306,
          -9056.506,
          -8997.155,
          -8937.253,
          -8876.796,
          -8815.783000000001,
          -8754.213,
          -8692.084,
          -8629.393,
          -8566.14,
          -8502.323,
          -8437.939,
          -8372.987,
          -8307.465,
          -8241.371,
          -8174.703,
          -8107.459,
          -8039.638000000001,
          -7971.238,
          -7902.255,
          -7832.689,
          -7762.5380000000005,
          -7691.798000000001,
          -7620.469,
          -7548.548000000001,
          -7476.034000000001,
          -7402.923000000001,
          -7329.213000000001,
          -7254.904,
          -7179.991999999999,
          -7104.476,
          -7028.353,
          -6951.621,
          -6874.276999999999,
          -6796.321,
          -6717.749,
          -6638.559,
          -6558.749,
          -6478.316999999999,
          -6397.2609999999995,
          -6315.578,
          -6233.266,
          -6150.323,
          -6066.746999999999,
          -5982.536,
          -5897.687,
          -5812.1990000000005,
          -5726.069,
          -5639.295999999999,
          -5551.8769999999995,
          -5463.81,
          -5375.094,
          -5285.726,
          -5195.705,
          -5105.029,
          -5013.696,
          -4921.705,
          -4829.054,
          -4735.742,
          -4641.768,
          -4547.13,
          -4451.8279999999995,
          -4355.86,
          -4259.226,
          -4161.925,
          -4063.9570000000003,
          -3965.322,
          -3866.0209999999997,
          -3766.051,
          -3665.4159999999997,
          -3564.117,
          -3462.1540000000005,
          -3359.528,
          -3256.243,
          -3152.3,
          -3047.703,
          -2942.455,
          -2836.559,
          -2730.022,
          -2622.847,
          -2515.042,
          -2406.612,
          -2297.5660000000003,
          -2187.9120000000003,
          -2077.66,
          -1966.8220000000001,
          -1855.408,
          -1743.433,
          -1630.912,
          -1517.86,
          -1404.297,
          -1290.242,
          -1175.718,
          -1060.749,
          -945.363,
          -829.591,
          -713.4639999999999,
          -597.02,
          -480.29900000000004,
          -363.345,
          -246.207,
          -128.939,
          -11.599,
          105.74700000000001,
          223.028,
          340.164,
          457.07,
          573.649,
          689.797,
          805.3989999999999,
          920.327,
          1034.442,
          1147.59,
          1259.603,
          1370.297,
          1479.4679999999998,
          1586.896,
          1692.338,
          1795.529,
          1896.182,
          1993.985,
          2088.6,
          2179.6620000000003,
          2266.782,
          2349.544,
          2427.508,
          2500.21,
          2567.172,
          2627.9,
          2681.893,
          2728.652,
          2767.69,
          2798.546,
          2820.789,
          2834.0429999999997,
          2837.991,
          2832.3920000000003,
          2817.0890000000004,
          2792.02,
          2757.218,
          2712.8179999999998,
          2659.046,
          2596.219,
          2524.729,
          2445.034,
          2357.6420000000003,
          2263.096,
          2161.9629999999997,
          2054.8179999999998,
          1942.231,
          1824.761,
          1702.95,
          1577.308,
          1448.3220000000001,
          1316.444,
          1182.087,
          1045.639,
          907.452,
          767.845,
          627.11,
          485.506,
          343.269,
          200.611,
          57.721000000000004,
          -85.234,
          -228.10299999999998,
          -370.75199999999995,
          -513.253,
          -654.934,
          -796.268,
          -936.9860000000001,
          -1077.015,
          -1216.292,
          -1354.763,
          -1492.3770000000002,
          -1629.095,
          -1764.879,
          -1899.6989999999998,
          -2033.526,
          -2166.3379999999997,
          -2298.115,
          -2428.842,
          -2558.504,
          -2687.091,
          -2814.593,
          -2941.005,
          -3066.321,
          -3190.538,
          -3313.653,
          -3435.6659999999997,
          -3556.577,
          -3676.388,
          -3795.1009999999997,
          -3912.717,
          -4029.241,
          -4144.678,
          -4259.032,
          -4372.308,
          -4484.512,
          -4595.649,
          -4705.725,
          -4814.748,
          -4922.723,
          -5029.657,
          -5135.559,
          -5240.434,
          -5344.29,
          -5447.134,
          -5548.973000000001,
          -5649.815,
          -5749.668000000001,
          -5848.5380000000005,
          -5946.434,
          -6043.361,
          -6139.329000000001,
          -6234.344,
          -6328.414000000001,
          -6421.545,
          -6513.746,
          -6605.024,
          -6695.385,
          -6784.835999999999,
          -6873.385,
          -6961.0380000000005,
          -7047.802,
          -7133.685,
          -7218.691999999999,
          -7302.831,
          -7386.108,
          -7468.529,
          -7550.101,
          -7630.83,
          -7710.722,
          -7789.783,
          -7868.02,
          -7945.438,
          -8022.043000000001,
          -8097.840999999999,
          -8172.838000000001,
          -8247.039,
          -8320.45,
          -8393.077,
          -8464.924,
          -8535.997,
          -8606.302,
          -8675.841999999999,
          -8744.625,
          -8812.653,
          -8879.933,
          -8946.468,
          -9012.265,
          -9077.328000000001,
          -9141.66,
          -9205.268,
          -9268.155,
          -9330.325,
          -9391.783000000001,
          -9452.534,
          -9512.581,
          -9571.929,
          -9630.582,
          -9688.543,
          -9745.817,
          -9802.407,
          -9858.317,
          -9913.552,
          -9968.114,
          -10022.009,
          -10075.238000000001,
          -10127.806,
          -10179.716,
          -10230.972,
          -10281.577,
          -10331.534,
          -10380.847,
          -10429.518,
          -10477.551,
          -10524.948999999999,
          -10571.716,
          -10617.853000000001,
          -10663.364,
          -10708.253,
          -10752.521999999999,
          -10796.173,
          -10839.21,
          -10881.636,
          -10923.452,
          -10964.663,
          -11005.268999999998,
          -11045.274,
          -11084.681,
          -11123.492,
          -11161.708999999999,
          -11199.335,
          -11236.372,
          -11272.823,
          -11308.69,
          -11343.973999999998,
          -11378.678999999998,
          -11412.806,
          -11446.358999999999,
          -11479.338,
          -11511.746000000001,
          -11543.586000000001,
          -11574.858,
          -11605.565,
          -11635.708999999999,
          -11665.292,
          -11694.316,
          -11722.783000000001,
          -11750.694,
          -11778.052,
          -11804.857,
          -11831.112,
          -11856.818000000001,
          -11881.978000000001,
          -11906.593,
          -11930.665,
          -11954.194,
          -11977.183,
          -11999.633999999998,
          -12021.546999999999,
          -12042.923999999999,
          -12063.767,
          -12084.078000000001,
          -12103.856000000002,
          -12123.105,
          -12141.825,
          -12160.018,
          -12177.684,
          -12194.826000000001,
          -12211.444,
          -12227.54,
          -12243.114,
          -12258.169,
          -12272.705,
          -12286.723999999998,
          -12300.226,
          -12313.213,
          -12325.685,
          -12337.645,
          -12349.091999999999,
          -12360.028,
          -12370.454,
          -12380.371000000001,
          -12389.778999999999,
          -12398.681,
          -12407.075,
          -12414.964,
          -12422.348999999998,
          -12429.23,
          -12435.607,
          -12441.482,
          -12446.856000000002,
          -12451.729,
          -12456.101999999999,
          -12459.976999999999,
          -12463.351999999999,
          -12466.23,
          -12468.611,
          -12470.495,
          -12471.883999999998,
          -12472.777,
          -12473.175,
          -12473.08,
          -12472.491000000002,
          -12471.409,
          -12469.833999999999,
          -12467.767,
          -12465.208999999999,
          -12462.16,
          -12458.62,
          -12454.591,
          -12450.071000000002,
          -12445.061000000002,
          -12439.563,
          -12433.576000000001,
          -12427.101,
          -12420.138,
          -12412.688,
          -12404.75,
          -12396.325,
          -12387.413,
          -12378.014,
          -12368.13,
          -12357.758,
          -12346.901000000002,
          -12335.558,
          -12323.73,
          -12311.415,
          -12298.616000000002,
          -12285.331,
          -12271.56,
          -12257.305,
          -12242.563999999998,
          -12227.338,
          -12211.627,
          -12195.431,
          -12178.75,
          -12161.583999999999,
          -12143.933,
          -12125.796,
          -12107.173999999999,
          -12088.067,
          -12068.473999999998,
          -12048.395,
          -12027.831,
          -12006.78,
          -11985.243,
          -11963.22,
          -11940.711000000001,
          -11917.714,
          -11894.23,
          -11870.258999999998,
          -11845.8,
          -11820.854,
          -11795.418,
          -11769.493999999999,
          -11743.082,
          -11716.18,
          -11688.788,
          -11660.906,
          -11632.534,
          -11603.67,
          -11574.315,
          -11544.469,
          -11514.128999999999,
          -11483.296999999999,
          -11451.972,
          -11420.152,
          -11387.838,
          -11355.028,
          -11321.723,
          -11287.921,
          -11253.623,
          -11218.826000000001,
          -11183.531,
          -11147.737,
          -11111.443000000001,
          -11074.649,
          -11037.354,
          -10999.556999999999,
          -10961.257,
          -10922.454,
          -10883.146,
          -10843.332,
          -10803.013,
          -10762.187,
          -10720.853000000001,
          -10679.01,
          -10636.657,
          -10593.794,
          -10550.419,
          -10506.531,
          -10462.13,
          -10417.213,
          -10371.780999999999,
          -10325.832,
          -10279.365,
          -10232.379,
          -10184.873,
          -10136.845,
          -10088.295,
          -10039.222,
          -9989.623,
          -9939.498,
          -9888.845,
          -9837.664,
          -9785.953000000001,
          -9733.71,
          -9680.934000000001,
          -9627.624,
          -9573.779,
          -9519.396999999999,
          -9464.476,
          -9409.015,
          -9353.011999999999,
          -9296.466999999999,
          -9239.378,
          -9181.743,
          -9123.56,
          -9064.828000000001,
          -9005.546,
          -8945.711,
          -8885.322,
          -8824.377,
          -8762.875,
          -8700.814,
          -8638.192,
          -8575.007,
          -8511.258,
          -8446.942,
          -8382.058,
          -8316.604,
          -8250.578000000001,
          -8183.979,
          -8116.803000000001,
          -8049.05,
          -7980.718000000001,
          -7911.804,
          -7842.306,
          -7772.223000000001,
          -7701.552,
          -7630.2919999999995,
          -7558.439,
          -7485.993,
          -7412.95,
          -7339.31,
          -7265.069,
          -7190.226,
          -7114.778,
          -7038.723000000001,
          -6962.059,
          -6884.785,
          -6806.897,
          -6728.393,
          -6649.272,
          -6569.53,
          -6489.1669999999995,
          -6408.179,
          -6326.565,
          -6244.321,
          -6161.446999999999,
          -6077.939,
          -5993.797,
          -5909.016,
          -5823.596,
          -5737.535,
          -5650.829000000001,
          -5563.477,
          -5475.478,
          -5386.83,
          -5297.529,
          -5207.576,
          -5116.967000000001,
          -5025.701,
          -4933.777,
          -4841.193,
          -4747.948,
          -4654.04,
          -4559.468,
          -4464.231,
          -4368.3279999999995,
          -4271.759,
          -4174.522,
          -4076.619,
          -3978.048,
          -3878.809,
          -3778.903,
          -3678.3309999999997,
          -3577.093,
          -3475.191,
          -3372.6259999999997,
          -3269.401,
          -3165.5170000000003,
          -3060.978,
          -2955.7870000000003,
          -2849.948,
          -2743.465,
          -2636.344,
          -2528.59,
          -2420.212,
          -2311.216,
          -2201.611,
          -2091.406,
          -1980.612,
          -1869.241,
          -1757.307,
          -1644.8229999999999,
          -1531.807,
          -1418.277,
          -1304.252,
          -1189.754,
          -1074.809,
          -959.443,
          -843.686,
          -727.57,
          -611.131,
          -494.411,
          -377.45099999999996,
          -260.302,
          -143.015,
          -25.649,
          91.73100000000001,
          209.054,
          326.243,
          443.211,
          559.865,
          676.1,
          791.803,
          906.847,
          1021.0939999999999,
          1134.392,
          1246.576,
          1357.461,
          1466.8470000000002,
          1574.514,
          1680.224,
          1783.714,
          1884.6970000000001,
          1982.865,
          2077.883,
          2169.389,
          2256.996,
          2340.291,
          2418.835,
          2492.169,
          2559.814,
          2621.278,
          2676.06,
          2723.66,
          2763.592,
          2795.387,
          2818.613,
          2832.887,
          2837.885,
          2833.3579999999997,
          2819.138,
          2795.155,
          2761.4309999999996,
          2718.0890000000004,
          2665.348,
          2603.514,
          2532.973,
          2454.174,
          2367.623,
          2273.86,
          2173.449,
          2066.9629999999997,
          1954.977,
          1838.0479999999998,
          1716.7220000000002,
          1591.5120000000002,
          1462.904,
          1331.3570000000002,
          1197.29,
          1061.0910000000001,
          923.1160000000001,
          783.688,
          643.1,
          501.616,
          359.475,
          216.89,
          74.05199999999999,
          -68.868,
          -211.71900000000002,
          -354.366,
          -496.68699999999995,
          -638.578,
          -779.945,
          -920.704,
          -1060.7830000000001,
          -1200.118,
          -1338.652,
          -1476.336,
          -1613.129,
          -1748.993,
          -1883.896,
          -2017.81,
          -2150.7129999999997,
          -2282.584,
          -2413.406,
          -2543.167,
          -2671.8540000000003,
          -2799.4570000000003,
          -2925.972,
          -3051.393,
          -3175.715,
          -3298.937,
          -3421.0570000000002,
          -3542.0759999999996,
          -3661.995,
          -3780.816,
          -3898.5409999999997,
          -4015.1740000000004,
          -4130.721,
          -4245.184,
          -4358.569,
          -4470.8820000000005,
          -4582.128,
          -4692.314,
          -4801.446,
          -4909.529,
          -5016.572,
          -5122.581,
          -5227.564,
          -5331.528,
          -5434.479,
          -5536.425,
          -5637.374,
          -5737.3330000000005,
          -5836.309,
          -5934.309,
          -6031.342,
          -6127.414000000001,
          -6222.533,
          -6316.706,
          -6409.941,
          -6502.245,
          -6593.625,
          -6684.0869999999995,
          -6773.64,
          -6862.29,
          -6950.044,
          -7036.908,
          -7122.89,
          -7207.996999999999,
          -7292.235,
          -7375.61,
          -7458.129,
          -7539.798000000001,
          -7620.624,
          -7700.613,
          -7779.771,
          -7858.103,
          -7935.616999999999,
          -8012.315,
          -8088.2080000000005,
          -8163.299,
          -8237.594000000001,
          -8311.099,
          -8383.819,
          -8455.758,
          -8526.924,
          -8597.32,
          -8666.953000000001,
          -8735.826,
          -8803.945,
          -8871.315,
          -8937.942,
          -9003.828000000001,
          -9068.981,
          -9133.403,
          -9197.099,
          -9260.074,
          -9322.333,
          -9383.879,
          -9444.718,
          -9504.851999999999,
          -9564.287,
          -9623.026,
          -9681.074,
          -9738.434000000001,
          -9795.11,
          -9851.106,
          -9906.427,
          -9961.074,
          -10015.053,
          -10068.367,
          -10121.019,
          -10173.013,
          -10224.351999999999,
          -10275.04,
          -10325.08,
          -10374.476,
          -10423.23,
          -10471.346,
          -10518.826000000001,
          -10565.673999999999,
          -10611.893999999998,
          -10657.487,
          -10702.457,
          -10746.806999999999,
          -10790.538999999999,
          -10833.657,
          -10876.163,
          -10918.059,
          -10959.35,
          -11000.036,
          -11040.121000000001,
          -11079.607,
          -11118.497,
          -11156.793,
          -11194.497,
          -11231.613000000001,
          -11268.142,
          -11304.087,
          -11339.45,
          -11374.233,
          -11408.438,
          -11442.068000000001,
          -11475.124,
          -11507.61,
          -11539.526000000002,
          -11570.875,
          -11601.659,
          -11631.88,
          -11661.538999999999,
          -11690.639,
          -11719.181999999999,
          -11747.169,
          -11774.601999999999,
          -11801.483,
          -11827.813999999998,
          -11853.596000000001,
          -11878.831,
          -11903.521,
          -11927.667,
          -11951.271,
          -11974.335,
          -11996.86,
          -12018.847,
          -12040.298,
          -12061.215,
          -12081.598999999998,
          -12101.452,
          -12120.774,
          -12139.568000000001,
          -12157.833999999999,
          -12175.573,
          -12192.788,
          -12209.479,
          -12225.648000000001,
          -12241.296,
          -12256.423999999999,
          -12271.033000000001,
          -12285.124,
          -12298.698,
          -12311.758,
          -12324.303,
          -12336.333999999999,
          -12347.853000000001,
          -12358.861,
          -12369.358999999999,
          -12379.348,
          -12388.828000000001,
          -12397.8,
          -12406.266000000001,
          -12414.226,
          -12421.681999999999,
          -12428.633,
          -12435.082,
          -12441.028,
          -12446.473,
          -12451.417,
          -12455.862,
          -12459.806,
          -12463.253,
          -12466.201000000001,
          -12468.652,
          -12470.607,
          -12472.066,
          -12473.028999999999,
          -12473.498,
          -12473.472,
          -12472.953000000001,
          -12471.941,
          -12470.436000000002,
          -12468.438999999998,
          -12465.951000000001,
          -12462.971000000001,
          -12459.501,
          -12455.541000000001,
          -12451.09,
          -12446.151000000002,
          -12440.722,
          -12434.805,
          -12428.399,
          -12421.505,
          -12414.123,
          -12406.253999999999,
          -12397.898000000001,
          -12389.055,
          -12379.725,
          -12369.909,
          -12359.607,
          -12348.818000000001,
          -12337.544,
          -12325.784,
          -12313.538,
          -12300.806999999999,
          -12287.591,
          -12273.889,
          -12259.702,
          -12245.03,
          -12229.872,
          -12214.23,
          -12198.101999999999,
          -12181.489,
          -12164.392,
          -12146.808,
          -12128.74,
          -12110.186000000002,
          -12091.146999999999,
          -12071.622,
          -12051.611,
          -12031.115,
          -12010.132,
          -11988.663,
          -11966.708,
          -11944.265,
          -11921.337,
          -11897.921,
          -11874.017,
          -11849.626,
          -11824.748,
          -11799.38,
          -11773.524,
          -11747.178999999998,
          -11720.345,
          -11693.021,
          -11665.207,
          -11636.902,
          -11608.106000000002,
          -11578.819,
          -11549.04,
          -11518.768,
          -11488.003999999999,
          -11456.746000000001,
          -11424.993,
          -11392.747,
          -11360.005,
          -11326.767,
          -11293.033000000001,
          -11258.802,
          -11224.073,
          -11188.846000000001,
          -11153.12,
          -11116.893999999998,
          -11080.167,
          -11042.938999999998,
          -11005.208999999999,
          -10966.976999999999,
          -10928.241000000002,
          -10889,
          -10849.255,
          -10809.003,
          -10768.243999999999,
          -10726.976999999999,
          -10685.202,
          -10642.917,
          -10600.121000000001,
          -10556.813999999998,
          -10512.993999999999,
          -10468.66,
          -10423.811,
          -10378.447,
          -10332.565999999999,
          -10286.167,
          -10239.249,
          -10191.81,
          -10143.85,
          -10095.368,
          -10046.362,
          -9996.831,
          -9946.774,
          -9896.189,
          -9845.076,
          -9793.431999999999,
          -9741.256,
          -9688.548,
          -9635.306999999999,
          -9581.529,
          -9527.215,
          -9472.362,
          -9416.969000000001,
          -9361.036,
          -9304.559000000001,
          -9247.538,
          -9189.971,
          -9131.856,
          -9073.193000000001,
          -9013.978000000001,
          -8954.212,
          -8893.891,
          -8833.015,
          -8771.581,
          -8709.588,
          -8647.034,
          -8583.918,
          -8520.237,
          -8455.99,
          -8391.175,
          -8325.789,
          -8259.832,
          -8193.302,
          -8126.195,
          -8058.51,
          -7990.246,
          -7921.401,
          -7851.972,
          -7781.9580000000005,
          -7711.356,
          -7640.164000000001,
          -7568.38,
          -7496.003000000001,
          -7423.029,
          -7349.4580000000005,
          -7275.286,
          -7200.512,
          -7125.133000000001,
          -7049.147,
          -6972.553000000001,
          -6895.347,
          -6817.528,
          -6739.094,
          -6660.041,
          -6580.369000000001,
          -6500.0740000000005,
          -6419.155,
          -6337.61,
          -6255.435,
          -6172.629,
          -6089.19,
          -6005.116,
          -5920.404,
          -5835.053000000001,
          -5749.06,
          -5662.423000000001,
          -5575.14,
          -5487.21,
          -5398.629,
          -5309.397,
          -5219.5109999999995,
          -5128.97,
          -5037.772,
          -4945.915,
          -4853.399,
          -4760.22,
          -4666.379,
          -4571.873,
          -4476.7029999999995,
          -4380.866,
          -4284.363,
          -4187.192,
          -4089.3520000000003,
          -3990.845,
          -3891.671,
          -3791.829,
          -3691.3190000000004,
          -3590.1440000000002,
          -3488.303,
          -3385.8,
          -3282.634,
          -3178.81,
          -3074.33,
          -2969.196,
          -2863.414,
          -2756.987,
          -2649.921,
          -2542.221,
          -2433.895,
          -2324.95,
          -2215.393,
          -2105.236,
          -1994.487,
          -1883.16,
          -1771.266,
          -1658.8210000000001,
          -1545.8410000000001,
          -1432.344,
          -1318.35,
          -1203.88,
          -1088.9589999999998,
          -973.613,
          -857.8710000000001,
          -741.7669999999999,
          -625.336,
          -508.61699999999996,
          -391.653,
          -274.493,
          -157.189,
          -39.798,
          77.615,
          194.98,
          312.22,
          429.251,
          545.9780000000001,
          662.3,
          778.102,
          893.2610000000001,
          1007.6389999999999,
          1121.087,
          1233.438,
          1344.513,
          1454.112,
          1562.019,
          1667.995,
          1771.78,
          1873.0929999999998,
          1971.624,
          2067.0429999999997,
          2158.991,
          2247.083,
          2330.908,
          2410.032,
          2483.996,
          2552.322,
          2614.52,
          2670.09,
          2718.532,
          2759.355,
          2792.091,
          2816.302,
          2831.599,
          2837.65,
          2834.197,
          2821.0679999999998,
          2798.176,
          2765.5370000000003,
          2723.262,
          2671.559,
          2610.728,
          2541.143,
          2463.2529999999997,
          2377.553,
          2284.5820000000003,
          2184.901,
          2079.0860000000002,
          1967.707,
          1851.329,
          1730.494,
          1605.721,
          1477.5,
          1346.2920000000001,
          1212.519,
          1076.5739999999998,
          938.815,
          799.57,
          659.133,
          517.7719999999999,
          375.728,
          233.217,
          90.43299999999999,
          -52.451,
          -195.283,
          -337.925,
          -480.256,
          -622.168,
          -763.566,
          -904.3660000000001,
          -1044.495,
          -1183.886,
          -1322.485,
          -1460.239,
          -1597.108,
          -1733.0510000000002,
          -1868.039,
          -2002.0410000000002,
          -2135.035,
          -2266.999,
          -2397.9179999999997,
          -2527.778,
          -2656.565,
          -2784.2709999999997,
          -2910.89,
          -3036.415,
          -3160.843,
          -3284.172,
          -3406.4,
          -3527.527,
          -3647.555,
          -3766.485,
          -3884.32,
          -4001.0640000000003,
          -4116.72,
          -4231.293,
          -4344.788,
          -4457.21,
          -4568.566,
          -4678.861,
          -4788.102,
          -4896.295,
          -5003.448,
          -5109.566,
          -5214.657,
          -5318.729,
          -5421.7880000000005,
          -5523.840999999999,
          -5624.897,
          -5724.9619999999995,
          -5824.044,
          -5922.15,
          -6019.2880000000005,
          -6115.465,
          -6210.689,
          -6304.967,
          -6398.305,
          -6490.7119999999995,
          -6582.194,
          -6672.759,
          -6762.414000000001,
          -6851.165,
          -6939.02,
          -7025.986,
          -7112.068,
          -7197.274,
          -7281.611,
          -7365.085,
          -7447.701999999999,
          -7529.469,
          -7610.393,
          -7690.478,
          -7769.733,
          -7848.161999999999,
          -7925.771,
          -8002.566999999999,
          -8078.555,
          -8153.741,
          -8228.131,
          -8301.729,
          -8374.542,
          -8446.575,
          -8517.834,
          -8588.322,
          -8658.046999999999,
          -8727.011999999999,
          -8795.222,
          -8862.683,
          -8929.4,
          -8995.377,
          -9060.619,
          -9125.13,
          -9188.916,
          -9251.98,
          -9314.327,
          -9375.962,
          -9436.888,
          -9497.11,
          -9556.632,
          -9615.458,
          -9673.593,
          -9731.039,
          -9787.801,
          -9843.884,
          -9899.289,
          -9954.021999999999,
          -10008.086,
          -10061.485,
          -10114.221,
          -10166.299,
          -10217.722,
          -10268.494,
          -10318.618,
          -10368.096,
          -10416.933,
          -10465.132,
          -10512.694,
          -10559.625,
          -10605.926000000001,
          -10651.601,
          -10696.653,
          -10741.083999999999,
          -10784.896999999999,
          -10828.096000000001,
          -10870.681999999999,
          -10912.659,
          -10954.028999999999,
          -10994.796,
          -11034.96,
          -11074.526000000002,
          -11113.495,
          -11151.87,
          -11189.653999999999,
          -11226.848,
          -11263.456,
          -11299.479,
          -11334.92,
          -11369.781,
          -11404.063999999998,
          -11437.771999999999,
          -11470.906,
          -11503.469,
          -11535.462,
          -11566.888,
          -11597.749,
          -11628.046,
          -11657.782,
          -11686.958999999999,
          -11715.577,
          -11743.64,
          -11771.149,
          -11798.106000000002,
          -11824.513,
          -11850.37,
          -11875.681,
          -11900.446000000002,
          -11924.667,
          -11948.346000000001,
          -11971.483999999999,
          -11994.083,
          -12016.145,
          -12037.671,
          -12058.662,
          -12079.12,
          -12099.046999999999,
          -12118.443000000001,
          -12137.31,
          -12155.65,
          -12173.463,
          -12190.751,
          -12207.516000000001,
          -12223.758,
          -12239.479,
          -12254.678999999998,
          -12269.361,
          -12283.525,
          -12297.171999999999,
          -12310.303999999998,
          -12322.921,
          -12335.025,
          -12346.616000000002,
          -12357.696000000002,
          -12368.266000000001,
          -12378.326000000001,
          -12387.878,
          -12396.921999999999,
          -12405.46,
          -12413.492,
          -12421.018,
          -12428.041000000001,
          -12434.561000000002,
          -12440.579,
          -12446.095,
          -12451.11,
          -12455.625,
          -12459.641000000001,
          -12463.158000000001,
          -12466.177,
          -12468.698999999999,
          -12470.723999999998,
          -12472.253,
          -12473.287,
          -12473.826000000001,
          -12473.87,
          -12473.421,
          -12472.479,
          -12471.044,
          -12469.117,
          -12466.698999999999,
          -12463.788999999999,
          -12460.389,
          -12456.498,
          -12452.118,
          -12447.248,
          -12441.888,
          -12436.04,
          -12429.704,
          -12422.88,
          -12415.567,
          -12407.767,
          -12399.48,
          -12390.706,
          -12381.446000000002,
          -12371.698999999999,
          -12361.465,
          -12350.746000000001,
          -12339.541000000001,
          -12327.848999999998,
          -12315.673,
          -12303.01,
          -12289.862,
          -12276.229,
          -12262.111,
          -12247.507,
          -12232.419,
          -12216.845,
          -12200.786,
          -12184.241000000002,
          -12167.212,
          -12149.697,
          -12131.697,
          -12113.211000000001,
          -12094.24,
          -12074.784,
          -12054.841,
          -12034.413,
          -12013.499,
          -11992.098,
          -11970.211000000001,
          -11947.837,
          -11924.976,
          -11901.628,
          -11877.793,
          -11853.47,
          -11828.659,
          -11803.36,
          -11777.572,
          -11751.295,
          -11724.528,
          -11697.271999999999,
          -11669.526000000002,
          -11641.288999999999,
          -11612.561000000002,
          -11583.341999999999,
          -11553.631000000001,
          -11523.427,
          -11492.73,
          -11461.54,
          -11429.855,
          -11397.676000000001,
          -11365.002,
          -11331.833,
          -11298.166000000001,
          -11264.003,
          -11229.341999999999,
          -11194.183,
          -11158.524,
          -11122.366000000002,
          -11085.708,
          -11048.546999999999,
          -11010.885,
          -10972.72,
          -10934.052,
          -10894.88,
          -10855.202,
          -10815.018,
          -10774.327,
          -10733.128,
          -10691.421,
          -10649.204,
          -10606.476,
          -10563.236,
          -10519.483999999999,
          -10475.218,
          -10430.438,
          -10385.141,
          -10339.328000000001,
          -10292.997,
          -10246.146999999999,
          -10198.777,
          -10150.885,
          -10102.471,
          -10053.533000000001,
          -10004.07,
          -9954.081,
          -9903.564,
          -9852.519,
          -9800.944,
          -9748.837,
          -9696.198,
          -9643.024,
          -9589.314,
          -9535.068000000001,
          -9480.284,
          -9424.96,
          -9369.094000000001,
          -9312.686,
          -9255.733,
          -9198.235,
          -9140.189,
          -9081.594000000001,
          -9022.448,
          -8962.75,
          -8902.499,
          -8841.690999999999,
          -8780.326,
          -8718.402,
          -8655.917,
          -8592.87,
          -8529.258,
          -8465.079,
          -8400.333,
          -8335.017,
          -8269.13,
          -8202.667,
          -8135.63,
          -8068.015,
          -7999.82,
          -7931.044,
          -7861.684,
          -7791.7390000000005,
          -7721.206,
          -7650.084,
          -7578.369000000001,
          -7506.061,
          -7433.156999999999,
          -7359.655,
          -7285.553000000001,
          -7210.848000000001,
          -7135.539000000001,
          -7059.6230000000005,
          -6983.098000000001,
          -6905.960999999999,
          -6828.2119999999995,
          -6749.847,
          -6670.8640000000005,
          -6591.2609999999995,
          -6511.036,
          -6430.187,
          -6348.71,
          -6266.605,
          -6183.869000000001,
          -6100.5,
          -6016.495,
          -5931.852,
          -5846.57,
          -5760.646,
          -5674.078,
          -5586.8640000000005,
          -5499.0019999999995,
          -5410.49,
          -5321.326999999999,
          -5231.51,
          -5141.037,
          -5049.907,
          -4958.119000000001,
          -4865.67,
          -4772.559,
          -4678.785,
          -4584.346,
          -4489.2429999999995,
          -4393.473,
          -4297.035,
          -4199.93,
          -4102.157,
          -4003.715,
          -3904.605,
          -3804.8259999999996,
          -3704.381,
          -3603.268,
          -3501.49,
          -3399.048,
          -3295.9440000000004,
          -3192.18,
          -3087.759,
          -2982.684,
          -2876.9590000000003,
          -2770.5890000000004,
          -2663.578,
          -2555.933,
          -2447.659,
          -2338.765,
          -2229.258,
          -2119.149,
          -2008.4470000000001,
          -1897.1629999999998,
          -1785.3120000000001,
          -1672.9070000000002,
          -1559.965,
          -1446.5020000000002,
          -1332.539,
          -1218.097,
          -1103.201,
          -987.8760000000001,
          -872.1510000000001,
          -756.059,
          -639.636,
          -522.919,
          -405.952,
          -288.782,
          -171.46200000000002,
          -54.047,
          63.397,
          180.803,
          298.094,
          415.186,
          531.985,
          648.3919999999999,
          764.293,
          879.565,
          994.072,
          1107.6680000000001,
          1220.187,
          1331.45,
          1441.2620000000002,
          1549.406,
          1655.646,
          1759.726,
          1861.365,
          1960.2579999999998,
          2056.077,
          2148.465,
          2237.04,
          2321.394,
          2401.095,
          2475.687,
          2544.6929999999998,
          2607.625,
          2663.982,
          2713.265,
          2754.9809999999998,
          2788.658,
          2813.8540000000003,
          2830.176,
          2837.283,
          2834.9120000000003,
          2822.8759999999997,
          2801.0820000000003,
          2769.535,
          2728.335,
          2677.6809999999996,
          2617.861,
          2549.245,
          2472.272,
          2387.433,
          2295.265,
          2196.325,
          2091.189,
          1980.4279999999999,
          1864.6070000000002,
          1744.2720000000002,
          1619.944,
          1492.1170000000002,
          1361.2520000000002,
          1227.779,
          1092.0919999999999,
          954.554,
          815.4939999999999,
          675.211,
          533.976,
          392.033,
          249.59900000000002,
          106.87100000000001,
          -35.977,
          -178.78900000000002,
          -321.426,
          -464.342,
          -605.698,
          -747.128,
          -887.9689999999999,
          -1028.1480000000001,
          -1167.597,
          -1306.259,
          -1444.0839999999998,
          -1581.0279999999998,
          -1717.0520000000001,
          -1852.124,
          -1986.214,
          -2119.3,
          -2251.359,
          -2382.375,
          -2512.333,
          -2641.2209999999995,
          -2769.031,
          -2895.7540000000004,
          -3021.385,
          -3145.92,
          -3269.3559999999998,
          -3391.6929999999998,
          -3512.929,
          -3633.066,
          -3752.1059999999998,
          -3870.052,
          -3986.906,
          -4102.673,
          -4217.355,
          -4330.960999999999,
          -4443.494000000001,
          -4554.960999999999,
          -4665.366,
          -4774.718,
          -4883.021,
          -4990.282999999999,
          -5096.51,
          -5201.71,
          -5305.891,
          -5409.058000000001,
          -5511.219,
          -5612.383000000001,
          -5712.555,
          -5811.743,
          -5909.956,
          -6007.2,
          -6103.483,
          -6198.811,
          -6293.194,
          -6386.6359999999995,
          -6479.147,
          -6570.733,
          -6661.4,
          -6751.156999999999,
          -6840.0109999999995,
          -6927.967,
          -7015.033,
          -7101.215999999999,
          -7186.522,
          -7270.9580000000005,
          -7354.531,
          -7437.2480000000005,
          -7519.113,
          -7600.135,
          -7680.318,
          -7759.669,
          -7838.195,
          -7915.901,
          -7992.7919999999995,
          -8068.876,
          -8144.156999999999,
          -8218.641,
          -8292.333,
          -8365.24,
          -8437.367,
          -8508.718,
          -8579.299,
          -8649.116,
          -8718.171999999999,
          -8786.474,
          -8854.027,
          -8920.834,
          -8986.902,
          -9052.234,
          -9116.835,
          -9180.71,
          -9243.864,
          -9306.3,
          -9368.023000000001,
          -9429.037,
          -9489.347,
          -9548.956,
          -9607.87,
          -9666.091,
          -9723.624,
          -9780.473,
          -9836.641,
          -9892.132,
          -9946.951,
          -10001.1,
          -10054.583,
          -10107.404,
          -10159.565999999999,
          -10211.074,
          -10261.929,
          -10312.136,
          -10361.698,
          -10410.618,
          -10458.899,
          -10506.545,
          -10553.558,
          -10599.941,
          -10645.698,
          -10690.831,
          -10735.343,
          -10779.238000000001,
          -10822.517,
          -10865.184,
          -10907.242,
          -10948.692,
          -10989.538999999999,
          -11029.783000000001,
          -11069.428999999998,
          -11108.476999999999,
          -11146.931999999999,
          -11184.794,
          -11222.067,
          -11258.753999999999,
          -11294.855,
          -11330.375,
          -11365.313999999998,
          -11399.675,
          -11433.46,
          -11466.671999999999,
          -11499.312,
          -11531.382,
          -11562.885,
          -11593.823,
          -11624.197,
          -11654.01,
          -11683.263,
          -11711.958,
          -11740.097,
          -11767.681999999999,
          -11794.714,
          -11821.196000000002,
          -11847.128999999999,
          -11872.515,
          -11897.355,
          -11921.652,
          -11945.405,
          -11968.618,
          -11991.292,
          -12013.428,
          -12035.028999999999,
          -12056.094,
          -12076.626,
          -12096.627,
          -12116.097,
          -12135.038,
          -12153.451000000001,
          -12171.338,
          -12188.698999999999,
          -12205.537,
          -12221.851999999999,
          -12237.646,
          -12252.919,
          -12267.673999999999,
          -12281.91,
          -12295.63,
          -12308.833999999999,
          -12321.524,
          -12333.7,
          -12345.363000000001,
          -12356.515,
          -12367.157,
          -12377.288999999999,
          -12386.913,
          -12396.035,
          -12404.643999999998,
          -12412.746000000001,
          -12420.343,
          -12427.437,
          -12434.027,
          -12440.115,
          -12445.701000000001,
          -12450.786,
          -12455.371000000001,
          -12459.457,
          -12463.044,
          -12466.132,
          -12468.723999999998,
          -12470.819,
          -12472.417,
          -12473.52,
          -12474.128999999999,
          -12474.243,
          -12473.863000000001,
          -12472.99,
          -12471.624,
          -12469.766000000001,
          -12467.417,
          -12464.576000000001,
          -12461.243999999999,
          -12457.423,
          -12453.111,
          -12448.309,
          -12443.018999999998,
          -12437.239,
          -12430.971000000001,
          -12424.215,
          -12416.971000000001,
          -12409.24,
          -12401.021,
          -12392.315,
          -12383.123,
          -12373.444,
          -12363.278,
          -12352.627,
          -12341.489,
          -12329.866000000002,
          -12317.757,
          -12305.163,
          -12292.083,
          -12278.517,
          -12264.466,
          -12249.931,
          -12234.909,
          -12219.403,
          -12203.411,
          -12186.934,
          -12169.972,
          -12152.525,
          -12134.591999999999,
          -12116.173999999999,
          -12097.27,
          -12077.881000000001,
          -12058.006000000001,
          -12037.645,
          -12016.798,
          -11995.464,
          -11973.643999999998,
          -11951.338,
          -11928.544,
          -11905.263,
          -11881.495,
          -11857.239,
          -11832.495,
          -11807.263,
          -11781.542,
          -11755.332,
          -11728.633,
          -11701.444,
          -11673.764,
          -11645.594,
          -11616.933,
          -11587.781,
          -11558.136,
          -11527.999,
          -11497.368999999999,
          -11466.245,
          -11434.627,
          -11402.515,
          -11369.908000000001,
          -11336.805,
          -11303.205,
          -11269.108999999999,
          -11234.515,
          -11199.421999999999,
          -11163.831,
          -11127.739,
          -11091.146999999999,
          -11054.053999999998,
          -11016.458999999999,
          -10978.362,
          -10939.76,
          -10900.655,
          -10861.044,
          -10820.927,
          -10780.303,
          -10739.171,
          -10697.53,
          -10655.38,
          -10612.719,
          -10569.546,
          -10525.861,
          -10481.662,
          -10436.948,
          -10391.719000000001,
          -10345.973,
          -10299.709,
          -10252.926,
          -10205.622,
          -10157.798,
          -10109.451,
          -10060.58,
          -10011.184000000001,
          -9961.261999999999,
          -9910.813,
          -9859.834,
          -9808.326,
          -9756.286,
          -9703.714,
          -9650.608,
          -9596.966,
          -9542.788,
          -9488.071,
          -9432.814,
          -9377.016,
          -9320.675,
          -9263.79,
          -9206.359,
          -9148.381,
          -9089.854,
          -9030.776,
          -8971.145,
          -8910.961,
          -8850.221,
          -8788.924,
          -8727.068000000001,
          -8664.651,
          -8601.671,
          -8538.127,
          -8474.017,
          -8409.339,
          -8344.091,
          -8278.271,
          -8211.878,
          -8144.908,
          -8077.361999999999,
          -8009.235,
          -7940.528,
          -7871.236,
          -7801.36,
          -7730.895,
          -7659.840999999999,
          -7588.194,
          -7515.955,
          -7443.119000000001,
          -7369.686,
          -7295.651999999999,
          -7221.016,
          -7145.775,
          -7069.927,
          -6993.471,
          -6916.403,
          -6838.723000000001,
          -6760.4259999999995,
          -6681.512,
          -6601.978,
          -6521.821,
          -6441.04,
          -6359.633000000001,
          -6277.597,
          -6194.929,
          -6111.628000000001,
          -6027.691999999999,
          -5943.118,
          -5857.904,
          -5772.049,
          -5685.549,
          -5598.403,
          -5510.61,
          -5422.166,
          -5333.07,
          -5243.321,
          -5152.916,
          -5061.853,
          -4970.1320000000005,
          -4877.749,
          -4784.706,
          -4690.998,
          -4596.627,
          -4501.589,
          -4405.885,
          -4309.513,
          -4212.474,
          -4114.766,
          -4016.388,
          -3917.343,
          -3817.6279999999997,
          -3717.2459999999996,
          -3616.196,
          -3514.48,
          -3412.099,
          -3309.0559999999996,
          -3205.3520000000003,
          -3100.99,
          -2995.973,
          -2890.3059999999996,
          -2783.992,
          -2677.0359999999996,
          -2569.444,
          -2461.224,
          -2352.381,
          -2242.924,
          -2132.862,
          -2022.2060000000001,
          -1910.967,
          -1799.158,
          -1686.793,
          -1573.888,
          -1460.46,
          -1346.529,
          -1232.117,
          -1117.246,
          -1001.943,
          -886.2360000000001,
          -770.158,
          -653.743,
          -537.029,
          -420.061,
          -302.883,
          -185.547,
          -68.111,
          49.364,
          166.808,
          284.147,
          401.29699999999997,
          518.1659999999999,
          634.654,
          750.65,
          866.0319999999999,
          980.6669999999999,
          1094.405,
          1207.086,
          1318.533,
          1428.55,
          1536.925,
          1643.4229999999998,
          1747.79,
          1849.7479999999998,
          1948.995,
          2045.204,
          2138.021,
          2227.069,
          2311.9410000000003,
          2392.2070000000003,
          2467.413,
          2537.0860000000002,
          2600.737,
          2657.867,
          2707.975,
          2750.567,
          2785.1690000000003,
          2811.335,
          2828.665,
          2836.813,
          2835.508,
          2824.552,
          2803.845,
          2773.3790000000004,
          2733.245,
          2683.63,
          2624.815,
          2557.161,
          2481.099,
          2397.119,
          2305.748,
          2207.548,
          2103.0879999999997,
          1992.942,
          1877.6770000000001,
          1757.84,
          1633.9560000000001,
          1506.5220000000002,
          1376.001,
          1242.826,
          1107.397,
          970.078,
          831.203,
          691.074,
          549.964,
          408.12,
          265.763,
          123.09,
          -19.721,
          -162.513,
          -305.145,
          -447.494,
          -589.447,
          -730.908,
          -871.791,
          -1012.0189999999999,
          -1151.525,
          -1290.251,
          -1428.1470000000002,
          -1565.1660000000002,
          -1701.27,
          -1836.4260000000002,
          -1970.605,
          -2103.781,
          -2235.9339999999997,
          -2367.047,
          -2497.104,
          -2626.094,
          -2754.006,
          -2880.833,
          -3006.5690000000004,
          -3131.21,
          -3254.7540000000004,
          -3377.198,
          -3498.5429999999997,
          -3618.789,
          -3737.938,
          -3855.993,
          -3972.9570000000003,
          -4088.833,
          -4203.627,
          -4317.343,
          -4429.985,
          -4541.561,
          -4652.076,
          -4761.536,
          -4869.9490000000005,
          -4977.319,
          -5083.655,
          -5188.964,
          -5293.2519999999995,
          -5396.526,
          -5498.795,
          -5600.065,
          -5700.344,
          -5799.639,
          -5897.956999999999,
          -5995.306,
          -6091.693,
          -6187.126,
          -6281.611999999999,
          -6375.158,
          -6467.771,
          -6559.4580000000005,
          -6650.227,
          -6740.085999999999,
          -6829.04,
          -6917.097,
          -7004.263000000001,
          -7090.545,
          -7175.951,
          -7260.486,
          -7344.156999999999,
          -7426.971,
          -7508.934,
          -7590.052,
          -7670.331999999999,
          -7749.779,
          -7828.4,
          -7906.201,
          -7983.188,
          -8059.365,
          -8134.74,
          -8209.318000000001,
          -8283.103000000001,
          -8356.103000000001,
          -8428.322,
          -8499.764000000001,
          -8570.437,
          -8640.345,
          -8709.492,
          -8777.885,
          -8845.528,
          -8912.425,
          -8978.582,
          -9044.003,
          -9108.693000000001,
          -9172.655999999999,
          -9235.896999999999,
          -9298.421,
          -9360.231,
          -9421.333,
          -9481.729,
          -9541.425,
          -9600.425,
          -9658.731,
          -9716.35,
          -9773.284,
          -9829.537,
          -9885.113000000001,
          -9940.015,
          -9994.248,
          -10047.815999999999,
          -10100.72,
          -10152.966,
          -10204.556,
          -10255.494,
          -10305.783000000001,
          -10355.427,
          -10404.429,
          -10452.792,
          -10500.518999999998,
          -10547.613000000001,
          -10594.077,
          -10639.913999999999,
          -10685.128,
          -10729.72,
          -10773.695,
          -10817.053999999998,
          -10859.801000000001,
          -10901.938,
          -10943.466999999999,
          -10984.392,
          -11024.716,
          -11064.44,
          -11103.567,
          -11142.098999999998,
          -11180.04,
          -11217.391000000001,
          -11254.155,
          -11290.333999999999,
          -11325.931,
          -11360.947,
          -11395.383999999998,
          -11429.246000000001,
          -11462.534,
          -11495.251,
          -11527.396999999999,
          -11558.976,
          -11589.989,
          -11620.438,
          -11650.326000000001,
          -11679.653999999999,
          -11708.423999999999,
          -11736.638,
          -11764.298,
          -11791.405,
          -11817.962,
          -11843.969,
          -11869.428999999998,
          -11894.343,
          -11918.714,
          -11942.541000000001,
          -11965.828000000001,
          -11988.576000000001,
          -12010.786,
          -12032.458999999999,
          -12053.598,
          -12074.203000000001,
          -12094.276000000002,
          -12113.819,
          -12132.832,
          -12151.318000000001,
          -12169.277,
          -12186.711000000001,
          -12203.621000000001,
          -12220.008,
          -12235.873,
          -12251.219,
          -12266.045,
          -12280.353000000001,
          -12294.143999999998,
          -12307.419,
          -12320.18,
          -12332.427,
          -12344.162,
          -12355.385,
          -12366.097,
          -12376.3,
          -12385.993999999999,
          -12395.18,
          -12403.86,
          -12412.034,
          -12419.702,
          -12426.867,
          -12433.528,
          -12439.687,
          -12445.344,
          -12450.5,
          -12455.155,
          -12459.311000000002,
          -12462.969,
          -12466.128,
          -12468.79,
          -12470.955,
          -12472.623,
          -12473.796999999999,
          -12474.475,
          -12474.659,
          -12474.348999999998,
          -12473.546,
          -12472.25,
          -12470.462,
          -12468.181999999999,
          -12465.41,
          -12462.148000000001,
          -12458.396,
          -12454.153,
          -12449.421,
          -12444.2,
          -12438.49,
          -12432.291000000001,
          -12425.604,
          -12418.428999999998,
          -12410.767,
          -12402.617,
          -12393.98,
          -12384.857,
          -12375.246000000001,
          -12365.149,
          -12354.566,
          -12343.498,
          -12331.943000000001,
          -12319.902,
          -12307.376,
          -12294.365,
          -12280.868,
          -12266.886,
          -12252.418,
          -12237.465,
          -12222.027,
          -12206.104,
          -12189.695,
          -12172.801000000001,
          -12155.421999999999,
          -12137.556999999999,
          -12119.207,
          -12100.372,
          -12081.05,
          -12061.243,
          -12040.95,
          -12020.171,
          -11998.905,
          -11977.153,
          -11954.915,
          -11932.188999999998,
          -11908.976,
          -11885.276000000002,
          -11861.088,
          -11836.412,
          -11811.247,
          -11785.594,
          -11759.452,
          -11732.82,
          -11705.698999999999,
          -11678.087,
          -11649.985,
          -11621.391000000001,
          -11592.306999999999,
          -11562.73,
          -11532.66,
          -11502.098,
          -11471.041000000001,
          -11439.492,
          -11407.447,
          -11374.907,
          -11341.872,
          -11308.34,
          -11274.311000000002,
          -11239.785,
          -11204.76,
          -11169.236,
          -11133.212,
          -11096.688,
          -11059.663,
          -11022.135,
          -10984.105,
          -10945.572,
          -10906.534,
          -10866.99,
          -10826.941,
          -10786.385,
          -10745.321000000002,
          -10703.748,
          -10661.665,
          -10619.072,
          -10575.966999999999,
          -10532.35,
          -10488.219,
          -10443.573,
          -10398.411,
          -10352.733,
          -10306.537,
          -10259.822,
          -10212.586,
          -10164.83,
          -10116.551,
          -10067.748,
          -10018.42,
          -9968.565999999999,
          -9918.185,
          -9867.274,
          -9815.834,
          -9763.863000000001,
          -9711.359,
          -9658.321,
          -9604.748,
          -9550.636999999999,
          -9495.989,
          -9440.8,
          -9385.071,
          -9328.798,
          -9271.982,
          -9214.619,
          -9156.71,
          -9098.253,
          -9039.243,
          -8979.681999999999,
          -8919.565999999999,
          -8858.895,
          -8797.667,
          -8735.879,
          -8673.530999999999,
          -8610.62,
          -8547.145,
          -8483.104,
          -8418.495,
          -8353.315999999999,
          -8287.565,
          -8221.24,
          -8154.34,
          -8086.863,
          -8018.806,
          -7950.1669999999995,
          -7880.945,
          -7811.138000000001,
          -7740.741999999999,
          -7669.758000000001,
          -7598.181,
          -7526.0109999999995,
          -7453.245,
          -7379.880999999999,
          -7305.9169999999995,
          -7231.35,
          -7156.179,
          -7080.401,
          -7004.014,
          -6927.016,
          -6849.405,
          -6771.178000000001,
          -6692.3330000000005,
          -6612.868,
          -6532.781999999999,
          -6452.07,
          -6370.732,
          -6288.765,
          -6206.1669999999995,
          -6122.936,
          -6039.069,
          -5954.565,
          -5869.42,
          -5783.634,
          -5697.203,
          -5610.1269999999995,
          -5522.401999999999,
          -5434.026999999999,
          -5345.001,
          -5255.319,
          -5164.983,
          -5073.988,
          -4982.335,
          -4890.021,
          -4797.045,
          -4703.406,
          -4609.101,
          -4514.130999999999,
          -4418.494000000001,
          -4322.189,
          -4225.215,
          -4127.573,
          -4029.261,
          -3930.28,
          -3830.63,
          -3730.3109999999997,
          -3629.325,
          -3527.672,
          -3425.353,
          -3322.3709999999996,
          -3218.728,
          -3114.426,
          -3009.468,
          -2903.8590000000004,
          -2797.6009999999997,
          -2690.702,
          -2583.165,
          -2474.9970000000003,
          -2366.206,
          -2256.8,
          -2146.7870000000003,
          -2036.1779999999999,
          -1924.984,
          -1813.2179999999998,
          -1700.894,
          -1588.027,
          -1474.635,
          -1360.736,
          -1246.353,
          -1131.508,
          -1016.227,
          -900.538,
          -784.4739999999999,
          -668.068,
          -551.3580000000001,
          -434.38800000000003,
          -317.202,
          -199.852,
          -82.39399999999999,
          35.111,
          152.594,
          269.981,
          387.189,
          504.12800000000004,
          620.698,
          736.789,
          852.2810000000001,
          967.041,
          1080.924,
          1193.768,
          1305.399,
          1415.6229999999998,
          1524.229,
          1630.986,
          1735.641,
          1837.918,
          1937.52,
          2034.12,
          2127.37,
          2216.891,
          2302.282,
          2383.116,
          2458.94,
          2529.283,
          2593.657,
          2651.5640000000003,
          2702.502,
          2745.978,
          2781.512,
          2808.655,
          2827.0029999999997,
          2836.204,
          2835.975,
          2826.113,
          2806.506,
          2777.134,
          2738.08,
          2689.5209999999997,
          2631.728,
          2565.052,
          2489.919,
          2406.813,
          2316.257,
          2218.81,
          2115.042,
          2005.5279999999998,
          1890.832,
          1771.507,
          1648.078,
          1521.047,
          1390.88,
          1258.014,
          1122.851,
          985.7589999999999,
          847.076,
          707.107,
          566.128,
          424.389,
          282.112,
          139.498,
          -3.273,
          -146.042,
          -288.66700000000003,
          -431.022,
          -572.994,
          -714.485,
          -855.408,
          -995.684,
          -1135.247,
          -1274.037,
          -1412.001,
          -1549.096,
          -1685.28,
          -1820.52,
          -1954.787,
          -2088.055,
          -2220.303,
          -2351.513,
          -2481.669,
          -2610.76,
          -2738.775,
          -2865.7070000000003,
          -2991.5490000000004,
          -3116.297,
          -3239.948,
          -3362.5009999999997,
          -3483.955,
          -3604.3109999999997,
          -3723.57,
          -3841.735,
          -3958.81,
          -4074.797,
          -4189.702,
          -4303.528,
          -4416.282,
          -4527.969,
          -4638.595,
          -4748.165,
          -4856.688,
          -4964.168,
          -5070.6140000000005,
          -5176.031,
          -5280.428000000001,
          -5383.811,
          -5486.188,
          -5587.566,
          -5687.951999999999,
          -5787.354,
          -5885.778,
          -5983.233,
          -6079.726,
          -6175.264,
          -6269.855,
          -6363.505,
          -6456.222,
          -6548.014,
          -6638.8859999999995,
          -6728.846,
          -6817.901999999999,
          -6906.06,
          -6993.326999999999,
          -7079.710999999999,
          -7165.215999999999,
          -7249.851,
          -7333.621999999999,
          -7416.534000000001,
          -7498.596,
          -7579.812,
          -7660.189,
          -7739.734,
          -7818.451,
          -7896.349,
          -7973.431,
          -8049.704000000001,
          -8125.174,
          -8199.846,
          -8273.726,
          -8346.819,
          -8419.131,
          -8490.667,
          -8561.433,
          -8631.433,
          -8700.673,
          -8769.157,
          -8836.891,
          -8903.879,
          -8970.126,
          -9035.636999999999,
          -9100.417,
          -9164.47,
          -9227.8,
          -9290.412,
          -9352.311,
          -9413.5,
          -9473.985,
          -9533.768,
          -9592.855,
          -9651.248,
          -9708.953000000001,
          -9765.973,
          -9822.312,
          -9877.974,
          -9932.962,
          -9987.28,
          -10040.931999999999,
          -10093.921,
          -10146.251,
          -10197.926,
          -10248.948,
          -10299.321,
          -10349.048,
          -10398.133,
          -10446.578000000001,
          -10494.386999999999,
          -10541.563,
          -10588.11,
          -10634.028999999999,
          -10679.323999999999,
          -10723.998,
          -10768.053,
          -10811.493,
          -10854.321000000002,
          -10896.538,
          -10938.148000000001,
          -10979.153,
          -11019.556,
          -11059.358999999999,
          -11098.566,
          -11137.177,
          -11175.197,
          -11212.627,
          -11249.469,
          -11285.726999999999,
          -11321.401000000002,
          -11356.495,
          -11391.011,
          -11424.95,
          -11458.316,
          -11491.108999999999,
          -11523.333,
          -11554.989,
          -11586.079,
          -11616.605,
          -11646.569,
          -11675.973,
          -11704.819,
          -11733.108999999999,
          -11760.845,
          -11788.027,
          -11814.659,
          -11840.742,
          -11866.277,
          -11891.267,
          -11915.712,
          -11939.614,
          -11962.976,
          -11985.798,
          -12008.082,
          -12029.829,
          -12051.042,
          -12071.721000000001,
          -12091.868,
          -12111.485,
          -12130.572,
          -12149.131000000001,
          -12167.163,
          -12184.67,
          -12201.653,
          -12218.113000000001,
          -12234.052,
          -12249.47,
          -12264.368,
          -12278.749,
          -12292.613000000001,
          -12305.96,
          -12318.793,
          -12331.113000000001,
          -12342.919,
          -12354.214,
          -12364.998,
          -12375.273000000001,
          -12385.038999999999,
          -12394.296999999999,
          -12403.048,
          -12411.293,
          -12419.033000000001,
          -12426.268999999998,
          -12433.001,
          -12439.231000000002,
          -12444.958999999999,
          -12450.185,
          -12454.912,
          -12459.138,
          -12462.866000000002,
          -12466.096000000001,
          -12468.828000000001,
          -12471.063,
          -12472.802,
          -12474.046,
          -12474.794,
          -12475.048,
          -12474.808,
          -12474.075,
          -12472.848999999998,
          -12471.13,
          -12468.92,
          -12466.218,
          -12463.026000000002,
          -12459.343,
          -12455.169,
          -12450.507,
          -12445.355,
          -12439.714,
          -12433.583999999999,
          -12426.966,
          -12419.861,
          -12412.267,
          -12404.187,
          -12395.618999999999,
          -12386.563999999998,
          -12377.023000000001,
          -12366.995,
          -12356.481000000002,
          -12345.481000000002,
          -12333.995,
          -12322.023000000001,
          -12309.565,
          -12296.622,
          -12283.194,
          -12269.28,
          -12254.881000000001,
          -12239.996000000001,
          -12224.626,
          -12208.771,
          -12192.431,
          -12175.605,
          -12158.294,
          -12140.498,
          -12122.216,
          -12103.448,
          -12084.195,
          -12064.456,
          -12044.231000000002,
          -12023.518999999998,
          -12002.322,
          -11980.638,
          -11958.466999999999,
          -11935.809,
          -11912.663999999999,
          -11889.032,
          -11864.911,
          -11840.303,
          -11815.206,
          -11789.621000000001,
          -11763.546,
          -11736.982,
          -11709.928999999998,
          -11682.385,
          -11654.35,
          -11625.823999999999,
          -11596.806999999999,
          -11567.298,
          -11537.296,
          -11506.801000000001,
          -11475.813,
          -11444.33,
          -11412.353000000001,
          -11379.881000000001,
          -11346.913999999999,
          -11313.448999999999,
          -11279.488000000001,
          -11245.028999999999,
          -11210.072,
          -11174.616000000002,
          -11138.659,
          -11102.203000000001,
          -11065.245,
          -11027.785,
          -10989.823,
          -10951.357,
          -10912.386,
          -10872.911,
          -10832.928999999998,
          -10792.44,
          -10751.444,
          -10709.938999999998,
          -10667.923999999999,
          -10625.398000000001,
          -10582.361,
          -10538.811000000002,
          -10494.748,
          -10450.17,
          -10405.076,
          -10359.466,
          -10313.338,
          -10266.69,
          -10219.523000000001,
          -10171.834,
          -10123.623,
          -10074.888,
          -10025.628,
          -9975.841999999999,
          -9925.529,
          -9874.687,
          -9823.315,
          -9771.412,
          -9718.976,
          -9666.006,
          -9612.501,
          -9558.459,
          -9503.879,
          -9448.759,
          -9393.097,
          -9336.893,
          -9280.145,
          -9222.851,
          -9165.01,
          -9106.619,
          -9047.678,
          -8988.185,
          -8928.138,
          -8867.536,
          -8806.376,
          -8744.657,
          -8682.378,
          -8619.536,
          -8556.129,
          -8492.157,
          -8427.617,
          -8362.506,
          -8296.824,
          -8230.569,
          -8163.738,
          -8096.329000000001,
          -8028.340999999999,
          -7959.772,
          -7890.619000000001,
          -7820.880999999999,
          -7750.555,
          -7679.639,
          -7608.132,
          -7536.031,
          -7463.334,
          -7390.04,
          -7316.145,
          -7241.647,
          -7166.545,
          -7090.8369999999995,
          -7014.519,
          -6937.590999999999,
          -6860.049,
          -6781.892,
          -6703.116999999999,
          -6623.721,
          -6543.704000000001,
          -6463.062,
          -6381.794,
          -6299.896,
          -6217.366999999999,
          -6134.205,
          -6050.408,
          -5965.972,
          -5880.897,
          -5795.18,
          -5708.819,
          -5621.811,
          -5534.155,
          -5445.85,
          -5356.891,
          -5267.278,
          -5177.01,
          -5086.084,
          -4994.499,
          -4902.254,
          -4809.345,
          -4715.773,
          -4621.536,
          -4526.633,
          -4431.062,
          -4334.823,
          -4237.916,
          -4140.339,
          -4042.093,
          -3943.177,
          -3843.591,
          -3743.337,
          -3642.414,
          -3540.823,
          -3438.567,
          -3335.6459999999997,
          -3232.0640000000003,
          -3127.822,
          -3022.923,
          -2917.3709999999996,
          -2811.171,
          -2704.328,
          -2596.845,
          -2488.731,
          -2379.994,
          -2270.638,
          -2160.674,
          -2050.112,
          -1938.963,
          -1827.24,
          -1714.957,
          -1602.129,
          -1488.7720000000002,
          -1374.9070000000002,
          -1260.553,
          -1145.734,
          -1030.476,
          -914.806,
          -798.7560000000001,
          -682.36,
          -565.655,
          -448.68300000000005,
          -331.49,
          -214.12599999999998,
          -96.647,
          20.886,
          138.406,
          255.84,
          373.105,
          490.11199999999997,
          606.762,
          722.947,
          838.547,
          953.431,
          1067.455,
          1180.4589999999998,
          1292.271,
          1402.6979999999999,
          1511.5320000000002,
          1618.5439999999999,
          1723.483,
          1826.076,
          1926.027,
          2023.014,
          2116.689,
          2206.68,
          2292.584,
          2373.979,
          2450.4139999999998,
          2521.419,
          2586.509,
          2645.185,
          2696.946,
          2741.297,
          2777.756,
          2805.8709999999996,
          2825.2309999999998,
          2835.4770000000003,
          2836.32,
          2827.548,
          2809.0370000000003,
          2780.76,
          2742.785,
          2695.283,
          2638.511,
          2572.817,
          2498.616,
          2416.387,
          2326.651,
          2229.9629999999997,
          2126.8920000000003,
          2018.0120000000002,
          1903.892,
          1785.082,
          1662.114,
          1535.489,
          1405.68,
          1273.126,
          1138.232,
          1001.3710000000001,
          862.883,
          723.077,
          582.231,
          440.598,
          298.403,
          155.851,
          13.120999999999999,
          -129.624,
          -272.24,
          -414.64599999999996,
          -556.59,
          -698.11,
          -839.071,
          -979.395,
          -1119.014,
          -1257.866,
          -1395.9,
          -1533.069,
          -1669.332,
          -1804.656,
          -1939.011,
          -2072.37,
          -2204.712,
          -2336.018,
          -2466.274,
          -2595.465,
          -2723.583,
          -2850.619,
          -2976.567,
          -3101.421,
          -3225.18,
          -3347.841,
          -3469.4040000000005,
          -3589.87,
          -3709.239,
          -3827.514,
          -3944.699,
          -4060.797,
          -4175.812,
          -4289.75,
          -4402.6140000000005,
          -4514.411,
          -4625.147,
          -4734.8279999999995,
          -4843.460999999999,
          -4951.0509999999995,
          -5057.606,
          -5163.1320000000005,
          -5267.638000000001,
          -5371.13,
          -5473.6140000000005,
          -5575.1,
          -5675.593000000001,
          -5775.101,
          -5873.632,
          -5971.193,
          -6067.7919999999995,
          -6163.435,
          -6258.13,
          -6351.884,
          -6444.705,
          -6536.6,
          -6627.575,
          -6717.638000000001,
          -6806.795999999999,
          -6895.055,
          -6982.424,
          -7068.906999999999,
          -7154.513000000001,
          -7239.246999999999,
          -7323.116999999999,
          -7406.128000000001,
          -7488.2880000000005,
          -7569.602,
          -7650.076,
          -7729.718000000001,
          -7808.531999999999,
          -7886.525,
          -7963.703,
          -8040.071,
          -8115.6359999999995,
          -8190.401999999999,
          -8264.377,
          -8337.563,
          -8409.969000000001,
          -8481.598,
          -8552.456,
          -8622.548,
          -8691.879,
          -8760.455,
          -8828.279,
          -8895.358,
          -8961.696,
          -9027.296999999999,
          -9092.166,
          -9156.308,
          -9219.726999999999,
          -9282.428,
          -9344.415,
          -9405.692,
          -9466.264000000001,
          -9526.135,
          -9585.308,
          -9643.789,
          -9701.58,
          -9758.686,
          -9815.11,
          -9870.857,
          -9925.931,
          -9980.334,
          -10034.07,
          -10087.144,
          -10139.558,
          -10191.315999999999,
          -10242.421999999999,
          -10292.878,
          -10342.688,
          -10391.855,
          -10440.383,
          -10488.275,
          -10535.533000000001,
          -10582.161,
          -10628.162,
          -10673.538,
          -10718.293,
          -10762.428999999998,
          -10805.95,
          -10848.857,
          -10891.155,
          -10932.844,
          -10973.928999999998,
          -11014.412,
          -11054.295,
          -11093.58,
          -11132.271,
          -11170.368999999999,
          -11207.877,
          -11244.798,
          -11281.133999999998,
          -11316.886,
          -11352.058,
          -11386.651000000002,
          -11420.668,
          -11454.111,
          -11486.981000000002,
          -11519.282,
          -11551.014,
          -11582.181,
          -11612.783000000001,
          -11642.823999999999,
          -11672.303999999998,
          -11701.226,
          -11729.591999999999,
          -11757.403,
          -11784.661,
          -11811.368,
          -11837.526000000002,
          -11863.136,
          -11888.2,
          -11912.72,
          -11936.697,
          -11960.133,
          -11983.028999999999,
          -12005.386999999999,
          -12027.208999999999,
          -12048.496000000001,
          -12069.248,
          -12089.469,
          -12109.159,
          -12128.319,
          -12146.951000000001,
          -12165.056999999999,
          -12182.636999999999,
          -12199.693000000001,
          -12216.225,
          -12232.236,
          -12247.726999999999,
          -12262.698,
          -12277.151000000002,
          -12291.087,
          -12304.506000000001,
          -12317.411,
          -12329.802,
          -12341.681,
          -12353.046999999999,
          -12363.903,
          -12374.249,
          -12384.086000000001,
          -12393.416000000001,
          -12402.238000000001,
          -12410.553999999998,
          -12418.365,
          -12425.671999999999,
          -12432.475,
          -12438.775,
          -12444.573,
          -12449.87,
          -12454.667,
          -12458.964,
          -12462.761999999999,
          -12466.062,
          -12468.865,
          -12471.17,
          -12472.979,
          -12474.292,
          -12475.11,
          -12475.434,
          -12475.264,
          -12474.6,
          -12473.443000000001,
          -12471.794,
          -12469.653,
          -12467.021,
          -12463.898000000001,
          -12460.284,
          -12456.18,
          -12451.586000000001,
          -12446.503,
          -12440.931,
          -12434.871000000001,
          -12428.322,
          -12421.285,
          -12413.76,
          -12405.748,
          -12397.249,
          -12388.263,
          -12378.79,
          -12368.83,
          -12358.385,
          -12347.453000000001,
          -12336.035,
          -12324.132,
          -12311.743,
          -12298.868,
          -12285.507,
          -12271.662,
          -12257.33,
          -12242.514,
          -12227.212,
          -12211.425,
          -12195.153,
          -12178.395,
          -12161.152,
          -12143.423,
          -12125.208999999999,
          -12106.508999999998,
          -12087.323,
          -12067.652,
          -12047.493999999999,
          -12026.851,
          -12005.721000000001,
          -11984.104,
          -11962.001,
          -11939.411,
          -11916.333,
          -11892.768,
          -11868.715,
          -11844.175,
          -11819.145,
          -11793.627,
          -11767.62,
          -11741.124,
          -11714.136999999999,
          -11686.661,
          -11658.693000000001,
          -11630.235,
          -11601.285,
          -11571.843,
          -11541.909,
          -11511.481000000002,
          -11480.56,
          -11449.146,
          -11417.236,
          -11384.831,
          -11351.931,
          -11318.534,
          -11284.64,
          -11250.248,
          -11215.358,
          -11179.969,
          -11144.08,
          -11107.69,
          -11070.8,
          -11033.407,
          -10995.511999999999,
          -10957.113000000001,
          -10918.21,
          -10878.802,
          -10838.886999999999,
          -10798.466,
          -10757.537,
          -10716.098999999998,
          -10674.151000000002,
          -10631.693000000001,
          -10588.723,
          -10545.241000000002,
          -10501.245,
          -10456.734,
          -10411.708,
          -10366.165,
          -10320.104,
          -10273.524,
          -10226.424,
          -10178.803,
          -10130.659,
          -10081.992,
          -10032.8,
          -9983.081,
          -9932.836,
          -9882.061,
          -9830.757,
          -9778.921999999999,
          -9726.553,
          -9673.651,
          -9620.214,
          -9566.239,
          -9511.726999999999,
          -9456.675,
          -9401.081,
          -9344.945,
          -9288.265,
          -9231.039,
          -9173.265,
          -9114.943000000001,
          -9056.07,
          -8996.645,
          -8936.666,
          -8876.132,
          -8815.04,
          -8753.39,
          -8691.178,
          -8628.405,
          -8565.067,
          -8501.163,
          -8436.690999999999,
          -8371.649,
          -8306.035,
          -8239.848,
          -8173.085999999999,
          -8105.746,
          -8037.826,
          -7969.326,
          -7900.241,
          -7830.571999999999,
          -7760.314,
          -7689.468000000001,
          -7618.029,
          -7545.996999999999,
          -7473.369000000001,
          -7400.143,
          -7326.316999999999,
          -7251.889,
          -7176.856,
          -7101.215999999999,
          -7024.968000000001,
          -6948.108,
          -6870.635,
          -6792.547,
          -6713.840999999999,
          -6634.514,
          -6554.566,
          -6473.993,
          -6392.793000000001,
          -6310.965,
          -6228.505,
          -6145.411999999999,
          -6061.683000000001,
          -5977.316,
          -5892.31,
          -5806.661,
          -5720.368,
          -5633.429,
          -5545.842,
          -5457.604,
          -5368.714,
          -5279.17,
          -5188.97,
          -5098.112,
          -5006.595,
          -4914.416,
          -4821.575,
          -4728.07,
          -4633.9,
          -4539.063,
          -4443.558,
          -4347.3859999999995,
          -4250.544,
          -4153.032,
          -4054.8509999999997,
          -3955.9990000000003,
          -3856.4770000000003,
          -3756.2859999999996,
          -3655.426,
          -3553.8979999999997,
          -3451.703,
          -3348.844,
          -3245.321,
          -3141.138,
          -3036.298,
          -2930.804,
          -2824.6609999999996,
          -2717.873,
          -2610.445,
          -2502.384,
          -2393.696,
          -2284.39,
          -2174.475,
          -2063.96,
          -1952.856,
          -1841.175,
          -1728.933,
          -1616.142,
          -1502.8210000000001,
          -1388.989,
          -1274.665,
          -1159.872,
          -1044.637,
          -928.9860000000001,
          -812.95,
          -696.564,
          -579.864,
          -462.89099999999996,
          -345.691,
          -228.315,
          -110.815,
          6.746,
          124.303,
          241.782,
          359.103,
          476.176,
          592.905,
          709.181,
          824.887,
          939.893,
          1054.056,
          1167.218,
          1279.2069999999999,
          1389.8339999999998,
          1498.892,
          1606.154,
          1711.372,
          1814.275,
          1914.57,
          2011.9370000000001,
          2106.031,
          2196.482,
          2282.8920000000003,
          2364.839,
          2441.875,
          2513.532,
          2579.327,
          2638.761,
          2691.3340000000003,
          2736.548,
          2773.921,
          2802.9959999999996,
          2823.3559999999998,
          2834.637,
          2836.542,
          2828.85,
          2811.427,
          2784.236,
          2747.336,
          2700.884,
          2645.131,
          2580.415,
          2507.145,
          2425.7929999999997,
          2336.877,
          2240.948,
          2138.575,
          2030.332,
          1916.7879999999998,
          1798.496,
          1675.991,
          1549.776,
          1420.3270000000002,
          1288.087,
          1153.465,
          1016.8380000000001,
          878.547,
          738.9069999999999,
          598.196,
          456.67199999999997,
          314.562,
          172.07299999999998,
          29.386999999999997,
          -113.33200000000001,
          -255.938,
          -398.30199999999996,
          -540.308,
          -681.8560000000001,
          -822.8539999999999,
          -963.225,
          -1102.8980000000001,
          -1241.8110000000001,
          -1379.912,
          -1517.154,
          -1653.496,
          -1788.9029999999998,
          -1923.3429999999998,
          -2056.792,
          -2189.2270000000003,
          -2320.629,
          -2450.9829999999997,
          -2580.274,
          -2708.494,
          -2835.633,
          -2961.685,
          -3086.645,
          -3210.511,
          -3333.2790000000005,
          -3454.95,
          -3575.5240000000003,
          -3695.0029999999997,
          -3813.387,
          -3930.6820000000002,
          -4046.89,
          -4162.015,
          -4276.062,
          -4389.036,
          -4500.943,
          -4611.788,
          -4721.579000000001,
          -4830.32,
          -4938.019,
          -5044.683,
          -5150.318,
          -5254.931,
          -5358.53,
          -5461.121999999999,
          -5562.714,
          -5663.314,
          -5762.929,
          -5861.565,
          -5959.232,
          -6055.935,
          -6151.682,
          -6246.481,
          -6340.339,
          -6433.263000000001,
          -6525.26,
          -6616.3369999999995,
          -6706.5019999999995,
          -6795.762,
          -6884.121999999999,
          -6971.590999999999,
          -7058.174,
          -7143.88,
          -7228.713000000001,
          -7312.681,
          -7395.791,
          -7478.048000000001,
          -7559.459,
          -7640.03,
          -7719.768,
          -7798.678000000001,
          -7876.767,
          -7954.04,
          -8030.503000000001,
          -8106.161999999999,
          -8181.022,
          -8255.09,
          -8328.37,
          -8400.868,
          -8472.589,
          -8543.539,
          -8613.723,
          -8683.145,
          -8751.812,
          -8819.726999999999,
          -8886.896,
          -8953.323,
          -9019.014000000001,
          -9083.972,
          -9148.203000000001,
          -9211.71,
          -9274.499,
          -9336.574,
          -9397.939,
          -9458.598,
          -9518.555,
          -9577.815,
          -9636.382,
          -9694.259,
          -9751.451,
          -9807.961,
          -9863.793,
          -9918.951,
          -9973.438,
          -10027.259,
          -10080.416,
          -10132.914,
          -10184.756,
          -10235.944,
          -10286.483,
          -10336.376,
          -10385.626,
          -10434.235999999999,
          -10482.209,
          -10529.548999999999,
          -10576.258999999998,
          -10622.341,
          -10667.798,
          -10712.633,
          -10756.85,
          -10800.451000000001,
          -10843.438999999998,
          -10885.816,
          -10927.585,
          -10968.75,
          -11009.311000000002,
          -11049.273000000001,
          -11088.636999999999,
          -11127.407,
          -11165.583,
          -11203.17,
          -11240.169,
          -11276.582,
          -11312.412,
          -11347.662,
          -11382.332,
          -11416.426000000001,
          -11449.946000000002,
          -11482.893,
          -11515.27,
          -11547.079,
          -11578.322,
          -11609.001,
          -11639.118,
          -11668.673999999999,
          -11697.671999999999,
          -11726.113000000001,
          -11754,
          -11781.333,
          -11808.115,
          -11834.348,
          -11860.032,
          -11885.171,
          -11909.765,
          -11933.817,
          -11957.327,
          -11980.296999999999,
          -12002.729,
          -12024.625,
          -12045.985,
          -12066.811000000002,
          -12087.105,
          -12106.868,
          -12126.101999999999,
          -12144.806999999999,
          -12162.985,
          -12180.638,
          -12197.766000000001,
          -12214.372,
          -12230.455,
          -12246.018,
          -12261.061000000002,
          -12275.586000000001,
          -12289.594,
          -12303.086000000001,
          -12316.063,
          -12328.525,
          -12340.475,
          -12351.913,
          -12362.841,
          -12373.258,
          -12383.166000000001,
          -12392.567,
          -12401.46,
          -12409.847,
          -12417.729,
          -12425.106000000002,
          -12431.98,
          -12438.351,
          -12444.22,
          -12449.587,
          -12454.454,
          -12458.822,
          -12462.69,
          -12466.06,
          -12468.931999999999,
          -12471.308,
          -12473.186000000002,
          -12474.569,
          -12475.457,
          -12475.851,
          -12475.75,
          -12475.156,
          -12474.069,
          -12472.489,
          -12470.418,
          -12467.854,
          -12464.8,
          -12461.256000000001,
          -12457.221000000001,
          -12452.696000000002,
          -12447.681999999999,
          -12442.178999999998,
          -12436.187,
          -12429.707,
          -12422.739,
          -12415.283000000001,
          -12407.34,
          -12398.909,
          -12389.991000000002,
          -12380.587,
          -12370.696000000002,
          -12360.319,
          -12349.456,
          -12338.106000000002,
          -12326.271,
          -12313.95,
          -12301.143,
          -12287.851,
          -12274.073999999999,
          -12259.81,
          -12245.062,
          -12229.828000000001,
          -12214.108999999999,
          -12197.905,
          -12181.215,
          -12164.038999999999,
          -12146.378999999999,
          -12128.232,
          -12109.6,
          -12090.483,
          -12070.878999999999,
          -12050.788999999999,
          -12030.213,
          -12009.151000000002,
          -11987.601999999999,
          -11965.566,
          -11943.044,
          -11920.034,
          -11896.536,
          -11872.551000000001,
          -11848.078000000001,
          -11823.116000000002,
          -11797.665,
          -11771.726,
          -11745.296999999999,
          -11718.378,
          -11690.969,
          -11663.069,
          -11634.678,
          -11605.796,
          -11576.421999999999,
          -11546.555,
          -11516.194,
          -11485.341,
          -11453.993999999999,
          -11422.152,
          -11389.813999999998,
          -11356.981000000002,
          -11323.651000000002,
          -11289.825,
          -11255.5,
          -11220.678,
          -11185.356000000002,
          -11149.535,
          -11113.213,
          -11076.389,
          -11039.063999999998,
          -11001.237,
          -10962.905,
          -10924.069,
          -10884.729,
          -10844.882,
          -10804.528,
          -10763.666000000001,
          -10722.296,
          -10680.415,
          -10638.025,
          -10595.123,
          -10551.708,
          -10507.778999999999,
          -10463.336,
          -10418.378,
          -10372.902,
          -10326.909,
          -10280.396999999999,
          -10233.364,
          -10185.811,
          -10137.735,
          -10089.135,
          -10040.011,
          -9990.36,
          -9940.183,
          -9889.476,
          -9838.24,
          -9786.472,
          -9734.171999999999,
          -9681.338,
          -9627.968,
          -9574.062,
          -9519.618,
          -9464.634,
          -9409.108,
          -9353.04,
          -9296.428,
          -9239.27,
          -9181.565,
          -9123.311,
          -9064.507,
          -9005.15,
          -8945.24,
          -8884.774,
          -8823.751,
          -8762.169,
          -8700.027,
          -8637.321,
          -8574.052,
          -8510.216999999999,
          -8445.814,
          -8380.841,
          -8315.296,
          -8249.178,
          -8182.484,
          -8115.213000000001,
          -8047.363,
          -7978.931,
          -7909.916,
          -7840.315,
          -7770.1269999999995,
          -7699.35,
          -7627.981,
          -7556.018,
          -7483.459,
          -7410.303000000001,
          -7336.545999999999,
          -7262.187,
          -7187.223000000001,
          -7111.653,
          -7035.474,
          -6958.684,
          -6881.28,
          -6803.2609999999995,
          -6724.625,
          -6645.368,
          -6565.4890000000005,
          -6484.985,
          -6403.855,
          -6322.096,
          -6239.706,
          -6156.682,
          -6073.023,
          -5988.725,
          -5903.7880000000005,
          -5818.209,
          -5731.985,
          -5645.115,
          -5557.597,
          -5469.428000000001,
          -5380.607,
          -5291.132,
          -5201.001,
          -5110.212,
          -5018.762,
          -4926.652,
          -4833.879,
          -4740.442,
          -4646.339,
          -4551.569,
          -4456.1320000000005,
          -4360.026,
          -4263.25,
          -4165.804,
          -4067.6890000000003,
          -3968.902,
          -3869.445,
          -3769.3179999999998,
          -3668.522,
          -3567.0570000000002,
          -3464.925,
          -3362.127,
          -3258.665,
          -3154.5429999999997,
          -3049.762,
          -2944.327,
          -2838.241,
          -2731.509,
          -2624.137,
          -2516.129,
          -2407.495,
          -2298.24,
          -2188.374,
          -2077.906,
          -1966.848,
          -1855.2120000000002,
          -1743.011,
          -1630.26,
          -1516.975,
          -1403.1760000000002,
          -1288.883,
          -1174.118,
          -1058.906,
          -943.275,
          -827.255,
          -710.88,
          -594.186,
          -477.214,
          -360.009,
          -242.62,
          -125.102,
          -7.513999999999999,
          110.07799999999999,
          227.601,
          344.976,
          462.115,
          578.9209999999999,
          695.288,
          811.0989999999999,
          926.2239999999999,
          1040.524,
          1153.8419999999999,
          1266.008,
          1376.8329999999999,
          1486.114,
          1593.625,
          1699.121,
          1802.3329999999999,
          1902.97,
          2000.7160000000001,
          2095.228,
          2186.14,
          2273.054,
          2355.552,
          2433.189,
          2505.5,
          2572,
          2632.1940000000004,
          2685.58,
          2731.66,
          2769.95,
          2799.989,
          2821.3559999999998,
          2833.679,
          2836.6540000000005,
          2830.051,
          2813.7270000000003,
          2787.634,
          2751.82,
          2706.4320000000002,
          2651.7129999999997,
          2587.989,
          2515.6639999999998,
          2435.203,
          2347.123,
          2251.967,
          2150.305,
          2042.7120000000002,
          1929.756,
          1811.993,
          1689.96,
          1564.164,
          1435.0839999999998,
          1303.1660000000002,
          1168.822,
          1032.433,
          894.3439999999999,
          754.8710000000001,
          614.3,
          472.88699999999994,
          330.865,
          188.44,
          45.799,
          -96.89200000000001,
          -239.487,
          -381.853,
          -523.875,
          -665.45,
          -806.4860000000001,
          -946.903,
          -1086.63,
          -1225.606,
          -1363.775,
          -1501.0910000000001,
          -1637.5120000000002,
          -1773.0020000000002,
          -1907.53,
          -2041.07,
          -2173.599,
          -2305.098,
          -2435.55,
          -2564.9429999999998,
          -2693.2659999999996,
          -2820.509,
          -2946.667,
          -3071.7340000000004,
          -3195.7070000000003,
          -3318.585,
          -3440.365,
          -3561.0490000000004,
          -3680.638,
          -3799.133,
          -3916.539,
          -4032.8579999999997,
          -4148.094,
          -4262.252,
          -4375.337,
          -4487.355,
          -4598.312,
          -4708.213,
          -4817.064,
          -4924.874,
          -5031.647,
          -5137.392,
          -5242.115,
          -5345.823,
          -5448.523,
          -5550.223000000001,
          -5650.931,
          -5750.653,
          -5849.396,
          -5947.169,
          -6043.978,
          -6139.831,
          -6234.735,
          -6328.696999999999,
          -6421.725,
          -6513.826,
          -6605.007,
          -6695.274,
          -6784.6359999999995,
          -6873.099,
          -6960.669,
          -7047.353,
          -7133.158,
          -7218.092,
          -7302.159000000001,
          -7385.368,
          -7467.724,
          -7549.233,
          -7629.901999999999,
          -7709.736999999999,
          -7788.744000000001,
          -7866.927,
          -7944.295999999999,
          -8020.855,
          -8096.61,
          -8171.565,
          -8245.726999999999,
          -8319.101,
          -8391.693000000001,
          -8463.507,
          -8534.55,
          -8604.826,
          -8674.341,
          -8743.099,
          -8811.105,
          -8878.365,
          -8944.883,
          -9010.663,
          -9075.711,
          -9140.032,
          -9203.628,
          -9266.506,
          -9328.669,
          -9390.122,
          -9450.869,
          -9510.914,
          -9570.261,
          -9628.915,
          -9686.878,
          -9744.155999999999,
          -9800.752,
          -9856.67,
          -9911.913,
          -9966.485999999999,
          -10020.392,
          -10073.634,
          -10126.216,
          -10178.141,
          -10229.413,
          -10280.036,
          -10330.011999999999,
          -10379.345,
          -10428.037,
          -10476.093,
          -10523.515,
          -10570.306999999999,
          -10616.471000000001,
          -10662.01,
          -10706.927,
          -10751.223999999998,
          -10794.906,
          -10837.973999999998,
          -10880.431999999999,
          -10922.281,
          -10963.526000000002,
          -11004.167,
          -11044.208,
          -11083.652,
          -11122.5,
          -11160.756000000001,
          -11198.421,
          -11235.498,
          -11271.99,
          -11307.898000000001,
          -11343.225,
          -11377.973,
          -11412.145,
          -11445.742,
          -11478.766000000001,
          -11511.22,
          -11543.106000000002,
          -11574.426000000001,
          -11605.181,
          -11635.374,
          -11665.006000000001,
          -11694.08,
          -11722.596000000001,
          -11750.558,
          -11777.966999999999,
          -11804.825,
          -11831.133,
          -11856.893,
          -11882.106000000002,
          -11906.775,
          -11930.901000000002,
          -11954.486,
          -11977.53,
          -12000.036,
          -12022.006000000001,
          -12043.44,
          -12064.34,
          -12084.708,
          -12104.544,
          -12123.851,
          -12142.63,
          -12160.881000000001,
          -12178.607,
          -12195.809,
          -12212.487,
          -12228.643,
          -12244.278,
          -12259.395,
          -12273.992,
          -12288.072,
          -12301.636,
          -12314.685,
          -12327.22,
          -12339.241000000002,
          -12350.751,
          -12361.75,
          -12372.239,
          -12382.219,
          -12391.69,
          -12400.655,
          -12409.113000000001,
          -12417.066,
          -12424.514,
          -12431.458999999999,
          -12437.9,
          -12443.84,
          -12449.278,
          -12454.216,
          -12458.653999999999,
          -12462.591999999999,
          -12466.032,
          -12468.975,
          -12471.42,
          -12473.368999999999,
          -12474.822,
          -12475.78,
          -12476.243,
          -12476.212,
          -12475.688,
          -12474.67,
          -12473.16,
          -12471.158000000001,
          -12468.663999999999,
          -12465.68,
          -12462.204,
          -12458.239,
          -12453.783000000001,
          -12448.838,
          -12443.403999999999,
          -12437.481000000002,
          -12431.07,
          -12424.171,
          -12416.784,
          -12408.909,
          -12400.546999999999,
          -12391.698,
          -12382.362,
          -12372.54,
          -12362.231000000002,
          -12351.436000000002,
          -12340.155,
          -12328.389,
          -12316.136,
          -12303.398000000001,
          -12290.173999999999,
          -12276.464,
          -12262.268999999998,
          -12247.589,
          -12232.423999999999,
          -12216.773000000001,
          -12200.636999999999,
          -12184.015,
          -12166.907,
          -12149.315,
          -12131.236,
          -12112.671999999999,
          -12093.622,
          -12074.086000000001,
          -12054.063999999998,
          -12033.556,
          -12012.561000000002,
          -11991.08,
          -11969.112,
          -11946.657,
          -11923.715,
          -11900.285,
          -11876.367,
          -11851.961000000001,
          -11827.067,
          -11801.684,
          -11775.812,
          -11749.45,
          -11722.598999999998,
          -11695.257,
          -11667.425,
          -11639.101,
          -11610.286,
          -11580.979,
          -11551.18,
          -11520.886999999999,
          -11490.101,
          -11458.821000000002,
          -11427.046,
          -11394.776000000002,
          -11362.01,
          -11328.748,
          -11294.989,
          -11260.732,
          -11225.976,
          -11190.722,
          -11154.968,
          -11118.713,
          -11081.958,
          -11044.7,
          -11006.938999999998,
          -10968.675,
          -10929.907,
          -10890.633999999998,
          -10850.854,
          -10810.568000000001,
          -10769.773000000001,
          -10728.47,
          -10686.658000000001,
          -10644.335,
          -10601.5,
          -10558.153,
          -10514.292,
          -10469.916,
          -10425.025,
          -10379.617,
          -10333.692,
          -10287.248,
          -10240.283000000001,
          -10192.798,
          -10144.789,
          -10096.257,
          -10047.201,
          -9997.618,
          -9947.508,
          -9896.87,
          -9845.701,
          -9794.001,
          -9741.769,
          -9689.003,
          -9635.701,
          -9581.863000000001,
          -9527.487,
          -9472.571,
          -9417.114,
          -9361.114,
          -9304.57,
          -9247.48,
          -9189.844000000001,
          -9131.658000000001,
          -9072.921999999999,
          -9013.634,
          -8953.792,
          -8893.394,
          -8832.44,
          -8770.926,
          -8708.851999999999,
          -8646.216,
          -8583.015,
          -8519.248,
          -8454.914,
          -8390.01,
          -8324.534,
          -8258.484,
          -8191.86,
          -8124.658,
          -8056.876,
          -7988.513000000001,
          -7919.566999999999,
          -7850.036,
          -7779.9169999999995,
          -7709.2080000000005,
          -7637.908,
          -7566.015,
          -7493.525,
          -7420.438,
          -7346.75,
          -7272.460999999999,
          -7197.566,
          -7122.066,
          -7045.956999999999,
          -6969.236,
          -6891.901999999999,
          -6813.953,
          -6735.385,
          -6656.198,
          -6576.388000000001,
          -6495.954000000001,
          -6414.894,
          -6333.204000000001,
          -6250.883000000001,
          -6167.928000000001,
          -6084.338000000001,
          -6000.11,
          -5915.241999999999,
          -5829.732,
          -5743.578,
          -5656.776999999999,
          -5569.326999999999,
          -5481.228,
          -5392.475,
          -5303.069,
          -5213.005,
          -5122.284000000001,
          -5030.904,
          -4938.861,
          -4846.156,
          -4752.786,
          -4658.751,
          -4564.049,
          -4468.678,
          -4372.639,
          -4275.929,
          -4178.55,
          -4080.5,
          -3981.778,
          -3882.386,
          -3782.324,
          -3681.591,
          -3580.1890000000003,
          -3478.119,
          -3375.384,
          -3271.9829999999997,
          -3167.921,
          -3063.2,
          -2957.823,
          -2851.795,
          -2745.12,
          -2637.803,
          -2529.851,
          -2421.269,
          -2312.065,
          -2202.249,
          -2091.8289999999997,
          -1980.818,
          -1869.225,
          -1757.066,
          -1644.355,
          -1531.1070000000002,
          -1417.3429999999998,
          -1303.08,
          -1188.343,
          -1073.156,
          -957.545,
          -841.5419999999999,
          -725.178,
          -608.491,
          -491.52,
          -374.311,
          -256.911,
          -139.374,
          -21.761,
          95.865,
          213.43200000000002,
          330.85900000000004,
          448.06199999999995,
          564.944,
          681.3989999999999,
          797.312,
          912.556,
          1026.991,
          1140.462,
          1252.802,
          1363.8229999999999,
          1473.3229999999999,
          1581.0810000000001,
          1686.851,
          1790.368,
          1891.3429999999998,
          1989.464,
          2084.389,
          2175.755,
          2263.1679999999997,
          2346.212,
          2424.445,
          2497.402,
          2564.601,
          2625.548,
          2679.742,
          2726.683,
          2765.883,
          2796.881,
          2819.248,
          2832.61,
          2836.652,
          2831.136,
          2815.9109999999996,
          2790.915,
          2756.188,
          2711.869,
          2658.1859999999997,
          2595.459,
          2524.084,
          2444.522,
          2357.28,
          2262.904,
          2161.96,
          2055.0229999999997,
          1942.661,
          1825.434,
          1703.879,
          1578.507,
          1449.8,
          1318.2089999999998,
          1184.1480000000001,
          1048.002,
          910.1189999999999,
          770.819,
          630.39,
          489.091,
          347.158,
          204.801,
          62.207,
          -80.455,
          -223.037,
          -365.945,
          -507.44199999999995,
          -649.0419999999999,
          -790.115,
          -930.577,
          -1070.359,
          -1209.395,
          -1347.6329999999998,
          -1485.023,
          -1621.5220000000002,
          -1757.095,
          -1891.711,
          -2025.3410000000001,
          -2157.964,
          -2289.5589999999997,
          -2420.111,
          -2549.605,
          -2678.03,
          -2805.3779999999997,
          -2931.6420000000003,
          -3056.816,
          -3180.897,
          -3303.883,
          -3425.7729999999997,
          -3546.567,
          -3666.2670000000003,
          -3784.873,
          -3902.389,
          -4018.8190000000004,
          -4134.167,
          -4248.436,
          -4361.633,
          -4473.762,
          -4584.829000000001,
          -4694.840999999999,
          -4803.803,
          -4911.723,
          -5018.607,
          -5124.462,
          -5229.294,
          -5333.111,
          -5435.92,
          -5537.729,
          -5638.544,
          -5738.3730000000005,
          -5837.223000000001,
          -5935.103,
          -6032.018,
          -6127.976,
          -6222.986,
          -6317.053000000001,
          -6410.185,
          -6502.389,
          -6593.673000000001,
          -6684.043000000001,
          -6773.507,
          -6862.071,
          -6949.743,
          -7036.528,
          -7122.434,
          -7207.467,
          -7291.635,
          -7374.941999999999,
          -7457.397,
          -7539.004,
          -7619.771,
          -7699.704000000001,
          -7778.808000000001,
          -7857.089,
          -7934.554,
          -8011.209,
          -8087.059,
          -8162.109,
          -8236.365,
          -8309.833,
          -8382.518,
          -8454.426,
          -8525.562,
          -8595.93,
          -8665.537,
          -8734.386,
          -8802.484,
          -8869.835,
          -8936.443000000001,
          -9002.314,
          -9067.452,
          -9131.862,
          -9195.548,
          -9258.514000000001,
          -9320.766,
          -9382.306999999999,
          -9443.142,
          -9503.274,
          -9562.708,
          -9621.449,
          -9679.499,
          -9736.863000000001,
          -9793.545,
          -9849.548,
          -9904.877,
          -9959.535,
          -10013.525,
          -10066.851999999999,
          -10119.518,
          -10171.527,
          -10222.883,
          -10273.589,
          -10323.649,
          -10373.064,
          -10421.84,
          -10469.978000000001,
          -10517.482,
          -10564.355,
          -10610.601,
          -10656.221000000001,
          -10701.22,
          -10745.598,
          -10789.361,
          -10832.508999999998,
          -10875.046999999999,
          -10916.976999999999,
          -10958.301000000001,
          -10999.021999999999,
          -11039.142,
          -11078.665,
          -11117.591999999999,
          -11155.927,
          -11193.67,
          -11230.826000000001,
          -11267.396,
          -11303.382,
          -11338.787,
          -11373.613000000001,
          -11407.862,
          -11441.536,
          -11474.638,
          -11507.169,
          -11539.131000000001,
          -11570.527,
          -11601.358999999999,
          -11631.628,
          -11661.336000000001,
          -11690.486,
          -11719.078000000001,
          -11747.116000000002,
          -11774.6,
          -11801.533000000001,
          -11827.916000000001,
          -11853.751,
          -11879.038999999999,
          -11903.783000000001,
          -11927.983,
          -11951.642,
          -11974.761,
          -11997.341,
          -12019.385,
          -12040.892,
          -12061.866000000002,
          -12082.308,
          -12102.218,
          -12121.598,
          -12140.448999999999,
          -12158.774,
          -12176.573,
          -12193.847,
          -12210.598,
          -12226.826000000001,
          -12242.534,
          -12257.722,
          -12272.392,
          -12286.544,
          -12300.18,
          -12313.3,
          -12325.907,
          -12338,
          -12349.582,
          -12360.652,
          -12371.212,
          -12381.264,
          -12390.806999999999,
          -12399.843,
          -12408.372,
          -12416.395,
          -12423.915,
          -12430.93,
          -12437.442,
          -12443.452,
          -12448.961000000001,
          -12453.969,
          -12458.476999999999,
          -12462.486,
          -12465.996000000001,
          -12469.008,
          -12471.524,
          -12473.542,
          -12475.065,
          -12476.093,
          -12476.626,
          -12476.663999999999,
          -12476.208999999999,
          -12475.261,
          -12473.82,
          -12471.886999999999,
          -12469.463,
          -12466.546999999999,
          -12463.141000000001,
          -12459.243999999999,
          -12454.858,
          -12449.982,
          -12444.617,
          -12438.763,
          -12432.42,
          -12425.589,
          -12418.271,
          -12410.465,
          -12402.171,
          -12393.391000000001,
          -12384.123,
          -12374.37,
          -12364.13,
          -12353.403,
          -12342.191,
          -12330.492,
          -12318.306999999999,
          -12305.636999999999,
          -12292.481000000002,
          -12278.839,
          -12264.712,
          -12250.1,
          -12235.002,
          -12219.419,
          -12203.35,
          -12186.796,
          -12169.756000000001,
          -12152.231000000002,
          -12134.22,
          -12115.723999999998,
          -12096.741000000002,
          -12077.273000000001,
          -12057.318000000001,
          -12036.878,
          -12015.951000000001,
          -11994.537,
          -11972.636,
          -11950.249,
          -11927.374,
          -11904.011,
          -11880.161,
          -11855.822,
          -11830.995,
          -11805.678999999998,
          -11779.874,
          -11753.58,
          -11726.796,
          -11699.521,
          -11671.756000000001,
          -11643.5,
          -11614.752,
          -11585.511999999999,
          -11555.78,
          -11525.555,
          -11494.836000000001,
          -11463.623,
          -11431.915,
          -11399.712,
          -11367.013,
          -11333.818000000001,
          -11300.126,
          -11265.936000000002,
          -11231.248,
          -11196.06,
          -11160.373,
          -11124.186000000002,
          -11087.497,
          -11050.306,
          -11012.613000000001,
          -10974.416000000001,
          -10935.715,
          -10896.508999999998,
          -10856.796,
          -10816.577,
          -10775.85,
          -10734.614,
          -10692.868,
          -10650.612,
          -10607.845,
          -10564.565,
          -10520.771,
          -10476.463,
          -10431.639000000001,
          -10386.298,
          -10340.44,
          -10294.062,
          -10247.165,
          -10199.746,
          -10151.805,
          -10103.341,
          -10054.351999999999,
          -10004.837,
          -9954.795,
          -9904.224,
          -9853.123,
          -9801.49,
          -9749.326,
          -9696.627,
          -9643.393,
          -9589.623,
          -9535.314,
          -9480.465,
          -9425.076,
          -9369.144,
          -9312.668,
          -9255.646,
          -9198.077,
          -9139.959,
          -9081.291,
          -9022.071,
          -8962.296999999999,
          -8901.966999999999,
          -8841.081,
          -8779.635,
          -8717.63,
          -8655.061,
          -8591.929,
          -8528.23,
          -8463.964,
          -8399.128,
          -8333.721,
          -8267.74,
          -8201.183,
          -8134.05,
          -8066.3369999999995,
          -7998.043000000001,
          -7929.165,
          -7859.701999999999,
          -7789.651999999999,
          -7719.013000000001,
          -7647.781999999999,
          -7575.956999999999,
          -7503.536,
          -7430.517,
          -7356.899,
          -7282.678000000001,
          -7207.852,
          -7132.42,
          -7056.379,
          -6979.728,
          -6902.4619999999995,
          -6824.581999999999,
          -6746.0830000000005,
          -6666.965,
          -6587.224,
          -6506.859,
          -6425.866999999999,
          -6344.246,
          -6261.994000000001,
          -6179.109,
          -6095.5869999999995,
          -6011.428000000001,
          -5926.629,
          -5841.187,
          -5755.102,
          -5668.369000000001,
          -5580.988,
          -5492.956999999999,
          -5404.273,
          -5314.935,
          -5224.94,
          -5134.287,
          -5042.974,
          -4950.999,
          -4858.361,
          -4765.059,
          -4671.09,
          -4576.454000000001,
          -4481.15,
          -4385.177,
          -4288.534000000001,
          -4191.22,
          -4093.2340000000004,
          -3994.578,
          -3895.25,
          -3795.2509999999997,
          -3694.5820000000003,
          -3593.243,
          -3491.235,
          -3388.5609999999997,
          -3285.2209999999995,
          -3181.219,
          -3076.5570000000002,
          -2971.238,
          -2865.2670000000003,
          -2758.6479999999997,
          -2651.386,
          -2543.487,
          -2434.9570000000003,
          -2325.805,
          -2216.0389999999998,
          -2105.667,
          -1994.701,
          -1883.1529999999998,
          -1771.035,
          -1658.3629999999998,
          -1545.1529999999998,
          -1431.422,
          -1317.191,
          -1202.482,
          -1087.319,
          -971.7289999999999,
          -855.742,
          -739.39,
          -622.71,
          -505.741,
          -388.527,
          -271.117,
          -153.563,
          -35.925,
          81.734,
          199.342,
          316.822,
          434.087,
          551.043,
          667.585,
          783.5989999999999,
          898.959,
          1013.5260000000001,
          1127.1480000000001,
          1239.6580000000001,
          1350.871,
          1460.588,
          1568.586,
          1674.625,
          1778.442,
          1879.75,
          1978.239,
          2073.571,
          2165.385,
          2253.2889999999998,
          2336.87,
          2415.689,
          2489.283,
          2557.173,
          2618.863,
          2673.8520000000003,
          2721.643,
          2761.743,
          2793.69,
          2817.048,
          2831.438,
          2836.538,
          2832.1009999999997,
          2817.966,
          2794.062,
          2760.4190000000003,
          2717.1620000000003,
          2664.513,
          2602.782,
          2532.3579999999997,
          2453.6929999999998,
          2367.2929999999997,
          2273.699,
          2173.476,
          2067.196,
          1955.433,
          1838.745,
          1717.671,
          1592.727,
          1464.3970000000002,
          1333.136,
          1199.361,
          1063.46,
          925.7860000000001,
          786.6610000000001,
          646.376,
          505.195,
          363.35400000000004,
          221.06599999999997,
          78.521,
          -64.11,
          -206.67700000000002,
          -349.045,
          -491.094,
          -632.72,
          -773.827,
          -914.334,
          -1054.1680000000001,
          -1193.264,
          -1331.568,
          -1469.03,
          -1605.6070000000002,
          -1741.2620000000002,
          -1875.963,
          -2009.683,
          -2142.399,
          -2274.09,
          -2404.74,
          -2534.335,
          -2662.862,
          -2790.3140000000003,
          -2916.6820000000002,
          -3041.9629999999997,
          -3166.151,
          -3289.245,
          -3411.244,
          -3532.147,
          -3651.9559999999997,
          -3770.673,
          -3888.2990000000004,
          -4004.84,
          -4120.298,
          -4234.678,
          -4347.985,
          -4460.225,
          -4571.403,
          -4681.525,
          -4790.598,
          -4898.627,
          -5005.62,
          -5111.584,
          -5216.525,
          -5320.45,
          -5423.368,
          -5525.284000000001,
          -5626.206,
          -5726.142,
          -5825.099,
          -5923.085,
          -6020.106,
          -6116.169,
          -6211.283,
          -6305.455,
          -6398.691,
          -6490.9980000000005,
          -6582.385,
          -6672.859,
          -6762.425,
          -6851.09,
          -6938.863,
          -7025.749,
          -7111.755,
          -7196.888000000001,
          -7281.154,
          -7364.561,
          -7447.1140000000005,
          -7528.819,
          -7609.683000000001,
          -7689.713000000001,
          -7768.9130000000005,
          -7847.291,
          -7924.852,
          -8001.601,
          -8077.545999999999,
          -8152.69,
          -8227.041,
          -8300.601999999999,
          -8373.381,
          -8445.381,
          -8516.61,
          -8587.071,
          -8656.769,
          -8725.711,
          -8793.899,
          -8861.341,
          -8928.039,
          -8994,
          -9059.228000000001,
          -9123.726999999999,
          -9187.502,
          -9250.556999999999,
          -9312.896999999999,
          -9374.526,
          -9435.448,
          -9495.668,
          -9555.189,
          -9614.016,
          -9672.152,
          -9729.603000000001,
          -9786.37,
          -9842.459,
          -9897.873,
          -9952.616,
          -10006.690999999999,
          -10060.101,
          -10112.851999999999,
          -10164.945,
          -10216.384,
          -10267.173,
          -10317.315999999999,
          -10366.815,
          -10415.673,
          -10463.893,
          -10511.479,
          -10558.434,
          -10604.761,
          -10650.462,
          -10695.541000000001,
          -10740.001,
          -10783.844,
          -10827.073,
          -10869.691,
          -10911.7,
          -10953.104,
          -10993.903999999999,
          -11034.104,
          -11073.706,
          -11112.712,
          -11151.125,
          -11188.947,
          -11226.181,
          -11262.829,
          -11298.893,
          -11334.376,
          -11369.278999999999,
          -11403.605,
          -11437.357,
          -11470.535,
          -11503.143,
          -11535.181999999999,
          -11566.653999999999,
          -11597.562,
          -11627.907,
          -11657.692,
          -11686.918,
          -11715.586000000001,
          -11743.698999999999,
          -11771.258999999998,
          -11798.267,
          -11824.723999999998,
          -11850.633999999998,
          -11875.997,
          -11900.815,
          -11925.09,
          -11948.823,
          -11972.016000000001,
          -11994.671,
          -12016.788,
          -12038.368999999999,
          -12059.417,
          -12079.931999999999,
          -12099.915,
          -12119.368,
          -12138.293,
          -12156.691,
          -12174.562,
          -12191.909,
          -12208.732,
          -12225.034,
          -12240.813999999998,
          -12256.073999999999,
          -12270.816,
          -12285.04,
          -12298.748,
          -12311.94,
          -12324.618,
          -12336.783000000001,
          -12348.436000000002,
          -12359.578000000001,
          -12370.208999999999,
          -12380.332,
          -12389.946000000002,
          -12399.053,
          -12407.653,
          -12415.748,
          -12423.337,
          -12430.423,
          -12437.006000000001,
          -12443.087,
          -12448.666000000001,
          -12453.743999999999,
          -12458.322,
          -12462.401000000002,
          -12465.981000000002,
          -12469.063999999998,
          -12471.649,
          -12473.738000000001,
          -12475.33,
          -12476.427,
          -12477.03,
          -12477.138,
          -12476.752,
          -12475.873,
          -12474.502,
          -12472.638,
          -12470.283000000001,
          -12467.437,
          -12464.098999999998,
          -12460.271999999999,
          -12455.954,
          -12451.146999999999,
          -12445.85,
          -12440.065,
          -12433.791000000001,
          -12427.028999999999,
          -12419.778999999999,
          -12412.042,
          -12403.817,
          -12395.105,
          -12385.906,
          -12376.22,
          -12366.048999999999,
          -12355.39,
          -12344.246000000001,
          -12332.615,
          -12320.499,
          -12307.896,
          -12294.808,
          -12281.235,
          -12267.176000000001,
          -12252.631000000001,
          -12237.601,
          -12222.086000000001,
          -12206.085,
          -12189.598,
          -12172.626,
          -12155.169,
          -12137.226,
          -12118.796999999999,
          -12099.882,
          -12080.481000000002,
          -12060.594,
          -12040.221000000001,
          -12019.361,
          -11998.015,
          -11976.181999999999,
          -11953.862,
          -11931.055,
          -11907.758999999998,
          -11883.976,
          -11859.705,
          -11834.945,
          -11809.697,
          -11783.958999999999,
          -11757.732,
          -11731.015,
          -11703.808,
          -11676.11,
          -11647.92,
          -11619.24,
          -11590.067,
          -11560.402,
          -11530.243,
          -11499.591,
          -11468.445,
          -11436.805,
          -11404.669,
          -11372.037,
          -11338.909,
          -11305.284,
          -11271.161,
          -11236.54,
          -11201.42,
          -11165.8,
          -11129.68,
          -11093.058,
          -11055.935,
          -11018.309,
          -10980.178999999998,
          -10941.545,
          -10902.406,
          -10862.761,
          -10822.608999999999,
          -10781.948999999999,
          -10740.78,
          -10699.101999999999,
          -10656.913,
          -10614.212,
          -10571,
          -10527.273000000001,
          -10483.032,
          -10438.275,
          -10393.002,
          -10347.211,
          -10300.901,
          -10254.071,
          -10206.72,
          -10158.847,
          -10110.449,
          -10061.528,
          -10012.08,
          -9962.105,
          -9911.601,
          -9860.568000000001,
          -9809.003,
          -9756.907,
          -9704.276,
          -9651.11,
          -9597.407,
          -9543.166,
          -9488.385,
          -9433.064,
          -9377.2,
          -9320.791,
          -9263.838,
          -9206.337,
          -9148.287,
          -9089.687,
          -9030.534,
          -8970.829,
          -8910.567,
          -8849.749,
          -8788.372,
          -8726.434000000001,
          -8663.934000000001,
          -8600.87,
          -8537.24,
          -8473.042,
          -8408.275,
          -8342.936,
          -8277.023000000001,
          -8210.536,
          -8143.471,
          -8075.826999999999,
          -8007.602,
          -7938.793000000001,
          -7869.399,
          -7799.4169999999995,
          -7728.846,
          -7657.684,
          -7585.928000000001,
          -7513.576,
          -7440.626,
          -7367.076999999999,
          -7292.925,
          -7218.168000000001,
          -7142.805,
          -7066.834,
          -6990.251,
          -6913.055,
          -6835.244000000001,
          -6756.814,
          -6677.765,
          -6598.094,
          -6517.798000000001,
          -6436.875,
          -6355.323,
          -6273.141,
          -6190.325,
          -6106.871999999999,
          -6022.781999999999,
          -5938.052,
          -5852.679,
          -5766.661999999999,
          -5679.999,
          -5592.687,
          -5504.724,
          -5416.108,
          -5326.838000000001,
          -5236.912,
          -5146.327,
          -5055.082,
          -4963.175,
          -4870.605,
          -4777.37,
          -4683.468,
          -4588.9,
          -4493.663,
          -4397.755999999999,
          -4301.179,
          -4203.931,
          -4106.012,
          -4007.42,
          -3908.157,
          -3808.222,
          -3707.617,
          -3606.341,
          -3504.3959999999997,
          -3401.783,
          -3298.505,
          -3194.563,
          -3089.961,
          -2984.7009999999996,
          -2878.788,
          -2772.225,
          -2665.0190000000002,
          -2557.174,
          -2448.697,
          -2339.596,
          -2229.879,
          -2119.556,
          -2008.6370000000002,
          -1897.1329999999998,
          -1785.058,
          -1672.4270000000001,
          -1559.254,
          -1445.558,
          -1331.359,
          -1216.6789999999999,
          -1101.5410000000002,
          -985.972,
          -870.002,
          -753.663,
          -636.991,
          -520.025,
          -402.80800000000005,
          -285.388,
          -167.81799999999998,
          -50.156000000000006,
          67.535,
          185.18400000000003,
          302.714,
          420.04,
          537.068,
          653.696,
          769.809,
          885.283,
          999.9810000000001,
          1113.752,
          1226.431,
          1337.836,
          1447.765,
          1556.003,
          1662.309,
          1766.424,
          1868.0620000000001,
          1966.918,
          2062.654,
          2154.9120000000003,
          2243.305,
          2327.422,
          2406.825,
          2481.054,
          2549.631,
          2612.062,
          2667.848,
          2716.487,
          2757.488,
          2790.382,
          2814.7340000000004,
          2830.155,
          2836.317,
          2832.9640000000004,
          2819.925,
          2797.1209999999996,
          2764.5690000000004,
          2722.385,
          2670.781,
          2610.056,
          2540.594,
          2462.8379999999997,
          2377.292,
          2284.492,
          2185.001,
          2079.391,
          1968.236,
          1852.096,
          1731.513,
          1607.005,
          1479.0610000000001,
          1348.136,
          1214.653,
          1079.004,
          941.543,
          802.5980000000001,
          662.461,
          521.401,
          379.655,
          237.44,
          94.947,
          -47.652,
          -190.203,
          -332.569,
          -474.631,
          -616.28,
          -757.422,
          -897.9730000000001,
          -1037.859,
          -1177.015,
          -1315.385,
          -1452.9189999999999,
          -1589.5739999999998,
          -1725.3110000000001,
          -1860.099,
          -1993.91,
          -2126.719,
          -2258.506,
          -2389.254,
          -2518.949,
          -2647.579,
          -2775.136,
          -2901.611,
          -3026.998,
          -3151.295,
          -3274.498,
          -3396.6059999999998,
          -3517.619,
          -3637.539,
          -3756.367,
          -3874.105,
          -3990.757,
          -4106.326,
          -4220.818,
          -4334.237,
          -4446.589,
          -4557.878,
          -4668.111,
          -4777.295,
          -4885.435,
          -4992.538,
          -5098.612,
          -5203.662,
          -5307.696999999999,
          -5410.724,
          -5512.749,
          -5613.779,
          -5713.823,
          -5812.888000000001,
          -5910.981,
          -6008.108,
          -6104.278,
          -6199.4980000000005,
          -6293.774,
          -6387.115,
          -6479.526999999999,
          -6571.017,
          -6661.593000000001,
          -6751.262,
          -6840.03,
          -6927.904,
          -7014.892,
          -7100.999,
          -7186.232,
          -7270.599,
          -7354.105,
          -7436.757,
          -7518.562,
          -7599.525,
          -7679.651999999999,
          -7758.95,
          -7837.425,
          -7915.081999999999,
          -7991.927,
          -8067.967,
          -8143.206999999999,
          -8217.652,
          -8291.308,
          -8364.181,
          -8436.275,
          -8507.597,
          -8578.15,
          -8647.940999999999,
          -8716.974,
          -8785.255,
          -8852.788,
          -8919.578000000001,
          -8985.629,
          -9050.947,
          -9115.536,
          -9179.4,
          -9242.545,
          -9304.974,
          -9366.690999999999,
          -9427.702,
          -9488.009,
          -9547.618,
          -9606.532,
          -9664.756,
          -9722.293,
          -9779.146999999999,
          -9835.322,
          -9890.821,
          -9945.649,
          -9999.809000000001,
          -10053.305,
          -10106.14,
          -10158.318000000001,
          -10209.841999999999,
          -10260.715,
          -10310.940999999999,
          -10360.521999999999,
          -10409.463,
          -10457.766,
          -10505.435,
          -10552.472,
          -10598.881000000001,
          -10644.663999999999,
          -10689.825,
          -10734.365,
          -10778.288999999999,
          -10821.598999999998,
          -10864.298,
          -10906.388,
          -10947.871000000001,
          -10988.752,
          -11029.031,
          -11068.713,
          -11107.798,
          -11146.291000000001,
          -11184.192,
          -11221.505,
          -11258.232,
          -11294.374,
          -11329.935,
          -11364.916000000001,
          -11399.32,
          -11433.149,
          -11466.405,
          -11499.09,
          -11531.206,
          -11562.756000000001,
          -11593.74,
          -11624.162,
          -11654.021999999999,
          -11683.323999999999,
          -11712.068000000001,
          -11740.257,
          -11767.892,
          -11794.976,
          -11821.508999999998,
          -11847.493999999999,
          -11872.931999999999,
          -11897.825,
          -11922.175,
          -11945.983,
          -11969.25,
          -11991.979,
          -12014.171,
          -12035.827,
          -12056.948999999999,
          -12077.537,
          -12097.594,
          -12117.121000000001,
          -12136.12,
          -12154.59,
          -12172.535,
          -12189.955,
          -12206.851,
          -12223.226,
          -12239.078000000001,
          -12254.411,
          -12269.226,
          -12283.521999999999,
          -12297.302,
          -12310.567,
          -12323.317,
          -12335.553999999998,
          -12347.278999999999,
          -12358.492,
          -12369.195,
          -12379.389,
          -12389.075,
          -12398.253,
          -12406.923999999999,
          -12415.09,
          -12422.751,
          -12429.908000000001,
          -12436.562,
          -12442.714,
          -12448.363000000001,
          -12453.511999999999,
          -12458.161,
          -12462.311000000002,
          -12465.961000000001,
          -12469.114,
          -12471.768999999998,
          -12473.928,
          -12475.591,
          -12476.758,
          -12477.43,
          -12477.608,
          -12477.292,
          -12476.483,
          -12475.181999999999,
          -12473.388,
          -12471.101999999999,
          -12468.325,
          -12465.056999999999,
          -12461.298999999999,
          -12457.05,
          -12452.312,
          -12447.085,
          -12441.368999999999,
          -12435.163999999999,
          -12428.471000000001,
          -12421.29,
          -12413.622,
          -12405.466,
          -12396.823,
          -12387.692,
          -12378.075,
          -12367.972,
          -12357.382,
          -12346.306,
          -12334.743999999999,
          -12322.696000000002,
          -12310.162,
          -12297.142,
          -12283.636999999999,
          -12269.646,
          -12255.17,
          -12240.208,
          -12224.761,
          -12208.828000000001,
          -12192.409,
          -12175.505,
          -12158.116000000002,
          -12140.241000000002,
          -12121.88,
          -12103.033000000001,
          -12083.7,
          -12063.881000000001,
          -12043.575,
          -12022.783000000001,
          -12001.505,
          -11979.74,
          -11957.488000000001,
          -11934.748,
          -11911.52,
          -11887.805,
          -11863.601,
          -11838.909,
          -11813.728000000001,
          -11788.058,
          -11761.899,
          -11735.249,
          -11708.11,
          -11680.479,
          -11652.357,
          -11623.743999999999,
          -11594.639,
          -11565.041000000001,
          -11534.95,
          -11504.366000000002,
          -11473.287,
          -11441.714,
          -11409.646,
          -11377.082,
          -11344.021,
          -11310.463,
          -11276.408000000001,
          -11241.854,
          -11206.802,
          -11171.249,
          -11135.196000000002,
          -11098.642,
          -11061.586000000001,
          -11024.028,
          -10985.966,
          -10947.4,
          -10908.328000000001,
          -10868.75,
          -10828.665,
          -10788.073,
          -10746.972,
          -10705.361,
          -10663.24,
          -10620.607,
          -10577.462,
          -10533.803,
          -10489.63,
          -10444.940999999999,
          -10399.735,
          -10354.011999999999,
          -10307.77,
          -10261.008,
          -10213.724,
          -10165.919,
          -10117.589,
          -10068.735,
          -10019.357,
          -9969.449,
          -9919.014000000001,
          -9868.048,
          -9816.552,
          -9764.523000000001,
          -9711.96,
          -9658.862,
          -9605.226999999999,
          -9551.055,
          -9496.343,
          -9441.09,
          -9385.294,
          -9328.954,
          -9272.068000000001,
          -9214.636,
          -9156.654,
          -9098.123,
          -9039.039,
          -8979.402,
          -8919.209,
          -8858.459,
          -8797.151,
          -8735.282,
          -8672.851,
          -8609.855,
          -8546.294,
          -8482.165,
          -8417.466999999999,
          -8352.197,
          -8286.354,
          -8219.935,
          -8152.939,
          -8085.3640000000005,
          -8017.2080000000005,
          -7948.469,
          -7879.144,
          -7809.232,
          -7738.73,
          -7667.637,
          -7595.951,
          -7523.668000000001,
          -7450.7880000000005,
          -7377.308000000001,
          -7303.226,
          -7228.539000000001,
          -7153.246,
          -7077.344,
          -7000.831,
          -6923.704000000001,
          -6845.9619999999995,
          -6767.603,
          -6688.624,
          -6609.022,
          -6528.797,
          -6447.944,
          -6366.4619999999995,
          -6284.348000000001,
          -6201.602,
          -6118.219,
          -6034.1990000000005,
          -5949.5380000000005,
          -5864.235,
          -5778.2880000000005,
          -5691.694,
          -5604.451,
          -5516.557,
          -5428.0109999999995,
          -5338.81,
          -5248.953,
          -5158.437,
          -5067.2609999999995,
          -4975.423,
          -4882.920999999999,
          -4789.755,
          -4695.9220000000005,
          -4601.420999999999,
          -4506.251,
          -4410.412,
          -4313.901,
          -4216.72,
          -4118.867,
          -4020.341,
          -3921.143,
          -3821.2740000000003,
          -3720.7329999999997,
          -3619.5209999999997,
          -3517.639,
          -3415.0890000000004,
          -3311.873,
          -3207.993,
          -3103.452,
          -2998.252,
          -2892.397,
          -2785.8920000000003,
          -2678.742,
          -2570.952,
          -2462.53,
          -2353.482,
          -2243.8160000000003,
          -2133.542,
          -2022.67,
          -1911.2120000000002,
          -1799.18,
          -1686.589,
          -1573.455,
          -1459.795,
          -1345.629,
          -1230.978,
          -1115.867,
          -1000.321,
          -884.37,
          -768.045,
          -651.382,
          -534.42,
          -417.20099999999996,
          -299.774,
          -182.18900000000002,
          -64.50399999999999,
          53.217,
          170.90599999999998,
          288.485,
          405.871,
          522.971,
          639.682,
          755.8939999999999,
          871.4810000000001,
          986.309,
          1100.2269999999999,
          1213.073,
          1324.6660000000002,
          1434.808,
          1543.2839999999999,
          1649.856,
          1754.2679999999998,
          1856.236,
          1955.455,
          2051.594,
          2144.297,
          2233.179,
          2317.83,
          2397.817,
          2472.681,
          2541.946,
          2605.12,
          2661.704,
          2711.1929999999998,
          2753.099,
          2786.947,
          2812.297,
          2828.756,
          2835.988,
          2833.7290000000003,
          2821.798,
          2800.105,
          2768.658,
          2727.5609999999997,
          2677.0159999999996,
          2617.314,
          2548.8289999999997,
          2472.001,
          2387.323,
          2295.3320000000003,
          2196.587,
          2091.663,
          1981.129,
          1865.55,
          1745.47,
          1621.408,
          1493.858,
          1363.279,
          1230.096,
          1094.705,
          957.4639999999999,
          818.704,
          678.72,
          537.785,
          396.13699999999994,
          253.99599999999998,
          111.557,
          -31.006999999999998,
          -173.53900000000002,
          -315.469,
          -457.976,
          -599.648,
          -740.824,
          -881.419,
          -1021.3580000000001,
          -1160.5739999999998,
          -1299.011,
          -1436.618,
          -1573.351,
          -1709.172,
          -1844.0479999999998,
          -1977.9489999999998,
          -2110.853,
          -2242.737,
          -2373.5860000000002,
          -2503.383,
          -2632.118,
          -2759.78,
          -2886.362,
          -3011.8579999999997,
          -3136.264,
          -3259.577,
          -3381.797,
          -3502.922,
          -3622.954,
          -3741.8940000000002,
          -3859.745,
          -3976.51,
          -4092.1940000000004,
          -4206.799,
          -4320.33,
          -4432.795,
          -4544.197,
          -4654.543,
          -4763.838,
          -4872.090999999999,
          -4979.306,
          -5085.491,
          -5190.653,
          -5294.8,
          -5397.937,
          -5500.071999999999,
          -5601.213000000001,
          -5701.366,
          -5800.539000000001,
          -5898.74,
          -5995.975,
          -6092.2519999999995,
          -6187.579000000001,
          -6281.9619999999995,
          -6375.409000000001,
          -6467.927,
          -6559.523,
          -6650.204000000001,
          -6739.976,
          -6828.848000000001,
          -6916.826,
          -7003.916,
          -7090.125,
          -7175.46,
          -7259.928000000001,
          -7343.535,
          -7426.286999999999,
          -7508.191,
          -7589.253000000001,
          -7669.48,
          -7748.8769999999995,
          -7827.45,
          -7905.205,
          -7982.148,
          -8058.284000000001,
          -8133.621,
          -8208.162,
          -8281.913,
          -8354.881,
          -8427.07,
          -8498.485999999999,
          -8569.133,
          -8639.017,
          -8708.144,
          -8776.517,
          -8844.143,
          -8911.024,
          -8977.168,
          -9042.577,
          -9107.256,
          -9171.211,
          -9234.446,
          -9296.965,
          -9358.771999999999,
          -9419.871,
          -9480.268,
          -9539.965,
          -9598.966999999999,
          -9657.279,
          -9714.903,
          -9771.844000000001,
          -9828.106,
          -9883.692,
          -9938.607,
          -9992.854,
          -10046.435,
          -10099.356,
          -10151.618,
          -10203.226999999999,
          -10254.184000000001,
          -10304.494,
          -10354.16,
          -10403.185,
          -10451.571,
          -10499.323,
          -10546.443000000001,
          -10592.935,
          -10638.8,
          -10684.043,
          -10728.666000000001,
          -10772.671999999999,
          -10816.063,
          -10858.844,
          -10901.015,
          -10942.58,
          -10983.541000000001,
          -11023.901000000002,
          -11063.662,
          -11102.828000000001,
          -11141.4,
          -11179.38,
          -11216.771999999999,
          -11253.578000000001,
          -11289.798999999999,
          -11325.438999999998,
          -11360.499,
          -11394.981000000002,
          -11428.888,
          -11462.222,
          -11494.985,
          -11527.178999999998,
          -11558.806,
          -11589.868,
          -11620.367,
          -11650.305,
          -11679.683,
          -11708.503999999999,
          -11736.768999999998,
          -11764.481000000002,
          -11791.64,
          -11818.25,
          -11844.31,
          -11869.823999999999,
          -11894.793,
          -11919.218,
          -11943.101,
          -11966.443000000001,
          -11989.247,
          -12011.513,
          -12033.243999999999,
          -12054.44,
          -12075.101999999999,
          -12095.233999999999,
          -12114.835,
          -12133.907,
          -12152.452,
          -12170.471000000001,
          -12187.964,
          -12204.934,
          -12221.382,
          -12237.308,
          -12252.714,
          -12267.601,
          -12281.97,
          -12295.823,
          -12309.16,
          -12321.983,
          -12334.292,
          -12346.089,
          -12357.375,
          -12368.15,
          -12378.416000000001,
          -12388.173,
          -12397.423,
          -12406.166000000001,
          -12414.403,
          -12422.135,
          -12429.364,
          -12436.089,
          -12442.312,
          -12448.033000000001,
          -12453.253,
          -12457.973,
          -12462.193000000001,
          -12465.913999999999,
          -12469.138,
          -12471.864,
          -12474.093,
          -12475.826000000001,
          -12477.063999999998,
          -12477.806,
          -12478.053999999998,
          -12477.809,
          -12477.07,
          -12475.838,
          -12474.114,
          -12471.898000000001,
          -12469.19,
          -12465.992,
          -12462.303,
          -12458.125,
          -12453.456,
          -12448.298,
          -12442.651000000002,
          -12436.516000000001,
          -12429.893,
          -12422.781,
          -12415.181,
          -12407.094,
          -12398.52,
          -12389.458999999999,
          -12379.91,
          -12369.876,
          -12359.355,
          -12348.347,
          -12336.854,
          -12324.874,
          -12312.409,
          -12299.458,
          -12286.021,
          -12272.098999999998,
          -12257.691,
          -12242.796999999999,
          -12227.418,
          -12211.553999999998,
          -12195.204,
          -12178.368,
          -12161.046,
          -12143.239,
          -12124.947,
          -12106.168,
          -12086.903999999999,
          -12067.153,
          -12046.915,
          -12026.191,
          -12004.981000000002,
          -11983.283000000001,
          -11961.098,
          -11938.426000000001,
          -11915.266000000001,
          -11891.618999999999,
          -11867.483,
          -11842.858999999999,
          -11817.745,
          -11792.143,
          -11766.051000000001,
          -11739.469,
          -11712.396999999999,
          -11684.833999999999,
          -11656.78,
          -11628.235,
          -11599.197,
          -11569.667,
          -11539.643999999998,
          -11509.127,
          -11478.117,
          -11446.611,
          -11414.61,
          -11382.114,
          -11349.121000000001,
          -11315.631000000001,
          -11281.643,
          -11247.157,
          -11212.171,
          -11176.686000000002,
          -11140.701000000001,
          -11104.214,
          -11067.226,
          -11029.735,
          -10991.74,
          -10953.241000000002,
          -10914.237,
          -10874.726,
          -10834.708999999999,
          -10794.185,
          -10753.151000000002,
          -10711.608,
          -10669.555,
          -10626.99,
          -10583.913,
          -10540.321000000002,
          -10496.216,
          -10451.595,
          -10406.457,
          -10360.801,
          -10314.627,
          -10267.931999999999,
          -10220.716999999999,
          -10172.979,
          -10124.716999999999,
          -10075.931,
          -10026.619,
          -9976.78,
          -9926.412,
          -9875.515,
          -9824.086,
          -9772.125,
          -9719.63,
          -9666.6,
          -9613.034,
          -9558.929,
          -9504.286,
          -9449.101,
          -9393.373,
          -9337.101,
          -9280.284,
          -9222.92,
          -9165.007,
          -9106.544,
          -9047.529,
          -8987.96,
          -8927.836,
          -8867.155,
          -8805.915,
          -8744.114,
          -8681.752,
          -8618.825,
          -8555.333,
          -8491.273000000001,
          -8426.643,
          -8361.442,
          -8295.668,
          -8229.318000000001,
          -8162.391,
          -8094.885,
          -8026.799,
          -7958.128000000001,
          -7888.8730000000005,
          -7819.03,
          -7748.597,
          -7677.5740000000005,
          -7605.956,
          -7533.743,
          -7460.933000000001,
          -7387.522,
          -7313.509,
          -7238.892,
          -7163.668000000001,
          -7087.835,
          -7011.392,
          -6934.335,
          -6856.6630000000005,
          -6778.3730000000005,
          -6699.463000000001,
          -6619.932,
          -6539.776,
          -6458.991999999999,
          -6377.58,
          -6295.536,
          -6212.859,
          -6129.545999999999,
          -6045.595,
          -5961.004,
          -5875.771,
          -5789.893,
          -5703.368,
          -5616.194,
          -5528.37,
          -5439.893,
          -5350.7609999999995,
          -5260.972,
          -5170.525,
          -5079.418,
          -4987.649,
          -4895.215,
          -4802.117,
          -4708.352,
          -4613.919,
          -4518.816,
          -4423.045999999999,
          -4326.603,
          -4229.488,
          -4131.701,
          -4033.241,
          -3934.1090000000004,
          -3834.304,
          -3733.827,
          -3632.679,
          -3530.861,
          -3428.3740000000003,
          -3325.22,
          -3221.401,
          -3116.92,
          -3011.78,
          -2905.9840000000004,
          -2799.5359999999996,
          -2692.4429999999998,
          -2584.709,
          -2476.34,
          -2367.344,
          -2257.73,
          -2147.505,
          -2036.681,
          -1925.269,
          -1813.28,
          -1700.731,
          -1587.636,
          -1474.0120000000002,
          -1359.88,
          -1245.259,
          -1130.175,
          -1014.6519999999999,
          -898.7189999999999,
          -782.409,
          -665.755,
          -548.798,
          -431.57800000000003,
          -314.142,
          -196.543,
          -78.837,
          38.914,
          156.641,
          274.268,
          391.712,
          508.88199999999995,
          625.6759999999999,
          741.9830000000001,
          857.681,
          972.6360000000001,
          1086.701,
          1199.711,
          1311.49,
          1421.842,
          1530.5520000000001,
          1637.3870000000002,
          1742.092,
          1844.385,
          1943.964,
          2040.503,
          2133.644,
          2223.009,
          2308.19,
          2388.754,
          2464.248,
          2534.195,
          2598.106,
          2655.4809999999998,
          2705.816,
          2748.619,
          2783.4159999999997,
          2809.76,
          2827.2529999999997,
          2835.552,
          2834.385,
          2823.5609999999997,
          2802.98,
          2772.638,
          2732.631,
          2683.1490000000003,
          2624.4759999999997,
          2556.974,
          2481.078,
          2397.277,
          2306.1020000000003,
          2208.112,
          2103.879,
          1993.974,
          1878.963,
          1759.392,
          1635.7839999999999,
          1508.635,
          1378.406,
          1245.529,
          1110.401,
          973.385,
          834.814,
          694.987,
          554.178,
          412.63199999999995,
          270.569,
          128.186,
          -14.341,
          -156.85399999999998,
          -299.21299999999997,
          -441.295,
          -582.989,
          -724.197,
          -864.835,
          -1004.824,
          -1144.1,
          -1282.604,
          -1420.283,
          -1557.094,
          -1692.9979999999998,
          -1827.961,
          -1961.954,
          -2094.951,
          -2226.933,
          -2357.881,
          -2487.78,
          -2616.619,
          -2744.386,
          -2871.075,
          -2996.6809999999996,
          -3121.196,
          -3244.62,
          -3366.9509999999996,
          -3488.188,
          -3608.3320000000003,
          -3727.385,
          -3845.349,
          -3962.2270000000003,
          -4078.0229999999997,
          -4192.7429999999995,
          -4306.388,
          -4418.965,
          -4530.481,
          -4640.939,
          -4750.348,
          -4858.713,
          -4966.04,
          -5072.337,
          -5177.612,
          -5281.869000000001,
          -5385.116999999999,
          -5487.361999999999,
          -5588.613,
          -5688.875,
          -5788.158,
          -5886.467,
          -5983.811,
          -6080.196,
          -6175.63,
          -6270.12,
          -6363.673000000001,
          -6456.297,
          -6547.9980000000005,
          -6638.784000000001,
          -6728.661,
          -6817.6359999999995,
          -6905.717,
          -6992.91,
          -7079.222,
          -7164.66,
          -7249.23,
          -7332.938,
          -7415.791,
          -7497.795,
          -7578.956999999999,
          -7659.281999999999,
          -7738.778,
          -7817.4490000000005,
          -7895.302,
          -7972.342,
          -8048.576,
          -8124.009,
          -8198.646999999999,
          -8272.494,
          -8345.556999999999,
          -8417.841,
          -8489.351,
          -8560.093,
          -8630.071,
          -8699.291,
          -8767.757,
          -8835.474,
          -8902.448,
          -8968.683,
          -9034.185,
          -9098.956,
          -9163.001,
          -9226.326,
          -9288.935,
          -9350.832,
          -9412.021,
          -9472.506,
          -9532.292,
          -9591.383,
          -9649.783000000001,
          -9707.495,
          -9764.523000000001,
          -9820.872,
          -9876.546,
          -9931.546999999999,
          -9985.88,
          -10039.546999999999,
          -10092.553,
          -10144.901,
          -10196.595,
          -10247.636999999999,
          -10298.030999999999,
          -10347.780999999999,
          -10396.89,
          -10445.36,
          -10493.196000000002,
          -10540.399,
          -10586.973999999998,
          -10632.921999999999,
          -10678.248,
          -10722.953000000001,
          -10767.041000000001,
          -10810.514,
          -10853.376,
          -10895.628,
          -10937.274,
          -10978.315,
          -11018.756000000001,
          -11058.598,
          -11097.844,
          -11136.495,
          -11174.556,
          -11212.028,
          -11248.912,
          -11285.213,
          -11320.931999999999,
          -11356.071000000002,
          -11390.632,
          -11424.618,
          -11458.03,
          -11490.871000000001,
          -11523.142,
          -11554.847,
          -11585.986,
          -11616.562,
          -11646.576000000001,
          -11676.032,
          -11704.928999999998,
          -11733.271,
          -11761.059,
          -11788.295,
          -11814.98,
          -11841.117,
          -11866.707,
          -11891.751,
          -11916.252,
          -11940.211000000001,
          -11963.628999999999,
          -11986.507,
          -12008.848,
          -12030.653,
          -12051.923999999999,
          -12072.661,
          -12092.867,
          -12112.542,
          -12131.688999999998,
          -12150.306999999999,
          -12168.399,
          -12185.966,
          -12203.01,
          -12219.531,
          -12235.53,
          -12251.01,
          -12265.97,
          -12280.413,
          -12294.338,
          -12307.748,
          -12320.643999999998,
          -12333.026000000002,
          -12344.895,
          -12356.253,
          -12367.1,
          -12377.438,
          -12387.267,
          -12396.589,
          -12405.403999999999,
          -12413.713,
          -12421.516000000001,
          -12428.816,
          -12435.613000000001,
          -12441.906,
          -12447.698999999999,
          -12452.99,
          -12457.781,
          -12462.072,
          -12465.865,
          -12469.159,
          -12471.955,
          -12474.255,
          -12476.059,
          -12477.367,
          -12478.18,
          -12478.498,
          -12478.322,
          -12477.653999999999,
          -12476.492,
          -12474.838,
          -12472.692,
          -12470.053999999998,
          -12466.926000000001,
          -12463.306999999999,
          -12459.197,
          -12454.598,
          -12449.51,
          -12443.933,
          -12437.867,
          -12431.313,
          -12424.27,
          -12416.74,
          -12408.722,
          -12400.216999999999,
          -12391.223999999998,
          -12381.745,
          -12371.778999999999,
          -12361.327,
          -12350.388,
          -12338.964,
          -12327.053,
          -12314.656,
          -12301.774,
          -12288.406,
          -12274.552,
          -12260.213,
          -12245.388,
          -12230.078000000001,
          -12214.282,
          -12198,
          -12181.232,
          -12163.979,
          -12146.24,
          -12128.016000000001,
          -12109.305,
          -12090.108,
          -12070.425,
          -12050.256000000001,
          -12029.6,
          -12008.457,
          -11986.828000000001,
          -11964.711000000001,
          -11942.107,
          -11919.015,
          -11895.435,
          -11871.367,
          -11846.811000000002,
          -11821.766000000001,
          -11796.232,
          -11770.208,
          -11743.693000000001,
          -11716.688999999998,
          -11689.194,
          -11661.208,
          -11632.73,
          -11603.76,
          -11574.296999999999,
          -11544.341999999999,
          -11513.892,
          -11482.948999999999,
          -11451.511,
          -11419.578000000001,
          -11387.149,
          -11354.223,
          -11320.801000000001,
          -11286.881000000001,
          -11252.462,
          -11217.545,
          -11182.128,
          -11146.21,
          -11109.791000000001,
          -11072.87,
          -11035.447,
          -10997.52,
          -10959.088,
          -10920.152,
          -10880.708999999999,
          -10840.76,
          -10800.302,
          -10759.337,
          -10717.861,
          -10675.875,
          -10633.378,
          -10590.368,
          -10546.844,
          -10502.806999999999,
          -10458.253,
          -10413.184000000001,
          -10367.596,
          -10321.489,
          -10274.863000000001,
          -10227.715,
          -10180.045,
          -10131.851999999999,
          -10083.134,
          -10033.89,
          -9984.118,
          -9933.819,
          -9882.989,
          -9831.629,
          -9779.735999999999,
          -9727.309000000001,
          -9674.347,
          -9620.849,
          -9566.813,
          -9512.237,
          -9457.12,
          -9401.461,
          -9345.258,
          -9288.509,
          -9231.213,
          -9173.369,
          -9114.974,
          -9056.027,
          -8996.527,
          -8936.472,
          -8875.859,
          -8814.688,
          -8752.957,
          -8690.663,
          -8627.805,
          -8564.382,
          -8500.39,
          -8435.83,
          -8370.698,
          -8304.993,
          -8238.713,
          -8171.855,
          -8104.418000000001,
          -8036.4,
          -7967.799,
          -7898.611999999999,
          -7828.839,
          -7758.476,
          -7687.521,
          -7615.973000000001,
          -7543.83,
          -7471.089,
          -7397.7480000000005,
          -7323.804,
          -7249.257,
          -7174.103,
          -7098.340999999999,
          -7021.967,
          -6944.98,
          -6867.3769999999995,
          -6789.156999999999,
          -6710.316999999999,
          -6630.855,
          -6550.768,
          -6470.054,
          -6388.7119999999995,
          -6306.738,
          -6224.13,
          -6140.887,
          -6057.005999999999,
          -5972.485,
          -5887.321999999999,
          -5801.513000000001,
          -5715.058000000001,
          -5627.954000000001,
          -5540.1990000000005,
          -5451.7919999999995,
          -5362.729,
          -5273.009,
          -5182.630999999999,
          -5091.592000000001,
          -4999.891,
          -4907.526,
          -4814.496,
          -4720.799,
          -4626.434,
          -4531.4,
          -4435.696,
          -4339.32,
          -4242.272,
          -4144.5509999999995,
          -4046.157,
          -3947.091,
          -3847.3509999999997,
          -3746.9390000000003,
          -3645.8559999999998,
          -3544.1009999999997,
          -3441.677,
          -3338.585,
          -3234.828,
          -3130.407,
          -3025.327,
          -2919.59,
          -2813.2009999999996,
          -2706.165,
          -2598.486,
          -2490.172,
          -2381.23,
          -2271.666,
          -2161.492,
          -2050.716,
          -1939.35,
          -1827.406,
          -1714.898,
          -1601.842,
          -1488.256,
          -1374.1570000000002,
          -1259.568,
          -1144.511,
          -1029.011,
          -913.0980000000001,
          -796.803,
          -680.16,
          -563.2080000000001,
          -445.98800000000006,
          -328.546,
          -210.93400000000003,
          -93.20700000000001,
          24.572,
          142.336,
          260.01,
          377.51099999999997,
          494.749,
          611.624,
          728.0260000000001,
          843.8330000000001,
          958.914,
          1073.122,
          1186.295,
          1298.258,
          1408.817,
          1517.76,
          1624.855,
          1729.849,
          1832.464,
          1932.401,
          2029.335,
          2122.913,
          2212.756,
          2298.4629999999997,
          2379.6020000000003,
          2455.722,
          2526.348,
          2590.992,
          2649.1540000000005,
          2700.333,
          2744.033,
          2779.776,
          2807.114,
          2825.6420000000003,
          2835.009,
          2834.935,
          2825.223,
          2805.759,
          2776.531,
          2737.6220000000003,
          2689.2129999999997,
          2631.5759999999996,
          2565.0679999999998,
          2490.115,
          2407.202,
          2316.855,
          2219.631,
          2116.098,
          2006.8339999999998,
          1892.401,
          1773.348,
          1650.203,
          1523.461,
          1393.5910000000001,
          1261.027,
          1126.167,
          989.3810000000001,
          851.003,
          711.3380000000001,
          570.661,
          429.221,
          287.238,
          144.914,
          2.426,
          -140.065,
          -282.418,
          -424.50800000000004,
          -566.2230000000001,
          -707.4639999999999,
          -848.1439999999999,
          -988.184,
          -1127.519,
          -1266.088,
          -1403.84,
          -1540.729,
          -1676.7160000000001,
          -1811.765,
          -1945.849,
          -2078.942,
          -2211.022,
          -2342.07,
          -2472.072,
          -2601.015,
          -2728.889,
          -2855.685,
          -2981.3990000000003,
          -3106.025,
          -3229.5609999999997,
          -3352.0029999999997,
          -3473.353,
          -3593.61,
          -3712.777,
          -3830.855,
          -3947.847,
          -4063.758,
          -4178.59,
          -4292.35,
          -4405.041,
          -4516.670999999999,
          -4627.2429999999995,
          -4736.765,
          -4845.2429999999995,
          -4952.685,
          -5059.095,
          -5164.481,
          -5268.85,
          -5372.209,
          -5474.566,
          -5575.927,
          -5676.3,
          -5775.693,
          -5874.111999999999,
          -5971.565,
          -6068.058000000001,
          -6163.6,
          -6258.198,
          -6351.858,
          -6444.588000000001,
          -6536.395,
          -6627.286,
          -6717.269,
          -6806.35,
          -6894.535,
          -6981.831999999999,
          -7068.246999999999,
          -7153.786999999999,
          -7238.459,
          -7322.269,
          -7405.223000000001,
          -7487.328,
          -7568.590999999999,
          -7649.017,
          -7728.611999999999,
          -7807.382,
          -7885.3330000000005,
          -7962.472,
          -8038.803000000001,
          -8114.3330000000005,
          -8189.066999999999,
          -8263.011,
          -8336.171,
          -8408.551,
          -8480.155999999999,
          -8550.993,
          -8621.065,
          -8690.379,
          -8758.938,
          -8826.749,
          -8893.815999999999,
          -8960.143,
          -9025.735999999999,
          -9090.599,
          -9154.735999999999,
          -9218.153,
          -9280.851999999999,
          -9342.839,
          -9404.118,
          -9464.693000000001,
          -9524.568000000001,
          -9583.748,
          -9642.235999999999,
          -9700.037,
          -9757.153,
          -9813.59,
          -9869.351,
          -9924.439,
          -9978.858,
          -10032.612,
          -10085.704,
          -10138.138,
          -10189.917,
          -10241.045,
          -10291.524,
          -10341.359,
          -10390.552,
          -10439.107,
          -10487.026000000002,
          -10534.313999999998,
          -10580.972,
          -10627.003,
          -10672.412,
          -10717.198999999999,
          -10761.37,
          -10804.925,
          -10847.868,
          -10890.202,
          -10931.928999999998,
          -10973.052,
          -11013.573999999999,
          -11053.497,
          -11092.823999999999,
          -11131.556,
          -11169.697,
          -11207.248,
          -11244.213,
          -11280.593,
          -11316.391000000001,
          -11351.608999999999,
          -11386.249,
          -11420.313,
          -11453.803999999998,
          -11486.723,
          -11519.073,
          -11550.855,
          -11582.072,
          -11612.726,
          -11642.818000000001,
          -11672.351,
          -11701.326000000001,
          -11729.745,
          -11757.61,
          -11784.921999999999,
          -11811.684,
          -11837.896999999999,
          -11863.563,
          -11888.683,
          -11913.258999999998,
          -11937.293,
          -11960.787,
          -11983.741000000002,
          -12006.157,
          -12028.037,
          -12049.383,
          -12070.196000000002,
          -12090.476,
          -12110.226,
          -12129.447,
          -12148.139,
          -12166.306,
          -12183.947,
          -12201.063999999998,
          -12217.659,
          -12233.732,
          -12249.284,
          -12264.318000000001,
          -12278.833999999999,
          -12292.832,
          -12306.315,
          -12319.284,
          -12331.739,
          -12343.681,
          -12355.112,
          -12366.031,
          -12376.442,
          -12386.343,
          -12395.737,
          -12404.624,
          -12413.005,
          -12420.88,
          -12428.252,
          -12435.12,
          -12441.485,
          -12447.348999999998,
          -12452.711000000001,
          -12457.573,
          -12461.936000000002,
          -12465.8,
          -12469.165,
          -12472.033000000001,
          -12474.403,
          -12476.278,
          -12477.656,
          -12478.54,
          -12478.928999999998,
          -12478.823,
          -12478.225,
          -12477.133,
          -12475.548999999999,
          -12473.473999999998,
          -12470.906,
          -12467.848,
          -12464.298999999999,
          -12460.26,
          -12455.731000000002,
          -12450.712,
          -12445.205,
          -12439.208,
          -12432.723,
          -12425.75,
          -12418.288999999999,
          -12410.34,
          -12401.903999999999,
          -12392.981000000002,
          -12383.571000000002,
          -12373.675,
          -12363.291000000001,
          -12352.421999999999,
          -12341.066,
          -12329.223999999998,
          -12316.896999999999,
          -12304.083999999999,
          -12290.785,
          -12276.999,
          -12262.729,
          -12247.972,
          -12232.73,
          -12217.003,
          -12200.788999999999,
          -12184.09,
          -12166.906,
          -12149.235,
          -12131.079,
          -12112.437,
          -12093.308,
          -12073.693000000001,
          -12053.591999999999,
          -12033.005,
          -12011.931,
          -11990.37,
          -11968.321000000002,
          -11945.785,
          -11922.761,
          -11899.25,
          -11875.25,
          -11850.761,
          -11825.784,
          -11800.317,
          -11774.361,
          -11747.915,
          -11720.978000000001,
          -11693.551000000001,
          -11665.633,
          -11637.223,
          -11608.32,
          -11578.926000000001,
          -11549.038999999999,
          -11518.658000000001,
          -11487.782,
          -11456.412,
          -11424.546,
          -11392.185,
          -11359.327,
          -11325.973,
          -11292.12,
          -11257.77,
          -11222.92,
          -11187.57,
          -11151.72,
          -11115.368999999999,
          -11078.516000000001,
          -11041.16,
          -11003.301000000001,
          -10964.937,
          -10926.069,
          -10886.694,
          -10846.813,
          -10806.423,
          -10765.525,
          -10724.118,
          -10682.2,
          -10639.77,
          -10596.828000000001,
          -10553.373,
          -10509.403,
          -10464.917,
          -10419.915,
          -10374.395,
          -10328.357,
          -10281.798,
          -10234.719000000001,
          -10187.117,
          -10138.992,
          -10090.341999999999,
          -10041.166,
          -9991.463,
          -9941.232,
          -9890.47,
          -9839.178,
          -9787.353000000001,
          -9734.995,
          -9682.101999999999,
          -9628.671,
          -9574.703000000001,
          -9520.196,
          -9465.148000000001,
          -9409.556999999999,
          -9353.423,
          -9296.743,
          -9239.516,
          -9181.74,
          -9123.414,
          -9064.536,
          -9005.104,
          -8945.118,
          -8884.574,
          -8823.472,
          -8761.809000000001,
          -8699.585,
          -8636.796,
          -8573.442,
          -8509.52,
          -8445.029,
          -8379.966,
          -8314.33,
          -8248.119,
          -8181.33,
          -8113.963000000001,
          -8046.014,
          -7977.483,
          -7908.366,
          -7838.661999999999,
          -7768.368,
          -7697.484,
          -7626.005,
          -7553.932,
          -7481.2609999999995,
          -7407.99,
          -7334.116,
          -7259.639,
          -7184.554,
          -7108.861,
          -7032.558000000001,
          -6955.641,
          -6878.108,
          -6799.9580000000005,
          -6721.188,
          -6641.795999999999,
          -6561.779,
          -6481.1359999999995,
          -6399.8640000000005,
          -6317.96,
          -6235.423000000001,
          -6152.25,
          -6068.439,
          -5983.986999999999,
          -5898.893,
          -5813.155,
          -5726.77,
          -5639.736,
          -5552.05,
          -5463.7119999999995,
          -5374.72,
          -5285.07,
          -5194.7609999999995,
          -5103.792,
          -5012.16,
          -4919.8640000000005,
          -4826.903,
          -4733.274,
          -4638.977,
          -4544.0109999999995,
          -4448.374,
          -4352.066,
          -4255.085,
          -4157.431,
          -4059.1040000000003,
          -3960.105,
          -3860.4309999999996,
          -3760.0840000000003,
          -3659.065,
          -3557.375,
          -3455.015,
          -3351.986,
          -3248.29,
          -3143.9309999999996,
          -3038.9109999999996,
          -2933.2340000000004,
          -2826.9040000000005,
          -2719.925,
          -2612.304,
          -2504.045,
          -2395.156,
          -2285.645,
          -2175.521,
          -2064.794,
          -1953.475,
          -1841.576,
          -1729.111,
          -1616.096,
          -1502.547,
          -1388.483,
          -1273.925,
          -1158.896,
          -1043.422,
          -927.53,
          -811.2510000000001,
          -694.62,
          -577.674,
          -460.455,
          -343.00800000000004,
          -225.38400000000001,
          -107.639,
          10.168,
          127.96799999999999,
          245.687,
          363.244,
          480.548,
          597.502,
          713.997,
          829.9119999999999,
          945.117,
          1059.4660000000001,
          1172.8,
          1284.944,
          1395.7079999999999,
          1504.881,
          1612.235,
          1717.516,
          1820.451,
          1920.743,
          2018.069,
          2112.08,
          2202.401,
          2288.631,
          2370.343,
          2447.085,
          2518.388,
          2583.764,
          2642.7140000000004,
          2694.7340000000004,
          2739.3309999999997,
          2776.0209999999997,
          2804.355,
          2823.9190000000003,
          2834.36,
          2835.387,
          2826.792,
          2808.454,
          2780.347,
          2742.546,
          2695.22,
          2638.633,
          2573.132,
          2499.135,
          2417.1220000000003,
          2327.617,
          2231.1710000000003,
          2128.353,
          2019.74,
          1905.8970000000002,
          1787.3729999999998,
          1664.6989999999998,
          1538.375,
          1408.872,
          1276.627,
          1142.0430000000001,
          1005.493,
          867.314,
          727.815,
          587.274,
          445.94199999999995,
          304.043,
          161.78,
          19.334,
          -123.133,
          -265.573,
          -407.57599999999996,
          -549.311,
          -690.5830000000001,
          -831.304,
          -971.395,
          -1110.789,
          -1249.424,
          -1387.2479999999998,
          -1524.2160000000001,
          -1660.285,
          -1795.4229999999998,
          -1929.598,
          -2062.786,
          -2194.965,
          -2326.114,
          -2456.219,
          -2585.268,
          -2713.2490000000003,
          -2840.1540000000005,
          -2965.978,
          -3090.716,
          -3214.364,
          -3336.9190000000003,
          -3458.383,
          -3578.7540000000004,
          -3698.035,
          -3816.228,
          -3933.335,
          -4049.362,
          -4164.31,
          -4278.185,
          -4390.991,
          -4502.736,
          -4613.423,
          -4723.06,
          -4831.653,
          -4939.208,
          -5045.732,
          -5151.232,
          -5255.714,
          -5359.186,
          -5461.655,
          -5563.128000000001,
          -5663.613,
          -5763.116999999999,
          -5861.647,
          -5959.209,
          -6055.813,
          -6151.464,
          -6246.17,
          -6339.938,
          -6432.775,
          -6524.69,
          -6615.687,
          -6705.776,
          -6794.9619999999995,
          -6883.253000000001,
          -6970.655,
          -7057.174,
          -7142.818,
          -7227.593000000001,
          -7311.505999999999,
          -7394.563,
          -7476.769,
          -7558.133000000001,
          -7638.66,
          -7718.356,
          -7797.226,
          -7875.276999999999,
          -7952.514,
          -8028.944,
          -8104.573,
          -8179.405,
          -8253.446,
          -8326.702,
          -8399.179,
          -8470.88,
          -8541.812,
          -8611.98,
          -8681.388,
          -8750.042,
          -8817.947,
          -8885.108,
          -8951.528,
          -9017.214,
          -9082.17,
          -9146.399,
          -9209.907,
          -9272.698,
          -9334.776,
          -9396.145,
          -9456.811,
          -9516.776,
          -9576.045,
          -9634.623,
          -9692.511999999999,
          -9749.718,
          -9806.243,
          -9862.091999999999,
          -9917.268,
          -9971.774,
          -10025.615,
          -10078.794,
          -10131.314,
          -10183.18,
          -10234.393,
          -10284.958,
          -10334.879,
          -10384.157,
          -10432.796999999999,
          -10480.801,
          -10528.171999999999,
          -10574.913999999999,
          -10621.028999999999,
          -10666.521,
          -10711.392,
          -10755.645,
          -10799.283000000001,
          -10842.309,
          -10884.726,
          -10926.535,
          -10967.74,
          -11008.343,
          -11048.348,
          -11087.755,
          -11126.568000000001,
          -11164.788999999999,
          -11202.421,
          -11239.466,
          -11275.926000000001,
          -11311.803999999998,
          -11347.101,
          -11381.821000000002,
          -11415.965,
          -11449.535,
          -11482.533000000001,
          -11514.961000000001,
          -11546.822,
          -11578.118,
          -11608.848999999998,
          -11639.018999999998,
          -11668.63,
          -11697.681999999999,
          -11726.178,
          -11754.12,
          -11781.51,
          -11808.348999999998,
          -11834.639,
          -11860.381000000001,
          -11885.578000000001,
          -11910.23,
          -11934.34,
          -11957.909,
          -11980.938999999998,
          -12003.431,
          -12025.386999999999,
          -12046.806999999999,
          -12067.695,
          -12088.05,
          -12107.875,
          -12127.17,
          -12145.938,
          -12164.178999999998,
          -12181.895,
          -12199.086000000001,
          -12215.755,
          -12231.902,
          -12247.528,
          -12262.635,
          -12277.223999999998,
          -12291.296999999999,
          -12304.853000000001,
          -12317.893999999998,
          -12330.421999999999,
          -12342.437,
          -12353.941,
          -12364.934,
          -12375.417,
          -12385.391000000001,
          -12394.857,
          -12403.816,
          -12412.268999999998,
          -12420.216999999999,
          -12427.66,
          -12434.6,
          -12441.037,
          -12446.972,
          -12452.406,
          -12457.34,
          -12461.774,
          -12465.708999999999,
          -12469.146,
          -12472.083999999999,
          -12474.526000000002,
          -12476.471000000001,
          -12477.921,
          -12478.875,
          -12479.333999999999,
          -12479.3,
          -12478.771999999999,
          -12477.751,
          -12476.237,
          -12474.232,
          -12471.735,
          -12468.746000000001,
          -12465.267,
          -12461.298,
          -12456.839,
          -12451.891000000001,
          -12446.453000000001,
          -12440.526000000002,
          -12434.111,
          -12427.207,
          -12419.816,
          -12411.936000000002,
          -12403.57,
          -12394.716,
          -12385.375,
          -12375.548,
          -12365.233999999999,
          -12354.434,
          -12343.146999999999,
          -12331.375,
          -12319.116000000002,
          -12306.372,
          -12293.141000000001,
          -12279.425,
          -12265.223,
          -12250.535,
          -12235.362,
          -12219.703000000001,
          -12203.558,
          -12186.928,
          -12169.811000000002,
          -12152.208999999999,
          -12134.122,
          -12115.548,
          -12096.488000000001,
          -12076.942,
          -12056.909,
          -12036.39,
          -12015.383,
          -11993.89,
          -11971.91,
          -11949.442,
          -11926.486,
          -11903.042,
          -11879.11,
          -11854.69,
          -11829.781,
          -11804.382,
          -11778.493999999999,
          -11752.116000000002,
          -11725.247,
          -11697.888,
          -11670.038,
          -11641.696000000002,
          -11612.861,
          -11583.534,
          -11553.714,
          -11523.401000000002,
          -11492.593,
          -11461.291000000001,
          -11429.493,
          -11397.2,
          -11364.41,
          -11331.123,
          -11297.338,
          -11263.056,
          -11228.274,
          -11192.992,
          -11157.208999999999,
          -11120.926000000001,
          -11084.141000000001,
          -11046.851999999999,
          -11009.061000000002,
          -10970.765,
          -10931.964,
          -10892.657,
          -10852.843,
          -10812.521,
          -10771.691,
          -10730.351,
          -10688.501,
          -10646.14,
          -10603.266000000001,
          -10559.878,
          -10515.976,
          -10471.558,
          -10426.624,
          -10381.171999999999,
          -10335.201,
          -10288.711,
          -10241.699,
          -10194.165,
          -10146.107,
          -10097.525,
          -10048.418,
          -9998.783000000001,
          -9948.62,
          -9897.927,
          -9846.703000000001,
          -9794.946,
          -9742.655999999999,
          -9689.831,
          -9636.469000000001,
          -9582.569,
          -9528.13,
          -9473.15,
          -9417.627,
          -9361.561,
          -9304.95,
          -9247.792,
          -9190.084,
          -9131.827,
          -9073.017,
          -9013.655,
          -8953.737,
          -8893.261999999999,
          -8832.228000000001,
          -8770.635,
          -8708.479,
          -8645.759,
          -8582.473,
          -8518.62,
          -8454.198,
          -8389.204,
          -8323.638,
          -8257.496,
          -8190.776,
          -8123.478,
          -8055.599,
          -7987.1359999999995,
          -7918.089,
          -7848.454000000001,
          -7778.23,
          -7707.415,
          -7636.005999999999,
          -7564.0019999999995,
          -7491.401,
          -7418.1990000000005,
          -7344.396,
          -7269.986999999999,
          -7194.973000000001,
          -7119.35,
          -7043.116,
          -6966.268,
          -6888.806,
          -6810.726,
          -6732.025,
          -6652.703,
          -6572.757,
          -6492.184,
          -6410.981,
          -6329.147,
          -6246.68,
          -6163.576,
          -6079.835,
          -5995.453,
          -5910.429,
          -5824.7609999999995,
          -5738.445,
          -5651.481,
          -5563.865,
          -5475.597,
          -5386.674,
          -5297.093000000001,
          -5206.853,
          -5115.9529999999995,
          -5024.39,
          -4932.163,
          -4839.27,
          -4745.71,
          -4651.482,
          -4556.584,
          -4461.015,
          -4364.774,
          -4267.86,
          -4170.274,
          -4072.013,
          -3973.079,
          -3873.4709999999995,
          -3773.1890000000003,
          -3672.235,
          -3570.6090000000004,
          -3468.312,
          -3365.3459999999995,
          -3261.7129999999997,
          -3157.4159999999997,
          -3052.4570000000003,
          -2946.8390000000004,
          -2840.567,
          -2733.6459999999997,
          -2626.08,
          -2517.877,
          -2409.042,
          -2299.584,
          -2189.511,
          -2078.833,
          -1967.5620000000001,
          -1855.7079999999999,
          -1743.286,
          -1630.3110000000001,
          -1516.8,
          -1402.7720000000002,
          -1288.246,
          -1173.246,
          -1057.796,
          -941.925,
          -825.663,
          -709.045,
          -592.106,
          -474.88800000000003,
          -357.43699999999995,
          -239.80200000000002,
          -122.039,
          -4.206,
          113.62799999999999,
          231.391,
          349.00199999999995,
          466.37199999999996,
          583.403,
          699.988,
          816.0089999999999,
          931.334,
          1045.822,
          1159.3139999999999,
          1271.638,
          1382.605,
          1492.004,
          1599.611,
          1705.175,
          1808.4260000000002,
          1909.068,
          2006.7820000000002,
          2101.221,
          2192.013,
          2278.761,
          2361.038,
          2438.3979999999997,
          2510.3720000000003,
          2576.473,
          2636.203,
          2689.06,
          2734.546,
          2772.179,
          2801.502,
          2822.1,
          2833.6090000000004,
          2835.7340000000004,
          2828.256,
          2811.0429999999997,
          2784.06,
          2747.369,
          2701.132,
          2645.599,
          2581.11,
          2508.077,
          2426.973,
          2338.3160000000003,
          2242.656,
          2140.563,
          2032.609,
          1919.362,
          1801.3770000000002,
          1679.181,
          1553.2820000000002,
          1424.151,
          1292.231,
          1157.93,
          1021.62,
          883.6460000000001,
          744.317,
          603.915,
          462.694,
          320.882,
          178.68400000000003,
          36.282,
          -106.16,
          -248.49599999999998,
          -390.598,
          -532.351,
          -673.653,
          -814.414,
          -954.555,
          -1094.006,
          -1232.7069999999999,
          -1370.6029999999998,
          -1507.648,
          -1643.8,
          -1779.025,
          -1913.293,
          -2046.576,
          -2178.851,
          -2310.1020000000003,
          -2440.31,
          -2569.464,
          -2697.553,
          -2824.5679999999998,
          -2950.502,
          -3075.3509999999997,
          -3199.111,
          -3321.7790000000005,
          -3443.357,
          -3563.843,
          -3683.239,
          -3801.547,
          -3918.77,
          -4034.9109999999996,
          -4149.975,
          -4263.965,
          -4376.888,
          -4488.748,
          -4599.5509999999995,
          -4709.303,
          -4818.0109999999995,
          -4925.68,
          -5032.318,
          -5137.931,
          -5242.527,
          -5346.113,
          -5448.695,
          -5550.281,
          -5650.8769999999995,
          -5750.491999999999,
          -5849.132,
          -5946.806,
          -6043.519,
          -6139.28,
          -6234.096,
          -6327.973000000001,
          -6420.919,
          -6512.941,
          -6604.045999999999,
          -6694.241,
          -6783.533,
          -6871.93,
          -6959.437,
          -7046.061,
          -7131.809,
          -7216.687,
          -7300.703,
          -7383.861999999999,
          -7466.172,
          -7547.637,
          -7628.265,
          -7708.061,
          -7787.031999999999,
          -7865.183000000001,
          -7942.52,
          -8019.049,
          -8094.776,
          -8169.706,
          -8243.845,
          -8317.198,
          -8389.771,
          -8461.569,
          -8532.597,
          -8602.86,
          -8672.364
         ]
        },
        {
         "marker": {
          "color": "yellow",
          "colorscale": [
           [
            0,
            "#440154"
           ],
           [
            0.1111111111111111,
            "#482878"
           ],
           [
            0.2222222222222222,
            "#3e4989"
           ],
           [
            0.3333333333333333,
            "#31688e"
           ],
           [
            0.4444444444444444,
            "#26828e"
           ],
           [
            0.5555555555555556,
            "#1f9e89"
           ],
           [
            0.6666666666666666,
            "#35b779"
           ],
           [
            0.7777777777777778,
            "#6ece58"
           ],
           [
            0.8888888888888888,
            "#b5de2b"
           ],
           [
            1,
            "#fde725"
           ]
          ],
          "opacity": 0.8,
          "size": 30
         },
         "mode": "markers",
         "type": "scatter3d",
         "x": [
          0
         ],
         "y": [
          0
         ],
         "z": [
          0
         ]
        }
       ],
       "layout": {
        "margin": {
         "b": 0,
         "l": 0,
         "r": 0,
         "t": 0
        },
        "scene": {
         "aspectmode": "data"
        },
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"287814fa-7acb-4938-bd78-5af64e726595\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"287814fa-7acb-4938-bd78-5af64e726595\")) {                    Plotly.newPlot(                        \"287814fa-7acb-4938-bd78-5af64e726595\",                        [{\"marker\": {\"color\": \"blue\", \"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"opacity\": 0.8, \"size\": 1}, \"mode\": \"lines\", \"type\": \"scatter3d\", \"x\": [806.203, 799.885, 793.075, 785.819, 778.143, 770.069, 761.6189999999999, 752.812, 743.669, 734.206, 724.441, 714.3889999999999, 704.067, 693.487, 682.663, 671.6089999999999, 660.335, 648.8530000000001, 637.175, 625.309, 613.266, 601.054, 588.683, 576.16, 563.494, 550.691, 537.759, 524.705, 511.535, 498.254, 484.869, 471.38599999999997, 457.809, 444.14300000000003, 430.394, 416.565, 402.662, 388.68800000000005, 374.648, 360.545, 346.38300000000004, 332.165, 317.895, 303.577, 289.212, 274.805, 260.357, 245.873, 231.354, 216.803, 202.222, 187.614, 172.981, 158.326, 143.65, 128.955, 114.243, 99.516, 84.777, 70.02600000000001, 55.266000000000005, 40.498000000000005, 25.724, 10.944, -3.838, -18.623, -33.408, -48.192, -62.973, -77.752, -92.52600000000001, -107.294, -122.055, -136.808, -151.55200000000002, -166.285, -181.00799999999998, -195.718, -210.415, -225.09799999999998, -239.766, -254.418, -269.053, -283.671, -298.27, -312.85, -327.41, -341.949, -356.466, -370.962, -385.434, -399.88300000000004, -414.30800000000005, -428.708, -443.082, -457.43, -471.751, -486.045, -500.311, -514.548, -528.756, -542.935, -557.0830000000001, -571.201, -585.2869999999999, -599.341, -613.364, -627.3530000000001, -641.31, -655.232, -669.1210000000001, -682.975, -696.793, -710.577, -724.324, -738.035, -751.709, -765.346, -778.946, -792.507, -806.03, -819.515, -832.96, -846.365, -859.7310000000001, -873.056, -886.341, -899.584, -912.7860000000001, -925.947, -939.065, -952.1410000000001, -965.174, -978.163, -991.11, -1004.012, -1016.8710000000001, -1029.685, -1042.454, -1055.178, -1067.856, -1080.489, -1093.076, -1105.616, -1118.109, -1130.556, -1142.955, -1155.306, -1167.61, -1179.865, -1192.072, -1204.229, -1216.338, -1228.397, -1240.406, -1252.365, -1264.274, -1276.132, -1287.9389999999999, -1299.695, -1311.4, -1323.0520000000001, -1334.652, -1346.2, -1357.695, -1369.136, -1380.525, -1391.859, -1403.14, -1414.3670000000002, -1425.539, -1436.656, -1447.717, -1458.724, -1469.674, -1480.569, -1491.4070000000002, -1502.1879999999999, -1512.9129999999998, -1523.611, -1534.221, -1544.7720000000002, -1555.266, -1565.701, -1576.0770000000002, -1586.394, -1596.651, -1606.848, -1616.986, -1627.0629999999999, -1637.079, -1647.035, -1656.9279999999999, -1666.761, -1676.531, -1686.2379999999998, -1695.8829999999998, -1705.465, -1714.984, -1724.4389999999999, -1733.83, -1743.156, -1752.418, -1761.615, -1770.746, -1779.8110000000001, -1788.81, -1797.743, -1806.609, -1815.408, -1824.139, -1832.8020000000001, -1841.3970000000002, -1849.9229999999998, -1858.379, -1866.767, -1875.085, -1883.332, -1891.509, -1899.614, -1907.649, -1915.611, -1923.501, -1931.319, -1939.0629999999999, -1946.734, -1954.3310000000001, -1961.854, -1969.3020000000001, -1976.674, -1983.971, -1991.192, -1998.3370000000002, -2005.404, -2012.394, -2019.306, -2026.14, -2032.895, -2039.57, -2046.1660000000002, -2052.681, -2059.116, -2065.469, -2071.741, -2077.93, -2084.036, -2090.0589999999997, -2095.998, -2101.853, -2107.6220000000003, -2113.306, -2118.904, -2124.416, -2129.84, -2135.177, -2140.425, -2145.584, -2150.654, -2155.633, -2160.522, -2165.319, -2170.025, -2174.637, -2179.157, -2183.5820000000003, -2187.913, -2192.149, -2196.288, -2200.331, -2204.277, -2208.125, -2211.874, -2215.5229999999997, -2219.072, -2222.521, -2225.867, -2229.112, -2232.2529999999997, -2235.2889999999998, -2238.222, -2241.048, -2243.768, -2246.38, -2248.885, -2251.28, -2253.5660000000003, -2255.74, -2257.803, -2259.754, -2261.591, -2263.313, -2264.92, -2266.411, -2267.784, -2269.0389999999998, -2270.174, -2271.189, -2272.083, -2272.854, -2273.501, -2274.024, -2274.4210000000003, -2274.69, -2274.8320000000003, -2274.844, -2274.726, -2274.476, -2274.093, -2273.575, -2272.922, -2272.133, -2271.205, -2270.137, -2268.929, -2267.578, -2266.084, -2264.444, -2262.658, -2260.724, -2258.64, -2256.404, -2254.016, -2251.473, -2248.774, -2245.917, -2242.901, -2239.723, -2236.383, -2232.877, -2229.2039999999997, -2225.363, -2221.351, -2217.167, -2212.808, -2208.272, -2203.5570000000002, -2198.6620000000003, -2193.584, -2188.32, -2182.868, -2177.2270000000003, -2171.393, -2165.365, -2159.139, -2152.7129999999997, -2146.085, -2139.252, -2132.21, -2124.959, -2117.493, -2109.811, -2101.91, -2093.786, -2085.437, -2076.859, -2068.048, -2059.002, -2049.718, -2040.19, -2030.4160000000002, -2020.3929999999998, -2010.116, -1999.5810000000001, -1988.7839999999999, -1977.7220000000002, -1966.389, -1954.7820000000002, -1942.896, -1930.727, -1918.269, -1905.5179999999998, -1892.469, -1879.118, -1865.4579999999999, -1851.484, -1837.19, -1822.5720000000001, -1807.622, -1792.336, -1776.7060000000001, -1760.726, -1744.39, -1727.691, -1710.622, -1693.175, -1675.3429999999998, -1657.119, -1638.494, -1619.461, -1600.011, -1580.135, -1559.825, -1539.0710000000001, -1517.864, -1496.194, -1474.0520000000001, -1451.4270000000001, -1428.308, -1404.684, -1380.545, -1355.878, -1330.672, -1304.915, -1278.595, -1251.698, -1224.212, -1196.124, -1167.4189999999999, -1138.085, -1108.108, -1077.473, -1046.167, -1014.176, -981.4860000000001, -948.0830000000001, -913.955, -879.087, -843.4689999999999, -807.0880000000001, -769.936, -732.003, -693.2819999999999, -653.769, -613.4630000000001, -572.365, -530.48, -487.81800000000004, -444.39599999999996, -400.235, -355.36400000000003, -309.82099999999997, -263.653, -216.919, -169.68599999999998, -122.039, -74.072, -25.896, 22.365, 70.57300000000001, 118.57600000000001, 166.213, 213.31099999999998, 259.693, 305.178, 349.589, 392.75199999999995, 434.506, 474.704, 513.2180000000001, 549.939, 584.7819999999999, 617.684, 648.604, 677.5219999999999, 704.442, 729.38, 752.37, 773.456, 792.696, 810.15, 825.887, 839.9789999999999, 852.497, 863.518, 873.115, 881.36, 888.324, 894.074, 898.677, 902.195, 904.689, 906.215, 906.827, 906.577, 905.5110000000001, 903.677, 901.1160000000001, 897.868, 893.972, 889.462, 884.3739999999999, 878.737, 872.582, 865.937, 858.827, 851.2760000000001, 843.309, 834.947, 826.211, 817.1189999999999, 807.69, 797.942, 787.89, 777.55, 766.936, 756.062, 744.941, 733.585, 722.007, 710.216, 698.2230000000001, 686.038, 673.671, 661.1310000000001, 648.4259999999999, 635.563, 622.552, 609.398, 596.11, 582.694, 569.155, 555.501, 541.736, 527.867, 513.899, 499.836, 485.68300000000005, 471.44599999999997, 457.12800000000004, 442.73400000000004, 428.267, 413.73199999999997, 399.13300000000004, 384.472, 369.754, 354.98199999999997, 340.158, 325.286, 310.369, 295.409, 280.41, 265.374, 250.303, 235.2, 220.06799999999998, 204.907, 189.722, 174.513, 159.283, 144.033, 128.766, 113.484, 98.18799999999999, 82.87899999999999, 67.56, 52.233000000000004, 36.898, 21.557, 6.212000000000001, -9.136000000000001, -24.485, -39.835, -55.183, -70.53, -85.87299999999999, -101.211, -116.54299999999999, -131.868, -147.185, -162.493, -177.791, -193.078, -208.35299999999998, -223.614, -238.862, -254.095, -269.312, -284.512, -299.695, -314.86, -330.006, -345.131, -360.23699999999997, -375.32099999999997, -390.38300000000004, -405.42199999999997, -420.43699999999995, -435.42900000000003, -450.39599999999996, -465.337, -480.25300000000004, -495.14099999999996, -510.00300000000004, -524.836, -539.641, -554.4169999999999, -569.163, -583.879, -598.564, -613.2180000000001, -627.841, -642.431, -656.988, -671.512, -686.002, -700.457, -714.878, -729.2639999999999, -743.6139999999999, -757.928, -772.205, -786.446, -800.648, -814.813, -828.94, -843.0269999999999, -857.076, -871.085, -885.054, -898.982, -912.87, -926.716, -940.5210000000001, -954.284, -968.005, -981.682, -995.317, -1008.908, -1022.456, -1035.9589999999998, -1049.417, -1062.8310000000001, -1076.1989999999998, -1089.522, -1102.799, -1116.029, -1129.213, -1142.349, -1155.438, -1168.479, -1181.473, -1194.417, -1207.313, -1220.16, -1232.958, -1245.705, -1258.403, -1271.05, -1283.646, -1296.191, -1308.685, -1321.1270000000002, -1333.517, -1345.854, -1358.139, -1370.37, -1382.5479999999998, -1394.672, -1406.7420000000002, -1418.7579999999998, -1430.719, -1442.625, -1454.475, -1466.27, -1478.009, -1489.691, -1501.316, -1512.884, -1524.395, -1535.848, -1547.243, -1558.58, -1569.858, -1581.076, -1592.235, -1603.335, -1614.374, -1625.3529999999998, -1636.271, -1647.1270000000002, -1657.9229999999998, -1668.656, -1679.3270000000002, -1689.935, -1700.481, -1710.963, -1721.381, -1731.736, -1742.026, -1752.251, -1762.411, -1772.506, -1782.535, -1792.497, -1802.3929999999998, -1812.2220000000002, -1821.983, -1831.6770000000001, -1841.3020000000001, -1850.859, -1860.3470000000002, -1869.765, -1879.114, -1888.392, -1897.6, -1906.737, -1915.8029999999999, -1924.796, -1933.7179999999998, -1942.566, -1951.342, -1960.0439999999999, -1968.672, -1977.225, -1985.704, -1994.1070000000002, -2002.435, -2010.6860000000001, -2018.861, -2026.9579999999999, -2034.9779999999998, -2042.92, -2050.783, -2058.567, -2066.271, -2073.896, -2081.44, -2088.902, -2096.283, -2103.5820000000003, -2110.799, -2117.9320000000002, -2124.981, -2131.947, -2138.827, -2145.6220000000003, -2152.331, -2158.9539999999997, -2165.49, -2171.938, -2178.298, -2184.569, -2190.751, -2196.842, -2202.844, -2208.7529999999997, -2214.571, -2220.297, -2225.929, -2231.468, -2236.9120000000003, -2242.261, -2247.515, -2252.6710000000003, -2257.731, -2262.6929999999998, -2267.556, -2272.32, -2276.9829999999997, -2281.5460000000003, -2286.008, -2290.367, -2294.623, -2298.775, -2302.822, -2306.764, -2310.6, -2314.3289999999997, -2317.949, -2321.4610000000002, -2324.864, -2328.156, -2331.3360000000002, -2334.404, -2337.359, -2340.2, -2342.925, -2345.535, -2348.027, -2350.402, -2352.657, -2354.7929999999997, -2356.8070000000002, -2358.699, -2360.468, -2362.113, -2363.633, -2365.026, -2366.291, -2367.428, -2368.4339999999997, -2369.31, -2370.053, -2370.6620000000003, -2371.137, -2371.476, -2371.677, -2371.74, -2371.6620000000003, -2371.4429999999998, -2371.081, -2370.575, -2369.924, -2369.125, -2368.177, -2367.08, -2365.831, -2364.428, -2362.871, -2361.157, -2359.285, -2357.2529999999997, -2355.06, -2352.703, -2350.181, -2347.492, -2344.635, -2341.606, -2338.405, -2335.03, -2331.4770000000003, -2327.746, -2323.834, -2319.739, -2315.459, -2310.991, -2306.333, -2301.484, -2296.44, -2291.2, -2285.76, -2280.118, -2274.272, -2268.218, -2261.955, -2255.479, -2248.788, -2241.8779999999997, -2234.746, -2227.391, -2219.8070000000002, -2211.993, -2203.945, -2195.659, -2187.133, -2178.362, -2169.344, -2160.073, -2150.548, -2140.763, -2130.714, -2120.3979999999997, -2109.811, -2098.947, -2087.804, -2076.375, -2064.657, -2052.645, -2040.3329999999999, -2027.7160000000001, -2014.7910000000002, -2001.55, -1987.99, -1974.1029999999998, -1959.884, -1945.328, -1930.4279999999999, -1915.1779999999999, -1899.5710000000001, -1883.6, -1867.259, -1850.54, -1833.4370000000001, -1815.941, -1798.045, -1779.741, -1761.021, -1741.875, -1722.296, -1702.274, -1681.799, -1660.8629999999998, -1639.4560000000001, -1617.566, -1595.183, -1572.2979999999998, -1548.898, -1524.9720000000002, -1500.5079999999998, -1475.494, -1449.918, -1423.766, -1397.026, -1369.683, -1341.724, -1313.135, -1283.9, -1254.006, -1223.4360000000001, -1192.177, -1160.212, -1127.525, -1094.1019999999999, -1059.9260000000002, -1024.983, -989.2560000000001, -952.732, -915.395, -877.2339999999999, -838.235, -798.3889999999999, -757.686, -716.1210000000001, -673.688, -630.388, -586.225, -541.206, -495.345, -448.664, -401.19, -352.959, -304.02, -254.43, -204.26, -153.594, -102.529, -51.18, 0.324, 51.84, 103.21, 154.263, 204.817, 254.685, 303.67400000000004, 351.593, 398.259, 443.49699999999996, 487.14599999999996, 529.065, 569.135, 607.259, 643.366, 677.405, 709.3530000000001, 739.203, 766.971, 792.686, 816.393, 838.145, 858.007, 876.046, 892.336, 906.952, 919.971, 931.4689999999999, 941.5210000000001, 950.202, 957.5830000000001, 963.7310000000001, 968.7139999999999, 972.5939999999999, 975.432, 977.285, 978.205, 978.245, 977.451, 975.8710000000001, 973.545, 970.515, 966.818, 962.4889999999999, 957.564, 952.072, 946.044, 939.508, 932.4889999999999, 925.013, 917.1030000000001, 908.7810000000001, 900.068, 890.9830000000001, 881.545, 871.77, 861.677, 851.28, 840.5930000000001, 829.632, 818.409, 806.937, 795.227, 783.291, 771.14, 758.784, 746.232, 733.493, 720.577, 707.492, 694.2460000000001, 680.845, 667.299, 653.612, 639.793, 625.846, 611.779, 597.597, 583.305, 568.908, 554.4119999999999, 539.822, 525.1419999999999, 510.376, 495.529, 480.605, 465.60699999999997, 450.54, 435.407, 420.212, 404.957, 389.647, 374.283, 358.87, 343.41, 327.906, 312.36, 296.775, 281.154, 265.499, 249.812, 234.095, 218.351, 202.581, 186.78900000000002, 170.975, 155.141, 139.29, 123.42299999999999, 107.542, 91.649, 75.745, 59.831, 43.91, 27.982, 12.049000000000001, -3.887, -19.825, -35.764, -51.702, -67.639, -83.573, -99.50299999999999, -115.427, -131.345, -147.256, -163.159, -179.05200000000002, -194.93400000000003, -210.805, -226.66299999999998, -242.50900000000001, -258.34, -274.155, -289.955, -305.738, -321.503, -337.25, -352.977, -368.685, -384.371, -400.036, -415.67900000000003, -431.29900000000004, -446.895, -462.466, -478.01300000000003, -493.534, -509.029, -524.496, -539.936, -555.3480000000001, -570.731, -586.085, -601.408, -616.701, -631.9630000000001, -647.194, -662.3919999999999, -677.557, -692.689, -707.788, -722.852, -737.8810000000001, -752.875, -767.8330000000001, -782.755, -797.64, -812.4889999999999, -827.299, -842.071, -856.805, -871.4989999999999, -886.155, -900.77, -915.345, -929.8789999999999, -944.372, -958.823, -973.232, -987.5989999999999, -1001.923, -1016.204, -1030.44, -1044.633, -1058.782, -1072.885, -1086.943, -1100.9560000000001, -1114.922, -1128.8419999999999, -1142.715, -1156.5410000000002, -1170.32, -1184.05, -1197.732, -1211.366, -1224.95, -1238.485, -1251.97, -1265.405, -1278.789, -1292.123, -1305.405, -1318.635, -1331.8129999999999, -1344.9389999999999, -1358.0120000000002, -1371.0320000000002, -1383.999, -1396.912, -1409.77, -1422.5739999999998, -1435.3229999999999, -1448.017, -1460.655, -1473.237, -1485.7620000000002, -1498.231, -1510.6429999999998, -1522.997, -1535.2939999999999, -1547.5320000000002, -1559.7120000000002, -1571.832, -1583.894, -1595.896, -1607.8370000000002, -1619.719, -1631.539, -1643.2979999999998, -1654.996, -1666.632, -1678.205, -1689.7160000000001, -1701.164, -1712.5479999999998, -1723.868, -1735.125, -1746.316, -1757.443, -1768.504, -1779.499, -1790.4279999999999, -1801.2910000000002, -1812.086, -1822.8139999999999, -1833.475, -1844.067, -1854.59, -1865.0439999999999, -1875.4289999999999, -1885.744, -1895.9879999999998, -1906.162, -1916.265, -1926.295, -1936.254, -1946.141, -1955.954, -1965.694, -1975.36, -1984.9520000000002, -1994.469, -2003.91, -2013.276, -2022.566, -2031.779, -2040.915, -2049.974, -2058.9539999999997, -2067.856, -2076.678, -2085.4210000000003, -2094.084, -2102.666, -2111.167, -2119.5860000000002, -2127.923, -2136.178, -2144.349, -2152.436, -2160.439, -2168.357, -2176.189, -2183.935, -2191.595, -2199.1679999999997, -2206.652, -2214.048, -2221.356, -2228.573, -2235.7, -2242.737, -2249.6820000000002, -2256.535, -2263.295, -2269.9610000000002, -2276.534, -2283.012, -2289.394, -2295.681, -2301.87, -2307.962, -2313.956, -2319.851, -2325.646, -2331.341, -2336.935, -2342.426, -2347.815, -2353.101, -2358.283, -2363.359, -2368.33, -2373.194, -2377.95, -2382.598, -2387.137, -2391.5660000000003, -2395.884, -2400.09, -2404.183, -2408.163, -2412.028, -2415.778, -2419.4120000000003, -2422.928, -2426.325, -2429.603, -2432.761, -2435.798, -2438.712, -2441.502, -2444.1679999999997, -2446.708, -2449.121, -2451.406, -2453.562, -2455.5879999999997, -2457.482, -2459.244, -2460.8720000000003, -2462.365, -2463.721, -2464.94, -2466.02, -2466.959, -2467.757, -2468.4120000000003, -2468.923, -2469.2870000000003, -2469.505, -2469.573, -2469.492, -2469.258, -2468.8720000000003, -2468.33, -2467.632, -2466.776, -2465.76, -2464.5820000000003, -2463.242, -2461.736, -2460.063, -2458.222, -2456.2110000000002, -2454.027, -2451.6679999999997, -2449.134, -2446.4210000000003, -2443.527, -2440.451, -2437.1910000000003, -2433.744, -2430.107, -2426.28, -2422.258, -2418.041, -2413.625, -2409.008, -2404.188, -2399.1620000000003, -2393.927, -2388.481, -2382.82, -2376.9429999999998, -2370.846, -2364.526, -2357.98, -2351.205, -2344.199, -2336.956, -2329.476, -2321.7529999999997, -2313.784, -2305.567, -2297.097, -2288.37, -2279.383, -2270.132, -2260.612, -2250.82, -2240.751, -2230.402, -2219.766, -2208.841, -2197.621, -2186.101, -2174.277, -2162.143, -2149.694, -2136.924, -2123.8289999999997, -2110.402, -2096.638, -2082.53, -2068.072, -2053.259, -2038.0829999999999, -2022.537, -2006.616, -1990.31, -1973.614, -1956.519, -1939.0179999999998, -1921.102, -1902.763, -1883.993, -1864.783, -1845.1229999999998, -1825.004, -1804.4170000000001, -1783.351, -1761.796, -1739.741, -1717.175, -1694.088, -1670.467, -1646.3, -1621.575, -1596.279, -1570.399, -1543.922, -1516.832, -1489.116, -1460.76, -1431.747, -1402.0629999999999, -1371.691, -1340.616, -1308.8210000000001, -1276.289, -1243.003, -1208.9460000000001, -1174.101, -1138.4489999999998, -1101.975, -1064.661, -1026.49, -987.446, -947.515, -906.682, -864.935, -822.262, -778.655, -734.1080000000001, -688.618, -642.188, -594.8240000000001, -546.536, -497.347, -447.281, -396.376, -344.67800000000005, -292.245, -239.148, -185.47400000000002, -131.322, -76.81, -22.070999999999998, 32.746, 87.47399999999999, 141.937, 195.942, 249.291, 301.782, 353.21, 403.38, 452.101, 499.204, 544.534, 587.9590000000001, 629.372, 668.69, 705.8580000000001, 740.8430000000001, 773.635, 804.243, 832.695, 859.033, 883.311, 905.591, 925.944, 944.445, 961.17, 976.199, 989.61, 1001.4810000000001, 1011.8910000000001, 1020.9119999999999, 1028.618, 1035.077, 1040.355, 1044.514, 1047.617, 1049.718, 1050.872, 1051.13, 1050.539, 1049.145, 1046.99, 1044.114, 1040.665, 1036.349, 1031.529, 1026.127, 1020.173, 1013.694, 1006.717, 999.2669999999999, 991.367, 983.04, 974.306, 965.185, 955.696, 945.8560000000001, 935.682, 925.19, 914.3960000000001, 903.312, 891.953, 880.331, 868.4580000000001, 856.347, 844.007, 831.449, 818.684, 805.721, 792.568, 779.2339999999999, 765.727, 752.056, 738.227, 724.248, 710.125, 695.865, 681.475, 666.959, 652.3240000000001, 637.575, 622.717, 607.756, 592.696, 577.5419999999999, 562.298, 546.9680000000001, 531.557, 516.068, 500.506, 484.87300000000005, 469.17400000000004, 453.411, 437.589, 421.709, 405.776, 389.792, 373.759, 357.681, 341.56, 325.399, 309.2, 292.966, 276.698, 260.399, 244.071, 227.717, 211.33700000000002, 194.935, 178.512, 162.069, 145.609, 129.134, 112.64399999999999, 96.14200000000001, 79.63, 63.108000000000004, 46.578, 30.041, 13.5, -3.045, -19.592, -36.14, -52.688, -69.234, -85.77799999999999, -102.318, -118.853, -135.382, -151.903, -168.417, -184.921, -201.415, -217.898, -234.368, -250.826, -267.269, -283.698, -300.111, -316.507, -332.88599999999997, -349.246, -365.587, -381.909, -398.209, -414.48900000000003, -430.746, -446.98, -463.191, -479.37699999999995, -495.538, -511.67400000000004, -527.784, -543.866, -559.9209999999999, -575.947, -591.945, -607.913, -623.851, -639.759, -655.635, -671.4789999999999, -687.2919999999999, -703.071, -718.816, -734.528, -750.205, -765.847, -781.453, -797.023, -812.557, -828.053, -843.512, -858.932, -874.315, -889.6569999999999, -904.961, -920.2239999999999, -935.447, -950.6289999999999, -965.7689999999999, -980.868, -995.924, -1010.938, -1025.9080000000001, -1040.835, -1055.7169999999999, -1070.555, -1085.348, -1100.096, -1114.798, -1129.454, -1144.063, -1158.625, -1173.139, -1187.606, -1202.024, -1216.394, -1230.715, -1244.986, -1259.2069999999999, -1273.378, -1287.498, -1301.567, -1315.585, -1329.55, -1343.464, -1357.3239999999998, -1371.132, -1384.886, -1398.586, -1412.2320000000002, -1425.8229999999999, -1439.359, -1452.839, -1466.264, -1479.632, -1492.944, -1506.1989999999998, -1519.396, -1532.536, -1545.6170000000002, -1558.639, -1571.6029999999998, -1584.507, -1597.351, -1610.135, -1622.859, -1635.521, -1648.122, -1660.661, -1673.138, -1685.5520000000001, -1697.9029999999998, -1710.191, -1722.414, -1734.5739999999998, -1746.6689999999999, -1758.6979999999999, -1770.662, -1782.56, -1794.392, -1806.1570000000002, -1817.855, -1829.485, -1841.047, -1852.54, -1863.964, -1875.319, -1886.604, -1897.819, -1908.963, -1920.035, -1931.036, -1941.965, -1952.8210000000001, -1963.605, -1974.3139999999999, -1984.95, -1995.511, -2005.997, -2016.408, -2026.743, -2037.001, -2047.183, -2057.2870000000003, -2067.313, -2077.261, -2087.13, -2096.919, -2106.6279999999997, -2116.257, -2125.805, -2135.271, -2144.655, -2153.9570000000003, -2163.175, -2172.31, -2181.36, -2190.325, -2199.205, -2207.999, -2216.706, -2225.326, -2233.8579999999997, -2242.301, -2250.656, -2258.9210000000003, -2267.096, -2275.179, -2283.172, -2291.072, -2298.879, -2306.593, -2314.212, -2321.737, -2329.166, -2336.499, -2343.735, -2350.874, -2357.9139999999998, -2364.855, -2371.696, -2378.437, -2385.077, -2391.614, -2398.049, -2404.38, -2410.607, -2416.728, -2422.744, -2428.653, -2434.4539999999997, -2440.146, -2445.73, -2451.203, -2456.565, -2461.815, -2466.952, -2471.976, -2476.884, -2481.677, -2486.354, -2490.913, -2495.353, -2499.674, -2503.874, -2507.953, -2511.909, -2515.741, -2519.449, -2523.031, -2526.486, -2529.813, -2533.01, -2536.078, -2539.014, -2541.817, -2544.486, -2547.021, -2549.419, -2551.679, -2553.8, -2555.781, -2557.621, -2559.317, -2560.869, -2562.276, -2563.535, -2564.646, -2565.607, -2566.416, -2567.072, -2567.573, -2567.9179999999997, -2568.106, -2568.134, -2568.0, -2567.7039999999997, -2567.244, -2566.617, -2565.822, -2564.857, -2563.72, -2562.41, -2560.924, -2559.26, -2557.417, -2555.3920000000003, -2553.183, -2550.788, -2548.206, -2545.433, -2542.467, -2539.3070000000002, -2535.95, -2532.393, -2528.633, -2524.669, -2520.498, -2516.117, -2511.524, -2506.716, -2501.69, -2496.4429999999998, -2490.972, -2485.274, -2479.347, -2473.187, -2466.79, -2460.155, -2453.276, -2446.152, -2438.777, -2431.15, -2423.265, -2415.12, -2406.71, -2398.032, -2389.08, -2379.853, -2370.344, -2360.549, -2350.465, -2340.0860000000002, -2329.407, -2318.425, -2307.133, -2295.527, -2283.601, -2271.35, -2258.769, -2245.851, -2232.591, -2218.9829999999997, -2205.02, -2190.697, -2176.006, -2160.9410000000003, -2145.494, -2129.659, -2113.428, -2096.794, -2079.748, -2062.283, -2044.389, -2026.059, -2007.2839999999999, -1988.0539999999999, -1968.36, -1948.193, -1927.5410000000002, -1906.395, -1884.744, -1862.576, -1839.882, -1816.648, -1792.8629999999998, -1768.513, -1743.5870000000002, -1718.0710000000001, -1691.95, -1665.2120000000002, -1637.84, -1609.8210000000001, -1581.138, -1551.776, -1521.7179999999998, -1490.9470000000001, -1459.4470000000001, -1427.2, -1394.1879999999999, -1360.392, -1325.795, -1290.376, -1254.118, -1217.001, -1179.006, -1140.114, -1100.307, -1059.567, -1017.877, -975.22, -931.582, -886.949, -841.312, -794.6619999999999, -746.9939999999999, -698.307, -648.609, -597.908, -546.222, -493.577, -440.00800000000004, -385.56199999999995, -330.29699999999997, -274.285, -217.613, -160.384, -102.719, -44.755, 13.353, 71.432, 129.297, 186.74599999999998, 243.571, 299.559, 354.49300000000005, 408.164, 460.37, 510.92800000000005, 559.668, 606.451, 651.156, 693.693, 733.9960000000001, 772.0239999999999, 807.765, 841.221, 872.418, 901.3960000000001, 928.2080000000001, 952.9169999999999, 975.5930000000001, 996.314, 1015.1569999999999, 1032.205, 1047.539, 1061.24, 1073.387, 1084.059, 1093.3310000000001, 1101.274, 1107.9589999999998, 1113.451, 1117.812, 1121.103, 1123.381, 1124.698, 1125.106, 1124.652, 1123.38, 1121.333, 1118.552, 1115.0739999999998, 1110.933, 1106.165, 1100.8, 1094.869, 1088.3980000000001, 1081.415, 1073.945, 1066.011, 1057.635, 1048.838, 1039.641, 1030.062, 1020.118, 1009.828, 999.206, 988.268, 977.028, 965.5, 953.697, 941.632, 929.315, 916.758, 903.972, 890.966, 877.7510000000001, 864.336, 850.7289999999999, 836.939, 822.9730000000001, 808.84, 794.547, 780.1, 765.5060000000001, 750.7710000000001, 735.903, 720.9060000000001, 705.7860000000001, 690.549, 675.2, 659.7439999999999, 644.185, 628.528, 612.778, 596.938, 581.014, 565.008, 548.925, 532.768, 516.54, 500.246, 483.88800000000003, 467.47, 450.994, 434.464, 417.88199999999995, 401.251, 384.574, 367.853, 351.091, 334.29, 317.453, 300.582, 283.678, 266.744, 249.783, 232.795, 215.78400000000002, 198.75099999999998, 181.697, 164.62400000000002, 147.535, 130.431, 113.31299999999999, 96.18299999999999, 79.043, 61.893, 44.736999999999995, 27.574, 10.405999999999999, -6.765, -23.938000000000002, -41.111999999999995, -58.285, -75.457, -92.626, -109.791, -126.95100000000001, -144.105, -161.252, -178.39, -195.519, -212.638, -229.745, -246.84, -263.922, -280.98900000000003, -298.04200000000003, -315.079, -332.099, -349.101, -366.085, -383.05, -399.995, -416.91900000000004, -433.82099999999997, -450.70099999999996, -467.55800000000005, -484.39099999999996, -501.199, -517.9830000000001, -534.74, -551.471, -568.174, -584.85, -601.497, -618.115, -634.703, -651.26, -667.7869999999999, -684.2810000000001, -700.7439999999999, -717.173, -733.57, -749.932, -766.26, -782.552, -798.809, -815.03, -831.2130000000001, -847.36, -863.4689999999999, -879.539, -895.571, -911.563, -927.5160000000001, -943.428, -959.299, -975.1289999999999, -990.9169999999999, -1006.663, -1022.3660000000001, -1038.026, -1053.642, -1069.214, -1084.741, -1100.223, -1115.6589999999999, -1131.05, -1146.394, -1161.691, -1176.94, -1192.142, -1207.295, -1222.4, -1237.4560000000001, -1252.462, -1267.417, -1282.323, -1297.177, -1311.981, -1326.7320000000002, -1341.431, -1356.078, -1370.671, -1385.211, -1399.6970000000001, -1414.129, -1428.506, -1442.828, -1457.094, -1471.3039999999999, -1485.4579999999999, -1499.5539999999999, -1513.594, -1527.575, -1541.499, -1555.364, -1569.17, -1582.9160000000002, -1596.602, -1610.229, -1623.7939999999999, -1637.2979999999998, -1650.741, -1664.121, -1677.4389999999999, -1690.694, -1703.886, -1717.014, -1730.078, -1743.0770000000002, -1756.011, -1768.879, -1781.681, -1794.4170000000001, -1807.086, -1819.6879999999999, -1832.2220000000002, -1844.6870000000001, -1857.0839999999998, -1869.412, -1881.67, -1893.8570000000002, -1905.974, -1918.021, -1929.995, -1941.898, -1953.7279999999998, -1965.485, -1977.1689999999999, -1988.7779999999998, -2000.3129999999999, -2011.774, -2023.158, -2034.467, -2045.6989999999998, -2056.854, -2067.9320000000002, -2078.9320000000002, -2089.853, -2100.695, -2111.4570000000003, -2122.14, -2132.741, -2143.262, -2153.7, -2164.056, -2174.3289999999997, -2184.519, -2194.624, -2204.645, -2214.581, -2224.431, -2234.194, -2243.871, -2253.46, -2262.96, -2272.3720000000003, -2281.694, -2290.926, -2300.0679999999998, -2309.118, -2318.076, -2326.9410000000003, -2335.7129999999997, -2344.391, -2352.974, -2361.4610000000002, -2369.853, -2378.1479999999997, -2386.345, -2394.444, -2402.444, -2410.344, -2418.144, -2425.843, -2433.439, -2440.933, -2448.324, -2455.61, -2462.791, -2469.866, -2476.834, -2483.695, -2490.447, -2497.09, -2503.623, -2510.045, -2516.355, -2522.552, -2528.635, -2534.604, -2540.4570000000003, -2546.194, -2551.813, -2557.314, -2562.695, -2567.956, -2573.095, -2578.112, -2583.005, -2587.774, -2592.416, -2596.933, -2601.321, -2605.58, -2609.709, -2613.7070000000003, -2617.572, -2621.303, -2624.9, -2628.36, -2631.683, -2634.868, -2637.9120000000003, -2640.815, -2643.5759999999996, -2646.192, -2648.664, -2650.988, -2653.164, -2655.191, -2657.067, -2658.79, -2660.3579999999997, -2661.7709999999997, -2663.027, -2664.1240000000003, -2665.0609999999997, -2665.835, -2666.446, -2666.89, -2667.1679999999997, -2667.276, -2667.2140000000004, -2666.9790000000003, -2666.5690000000004, -2665.982, -2665.217, -2664.2709999999997, -2663.143, -2661.83, -2660.33, -2658.6420000000003, -2656.762, -2654.688, -2652.4190000000003, -2649.953, -2647.285, -2644.415, -2641.3390000000004, -2638.0559999999996, -2634.562, -2630.855, -2626.9320000000002, -2622.7909999999997, -2618.428, -2613.841, -2609.027, -2603.982, -2598.705, -2593.1910000000003, -2587.437, -2581.44, -2575.197, -2568.7039999999997, -2561.958, -2554.955, -2547.6910000000003, -2540.1620000000003, -2532.366, -2524.297, -2515.951, -2507.325, -2498.415, -2489.214, -2479.72, -2469.928, -2459.8320000000003, -2449.428, -2438.712, -2427.676, -2416.3179999999998, -2404.63, -2392.6079999999997, -2380.246, -2367.5370000000003, -2354.476, -2341.0570000000002, -2327.2729999999997, -2313.118, -2298.583, -2283.6639999999998, -2268.3520000000003, -2252.641, -2236.522, -2219.988, -2203.03, -2185.641, -2167.811, -2149.532, -2130.794, -2111.589, -2091.905, -2071.734, -2051.065, -2029.888, -2008.19, -1985.961, -1963.1889999999999, -1939.861, -1915.9660000000001, -1891.49, -1866.42, -1840.741, -1814.441, -1787.503, -1759.914, -1731.6570000000002, -1702.7160000000001, -1673.0739999999998, -1642.715, -1611.62, -1579.773, -1547.154, -1513.744, -1479.524, -1444.473, -1408.5729999999999, -1371.8029999999999, -1334.142, -1295.569, -1256.0639999999999, -1215.605, -1174.173, -1131.747, -1088.309, -1043.839, -998.321, -951.74, -904.084, -855.342, -805.508, -754.579, -702.558, -649.455, -595.285, -540.073, -483.852, -426.671, -368.586, -309.671, -250.013, -189.71900000000002, -128.912, -67.733, -6.343999999999999, 55.077, 116.336, 177.22299999999998, 237.519, 296.999, 355.435, 412.60400000000004, 468.293, 522.305, 574.4590000000001, 624.602, 672.6030000000001, 718.3610000000001, 761.804, 802.8839999999999, 841.58, 877.8919999999999, 911.842, 943.4689999999999, 972.824, 999.971, 1024.979, 1047.9289999999999, 1068.901, 1087.9769999999999, 1105.244, 1120.782, 1134.678, 1147.01, 1157.858, 1167.296, 1175.397, 1182.229, 1187.859, 1192.349, 1195.759, 1198.145, 1199.56, 1200.053, 1199.673, 1198.465, 1196.469, 1193.726, 1190.274, 1186.1480000000001, 1181.381, 1176.003, 1170.047, 1163.539, 1156.505, 1148.971, 1140.96, 1132.495, 1123.597, 1114.285, 1104.579, 1094.496, 1084.0539999999999, 1073.269, 1062.155, 1050.728, 1039.001, 1026.988, 1014.7, 1002.15, 989.3489999999999, 976.309, 963.038, 949.547, 935.846, 921.942, 907.846, 893.564, 879.105, 864.477, 849.685, 834.738, 819.6410000000001, 804.4019999999999, 789.025, 773.518, 757.885, 742.1310000000001, 726.263, 710.284, 694.199, 678.0139999999999, 661.732, 645.3580000000001, 628.896, 612.349, 595.722, 579.018, 562.24, 545.3919999999999, 528.4780000000001, 511.5, 494.462, 477.366, 460.215, 443.01300000000003, 425.76099999999997, 408.462, 391.12, 373.735, 356.31199999999995, 338.851, 321.356, 303.827, 286.269, 268.681, 251.067, 233.428, 215.767, 198.084, 180.382, 162.662, 144.92700000000002, 127.177, 109.414, 91.64, 73.857, 56.065, 38.266, 20.462, 2.653, -15.158, -32.971, -50.784, -68.596, -86.406, -104.213, -122.016, -139.813, -157.60299999999998, -175.386, -193.16, -210.924, -228.678, -246.419, -264.149, -281.86400000000003, -299.565, -317.251, -334.92, -352.57199999999995, -370.20599999999996, -387.82199999999995, -405.417, -422.99199999999996, -440.546, -458.07800000000003, -475.587, -493.07199999999995, -510.533, -527.969, -545.379, -562.763, -580.12, -597.4490000000001, -614.749, -632.02, -649.262, -666.472, -683.6519999999999, -700.8, -717.916, -734.998, -752.048, -769.062, -786.043, -802.987, -819.8960000000001, -836.7689999999999, -853.6039999999999, -870.4019999999999, -887.1610000000001, -903.882, -920.564, -937.206, -953.807, -970.368, -986.887, -1003.3639999999999, -1019.799, -1036.191, -1052.54, -1068.844, -1085.104, -1101.32, -1117.489, -1133.613, -1149.691, -1165.721, -1181.705, -1197.64, -1213.527, -1229.366, -1245.155, -1260.894, -1276.583, -1292.221, -1307.808, -1323.344, -1338.828, -1354.2579999999998, -1369.636, -1384.961, -1400.231, -1415.4479999999999, -1430.609, -1445.715, -1460.765, -1475.759, -1490.6970000000001, -1505.5770000000002, -1520.4, -1535.164, -1549.871, -1564.5179999999998, -1579.105, -1593.6329999999998, -1608.101, -1622.5079999999998, -1636.8529999999998, -1651.1370000000002, -1665.359, -1679.5179999999998, -1693.614, -1707.646, -1721.615, -1735.519, -1749.358, -1763.131, -1776.839, -1790.48, -1804.0539999999999, -1817.5610000000001, -1831.0, -1844.371, -1857.6729999999998, -1870.906, -1884.069, -1897.162, -1910.184, -1923.135, -1936.014, -1948.82, -1961.5539999999999, -1974.215, -1986.8020000000001, -1999.315, -2011.753, -2024.115, -2036.402, -2048.612, -2060.746, -2072.802, -2084.78, -2096.679, -2108.5, -2120.24, -2131.901, -2143.481, -2154.979, -2166.396, -2177.73, -2188.981, -2200.149, -2211.232, -2222.23, -2233.143, -2243.971, -2254.7110000000002, -2265.364, -2275.93, -2286.406, -2296.794, -2307.092, -2317.3, -2327.416, -2337.4410000000003, -2347.374, -2357.2129999999997, -2366.959, -2376.61, -2386.166, -2395.627, -2404.99, -2414.257, -2423.425, -2432.495, -2441.466, -2450.3360000000002, -2459.106, -2467.7729999999997, -2476.3379999999997, -2484.8, -2493.158, -2501.411, -2509.558, -2517.599, -2525.533, -2533.3579999999997, -2541.074, -2548.68, -2556.176, -2563.56, -2570.831, -2577.989, -2585.033, -2591.9610000000002, -2598.7729999999997, -2605.468, -2612.045, -2618.502, -2624.84, -2631.0559999999996, -2637.15, -2643.12, -2648.967, -2654.688, -2660.282, -2665.7490000000003, -2671.0879999999997, -2676.296, -2681.3740000000003, -2686.3190000000004, -2691.132, -2695.809, -2700.3520000000003, -2704.757, -2709.0240000000003, -2713.151, -2717.138, -2720.9829999999997, -2724.684, -2728.241, -2731.651, -2734.914, -2738.028, -2740.991, -2743.803, -2746.461, -2748.9640000000004, -2751.3109999999997, -2753.5, -2755.5290000000005, -2757.397, -2759.1009999999997, -2760.6420000000003, -2762.0159999999996, -2763.222, -2764.258, -2765.1220000000003, -2765.813, -2766.328, -2766.667, -2766.8259999999996, -2766.803, -2766.598, -2766.2070000000003, -2765.6290000000004, -2764.861, -2763.902, -2762.7490000000003, -2761.3990000000003, -2759.8509999999997, -2758.1020000000003, -2756.15, -2753.992, -2751.6259999999997, -2749.0490000000004, -2746.259, -2743.2529999999997, -2740.028, -2736.5809999999997, -2732.91, -2729.012, -2724.883, -2720.5209999999997, -2715.923, -2711.085, -2706.0040000000004, -2700.677, -2695.1, -2689.2709999999997, -2683.185, -2676.8390000000004, -2670.2290000000003, -2663.3509999999997, -2656.202, -2648.778, -2641.073, -2633.085, -2624.809, -2616.24, -2607.374, -2598.206, -2588.732, -2578.946, -2568.844, -2558.42, -2547.67, -2536.587, -2525.167, -2513.403, -2501.29, -2488.821, -2475.991, -2462.7929999999997, -2449.22, -2435.265, -2420.922, -2406.1839999999997, -2391.042, -2375.49, -2359.52, -2343.124, -2326.2929999999997, -2309.019, -2291.292, -2273.105, -2254.446, -2235.308, -2215.679, -2195.549, -2174.909, -2153.745, -2132.049, -2109.8070000000002, -2087.007, -2063.638, -2039.6860000000001, -2015.1370000000002, -1989.979, -1964.195, -1937.774, -1910.6979999999999, -1882.953, -1854.521, -1825.388, -1795.5339999999999, -1764.943, -1733.596, -1701.475, -1668.56, -1634.832, -1600.269, -1564.851, -1528.558, -1491.3670000000002, -1453.256, -1414.204, -1374.1870000000001, -1333.183, -1291.1689999999999, -1248.123, -1204.024, -1158.85, -1112.579, -1065.195, -1016.68, -967.0189999999999, -916.199, -864.2130000000001, -811.055, -756.7260000000001, -701.2339999999999, -644.594, -586.8290000000001, -527.9730000000001, -468.07, -407.18, -345.375, -282.745, -219.398, -155.461, -91.08, -26.42, 38.333, 102.977, 167.294, 231.055, 294.022, 355.957, 416.624, 475.796, 533.264, 588.8330000000001, 642.34, 693.643, 742.6310000000001, 789.221, 833.36, 875.02, 914.199, 950.913, 985.199, 1017.1080000000001, 1046.704, 1074.058, 1099.248, 1122.359, 1143.476, 1162.6860000000001, 1180.076, 1195.73, 1209.734, 1222.1680000000001, 1233.111, 1242.639, 1250.822, 1257.731, 1263.43, 1267.982, 1271.4460000000001, 1273.878, 1275.329, 1275.851, 1275.489, 1274.3210000000001, 1272.29, 1269.5339999999999, 1266.058, 1261.897, 1257.083, 1251.6480000000001, 1245.623, 1239.0339999999999, 1231.9080000000001, 1224.271, 1216.145, 1207.553, 1198.516, 1189.0539999999999, 1179.1860000000001, 1168.931, 1158.305, 1147.3239999999998, 1136.005, 1124.36, 1112.406, 1100.154, 1087.618, 1074.809, 1061.738, 1048.4180000000001, 1034.858, 1021.068, 1007.058, 992.836, 978.4119999999999, 963.794, 948.99, 934.0060000000001, 918.852, 903.533, 888.057, 872.429, 856.6569999999999, 840.745, 824.7, 808.5269999999999, 792.232, 775.819, 759.293, 742.659, 725.922, 709.085, 692.154, 675.1310000000001, 658.0219999999999, 640.8290000000001, 623.557, 606.2090000000001, 588.788, 571.298, 553.742, 536.122, 518.443, 500.70599999999996, 482.914, 465.07099999999997, 447.17800000000005, 429.23900000000003, 411.256, 393.23, 375.166, 357.064, 338.926, 320.756, 302.555, 284.325, 266.068, 247.78599999999997, 229.481, 211.15400000000002, 192.808, 174.44299999999998, 156.062, 137.666, 119.257, 100.837, 82.406, 63.966, 45.519, 27.066, 8.607999999999999, -9.853, -28.316, -46.778999999999996, -65.243, -83.704, -102.163, -120.617, -139.067, -157.51, -175.946, -194.37400000000002, -212.792, -231.2, -249.59599999999998, -267.98, -286.351, -304.707, -323.04900000000004, -341.374, -359.68199999999996, -377.972, -396.244, -414.496, -432.727, -450.93800000000005, -469.126, -487.292, -505.434, -523.552, -541.645, -559.712, -577.752, -595.765, -613.75, -631.707, -649.634, -667.5310000000001, -685.398, -703.2330000000001, -721.0360000000001, -738.806, -756.543, -774.247, -791.915, -809.549, -827.1469999999999, -844.7080000000001, -862.2330000000001, -879.7189999999999, -897.168, -914.578, -931.949, -949.28, -966.57, -983.82, -1001.0269999999999, -1018.193, -1035.316, -1052.396, -1069.433, -1086.425, -1103.372, -1120.274, -1137.13, -1153.94, -1170.702, -1187.4180000000001, -1204.086, -1220.705, -1237.275, -1253.796, -1270.267, -1286.687, -1303.057, -1319.375, -1335.641, -1351.855, -1368.015, -1384.1229999999998, -1400.1760000000002, -1416.175, -1432.12, -1448.009, -1463.842, -1479.618, -1495.338, -1511.0, -1526.605, -1542.151, -1557.639, -1573.067, -1588.4360000000001, -1603.744, -1618.991, -1634.1779999999999, -1649.3020000000001, -1664.364, -1679.364, -1694.3, -1709.1729999999998, -1723.9820000000002, -1738.725, -1753.404, -1768.017, -1782.5639999999999, -1797.0439999999999, -1811.457, -1825.8020000000001, -1840.079, -1854.2879999999998, -1868.4270000000001, -1882.496, -1896.495, -1910.424, -1924.281, -1938.066, -1951.779, -1965.4189999999999, -1978.986, -1992.479, -2005.8970000000002, -2019.24, -2032.5079999999998, -2045.6989999999998, -2058.814, -2071.8520000000003, -2084.812, -2097.694, -2110.496, -2123.22, -2135.863, -2148.426, -2160.907, -2173.3070000000002, -2185.624, -2197.8579999999997, -2210.009, -2222.075, -2234.0570000000002, -2245.953, -2257.764, -2269.487, -2281.124, -2292.672, -2304.132, -2315.5029999999997, -2326.784, -2337.974, -2349.073, -2360.08, -2370.995, -2381.817, -2392.544, -2403.177, -2413.715, -2424.156, -2434.501, -2444.748, -2454.897, -2464.948, -2474.8979999999997, -2484.748, -2494.4970000000003, -2504.143, -2513.687, -2523.127, -2532.4629999999997, -2541.6929999999998, -2550.8179999999998, -2559.835, -2568.745, -2577.547, -2586.238, -2594.82, -2603.29, -2611.6479999999997, -2619.894, -2628.025, -2636.042, -2643.942, -2651.7259999999997, -2659.3920000000003, -2666.94, -2674.368, -2681.675, -2688.861, -2695.9240000000004, -2702.863, -2709.677, -2716.365, -2722.927, -2729.36, -2735.664, -2741.8379999999997, -2747.88, -2753.789, -2759.565, -2765.205, -2770.71, -2776.0759999999996, -2781.304, -2786.3920000000003, -2791.3390000000004, -2796.143, -2800.803, -2805.3179999999998, -2809.6859999999997, -2813.906, -2817.9759999999997, -2821.8959999999997, -2825.6620000000003, -2829.275, -2832.7329999999997, -2836.033, -2839.175, -2842.157, -2844.9770000000003, -2847.634, -2850.125, -2852.45, -2854.6059999999998, -2856.592, -2858.405, -2860.045, -2861.509, -2862.795, -2863.902, -2864.827, -2865.5679999999998, -2866.1240000000003, -2866.492, -2866.67, -2866.656, -2866.448, -2866.0440000000003, -2865.441, -2864.637, -2863.6290000000004, -2862.4159999999997, -2860.995, -2859.362, -2857.5170000000003, -2855.455, -2853.1740000000004, -2850.672, -2847.946, -2844.993, -2841.81, -2838.3940000000002, -2834.742, -2830.8509999999997, -2826.717, -2822.3379999999997, -2817.71, -2812.83, -2807.6940000000004, -2802.298, -2796.64, -2790.715, -2784.52, -2778.05, -2771.302, -2764.272, -2756.955, -2749.347, -2741.4429999999998, -2733.24, -2724.7329999999997, -2715.9159999999997, -2706.785, -2697.335, -2687.56, -2677.4570000000003, -2667.018, -2656.239, -2645.114, -2633.636, -2621.801, -2609.6020000000003, -2597.032, -2584.085, -2570.754, -2557.033, -2542.913, -2528.389, -2513.451, -2498.093, -2482.3070000000002, -2466.084, -2449.416, -2432.294, -2414.709, -2396.651, -2378.112, -2359.081, -2339.548, -2319.502, -2298.933, -2277.8289999999997, -2256.179, -2233.97, -2211.1910000000003, -2187.828, -2163.868, -2139.299, -2114.104, -2088.27, -2061.782, -2034.625, -2006.7820000000002, -1978.237, -1948.9720000000002, -1918.97, -1888.2120000000002, -1856.681, -1824.355, -1791.2160000000001, -1757.243, -1722.414, -1686.707, -1650.102, -1612.575, -1574.1029999999998, -1534.662, -1494.2279999999998, -1452.777, -1410.285, -1366.727, -1322.079, -1276.317, -1229.4180000000001, -1181.36, -1132.122, -1081.684, -1030.029, -977.1439999999999, -923.0169999999999, -867.6419999999999, -811.018, -753.1519999999999, -694.055, -633.75, -572.27, -509.659, -445.976, -381.29400000000004, -315.704, -249.317, -182.261, -114.68799999999999, -46.769, 21.305999999999997, 89.32600000000001, 157.064, 224.28099999999998, 290.728, 356.156, 420.316, 482.968, 543.889, 602.875, 659.7460000000001, 714.352, 766.571, 816.313, 863.5139999999999, 908.1439999999999, 950.194, 989.679, 1026.631, 1061.1019999999999, 1093.154, 1122.86, 1150.3, 1175.558, 1198.724, 1219.886, 1239.134, 1256.557, 1272.24, 1286.269, 1298.726, 1309.688, 1319.2320000000002, 1327.4279999999999, 1334.345, 1340.047, 1344.598, 1348.0539999999999, 1350.471, 1351.901, 1352.394, 1351.995, 1350.75, 1348.6979999999999, 1345.88, 1342.332, 1338.089, 1333.184, 1327.649, 1321.5120000000002, 1314.8010000000002, 1307.5439999999999, 1299.764, 1291.485, 1282.73, 1273.52, 1263.874, 1253.812, 1243.3519999999999, 1232.511, 1221.305, 1209.75, 1197.861, 1185.651, 1173.134, 1160.323, 1147.23, 1133.866, 1120.243, 1106.37, 1092.259, 1077.9189999999999, 1063.358, 1048.587, 1033.612, 1018.443, 1003.087, 987.552, 971.8439999999999, 955.971, 939.939, 923.7539999999999, 907.423, 890.951, 874.3439999999999, 857.6080000000001, 840.7460000000001, 823.7660000000001, 806.67, 789.465, 772.154, 754.742, 737.232, 719.63, 701.938, 684.1610000000001, 666.302, 648.365, 630.3530000000001, 612.269, 594.117, 575.9, 557.62, 539.28, 520.884, 502.434, 483.93199999999996, 465.38199999999995, 446.785, 428.144, 409.462, 390.74, 371.981, 353.18699999999995, 334.36, 315.502, 296.616, 277.702, 258.763, 239.8, 220.81599999999997, 201.812, 182.79, 163.752, 144.69799999999998, 125.631, 106.552, 87.463, 68.365, 49.25899999999999, 30.147, 11.03, -8.09, -27.212, -46.336000000000006, -65.459, -84.58, -103.699, -122.814, -141.924, -161.028, -180.12400000000002, -199.21200000000002, -218.291, -237.36, -256.41700000000003, -275.462, -294.494, -313.512, -332.514, -351.5, -370.469, -389.42, -408.352, -427.265, -446.157, -465.028, -483.87699999999995, -502.702, -521.504, -540.2819999999999, -559.034, -577.76, -596.46, -615.131, -633.775, -652.389, -670.9739999999999, -689.528, -708.051, -726.543, -745.002, -763.428, -781.82, -800.177, -818.5, -836.7860000000001, -855.0369999999999, -873.25, -891.426, -909.563, -927.6619999999999, -945.721, -963.74, -981.7189999999999, -999.6560000000001, -1017.551, -1035.404, -1053.214, -1070.981, -1088.703, -1106.381, -1124.013, -1141.6, -1159.14, -1176.634, -1194.08, -1211.478, -1228.827, -1246.127, -1263.378, -1280.579, -1297.728, -1314.8270000000002, -1331.874, -1348.869, -1365.81, -1382.6989999999998, -1399.533, -1416.3139999999999, -1433.039, -1449.7089999999998, -1466.3229999999999, -1482.88, -1499.381, -1515.8239999999998, -1532.2089999999998, -1548.535, -1564.8020000000001, -1581.01, -1597.158, -1613.245, -1629.271, -1645.235, -1661.1370000000002, -1676.977, -1692.753, -1708.465, -1724.1129999999998, -1739.6970000000001, -1755.215, -1770.6670000000001, -1786.0529999999999, -1801.372, -1816.6229999999998, -1831.807, -1846.922, -1861.9679999999998, -1876.944, -1891.85, -1906.6860000000001, -1921.45, -1936.1429999999998, -1950.763, -1965.3110000000001, -1979.785, -1994.185, -2008.511, -2022.7620000000002, -2036.9370000000001, -2051.035, -2065.0570000000002, -2079.002, -2092.869, -2106.656, -2120.365, -2133.994, -2147.5429999999997, -2161.011, -2174.3979999999997, -2187.702, -2200.923, -2214.062, -2227.116, -2240.085, -2252.97, -2265.768, -2278.48, -2291.105, -2303.6420000000003, -2316.091, -2328.45, -2340.72, -2352.899, -2364.987, -2376.9829999999997, -2388.886, -2400.697, -2412.413, -2424.035, -2435.561, -2446.991, -2458.325, -2469.561, -2480.698, -2491.736, -2502.675, -2513.513, -2524.25, -2534.884, -2545.415, -2555.843, -2566.166, -2576.383, -2586.495, -2596.499, -2606.395, -2616.183, -2625.861, -2635.428, -2644.883, -2654.2270000000003, -2663.4570000000003, -2672.573, -2681.574, -2690.458, -2699.2259999999997, -2707.8759999999997, -2716.407, -2724.817, -2733.107, -2741.275, -2749.3190000000004, -2757.24, -2765.035, -2772.704, -2780.2459999999996, -2787.659, -2794.9429999999998, -2802.0959999999995, -2809.117, -2816.005, -2822.759, -2829.3779999999997, -2835.86, -2842.204, -2848.409, -2854.473, -2860.3959999999997, -2866.175, -2871.8109999999997, -2877.3, -2882.643, -2887.837, -2892.881, -2897.7740000000003, -2902.514, -2907.1, -2911.53, -2915.802, -2919.9159999999997, -2923.87, -2927.6609999999996, -2931.288, -2934.7509999999997, -2938.046, -2941.172, -2944.1279999999997, -2946.9109999999996, -2949.5209999999997, -2951.954, -2954.21, -2956.285, -2958.179, -2959.89, -2961.414, -2962.7509999999997, -2963.8979999999997, -2964.853, -2965.614, -2966.178, -2966.5440000000003, -2966.7090000000003, -2966.671, -2966.427, -2965.975, -2965.312, -2964.4359999999997, -2963.345, -2962.035, -2960.505, -2958.75, -2956.7690000000002, -2954.559, -2952.116, -2949.438, -2946.522, -2943.364, -2939.961, -2936.3109999999997, -2932.409, -2928.2529999999997, -2923.8390000000004, -2919.163, -2914.2209999999995, -2909.01, -2903.527, -2897.7670000000003, -2891.7259999999997, -2885.401, -2878.7870000000003, -2871.8790000000004, -2864.6740000000004, -2857.167, -2849.3520000000003, -2841.2270000000003, -2832.785, -2824.022, -2814.9320000000002, -2805.511, -2795.7529999999997, -2785.652, -2775.203, -2764.4, -2753.237, -2741.708, -2729.8059999999996, -2717.526, -2704.86, -2691.802, -2678.344, -2664.4790000000003, -2650.2009999999996, -2635.5, -2620.369, -2604.8, -2588.786, -2572.3160000000003, -2555.382, -2537.975, -2520.0860000000002, -2501.7039999999997, -2482.819, -2463.422, -2443.501, -2423.045, -2402.0429999999997, -2380.4829999999997, -2358.3520000000003, -2335.639, -2312.33, -2288.411, -2263.869, -2238.689, -2212.856, -2186.356, -2159.1710000000003, -2131.2870000000003, -2102.685, -2073.348, -2043.2579999999998, -2012.3970000000002, -1980.744, -1948.281, -1914.986, -1880.839, -1845.816, -1809.8970000000002, -1773.058, -1735.275, -1696.525, -1656.7820000000002, -1616.021, -1574.217, -1531.344, -1487.375, -1442.2839999999999, -1396.045, -1348.6329999999998, -1300.022, -1250.1889999999999, -1199.108, -1146.761, -1093.126, -1038.188, -981.934, -924.357, -865.453, -805.225, -743.686, -680.855, -616.766, -551.461, -484.99800000000005, -417.45300000000003, -348.917, -279.504, -209.34400000000002, -138.592, -67.425, 3.96, 75.345, 146.495, 217.16099999999997, 287.082, 355.99699999999996, 423.645, 489.773, 554.146, 616.5459999999999, 676.783, 734.694, 790.1469999999999, 843.044, 893.315, 940.92, 985.8480000000001, 1028.109, 1067.736, 1104.776, 1139.2930000000001, 1171.36, 1201.058, 1228.473, 1253.6960000000001, 1276.82, 1297.9360000000001, 1317.135, 1334.5079999999998, 1350.141, 1364.12, 1376.527, 1387.4389999999999, 1396.931, 1405.0739999999998, 1411.9370000000001, 1417.5810000000001, 1422.0710000000001, 1425.4620000000002, 1427.81, 1429.1660000000002, 1429.578, 1429.0929999999998, 1427.753, 1425.601, 1422.674, 1419.01, 1414.642, 1409.604, 1403.9260000000002, 1397.639, 1390.769, 1383.342, 1375.384, 1366.918, 1357.9660000000001, 1348.549, 1338.6879999999999, 1328.401, 1317.7060000000001, 1306.621, 1295.162, 1283.344, 1271.183, 1258.692, 1245.886, 1232.776, 1219.375, 1205.694, 1191.746, 1177.54, 1163.087, 1148.396, 1133.476, 1118.338, 1102.989, 1087.437, 1071.691, 1055.758, 1039.645, 1023.3589999999999, 1006.9069999999999, 990.295, 973.53, 956.617, 939.563, 922.372, 905.049, 887.6010000000001, 870.0319999999999, 852.347, 834.55, 816.6460000000001, 798.6389999999999, 780.533, 762.332, 744.04, 725.6610000000001, 707.198, 688.655, 670.035, 651.342, 632.5790000000001, 613.748, 594.8530000000001, 575.896, 556.881, 537.81, 518.686, 499.51099999999997, 480.288, 461.019, 441.70599999999996, 422.353, 402.96, 383.531, 364.06699999999995, 344.57, 325.043, 305.487, 285.904, 266.297, 246.666, 227.013, 207.34099999999998, 187.65099999999998, 167.94400000000002, 148.22299999999998, 128.488, 108.741, 88.984, 69.218, 49.445, 29.666, 9.882, -9.906, -29.695999999999998, -49.486000000000004, -69.27600000000001, -89.065, -108.85, -128.632, -148.409, -168.179, -187.942, -207.697, -227.442, -247.17700000000002, -266.9, -286.611, -306.308, -325.991, -345.658, -365.309, -384.94300000000004, -404.55800000000005, -424.154, -443.731, -463.286, -482.82, -502.332, -521.82, -541.284, -560.7230000000001, -580.136, -599.523, -618.882, -638.214, -657.5160000000001, -676.789, -696.0319999999999, -715.2439999999999, -734.424, -753.572, -772.686, -791.7669999999999, -810.813, -829.825, -848.8, -867.7389999999999, -886.64, -905.5039999999999, -924.329, -943.1160000000001, -961.862, -980.568, -999.2339999999999, -1017.857, -1036.4389999999999, -1054.9769999999999, -1073.472, -1091.923, -1110.33, -1128.691, -1147.007, -1165.276, -1183.498, -1201.672, -1219.799, -1237.876, -1255.905, -1273.883, -1291.81, -1309.687, -1327.513, -1345.286, -1363.007, -1380.674, -1398.2879999999998, -1415.848, -1433.352, -1450.8010000000002, -1468.194, -1485.531, -1502.81, -1520.0320000000002, -1537.195, -1554.3, -1571.345, -1588.3310000000001, -1605.256, -1622.12, -1638.9229999999998, -1655.664, -1672.342, -1688.957, -1705.5079999999998, -1721.995, -1738.4170000000001, -1754.774, -1771.0639999999999, -1787.289, -1803.4460000000001, -1819.536, -1835.558, -1851.51, -1867.394, -1883.2079999999999, -1898.951, -1914.6229999999998, -1930.224, -1945.753, -1961.2089999999998, -1976.592, -1991.9, -2007.135, -2022.2939999999999, -2037.378, -2052.385, -2067.3160000000003, -2082.169, -2096.945, -2111.641, -2126.259, -2140.7960000000003, -2155.2529999999997, -2169.629, -2183.923, -2198.135, -2212.264, -2226.3089999999997, -2240.27, -2254.147, -2267.937, -2281.641, -2295.259, -2308.7889999999998, -2322.231, -2335.583, -2348.847, -2362.02, -2375.1020000000003, -2388.092, -2400.99, -2413.795, -2426.506, -2439.123, -2451.644, -2464.069, -2476.3979999999997, -2488.629, -2500.762, -2512.7960000000003, -2524.73, -2536.563, -2548.295, -2559.925, -2571.452, -2582.875, -2594.1929999999998, -2605.406, -2616.513, -2627.513, -2638.4040000000005, -2649.187, -2659.86, -2670.422, -2680.873, -2691.212, -2701.437, -2711.547, -2721.5429999999997, -2731.422, -2741.184, -2750.828, -2760.353, -2769.757, -2779.0409999999997, -2788.202, -2797.241, -2806.1540000000005, -2814.9429999999998, -2823.605, -2832.14, -2840.546, -2848.822, -2856.967, -2864.98, -2872.861, -2880.6059999999998, -2888.216, -2895.69, -2903.025, -2910.2209999999995, -2917.276, -2924.19, -2930.96, -2937.586, -2944.066, -2950.3990000000003, -2956.583, -2962.617, -2968.5, -2974.2290000000003, -2979.805, -2985.224, -2990.486, -2995.5890000000004, -3000.531, -3005.312, -3009.928, -3014.3790000000004, -3018.663, -3022.7790000000005, -3026.723, -3030.495, -3034.094, -3037.5159999999996, -3040.76, -3043.825, -3046.708, -3049.408, -3051.922, -3054.248, -3056.385, -3058.33, -3060.0809999999997, -3061.636, -3062.993, -3064.1490000000003, -3065.103, -3065.8509999999997, -3066.3909999999996, -3066.722, -3066.84, -3066.743, -3066.428, -3065.893, -3065.134, -3064.15, -3062.938, -3061.494, -3059.816, -3057.9, -3055.744, -3053.345, -3050.699, -3047.803, -3044.653, -3041.2470000000003, -3037.5809999999997, -3033.651, -3029.454, -3024.986, -3020.244, -3015.222, -3009.9179999999997, -3004.327, -2998.445, -2992.2690000000002, -2985.792, -2979.012, -2971.923, -2964.52, -2956.8, -2948.756, -2940.384, -2931.68, -2922.636, -2913.2490000000003, -2903.511, -2893.4190000000003, -2882.965, -2872.143, -2860.948, -2849.3720000000003, -2837.41, -2825.054, -2812.298, -2799.134, -2785.555, -2771.554, -2757.1220000000003, -2742.2509999999997, -2726.934, -2711.1609999999996, -2694.9240000000004, -2678.2140000000004, -2661.0209999999997, -2643.336, -2625.1490000000003, -2606.45, -2587.2270000000003, -2567.471, -2547.17, -2526.311, -2504.884, -2482.875, -2460.272, -2437.062, -2413.231, -2388.765, -2363.649, -2337.868, -2311.406, -2284.248, -2256.376, -2227.7729999999997, -2198.4210000000003, -2168.303, -2137.3979999999997, -2105.687, -2073.15, -2039.765, -2005.5120000000002, -1970.3670000000002, -1934.307, -1897.309, -1859.3470000000002, -1820.399, -1780.4370000000001, -1739.4360000000001, -1697.368, -1654.2060000000001, -1609.9229999999998, -1564.491, -1517.881, -1470.066, -1421.0179999999998, -1370.7089999999998, -1319.114, -1266.2060000000001, -1211.964, -1156.365, -1099.391, -1041.027, -981.262, -920.0930000000001, -857.5210000000001, -793.555, -728.216, -661.533, -593.55, -524.325, -453.934, -382.469, -310.04400000000004, -236.794, -162.878, -88.476, -13.793, 60.946000000000005, 135.498, 209.60299999999998, 282.991, 355.38800000000003, 426.52, 496.12300000000005, 563.946, 629.763, 693.367, 754.587, 813.2810000000001, 869.3389999999999, 922.685, 973.275, 1021.09, 1066.139, 1108.4489999999998, 1148.07, 1185.062, 1219.501, 1251.468, 1281.052, 1308.345, 1333.441, 1356.435, 1377.422, 1396.495, 1413.745, 1429.2579999999998, 1443.119, 1455.41, 1466.2079999999999, 1475.588, 1483.619, 1490.369, 1495.902, 1500.277, 1503.5520000000001, 1505.78, 1506.994, 1507.296, 1506.6770000000001, 1505.2, 1502.9029999999998, 1499.825, 1496.004, 1491.4720000000002, 1486.2620000000002, 1480.406, 1473.931, 1466.866, 1459.235, 1451.065, 1442.379, 1433.1989999999998, 1423.545, 1413.4379999999999, 1402.8970000000002, 1391.94, 1380.5829999999999, 1368.845, 1356.739, 1344.2820000000002, 1331.486, 1318.366, 1304.934, 1291.204, 1277.1860000000001, 1262.891, 1248.3310000000001, 1233.517, 1218.4560000000001, 1203.16, 1187.637, 1171.896, 1155.9460000000001, 1139.7930000000001, 1123.4460000000001, 1106.912, 1090.1989999999998, 1073.312, 1056.26, 1039.047, 1021.679, 1004.164, 986.5060000000001, 968.711, 950.784, 932.7289999999999, 914.553, 896.2589999999999, 877.8530000000001, 859.3380000000001, 840.7180000000001, 821.9989999999999, 803.183, 784.2739999999999, 765.2769999999999, 746.195, 727.0310000000001, 707.789, 688.472, 669.0830000000001, 649.625, 630.101, 610.514, 590.867, 571.163, 551.404, 531.592, 511.731, 491.82199999999995, 471.869, 451.87300000000005, 431.836, 411.76099999999997, 391.65, 371.505, 351.32800000000003, 331.12, 310.885, 290.623, 270.336, 250.02700000000002, 229.697, 209.347, 188.98, 168.597, 148.19899999999998, 127.788, 107.365, 86.93299999999999, 66.492, 46.044, 25.59, 5.132000000000001, -15.33, -35.793, -56.257, -76.72, -97.181, -117.639, -138.093, -158.541, -178.983, -199.418, -219.843, -240.25900000000001, -260.663, -281.056, -301.436, -321.802, -342.154, -362.48900000000003, -382.80699999999996, -403.108, -423.39, -443.653, -463.895, -484.116, -504.314, -524.49, -544.641, -564.768, -584.87, -604.945, -624.993, -645.013, -665.0039999999999, -684.965, -704.8969999999999, -724.797, -744.666, -764.502, -784.305, -804.074, -823.808, -843.508, -863.171, -882.797, -902.3860000000001, -921.936, -941.448, -960.921, -980.3530000000001, -999.745, -1019.095, -1038.403, -1057.6680000000001, -1076.89, -1096.068, -1115.202, -1134.29, -1153.3319999999999, -1172.328, -1191.277, -1210.178, -1229.03, -1247.8339999999998, -1266.588, -1285.292, -1303.9460000000001, -1322.5479999999998, -1341.098, -1359.595, -1378.04, -1396.431, -1414.767, -1433.049, -1451.275, -1469.445, -1487.559, -1505.615, -1523.6129999999998, -1541.5529999999999, -1559.435, -1577.256, -1595.0179999999998, -1612.719, -1630.358, -1647.9360000000001, -1665.451, -1682.904, -1700.2920000000001, -1717.6170000000002, -1734.8770000000002, -1752.0710000000001, -1769.2, -1786.2620000000002, -1803.257, -1820.184, -1837.043, -1853.8329999999999, -1870.5539999999999, -1887.205, -1903.785, -1920.2939999999999, -1936.731, -1953.095, -1969.3870000000002, -1985.605, -2001.749, -2017.817, -2033.8110000000001, -2049.728, -2065.569, -2081.3320000000003, -2097.0170000000003, -2112.624, -2128.151, -2143.599, -2158.966, -2174.252, -2189.456, -2204.578, -2219.617, -2234.572, -2249.4429999999998, -2264.228, -2278.928, -2293.541, -2308.067, -2322.506, -2336.856, -2351.116, -2365.2870000000003, -2379.367, -2393.356, -2407.2529999999997, -2421.0570000000002, -2434.768, -2448.384, -2461.906, -2475.331, -2488.661, -2501.893, -2515.026, -2528.062, -2540.9970000000003, -2553.8320000000003, -2566.5660000000003, -2579.198, -2591.7270000000003, -2604.153, -2616.474, -2628.69, -2640.7990000000004, -2652.802, -2664.697, -2676.4829999999997, -2688.159, -2699.725, -2711.179, -2722.5209999999997, -2733.7490000000003, -2744.864, -2755.863, -2766.7459999999996, -2777.512, -2788.159, -2798.688, -2809.097, -2819.384, -2829.55, -2839.592, -2849.51, -2859.302, -2868.968, -2878.507, -2887.917, -2897.197, -2906.347, -2915.364, -2924.248, -2932.998, -2941.613, -2950.09, -2958.429, -2966.6290000000004, -2974.6890000000003, -2982.6059999999998, -2990.381, -2998.01, -3005.495, -3012.8309999999997, -3020.02, -3027.058, -3033.945, -3040.679, -3047.259, -3053.683, -3059.95, -3066.058, -3072.005, -3077.79, -3083.4120000000003, -3088.868, -3094.158, -3099.278, -3104.2290000000003, -3109.007, -3113.612, -3118.0409999999997, -3122.292, -3126.364, -3130.2540000000004, -3133.962, -3137.4840000000004, -3140.8190000000004, -3143.9640000000004, -3146.9190000000003, -3149.68, -3152.245, -3154.613, -3156.781, -3158.7459999999996, -3160.507, -3162.0609999999997, -3163.406, -3164.539, -3165.4570000000003, -3166.159, -3166.6409999999996, -3166.902, -3166.937, -3166.7459999999996, -3166.323, -3165.6679999999997, -3164.777, -3163.6459999999997, -3162.2740000000003, -3160.656, -3158.79, -3156.672, -3154.2990000000004, -3151.6679999999997, -3148.775, -3145.617, -3142.19, -3138.49, -3134.514, -3130.258, -3125.717, -3120.888, -3115.7670000000003, -3110.349, -3104.63, -3098.605, -3092.2709999999997, -3085.6220000000003, -3078.653, -3071.36, -3063.737, -3055.78, -3047.4829999999997, -3038.841, -3029.849, -3020.5, -3010.788, -3000.708, -2990.2540000000004, -2979.4179999999997, -2968.196, -2956.579, -2944.5609999999997, -2932.135, -2919.2940000000003, -2906.03, -2892.335, -2878.202, -2863.6220000000003, -2848.587, -2833.0890000000004, -2817.117, -2800.664, -2783.72, -2766.2740000000003, -2748.3179999999998, -2729.8390000000004, -2710.829, -2691.275, -2671.1659999999997, -2650.491, -2629.237, -2607.391, -2584.94, -2561.873, -2538.173, -2513.828, -2488.822, -2463.14, -2436.765, -2409.6820000000002, -2381.874, -2353.322, -2324.01, -2293.917, -2263.026, -2231.315, -2198.763, -2165.351, -2131.054, -2095.851, -2059.718, -2022.63, -1984.5620000000001, -1945.49, -1905.386, -1864.224, -1821.974, -1778.61, -1734.102, -1688.421, -1641.537, -1593.42, -1544.04, -1493.368, -1441.3729999999998, -1388.029, -1333.308, -1277.184, -1219.634, -1160.637, -1100.1760000000002, -1038.239, -974.819, -909.916, -843.539, -775.704, -706.444, -635.798, -563.826, -490.603, -416.223, -340.801, -264.475, -187.408, -109.785, -31.816, 46.265, 124.208, 201.74200000000002, 278.587, 354.458, 429.06699999999995, 502.139, 573.41, 642.638, 709.6080000000001, 774.1360000000001, 836.069, 895.291, 951.716, 1005.2919999999999, 1055.998, 1103.837, 1148.837, 1191.0439999999999, 1230.518, 1267.3339999999998, 1301.577, 1333.336, 1362.705, 1389.781, 1414.662, 1437.445, 1458.225, 1477.0970000000002, 1494.151, 1509.475, 1523.1529999999998, 1535.266, 1545.889, 1555.098, 1562.96, 1569.5439999999999, 1574.91, 1579.12, 1582.227, 1584.286, 1585.3470000000002, 1585.457, 1584.661, 1583.0020000000002, 1580.5179999999998, 1577.249, 1573.231, 1568.496, 1563.0770000000002, 1557.005, 1550.308, 1543.013, 1535.146, 1526.733, 1517.795, 1508.356, 1498.4360000000001, 1488.055, 1477.233, 1465.986, 1454.3329999999999, 1442.289, 1429.871, 1417.0929999999998, 1403.969, 1390.514, 1376.739, 1362.6570000000002, 1348.281, 1333.621, 1318.6879999999999, 1303.492, 1288.045, 1272.354, 1256.4289999999999, 1240.28, 1223.913, 1207.338, 1190.563, 1173.594, 1156.438, 1139.103, 1121.596, 1103.922, 1086.088, 1068.1, 1049.963, 1031.683, 1013.265, 994.715, 976.0369999999999, 957.237, 938.318, 919.285, 900.143, 880.895, 861.547, 842.1010000000001, 822.561, 802.932, 783.216, 763.418, 743.54, 723.585, 703.558, 683.46, 663.295, 643.066, 622.776, 602.427, 582.0219999999999, 561.563, 541.053, 520.495, 499.89, 479.24199999999996, 458.551, 437.82199999999995, 417.055, 396.25199999999995, 375.417, 354.55, 333.653, 312.73, 291.78, 270.807, 249.81099999999998, 228.796, 207.761, 186.709, 165.642, 144.561, 123.46700000000001, 102.363, 81.249, 60.126999999999995, 38.998000000000005, 17.864, -3.2739999999999996, -24.415, -45.556000000000004, -66.69800000000001, -87.839, -108.977, -130.112, -151.24200000000002, -172.365, -193.482, -214.59099999999998, -235.69, -256.779, -277.857, -298.922, -319.973, -341.01, -362.032, -383.037, -404.025, -424.994, -445.944, -466.874, -487.782, -508.66900000000004, -529.5319999999999, -550.372, -571.188, -591.977, -612.741, -633.477, -654.185, -674.865, -695.515, -716.1339999999999, -736.7230000000001, -757.279, -777.803, -798.294, -818.75, -839.171, -859.557, -879.9060000000001, -900.2189999999999, -920.493, -940.7289999999999, -960.925, -981.082, -1001.198, -1021.273, -1041.306, -1061.296, -1081.243, -1101.146, -1121.004, -1140.817, -1160.5839999999998, -1180.3039999999999, -1199.9769999999999, -1219.6019999999999, -1239.1789999999999, -1258.7060000000001, -1278.184, -1297.611, -1316.987, -1336.3110000000001, -1355.5839999999998, -1374.8029999999999, -1393.9679999999998, -1413.079, -1432.136, -1451.1370000000002, -1470.082, -1488.97, -1507.8010000000002, -1526.5739999999998, -1545.289, -1563.944, -1582.54, -1601.075, -1619.55, -1637.963, -1656.3139999999999, -1674.602, -1692.826, -1710.987, -1729.0829999999999, -1747.114, -1765.079, -1782.977, -1800.809, -1818.5720000000001, -1836.2679999999998, -1853.895, -1871.4520000000002, -1888.9389999999999, -1906.355, -1923.7, -1940.9720000000002, -1958.172, -1975.299, -1992.352, -2009.3310000000001, -2026.234, -2043.0610000000001, -2059.812, -2076.486, -2093.0820000000003, -2109.6, -2126.038, -2142.397, -2158.676, -2174.873, -2190.989, -2207.022, -2222.973, -2238.839, -2254.621, -2270.3179999999998, -2285.929, -2301.4539999999997, -2316.8920000000003, -2332.241, -2347.502, -2362.673, -2377.755, -2392.746, -2407.645, -2422.451, -2437.165, -2451.785, -2466.311, -2480.741, -2495.075, -2509.312, -2523.452, -2537.493, -2551.435, -2565.277, -2579.018, -2592.658, -2606.195, -2619.629, -2632.958, -2646.183, -2659.301, -2672.313, -2685.218, -2698.013, -2710.7, -2723.276, -2735.741, -2748.094, -2760.3340000000003, -2772.4590000000003, -2784.47, -2796.365, -2808.143, -2819.803, -2831.344, -2842.765, -2854.065, -2865.244, -2876.2990000000004, -2887.23, -2898.0359999999996, -2908.716, -2919.2690000000002, -2929.6929999999998, -2939.987, -2950.151, -2960.183, -2970.0820000000003, -2979.847, -2989.4770000000003, -2998.969, -3008.324, -3017.54, -3026.615, -3035.5490000000004, -3044.34, -3052.986, -3061.487, -3069.841, -3078.046, -3086.1020000000003, -3094.007, -3101.758, -3109.3559999999998, -3116.798, -3124.083, -3131.21, -3138.177, -3144.9809999999998, -3151.623, -3158.099, -3164.409, -3170.551, -3176.5229999999997, -3182.323, -3187.95, -3193.401, -3198.675, -3203.7709999999997, -3208.685, -3213.417, -3217.965, -3222.325, -3226.4970000000003, -3230.4790000000003, -3234.268, -3237.861, -3241.258, -3244.4559999999997, -3247.452, -3250.245, -3252.8309999999997, -3255.2090000000003, -3257.3759999999997, -3259.33, -3261.0690000000004, -3262.5890000000004, -3263.888, -3264.9640000000004, -3265.813, -3266.434, -3266.822, -3266.9759999999997, -3266.893, -3266.5690000000004, -3266.002, -3265.188, -3264.1240000000003, -3262.8070000000002, -3261.2340000000004, -3259.401, -3257.305, -3254.942, -3252.309, -3249.402, -3246.217, -3242.7509999999997, -3238.9990000000003, -3234.958, -3230.623, -3225.99, -3221.0559999999996, -3215.8140000000003, -3210.262, -3204.3940000000002, -3198.205, -3191.691, -3184.847, -3177.6679999999997, -3170.1479999999997, -3162.281, -3154.0640000000003, -3145.489, -3136.552, -3127.2459999999996, -3117.5640000000003, -3107.502, -3097.052, -3086.208, -3074.9629999999997, -3063.31, -3051.242, -3038.7509999999997, -3025.83, -3012.4709999999995, -2998.667, -2984.407, -2969.6859999999997, -2954.492, -2938.8190000000004, -2922.655, -2905.992, -2888.8190000000004, -2871.127, -2852.905, -2834.1420000000003, -2814.827, -2794.949, -2774.494, -2753.452, -2731.809, -2709.552, -2686.6690000000003, -2663.143, -2638.962, -2614.111, -2588.572, -2562.3320000000003, -2535.3720000000003, -2507.676, -2479.226, -2450.004, -2419.991, -2389.166, -2357.511, -2325.002, -2291.62, -2257.342, -2222.143, -2186.001, -2148.889, -2110.784, -2071.659, -2031.486, -1990.237, -1947.885, -1904.4, -1859.751, -1813.9089999999999, -1766.8410000000001, -1718.5179999999998, -1668.906, -1617.975, -1565.691, -1512.025, -1456.9470000000001, -1400.4260000000002, -1342.435, -1282.948, -1221.942, -1159.4, -1095.305, -1029.65, -962.432, -893.659, -823.347, -751.5239999999999, -678.232, -603.528, -527.489, -450.21, -371.806, -292.42, -212.217, -131.388, -50.147, 31.264, 112.585, 193.53799999999998, 273.83099999999996, 353.166, 431.246, 507.78, 582.494, 655.131, 725.466, 793.3, 858.4739999999999, 920.86, 980.3660000000001, 1036.934, 1090.535, 1141.171, 1188.866, 1233.664, 1275.628, 1314.83, 1351.355, 1385.297, 1416.75, 1445.815, 1472.59, 1497.1770000000001, 1519.6729999999998, 1540.1760000000002, 1558.78, 1575.575, 1590.648, 1604.0829999999999, 1615.9589999999998, 1626.3529999999998, 1635.3370000000002, 1642.979, 1649.345, 1654.496, 1658.4920000000002, 1661.386, 1663.2320000000002, 1664.078, 1663.9720000000002, 1662.957, 1661.076, 1658.3670000000002, 1654.869, 1650.6170000000002, 1645.6429999999998, 1639.981, 1633.66, 1626.707, 1619.151, 1611.017, 1602.33, 1593.1129999999998, 1583.3870000000002, 1573.1729999999998, 1562.4920000000002, 1551.362, 1539.8, 1527.826, 1515.454, 1502.7, 1489.579, 1476.106, 1462.293, 1448.155, 1433.703, 1418.9489999999998, 1403.904, 1388.58, 1372.987, 1357.135, 1341.033, 1324.69, 1308.117, 1291.32, 1274.308, 1257.089, 1239.67, 1222.06, 1204.264, 1186.289, 1168.142, 1149.829, 1131.357, 1112.73, 1093.954, 1075.036, 1055.98, 1036.7910000000002, 1017.4730000000001, 998.033, 978.4739999999999, 958.8, 939.0169999999999, 919.127, 899.135, 879.046, 858.862, 838.587, 818.225, 797.78, 777.2539999999999, 756.65, 735.9730000000001, 715.225, 694.408, 673.5260000000001, 652.582, 631.578, 610.5169999999999, 589.401, 568.2330000000001, 547.016, 525.751, 504.44199999999995, 483.09, 461.69699999999995, 440.26599999999996, 418.79900000000004, 397.29699999999997, 375.764, 354.199, 332.60699999999997, 310.988, 289.344, 267.677, 245.989, 224.28099999999998, 202.55599999999998, 180.81400000000002, 159.05700000000002, 137.287, 115.506, 93.714, 71.913, 50.106, 28.291999999999998, 6.474, -15.347999999999999, -37.171, -58.995, -80.819, -102.64, -124.458, -146.27200000000002, -168.081, -189.88299999999998, -211.67700000000002, -233.46200000000002, -255.237, -277.001, -298.753, -320.491, -342.216, -363.925, -385.61699999999996, -407.293, -428.95, -450.588, -472.20599999999996, -493.80300000000005, -515.378, -536.93, -558.4580000000001, -579.962, -601.44, -622.891, -644.316, -665.712, -687.079, -708.416, -729.7230000000001, -750.9989999999999, -772.242, -793.452, -814.6289999999999, -835.7710000000001, -856.877, -877.948, -898.982, -919.9780000000001, -940.936, -961.855, -982.7339999999999, -1003.572, -1024.37, -1045.125, -1065.838, -1086.508, -1107.133, -1127.714, -1148.249, -1168.738, -1189.181, -1209.575, -1229.922, -1250.22, -1270.469, -1290.667, -1310.815, -1330.911, -1350.955, -1370.9460000000001, -1390.8829999999998, -1410.767, -1430.596, -1450.369, -1470.0870000000002, -1489.747, -1509.351, -1528.896, -1548.3829999999998, -1567.8110000000001, -1587.1779999999999, -1606.486, -1625.7320000000002, -1644.9160000000002, -1664.037, -1683.096, -1702.0910000000001, -1721.021, -1739.8870000000002, -1758.6870000000001, -1777.42, -1796.0870000000002, -1814.6860000000001, -1833.2160000000001, -1851.6779999999999, -1870.0710000000001, -1888.3929999999998, -1906.644, -1924.8239999999998, -1942.932, -1960.967, -1978.9279999999999, -1996.816, -2014.628, -2032.366, -2050.027, -2067.611, -2085.118, -2102.547, -2119.897, -2137.1679999999997, -2154.3579999999997, -2171.468, -2188.496, -2205.442, -2222.305, -2239.085, -2255.78, -2272.39, -2288.9139999999998, -2305.3520000000003, -2321.702, -2337.965, -2354.139, -2370.224, -2386.218, -2402.1220000000003, -2417.9339999999997, -2433.654, -2449.28, -2464.812, -2480.25, -2495.593, -2510.839, -2525.988, -2541.0389999999998, -2555.991, -2570.844, -2585.597, -2600.248, -2614.798, -2629.244, -2643.587, -2657.825, -2671.958, -2685.985, -2699.905, -2713.716, -2727.4190000000003, -2741.011, -2754.493, -2767.863, -2781.12, -2794.264, -2807.2929999999997, -2820.2070000000003, -2833.0040000000004, -2845.683, -2858.244, -2870.6859999999997, -2883.007, -2895.2059999999997, -2907.282, -2919.235, -2931.063, -2942.7659999999996, -2954.341, -2965.788, -2977.1059999999998, -2988.2940000000003, -2999.35, -3010.2729999999997, -3021.062, -3031.717, -3042.235, -3052.616, -3062.8579999999997, -3072.96, -3082.92, -3092.738, -3102.4120000000003, -3111.941, -3121.323, -3130.5570000000002, -3139.6420000000003, -3148.5759999999996, -3157.3579999999997, -3165.987, -3174.46, -3182.776, -3190.934, -3198.933, -3206.7709999999997, -3214.445, -3221.955, -3229.2990000000004, -3236.4759999999997, -3243.4829999999997, -3250.3190000000004, -3256.982, -3263.4709999999995, -3269.783, -3275.917, -3281.8709999999996, -3287.643, -3293.2309999999998, -3298.633, -3303.847, -3308.8720000000003, -3313.705, -3318.343, -3322.7859999999996, -3327.031, -3331.075, -3334.9159999999997, -3338.552, -3341.9809999999998, -3345.2009999999996, -3348.2090000000003, -3351.002, -3353.578, -3355.934, -3358.0690000000004, -3359.978, -3361.6609999999996, -3363.113, -3364.3320000000003, -3365.316, -3366.06, -3366.563, -3366.822, -3366.8320000000003, -3366.592, -3366.097, -3365.345, -3364.3320000000003, -3363.055, -3361.511, -3359.6940000000004, -3357.603, -3355.2340000000004, -3352.5809999999997, -3349.643, -3346.414, -3342.89, -3339.0679999999998, -3334.9429999999998, -3330.511, -3325.7659999999996, -3320.7059999999997, -3315.324, -3309.617, -3303.579, -3297.204, -3290.489, -3283.428, -3276.015, -3268.244, -3260.111, -3251.6079999999997, -3242.7309999999998, -3233.473, -3223.828, -3213.788, -3203.348, -3192.5009999999997, -3181.239, -3169.555, -3157.442, -3144.893, -3131.8979999999997, -3118.45, -3104.542, -3090.163, -3075.3059999999996, -3059.96, -3044.118, -3027.768, -3010.902, -2993.508, -2975.577, -2957.097, -2938.0559999999996, -2918.4440000000004, -2898.2490000000003, -2877.4570000000003, -2856.0559999999996, -2834.032, -2811.3720000000003, -2788.063, -2764.0890000000004, -2739.435, -2714.085, -2688.0240000000003, -2661.2340000000004, -2633.698, -2605.399, -2576.317, -2546.4339999999997, -2515.73, -2484.183, -2451.774, -2418.48, -2384.277, -2349.144, -2313.054, -2275.984, -2237.907, -2198.7960000000003, -2158.625, -2117.364, -2074.984, -2031.455, -1986.747, -1940.8270000000002, -1893.664, -1845.225, -1795.477, -1744.385, -1691.9170000000001, -1638.0379999999998, -1582.717, -1525.92, -1467.615, -1407.773, -1346.3670000000002, -1283.371, -1218.764, -1152.53, -1084.6580000000001, -1015.143, -943.993, -871.222, -796.855, -720.936, -643.52, -564.684, -484.523, -403.157, -320.728, -237.40599999999998, -153.385, -68.888, 15.839, 100.52600000000001, 184.885, 268.616, 351.408, 432.952, 512.944, 591.096, 667.1419999999999, 740.841, 811.9860000000001, 880.403, 945.9580000000001, 1008.55, 1068.116, 1124.621, 1178.0610000000001, 1228.46, 1275.86, 1320.3220000000001, 1361.92, 1400.739, 1436.874, 1470.422, 1501.485, 1530.1660000000002, 1556.567, 1580.79, 1602.935, 1623.098, 1641.374, 1657.8529999999998, 1672.62, 1685.759, 1697.348, 1707.4620000000002, 1716.1729999999998, 1723.5479999999998, 1729.651, 1734.543, 1738.2220000000002, 1740.921, 1742.513, 1743.105, 1742.744, 1741.473, 1739.3329999999999, 1736.364, 1732.602, 1728.082, 1722.838, 1716.9, 1710.2979999999998, 1703.0610000000001, 1695.215, 1686.785, 1677.797, 1668.2720000000002, 1658.233, 1647.701, 1636.694, 1625.233, 1613.3339999999998, 1601.015, 1588.2920000000001, 1575.182, 1561.6979999999999, 1547.855, 1533.6660000000002, 1519.145, 1504.3039999999999, 1489.154, 1473.7079999999999, 1457.976, 1441.969, 1425.6960000000001, 1409.1670000000001, 1392.392, 1375.38, 1358.138, 1340.6760000000002, 1323.001, 1305.12, 1287.0410000000002, 1268.772, 1250.318, 1231.687, 1212.884, 1193.9160000000002, 1174.789, 1155.508, 1136.079, 1116.508, 1096.798, 1076.955, 1056.985, 1036.891, 1016.678, 996.35, 975.9119999999999, 955.368, 934.721, 913.9760000000001, 893.1360000000001, 872.204, 851.185, 830.081, 808.8960000000001, 787.6339999999999, 766.296, 744.887, 723.408, 701.8639999999999, 680.257, 658.5889999999999, 636.863, 615.082, 593.248, 571.364, 549.431, 527.453, 505.43199999999996, 483.369, 461.267, 439.12800000000004, 416.954, 394.74699999999996, 372.509, 350.24199999999996, 327.94699999999995, 305.627, 283.284, 260.918, 238.532, 216.128, 193.707, 171.27, 148.82, 126.35700000000001, 103.884, 81.40100000000001, 58.911, 36.414, 13.912, -8.594, -31.101999999999997, -53.61, -76.119, -98.626, -121.131, -143.631, -166.12599999999998, -188.615, -211.09599999999998, -233.56799999999998, -256.031, -278.483, -300.922, -323.349, -345.76199999999994, -368.159, -390.54, -412.904, -435.249, -457.57599999999996, -479.88199999999995, -502.167, -524.43, -546.67, -568.886, -591.078, -613.243, -635.382, -657.493, -679.576, -701.63, -723.654, -745.6469999999999, -767.6080000000001, -789.5360000000001, -811.431, -833.2919999999999, -855.117, -876.9069999999999, -898.6610000000001, -920.377, -942.055, -963.694, -985.293, -1006.852, -1028.369, -1049.845, -1071.278, -1092.6680000000001, -1114.013, -1135.3139999999999, -1156.569, -1177.778, -1198.94, -1220.0539999999999, -1241.12, -1262.136, -1283.103, -1304.019, -1324.885, -1345.6979999999999, -1366.4579999999999, -1387.1660000000002, -1407.819, -1428.418, -1448.961, -1469.4479999999999, -1489.879, -1510.2520000000002, -1530.568, -1550.8239999999998, -1571.021, -1591.1589999999999, -1611.235, -1631.25, -1651.203, -1671.094, -1690.921, -1710.683, -1730.382, -1750.014, -1769.5810000000001, -1789.0810000000001, -1808.513, -1827.878, -1847.1729999999998, -1866.4, -1885.556, -1904.641, -1923.655, -1942.596, -1961.465, -1980.261, -1998.9820000000002, -2017.628, -2036.1989999999998, -2054.6929999999998, -2073.11, -2091.45, -2109.7110000000002, -2127.894, -2145.996, -2164.018, -2181.959, -2199.8179999999998, -2217.594, -2235.2870000000003, -2252.896, -2270.42, -2287.8579999999997, -2305.21, -2322.475, -2339.653, -2356.742, -2373.741, -2390.65, -2407.469, -2424.196, -2440.83, -2457.3720000000003, -2473.819, -2490.172, -2506.429, -2522.59, -2538.654, -2554.619, -2570.486, -2586.2529999999997, -2601.92, -2617.485, -2632.948, -2648.308, -2663.5640000000003, -2678.716, -2693.761, -2708.7009999999996, -2723.532, -2738.255, -2752.869, -2767.373, -2781.765, -2796.045, -2810.2129999999997, -2824.2659999999996, -2838.204, -2852.026, -2865.7309999999998, -2879.3179999999998, -2892.7870000000003, -2906.135, -2919.361, -2932.466, -2945.448, -2958.305, -2971.0370000000003, -2983.6420000000003, -2996.12, -3008.469, -3020.6890000000003, -3032.777, -3044.7329999999997, -3056.5559999999996, -3068.244, -3079.796, -3091.212, -3102.489, -3113.6259999999997, -3124.623, -3135.478, -3146.1890000000003, -3156.756, -3167.177, -3177.45, -3187.574, -3197.5490000000004, -3207.3709999999996, -3217.0409999999997, -3226.5559999999996, -3235.915, -3245.117, -3254.159, -3263.0409999999997, -3271.761, -3280.317, -3288.708, -3296.9309999999996, -3304.986, -3312.8709999999996, -3320.583, -3328.1220000000003, -3335.485, -3342.671, -3349.678, -3356.5040000000004, -3363.1459999999997, -3369.6040000000003, -3375.875, -3381.9570000000003, -3387.848, -3393.547, -3399.05, -3404.357, -3409.4640000000004, -3414.37, -3419.071, -3423.567, -3427.855, -3431.9320000000002, -3435.796, -3439.445, -3442.8759999999997, -3446.086, -3449.073, -3451.8340000000003, -3454.367, -3456.6690000000003, -3458.737, -3460.5679999999998, -3462.159, -3463.508, -3464.611, -3465.466, -3466.0690000000004, -3466.4159999999997, -3466.506, -3466.3340000000003, -3465.8959999999997, -3465.19, -3464.2129999999997, -3462.9590000000003, -3461.426, -3459.61, -3457.507, -3455.113, -3452.423, -3449.435, -3446.143, -3442.5440000000003, -3438.632, -3434.403, -3429.853, -3424.978, -3419.7709999999997, -3414.228, -3408.344, -3402.114, -3395.532, -3388.593, -3381.2909999999997, -3373.62, -3365.575, -3357.15, -3348.3379999999997, -3339.133, -3329.527, -3319.5159999999996, -3309.091, -3298.245, -3286.9709999999995, -3275.262, -3263.11, -3250.506, -3237.4429999999998, -3223.913, -3209.906, -3195.413, -3180.426, -3164.934, -3148.929, -3132.4, -3115.337, -3097.728, -3079.5640000000003, -3060.8320000000003, -3041.5209999999997, -3021.619, -3001.113, -2979.99, -2958.238, -2935.841, -2912.7859999999996, -2889.058, -2864.6420000000003, -2839.5229999999997, -2813.683, -2787.107, -2759.776, -2731.673, -2702.7790000000005, -2673.074, -2642.539, -2611.152, -2578.893, -2545.74, -2511.669, -2476.656, -2440.677, -2403.7070000000003, -2365.719, -2326.686, -2286.581, -2245.375, -2203.0370000000003, -2159.536, -2114.843, -2068.923, -2021.745, -1973.274, -1923.475, -1872.315, -1819.756, -1765.764, -1710.305, -1653.3410000000001, -1594.839, -1534.765, -1473.088, -1409.777, -1344.805, -1278.149, -1209.79, -1139.7169999999999, -1067.924, -994.413, -919.198, -842.305, -763.7739999999999, -683.663, -602.0459999999999, -519.021, -434.707, -349.25199999999995, -262.827, -175.63099999999997, -87.89299999999999, 0.135, 88.17399999999999, 175.929, 263.085, 349.32300000000004, 434.32, 517.762, 599.347, 678.795, 755.8539999999999, 830.304, 901.9639999999999, 970.687, 1036.366, 1098.93, 1158.34, 1214.589, 1267.695, 1317.7, 1364.665, 1408.664, 1449.783, 1488.115, 1523.764, 1556.832, 1587.425, 1615.6470000000002, 1641.604, 1665.3970000000002, 1687.1270000000002, 1706.891, 1724.7820000000002, 1740.889, 1755.297, 1768.089, 1779.3410000000001, 1789.128, 1797.519, 1804.5810000000001, 1810.3770000000002, 1814.967, 1818.408, 1820.751, 1822.049, 1822.349, 1821.6960000000001, 1820.132, 1817.6989999999998, 1814.435, 1810.375, 1805.556, 1800.0079999999998, 1793.764, 1786.852, 1779.3010000000002, 1771.136, 1762.384, 1753.067, 1743.21, 1732.8329999999999, 1721.957, 1710.601, 1698.785, 1686.526, 1673.842, 1660.747, 1647.259, 1633.392, 1619.16, 1604.576, 1589.654, 1574.4070000000002, 1558.845, 1542.98, 1526.8239999999998, 1510.386, 1493.6779999999999, 1476.7079999999999, 1459.486, 1442.021, 1424.3210000000001, 1406.395, 1388.251, 1369.896, 1351.338, 1332.5829999999999, 1313.639, 1294.513, 1275.21, 1255.737, 1236.1, 1216.3039999999999, 1196.355, 1176.259, 1156.02, 1135.644, 1115.135, 1094.498, 1073.738, 1052.859, 1031.866, 1010.762, 989.551, 968.238, 946.826, 925.319, 903.721, 882.034, 860.262, 838.409, 816.4780000000001, 794.471, 772.3919999999999, 750.243, 728.028, 705.75, 683.41, 661.012, 638.557, 616.05, 593.491, 570.884, 548.231, 525.533, 502.79400000000004, 480.015, 457.199, 434.347, 411.461, 388.54400000000004, 365.597, 342.62199999999996, 319.621, 296.596, 273.54900000000004, 250.481, 227.394, 204.29, 181.17, 158.035, 134.888, 111.73, 88.56200000000001, 65.38600000000001, 42.20399999999999, 19.016, -4.176, -27.371, -50.567, -73.763, -96.95700000000001, -120.149, -143.33700000000002, -166.52, -189.697, -212.86599999999999, -236.02700000000002, -259.178, -282.318, -305.44599999999997, -328.561, -351.662, -374.74699999999996, -397.81699999999995, -420.869, -443.902, -466.917, -489.911, -512.883, -535.8340000000001, -558.761, -581.664, -604.5409999999999, -627.393, -650.2180000000001, -673.015, -695.783, -718.5219999999999, -741.23, -763.9060000000001, -786.551, -809.1619999999999, -831.74, -854.2819999999999, -876.789, -899.26, -921.693, -944.0889999999999, -966.445, -988.762, -1011.039, -1033.274, -1055.468, -1077.618, -1099.726, -1121.788, -1143.806, -1165.779, -1187.704, -1209.583, -1231.413, -1253.195, -1274.927, -1296.609, -1318.24, -1339.819, -1361.346, -1382.82, -1404.241, -1425.606, -1446.9170000000001, -1468.171, -1489.369, -1510.51, -1531.592, -1552.616, -1573.58, -1594.484, -1615.328, -1636.109, -1656.829, -1677.485, -1698.078, -1718.606, -1739.069, -1759.467, -1779.7979999999998, -1800.0620000000001, -1820.2579999999998, -1840.386, -1860.444, -1880.432, -1900.35, -1920.1960000000001, -1939.97, -1959.671, -1979.299, -1998.852, -2018.3310000000001, -2037.734, -2057.061, -2076.31, -2095.482, -2114.575, -2133.5879999999997, -2152.522, -2171.375, -2190.147, -2208.8360000000002, -2227.442, -2245.965, -2264.403, -2282.756, -2301.0229999999997, -2319.203, -2337.2960000000003, -2355.3, -2373.215, -2391.04, -2408.775, -2426.4179999999997, -2443.969, -2461.427, -2478.792, -2496.061, -2513.235, -2530.313, -2547.2929999999997, -2564.176, -2580.959, -2597.643, -2614.2270000000003, -2630.7090000000003, -2647.0890000000004, -2663.365, -2679.538, -2695.6059999999998, -2711.567, -2727.423, -2743.17, -2758.809, -2774.3379999999997, -2789.757, -2805.0640000000003, -2820.259, -2835.341, -2850.308, -2865.16, -2879.8959999999997, -2894.514, -2909.014, -2923.395, -2937.655, -2951.7940000000003, -2965.81, -2979.702, -2993.47, -3007.112, -3020.627, -3034.014, -3047.272, -3060.3990000000003, -3073.395, -3086.258, -3098.987, -3111.5809999999997, -3124.039, -3136.3590000000004, -3148.5409999999997, -3160.5820000000003, -3172.482, -3184.239, -3195.8520000000003, -3207.32, -3218.6409999999996, -3229.8140000000003, -3240.8379999999997, -3251.711, -3262.4309999999996, -3272.998, -3283.41, -3293.664, -3303.761, -3313.698, -3323.473, -3333.086, -3342.534, -3351.816, -3360.93, -3369.875, -3378.6490000000003, -3387.25, -3395.676, -3403.925, -3411.9970000000003, -3419.888, -3427.598, -3435.1240000000003, -3442.4640000000004, -3449.617, -3456.58, -3463.3509999999997, -3469.929, -3476.3109999999997, -3482.494, -3488.478, -3494.26, -3499.837, -3505.2070000000003, -3510.369, -3515.3179999999998, -3520.054, -3524.574, -3528.875, -3532.954, -3536.81, -3540.4390000000003, -3543.84, -3547.008, -3549.941, -3552.637, -3555.093, -3557.3059999999996, -3559.272, -3560.989, -3562.453, -3563.6609999999996, -3564.611, -3565.2990000000004, -3565.7209999999995, -3565.8740000000003, -3565.7540000000004, -3565.3579999999997, -3564.6820000000002, -3563.723, -3562.4770000000003, -3560.9390000000003, -3559.105, -3556.972, -3554.5359999999996, -3551.792, -3548.735, -3545.362, -3541.667, -3537.6459999999997, -3533.2940000000003, -3528.607, -3523.579, -3518.204, -3512.4790000000003, -3506.397, -3499.952, -3493.14, -3485.954, -3478.388, -3470.4359999999997, -3462.092, -3453.349, -3444.202, -3434.6420000000003, -3424.663, -3414.258, -3403.4190000000003, -3392.139, -3380.409, -3368.223, -3355.571, -3342.446, -3328.8379999999997, -3314.738, -3300.137, -3285.026, -3269.395, -3253.2340000000004, -3236.531, -3219.277, -3201.461, -3183.07, -3164.094, -3144.5190000000002, -3124.3340000000003, -3103.525, -3082.079, -3059.982, -3037.219, -3013.776, -2989.638, -2964.789, -2939.2129999999997, -2912.8920000000003, -2885.809, -2857.946, -2829.284, -2799.803, -2769.485, -2738.3070000000002, -2706.248, -2673.2859999999996, -2639.3979999999997, -2604.561, -2568.748, -2531.935, -2494.094, -2455.2, -2415.223, -2374.135, -2331.904, -2288.501, -2243.893, -2198.047, -2150.929, -2102.504, -2052.738, -2001.594, -1949.0339999999999, -1895.023, -1839.523, -1782.496, -1723.905, -1663.714, -1601.8870000000002, -1538.389, -1473.19, -1406.259, -1337.57, -1267.105, -1194.849, -1120.7930000000001, -1044.9389999999999, -967.299, -887.898, -806.775, -723.9860000000001, -639.606, -553.735, -466.494, -378.03, -288.519, -198.166, -107.20299999999999, -15.89, 75.488, 166.622, 257.192, 346.865, 435.30800000000005, 522.191, 607.2, 690.044, 770.459, 848.2130000000001, 923.113, 995.005, 1063.771, 1129.335, 1191.653, 1250.714, 1306.532, 1359.1470000000002, 1408.62, 1455.026, 1498.45, 1538.989, 1576.745, 1611.825, 1644.336, 1674.3870000000002, 1702.085, 1727.535, 1750.84, 1772.1, 1791.411, 1808.865, 1824.5510000000002, 1838.5529999999999, 1850.951, 1861.8210000000001, 1871.237, 1879.265, 1885.974, 1891.4229999999998, 1895.672, 1898.776, 1900.787, 1901.755, 1901.727, 1900.747, 1898.858, 1896.099, 1892.507, 1888.12, 1882.971, 1877.0910000000001, 1870.5120000000002, 1863.263, 1855.37, 1846.861, 1837.76, 1828.0910000000001, 1817.8770000000002, 1807.138, 1795.896, 1784.1689999999999, 1771.977, 1759.338, 1746.267, 1732.7820000000002, 1718.8970000000002, 1704.628, 1689.989, 1674.993, 1659.6529999999998, 1643.9820000000002, 1627.9920000000002, 1611.693, 1595.098, 1578.2160000000001, 1561.058, 1543.6329999999998, 1525.951, 1508.02, 1489.85, 1471.4479999999999, 1452.8229999999999, 1433.9820000000002, 1414.933, 1395.683, 1376.239, 1356.6070000000002, 1336.7939999999999, 1316.806, 1296.65, 1276.33, 1255.853, 1235.224, 1214.448, 1193.53, 1172.476, 1151.289, 1129.976, 1108.539, 1086.983, 1065.313, 1043.5330000000001, 1021.6469999999999, 999.6569999999999, 977.569, 955.3860000000001, 933.1110000000001, 910.748, 888.3, 865.77, 843.1610000000001, 820.477, 797.721, 774.895, 752.0010000000001, 729.044, 706.0260000000001, 682.948, 659.814, 636.627, 613.388, 590.101, 566.766, 543.387, 519.966, 496.505, 473.006, 449.471, 425.902, 402.301, 378.67, 355.01099999999997, 331.32599999999996, 307.616, 283.884, 260.13, 236.357, 212.56599999999997, 188.76, 164.93900000000002, 141.105, 117.259, 93.404, 69.541, 45.67, 21.794, -2.086, -25.969, -49.853, -73.737, -97.62, -121.5, -145.377, -169.24900000000002, -193.114, -216.972, -240.821, -264.661, -288.48900000000003, -312.305, -336.10900000000004, -359.897, -383.671, -407.42800000000005, -431.167, -454.88800000000003, -478.589, -502.27, -525.929, -549.566, -573.178, -596.7669999999999, -620.3290000000001, -643.866, -667.375, -690.855, -714.306, -737.7280000000001, -761.118, -784.4760000000001, -807.801, -831.0930000000001, -854.35, -877.572, -900.757, -923.905, -947.0160000000001, -970.087, -993.1189999999999, -1016.1110000000001, -1039.0610000000001, -1061.969, -1084.835, -1107.656, -1130.434, -1153.1660000000002, -1175.8519999999999, -1198.491, -1221.083, -1243.627, -1266.121, -1288.566, -1310.96, -1333.3029999999999, -1355.5929999999998, -1377.8310000000001, -1400.015, -1422.144, -1444.219, -1466.2379999999998, -1488.2, -1510.105, -1531.9520000000002, -1553.739, -1575.4679999999998, -1597.136, -1618.743, -1640.289, -1661.7720000000002, -1683.192, -1704.5479999999998, -1725.839, -1747.065, -1768.225, -1789.318, -1810.3429999999998, -1831.3, -1852.1879999999999, -1873.007, -1893.755, -1914.431, -1935.036, -1955.568, -1976.026, -1996.411, -2016.72, -2036.954, -2057.112, -2077.192, -2097.194, -2117.118, -2136.962, -2156.7270000000003, -2176.41, -2196.011, -2215.53, -2234.966, -2254.3179999999998, -2273.585, -2292.7670000000003, -2311.862, -2330.87, -2349.79, -2368.621, -2387.363, -2406.015, -2424.575, -2443.0429999999997, -2461.419, -2479.701, -2497.888, -2515.98, -2533.976, -2551.875, -2569.676, -2587.379, -2604.982, -2622.4840000000004, -2639.885, -2657.184, -2674.38, -2691.472, -2708.4590000000003, -2725.3390000000004, -2742.114, -2758.78, -2775.3379999999997, -2791.7859999999996, -2808.1240000000003, -2824.35, -2840.4629999999997, -2856.4640000000004, -2872.349, -2888.119, -2903.7729999999997, -2919.309, -2934.7259999999997, -2950.0240000000003, -2965.2009999999996, -2980.257, -2995.1890000000003, -3009.998, -3024.6820000000002, -3039.239, -3053.6690000000003, -3067.9709999999995, -3082.1440000000002, -3096.185, -3110.095, -3123.8720000000003, -3137.514, -3151.0209999999997, -3164.3909999999996, -3177.623, -3190.716, -3203.6679999999997, -3216.478, -3229.1459999999997, -3241.6679999999997, -3254.045, -3266.275, -3278.3559999999998, -3290.2870000000003, -3302.067, -3313.6940000000004, -3325.167, -3336.4840000000004, -3347.643, -3358.6440000000002, -3369.4840000000004, -3380.163, -3390.678, -3401.028, -3411.212, -3421.2259999999997, -3431.071, -3440.745, -3450.244, -3459.5690000000004, -3468.716, -3477.685, -3486.473, -3495.079, -3503.5, -3511.7340000000004, -3519.781, -3527.637, -3535.3, -3542.77, -3550.0429999999997, -3557.117, -3563.991, -3570.6620000000003, -3577.1279999999997, -3583.386, -3589.435, -3595.272, -3600.8940000000002, -3606.3, -3611.486, -3616.45, -3621.19, -3625.702, -3629.985, -3634.0359999999996, -3637.8509999999997, -3641.429, -3644.765, -3647.8579999999997, -3650.704, -3653.3, -3655.6440000000002, -3657.7309999999998, -3659.559, -3661.125, -3662.4240000000004, -3663.454, -3664.212, -3664.6929999999998, -3664.8940000000002, -3664.8109999999997, -3664.441, -3663.7790000000005, -3662.822, -3661.566, -3660.006, -3658.138, -3655.958, -3653.461, -3650.6440000000002, -3647.5, -3644.026, -3640.217, -3636.0679999999998, -3631.573, -3626.728, -3621.526, -3615.9640000000004, -3610.034, -3603.732, -3597.051, -3589.985, -3582.5290000000005, -3574.675, -3566.417, -3557.7490000000003, -3548.664, -3539.155, -3529.2140000000004, -3518.835, -3508.008, -3496.7270000000003, -3484.9840000000004, -3472.7690000000002, -3460.0759999999996, -3446.8940000000002, -3433.2140000000004, -3419.028, -3404.3259999999996, -3389.098, -3373.3340000000003, -3357.0229999999997, -3340.1540000000005, -3322.717, -3304.7, -3286.09, -3266.8759999999997, -3247.046, -3226.585, -3205.4809999999998, -3183.72, -3161.2870000000003, -3138.167, -3114.345, -3089.8059999999996, -3064.533, -3038.508, -3011.715, -2984.135, -2955.75, -2926.539, -2896.4829999999997, -2865.56, -2833.75, -2801.03, -2767.3759999999997, -2732.765, -2697.172, -2660.571, -2622.935, -2584.237, -2544.448, -2503.54, -2461.482, -2418.241, -2373.786, -2328.084, -2281.099, -2232.797, -2183.1420000000003, -2132.096, -2079.621, -2025.6789999999999, -1970.2320000000002, -1913.239, -1854.662, -1794.4620000000002, -1732.599, -1669.036, -1603.737, -1536.668, -1467.796, -1397.096, -1324.545, -1250.125, -1173.827, -1095.651, -1015.607, -933.7189999999999, -850.0239999999999, -764.578, -677.459, -588.764, -498.615, -407.163, -314.586, -221.09400000000002, -126.92299999999999, -32.342, 62.357, 156.858, 250.829, 343.926, 435.80300000000005, 526.119, 614.549, 700.785, 784.553, 865.61, 943.752, 1018.814, 1090.672, 1159.241, 1224.473, 1286.3519999999999, 1344.889, 1400.124, 1452.114, 1500.934, 1546.674, 1589.4279999999999, 1629.3020000000001, 1666.4029999999998, 1700.844, 1732.733, 1762.182, 1789.2979999999998, 1814.1879999999999, 1836.953, 1857.695, 1876.506, 1893.479, 1908.701, 1922.254, 1934.217, 1944.6660000000002, 1953.672, 1961.3010000000002, 1967.5439999999999, 1972.685, 1976.558, 1979.2920000000001, 1980.9370000000001, 1981.5420000000001, 1981.155, 1979.818, 1977.5720000000001, 1974.457, 1970.511, 1965.7679999999998, 1960.261, 1954.023, 1947.0829999999999, 1939.471, 1931.2120000000002, 1922.335, 1912.8629999999998, 1902.818, 1892.225, 1881.104, 1869.474, 1857.3570000000002, 1844.769, 1831.73, 1818.254, 1804.36, 1790.0610000000001, 1775.374, 1760.3110000000001, 1744.886, 1729.1129999999998, 1713.004, 1696.5710000000001, 1679.8239999999998, 1662.776, 1645.4360000000001, 1627.815, 1609.922, 1591.7679999999998, 1573.36, 1554.707, 1535.819, 1516.7020000000002, 1497.365, 1477.815, 1458.06, 1438.106, 1417.9589999999998, 1397.628, 1377.1170000000002, 1356.432, 1335.5810000000001, 1314.568, 1293.3980000000001, 1272.078, 1250.612, 1229.005, 1207.263, 1185.389, 1163.388, 1141.264, 1119.0230000000001, 1096.6680000000001, 1074.202, 1051.631, 1028.9569999999999, 1006.185, 983.317, 960.3580000000001, 937.311, 914.178, 890.9639999999999, 867.672, 844.304, 820.863, 797.352, 773.775, 750.133, 726.43, 702.6669999999999, 678.8489999999999, 654.976, 631.052, 607.0790000000001, 583.058, 558.994, 534.886, 510.73900000000003, 486.55300000000005, 462.33099999999996, 438.07599999999996, 413.788, 389.469, 365.12300000000005, 340.75, 316.35200000000003, 291.931, 267.48900000000003, 243.028, 218.549, 194.054, 169.544, 145.02100000000002, 120.48700000000001, 95.943, 71.39, 46.831, 22.266, -2.3040000000000003, -26.875, -51.449, -76.02199999999999, -100.594, -125.163, -149.72899999999998, -174.28900000000002, -198.843, -223.389, -247.92700000000002, -272.454, -296.971, -321.475, -345.965, -370.441, -394.902, -419.345, -443.77099999999996, -468.17800000000005, -492.564, -516.93, -541.274, -565.595, -589.891, -614.163, -638.408, -662.627, -686.818, -710.9789999999999, -735.1110000000001, -759.2130000000001, -783.2819999999999, -807.319, -831.322, -855.291, -879.225, -903.122, -926.9830000000001, -950.804, -974.5880000000001, -998.332, -1022.0360000000001, -1045.698, -1069.318, -1092.895, -1116.4289999999999, -1139.917, -1163.361, -1186.758, -1210.107, -1233.41, -1256.663, -1279.867, -1303.02, -1326.1229999999998, -1349.174, -1372.172, -1395.116, -1418.007, -1440.8429999999998, -1463.622, -1486.346, -1509.0120000000002, -1531.62, -1554.1689999999999, -1576.6589999999999, -1599.088, -1621.4560000000001, -1643.763, -1666.006, -1688.1870000000001, -1710.3029999999999, -1732.354, -1754.34, -1776.26, -1798.112, -1819.896, -1841.611, -1863.2579999999998, -1884.8339999999998, -1906.338, -1927.7720000000002, -1949.132, -1970.42, -1991.6329999999998, -2012.7720000000002, -2033.835, -2054.822, -2075.731, -2096.563, -2117.3160000000003, -2137.99, -2158.583, -2179.095, -2199.526, -2219.874, -2240.138, -2260.3179999999998, -2280.4139999999998, -2300.423, -2320.346, -2340.1820000000002, -2359.929, -2379.587, -2399.155, -2418.632, -2438.018, -2457.312, -2476.512, -2495.618, -2514.629, -2533.544, -2552.363, -2571.084, -2589.706, -2608.229, -2626.652, -2644.974, -2663.1940000000004, -2681.3109999999997, -2699.323, -2717.232, -2735.034, -2752.73, -2770.3179999999998, -2787.797, -2805.167, -2822.426, -2839.574, -2856.6090000000004, -2873.531, -2890.3379999999997, -2907.03, -2923.605, -2940.063, -2956.402, -2972.6209999999996, -2988.719, -3004.696, -3020.55, -3036.2790000000005, -3051.883, -3067.361, -3082.712, -3097.934, -3113.026, -3127.988, -3142.817, -3157.513, -3172.074, -3186.4990000000003, -3200.788, -3214.938, -3228.949, -3242.8179999999998, -3256.546, -3270.13, -3283.5690000000004, -3296.862, -3310.008, -3323.005, -3335.8509999999997, -3348.545, -3361.087, -3373.473, -3385.704, -3397.776, -3409.69, -3421.4429999999998, -3433.033, -3444.46, -3455.7209999999995, -3466.815, -3477.74, -3488.494, -3499.077, -3509.485, -3519.718, -3529.7729999999997, -3539.6490000000003, -3549.344, -3558.8559999999998, -3568.183, -3577.323, -3586.275, -3595.0359999999996, -3603.6040000000003, -3611.9770000000003, -3620.153, -3628.131, -3635.907, -3643.48, -3650.847, -3658.006, -3664.9559999999997, -3671.6929999999998, -3678.215, -3684.5190000000002, -3690.6040000000003, -3696.467, -3702.105, -3707.5159999999996, -3712.696, -3717.6440000000002, -3722.3559999999998, -3726.83, -3731.063, -3735.052, -3738.7929999999997, -3742.285, -3745.5240000000003, -3748.506, -3751.2290000000003, -3753.69, -3755.884, -3757.809, -3759.461, -3760.837, -3761.933, -3762.745, -3763.27, -3763.5029999999997, -3763.441, -3763.08, -3762.4159999999997, -3761.445, -3760.1609999999996, -3758.562, -3756.6420000000003, -3754.3959999999997, -3751.821, -3748.9120000000003, -3745.663, -3742.0690000000004, -3738.1259999999997, -3733.828, -3729.1690000000003, -3724.145, -3718.75, -3712.9770000000003, -3706.821, -3700.276, -3693.336, -3685.993, -3678.242, -3670.0759999999996, -3661.489, -3652.4709999999995, -3643.018, -3633.12, -3622.7709999999997, -3611.962, -3600.6859999999997, -3588.934, -3576.697, -3563.967, -3550.735, -3536.99, -3522.725, -3507.927, -3492.5890000000004, -3476.698, -3460.244, -3443.216, -3425.6020000000003, -3407.3909999999996, -3388.57, -3369.1259999999997, -3349.047, -3328.3190000000004, -3306.927, -3284.8590000000004, -3262.098, -3238.6290000000004, -3214.437, -3189.505, -3163.816, -3137.353, -3110.097, -3082.0290000000005, -3053.13, -3023.38, -2992.757, -2961.24, -2928.808, -2895.437, -2861.1009999999997, -2825.778, -2789.441, -2752.062, -2713.616, -2674.072, -2633.401, -2591.574, -2548.5570000000002, -2504.319, -2458.825, -2412.042, -2363.9320000000002, -2314.46, -2263.587, -2211.275, -2157.485, -2102.176, -2045.308, -1986.839, -1926.7279999999998, -1864.934, -1801.4160000000002, -1736.134, -1669.0510000000002, -1600.13, -1529.336, -1456.642, -1382.023, -1305.458, -1226.938, -1146.4589999999998, -1064.031, -979.676, -893.43, -805.35, -715.51, -624.009, -530.972, -436.551, -340.92900000000003, -244.31599999999997, -146.957, -49.123999999999995, 48.88, 146.732, 244.08900000000003, 340.596, 435.897, 529.637, 621.476, 711.0980000000001, 798.2139999999999, 882.57, 963.95, 1042.182, 1117.131, 1188.7060000000001, 1256.854, 1321.5529999999999, 1382.8139999999999, 1440.671, 1495.184, 1546.424, 1594.484, 1639.46, 1681.4579999999999, 1720.588, 1756.964, 1790.6989999999998, 1821.905, 1850.695, 1877.1770000000001, 1901.4560000000001, 1923.635, 1943.8120000000001, 1962.079, 1978.5279999999998, 1993.244, 2006.308, 2017.7979999999998, 2027.787, 2036.346, 2043.54, 2049.4320000000002, 2054.081, 2057.544, 2059.874, 2061.121, 2061.333, 2060.556, 2058.831, 2056.2, 2052.702, 2048.3720000000003, 2043.246, 2037.356, 2030.734, 2023.4089999999999, 2015.41, 2006.763, 1997.494, 1987.6270000000002, 1977.1860000000001, 1966.192, 1954.6670000000001, 1942.631, 1930.1029999999998, 1917.102, 1903.6429999999998, 1889.746, 1875.425, 1860.6960000000001, 1845.5729999999999, 1830.0710000000001, 1814.203, 1797.9820000000002, 1781.42, 1764.529, 1747.3210000000001, 1729.806, 1711.996, 1693.9, 1675.527, 1656.889, 1637.9920000000002, 1618.8470000000002, 1599.461, 1579.842, 1559.999, 1539.9389999999999, 1519.6689999999999, 1499.1960000000001, 1478.526, 1457.6670000000001, 1436.625, 1415.405, 1394.014, 1372.4579999999999, 1350.741, 1328.87, 1306.849, 1284.683, 1262.378, 1239.938, 1217.368, 1194.671, 1171.853, 1148.9180000000001, 1125.869, 1102.71, 1079.447, 1056.0810000000001, 1032.617, 1009.058, 985.408, 961.67, 937.847, 913.943, 889.96, 865.9019999999999, 841.7719999999999, 817.571, 793.304, 768.9730000000001, 744.58, 720.128, 695.62, 671.057, 646.443, 621.78, 597.071, 572.316, 547.519, 522.682, 497.806, 472.894, 447.94800000000004, 422.97, 397.962, 372.925, 347.86199999999997, 322.774, 297.664, 272.532, 247.38, 222.21099999999998, 197.02599999999998, 171.826, 146.613, 121.389, 96.155, 70.91199999999999, 45.663000000000004, 20.408, -4.85, -30.112, -55.373999999999995, -80.63600000000001, -105.897, -131.155, -156.409, -181.658, -206.9, -232.13400000000001, -257.358, -282.573, -307.776, -332.967, -358.14300000000003, -383.305, -408.45, -433.579, -458.689, -483.78, -508.85, -533.899, -558.925, -583.927, -608.905, -633.8580000000001, -658.783, -683.682, -708.551, -733.3910000000001, -758.201, -782.9780000000001, -807.7239999999999, -832.436, -857.1139999999999, -881.757, -906.363, -930.933, -955.4639999999999, -979.957, -1004.41, -1028.823, -1053.194, -1077.522, -1101.808, -1126.049, -1150.246, -1174.397, -1198.501, -1222.558, -1246.567, -1270.526, -1294.4360000000001, -1318.295, -1342.102, -1365.8570000000002, -1389.559, -1413.207, -1436.8, -1460.338, -1483.819, -1507.243, -1530.609, -1553.9160000000002, -1577.1629999999998, -1600.351, -1623.477, -1646.5410000000002, -1669.5420000000001, -1692.48, -1715.354, -1738.162, -1760.905, -1783.58, -1806.1889999999999, -1828.729, -1851.2, -1873.601, -1895.932, -1918.191, -1940.378, -1962.4920000000002, -1984.5320000000002, -2006.497, -2028.388, -2050.202, -2071.938, -2093.598, -2115.178, -2136.679, -2158.1, -2179.44, -2200.698, -2221.873, -2242.965, -2263.973, -2284.895, -2305.732, -2326.481, -2347.143, -2367.717, -2388.201, -2408.595, -2428.897, -2449.1079999999997, -2469.2270000000003, -2489.251, -2509.181, -2529.016, -2548.754, -2568.395, -2587.938, -2607.382, -2626.7259999999997, -2645.969, -2665.111, -2684.15, -2703.085, -2721.9159999999997, -2740.6409999999996, -2759.26, -2777.7709999999997, -2796.1740000000004, -2814.468, -2832.651, -2850.723, -2868.6820000000002, -2886.528, -2904.26, -2921.8759999999997, -2939.3759999999997, -2956.758, -2974.0209999999997, -2991.165, -3008.188, -3025.09, -3041.868, -3058.522, -3075.051, -3091.454, -3107.7290000000003, -3123.875, -3139.8920000000003, -3155.777, -3171.531, -3187.151, -3202.636, -3217.985, -3233.197, -3248.2709999999997, -3263.205, -3277.998, -3292.6490000000003, -3307.156, -3321.518, -3335.7329999999997, -3349.801, -3363.72, -3377.488, -3391.1040000000003, -3404.567, -3417.8740000000003, -3431.026, -3444.0190000000002, -3456.853, -3469.526, -3482.0359999999996, -3494.382, -3506.562, -3518.575, -3530.4190000000003, -3542.092, -3553.592, -3564.9190000000003, -3576.0690000000004, -3587.0409999999997, -3597.8340000000003, -3608.446, -3618.8740000000003, -3629.117, -3639.172, -3649.039, -3658.715, -3668.198, -3677.485, -3686.5759999999996, -3695.467, -3704.157, -3712.643, -3720.923, -3728.9959999999996, -3736.8579999999997, -3744.507, -3751.941, -3759.157, -3766.1540000000005, -3772.928, -3779.4770000000003, -3785.7990000000004, -3791.8909999999996, -3797.7490000000003, -3803.3720000000003, -3808.757, -3813.9, -3818.7990000000004, -3823.4509999999996, -3827.853, -3832.002, -3835.895, -3839.5290000000005, -3842.9, -3846.005, -3848.841, -3851.4040000000005, -3853.691, -3855.698, -3857.422, -3858.8590000000004, -3860.005, -3860.8559999999998, -3861.408, -3861.658, -3861.6009999999997, -3861.2329999999997, -3860.5490000000004, -3859.545, -3858.218, -3856.5609999999997, -3854.57, -3852.242, -3849.5690000000004, -3846.5490000000004, -3843.1740000000004, -3839.441, -3835.344, -3830.8759999999997, -3826.033, -3820.809, -3815.197, -3809.192, -3802.7870000000003, -3795.9770000000003, -3788.7529999999997, -3781.11, -3773.04, -3764.5370000000003, -3755.592, -3746.2, -3736.35, -3726.0370000000003, -3715.252, -3703.986, -3692.2309999999998, -3679.978, -3667.217, -3653.94, -3640.137, -3625.797, -3610.9109999999996, -3595.468, -3579.4570000000003, -3562.867, -3545.6859999999997, -3527.903, -3509.505, -3490.4790000000003, -3470.813, -3450.493, -3429.5040000000004, -3407.8340000000003, -3385.465, -3362.385, -3338.575, -3314.0209999999997, -3288.704, -3262.6079999999997, -3235.715, -3208.0040000000004, -3179.458, -3150.055, -3119.775, -3088.5959999999995, -3056.4959999999996, -3023.452, -2989.4390000000003, -2954.433, -2918.408, -2881.3379999999997, -2843.1929999999998, -2803.947, -2763.5690000000004, -2722.028, -2679.2929999999997, -2635.3309999999997, -2590.1079999999997, -2543.589, -2495.738, -2446.5170000000003, -2395.888, -2343.813, -2290.25, -2235.159, -2178.498, -2120.224, -2060.295, -1998.6660000000002, -1935.295, -1870.139, -1803.1570000000002, -1734.307, -1663.5510000000002, -1590.855, -1516.1860000000001, -1439.5179999999998, -1360.829, -1280.105, -1197.344, -1112.553, -1025.751, -936.975, -846.28, -753.74, -659.456, -563.553, -466.185, -367.536, -267.823, -167.295, -66.23100000000001, 35.061, 136.247, 236.975, 336.879, 435.59, 532.741, 627.982, 720.9810000000001, 811.438, 899.087, 983.702, 1065.1, 1143.14, 1217.722, 1288.785, 1356.307, 1420.293, 1480.777, 1537.815, 1591.4820000000002, 1641.8670000000002, 1689.069, 1733.1970000000001, 1774.362, 1812.681, 1848.2679999999998, 1881.24, 1911.7089999999998, 1939.7910000000002, 1965.5910000000001, 1989.215, 2010.763, 2030.3339999999998, 2048.018, 2063.904, 2078.076, 2090.615, 2101.596, 2111.09, 2119.1679999999997, 2125.893, 2131.327, 2135.527, 2138.55, 2140.446, 2141.265, 2141.055, 2139.859, 2137.72, 2134.677, 2130.769, 2126.031, 2120.496, 2114.199, 2107.169, 2099.436, 2091.027, 2081.969, 2072.2870000000003, 2062.005, 2051.147, 2039.734, 2027.787, 2015.325, 2002.369, 1988.935, 1975.0420000000001, 1960.705, 1945.942, 1930.766, 1915.194, 1899.237, 1882.911, 1866.2279999999998, 1849.2, 1831.839, 1814.1570000000002, 1796.164, 1777.871, 1759.2879999999998, 1740.425, 1721.2920000000001, 1701.896, 1682.2479999999998, 1662.355, 1642.225, 1621.8670000000002, 1601.287, 1580.494, 1559.493, 1538.293, 1516.899, 1495.318, 1473.556, 1451.619, 1429.5120000000002, 1407.2420000000002, 1384.8129999999999, 1362.231, 1339.501, 1316.628, 1293.617, 1270.472, 1247.197, 1223.798, 1200.278, 1176.641, 1152.892, 1129.0339999999999, 1105.0710000000001, 1081.007, 1056.845, 1032.589, 1008.242, 983.808, 959.29, 934.69, 910.012, 885.2589999999999, 860.433, 835.539, 810.577, 785.552, 760.465, 735.32, 710.118, 684.863, 659.556, 634.2, 608.797, 583.35, 557.86, 532.33, 506.76199999999994, 481.158, 455.52, 429.85, 404.15, 378.421, 352.666, 326.887, 301.085, 275.26099999999997, 249.419, 223.55900000000003, 197.68200000000002, 171.792, 145.888, 119.97399999999999, 94.05, 68.117, 42.178000000000004, 16.234, -9.714, -35.664, -61.615, -87.566, -113.515, -139.461, -165.40200000000002, -191.338, -217.266, -243.18599999999998, -269.097, -294.997, -320.88599999999997, -346.76099999999997, -372.621, -398.467, -424.296, -450.10699999999997, -475.899, -501.671, -527.422, -553.151, -578.857, -604.539, -630.195, -655.825, -681.428, -707.002, -732.547, -758.062, -783.545, -808.997, -834.414, -859.798, -885.1460000000001, -910.459, -935.7339999999999, -960.971, -986.17, -1011.328, -1036.4460000000001, -1061.522, -1086.556, -1111.546, -1136.492, -1161.393, -1186.248, -1211.056, -1235.816, -1260.527, -1285.1889999999999, -1309.8010000000002, -1334.361, -1358.87, -1383.325, -1407.727, -1432.0739999999998, -1456.365, -1480.601, -1504.779, -1528.9, -1552.961, -1576.963, -1600.905, -1624.786, -1648.604, -1672.36, -1696.0520000000001, -1719.6789999999999, -1743.2420000000002, -1766.7379999999998, -1790.1670000000001, -1813.5279999999998, -1836.8210000000001, -1860.045, -1883.1979999999999, -1906.28, -1929.29, -1952.2279999999998, -1975.092, -1997.882, -2020.5970000000002, -2043.235, -2065.797, -2088.282, -2110.688, -2133.014, -2155.261, -2177.426, -2199.51, -2221.511, -2243.429, -2265.262, -2287.01, -2308.672, -2330.2470000000003, -2351.734, -2373.133, -2394.442, -2415.66, -2436.788, -2457.823, -2478.765, -2499.613, -2520.367, -2541.024, -2561.585, -2582.049, -2602.413, -2622.679, -2642.844, -2662.908, -2682.869, -2702.7270000000003, -2722.482, -2742.131, -2761.673, -2781.1090000000004, -2800.437, -2819.656, -2838.764, -2857.762, -2876.647, -2895.4190000000003, -2914.077, -2932.62, -2951.046, -2969.355, -2987.546, -3005.617, -3023.5679999999998, -3041.397, -3059.103, -3076.685, -3094.1420000000003, -3111.472, -3128.675, -3145.75, -3162.695, -3179.509, -3196.19, -3212.739, -3229.152, -3245.43, -3261.571, -3277.573, -3293.435, -3309.156, -3324.735, -3340.17, -3355.46, -3370.6040000000003, -3385.6, -3400.446, -3415.1420000000003, -3429.6859999999997, -3444.077, -3458.312, -3472.39, -3486.3109999999997, -3500.072, -3513.672, -3527.1090000000004, -3540.382, -3553.489, -3566.429, -3579.199, -3591.798, -3604.225, -3616.4770000000003, -3628.553, -3640.4509999999996, -3652.17, -3663.7070000000003, -3675.06, -3686.228, -3697.2090000000003, -3708.0009999999997, -3718.6009999999997, -3729.009, -3739.2209999999995, -3749.235, -3759.051, -3768.664, -3778.075, -3787.2790000000005, -3796.275, -3805.0609999999997, -3813.633, -3821.991, -3830.131, -3838.052, -3845.7490000000003, -3853.222, -3860.467, -3867.482, -3874.264, -3880.8109999999997, -3887.119, -3893.1859999999997, -3899.01, -3904.586, -3909.9120000000003, -3914.986, -3919.804, -3924.362, -3928.658, -3932.6890000000003, -3936.4509999999996, -3939.94, -3943.1540000000005, -3946.0890000000004, -3948.74, -3951.105, -3953.18, -3954.961, -3956.4440000000004, -3957.6240000000003, -3958.4990000000003, -3959.063, -3959.313, -3959.244, -3958.8520000000003, -3958.132, -3957.079, -3955.6890000000003, -3953.9570000000003, -3951.8779999999997, -3949.447, -3946.659, -3943.508, -3939.989, -3936.097, -3931.824, -3927.167, -3922.119, -3916.673, -3910.823, -3904.5640000000003, -3897.887, -3890.7870000000003, -3883.257, -3875.288, -3866.875, -3858.009, -3848.683, -3838.888, -3828.616, -3817.86, -3806.611, -3794.8590000000004, -3782.595, -3769.8109999999997, -3756.4959999999996, -3742.64, -3728.2329999999997, -3713.265, -3697.725, -3681.6009999999997, -3664.882, -3647.5570000000002, -3629.611, -3611.034, -3591.812, -3571.9320000000002, -3551.3790000000004, -3530.139, -3508.197, -3485.538, -3462.147, -3438.006, -3413.098, -3387.407, -3360.914, -3333.6, -3305.446, -3276.4309999999996, -3246.535, -3215.735, -3184.012, -3151.3390000000004, -3117.695, -3083.053, -3047.389, -3010.675, -2972.883, -2933.986, -2893.954, -2852.755, -2810.3579999999997, -2766.73, -2721.837, -2675.6440000000002, -2628.115, -2579.2110000000002, -2528.895, -2477.126, -2423.865, -2369.069, -2312.695, -2254.699, -2195.038, -2133.667, -2070.5389999999998, -2005.611, -1938.838, -1870.175, -1799.58, -1727.0120000000002, -1652.435, -1575.8129999999999, -1497.119, -1416.328, -1333.4260000000002, -1248.407, -1161.276, -1072.052, -980.77, -887.485, -792.2719999999999, -695.23, -596.485, -496.19300000000004, -394.542, -291.751, -188.076, -83.8, 20.76, 125.262, 229.345, 332.631, 434.73900000000003, 535.2919999999999, 633.9259999999999, 730.296, 824.09, 915.028, 1002.878, 1087.443, 1168.575, 1246.167, 1320.1529999999998, 1390.5020000000002, 1457.221, 1520.339, 1579.911, 1636.0120000000002, 1688.7320000000002, 1738.17, 1784.4370000000001, 1827.6470000000002, 1867.9170000000001, 1905.3670000000002, 1940.114, 1972.275, 2001.965, 2029.296, 2054.375, 2077.305, 2098.188, 2117.116, 2134.183, 2149.473, 2163.07, 2175.053, 2185.493, 2194.45, 2202.031, 2208.258, 2213.205, 2216.929, 2219.4829999999997, 2220.919, 2221.285, 2220.627, 2218.988, 2216.409, 2212.93, 2208.5879999999997, 2203.419, 2197.4539999999997, 2190.7270000000003, 2183.268, 2175.106, 2166.2670000000003, 2156.779, 2146.665, 2135.95, 2124.656, 2112.806, 2100.419, 2087.516, 2074.114, 2060.2329999999997, 2045.889, 2031.099, 2015.878, 2000.2420000000002, 1984.205, 1967.7820000000002, 1950.985, 1933.8270000000002, 1916.3210000000001, 1898.4779999999998, 1880.31, 1861.828, 1843.0420000000001, 1823.9620000000002, 1804.598, 1784.96, 1765.056, 1744.896, 1724.487, 1703.8370000000002, 1682.955, 1661.849, 1640.524, 1618.99, 1597.251, 1575.315, 1553.1889999999999, 1530.878, 1508.388, 1485.726, 1462.896, 1439.905, 1416.757, 1393.457, 1370.0120000000002, 1346.424, 1322.7, 1298.843, 1274.859, 1250.75, 1226.522, 1202.178, 1177.723, 1153.16, 1128.493, 1103.725, 1078.86, 1053.902, 1028.854, 1003.7189999999999, 978.5, 953.2, 927.823, 902.3710000000001, 876.847, 851.2539999999999, 825.595, 799.873, 774.0889999999999, 748.247, 722.3489999999999, 696.3969999999999, 670.395, 644.3430000000001, 618.246, 592.1030000000001, 565.919, 539.695, 513.433, 487.135, 460.80300000000005, 434.44, 408.046, 381.625, 355.17699999999996, 328.70599999999996, 302.211, 275.69599999999997, 249.162, 222.61, 196.043, 169.46200000000002, 142.868, 116.26299999999999, 89.649, 63.028, 36.399, 9.767000000000001, -16.87, -43.508, -70.14699999999999, -96.785, -123.42, -150.053, -176.68, -203.301, -229.91400000000002, -256.519, -283.11400000000003, -309.698, -336.269, -362.82599999999996, -389.369, -415.895, -442.404, -468.895, -495.36699999999996, -521.818, -548.247, -574.653, -601.035, -627.393, -653.724, -680.028, -706.305, -732.552, -758.768, -784.954, -811.107, -837.227, -863.313, -889.3639999999999, -915.3789999999999, -941.3560000000001, -967.296, -993.196, -1019.057, -1044.876, -1070.654, -1096.389, -1122.08, -1147.7269999999999, -1173.328, -1198.883, -1224.39, -1249.85, -1275.26, -1300.62, -1325.93, -1351.1870000000001, -1376.3929999999998, -1401.5439999999999, -1426.641, -1451.683, -1476.6689999999999, -1501.598, -1526.47, -1551.2820000000002, -1576.035, -1600.7279999999998, -1625.359, -1649.9279999999999, -1674.435, -1698.878, -1723.256, -1747.568, -1771.8139999999999, -1795.993, -1820.105, -1844.1470000000002, -1868.119, -1892.021, -1915.852, -1939.61, -1963.295, -1986.9070000000002, -2010.443, -2033.904, -2057.288, -2080.595, -2103.824, -2126.974, -2150.0429999999997, -2173.032, -2195.94, -2218.764, -2241.505, -2264.1620000000003, -2286.734, -2309.22, -2331.619, -2353.93, -2376.152, -2398.285, -2420.327, -2442.278, -2464.136, -2485.901, -2507.572, -2529.1479999999997, -2550.6279999999997, -2572.011, -2593.2960000000003, -2614.482, -2635.5679999999998, -2656.554, -2677.438, -2698.219, -2718.897, -2739.469, -2759.937, -2780.297, -2800.55, -2820.695, -2840.73, -2860.6540000000005, -2880.466, -2900.165, -2919.7509999999997, -2939.222, -2958.577, -2977.8140000000003, -2996.934, -3015.935, -3034.815, -3053.573, -3072.2090000000003, -3090.722, -3109.1090000000004, -3127.37, -3145.505, -3163.51, -3181.387, -3199.132, -3216.745, -3234.2259999999997, -3251.571, -3268.781, -3285.8540000000003, -3302.788, -3319.583, -3336.237, -3352.7490000000003, -3369.117, -3385.3390000000004, -3401.4159999999997, -3417.345, -3433.125, -3448.7540000000004, -3464.2309999999998, -3479.554, -3494.723, -3509.735, -3524.5879999999997, -3539.283, -3553.816, -3568.187, -3582.393, -3596.433, -3610.3059999999996, -3624.01, -3637.542, -3650.902, -3664.0879999999997, -3677.0959999999995, -3689.928, -3702.58, -3715.05, -3727.337, -3739.4390000000003, -3751.353, -3763.078, -3774.612, -3785.953, -3797.099, -3808.047, -3818.797, -3829.344, -3839.688, -3849.8259999999996, -3859.756, -3869.4759999999997, -3878.9829999999997, -3888.275, -3897.349, -3906.204, -3914.836, -3923.243, -3931.4240000000004, -3939.3740000000003, -3947.091, -3954.573, -3961.8179999999998, -3968.821, -3975.58, -3982.094, -3988.357, -3994.368, -4000.1240000000003, -4005.6209999999996, -4010.8559999999998, -4015.8259999999996, -4020.527, -4024.9570000000003, -4029.112, -4032.988, -4036.5820000000003, -4039.8909999999996, -4042.909, -4045.635, -4048.063, -4050.191, -4052.013, -4053.526, -4054.725, -4055.607, -4056.167, -4056.4, -4056.303, -4055.869, -4055.095, -4053.9759999999997, -4052.506, -4050.6809999999996, -4048.495, -4045.942, -4043.0190000000002, -4039.718, -4036.034, -4031.961, -4027.494, -4022.6259999999997, -4017.35, -4011.66, -4005.55, -3999.013, -3992.0409999999997, -3984.6279999999997, -3976.7659999999996, -3968.448, -3959.6659999999997, -3950.4109999999996, -3940.676, -3930.452, -3919.7309999999998, -3908.5040000000004, -3896.761, -3884.493, -3871.69, -3858.343, -3844.442, -3829.975, -3814.9309999999996, -3799.3, -3783.071, -3766.23, -3748.7659999999996, -3730.6659999999997, -3711.917, -3692.506, -3672.4190000000003, -3651.6409999999996, -3630.157, -3607.953, -3585.012, -3561.3179999999998, -3536.8540000000003, -3511.6020000000003, -3485.545, -3458.664, -3430.9390000000003, -3402.35, -3372.8759999999997, -3342.4970000000003, -3311.19, -3278.9309999999996, -3245.697, -3211.4629999999997, -3176.203, -3139.8909999999996, -3102.4990000000003, -3063.9990000000003, -3024.361, -2983.554, -2941.547, -2898.3059999999996, -2853.798, -2807.988, -2760.8379999999997, -2712.312, -2662.3709999999996, -2610.974, -2558.081, -2503.6479999999997, -2447.634, -2389.992, -2330.679, -2269.647, -2206.85, -2142.242, -2075.774, -2007.401, -1937.076, -1864.755, -1790.394, -1713.955, -1635.401, -1554.701, -1471.83, -1386.77, -1299.513, -1210.0639999999999, -1118.44, -1024.6760000000002, -928.824, -830.959, -731.18, -629.615, -526.422, -421.791, -315.945, -209.142, -101.675, 6.132999999999999, 113.93299999999999, 221.352, 328.004, 433.495, 537.436, 639.45, 739.18, 836.301, 930.5239999999999, 1021.6010000000001, 1109.328, 1193.549, 1274.149, 1351.055, 1424.234, 1493.685, 1559.4379999999999, 1621.547, 1680.085, 1735.1429999999998, 1786.8220000000001, 1835.233, 1880.4920000000002, 1922.719, 1962.036, 1998.5639999999999, 2032.422, 2063.7270000000003, 2092.594, 2119.134, 2143.4539999999997, 2165.655, 2185.835, 2204.0879999999997, 2220.504, 2235.166, 2248.156, 2259.55, 2269.4210000000003, 2277.8379999999997, 2284.865, 2290.5660000000003, 2294.998, 2298.218, 2300.277, 2301.2270000000003, 2301.113, 2299.982, 2297.875, 2294.833, 2290.895, 2286.096, 2280.473, 2274.056, 2266.879, 2258.97, 2250.3579999999997, 2241.07, 2231.131, 2220.567, 2209.401, 2197.655, 2185.35, 2172.506, 2159.144, 2145.282, 2130.938, 2116.1279999999997, 2100.87, 2085.178, 2069.0679999999998, 2052.554, 2035.651, 2018.37, 2000.726, 1982.73, 1964.394, 1945.73, 1926.747, 1907.4579999999999, 1887.871, 1867.997, 1847.845, 1827.4229999999998, 1806.7420000000002, 1785.809, 1764.632, 1743.2179999999998, 1721.5770000000002, 1699.715, 1677.638, 1655.355, 1632.871, 1610.193, 1587.3270000000002, 1564.279, 1541.055, 1517.661, 1494.102, 1470.3829999999998, 1446.51, 1422.487, 1398.319, 1374.0120000000002, 1349.569, 1324.995, 1300.295, 1275.472, 1250.531, 1225.475, 1200.309, 1175.036, 1149.66, 1124.184, 1098.613, 1072.948, 1047.195, 1021.355, 995.432, 969.429, 943.3489999999999, 917.195, 890.97, 864.677, 838.317, 811.895, 785.4119999999999, 758.8710000000001, 732.275, 705.625, 678.925, 652.177, 625.382, 598.544, 571.663, 544.744, 517.7869999999999, 490.79400000000004, 463.76800000000003, 436.71, 409.62300000000005, 382.509, 355.369, 328.204, 301.018, 273.811, 246.58599999999998, 219.343, 192.085, 164.81400000000002, 137.531, 110.23700000000001, 82.934, 55.623999999999995, 28.308000000000003, 0.988, -26.335, -53.66, -80.985, -108.30799999999999, -135.629, -162.945, -190.25599999999997, -217.56, -244.857, -272.143, -299.42, -326.684, -353.935, -381.17199999999997, -408.39300000000003, -435.598, -462.784, -489.952, -517.099, -544.225, -571.3290000000001, -598.408, -625.464, -652.493, -679.495, -706.47, -733.415, -760.33, -787.2139999999999, -814.066, -840.885, -867.67, -894.419, -921.132, -947.808, -974.446, -1001.044, -1027.603, -1054.12, -1080.595, -1107.027, -1133.415, -1159.759, -1186.056, -1212.307, -1238.51, -1264.664, -1290.769, -1316.8229999999999, -1342.826, -1368.776, -1394.674, -1420.517, -1446.305, -1472.0379999999998, -1497.713, -1523.3310000000001, -1548.891, -1574.391, -1599.83, -1625.2089999999998, -1650.525, -1675.7779999999998, -1700.9679999999998, -1726.0929999999998, -1751.152, -1776.145, -1801.07, -1825.9270000000001, -1850.715, -1875.433, -1900.08, -1924.655, -1949.158, -1973.588, -1997.942, -2022.2220000000002, -2046.4260000000002, -2070.552, -2094.601, -2118.571, -2142.4610000000002, -2166.27, -2189.999, -2213.644, -2237.2070000000003, -2260.685, -2284.078, -2307.386, -2330.606, -2353.739, -2376.783, -2399.737, -2422.601, -2445.373, -2468.053, -2490.64, -2513.132, -2535.529, -2557.83, -2580.033, -2602.139, -2624.145, -2646.052, -2667.857, -2689.56, -2711.1609999999996, -2732.657, -2754.048, -2775.333, -2796.511, -2817.5809999999997, -2838.542, -2859.393, -2880.132, -2900.76, -2921.2740000000003, -2941.673, -2961.9570000000003, -2982.1240000000003, -3002.1740000000004, -3022.105, -3041.9159999999997, -3061.6059999999998, -3081.173, -3100.618, -3119.937, -3139.131, -3158.199, -3177.138, -3195.948, -3214.627, -3233.1740000000004, -3251.5890000000004, -3269.87, -3288.014, -3306.0229999999997, -3323.893, -3341.623, -3359.2129999999997, -3376.6609999999996, -3393.966, -3411.125, -3428.139, -3445.005, -3461.722, -3478.288, -3494.703, -3510.9640000000004, -3527.071, -3543.0209999999997, -3558.813, -3574.446, -3589.9179999999997, -3605.2270000000003, -3620.373, -3635.3520000000003, -3650.164, -3664.8070000000002, -3679.2790000000005, -3693.579, -3707.705, -3721.6540000000005, -3735.426, -3749.018, -3762.429, -3775.656, -3788.699, -3801.554, -3814.22, -3826.696, -3838.978, -3851.066, -3862.9559999999997, -3874.647, -3886.137, -3897.423, -3908.5040000000004, -3919.377, -3930.04, -3940.49, -3950.7259999999997, -3960.744, -3970.5429999999997, -3980.12, -3989.472, -3998.598, -4007.493, -4016.157, -4024.585, -4032.776, -4040.7270000000003, -4048.435, -4055.8959999999997, -4063.1079999999997, -4070.0690000000004, -4076.7740000000003, -4083.222, -4089.408, -4095.33, -4100.984, -4106.367, -4111.476, -4116.308, -4120.858, -4125.123, -4129.099, -4132.782999999999, -4136.1720000000005, -4139.26, -4142.044, -4144.52, -4146.685, -4148.532999999999, -4150.06, -4151.262, -4152.135, -4152.674, -4152.874, -4152.73, -4152.238, -4151.392, -4150.188, -4148.62, -4146.682, -4144.37, -4141.677, -4138.598, -4135.127, -4131.258, -4126.984, -4122.3, -4117.1990000000005, -4111.674, -4105.718, -4099.3240000000005, -4092.486, -4085.195, -4077.445, -4069.2259999999997, -4060.533, -4051.355, -4041.685, -4031.514, -4020.833, -4009.633, -3997.905, -3985.639, -3972.825, -3959.452, -3945.511, -3930.989, -3915.877, -3900.163, -3883.8340000000003, -3866.8779999999997, -3849.283, -3831.0359999999996, -3812.123, -3792.531, -3772.244, -3751.2490000000003, -3729.53, -3707.071, -3683.8559999999998, -3659.868, -3635.09, -3609.5040000000004, -3583.09, -3555.83, -3527.703, -3498.69, -3468.768, -3437.915, -3406.11, -3373.3259999999996, -3339.5409999999997, -3304.7290000000003, -3268.862, -3231.915, -3193.857, -3154.66, -3114.2929999999997, -3072.724, -3029.922, -2985.8509999999997, -2940.4759999999997, -2893.762, -2845.67, -2796.1620000000003, -2745.197, -2692.735, -2638.732, -2583.145, -2525.928, -2467.036, -2406.4210000000003, -2344.036, -2279.8320000000003, -2213.76, -2145.772, -2075.8179999999998, -2003.85, -1929.8229999999999, -1853.69, -1775.41, -1694.944, -1612.26, -1527.33, -1440.135, -1350.664, -1258.921, -1164.921, -1068.698, -970.302, -869.809, -767.319, -662.959, -556.889, -449.301, -340.423, -230.517, -119.881, -8.846, 102.23100000000001, 212.968, 322.968, 431.82599999999996, 539.141, 644.521, 747.6, 848.039, 945.5369999999999, 1039.836, 1130.721, 1218.027, 1301.632, 1381.457, 1457.464, 1529.65, 1598.04, 1662.6879999999999, 1723.6670000000001, 1781.066, 1834.99, 1885.549, 1932.8629999999998, 1977.0529999999999, 2018.244, 2056.558, 2092.119, 2125.0460000000003, 2155.4570000000003, 2183.465, 2209.18, 2232.706, 2254.145, 2273.593, 2291.14, 2306.875, 2320.88, 2333.235, 2344.014, 2353.2870000000003, 2361.123, 2367.585, 2372.734, 2376.626, 2379.317, 2380.857, 2381.2960000000003, 2380.68, 2379.052, 2376.455, 2372.928, 2368.509, 2363.2329999999997, 2357.135, 2350.2470000000003, 2342.599, 2334.221, 2325.141, 2315.386, 2304.98, 2293.948, 2282.313, 2270.098, 2257.322, 2244.007, 2230.172, 2215.835, 2201.013, 2185.724, 2169.984, 2153.8089999999997, 2137.212, 2120.209, 2102.814, 2085.0389999999998, 2066.897, 2048.4, 2029.5610000000001, 2010.39, 1990.898, 1971.095, 1950.993, 1930.599, 1909.925, 1888.9779999999998, 1867.7679999999998, 1846.3029999999999, 1824.5910000000001, 1802.639, 1780.457, 1758.05, 1735.425, 1712.5910000000001, 1689.5529999999999, 1666.318, 1642.892, 1619.281, 1595.491, 1571.527, 1547.396, 1523.102, 1498.65, 1474.046, 1449.295, 1424.401, 1399.369, 1374.203, 1348.9070000000002, 1323.487, 1297.9460000000001, 1272.287, 1246.516, 1220.635, 1194.649, 1168.5610000000001, 1142.374, 1116.0919999999999, 1089.719, 1063.257, 1036.7089999999998, 1010.08, 983.3710000000001, 956.586, 929.7280000000001, 902.8, 875.803, 848.742, 821.618, 794.434, 767.193, 739.8969999999999, 712.548, 685.15, 657.703, 630.211, 602.6759999999999, 575.099, 547.484, 519.831, 492.144, 464.423, 436.67199999999997, 408.892, 381.084, 353.251, 325.395, 297.518, 269.62, 241.704, 213.77200000000002, 185.825, 157.865, 129.893, 101.912, 73.922, 45.925, 17.923, -10.083, -38.091, -66.09899999999999, -94.10799999999999, -122.11399999999999, -150.11700000000002, -178.115, -206.107, -234.092, -262.068, -290.034, -317.988, -345.93, -373.858, -401.77099999999996, -429.667, -457.546, -485.407, -513.247, -541.066, -568.863, -596.637, -624.386, -652.11, -679.807, -707.475, -735.115, -762.725, -790.304, -817.8510000000001, -845.3639999999999, -872.8439999999999, -900.2869999999999, -927.695, -955.065, -982.3969999999999, -1009.69, -1036.942, -1064.152, -1091.3210000000001, -1118.4460000000001, -1145.527, -1172.562, -1199.5510000000002, -1226.493, -1253.387, -1280.232, -1307.027, -1333.77, -1360.4620000000002, -1387.101, -1413.6860000000001, -1440.2160000000001, -1466.691, -1493.109, -1519.469, -1545.771, -1572.014, -1598.1960000000001, -1624.318, -1650.3770000000002, -1676.3729999999998, -1702.306, -1728.1729999999998, -1753.975, -1779.71, -1805.378, -1830.977, -1856.507, -1881.967, -1907.355, -1932.672, -1957.915, -1983.085, -2008.18, -2033.1989999999998, -2058.1420000000003, -2083.007, -2107.7929999999997, -2132.501, -2157.1279999999997, -2181.674, -2206.138, -2230.519, -2254.8160000000003, -2279.028, -2303.154, -2327.194, -2351.146, -2375.009, -2398.783, -2422.466, -2446.058, -2469.558, -2492.964, -2516.275, -2539.492, -2562.612, -2585.635, -2608.5589999999997, -2631.385, -2654.11, -2676.7340000000004, -2699.255, -2721.673, -2743.987, -2766.196, -2788.298, -2810.2929999999997, -2832.18, -2853.9559999999997, -2875.623, -2897.177, -2918.619, -2939.947, -2961.1609999999996, -2982.258, -3003.238, -3024.099, -3044.842, -3065.4640000000004, -3085.9640000000004, -3106.341, -3126.594, -3146.722, -3166.724, -3186.598, -3206.343, -3225.958, -3245.441, -3264.7929999999997, -3284.01, -3303.092, -3322.038, -3340.8459999999995, -3359.515, -3378.0440000000003, -3396.4309999999996, -3414.675, -3432.775, -3450.728, -3468.535, -3486.1929999999998, -3503.7, -3521.0570000000002, -3538.26, -3555.308, -3572.2009999999996, -3588.9359999999997, -3605.512, -3621.927, -3638.18, -3654.2690000000002, -3670.1929999999998, -3685.95, -3701.5370000000003, -3716.955, -3732.2, -3747.2709999999997, -3762.1659999999997, -3776.884, -3791.423, -3805.781, -3819.955, -3833.945, -3847.748, -3861.362, -3874.7859999999996, -3888.0170000000003, -3901.053, -3913.893, -3926.534, -3938.974, -3951.211, -3963.242, -3975.066, -3986.6809999999996, -3998.083, -4009.2709999999997, -4020.242, -4030.994, -4041.525, -4051.8320000000003, -4061.9120000000003, -4071.763, -4081.382, -4090.7670000000003, -4099.915, -4108.8240000000005, -4117.4890000000005, -4125.91, -4134.082, -4142.003, -4149.669, -4157.079000000001, -4164.228, -4171.113, -4177.732, -4184.08, -4190.156, -4195.954000000001, -4201.473, -4206.707, -4211.654, -4216.311, -4220.6720000000005, -4224.734, -4228.495, -4231.948, -4235.090999999999, -4237.919, -4240.428, -4242.6140000000005, -4244.472, -4245.998, -4247.187, -4248.034000000001, -4248.535, -4248.685, -4248.478, -4247.909000000001, -4246.974, -4245.667, -4243.981, -4241.913, -4239.455, -4236.602, -4233.348, -4229.687, -4225.612, -4221.116, -4216.194, -4210.838, -4205.041, -4198.7970000000005, -4192.096, -4184.933, -4177.299, -4169.187, -4160.587, -4151.492, -4141.893, -4131.78, -4121.146, -4109.98, -4098.273, -4086.015, -4073.196, -4059.804, -4045.83, -4031.262, -4016.0879999999997, -4000.297, -3983.8759999999997, -3966.8140000000003, -3949.0959999999995, -3930.7090000000003, -3911.64, -3891.875, -3871.3979999999997, -3850.195, -3828.2490000000003, -3805.545, -3782.065, -3757.7929999999997, -3732.711, -3706.7990000000004, -3680.039, -3652.41, -3623.893, -3594.465, -3564.1059999999998, -3532.792, -3500.5, -3467.204, -3432.881, -3397.502, -3361.0409999999997, -3323.4709999999995, -3284.76, -3244.88, -3203.798, -3161.4829999999997, -3117.8990000000003, -3073.013, -3026.7870000000003, -2979.184, -2930.1659999999997, -2879.6929999999998, -2827.722, -2774.211, -2719.116, -2662.3920000000003, -2603.992, -2543.868, -2481.971, -2418.2529999999997, -2352.6620000000003, -2285.149, -2215.661, -2144.1479999999997, -2070.561, -1994.85, -1916.9679999999998, -1836.871, -1754.519, -1669.8770000000002, -1582.914, -1493.608, -1401.951, -1307.941, -1211.593, -1112.938, -1012.0269999999999, -908.934, -803.76, -696.632, -587.7130000000001, -477.195, -365.311, -252.328, -138.548, -24.308000000000003, 90.025, 204.06, 317.389, 429.598, 540.271, 649.007, 755.425, 859.174, 959.941, 1057.4569999999999, 1151.498, 1241.888, 1328.5, 1411.247, 1490.086, 1565.01, 1636.043, 1703.236, 1766.662, 1826.411, 1882.5870000000002, 1935.3029999999999, 1984.68, 2030.8410000000001, 2073.9139999999998, 2114.024, 2151.2960000000003, 2185.855, 2217.819, 2247.304, 2274.423, 2299.285, 2321.992, 2342.6420000000003, 2361.331, 2378.1479999999997, 2393.177, 2406.501, 2418.18, 2428.3360000000002, 2436.989, 2444.221, 2450.095, 2454.669, 2458.0, 2460.14, 2461.14, 2461.047, 2459.908, 2457.764, 2454.657, 2450.625, 2445.706, 2439.935, 2433.344, 2425.966, 2417.831, 2408.967, 2399.402, 2389.163, 2378.274, 2366.759, 2354.6420000000003, 2341.942, 2328.6820000000002, 2314.882, 2300.56, 2285.734, 2270.423, 2254.643, 2238.409, 2221.738, 2204.644, 2187.141, 2169.243, 2150.9629999999997, 2132.314, 2113.3070000000002, 2093.955, 2074.268, 2054.258, 2033.934, 2013.307, 1992.3870000000002, 1971.183, 1949.704, 1927.9579999999999, 1905.954, 1883.7, 1861.205, 1838.474, 1815.517, 1792.34, 1768.9489999999998, 1745.352, 1721.555, 1697.5639999999999, 1673.385, 1649.025, 1624.4879999999998, 1599.78, 1574.908, 1549.875, 1524.6870000000001, 1499.349, 1473.865, 1448.241, 1422.48, 1396.588, 1370.567, 1344.424, 1318.161, 1291.782, 1265.292, 1238.694, 1211.992, 1185.1889999999999, 1158.289, 1131.2939999999999, 1104.2089999999998, 1077.037, 1049.781, 1022.443, 995.0269999999999, 967.535, 939.972, 912.3380000000001, 884.638, 856.873, 829.047, 801.1610000000001, 773.2189999999999, 745.2230000000001, 717.175, 689.078, 660.933, 632.743, 604.511, 576.238, 547.927, 519.58, 491.19800000000004, 462.784, 434.34, 405.86699999999996, 377.36800000000005, 348.844, 320.297, 291.72900000000004, 263.142, 234.537, 205.917, 177.283, 148.636, 119.978, 91.311, 62.636, 33.955, 5.269, -23.419, -52.108999999999995, -80.8, -109.48899999999999, -138.175, -166.857, -195.53400000000002, -224.204, -252.86599999999999, -281.518, -310.159, -338.788, -367.404, -396.005, -424.59, -453.158, -481.707, -510.23699999999997, -538.746, -567.2330000000001, -595.697, -624.136, -652.55, -680.937, -709.297, -737.627, -765.928, -794.197, -822.434, -850.638, -878.808, -906.942, -935.04, -963.1, -991.122, -1019.1039999999999, -1047.045, -1074.945, -1102.802, -1130.615, -1158.384, -1186.107, -1213.7830000000001, -1241.412, -1268.992, -1296.5230000000001, -1324.0020000000002, -1351.431, -1378.806, -1406.129, -1433.396, -1460.609, -1487.765, -1514.8629999999998, -1541.904, -1568.885, -1595.806, -1622.6660000000002, -1649.4479999999999, -1676.183, -1702.854, -1729.46, -1756.001, -1782.474, -1808.88, -1835.217, -1861.485, -1887.682, -1913.808, -1939.862, -1965.842, -1991.749, -2017.58, -2043.335, -2069.012, -2094.612, -2120.134, -2145.575, -2170.935, -2196.214, -2221.41, -2246.5229999999997, -2271.551, -2296.493, -2321.349, -2346.117, -2370.797, -2395.388, -2419.888, -2444.297, -2468.614, -2492.837, -2516.966, -2541.0, -2564.937, -2588.777, -2612.519, -2636.1609999999996, -2659.704, -2683.1440000000002, -2706.4829999999997, -2729.717, -2752.848, -2775.873, -2798.7909999999997, -2821.6009999999997, -2844.303, -2866.895, -2889.3759999999997, -2911.745, -2934.0009999999997, -2956.143, -2978.17, -3000.08, -3021.8720000000003, -3043.546, -3065.099, -3086.532, -3107.842, -3129.0290000000005, -3150.092, -3171.028, -3191.8379999999997, -3212.5190000000002, -3233.071, -3253.492, -3273.781, -3293.9359999999997, -3313.958, -3333.843, -3353.591, -3373.2, -3392.67, -3411.998, -3431.184, -3450.2259999999997, -3469.1220000000003, -3487.8720000000003, -3506.474, -3524.925, -3543.2259999999997, -3561.3740000000003, -3579.368, -3597.2070000000003, -3614.888, -3632.4109999999996, -3649.7729999999997, -3666.974, -3684.011, -3700.883, -3717.5890000000004, -3734.1259999999997, -3750.493, -3766.688, -3782.71, -3798.5559999999996, -3814.225, -3829.716, -3845.026, -3860.153, -3875.0959999999995, -3889.853, -3904.421, -3918.7990000000004, -3932.985, -3946.9770000000003, -3960.7729999999997, -3974.37, -3987.7670000000003, -4000.961, -4013.9509999999996, -4026.7329999999997, -4039.3070000000002, -4051.6690000000003, -4063.817, -4075.7490000000003, -4087.462, -4098.955, -4110.224, -4121.268, -4132.083, -4142.667, -4153.017, -4163.1320000000005, -4173.0070000000005, -4182.64, -4192.029, -4201.170999999999, -4210.062, -4218.6990000000005, -4227.081, -4235.2029999999995, -4243.063, -4250.657, -4257.982, -4265.034000000001, -4271.811, -4278.309, -4284.525, -4290.455, -4296.094, -4301.441, -4306.49, -4311.238, -4315.681, -4319.816, -4323.637, -4327.141, -4330.323, -4333.18, -4335.706, -4337.898, -4339.75, -4341.258, -4342.417, -4343.221, -4343.667, -4343.749, -4343.460999999999, -4342.798, -4341.755, -4340.326, -4338.505, -4336.286, -4333.663, -4330.63, -4327.181, -4323.308, -4319.005999999999, -4314.267, -4309.085, -4303.452, -4297.36, -4290.803, -4283.772, -4276.26, -4268.258, -4259.758, -4250.751, -4241.228, -4231.18, -4220.598, -4209.472, -4197.792, -4185.548, -4172.73, -4159.326, -4145.325, -4130.717000000001, -4115.488, -4099.628, -4083.123, -4065.96, -4048.127, -4029.6090000000004, -4010.3920000000003, -3990.461, -3969.802, -3948.3990000000003, -3926.235, -3903.2940000000003, -3879.559, -3855.011, -3829.633, -3803.405, -3776.308, -3748.321, -3719.4240000000004, -3689.593, -3658.8070000000002, -3627.042, -3594.2740000000003, -3560.4770000000003, -3525.625, -3489.692, -3452.65, -3414.468, -3375.117, -3334.567, -3292.783, -3249.7329999999997, -3205.382, -3159.6940000000004, -3112.631, -3064.155, -3014.2259999999997, -2962.801, -2909.8390000000004, -2855.296, -2799.125, -2741.28, -2681.7140000000004, -2620.375, -2557.215, -2492.181, -2425.223, -2356.286, -2285.3179999999998, -2212.2670000000003, -2137.08, -2059.706, -1980.096, -1898.205, -1813.9879999999998, -1727.4089999999999, -1638.4370000000001, -1547.047, -1453.226, -1356.974, -1258.3010000000002, -1157.24, -1053.839, -948.172, -840.34, -730.471, -618.727, -505.306, -390.44199999999995, -274.405, -157.505, -40.085, 77.48100000000001, 194.792, 311.43, 426.97, 540.984, 653.058, 762.8, 869.846, 973.87, 1074.594, 1171.782, 1265.251, 1354.8629999999998, 1440.527, 1522.195, 1599.855, 1673.53, 1743.267, 1809.141, 1871.24, 1929.67, 1984.545, 2035.9879999999998, 2084.124, 2129.0820000000003, 2170.992, 2209.981, 2246.175, 2279.697, 2310.665, 2339.196, 2365.3979999999997, 2389.3779999999997, 2411.238, 2431.075, 2448.979, 2465.04, 2479.34, 2491.959, 2502.971, 2512.448, 2520.458, 2527.063, 2532.326, 2536.304, 2539.051, 2540.62, 2541.058, 2540.4139999999998, 2538.731, 2536.051, 2532.415, 2527.86, 2522.423, 2516.137, 2509.0370000000003, 2501.151, 2492.512, 2483.146, 2473.081, 2462.343, 2450.956, 2438.9429999999998, 2426.328, 2413.131, 2399.373, 2385.074, 2370.252, 2354.926, 2339.113, 2322.83, 2306.092, 2288.9139999999998, 2271.311, 2253.298, 2234.888, 2216.094, 2196.928, 2177.402, 2157.528, 2137.3179999999998, 2116.781, 2095.929, 2074.771, 2053.317, 2031.576, 2009.558, 1987.27, 1964.721, 1941.92, 1918.875, 1895.592, 1872.079, 1848.3429999999998, 1824.392, 1800.2320000000002, 1775.868, 1751.309, 1726.559, 1701.624, 1676.511, 1651.224, 1625.769, 1600.152, 1574.3770000000002, 1548.45, 1522.375, 1496.156, 1469.799, 1443.307, 1416.6860000000001, 1389.9389999999999, 1363.07, 1336.0829999999999, 1308.983, 1281.772, 1254.455, 1227.035, 1199.516, 1171.901, 1144.193, 1116.396, 1088.512, 1060.545, 1032.498, 1004.3739999999999, 976.176, 947.9060000000001, 919.568, 891.163, 862.695, 834.1669999999999, 805.58, 776.937, 748.2410000000001, 719.4939999999999, 690.698, 661.8560000000001, 632.97, 604.0419999999999, 575.0740000000001, 546.069, 517.028, 487.95300000000003, 458.847, 429.711, 400.548, 371.358, 342.145, 312.91, 283.654, 254.38, 225.08900000000003, 195.78400000000002, 166.46400000000003, 137.13299999999998, 107.792, 78.442, 49.085, 19.723, -9.642000000000001, -39.010999999999996, -68.38, -97.74799999999999, -127.11399999999999, -156.477, -185.835, -215.18599999999998, -244.53, -273.865, -303.189, -332.501, -361.801, -391.086, -420.355, -449.608, -478.842, -508.05699999999996, -537.251, -566.424, -595.573, -624.698, -653.798, -682.872, -711.9169999999999, -740.934, -769.92, -798.8760000000001, -827.799, -856.689, -885.544, -914.3639999999999, -943.1469999999999, -971.8919999999999, -1000.5980000000001, -1029.265, -1057.891, -1086.474, -1115.015, -1143.512, -1171.963, -1200.369, -1228.7269999999999, -1257.037, -1285.298, -1313.509, -1341.6689999999999, -1369.777, -1397.8310000000001, -1425.8310000000001, -1453.776, -1481.665, -1509.497, -1537.271, -1564.986, -1592.64, -1620.234, -1647.766, -1675.234, -1702.639, -1729.979, -1757.253, -1784.461, -1811.6, -1838.671, -1865.672, -1892.6029999999998, -1919.4620000000002, -1946.2479999999998, -1972.961, -1999.599, -2026.162, -2052.6479999999997, -2079.0570000000002, -2105.388, -2131.639, -2157.81, -2183.9, -2209.907, -2235.8320000000003, -2261.672, -2287.426, -2313.095, -2338.677, -2364.17, -2389.574, -2414.888, -2440.111, -2465.242, -2490.28, -2515.223, -2540.071, -2564.823, -2589.478, -2614.034, -2638.492, -2662.848, -2687.1040000000003, -2711.257, -2735.3059999999996, -2759.2509999999997, -2783.09, -2806.822, -2830.447, -2853.9629999999997, -2877.368, -2900.663, -2923.845, -2946.914, -2969.868, -2992.7070000000003, -3015.428, -3038.032, -3060.5170000000003, -3082.881, -3105.1240000000003, -3127.245, -3149.241, -3171.112, -3192.857, -3214.474, -3235.9629999999997, -3257.321, -3278.548, -3299.643, -3320.603, -3341.429, -3362.117, -3382.6679999999997, -3403.08, -3423.35, -3443.4790000000003, -3463.465, -3483.3059999999996, -3503.0, -3522.547, -3541.945, -3561.1929999999998, -3580.288, -3599.23, -3618.0170000000003, -3636.647, -3655.119, -3673.4320000000002, -3691.583, -3709.571, -3727.395, -3745.053, -3762.542, -3779.863, -3797.012, -3813.988, -3830.789, -3847.414, -3863.861, -3880.1279999999997, -3896.212, -3912.113, -3927.828, -3943.3559999999998, -3958.6940000000004, -3973.84, -3988.792, -4003.55, -4018.1090000000004, -4032.469, -4046.6259999999997, -4060.58, -4074.327, -4087.866, -4101.194, -4114.309, -4127.209, -4139.891, -4152.353, -4164.592000000001, -4176.606, -4188.393, -4199.9490000000005, -4211.273, -4222.361, -4233.212, -4243.821, -4254.187, -4264.306, -4274.1759999999995, -4283.794, -4293.157, -4302.2609999999995, -4311.105, -4319.683, -4327.994000000001, -4336.034000000001, -4343.8, -4351.288, -4358.495, -4365.417, -4372.0509999999995, -4378.393, -4384.44, -4390.187, -4395.630999999999, -4400.768, -4405.594, -4410.105, -4414.295999999999, -4418.163, -4421.702, -4424.907999999999, -4427.778, -4430.305, -4432.486, -4434.316, -4435.789000000001, -4436.901, -4437.646, -4438.019, -4438.015, -4437.628, -4436.853, -4435.683, -4434.113, -4432.1359999999995, -4429.747, -4426.939, -4423.705, -4420.039000000001, -4415.935, -4411.384, -4406.379, -4400.914000000001, -4394.981, -4388.572, -4381.678, -4374.293, -4366.406, -4358.0109999999995, -4349.097, -4339.656, -4329.678, -4319.154, -4308.0740000000005, -4296.427, -4284.204000000001, -4271.393, -4257.983, -4243.963, -4229.32, -4214.044, -4198.121, -4181.539000000001, -4164.284000000001, -4146.342000000001, -4127.7, -4108.343, -4088.255, -4067.422, -4045.827, -4023.454, -4000.285, -3976.303, -3951.489, -3925.8259999999996, -3899.292, -3871.868, -3843.532, -3814.264, -3784.04, -3752.8379999999997, -3720.633, -3687.4, -3653.113, -3617.7459999999996, -3581.2709999999997, -3543.658, -3504.8779999999997, -3464.9, -3423.692, -3381.22, -3337.45, -3292.3459999999995, -3245.87, -3197.985, -3148.651, -3097.825, -3045.466, -2991.53, -2935.97, -2878.741, -2819.7929999999997, -2759.078, -2696.5429999999997, -2632.138, -2565.8089999999997, -2497.501, -2427.1620000000003, -2354.735, -2280.166, -2203.401, -2124.387, -2043.0729999999999, -1959.41, -1873.3529999999998, -1784.8629999999998, -1693.905, -1600.4560000000001, -1504.4979999999998, -1406.029, -1305.059, -1201.618, -1095.755, -987.543, -877.08, -764.497, -649.9580000000001, -533.661, -415.843, -296.78, -176.78599999999997, -56.211000000000006, 64.563, 185.127, 305.053, 423.903, 541.24, 656.6360000000001, 769.687, 880.0160000000001, 987.2869999999999, 1091.2069999999999, 1191.535, 1288.0739999999998, 1380.681, 1469.259, 1553.753, 1634.149, 1710.464, 1782.747, 1851.069, 1915.52, 1976.207, 2033.244, 2086.756, 2136.871, 2183.72, 2227.4339999999997, 2268.144, 2305.979, 2341.064, 2373.521, 2403.467, 2431.016, 2456.277, 2479.3520000000003, 2500.343, 2519.342, 2536.44, 2551.723, 2565.272, 2577.1639999999998, 2587.472, 2596.266, 2603.611, 2609.57, 2614.202, 2617.563, 2619.7070000000003, 2620.6839999999997, 2620.5429999999997, 2619.328, 2617.083, 2613.849, 2609.666, 2604.57, 2598.598, 2591.782, 2584.154, 2575.746, 2566.587, 2556.7039999999997, 2546.124, 2534.8720000000003, 2522.972, 2510.448, 2497.322, 2483.614, 2469.346, 2454.536, 2439.203, 2423.365, 2407.0389999999998, 2390.241, 2372.988, 2355.294, 2337.173, 2318.64, 2299.708, 2280.391, 2260.699, 2240.646, 2220.243, 2199.501, 2178.431, 2157.0429999999997, 2135.346, 2113.3520000000003, 2091.0679999999998, 2068.504, 2045.668, 2022.569, 1999.2160000000001, 1975.615, 1951.774, 1927.701, 1903.4029999999998, 1878.8870000000002, 1854.1589999999999, 1829.226, 1804.094, 1778.769, 1753.257, 1727.5639999999999, 1701.695, 1675.656, 1649.4520000000002, 1623.088, 1596.569, 1569.9, 1543.085, 1516.13, 1489.0379999999998, 1461.8139999999999, 1434.4620000000002, 1406.986, 1379.39, 1351.6789999999999, 1323.855, 1295.923, 1267.885, 1239.747, 1211.51, 1183.1789999999999, 1154.757, 1126.247, 1097.651, 1068.974, 1040.218, 1011.3860000000001, 982.48, 953.505, 924.461, 895.3530000000001, 866.182, 836.952, 807.664, 778.322, 748.927, 719.482, 689.9889999999999, 660.451, 630.87, 601.247, 571.586, 541.888, 512.155, 482.389, 452.593, 422.76800000000003, 392.916, 363.039, 333.139, 303.217, 273.277, 243.31799999999998, 213.34400000000002, 183.355, 153.35399999999998, 123.34200000000001, 93.32, 63.291000000000004, 33.256, 3.216, -26.826, -56.87, -86.914, -116.95700000000001, -146.996, -177.03099999999998, -207.06, -237.082, -267.096, -297.099, -327.09, -357.07, -387.035, -416.98400000000004, -446.917, -476.832, -506.728, -536.6030000000001, -566.457, -596.288, -626.094, -655.8760000000001, -685.63, -715.357, -745.055, -774.7230000000001, -804.36, -833.9639999999999, -863.535, -893.071, -922.571, -952.035, -981.46, -1010.847, -1040.193, -1069.498, -1098.761, -1127.98, -1157.155, -1186.2839999999999, -1215.367, -1244.402, -1273.388, -1302.325, -1331.211, -1360.045, -1388.826, -1417.5539999999999, -1446.227, -1474.844, -1503.404, -1531.906, -1560.349, -1588.733, -1617.055, -1645.316, -1673.514, -1701.648, -1729.717, -1757.72, -1785.656, -1813.525, -1841.325, -1869.055, -1896.714, -1924.3010000000002, -1951.815, -1979.256, -2006.622, -2033.912, -2061.126, -2088.261, -2115.3179999999998, -2142.295, -2169.192, -2196.006, -2222.738, -2249.387, -2275.95, -2302.428, -2328.8179999999998, -2355.1220000000003, -2381.3360000000002, -2407.46, -2433.494, -2459.435, -2485.284, -2511.0389999999998, -2536.699, -2562.262, -2587.729, -2613.097, -2638.366, -2663.535, -2688.603, -2713.5679999999998, -2738.43, -2763.187, -2787.8379999999997, -2812.382, -2836.8190000000004, -2861.1459999999997, -2885.364, -2909.47, -2933.4640000000004, -2957.344, -2981.1090000000004, -3004.758, -3028.2909999999997, -3051.705, -3075.0, -3098.1740000000004, -3121.2259999999997, -3144.155, -3166.96, -3189.64, -3212.192, -3234.617, -3256.9120000000003, -3279.077, -3301.11, -3323.01, -3344.775, -3366.405, -3387.897, -3409.2509999999997, -3430.465, -3451.5370000000003, -3472.468, -3493.2540000000004, -3513.8940000000002, -3534.388, -3554.7329999999997, -3574.928, -3594.973, -3614.864, -3634.6009999999997, -3654.1820000000002, -3673.605, -3692.87, -3711.974, -3730.9159999999997, -3749.6940000000004, -3768.3070000000002, -3786.752, -3805.0290000000005, -3823.135, -3841.0679999999998, -3858.828, -3876.4120000000003, -3893.8190000000004, -3911.046, -3928.092, -3944.954, -3961.632, -3978.123, -3994.425, -4010.5359999999996, -4026.454, -4042.177, -4057.704, -4073.031, -4088.157, -4103.08, -4117.798, -4132.308, -4146.608, -4160.696, -4174.569, -4188.226, -4201.663, -4214.879, -4227.87, -4240.635, -4253.170999999999, -4265.475, -4277.544, -4289.377, -4300.97, -4312.321, -4323.4259999999995, -4334.282999999999, -4344.889, -4355.241, -4365.335999999999, -4375.170999999999, -4384.7429999999995, -4394.049, -4403.085, -4411.848, -4420.335, -4428.543, -4436.468, -4444.106, -4451.454000000001, -4458.508, -4465.264, -4471.72, -4477.87, -4483.710999999999, -4489.238, -4494.4490000000005, -4499.337, -4503.9, -4508.133, -4512.031, -4515.59, -4518.805, -4521.670999999999, -4524.183, -4526.338, -4528.128, -4529.55, -4530.597, -4531.265, -4531.548, -4531.441, -4530.936, -4530.03, -4528.714, -4526.984, -4524.832, -4522.253, -4519.24, -4515.785, -4511.8820000000005, -4507.523, -4502.701, -4497.409000000001, -4491.639, -4485.3820000000005, -4478.6320000000005, -4471.378, -4463.613, -4455.327, -4446.513, -4437.159000000001, -4427.2570000000005, -4416.7970000000005, -4405.769, -4394.162, -4381.965, -4369.168, -4355.759, -4341.726, -4327.058, -4311.741, -4295.763, -4279.111, -4261.772, -4243.73, -4224.972, -4205.483, -4185.247, -4164.249, -4142.471, -4119.898, -4096.51, -4072.2909999999997, -4047.2209999999995, -4021.282, -3994.452, -3966.711, -3938.038, -3908.4109999999996, -3877.805, -3846.198, -3813.565, -3779.88, -3745.116, -3709.2459999999996, -3672.241, -3634.072, -3594.7070000000003, -3554.116, -3512.265, -3469.119, -3424.6440000000002, -3378.802, -3331.555, -3282.864, -3232.688, -3180.9829999999997, -3127.7070000000003, -3072.8140000000003, -3016.257, -2957.988, -2897.9570000000003, -2836.112, -2772.402, -2706.7729999999997, -2639.1690000000003, -2569.535, -2497.815, -2423.953, -2347.89, -2269.572, -2188.942, -2105.949, -2020.54, -1932.67, -1842.295, -1749.381, -1653.9, -1555.8339999999998, -1455.1779999999999, -1351.942, -1246.152, -1137.857, -1027.129, -914.067, -798.802, -681.498, -562.355, -441.615, -319.555, -196.49599999999998, -72.793, 51.163999999999994, 174.956, 298.147, 420.288, 540.928, 659.63, 775.9739999999999, 889.574, 1000.081, 1107.191, 1210.65, 1310.256, 1405.856, 1497.346, 1584.6660000000002, 1667.797, 1746.755, 1821.586, 1892.36, 1959.1689999999999, 2022.1170000000002, 2081.321, 2136.909, 2189.008, 2237.754, 2283.28, 2325.719, 2365.202, 2401.857, 2435.81, 2467.18, 2496.083, 2522.631, 2546.931, 2569.083, 2589.185, 2607.3289999999997, 2623.603, 2638.1679999999997, 2650.869, 2662.0159999999996, 2671.6020000000003, 2679.695, 2686.3579999999997, 2691.653, 2695.636, 2698.364, 2699.888, 2700.257, 2699.5190000000002, 2697.717, 2694.8940000000002, 2691.091, 2686.345, 2680.6929999999998, 2674.17, 2666.809, 2658.6409999999996, 2649.696, 2640.0029999999997, 2629.5890000000004, 2618.48, 2606.702, 2594.278, 2581.23, 2567.581, 2553.351, 2538.561, 2523.23, 2507.375, 2491.015, 2474.166, 2456.845, 2439.067, 2420.847, 2402.2, 2383.139, 2363.677, 2343.828, 2323.604, 2303.016, 2282.077, 2260.797, 2239.186, 2217.256, 2195.015, 2172.474, 2149.641, 2126.527, 2103.138, 2079.485, 2055.574, 2031.4129999999998, 2007.011, 1982.374, 1957.51, 1932.425, 1907.126, 1881.62, 1855.912, 1830.009, 1803.918, 1777.6429999999998, 1751.1889999999999, 1724.5639999999999, 1697.771, 1670.816, 1643.704, 1616.44, 1589.0279999999998, 1561.474, 1533.78, 1505.953, 1477.995, 1449.912, 1421.707, 1393.384, 1364.9460000000001, 1336.399, 1307.745, 1278.987, 1250.13, 1221.1760000000002, 1192.13, 1162.993, 1133.77, 1104.463, 1075.076, 1045.611, 1016.072, 986.46, 956.78, 927.0319999999999, 897.222, 867.3489999999999, 837.418, 807.431, 777.3910000000001, 747.298, 717.1569999999999, 686.9689999999999, 656.737, 626.462, 596.148, 565.795, 535.4069999999999, 504.98400000000004, 474.53, 444.046, 413.535, 382.99699999999996, 352.435, 321.851, 291.247, 260.625, 229.985, 199.33, 168.66299999999998, 137.983, 107.294, 76.596, 45.891000000000005, 15.182, -15.532, -46.247, -76.962, -107.677, -138.389, -169.097, -199.8, -230.49599999999998, -261.183, -291.861, -322.528, -353.18199999999996, -383.82300000000004, -414.44800000000004, -445.05699999999996, -475.648, -506.22, -536.7719999999999, -567.302, -597.809, -628.2919999999999, -658.75, -689.181, -719.585, -749.959, -780.303, -810.6160000000001, -840.8969999999999, -871.143, -901.355, -931.5310000000001, -961.67, -991.77, -1021.831, -1051.8519999999999, -1081.8310000000001, -1111.767, -1141.6589999999999, -1171.507, -1201.308, -1231.063, -1260.769, -1290.4260000000002, -1320.033, -1349.588, -1379.0910000000001, -1408.5410000000002, -1437.9360000000001, -1467.275, -1496.558, -1525.7839999999999, -1554.95, -1584.057, -1613.104, -1642.088, -1671.01, -1699.868, -1728.661, -1757.388, -1786.049, -1814.641, -1843.165, -1871.619, -1900.0020000000002, -1928.3120000000001, -1956.55, -1984.714, -2012.8029999999999, -2040.816, -2068.751, -2096.609, -2124.388, -2152.0860000000002, -2179.703, -2207.238, -2234.69, -2262.058, -2289.34, -2316.536, -2343.645, -2370.665, -2397.596, -2424.436, -2451.185, -2477.841, -2504.404, -2530.8720000000003, -2557.244, -2583.519, -2609.696, -2635.7740000000003, -2661.752, -2687.6290000000004, -2713.403, -2739.074, -2764.6409999999996, -2790.1009999999997, -2815.455, -2840.7009999999996, -2865.8390000000004, -2890.865, -2915.781, -2940.5840000000003, -2965.2729999999997, -2989.848, -3014.3059999999996, -3038.647, -3062.87, -3086.973, -3110.9559999999997, -3134.816, -3158.553, -3182.165, -3205.651, -3229.011, -3252.242, -3275.343, -3298.3140000000003, -3321.152, -3343.857, -3366.426, -3388.86, -3411.155, -3433.312, -3455.328, -3477.203, -3498.934, -3520.5209999999997, -3541.962, -3563.255, -3584.3990000000003, -3605.3920000000003, -3626.2340000000004, -3646.922, -3667.455, -3687.8309999999997, -3708.0490000000004, -3728.1079999999997, -3748.005, -3767.738, -3787.308, -3806.711, -3825.946, -3845.011, -3863.905, -3882.625, -3901.171, -3919.54, -3937.73, -3955.74, -3973.5679999999998, -3991.211, -4008.6690000000003, -4025.938, -4043.018, -4059.905, -4076.599, -4093.0959999999995, -4109.396, -4125.495, -4141.392, -4157.084, -4172.57, -4187.846, -4202.912, -4217.764, -4232.4, -4246.818, -4261.016, -4274.99, -4288.7390000000005, -4302.26, -4315.5509999999995, -4328.608, -4341.429, -4354.012, -4366.354, -4378.452, -4390.302, -4401.904, -4413.252, -4424.345, -4435.18, -4445.752, -4456.06, -4466.101, -4475.869000000001, -4485.3640000000005, -4494.58, -4503.516, -4512.166, -4520.529, -4528.599, -4536.374, -4543.85, -4551.022, -4557.887, -4564.442, -4570.681, -4576.601, -4582.198, -4587.467000000001, -4592.404, -4597.004, -4601.263, -4605.1759999999995, -4608.7390000000005, -4611.946, -4614.793, -4617.274, -4619.385, -4621.119000000001, -4622.472, -4623.438, -4624.0109999999995, -4624.186, -4623.956, -4623.315, -4622.258, -4620.778, -4618.8679999999995, -4616.521, -4613.732, -4610.492, -4606.795, -4602.6320000000005, -4597.998, -4592.883, -4587.281, -4581.182, -4574.5779999999995, -4567.460999999999, -4559.822, -4551.652, -4542.942, -4533.682, -4523.862, -4513.472, -4502.501, -4490.94, -4478.776, -4466.0, -4452.598, -4438.559, -4423.871, -4408.521, -4392.495, -4375.781, -4358.365, -4340.231, -4321.365, -4301.752, -4281.376, -4260.221, -4238.269, -4215.504, -4191.907999999999, -4167.460999999999, -4142.144, -4115.939, -4088.823, -4060.776, -4031.776, -4001.7990000000004, -3970.823, -3938.823, -3905.7729999999997, -3871.6459999999997, -3836.417, -3800.0559999999996, -3762.534, -3723.821, -3683.886, -3642.6940000000004, -3600.2140000000004, -3556.409, -3511.243, -3464.678, -3416.6740000000004, -3367.1929999999998, -3316.19, -3263.623, -3209.446, -3153.614, -3096.0759999999996, -3036.785, -2975.69, -2912.735, -2847.868, -2781.034, -2712.177, -2641.237, -2568.158, -2492.881, -2415.347, -2335.498, -2253.277, -2168.6279999999997, -2081.498, -1991.84, -1899.6070000000002, -1804.7620000000002, -1707.277, -1607.13, -1504.315, -1398.839, -1290.73, -1180.032, -1066.818, -951.187, -833.2689999999999, -713.2289999999999, -591.271, -467.63599999999997, -342.60900000000004, -216.513, -89.71, 37.403, 164.399, 290.83, 416.23800000000006, 540.161, 662.148, 781.7689999999999, 898.6239999999999, 1012.352, 1122.638, 1229.219, 1331.882, 1430.467, 1524.862, 1615.003, 1700.866, 1782.464, 1859.8410000000001, 1933.067, 2002.2320000000002, 2067.442, 2128.815, 2186.48, 2240.567, 2291.212, 2338.552, 2382.723, 2423.8579999999997, 2462.0879999999997, 2497.541, 2530.339, 2560.603, 2588.444, 2613.972, 2637.292, 2658.502, 2677.697, 2694.968, 2710.3990000000003, 2724.073, 2736.065, 2746.45, 2755.297, 2762.671, 2768.634, 2773.2470000000003, 2776.566, 2778.6440000000002, 2779.531, 2779.276, 2777.9240000000004, 2775.5190000000002, 2772.103, 2767.7140000000004, 2762.3909999999996, 2756.1679999999997, 2749.08, 2741.16, 2732.437, 2722.941, 2712.702, 2701.744, 2690.094, 2677.777, 2664.816, 2651.2329999999997, 2637.05, 2622.2870000000003, 2606.965, 2591.101, 2574.714, 2557.822, 2540.4410000000003, 2522.587, 2504.276, 2485.522, 2466.34, 2446.743, 2426.744, 2406.356, 2385.592, 2364.4629999999997, 2342.981, 2321.156, 2298.999, 2276.521, 2253.73, 2230.637, 2207.251, 2183.581, 2159.635, 2135.422, 2110.95, 2086.226, 2061.258, 2036.0529999999999, 2010.619, 1984.963, 1959.09, 1933.0079999999998, 1906.723, 1880.24, 1853.566, 1826.707, 1799.668, 1772.454, 1745.0710000000001, 1717.524, 1689.818, 1661.9579999999999, 1633.9479999999999, 1605.793, 1577.4979999999998, 1549.066, 1520.503, 1491.8120000000001, 1462.997, 1434.0629999999999, 1405.013, 1375.851, 1346.58, 1317.204, 1287.7269999999999, 1258.152, 1228.482, 1198.721, 1168.87, 1138.937, 1108.92, 1078.8239999999998, 1048.652, 1018.405, 988.09, 957.706, 927.2560000000001, 896.745, 866.173, 835.543, 804.8589999999999, 774.122, 743.336, 712.5, 681.62, 650.696, 619.731, 588.727, 557.686, 526.61, 495.501, 464.36199999999997, 433.194, 401.999, 370.779, 339.536, 308.272, 276.98900000000003, 245.688, 214.372, 183.041, 151.69799999999998, 120.345, 88.98200000000001, 57.611999999999995, 26.237, -5.143, -36.525, -67.908, -99.29, -130.671, -162.047, -193.419, -224.78400000000002, -256.14099999999996, -287.48900000000003, -318.82599999999996, -350.151, -381.462, -412.75800000000004, -444.038, -475.3, -506.54400000000004, -537.7669999999999, -568.9680000000001, -600.1469999999999, -631.3009999999999, -662.43, -693.533, -724.6080000000001, -755.653, -786.668, -817.6519999999999, -848.6030000000001, -879.52, -910.403, -941.248, -972.057, -1002.827, -1033.556, -1064.245, -1094.892, -1125.496, -1156.056, -1186.5710000000001, -1217.038, -1247.4589999999998, -1277.83, -1308.152, -1338.4229999999998, -1368.642, -1398.808, -1428.9189999999999, -1458.976, -1488.976, -1518.9189999999999, -1548.8039999999999, -1578.63, -1608.3929999999998, -1638.096, -1667.737, -1697.3129999999999, -1726.825, -1756.271, -1785.65, -1814.9620000000002, -1844.204, -1873.376, -1902.4779999999998, -1931.507, -1960.463, -1989.345, -2018.152, -2046.882, -2075.535, -2104.11, -2132.605, -2161.02, -2189.353, -2217.603, -2245.77, -2273.853, -2301.849, -2329.759, -2357.581, -2385.313, -2412.956, -2440.508, -2467.967, -2495.333, -2522.605, -2549.782, -2576.861, -2603.843, -2630.7270000000003, -2657.51, -2684.1929999999998, -2710.7729999999997, -2737.25, -2763.623, -2789.89, -2816.05, -2842.103, -2868.047, -2893.88, -2919.6020000000003, -2945.212, -2970.708, -2996.0890000000004, -3021.3540000000003, -3046.502, -3071.531, -3096.441, -3121.2290000000003, -3145.895, -3170.438, -3194.8559999999998, -3219.1479999999997, -3243.313, -3267.349, -3291.255, -3315.0290000000005, -3338.672, -3362.18, -3385.553, -3408.789, -3431.888, -3454.8459999999995, -3477.665, -3500.34, -3522.8720000000003, -3545.259, -3567.5, -3589.592, -3611.535, -3633.327, -3654.966, -3676.4509999999996, -3697.78, -3718.952, -3739.965, -3760.8179999999998, -3781.509, -3802.0359999999996, -3822.397, -3842.592, -3862.618, -3882.473, -3902.156, -3921.665, -3940.998, -3960.153, -3979.1290000000004, -3997.9240000000004, -4016.5359999999996, -4034.962, -4053.202, -4071.252, -4089.112, -4106.778, -4124.25, -4141.524, -4158.6, -4175.474, -4192.145, -4208.61, -4224.867, -4240.914000000001, -4256.749, -4272.369000000001, -4287.773, -4302.956, -4317.918, -4332.656, -4347.167, -4361.4490000000005, -4375.499, -4389.314, -4402.892, -4416.231, -4429.326, -4442.177, -4454.779, -4467.13, -4479.227, -4491.067, -4502.648, -4513.965, -4525.015, -4535.7970000000005, -4546.305, -4556.538, -4566.491, -4576.162, -4585.545999999999, -4594.64, -4603.441, -4611.945, -4620.148, -4628.045999999999, -4635.635, -4642.912, -4649.872, -4656.5109999999995, -4662.825, -4668.809, -4674.46, -4679.773, -4684.742, -4689.365, -4693.634, -4697.5470000000005, -4701.097, -4704.281, -4707.090999999999, -4709.524, -4711.5740000000005, -4713.235, -4714.501, -4715.367, -4715.827, -4715.875, -4715.504, -4714.709, -4713.482, -4711.816, -4709.706, -4707.144, -4704.123, -4700.6359999999995, -4696.674, -4692.231, -4687.298, -4681.8679999999995, -4675.931, -4669.479, -4662.504, -4654.997, -4646.947, -4638.347, -4629.185, -4619.452, -4609.137, -4598.231, -4586.721, -4574.597, -4561.847, -4548.459, -4534.420999999999, -4519.72, -4504.343, -4488.278, -4471.509, -4454.022, -4435.804, -4416.838, -4397.109, -4376.602, -4355.298, -4333.181, -4310.233, -4286.436, -4261.771, -4236.217000000001, -4209.755, -4182.3640000000005, -4154.021, -4124.704000000001, -4094.39, -4063.054, -4030.671, -3997.216, -3962.6609999999996, -3926.978, -3890.139, -3852.113, -3812.869, -3772.375, -3730.597, -3687.5009999999997, -3643.051, -3597.2090000000003, -3549.935, -3501.191, -3450.935, -3399.1220000000003, -3345.7090000000003, -3290.6490000000003, -3233.893, -3175.3940000000002, -3115.099, -3052.9559999999997, -2988.9109999999996, -2922.907, -2854.889, -2784.798, -2712.574, -2638.158, -2561.489, -2482.507, -2401.151, -2317.361, -2231.0820000000003, -2142.257, -2050.8360000000002, -1956.771, -1860.024, -1760.5610000000001, -1658.362, -1553.4170000000001, -1445.7320000000002, -1335.3329999999999, -1222.263, -1106.594, -988.425, -867.885, -745.1419999999999, -620.399, -493.902, -365.93800000000005, -236.835, -106.961, 23.279, 153.45, 283.096, 411.746, 538.928, 664.18, 787.058, 907.1489999999999, 1024.083, 1137.532, 1247.222, 1352.931, 1454.491, 1551.7839999999999, 1644.739, 1733.33, 1817.565, 1897.486, 1973.161, 2044.682, 2112.154, 2175.697, 2235.44, 2291.516, 2344.063, 2393.221, 2439.126, 2481.917, 2521.726, 2558.6839999999997, 2592.915, 2624.5429999999997, 2653.6820000000002, 2680.445, 2704.937, 2727.261, 2747.514, 2765.788, 2782.17, 2796.743, 2809.5879999999997, 2820.778, 2830.385, 2838.4759999999997, 2845.116, 2850.365, 2854.282, 2856.92, 2858.3320000000003, 2858.5679999999998, 2857.6740000000004, 2855.6940000000004, 2852.673, 2848.6490000000003, 2843.6609999999996, 2837.7459999999996, 2830.94, 2823.2740000000003, 2814.781, 2805.491, 2795.4320000000002, 2784.634, 2773.1209999999996, 2760.9190000000003, 2748.052, 2734.5429999999997, 2720.414, 2705.687, 2690.381, 2674.5170000000003, 2658.112, 2641.184, 2623.7509999999997, 2605.83, 2587.435, 2568.5820000000003, 2549.2870000000003, 2529.562, 2509.422, 2488.879, 2467.946, 2446.636, 2424.96, 2402.928, 2380.553, 2357.845, 2334.813, 2311.468, 2287.819, 2263.875, 2239.646, 2215.138, 2190.362, 2165.325, 2140.034, 2114.498, 2088.723, 2062.716, 2036.486, 2010.037, 1983.3770000000002, 1956.5120000000002, 1929.4470000000001, 1902.19, 1874.745, 1847.119, 1819.316, 1791.342, 1763.2020000000002, 1734.901, 1706.444, 1677.836, 1649.0810000000001, 1620.183, 1591.148, 1561.98, 1532.681, 1503.2579999999998, 1473.713, 1444.0510000000002, 1414.274, 1384.388, 1354.395, 1324.299, 1294.103, 1263.812, 1233.427, 1202.953, 1172.392, 1141.747, 1111.022, 1080.219, 1049.3410000000001, 1018.3919999999999, 987.3739999999999, 956.289, 925.14, 893.93, 862.6610000000001, 831.336, 799.9580000000001, 768.528, 737.049, 705.523, 673.953, 642.341, 610.688, 578.998, 547.2719999999999, 515.513, 483.722, 451.901, 420.05300000000005, 388.17900000000003, 356.281, 324.361, 292.421, 260.46299999999997, 228.489, 196.5, 164.498, 132.484, 100.462, 68.431, 36.394, 4.353, -27.691999999999997, -59.736999999999995, -91.78299999999999, -123.82700000000001, -155.86700000000002, -187.903, -219.93200000000002, -251.954, -283.967, -315.969, -347.959, -379.936, -411.898, -443.843, -475.77099999999996, -507.681, -539.57, -571.437, -603.2819999999999, -635.102, -666.8969999999999, -698.665, -730.4060000000001, -762.117, -793.797, -825.446, -857.062, -888.6439999999999, -920.19, -951.7, -983.172, -1014.605, -1045.998, -1077.35, -1108.66, -1139.925, -1171.146, -1202.3210000000001, -1233.45, -1264.53, -1295.56, -1326.5410000000002, -1357.469, -1388.345, -1419.168, -1449.935, -1480.6470000000002, -1511.3020000000001, -1541.898, -1572.435, -1602.912, -1633.328, -1663.681, -1693.97, -1724.195, -1754.354, -1784.4460000000001, -1814.47, -1844.4260000000002, -1874.3110000000001, -1904.126, -1933.868, -1963.536, -1993.131, -2022.65, -2052.093, -2081.458, -2110.744, -2139.951, -2169.077, -2198.121, -2227.0820000000003, -2255.959, -2284.751, -2313.456, -2342.075, -2370.605, -2399.045, -2427.395, -2455.653, -2483.8179999999998, -2511.89, -2539.866, -2567.746, -2595.529, -2623.2129999999997, -2650.798, -2678.282, -2705.665, -2732.9440000000004, -2760.119, -2787.1890000000003, -2814.152, -2841.008, -2867.755, -2894.3920000000003, -2920.9179999999997, -2947.3309999999997, -2973.631, -2999.816, -3025.885, -3051.836, -3077.6690000000003, -3103.383, -3128.975, -3154.445, -3179.7909999999997, -3205.012, -3230.1079999999997, -3255.0759999999996, -3279.915, -3304.623, -3329.2009999999996, -3353.6459999999997, -3377.9559999999997, -3402.131, -3426.1690000000003, -3450.0690000000004, -3473.828, -3497.447, -3520.923, -3544.255, -3567.442, -3590.4809999999998, -3613.373, -3636.114, -3658.703, -3681.14, -3703.421, -3725.547, -3747.515, -3769.323, -3790.9709999999995, -3812.455, -3833.776, -3854.93, -3875.917, -3896.7340000000004, -3917.38, -3937.853, -3958.151, -3978.2729999999997, -3998.217, -4017.98, -4037.5609999999997, -4056.958, -4076.1690000000003, -4095.1929999999998, -4114.026, -4132.668, -4151.116, -4169.3679999999995, -4187.4220000000005, -4205.276, -4222.928, -4240.375, -4257.616, -4274.648, -4291.469, -4308.077, -4324.468, -4340.642, -4356.595, -4372.326, -4387.831, -4403.108, -4418.155, -4432.968, -4447.545999999999, -4461.8859999999995, -4475.985, -4489.84, -4503.448, -4516.807, -4529.913, -4542.765, -4555.358, -4567.689, -4579.7570000000005, -4591.556, -4603.085, -4614.34, -4625.318, -4636.014, -4646.427, -4656.552, -4666.3859999999995, -4675.924, -4685.165, -4694.103, -4702.734, -4711.056, -4719.063, -4726.752, -4734.119000000001, -4741.16, -4747.869000000001, -4754.2429999999995, -4760.278, -4765.968, -4771.309, -4776.295999999999, -4780.924, -4785.189, -4789.085, -4792.607, -4795.75, -4798.508, -4800.875, -4802.847, -4804.417, -4805.579000000001, -4806.3279999999995, -4806.656, -4806.559, -4806.028, -4805.058, -4803.641, -4801.771, -4799.441, -4796.643, -4793.369000000001, -4789.613, -4785.366, -4780.619000000001, -4775.365, -4769.595, -4763.3009999999995, -4756.473, -4749.102, -4741.179, -4732.693, -4723.6359999999995, -4713.996, -4703.763, -4692.927, -4681.475, -4669.397, -4656.68, -4643.313, -4629.282999999999, -4614.577, -4599.181, -4583.082, -4566.266, -4548.718, -4530.424, -4511.366, -4491.531, -4470.9, -4449.457, -4427.185, -4404.064, -4380.076, -4355.202, -4329.4220000000005, -4302.714, -4275.057, -4246.43, -4216.807, -4186.167, -4154.483, -4121.731, -4087.882, -4052.9109999999996, -4016.788, -3979.4840000000004, -3940.968, -3901.2070000000003, -3860.17, -3817.821, -3774.125, -3729.045, -3682.542, -3634.578, -3585.11, -3534.0959999999995, -3481.491, -3427.25, -3371.325, -3313.667, -3254.225, -3192.947, -3129.778, -3064.664, -2997.546, -2928.366, -2857.065, -2783.5809999999997, -2707.8520000000003, -2629.817, -2549.4120000000003, -2466.575, -2381.246, -2293.364, -2202.873, -2109.718, -2013.852, -1915.2320000000002, -1813.8239999999998, -1709.604, -1602.5620000000001, -1492.7020000000002, -1380.046, -1264.639, -1146.55, -1025.878, -902.752, -777.34, -649.8480000000001, -520.523, -389.655, -257.578, -124.666, 8.671, 141.988, 274.82099999999997, 406.689, 537.107, 665.602, 791.717, 915.029, 1035.153, 1151.752, 1264.5410000000002, 1373.289, 1477.818, 1578.004, 1673.77, 1765.086, 1851.957, 1934.422, 2012.5479999999998, 2086.427, 2156.1639999999998, 2221.88, 2283.705, 2341.774, 2396.229, 2447.209, 2494.855, 2539.3070000000002, 2580.701, 2619.17, 2654.841, 2687.8390000000004, 2718.283, 2746.2870000000003, 2771.9590000000003, 2795.405, 2816.722, 2836.006, 2853.317, 2868.827, 2882.531, 2894.534, 2904.909, 2913.7259999999997, 2921.05, 2926.9429999999998, 2931.465, 2934.672, 2936.617, 2937.3520000000003, 2936.923, 2935.377, 2932.758, 2929.107, 2924.4629999999997, 2918.865, 2912.347, 2904.945, 2896.6890000000003, 2887.613, 2877.745, 2867.113, 2855.745, 2843.667, 2830.902, 2817.4759999999997, 2803.41, 2788.7270000000003, 2773.447, 2757.5890000000004, 2741.1740000000004, 2724.22, 2706.744, 2688.763, 2670.2929999999997, 2651.35, 2631.95, 2612.106, 2591.8320000000003, 2571.143, 2550.05, 2528.567, 2506.705, 2484.476, 2461.8920000000003, 2438.962, 2415.698, 2392.109, 2368.205, 2343.996, 2319.491, 2294.698, 2269.626, 2244.284, 2218.679, 2192.819, 2166.712, 2140.364, 2113.784, 2086.9770000000003, 2059.951, 2032.711, 2005.265, 1977.618, 1949.776, 1921.745, 1893.53, 1865.138, 1836.5720000000001, 1807.839, 1778.944, 1749.89, 1720.684, 1691.329, 1661.83, 1632.192, 1602.418, 1572.514, 1542.483, 1512.328, 1482.055, 1451.6660000000002, 1421.165, 1390.557, 1359.844, 1329.03, 1298.118, 1267.112, 1236.015, 1204.83, 1173.56, 1142.208, 1110.777, 1079.271, 1047.691, 1016.04, 984.323, 952.54, 920.695, 888.789, 856.827, 824.81, 792.7410000000001, 760.6210000000001, 728.454, 696.2410000000001, 663.9860000000001, 631.689, 599.354, 566.982, 534.575, 502.13599999999997, 469.667, 437.16900000000004, 404.645, 372.097, 339.526, 306.934, 274.323, 241.695, 209.05200000000002, 176.396, 143.727, 111.04899999999999, 78.362, 45.669, 12.970999999999998, -19.730999999999998, -52.434, -85.137, -117.84, -150.539, -183.233, -215.922, -248.60299999999998, -281.276, -313.937, -346.587, -379.224, -411.846, -444.452, -477.04, -509.61, -542.159, -574.687, -607.191, -639.672, -672.127, -704.555, -736.955, -769.326, -801.666, -833.9739999999999, -866.248, -898.4889999999999, -930.693, -962.8610000000001, -994.9910000000001, -1027.0810000000001, -1059.131, -1091.139, -1123.105, -1155.026, -1186.902, -1218.731, -1250.513, -1282.246, -1313.93, -1345.5620000000001, -1377.142, -1408.6689999999999, -1440.141, -1471.558, -1502.918, -1534.22, -1565.464, -1596.6470000000002, -1627.769, -1658.828, -1689.825, -1720.756, -1751.6229999999998, -1782.422, -1813.154, -1843.816, -1874.4089999999999, -1904.93, -1935.38, -1965.755, -1996.056, -2026.2820000000002, -2056.431, -2086.5029999999997, -2116.495, -2146.409, -2176.239, -2205.989, -2235.655, -2265.236, -2294.7329999999997, -2324.1420000000003, -2353.464, -2382.697, -2411.839, -2440.891, -2469.85, -2498.716, -2527.488, -2556.1639999999998, -2584.742, -2613.223, -2641.605, -2669.887, -2698.067, -2726.1440000000002, -2754.118, -2781.986, -2809.7490000000003, -2837.4040000000005, -2864.95, -2892.387, -2919.712, -2946.926, -2974.026, -3001.011, -3027.881, -3054.633, -3081.2659999999996, -3107.78, -3134.173, -3160.4440000000004, -3186.591, -3212.614, -3238.51, -3264.278, -3289.9179999999997, -3315.427, -3340.805, -3366.05, -3391.1609999999996, -3416.136, -3440.973, -3465.673, -3490.232, -3514.65, -3538.925, -3563.0559999999996, -3587.04, -3610.8779999999997, -3634.567, -3658.105, -3681.492, -3704.725, -3727.803, -3750.724, -3773.487, -3796.09, -3818.532, -3840.8109999999997, -3862.9240000000004, -3884.8720000000003, -3906.651, -3928.26, -3949.697, -3970.96, -3992.0490000000004, -4012.96, -4033.692, -4054.243, -4074.612, -4094.796, -4114.793, -4134.602, -4154.22, -4173.646, -4192.877, -4211.911, -4230.747, -4249.380999999999, -4267.813, -4286.039000000001, -4304.058, -4321.8679999999995, -4339.465, -4356.848, -4374.014, -4390.962, -4407.688, -4424.19, -4440.465, -4456.512, -4472.3279999999995, -4487.909000000001, -4503.254, -4518.359, -4533.223, -4547.840999999999, -4562.212, -4576.332, -4590.1990000000005, -4603.809, -4617.16, -4630.249, -4643.072, -4655.626, -4667.907999999999, -4679.915, -4691.644, -4703.09, -4714.252, -4725.124, -4735.704000000001, -4745.987, -4755.971, -4765.651, -4775.024, -4784.085999999999, -4792.832, -4801.258, -4809.361, -4817.1359999999995, -4824.579000000001, -4831.685, -4838.45, -4844.87, -4850.939, -4856.653, -4862.0070000000005, -4866.996, -4871.615, -4875.858, -4879.721, -4883.198, -4886.284000000001, -4888.972, -4891.2570000000005, -4893.133, -4894.594, -4895.634, -4896.247, -4896.425, -4896.163, -4895.4529999999995, -4894.288, -4892.663, -4890.568, -4887.996, -4884.941, -4881.394, -4877.346, -4872.791, -4867.718, -4862.12, -4855.988, -4849.312, -4842.083, -4834.291, -4825.9259999999995, -4816.978, -4807.438, -4797.292, -4786.532, -4775.145, -4763.119000000001, -4750.442, -4737.103, -4723.087, -4708.383, -4692.975, -4676.851, -4659.996, -4642.395, -4624.032, -4604.891, -4584.957, -4564.212, -4542.639, -4520.22, -4496.935, -4472.767, -4447.695, -4421.697, -4394.754, -4366.843, -4337.941, -4308.025, -4277.07, -4245.049, -4211.939, -4177.71, -4142.335, -4105.785, -4068.0290000000005, -4029.0359999999996, -3988.7729999999997, -3947.2070000000003, -3904.301, -3860.02, -3814.3259999999996, -3767.18, -3718.54, -3668.365, -3616.61, -3563.2309999999998, -3508.18, -3451.409, -3392.866, -3332.5009999999997, -3270.26, -3206.086, -3139.923, -3071.712, -3001.393, -2928.9040000000005, -2854.183, -2777.1659999999997, -2697.788, -2615.986, -2531.695, -2444.851, -2355.394, -2263.263, -2168.404, -2070.765, -1970.3020000000001, -1866.979, -1760.7720000000002, -1651.665, -1539.661, -1424.7820000000002, -1307.0710000000001, -1186.596, -1063.454, -937.7760000000001, -809.73, -679.523, -547.404, -413.667, -278.65, -142.731, -6.329, 130.105, 266.096, 401.153, 534.7819999999999, 666.4960000000001, 795.827, 922.3389999999999, 1045.636, 1165.37, 1281.243, 1393.017, 1500.505, 1603.575, 1702.146, 1796.18, 1885.681, 1970.6860000000001, 2051.261, 2127.4970000000003, 2199.498, 2267.386, 2331.294, 2391.3579999999997, 2447.721, 2500.526, 2549.916, 2596.034, 2639.0159999999996, 2678.9990000000003, 2716.113, 2750.486, 2782.239, 2811.489, 2838.3459999999995, 2862.9179999999997, 2885.305, 2905.6040000000003, 2923.908, 2940.303, 2954.8740000000003, 2967.696, 2978.8459999999995, 2988.3940000000002, 2996.408, 3002.952, 3008.087, 3011.869, 3014.3540000000003, 3015.594, 3015.638, 3014.533, 3012.324, 3009.053, 3004.761, 2999.486, 2993.265, 2986.133, 2978.1240000000003, 2969.2690000000002, 2959.598, 2949.1420000000003, 2937.926, 2925.9790000000003, 2913.3259999999996, 2899.99, 2885.995, 2871.364, 2856.118, 2840.276, 2823.8590000000004, 2806.886, 2789.375, 2771.342, 2752.8059999999996, 2733.781, 2714.284, 2694.33, 2673.9309999999996, 2653.103, 2631.8590000000004, 2610.212, 2588.173, 2565.754, 2542.969, 2519.826, 2496.337, 2472.513, 2448.363, 2423.8979999999997, 2399.125, 2374.055, 2348.697, 2323.058, 2297.147, 2270.972, 2244.541, 2217.861, 2190.939, 2163.783, 2136.399, 2108.7929999999997, 2080.974, 2052.945, 2024.715, 1996.2879999999998, 1967.67, 1938.8670000000002, 1909.885, 1880.7279999999998, 1851.402, 1821.912, 1792.2620000000002, 1762.4579999999999, 1732.504, 1702.405, 1672.164, 1641.787, 1611.2779999999998, 1580.64, 1549.8770000000002, 1518.994, 1487.995, 1456.882, 1425.66, 1394.332, 1362.902, 1331.372, 1299.747, 1268.03, 1236.224, 1204.3310000000001, 1172.355, 1140.3, 1108.167, 1075.96, 1043.681, 1011.3330000000001, 978.92, 946.443, 913.905, 881.309, 848.6569999999999, 815.952, 783.196, 750.3910000000001, 717.54, 684.645, 651.7080000000001, 618.732, 585.7180000000001, 552.669, 519.587, 486.473, 453.33099999999996, 420.162, 386.967, 353.749, 320.51, 287.251, 253.975, 220.683, 187.377, 154.059, 120.73, 87.39299999999999, 54.049, 20.699, -12.655, -46.01, -79.366, -112.721, -146.07399999999998, -179.422, -212.764, -246.09900000000002, -279.425, -312.741, -346.045, -379.336, -412.61199999999997, -445.87199999999996, -479.11400000000003, -512.3380000000001, -545.5419999999999, -578.724, -611.882, -645.0169999999999, -678.1260000000001, -711.207, -744.2610000000001, -777.285, -810.278, -843.238, -876.166, -909.058, -941.914, -974.7339999999999, -1007.5139999999999, -1040.255, -1072.9560000000001, -1105.613, -1138.228, -1170.798, -1203.322, -1235.799, -1268.228, -1300.608, -1332.9370000000001, -1365.214, -1397.4389999999999, -1429.609, -1461.725, -1493.7839999999999, -1525.785, -1557.7279999999998, -1589.611, -1621.433, -1653.193, -1684.89, -1716.5220000000002, -1748.089, -1779.589, -1811.0220000000002, -1842.385, -1873.6789999999999, -1904.901, -1936.0520000000001, -1967.128, -1998.13, -2029.057, -2059.907, -2090.678, -2121.371, -2151.984, -2182.515, -2212.964, -2243.3289999999997, -2273.609, -2303.804, -2333.911, -2363.93, -2393.86, -2423.7, -2453.448, -2483.103, -2512.6639999999998, -2542.13, -2571.5, -2600.772, -2629.946, -2659.0190000000002, -2687.992, -2716.863, -2745.63, -2774.2929999999997, -2802.85, -2831.3, -2859.6409999999996, -2887.873, -2915.995, -2944.0040000000004, -2971.9, -2999.6820000000002, -3027.348, -3054.897, -3082.328, -3109.639, -3136.829, -3163.8979999999997, -3190.842, -3217.6620000000003, -3244.3559999999998, -3270.922, -3297.3590000000004, -3323.667, -3349.842, -3375.885, -3401.7929999999997, -3427.565, -3453.2009999999996, -3478.697, -3504.054, -3529.268, -3554.34, -3579.268, -3604.0490000000004, -3628.683, -3653.1679999999997, -3677.502, -3701.684, -3725.712, -3749.585, -3773.301, -3796.8579999999997, -3820.255, -3843.491, -3866.562, -3889.469, -3912.2090000000003, -3934.7790000000005, -3957.18, -3979.408, -4001.462, -4023.341, -4045.0409999999997, -4066.562, -4087.902, -4109.059, -4130.03, -4150.814, -4171.409000000001, -4191.812, -4212.023, -4232.038, -4251.856, -4271.474, -4290.891, -4310.104, -4329.111, -4347.91, -4366.498, -4384.874, -4403.035, -4420.978, -4438.702, -4456.2029999999995, -4473.479, -4490.529, -4507.348, -4523.936, -4540.288, -4556.403, -4572.278, -4587.909000000001, -4603.295, -4618.433, -4633.318, -4647.95, -4662.3240000000005, -4676.437, -4690.287, -4703.871, -4717.185, -4730.225, -4742.99, -4755.475, -4767.677, -4779.592000000001, -4791.218, -4802.55, -4813.585, -4824.318, -4834.748, -4844.8679999999995, -4854.6759999999995, -4864.168, -4873.339, -4882.185, -4890.702, -4898.8859999999995, -4906.733, -4914.237, -4921.394, -4928.2, -4934.65, -4940.738, -4946.46, -4951.812, -4956.786, -4961.38, -4965.585999999999, -4969.399, -4972.814, -4975.825, -4978.4259999999995, -4980.611, -4982.374, -4983.708, -4984.607, -4985.064, -4985.0740000000005, -4984.627, -4983.718, -4982.34, -4980.484, -4978.143, -4975.31, -4971.976, -4968.133, -4963.772, -4958.8859999999995, -4953.464, -4947.498, -4940.979, -4933.897, -4926.241, -4918.003, -4909.170999999999, -4899.734, -4889.683, -4879.004, -4867.687, -4855.72, -4843.090999999999, -4829.785, -4815.792, -4801.096, -4785.685, -4769.543, -4752.656, -4735.009, -4716.585999999999, -4697.371, -4677.346, -4656.496, -4634.802, -4612.245, -4588.806, -4564.467000000001, -4539.206, -4513.002, -4485.834, -4457.679, -4428.514, -4398.314, -4367.055, -4334.710999999999, -4301.254, -4266.657999999999, -4230.892, -4193.928, -4155.734, -4116.278, -4075.526, -4033.445, -3989.9970000000003, -3945.147, -3898.855, -3851.08, -3801.781, -3750.915, -3698.438, -3644.302, -3588.4590000000003, -3530.861, -3471.454, -3410.1859999999997, -3347.0009999999997, -3281.843, -3214.653, -3145.3709999999996, -3073.935, -3000.282, -2924.348, -2846.066, -2765.3720000000003, -2682.198, -2596.479, -2508.149, -2417.144, -2323.403, -2226.869, -2127.488, -2025.214, -1920.0079999999998, -1811.844, -1700.705, -1586.592, -1469.524, -1349.5439999999999, -1226.718, -1101.142, -972.949, -842.305, -709.419, -574.5419999999999, -437.973, -300.05, -161.16, -21.726999999999997, 117.791, 256.91, 395.12800000000004, 531.94, 666.847, 799.3710000000001, 929.062, 1055.513, 1178.363, 1297.306, 1412.092, 1522.526, 1628.471, 1729.8370000000002, 1826.5829999999999, 1918.7089999999998, 2006.25, 2089.271, 2167.859, 2242.123, 2312.1839999999997, 2378.174, 2440.234, 2498.507, 2553.138, 2604.2729999999997, 2652.0570000000002, 2696.631, 2738.132, 2776.6940000000004, 2812.446, 2845.513, 2876.013, 2904.06, 2929.763, 2953.225, 2974.546, 2993.8190000000004, 3011.134, 3026.575, 3040.223, 3052.153, 3062.44, 3071.151, 3078.3520000000003, 3084.1059999999998, 3088.4709999999995, 3091.5029999999997, 3093.255, 3093.7790000000005, 3093.1220000000003, 3091.33, 3088.447, 3084.513, 3079.57, 3073.653, 3066.8, 3059.0429999999997, 3050.417, 3040.952, 3030.678, 3019.6240000000003, 3007.816, 2995.281, 2982.0440000000003, 2968.1279999999997, 2953.5570000000002, 2938.3520000000003, 2922.534, 2906.1240000000003, 2889.14, 2871.6020000000003, 2853.527, 2834.9320000000002, 2815.8340000000003, 2796.2490000000003, 2776.192, 2755.677, 2734.719, 2713.3320000000003, 2691.528, 2669.321, 2646.722, 2623.743, 2600.396, 2576.692, 2552.641, 2528.254, 2503.54, 2478.509, 2453.1710000000003, 2427.534, 2401.6079999999997, 2375.4, 2348.919, 2322.172, 2295.1679999999997, 2267.9139999999998, 2240.416, 2212.683, 2184.721, 2156.536, 2128.135, 2099.525, 2070.7110000000002, 2041.6989999999998, 2012.494, 1983.104, 1953.5320000000002, 1923.7839999999999, 1893.866, 1863.7820000000002, 1833.5379999999998, 1803.1370000000002, 1772.586, 1741.8870000000002, 1711.046, 1680.067, 1648.954, 1617.711, 1586.3429999999998, 1554.8529999999998, 1523.245, 1491.5220000000002, 1459.6889999999999, 1427.749, 1395.705, 1363.5610000000001, 1331.32, 1298.985, 1266.5610000000001, 1234.049, 1201.452, 1168.775, 1136.019, 1103.188, 1070.285, 1037.3110000000001, 1004.2710000000001, 971.166, 937.9989999999999, 904.7739999999999, 871.4910000000001, 838.154, 804.7660000000001, 771.328, 737.842, 704.313, 670.74, 637.127, 603.477, 569.79, 536.069, 502.31699999999995, 468.534, 434.724, 400.889, 367.029, 333.148, 299.247, 265.328, 231.392, 197.442, 163.47899999999998, 129.506, 95.523, 61.533, 27.538, -6.462000000000001, -40.464, -74.467, -108.469, -142.468, -176.46400000000003, -210.453, -244.43599999999998, -278.41, -312.373, -346.325, -380.264, -414.18800000000005, -448.096, -481.98699999999997, -515.859, -549.71, -583.539, -617.346, -651.128, -684.8839999999999, -718.612, -752.313, -785.9830000000001, -819.622, -853.2289999999999, -886.802, -920.34, -953.841, -987.305, -1020.73, -1054.115, -1087.458, -1120.758, -1154.015, -1187.2269999999999, -1220.392, -1253.51, -1286.579, -1319.598, -1352.565, -1385.481, -1418.342, -1451.149, -1483.9, -1516.594, -1549.23, -1581.806, -1614.3210000000001, -1646.775, -1679.165, -1711.4920000000002, -1743.753, -1775.9470000000001, -1808.0739999999998, -1840.132, -1872.12, -1904.037, -1935.882, -1967.6529999999998, -1999.349, -2030.97, -2062.514, -2093.98, -2125.367, -2156.673, -2187.8979999999997, -2219.04, -2250.098, -2281.071, -2311.958, -2342.757, -2373.468, -2404.089, -2434.62, -2465.058, -2495.403, -2525.653, -2555.808, -2585.866, -2615.826, -2645.687, -2675.447, -2705.1059999999998, -2734.6609999999996, -2764.113, -2793.4590000000003, -2822.699, -2851.8309999999997, -2880.853, -2909.7659999999996, -2938.567, -2967.255, -2995.828, -3024.2870000000003, -3052.6279999999997, -3080.8520000000003, -3108.9559999999997, -3136.94, -3164.801, -3192.54, -3220.1540000000005, -3247.6409999999996, -3275.002, -3302.2329999999997, -3329.335, -3356.305, -3383.1420000000003, -3409.844, -3436.4109999999996, -3462.841, -3489.132, -3515.283, -3541.292, -3567.158, -3592.88, -3618.455, -3643.883, -3669.1620000000003, -3694.29, -3719.265, -3744.087, -3768.7529999999997, -3793.262, -3817.612, -3841.801, -3865.829, -3889.692, -3913.3909999999996, -3936.921, -3960.283, -3983.474, -4006.493, -4029.337, -4052.005, -4074.494, -4096.804, -4118.932, -4140.876, -4162.635, -4184.206, -4205.587, -4226.776, -4247.772, -4268.572, -4289.174, -4309.576, -4329.776, -4349.771, -4369.56, -4389.14, -4408.509, -4427.665, -4446.605, -4465.327, -4483.829000000001, -4502.107, -4520.16, -4537.985, -4555.58, -4572.942, -4590.068, -4606.956, -4623.602, -4640.005, -4656.162, -4672.069, -4687.723, -4703.123, -4718.264, -4733.144, -4747.76, -4762.109, -4776.186, -4789.99, -4803.517, -4816.763, -4829.725, -4842.4, -4854.784000000001, -4866.874, -4878.665, -4890.155, -4901.339, -4912.213, -4922.775, -4933.018, -4942.94, -4952.537, -4961.804, -4970.736, -4979.33, -4987.58, -4995.483, -5003.034000000001, -5010.227, -5017.058, -5023.523, -5029.615, -5035.33, -5040.662, -5045.607, -5050.157999999999, -5054.309, -5058.056, -5061.392, -5064.311, -5066.808, -5068.874, -5070.505999999999, -5071.694, -5072.434, -5072.717000000001, -5072.538, -5071.888, -5070.76, -5069.147, -5067.041, -5064.433, -5061.317, -5057.682, -5053.521, -5048.825, -5043.584, -5037.79, -5031.432, -5024.502, -5016.988, -5008.880999999999, -5000.17, -4990.844, -4980.892, -4970.302, -4959.062, -4947.16, -4934.583, -4921.319, -4907.354, -4892.675, -4877.267, -4861.115, -4844.204000000001, -4826.519, -4808.044, -4788.763, -4768.657, -4747.710999999999, -4725.904, -4703.22, -4679.637, -4655.1359999999995, -4629.697, -4603.2970000000005, -4575.915, -4547.528, -4518.111, -4487.64, -4456.09, -4423.433, -4389.644, -4354.692, -4318.55, -4281.185, -4242.567, -4202.662, -4161.437, -4118.856, -4074.883, -4029.4790000000003, -3982.605, -3934.219, -3884.2790000000005, -3832.741, -3779.558, -3724.685, -3668.07, -3609.664, -3549.413, -3487.262, -3423.156, -3357.0370000000003, -3288.843, -3218.513, -3145.9840000000004, -3071.192, -2994.071, -2914.551, -2832.567, -2748.05, -2660.9309999999996, -2571.144, -2478.6220000000003, -2383.302, -2285.125, -2184.034, -2079.982, -1972.9289999999999, -1862.842, -1749.707, -1633.521, -1514.3020000000001, -1392.09, -1266.951, -1138.982, -1008.312, -875.1089999999999, -739.5830000000001, -601.989, -462.62300000000005, -321.83299999999997, -180.00799999999998, -37.578, 104.98899999999999, 247.202, 388.54900000000004, 528.515, 666.59, 802.2819999999999, 935.13, 1064.714, 1190.663, 1312.66, 1430.444, 1543.8139999999999, 1652.6229999999998, 1756.777, 1856.229, 1950.975, 2041.0479999999998, 2126.511, 2207.451, 2283.9770000000003, 2356.21, 2424.284, 2488.34, 2548.525, 2604.985, 2657.869, 2707.323, 2753.492, 2796.515, 2836.5290000000005, 2873.665, 2908.05, 2939.8059999999996, 2969.048, 2995.888, 3020.4309999999996, 3042.7790000000005, 3063.067, 3081.268, 3097.586, 3112.066, 3124.784, 3135.816, 3145.2309999999998, 3153.0959999999995, 3159.4759999999997, 3164.4309999999996, 3168.0170000000003, 3170.289, 3171.3, 3171.099, 3169.7309999999998, 3167.243, 3163.676, 3159.072, 3153.467, 3146.9, 3139.405, 3131.0159999999996, 3121.765, 3111.6820000000002, 3100.797, 3089.136, 3076.728, 3063.598, 3049.7690000000002, 3035.2659999999996, 3020.112, 3004.3259999999996, 2987.9309999999996, 2970.945, 2953.388, 2935.2790000000005, 2916.634, 2897.472, 2877.8070000000002, 2857.656, 2837.034, 2815.955, 2794.433, 2772.482, 2750.115, 2727.344, 2704.1820000000002, 2680.64, 2656.728, 2632.46, 2607.844, 2582.891, 2557.611, 2532.013, 2506.107, 2479.901, 2453.405, 2426.627, 2399.574, 2372.255, 2344.677, 2316.848, 2288.775, 2260.464, 2231.924, 2203.159, 2174.178, 2144.985, 2115.5879999999997, 2085.991, 2056.201, 2026.224, 1996.0629999999999, 1965.726, 1935.217, 1904.5410000000002, 1873.703, 1842.7079999999999, 1811.56, 1780.265, 1748.825, 1717.246, 1685.5320000000002, 1653.6879999999999, 1621.7160000000001, 1589.621, 1557.4070000000002, 1525.0770000000002, 1492.636, 1460.0870000000002, 1427.432, 1394.6770000000001, 1361.8229999999999, 1328.875, 1295.835, 1262.708, 1229.494, 1196.1989999999998, 1162.825, 1129.374, 1095.849, 1062.254, 1028.5910000000001, 994.863, 961.072, 927.22, 893.312, 859.3480000000001, 825.332, 791.265, 757.1510000000001, 722.9910000000001, 688.788, 654.544, 620.261, 585.941, 551.5880000000001, 517.201, 482.785, 448.34, 413.86800000000005, 379.37300000000005, 344.855, 310.317, 275.76, 241.187, 206.59900000000002, 171.998, 137.385, 102.76299999999999, 68.134, 33.498000000000005, -1.141, -35.784, -70.42699999999999, -105.07, -139.71, -174.34599999999998, -208.977, -243.601, -278.216, -312.82099999999997, -347.415, -381.995, -416.56, -451.11, -485.642, -520.154, -554.6469999999999, -589.117, -623.564, -657.9860000000001, -692.383, -726.752, -761.092, -795.4019999999999, -829.68, -863.926, -898.137, -932.313, -966.452, -1000.554, -1034.615, -1068.636, -1102.616, -1136.552, -1170.443, -1204.289, -1238.088, -1271.839, -1305.54, -1339.191, -1372.79, -1406.335, -1439.8270000000002, -1473.2620000000002, -1506.642, -1539.963, -1573.225, -1606.4260000000002, -1639.566, -1672.6429999999998, -1705.6570000000002, -1738.605, -1771.487, -1804.3010000000002, -1837.046, -1869.7220000000002, -1902.3270000000002, -1934.859, -1967.318, -1999.7020000000002, -2032.011, -2064.242, -2096.396, -2128.469, -2160.4629999999997, -2192.375, -2224.203, -2255.948, -2287.607, -2319.18, -2350.665, -2382.061, -2413.368, -2444.5820000000003, -2475.705, -2506.7329999999997, -2537.667, -2568.505, -2599.245, -2629.886, -2660.428, -2690.869, -2721.2070000000003, -2751.442, -2781.572, -2811.5959999999995, -2841.513, -2871.321, -2901.0190000000002, -2930.6059999999998, -2960.08, -2989.441, -3018.687, -3047.816, -3076.828, -3105.7209999999995, -3134.493, -3163.1440000000002, -3191.672, -3220.075, -3248.353, -3276.5029999999997, -3304.525, -3332.417, -3360.177, -3387.805, -3415.298, -3442.656, -3469.877, -3496.9590000000003, -3523.901, -3550.702, -3577.3590000000004, -3603.8720000000003, -3630.239, -3656.458, -3682.527, -3708.446, -3734.2129999999997, -3759.825, -3785.282, -3810.5820000000003, -3835.723, -3860.703, -3885.52, -3910.1740000000004, -3934.6620000000003, -3958.9829999999997, -3983.134, -4007.114, -4030.921, -4054.554, -4078.01, -4101.288, -4124.3859999999995, -4147.3009999999995, -4170.032, -4192.5779999999995, -4214.935, -4237.102, -4259.077, -4280.858, -4302.443, -4323.829000000001, -4345.015, -4365.998, -4386.777, -4407.348, -4427.71, -4447.861, -4467.7970000000005, -4487.518, -4507.02, -4526.3, -4545.358, -4564.189, -4582.792, -4601.163, -4619.3009999999995, -4637.2029999999995, -4654.866, -4672.287, -4689.464, -4706.394, -4723.073, -4739.499, -4755.67, -4771.582, -4787.231, -4802.616, -4817.733, -4832.579000000001, -4847.15, -4861.442, -4875.454000000001, -4889.181, -4902.62, -4915.767, -4928.619000000001, -4941.173, -4953.423, -4965.367, -4977.001, -4988.321, -4999.323, -5010.002, -5020.355, -5030.377, -5040.065, -5049.413, -5058.417, -5067.072, -5075.375, -5083.319, -5090.901, -5098.115, -5104.956, -5111.42, -5117.5, -5123.191, -5128.488, -5133.3859999999995, -5137.878, -5141.958, -5145.621, -5148.861, -5151.67, -5154.044, -5155.974, -5157.455, -5158.48, -5159.041, -5159.130999999999, -5158.7429999999995, -5157.87, -5156.503, -5154.634, -5152.255999999999, -5149.361, -5145.938, -5141.981, -5137.479, -5132.424, -5126.806, -5120.615, -5113.840999999999, -5106.475, -5098.504, -5089.92, -5080.71, -5070.863, -5060.367, -5049.21, -5037.38, -5024.863, -5011.647, -4997.718, -4983.061, -4967.663, -4951.508, -4934.582, -4916.867, -4898.349, -4879.009, -4858.831, -4837.7970000000005, -4815.888, -4793.084, -4769.367, -4744.715, -4719.108, -4692.522, -4664.937, -4636.3279999999995, -4606.6720000000005, -4575.941, -4544.112, -4511.156, -4477.045, -4441.752, -4405.245, -4367.494000000001, -4328.465, -4288.127, -4246.443, -4203.377, -4158.893, -4112.951, -4065.511, -4016.531, -3965.967, -3913.7740000000003, -3859.905, -3804.312, -3746.945, -3687.7509999999997, -3626.676, -3563.664, -3498.658, -3431.598, -3362.423, -3291.0690000000004, -3217.472, -3141.565, -3063.28, -2982.5490000000004, -2899.301, -2813.467, -2724.9770000000003, -2633.763, -2539.7529999999997, -2442.885, -2343.095, -2240.327, -2134.529, -2025.661, -1913.6870000000001, -1798.5910000000001, -1680.3670000000002, -1559.0339999999999, -1434.628, -1307.214, -1176.889, -1043.781, -908.059, -769.932, -629.6569999999999, -487.535, -343.916, -199.19299999999998, -53.805, 91.777, 237.05, 381.494, 524.582, 665.794, 804.6260000000001, 940.605, 1073.3, 1202.328, 1327.359, 1448.126, 1564.4160000000002, 1676.076, 1783.005, 1885.1529999999998, 1982.51, 2075.1079999999997, 2163.008, 2246.295, 2325.078, 2399.479, 2469.636, 2535.687, 2597.783, 2656.072, 2710.704, 2761.8309999999997, 2809.595, 2854.1420000000003, 2895.61, 2934.132, 2969.8379999999997, 3002.853, 3033.2940000000003, 3061.275, 3086.9040000000005, 3110.283, 3131.512, 3150.6820000000002, 3167.883, 3183.2, 3196.711, 3208.492, 3218.618, 3227.1540000000005, 3234.1659999999997, 3239.716, 3243.863, 3246.6620000000003, 3248.167, 3248.427, 3247.492, 3245.405, 3242.212, 3237.954, 3232.6690000000003, 3226.395, 3219.1690000000003, 3211.025, 3201.995, 3192.111, 3181.403, 3169.8979999999997, 3157.625, 3144.6090000000004, 3130.8759999999997, 3116.449, 3101.3520000000003, 3085.607, 3069.2340000000004, 3052.255, 3034.688, 3016.553, 2997.868, 2978.6490000000003, 2958.913, 2938.677, 2917.9559999999997, 2896.764, 2875.117, 2853.028, 2830.509, 2807.575, 2784.238, 2760.509, 2736.4, 2711.922, 2687.086, 2661.903, 2636.383, 2610.534, 2584.368, 2557.893, 2531.117, 2504.05, 2476.7, 2449.075, 2421.183, 2393.031, 2364.627, 2335.978, 2307.09, 2277.972, 2248.629, 2219.067, 2189.2929999999997, 2159.313, 2129.133, 2098.759, 2068.196, 2037.4489999999998, 2006.524, 1975.4260000000002, 1944.1589999999999, 1912.73, 1881.142, 1849.401, 1817.51, 1785.475, 1753.299, 1720.987, 1688.543, 1655.97, 1623.274, 1590.457, 1557.524, 1524.4779999999998, 1491.3220000000001, 1458.0610000000001, 1424.6979999999999, 1391.236, 1357.6779999999999, 1324.027, 1290.287, 1256.462, 1222.553, 1188.563, 1154.497, 1120.356, 1086.144, 1051.863, 1017.5160000000001, 983.105, 948.6339999999999, 914.1039999999999, 879.518, 844.8789999999999, 810.189, 775.451, 740.6669999999999, 705.8380000000001, 670.9680000000001, 636.059, 601.112, 566.131, 531.116, 496.07099999999997, 460.99699999999996, 425.89599999999996, 390.77, 355.62199999999996, 320.453, 285.265, 250.06, 214.84, 179.606, 144.361, 109.10600000000001, 73.844, 38.575, 3.301, -31.975, -67.252, -102.529, -137.803, -173.074, -208.33900000000003, -243.597, -278.847, -314.086, -349.314, -384.529, -419.72900000000004, -454.912, -490.07800000000003, -525.225, -560.351, -595.455, -630.536, -665.591, -700.6210000000001, -735.622, -770.595, -805.5369999999999, -840.447, -875.324, -910.1669999999999, -944.9730000000001, -979.743, -1014.4739999999999, -1049.165, -1083.8139999999999, -1118.422, -1152.986, -1187.504, -1221.9769999999999, -1256.402, -1290.778, -1325.104, -1359.378, -1393.6, -1427.7679999999998, -1461.881, -1495.9379999999999, -1529.9370000000001, -1563.8770000000002, -1597.757, -1631.576, -1665.3329999999999, -1699.026, -1732.654, -1766.215, -1799.71, -1833.136, -1866.4920000000002, -1899.777, -1932.99, -1966.129, -1999.194, -2032.183, -2065.095, -2097.929, -2130.683, -2163.356, -2195.948, -2228.4570000000003, -2260.881, -2293.22, -2325.472, -2357.636, -2389.7110000000002, -2421.695, -2453.5879999999997, -2485.388, -2517.093, -2548.7039999999997, -2580.217, -2611.633, -2642.95, -2674.1659999999997, -2705.281, -2736.2929999999997, -2767.2009999999996, -2798.0029999999997, -2828.698, -2859.2859999999996, -2889.764, -2920.131, -2950.388, -2980.53, -3010.558, -3040.47, -3070.264, -3099.94, -3129.4959999999996, -3158.9309999999996, -3188.243, -3217.4309999999996, -3246.494, -3275.429, -3304.237, -3332.915, -3361.461, -3389.875, -3418.156, -3446.3, -3474.308, -3502.177, -3529.907, -3557.495, -3584.94, -3612.24, -3639.395, -3666.401, -3693.259, -3719.966, -3746.52, -3772.921, -3799.1659999999997, -3825.2529999999997, -3851.1820000000002, -3876.95, -3902.555, -3927.9959999999996, -3953.272, -3978.38, -4003.3190000000004, -4028.086, -4052.68, -4077.1, -4101.343, -4125.407, -4149.291, -4172.992, -4196.51, -4219.84, -4242.983, -4265.935, -4288.695, -4311.26, -4333.629, -4355.799, -4377.769, -4399.535, -4421.096, -4442.45, -4463.594, -4484.526, -4505.244000000001, -4525.746, -4546.028, -4566.089, -4585.925, -4605.536, -4624.917, -4644.067, -4662.983, -4681.662, -4700.101, -4718.299, -4736.251, -4753.956, -4771.41, -4788.61, -4805.554, -4822.2390000000005, -4838.661, -4854.818, -4870.706, -4886.322, -4901.662, -4916.725, -4931.505, -4946.001, -4960.208, -4974.122, -4987.741, -5001.06, -5014.076, -5026.785, -5039.183, -5051.267, -5063.031, -5074.473, -5085.588, -5096.372, -5106.82, -5116.928, -5126.692, -5136.107, -5145.168, -5153.87, -5162.209, -5170.18, -5177.778, -5184.997, -5191.832, -5198.278, -5204.33, -5209.981, -5215.227, -5220.06, -5224.476, -5228.468, -5232.03, -5235.155, -5237.837, -5240.069, -5241.845, -5243.156999999999, -5243.9980000000005, -5244.361, -5244.238, -5243.621999999999, -5242.504, -5240.877, -5238.732, -5236.061, -5232.855, -5229.105, -5224.802, -5219.937, -5214.499, -5208.479, -5201.867, -5194.653, -5186.8240000000005, -5178.372, -5169.282999999999, -5159.5470000000005, -5149.151, -5138.083, -5126.331, -5113.88, -5100.719, -5086.832, -5072.205, -5056.825, -5040.675, -5023.74, -5006.004, -4987.45, -4968.061, -4947.819, -4926.706, -4904.7029999999995, -4881.791, -4857.948, -4833.155, -4807.389, -4780.629, -4752.851, -4724.032, -4694.146, -4663.168, -4631.071, -4597.8279999999995, -4563.41, -4527.787, -4490.93, -4452.805, -4413.380999999999, -4372.623, -4330.495, -4286.96, -4241.981, -4195.517, -4147.528, -4097.971, -4046.8, -3993.97, -3939.434, -3883.1409999999996, -3825.04, -3765.078, -3703.199, -3639.347, -3573.4629999999997, -3505.486, -3435.353, -3362.998, -3288.357, -3211.36, -3131.938, -3050.0209999999997, -2965.538, -2878.4159999999997, -2788.585, -2695.97, -2600.504, -2502.118, -2400.748, -2296.3360000000002, -2188.827, -2078.178, -1964.3529999999998, -1847.332, -1727.109, -1603.6989999999998, -1477.1370000000002, -1347.489, -1214.847, -1079.3410000000001, -941.14, -800.454, -657.54, -512.702, -366.29400000000004, -218.71400000000003, -70.405, 78.153, 226.45, 373.95599999999996, 520.134, 664.452, 806.395, 945.4789999999999, 1081.259, 1213.3410000000001, 1341.3870000000002, 1465.1170000000002, 1584.31, 1698.806, 1808.499, 1913.33, 2013.289, 2108.403, 2198.732, 2284.36, 2365.395, 2441.962, 2514.196, 2582.241, 2646.245, 2706.362, 2762.743, 2815.54, 2864.902, 2910.974, 2953.897, 2993.808, 3030.8379999999997, 3065.114, 3096.756, 3125.882, 3152.599, 3177.014, 3199.2270000000003, 3219.333, 3237.421, 3253.579, 3267.888, 3280.426, 3291.2659999999996, 3300.478, 3308.1290000000004, 3314.28, 3318.994, 3322.3259999999996, 3324.3309999999997, 3325.06, 3324.563, 3322.886, 3320.073, 3316.1679999999997, 3311.21, 3305.237, 3298.2870000000003, 3290.395, 3281.594, 3271.9159999999997, 3261.393, 3250.051, 3237.92, 3225.027, 3211.3979999999997, 3197.0559999999996, 3182.025, 3166.329, 3149.988, 3133.0229999999997, 3115.455, 3097.302, 3078.5840000000003, 3059.317, 3039.5190000000002, 3019.2070000000003, 2998.395, 2977.1, 2955.336, 2933.117, 2910.4570000000003, 2887.368, 2863.865, 2839.958, 2815.66, 2790.9829999999997, 2765.9359999999997, 2740.532, 2714.78, 2688.69, 2662.2729999999997, 2635.5370000000003, 2608.492, 2581.146, 2553.508, 2525.5860000000002, 2497.388, 2468.923, 2440.197, 2411.218, 2381.994, 2352.53, 2322.834, 2292.913, 2262.7729999999997, 2232.419, 2201.859, 2171.097, 2140.14, 2108.992, 2077.661, 2046.15, 2014.464, 1982.61, 1950.592, 1918.414, 1886.082, 1853.599, 1820.971, 1788.201, 1755.2939999999999, 1722.254, 1689.0839999999998, 1655.79, 1622.374, 1588.8410000000001, 1555.194, 1521.4370000000001, 1487.5729999999999, 1453.606, 1419.539, 1385.375, 1351.119, 1316.7720000000002, 1282.338, 1247.82, 1213.221, 1178.5439999999999, 1143.792, 1108.9669999999999, 1074.073, 1039.113, 1004.0880000000001, 969.0010000000001, 933.855, 898.653, 863.3969999999999, 828.09, 792.7330000000001, 757.33, 721.882, 686.3919999999999, 650.862, 615.294, 579.691, 544.055, 508.38699999999994, 472.69, 436.966, 401.217, 365.444, 329.651, 293.83799999999997, 258.008, 222.162, 186.303, 150.43200000000002, 114.551, 78.66199999999999, 42.766999999999996, 6.867000000000001, -29.035999999999998, -64.94, -100.844, -136.745, -172.643, -208.53599999999997, -244.421, -280.298, -316.164, -352.019, -387.861, -423.68699999999995, -459.49800000000005, -495.29, -531.063, -566.816, -602.5459999999999, -638.252, -673.934, -709.5880000000001, -745.215, -780.812, -816.378, -851.9119999999999, -887.413, -922.8789999999999, -958.308, -993.7, -1029.052, -1064.364, -1099.635, -1134.863, -1170.046, -1205.184, -1240.274, -1275.317, -1310.31, -1345.2520000000002, -1380.142, -1414.979, -1449.761, -1484.487, -1519.1570000000002, -1553.767, -1588.318, -1622.808, -1657.236, -1691.601, -1725.901, -1760.135, -1794.3010000000002, -1828.4, -1862.4289999999999, -1896.386, -1930.2720000000002, -1964.085, -1997.8229999999999, -2031.485, -2065.07, -2098.576, -2132.0029999999997, -2165.35, -2198.614, -2231.795, -2264.8920000000003, -2297.903, -2330.827, -2363.663, -2396.409, -2429.064, -2461.6279999999997, -2494.098, -2526.474, -2558.754, -2590.937, -2623.022, -2655.007, -2686.8909999999996, -2718.673, -2750.3520000000003, -2781.925, -2813.393, -2844.7529999999997, -2876.005, -2907.147, -2938.177, -2969.095, -2999.8990000000003, -3030.587, -3061.159, -3091.612, -3121.946, -3152.16, -3182.2509999999997, -3212.218, -3242.06, -3271.776, -3301.363, -3330.823, -3360.151, -3389.3459999999995, -3418.408, -3447.335, -3476.125, -3504.777, -3533.289, -3561.66, -3589.888, -3617.972, -3645.9109999999996, -3673.7009999999996, -3701.343, -3728.8340000000003, -3756.173, -3783.357, -3810.387, -3837.259, -3863.972, -3890.5240000000003, -3916.914, -3943.14, -3969.2009999999996, -3995.093, -4020.816, -4046.368, -4071.7470000000003, -4096.951, -4121.979, -4146.827, -4171.495, -4195.981, -4220.282, -4244.396, -4268.323, -4292.058, -4315.601, -4338.95, -4362.102, -4385.055, -4407.807, -4430.355, -4452.698, -4474.834, -4496.76, -4518.473, -4539.972, -4561.254, -4582.317, -4603.157, -4623.774, -4644.164000000001, -4664.3240000000005, -4684.253, -4703.947, -4723.404, -4742.621, -4761.596, -4780.325, -4798.806, -4817.036, -4835.012, -4852.732, -4870.191, -4887.388, -4904.319, -4920.98, -4937.369000000001, -4953.483, -4969.318, -4984.87, -5000.137, -5015.115, -5029.8, -5044.189, -5058.278, -5072.063, -5085.541, -5098.707, -5111.559, -5124.090999999999, -5136.3, -5148.181, -5159.731, -5170.945, -5181.819, -5192.348, -5202.527, -5212.353, -5221.819, -5230.9220000000005, -5239.656, -5248.016, -5255.9980000000005, -5263.596, -5270.804, -5277.616999999999, -5284.03, -5290.036999999999, -5295.632, -5300.809, -5305.562, -5309.884, -5313.77, -5317.213000000001, -5320.205, -5322.741999999999, -5324.814, -5326.416, -5327.54, -5328.178000000001, -5328.323, -5327.967, -5327.102, -5325.72, -5323.812, -5321.369000000001, -5318.383000000001, -5314.845, -5310.745, -5306.073, -5300.821, -5294.977, -5288.531, -5281.473000000001, -5273.7919999999995, -5265.477, -5256.515, -5246.895, -5236.606, -5225.634, -5213.965, -5201.587, -5188.487, -5174.65, -5160.061, -5144.705, -5128.568, -5111.633, -5093.883, -5075.302, -5055.872, -5035.576, -5014.393, -4992.306, -4969.294, -4945.335999999999, -4920.412, -4894.499, -4867.575, -4839.616, -4810.597, -4780.495, -4749.281, -4716.929, -4683.411, -4648.6990000000005, -4612.7609999999995, -4575.566, -4537.083, -4497.278, -4456.115, -4413.559, -4369.571, -4324.1140000000005, -4277.145, -4228.625, -4178.508, -4126.749, -4073.302, -4018.116, -3961.143, -3902.33, -3841.6209999999996, -3778.961, -3714.292, -3647.553, -3578.6809999999996, -3507.615, -3434.285, -3358.6240000000003, -3280.5640000000003, -3200.034, -3116.96, -3031.27, -2942.89, -2851.7459999999996, -2757.765, -2660.8740000000003, -2561.004, -2458.089, -2352.067, -2242.884, -2130.491, -2014.8529999999998, -1895.9460000000001, -1773.764, -1648.317, -1519.642, -1387.8, -1252.885, -1115.024, -974.387, -831.184, -685.675, -538.165, -389.01099999999997, -238.61599999999999, -87.427, 64.067, 215.34900000000002, 365.88199999999995, 515.115, 662.507, 807.5310000000001, 949.691, 1088.53, 1223.644, 1354.683, 1481.3570000000002, 1603.4370000000001, 1720.754, 1833.1960000000001, 1940.701, 2043.2520000000002, 2140.874, 2233.624, 2321.5879999999997, 2404.871, 2483.598, 2557.907, 2627.9429999999998, 2693.855, 2755.7990000000004, 2813.929, 2868.3979999999997, 2919.3579999999997, 2966.9559999999997, 3011.337, 3052.638, 3090.995, 3126.5359999999996, 3159.383, 3189.657, 3217.467, 3242.922, 3266.155, 3287.1679999999997, 3306.1490000000003, 3323.155, 3338.2670000000003, 3351.566, 3363.1259999999997, 3373.0209999999997, 3381.315, 3388.075, 3393.362, 3397.2340000000004, 3399.745, 3400.95, 3400.8979999999997, 3399.637, 3397.2129999999997, 3393.6679999999997, 3389.0440000000003, 3383.38, 3376.7140000000004, 3369.0809999999997, 3360.5170000000003, 3351.053, 3340.722, 3329.552, 3317.572, 3304.81, 3291.292, 3277.0429999999997, 3262.087, 3246.448, 3230.147, 3213.2059999999997, 3195.645, 3177.4840000000004, 3158.741, 3139.4359999999997, 3119.5840000000003, 3099.204, 3078.3109999999997, 3056.922, 3035.05, 3012.71, 2989.917, 2966.683, 2943.0229999999997, 2918.948, 2894.47, 2869.6020000000003, 2844.3540000000003, 2818.738, 2792.764, 2766.4429999999998, 2739.784, 2712.797, 2685.491, 2657.875, 2629.9590000000003, 2601.75, 2573.257, 2544.488, 2515.45, 2486.151, 2456.599, 2426.8, 2396.762, 2366.49, 2335.993, 2305.275, 2274.344, 2243.2039999999997, 2211.863, 2180.325, 2148.596, 2116.6820000000002, 2084.5879999999997, 2052.319, 2019.88, 1987.276, 1954.511, 1921.5910000000001, 1888.52, 1855.3020000000001, 1821.942, 1788.443, 1754.8110000000001, 1721.049, 1687.161, 1653.15, 1619.021, 1584.7779999999998, 1550.4229999999998, 1515.961, 1481.395, 1446.7279999999998, 1411.964, 1377.106, 1342.1570000000002, 1307.12, 1271.998, 1236.795, 1201.513, 1166.155, 1130.724, 1095.222, 1059.654, 1024.02, 988.324, 952.569, 916.7560000000001, 880.8889999999999, 844.97, 809.0010000000001, 772.985, 736.924, 700.821, 664.677, 628.494, 592.276, 556.024, 519.741, 483.42699999999996, 447.087, 410.721, 374.33099999999996, 337.92, 301.48900000000003, 265.041, 228.577, 192.1, 155.61, 119.11, 82.602, 46.088, 9.568999999999999, -26.954, -63.477, -100.0, -136.52200000000002, -173.03900000000002, -209.551, -246.05599999999998, -282.552, -319.038, -355.51199999999994, -391.973, -428.418, -464.848, -501.259, -537.65, -574.021, -610.369, -646.693, -682.992, -719.2639999999999, -755.507, -791.721, -827.903, -864.053, -900.169, -936.2489999999999, -972.293, -1008.298, -1044.264, -1080.1889999999999, -1116.072, -1151.911, -1187.7060000000001, -1223.454, -1259.154, -1294.806, -1330.4070000000002, -1365.957, -1401.454, -1436.8970000000002, -1472.2839999999999, -1507.615, -1542.888, -1578.102, -1613.255, -1648.346, -1683.374, -1718.3370000000002, -1753.235, -1788.066, -1822.829, -1857.523, -1892.145, -1926.6960000000001, -1961.174, -1995.576, -2029.904, -2064.154, -2098.326, -2132.4179999999997, -2166.429, -2200.359, -2234.205, -2267.966, -2301.6420000000003, -2335.23, -2368.73, -2402.14, -2435.459, -2468.686, -2501.819, -2534.8579999999997, -2567.8, -2600.645, -2633.3920000000003, -2666.038, -2698.5820000000003, -2731.025, -2763.363, -2795.5959999999995, -2827.722, -2859.74, -2891.6490000000003, -2923.447, -2955.134, -2986.7070000000003, -3018.165, -3049.507, -3080.732, -3111.837, -3142.823, -3173.687, -3204.427, -3235.0429999999997, -3265.534, -3295.8959999999997, -3326.13, -3356.2340000000004, -3386.204, -3416.0429999999997, -3445.7459999999996, -3475.3140000000003, -3504.743, -3534.033, -3563.1820000000002, -3592.1890000000003, -3621.052, -3649.7690000000002, -3678.3390000000004, -3706.76, -3735.031, -3763.1490000000003, -3791.114, -3818.9240000000004, -3846.577, -3874.07, -3901.4040000000005, -3928.575, -3955.5820000000003, -3982.423, -4009.097, -4035.6009999999997, -4061.935, -4088.095, -4114.081, -4139.89, -4165.52, -4190.969, -4216.236, -4241.319, -4266.215, -4290.9220000000005, -4315.44, -4339.764, -4363.894, -4387.827, -4411.561, -4435.093, -4458.423, -4481.5470000000005, -4504.463, -4527.169, -4549.663, -4571.942, -4594.004, -4615.847, -4637.467000000001, -4658.863, -4680.032, -4700.971, -4721.678, -4742.151, -4762.3859999999995, -4782.380999999999, -4802.134, -4821.64, -4840.899, -4859.906, -4878.659000000001, -4897.155, -4915.39, -4933.363, -4951.069, -4968.505999999999, -4985.67, -5002.558, -5019.168, -5035.494000000001, -5051.535, -5067.286, -5082.745, -5097.907, -5112.768, -5127.326, -5141.576, -5155.514, -5169.137, -5182.441, -5195.420999999999, -5208.073, -5220.394, -5232.378, -5244.021, -5255.32, -5266.269, -5276.863, -5287.099, -5296.971, -5306.474, -5315.603, -5324.354, -5332.72, -5340.696999999999, -5348.279, -5355.460999999999, -5362.236, -5368.599, -5374.544, -5380.066, -5385.156999999999, -5389.811, -5394.023, -5397.785, -5401.09, -5403.932, -5406.304, -5408.198, -5409.607, -5410.524, -5410.939, -5410.846, -5410.236999999999, -5409.102, -5407.434, -5405.224, -5402.4619999999995, -5399.139, -5395.245, -5390.772, -5385.709, -5380.045999999999, -5373.771, -5366.875, -5359.347, -5351.174, -5342.345, -5332.847, -5322.669, -5311.798000000001, -5300.219, -5287.920999999999, -5274.889, -5261.108, -5246.564, -5231.241, -5215.123, -5198.196, -5180.44, -5161.840999999999, -5142.379, -5122.036, -5100.793, -5078.6320000000005, -5055.53, -5031.467000000001, -5006.4220000000005, -4980.373, -4953.295, -4925.166, -4895.959, -4865.651, -4834.213, -4801.619000000001, -4767.839, -4732.845, -4696.606, -4659.089, -4620.262, -4580.09, -4538.538, -4495.569, -4451.144, -4405.224, -4357.768, -4308.733, -4258.0740000000005, -4205.746, -4151.7, -4095.886, -4038.252, -3978.7459999999996, -3917.312, -3853.893, -3788.428, -3720.857, -3651.116, -3579.139, -3504.8579999999997, -3428.205, -3349.1090000000004, -3267.4970000000003, -3183.2940000000003, -3096.425, -3006.816, -2914.3909999999996, -2819.073, -2720.7909999999997, -2619.471, -2515.044, -2407.448, -2296.625, -2182.526, -2065.112, -1944.358, -1820.255, -1692.8129999999999, -1562.065, -1428.0710000000001, -1290.924, -1150.752, -1007.7230000000001, -862.048, -713.987, -563.8480000000001, -411.991, -258.822, -104.796, 49.593, 203.821, 357.339, 509.591, 660.0219999999999, 808.0939999999999, 953.299, 1095.17, 1233.289, 1367.295, 1496.891, 1621.838, 1741.9579999999999, 1857.1329999999998, 1967.295, 2072.425, 2172.5429999999997, 2267.7039999999997, 2357.993, 2443.516, 2524.399, 2600.776, 2672.797, 2740.614, 2804.381, 2864.256, 2920.395, 2972.952, 3022.075, 3067.913, 3110.605, 3150.289, 3187.0959999999995, 3221.15, 3252.572, 3281.4770000000003, 3307.974, 3332.167, 3354.156, 3374.033, 3391.889, 3407.809, 3421.873, 3434.159, 3444.739, 3453.683, 3461.0570000000002, 3466.922, 3471.3379999999997, 3474.363, 3476.0490000000004, 3476.449, 3475.61, 3473.58, 3470.402, 3466.118, 3460.77, 3454.3940000000002, 3447.0290000000005, 3438.7090000000003, 3429.467, 3419.335, 3408.343, 3396.522, 3383.8990000000003, 3370.5, 3356.3520000000003, 3341.4790000000003, 3325.905, 3309.652, 3292.743, 3275.197, 3257.0359999999996, 3238.278, 3218.942, 3199.046, 3178.607, 3157.6420000000003, 3136.1659999999997, 3114.196, 3091.745, 3068.828, 3045.4590000000003, 3021.65, 2997.4159999999997, 2972.768, 2947.718, 2922.2790000000005, 2896.46, 2870.2740000000003, 2843.73, 2816.8379999999997, 2789.6090000000004, 2762.053, 2734.177, 2705.992, 2677.505, 2648.7259999999997, 2619.663, 2590.323, 2560.714, 2530.843, 2500.719, 2470.348, 2439.736, 2408.891, 2377.819, 2346.526, 2315.019, 2283.303, 2251.384, 2219.268, 2186.9610000000002, 2154.468, 2121.794, 2088.944, 2055.924, 2022.737, 1989.39, 1955.886, 1922.23, 1888.4270000000001, 1854.48, 1820.395, 1786.175, 1751.8239999999998, 1717.346, 1682.746, 1648.026, 1613.191, 1578.244, 1543.1879999999999, 1508.0279999999998, 1472.767, 1437.4070000000002, 1401.953, 1366.4070000000002, 1330.773, 1295.053, 1259.251, 1223.369, 1187.411, 1151.38, 1115.277, 1079.107, 1042.87, 1006.572, 970.2130000000001, 933.796, 897.325, 860.801, 824.2260000000001, 787.6039999999999, 750.937, 714.2260000000001, 677.475, 640.685, 603.859, 566.998, 530.106, 493.184, 456.23400000000004, 419.25800000000004, 382.259, 345.23699999999997, 308.197, 271.138, 234.063, 196.975, 159.874, 122.76299999999999, 85.64399999999999, 48.518, 11.387, -25.747, -62.882, -100.01700000000001, -137.149, -174.278, -211.40099999999998, -248.518, -285.625, -322.722, -359.80800000000005, -396.879, -433.936, -470.975, -507.99699999999996, -544.999, -581.979, -618.937, -655.87, -692.778, -729.658, -766.5089999999999, -803.331, -840.1210000000001, -876.877, -913.6, -950.2860000000001, -986.935, -1023.546, -1060.116, -1096.645, -1133.131, -1169.573, -1205.97, -1242.319, -1278.62, -1314.872, -1351.0729999999999, -1387.221, -1423.316, -1459.356, -1495.339, -1531.266, -1567.1329999999998, -1602.94, -1638.6860000000001, -1674.369, -1709.987, -1745.5410000000002, -1781.0279999999998, -1816.4460000000001, -1851.796, -1887.075, -1922.2820000000002, -1957.4160000000002, -1992.476, -2027.46, -2062.367, -2097.195, -2131.945, -2166.613, -2201.199, -2235.702, -2270.12, -2304.452, -2338.696, -2372.8520000000003, -2406.9179999999997, -2440.893, -2474.776, -2508.564, -2542.258, -2575.855, -2609.354, -2642.7540000000004, -2676.053, -2709.2509999999997, -2742.3459999999995, -2775.336, -2808.22, -2840.998, -2873.6659999999997, -2906.225, -2938.673, -2971.008, -3003.2290000000003, -3035.3340000000003, -3067.323, -3099.1929999999998, -3130.9440000000004, -3162.573, -3194.0809999999997, -3225.4640000000004, -3256.722, -3287.853, -3318.855, -3349.728, -3380.469, -3411.078, -3441.552, -3471.8909999999996, -3502.092, -3532.1540000000005, -3562.0759999999996, -3591.8559999999998, -3621.492, -3650.9829999999997, -3680.327, -3709.522, -3738.5679999999998, -3767.461, -3796.2009999999996, -3824.7870000000003, -3853.215, -3881.485, -3909.594, -3937.542, -3965.3259999999996, -3992.9440000000004, -4020.395, -4047.677, -4074.788, -4101.726, -4128.4890000000005, -4155.076, -4181.484, -4207.712, -4233.7570000000005, -4259.6179999999995, -4285.292, -4310.778, -4336.0740000000005, -4361.177, -4386.085, -4410.795999999999, -4435.309, -4459.62, -4483.728, -4507.630999999999, -4531.326, -4554.81, -4578.082, -4601.14, -4623.98, -4646.601, -4668.999, -4691.174, -4713.121, -4734.838, -4756.323, -4777.5740000000005, -4798.587, -4819.359, -4839.889, -4860.173, -4880.209, -4899.9929999999995, -4919.523, -4938.795, -4957.807, -4976.556, -4995.039000000001, -5013.252, -5031.192, -5048.856, -5066.241, -5083.344, -5100.16, -5116.686, -5132.92, -5148.857, -5164.4929999999995, -5179.826, -5194.85, -5209.563, -5223.960999999999, -5238.038, -5251.793000000001, -5265.219, -5278.313, -5291.071, -5303.4890000000005, -5315.561, -5327.284000000001, -5338.651999999999, -5349.661, -5360.307, -5370.5830000000005, -5380.486, -5390.0109999999995, -5399.151, -5407.901999999999, -5416.258000000001, -5424.214, -5431.764, -5438.901999999999, -5445.621999999999, -5451.918000000001, -5457.785, -5463.215, -5468.203, -5472.741, -5476.8240000000005, -5480.443, -5483.593000000001, -5486.266, -5488.454000000001, -5490.15, -5491.347, -5492.035, -5492.2080000000005, -5491.857, -5490.973000000001, -5489.548000000001, -5487.571999999999, -5485.036999999999, -5481.933000000001, -5478.25, -5473.979, -5469.109, -5463.63, -5457.531, -5450.802, -5443.43, -5435.405, -5426.713000000001, -5417.343000000001, -5407.281999999999, -5396.517, -5385.036, -5372.823, -5359.865, -5346.147, -5331.654, -5316.37, -5300.28, -5283.368, -5265.615, -5247.004, -5227.518, -5207.137, -5185.843, -5163.616, -5140.433, -5116.275, -5091.119000000001, -5064.943, -5037.723, -5009.434, -4980.0509999999995, -4949.549, -4917.899, -4885.075, -4851.045999999999, -4815.782999999999, -4779.255, -4741.43, -4702.272, -4661.748, -4619.821, -4576.454000000001, -4531.608, -4485.2429999999995, -4437.316, -4387.782999999999, -4336.601, -4283.721, -4229.094, -4172.67, -4114.396, -4054.218, -3992.079, -3927.921, -3861.684, -3793.304, -3722.715, -3649.853, -3574.647, -3497.026, -3416.92, -3334.2529999999997, -3248.949, -3160.9309999999996, -3070.123, -2976.447, -2879.8259999999996, -2780.183, -2677.445, -2571.541, -2462.406, -2349.98, -2234.212, -2115.06, -1992.4979999999998, -1866.515, -1737.118, -1604.339, -1468.236, -1328.902, -1186.463, -1041.086, -892.9830000000001, -742.416, -589.694, -435.17900000000003, -279.284, -122.465, 34.775999999999996, 191.907, 348.371, 503.601, 657.0319999999999, 808.115, 956.331, 1101.1989999999998, 1242.2939999999999, 1379.241, 1511.7320000000002, 1639.5220000000002, 1762.4229999999998, 1880.3110000000001, 1993.114, 2100.805, 2203.404, 2300.965, 2393.5679999999998, 2481.32, 2564.348, 2642.7870000000003, 2716.7859999999996, 2786.5, 2852.086, 2913.702, 2971.507, 3025.657, 3076.305, 3123.598, 3167.68, 3208.69, 3246.763, 3282.025, 3314.597, 3344.599, 3372.139, 3397.3259999999996, 3420.26, 3441.0359999999996, 3459.7459999999996, 3476.4770000000003, 3491.3109999999997, 3504.3259999999996, 3515.597, 3525.195, 3533.187, 3539.636, 3544.6020000000003, 3548.145, 3550.3190000000004, 3551.176, 3550.765, 3549.135, 3546.3309999999997, 3542.395, 3537.368, 3531.2909999999997, 3524.2, 3516.131, 3507.117, 3497.192, 3486.388, 3474.732, 3462.256, 3448.985, 3434.946, 3420.164, 3404.663, 3388.467, 3371.598, 3354.0759999999996, 3335.923, 3317.159, 3297.801, 3277.869, 3257.38, 3236.3509999999997, 3214.7990000000004, 3192.739, 3170.185, 3147.153, 3123.657, 3099.711, 3075.3259999999996, 3050.5170000000003, 3025.296, 2999.6740000000004, 2973.6620000000003, 2947.2729999999997, 2920.5159999999996, 2893.402, 2865.941, 2838.1440000000002, 2810.018, 2781.574, 2752.82, 2723.764, 2694.417, 2664.784, 2634.875, 2604.697, 2574.257, 2543.563, 2512.621, 2481.439, 2450.022, 2418.379, 2386.514, 2354.4339999999997, 2322.145, 2289.652, 2256.962, 2224.08, 2191.012, 2157.761, 2124.335, 2090.737, 2056.972, 2023.046, 1988.9620000000002, 1954.726, 1920.342, 1885.8139999999999, 1851.1470000000002, 1816.344, 1781.4089999999999, 1746.3470000000002, 1711.162, 1675.8570000000002, 1640.435, 1604.901, 1569.2579999999998, 1533.51, 1497.66, 1461.711, 1425.6660000000002, 1389.53, 1353.3039999999999, 1316.9920000000002, 1280.598, 1244.123, 1207.5710000000001, 1170.9460000000001, 1134.248, 1097.483, 1060.651, 1023.7560000000001, 986.8, 949.7869999999999, 912.717, 875.595, 838.423, 801.202, 763.935, 726.625, 689.2739999999999, 651.884, 614.457, 576.996, 539.502, 501.97900000000004, 464.42699999999996, 426.85, 389.24800000000005, 351.625, 313.981, 276.32, 238.643, 200.951, 163.248, 125.53399999999999, 87.811, 50.082, 12.347999999999999, -25.389, -63.126999999999995, -100.865, -138.601, -176.333, -214.05900000000003, -251.778, -289.488, -327.188, -364.875, -402.54900000000004, -440.208, -477.849, -515.472, -553.075, -590.656, -628.215, -665.748, -703.2560000000001, -740.7360000000001, -778.186, -815.607, -852.995, -890.3489999999999, -927.669, -964.952, -1002.198, -1039.404, -1076.57, -1113.693, -1150.7730000000001, -1187.809, -1224.798, -1261.739, -1298.632, -1335.474, -1372.264, -1409.0020000000002, -1445.685, -1482.3120000000001, -1518.8829999999998, -1555.395, -1591.8470000000002, -1628.2379999999998, -1664.567, -1700.8310000000001, -1737.031, -1773.165, -1809.231, -1845.227, -1881.154, -1917.009, -1952.7910000000002, -1988.4979999999998, -2024.13, -2059.685, -2095.1620000000003, -2130.5589999999997, -2165.876, -2201.11, -2236.261, -2271.327, -2306.3070000000002, -2341.2, -2376.004, -2410.717, -2445.34, -2479.869, -2514.304, -2548.645, -2582.888, -2617.033, -2651.079, -2685.0240000000003, -2718.866, -2752.6059999999998, -2786.24, -2819.768, -2853.188, -2886.5, -2919.7, -2952.79, -2985.765, -3018.627, -3051.3720000000003, -3083.9990000000003, -3116.508, -3148.8959999999997, -3181.163, -3213.3059999999996, -3245.325, -3277.217, -3308.9809999999998, -3340.617, -3372.1209999999996, -3403.494, -3434.732, -3465.836, -3496.802, -3527.63, -3558.3179999999998, -3588.865, -3619.268, -3649.527, -3679.639, -3709.603, -3739.4179999999997, -3769.0809999999997, -3798.591, -3827.946, -3857.145, -3886.1859999999997, -3915.067, -3943.7859999999996, -3972.342, -4000.732, -4028.9559999999997, -4057.01, -4084.8940000000002, -4112.606, -4140.142, -4167.503, -4194.685, -4221.687, -4248.5070000000005, -4275.142, -4301.590999999999, -4327.852, -4353.923, -4379.8009999999995, -4405.484, -4430.971, -4456.259, -4481.347, -4506.231, -4530.909000000001, -4555.38, -4579.64, -4603.689, -4627.522, -4651.139, -4674.535, -4697.71, -4720.661, -4743.384, -4765.878, -4788.14, -4810.167, -4831.957, -4853.505999999999, -4874.812, -4895.873, -4916.685, -4937.246, -4957.552, -4977.601, -4997.39, -5016.916, -5036.175, -5055.164000000001, -5073.880999999999, -5092.322, -5110.483, -5128.362, -5145.955, -5163.258, -5180.268, -5196.981, -5213.394, -5229.503, -5245.304, -5260.794, -5275.968000000001, -5290.821999999999, -5305.353, -5319.556, -5333.427, -5346.9619999999995, -5360.156999999999, -5373.005999999999, -5385.505999999999, -5397.651999999999, -5409.439, -5420.861999999999, -5431.9169999999995, -5442.598000000001, -5452.901, -5462.819, -5472.349, -5481.484, -5490.219, -5498.549, -5506.468000000001, -5513.969, -5521.047, -5527.695, -5533.908, -5539.678000000001, -5545.0, -5549.866999999999, -5554.271, -5558.206999999999, -5561.666, -5564.641, -5567.126, -5569.111, -5570.59, -5571.554, -5571.995, -5571.905, -5571.275, -5570.096, -5568.358, -5566.054, -5563.172, -5559.704000000001, -5555.639, -5550.965999999999, -5545.6759999999995, -5539.757, -5533.1990000000005, -5525.9890000000005, -5518.116, -5509.566999999999, -5500.33, -5490.393, -5479.741, -5468.361999999999, -5456.241, -5443.3640000000005, -5429.715999999999, -5415.281, -5400.045, -5383.99, -5367.1, -5349.357, -5330.745, -5311.243, -5290.834, -5269.496999999999, -5247.214, -5223.960999999999, -5199.717000000001, -5174.460999999999, -5148.169, -5120.817, -5092.38, -5062.833, -5032.149, -5000.3009999999995, -4967.259, -4932.994000000001, -4897.477, -4860.674, -4822.554, -4783.081, -4742.22, -4699.935, -4656.187, -4610.937, -4564.143, -4515.762, -4465.751, -4414.064, -4360.651, -4305.464, -4248.451, -4189.558, -4128.73, -4065.909, -4001.0359999999996, -3934.05, -3864.884, -3793.475, -3719.7529999999997, -3643.6479999999997, -3565.0879999999997, -3484.0009999999997, -3400.308, -3313.9320000000002, -3224.797, -3132.822, -3037.928, -2940.0359999999996, -2839.0690000000004, -2734.949, -2627.605, -2516.969, -2402.98, -2285.5820000000003, -2164.735, -2040.4070000000002, -1912.5870000000002, -1781.279, -1646.514, -1508.349, -1366.874, -1222.215, -1074.538, -924.057, -771.0319999999999, -615.775, -458.652, -300.077, -140.512, 19.535, 179.523, 338.89, 497.05800000000005, 653.45, 807.508, 958.7, 1106.535, 1250.5739999999998, 1390.434, 1525.796, 1656.405, 1782.067, 1902.649, 2018.0739999999998, 2128.314, 2233.381, 2333.328, 2428.234, 2518.2070000000003, 2603.371, 2683.865, 2759.837, 2831.4429999999998, 2898.844, 2962.198, 3021.667, 3077.408, 3129.578, 3178.3259999999996, 3223.798, 3266.135, 3305.474, 3341.9440000000004, 3375.6690000000003, 3406.7690000000002, 3435.3559999999998, 3461.594, 3485.421, 3507.1, 3526.6679999999997, 3544.2140000000004, 3559.821, 3573.571, 3585.5370000000003, 3595.7940000000003, 3604.409, 3611.447, 3616.97, 3621.0370000000003, 3623.704, 3625.0240000000003, 3625.0490000000004, 3623.8259999999996, 3621.402, 3617.82, 3613.123, 3607.35, 3600.54, 3592.73, 3583.953, 3574.244, 3563.633, 3552.152, 3539.83, 3526.695, 3512.7729999999997, 3498.091, 3482.672, 3466.5409999999997, 3449.72, 3432.232, 3414.0959999999995, 3395.3340000000003, 3375.9640000000004, 3356.005, 3335.4759999999997, 3314.3920000000003, 3292.772, 3270.632, 3247.986, 3224.848, 3201.235, 3177.16, 3152.635, 3127.675, 3102.292, 3076.4970000000003, 3050.303, 3023.72, 2996.76, 2969.434, 2941.752, 2913.723, 2885.357, 2856.664, 2827.652, 2798.3320000000003, 2768.71, 2738.795, 2708.597, 2678.1209999999996, 2647.3759999999997, 2616.369, 2585.1079999999997, 2553.599, 2521.849, 2489.865, 2457.653, 2425.22, 2392.571, 2359.7129999999997, 2326.651, 2293.391, 2259.938, 2226.298, 2192.476, 2158.4770000000003, 2124.306, 2089.969, 2055.468, 2020.81, 1985.999, 1951.04, 1915.935, 1880.691, 1845.3110000000001, 1809.7979999999998, 1774.158, 1738.3929999999998, 1702.5079999999998, 1666.506, 1630.391, 1594.1670000000001, 1557.8370000000002, 1521.404, 1484.872, 1448.244, 1411.523, 1374.713, 1337.816, 1300.835, 1263.775, 1226.636, 1189.423, 1152.139, 1114.785, 1077.365, 1039.881, 1002.336, 964.732, 927.073, 889.3610000000001, 851.597, 813.785, 775.927, 738.025, 700.082, 662.1, 624.08, 586.026, 547.94, 509.82300000000004, 471.67800000000005, 433.506, 395.311, 357.094, 318.856, 280.601, 242.329, 204.043, 165.745, 127.43700000000001, 89.12, 50.797, 12.468, -25.863000000000003, -64.196, -102.52799999999999, -140.858, -179.18400000000003, -217.50400000000002, -255.817, -294.121, -332.414, -370.694, -408.961, -447.212, -485.44599999999997, -523.661, -561.856, -600.029, -638.179, -676.303, -714.4010000000001, -752.471, -790.5110000000001, -828.5210000000001, -866.497, -904.44, -942.3480000000001, -980.2180000000001, -1018.05, -1055.8419999999999, -1093.593, -1131.302, -1168.9660000000001, -1206.585, -1244.157, -1281.681, -1319.155, -1356.578, -1393.9479999999999, -1431.265, -1468.526, -1505.731, -1542.878, -1579.965, -1616.9920000000002, -1653.957, -1690.859, -1727.6960000000001, -1764.467, -1801.17, -1837.805, -1874.369, -1910.862, -1947.283, -1983.629, -2019.9, -2056.094, -2092.21, -2128.246, -2164.202, -2200.076, -2235.866, -2271.571, -2307.19, -2342.721, -2378.1639999999998, -2413.5170000000003, -2448.777, -2483.945, -2519.019, -2553.9970000000003, -2588.8779999999997, -2623.6609999999996, -2658.344, -2692.925, -2727.405, -2761.78, -2796.05, -2830.2129999999997, -2864.268, -2898.2140000000004, -2932.0490000000004, -2965.7709999999997, -2999.38, -3032.873, -3066.25, -3099.509, -3132.6479999999997, -3165.6659999999997, -3198.5609999999997, -3231.333, -3263.9790000000003, -3296.498, -3328.888, -3361.1479999999997, -3393.277, -3425.2729999999997, -3457.134, -3488.8590000000004, -3520.446, -3551.8940000000002, -3583.2, -3614.365, -3645.385, -3676.259, -3706.985, -3737.563, -3767.989, -3798.263, -3828.383, -3858.347, -3888.153, -3917.7990000000004, -3947.284, -3976.607, -4005.764, -4034.755, -4063.577, -4092.2290000000003, -4120.708, -4149.014, -4177.143, -4205.095, -4232.866, -4260.456, -4287.861, -4315.081, -4342.113, -4368.954000000001, -4395.604, -4422.059, -4448.317, -4474.378, -4500.237, -4525.893, -4551.344, -4576.588, -4601.621, -4626.443, -4651.05, -4675.44, -4699.61, -4723.559, -4747.284000000001, -4770.781, -4794.05, -4817.085999999999, -4839.887, -4862.451, -4884.776, -4906.857, -4928.693, -4950.28, -4971.616, -4992.698, -5013.523, -5034.088, -5054.389, -5074.424, -5094.19, -5113.683, -5132.9, -5151.839, -5170.494000000001, -5188.8640000000005, -5206.944, -5224.731, -5242.222, -5259.4130000000005, -5276.299, -5292.878000000001, -5309.146, -5325.098000000001, -5340.731, -5356.04, -5371.022, -5385.672, -5399.986999999999, -5413.96, -5427.59, -5440.87, -5453.795999999999, -5466.3640000000005, -5478.568, -5490.404, -5501.866999999999, -5512.951999999999, -5523.654, -5533.967, -5543.8859999999995, -5553.405, -5562.519, -5571.223000000001, -5579.51, -5587.374, -5594.81, -5601.811, -5608.37, -5614.482, -5620.139, -5625.335, -5630.063, -5634.316, -5638.085, -5641.365, -5644.148, -5646.425, -5648.188, -5649.43, -5650.142, -5650.315, -5649.941999999999, -5649.012, -5647.516, -5645.445, -5642.79, -5639.539000000001, -5635.684, -5631.213000000001, -5626.116, -5620.382, -5614.0, -5606.956999999999, -5599.241, -5590.84, -5581.741999999999, -5571.933000000001, -5561.4, -5550.13, -5538.107, -5525.318, -5511.746, -5497.378000000001, -5482.196, -5466.184, -5449.3240000000005, -5431.601, -5412.995, -5393.486999999999, -5373.058000000001, -5351.689, -5329.358, -5306.044, -5281.726, -5256.38, -5229.983, -5202.5109999999995, -5173.938, -5144.238, -5113.3859999999995, -5081.351, -5048.105, -5013.6179999999995, -4977.859, -4940.7970000000005, -4902.396, -4862.623, -4821.441, -4778.814, -4734.702, -4689.064, -4641.859, -4593.043, -4542.572, -4490.398, -4436.474, -4380.747, -4323.165, -4263.675, -4202.219, -4138.7390000000005, -4073.1740000000004, -4005.4629999999997, -3935.5370000000003, -3863.3320000000003, -3788.777, -3711.801, -3632.3309999999997, -3550.289, -3465.6, -3378.184, -3287.9629999999997, -3194.8540000000003, -3098.775, -2999.647, -2897.39, -2791.926, -2683.179, -2571.081, -2455.5679999999998, -2336.5820000000003, -2214.08, -2088.029, -1958.4160000000002, -1825.243, -1688.537, -1548.3570000000002, -1404.789, -1257.9569999999999, -1108.03, -955.22, -799.7869999999999, -642.0459999999999, -482.36199999999997, -321.156, -158.894, 3.911, 166.71200000000002, 328.935, 489.996, 649.308, 806.301, 960.433, 1111.1989999999998, 1258.15, 1400.8929999999998, 1539.098, 1672.499, 1800.899, 1924.154, 2042.183, 2154.951, 2262.47, 2364.7889999999998, 2461.986, 2554.1679999999997, 2641.458, 2723.9970000000003, 2801.934, 2875.426, 2944.634, 3009.7209999999995, 3070.849, 3128.178, 3181.867, 3232.067, 3278.927, 3322.591, 3363.195, 3400.873, 3435.7509999999997, 3467.95, 3497.585, 3524.7670000000003, 3549.599, 3572.1820000000002, 3592.61, 3610.975, 3627.36, 3641.847, 3654.513, 3665.433, 3674.675, 3682.3070000000002, 3688.3920000000003, 3692.988, 3696.1540000000005, 3697.9440000000004, 3698.409, 3697.6, 3695.562, 3692.341, 3687.98, 3682.5190000000002, 3675.998, 3668.453, 3659.92, 3650.433, 3640.025, 3628.7259999999997, 3616.566, 3603.575, 3589.7790000000005, 3575.204, 3559.8759999999997, 3543.8190000000004, 3527.055, 3509.6079999999997, 3491.4990000000003, 3472.7490000000003, 3453.375, 3433.3990000000003, 3412.8379999999997, 3391.71, 3370.031, 3347.8190000000004, 3325.0890000000004, 3301.8559999999998, 3278.136, 3253.941, 3229.2859999999996, 3204.185, 3178.6490000000003, 3152.692, 3126.325, 3099.559, 3072.407, 3044.8779999999997, 3016.9840000000004, 2988.7340000000004, 2960.139, 2931.2070000000003, 2901.949, 2872.373, 2842.488, 2812.302, 2781.824, 2751.062, 2720.0229999999997, 2688.7140000000004, 2657.1440000000002, 2625.3190000000004, 2593.2470000000003, 2560.933, 2528.385, 2495.609, 2462.611, 2429.3979999999997, 2395.974, 2362.347, 2328.521, 2294.502, 2260.2960000000003, 2225.907, 2191.341, 2156.6020000000003, 2121.696, 2086.6279999999997, 2051.401, 2016.02, 1980.491, 1944.816, 1909.001, 1873.049, 1836.965, 1800.7520000000002, 1764.414, 1727.9560000000001, 1691.381, 1654.692, 1617.892, 1580.987, 1543.9779999999998, 1506.87, 1469.665, 1432.368, 1394.98, 1357.505, 1319.9460000000001, 1282.307, 1244.589, 1206.797, 1168.932, 1130.998, 1092.997, 1054.932, 1016.805, 978.62, 940.3789999999999, 902.084, 863.738, 825.3430000000001, 786.9019999999999, 748.4169999999999, 709.89, 671.323, 632.72, 594.082, 555.411, 516.7090000000001, 477.97900000000004, 439.223, 400.44300000000004, 361.64099999999996, 322.818, 283.97700000000003, 245.12, 206.24900000000002, 167.36599999999999, 128.472, 89.57, 50.661, 11.748, -27.169, -66.086, -105.00299999999999, -143.918, -182.828, -221.733, -260.63, -299.518, -338.395, -377.259, -416.10900000000004, -454.944, -493.76, -532.558, -571.335, -610.09, -648.82, -687.5260000000001, -726.204, -764.8539999999999, -803.4739999999999, -842.063, -880.618, -919.1389999999999, -957.6239999999999, -996.072, -1034.48, -1072.848, -1111.175, -1149.458, -1187.6960000000001, -1225.888, -1264.0330000000001, -1302.128, -1340.1729999999998, -1378.1660000000002, -1416.106, -1453.9920000000002, -1491.8210000000001, -1529.5929999999998, -1567.306, -1604.9589999999998, -1642.55, -1680.078, -1717.5420000000001, -1754.941, -1792.2720000000002, -1829.535, -1866.7279999999998, -1903.849, -1940.899, -1977.874, -2014.774, -2051.597, -2088.343, -2125.009, -2161.594, -2198.097, -2234.5170000000003, -2270.8520000000003, -2307.101, -2343.262, -2379.334, -2415.3160000000003, -2451.206, -2487.004, -2522.706, -2558.313, -2593.823, -2629.2340000000004, -2664.545, -2699.755, -2734.861, -2769.864, -2804.761, -2839.551, -2874.232, -2908.803, -2943.263, -2977.61, -3011.843, -3045.96, -3079.96, -3113.841, -3147.6020000000003, -3181.241, -3214.757, -3248.1490000000003, -3281.414, -3314.551, -3347.56, -3380.437, -3413.1820000000002, -3445.7929999999997, -3478.2690000000002, -3510.607, -3542.8070000000002, -3574.866, -3606.784, -3638.558, -3670.1859999999997, -3701.6679999999997, -3733.0009999999997, -3764.184, -3795.216, -3826.093, -3856.815, -3887.38, -3917.7859999999996, -3948.031, -3978.113, -4008.031, -4037.783, -4067.367, -4096.781, -4126.023, -4155.092000000001, -4183.985, -4212.7, -4241.236, -4269.59, -4297.7609999999995, -4325.746, -4353.544, -4381.151, -4408.568, -4435.79, -4462.816, -4489.643, -4516.271, -4542.695, -4568.915, -4594.927, -4620.73, -4646.321, -4671.698, -4696.858, -4721.799, -4746.519, -4771.014, -4795.282999999999, -4819.323, -4843.130999999999, -4866.704000000001, -4890.041, -4913.138, -4935.992, -4958.601, -4980.960999999999, -5003.071, -5024.927, -5046.526, -5067.865, -5088.941, -5109.751, -5130.292, -5150.56, -5170.553, -5190.267, -5209.698, -5228.844, -5247.701999999999, -5266.266, -5284.534000000001, -5302.5019999999995, -5320.1669999999995, -5337.524, -5354.57, -5371.3009999999995, -5387.714, -5403.803000000001, -5419.565, -5434.995, -5450.09, -5464.846, -5479.257, -5493.319, -5507.028, -5520.379, -5533.366999999999, -5545.986999999999, -5558.235, -5570.105, -5581.593000000001, -5592.691999999999, -5603.398, -5613.706, -5623.609, -5633.102, -5642.179, -5650.834, -5659.062, -5666.855, -5674.209, -5681.116, -5687.569, -5693.562, -5699.088000000001, -5704.14, -5708.710999999999, -5712.793000000001, -5716.379, -5719.46, -5722.03, -5724.08, -5725.602, -5726.5869999999995, -5727.026999999999, -5726.911999999999, -5726.234, -5724.982, -5723.149, -5720.722, -5717.694, -5714.052, -5709.786999999999, -5704.887, -5699.342, -5693.139, -5686.268, -5678.714, -5670.467, -5661.513000000001, -5651.839, -5641.431, -5630.275, -5618.357, -5605.661999999999, -5592.174, -5577.878000000001, -5562.758000000001, -5546.795999999999, -5529.975, -5512.279, -5493.687, -5474.182, -5453.741999999999, -5432.349, -5409.981, -5386.616999999999, -5362.234, -5336.809, -5310.318, -5282.736999999999, -5254.039000000001, -5224.1990000000005, -5193.189, -5160.98, -5127.544, -5092.848, -5056.863, -5019.554, -4980.888, -4940.83, -4899.343, -4856.39, -4811.929, -4765.920999999999, -4718.323, -4669.090999999999, -4618.178, -4565.537, -4511.12, -4454.874, -4396.745, -4336.678, -4274.617, -4210.501, -4144.268, -4075.8559999999998, -4005.196, -3932.2209999999995, -3856.86, -3779.04, -3698.6859999999997, -3615.7209999999995, -3530.067, -3441.6420000000003, -3350.366, -3256.1540000000005, -3158.926, -3058.597, -2955.087, -2848.3140000000003, -2738.203, -2624.6809999999996, -2507.6839999999997, -2387.152, -2263.038, -2135.3089999999997, -2003.9470000000001, -1868.953, -1730.355, -1588.207, -1442.594, -1293.641, -1141.514, -986.424, -828.635, -668.46, -506.26800000000003, -342.48199999999997, -177.575, -12.062000000000001, 153.502, 318.53700000000003, 482.445, 644.633, 804.5189999999999, 961.548, 1115.208, 1265.036, 1410.6270000000002, 1551.644, 1687.8110000000001, 1818.921, 1944.825, 2065.4339999999997, 2180.7110000000002, 2290.663, 2395.337, 2494.81, 2589.186, 2678.591, 2763.163, 2843.055, 2918.423, 2989.4309999999996, 3056.244, 3119.025, 3177.937, 3233.1409999999996, 3284.789, 3333.033, 3378.02, 3419.889, 3458.7740000000003, 3494.803, 3528.1009999999997, 3558.785, 3586.966, 3612.75, 3636.239, 3657.53, 3676.715, 3693.88, 3709.107, 3722.4770000000003, 3734.0640000000003, 3743.938, 3752.1679999999997, 3758.8190000000004, 3763.95, 3767.62, 3769.884, 3770.796, 3770.406, 3768.761, 3765.907, 3761.888, 3756.7459999999996, 3750.52, 3743.248, 3734.967, 3725.7090000000003, 3715.511, 3704.401, 3692.4120000000003, 3679.573, 3665.91, 3651.4509999999996, 3636.222, 3620.2470000000003, 3603.55, 3586.153, 3568.079, 3549.349, 3529.9809999999998, 3509.9959999999996, 3489.413, 3468.2490000000003, 3446.522, 3424.2490000000003, 3401.445, 3378.1259999999997, 3354.308, 3330.0040000000004, 3305.2290000000003, 3279.9959999999996, 3254.3179999999998, 3228.208, 3201.679, 3174.741, 3147.406, 3119.685, 3091.59, 3063.13, 3034.316, 3005.156, 2975.6620000000003, 2945.841, 2915.704, 2885.257, 2854.511, 2823.473, 2792.15, 2760.551, 2728.683, 2696.553, 2664.1679999999997, 2631.5359999999996, 2598.663, 2565.556, 2532.22, 2498.663, 2464.89, 2430.906, 2396.719, 2362.333, 2327.7529999999997, 2292.986, 2258.036, 2222.908, 2187.6079999999997, 2152.14, 2116.509, 2080.719, 2044.775, 2008.682, 1972.444, 1936.0639999999999, 1899.547, 1862.898, 1826.12, 1789.2160000000001, 1752.192, 1715.049, 1677.793, 1640.4270000000001, 1602.953, 1565.3770000000002, 1527.7, 1489.9260000000002, 1452.059, 1414.101, 1376.056, 1337.9270000000001, 1299.7169999999999, 1261.428, 1223.0639999999999, 1184.627, 1146.121, 1107.548, 1068.91, 1030.211, 991.453, 952.638, 913.7689999999999, 874.8489999999999, 835.88, 796.865, 757.805, 718.703, 679.562, 640.384, 601.17, 561.924, 522.6469999999999, 483.342, 444.01, 404.654, 365.276, 325.877, 286.461, 247.028, 207.582, 168.123, 128.653, 89.176, 49.691, 10.203, -29.289, -68.782, -108.274, -147.763, -187.24900000000002, -226.72799999999998, -266.199, -305.661, -345.111, -384.54900000000004, -423.972, -463.38, -502.769, -542.138, -581.487, -620.813, -660.115, -699.3910000000001, -738.64, -777.8589999999999, -817.048, -856.206, -895.329, -934.418, -973.47, -1012.4839999999999, -1051.458, -1090.392, -1129.282, -1168.129, -1206.931, -1245.685, -1284.392, -1323.0479999999998, -1361.654, -1400.2060000000001, -1438.705, -1477.148, -1515.5339999999999, -1553.862, -1592.131, -1630.338, -1668.4820000000002, -1706.5629999999999, -1744.578, -1782.527, -1820.408, -1858.219, -1895.9589999999998, -1933.626, -1971.221, -2008.74, -2046.182, -2083.547, -2120.833, -2158.038, -2195.161, -2232.2, -2269.155, -2306.0229999999997, -2342.804, -2379.496, -2416.098, -2452.6079999999997, -2489.025, -2525.347, -2561.573, -2597.702, -2633.732, -2669.6609999999996, -2705.489, -2741.2140000000004, -2776.835, -2812.349, -2847.756, -2883.054, -2918.242, -2953.3179999999998, -2988.281, -3023.1279999999997, -3057.86, -3092.474, -3126.969, -3161.343, -3195.594, -3229.722, -3263.725, -3297.6009999999997, -3331.348, -3364.965, -3398.4509999999996, -3431.804, -3465.022, -3498.1040000000003, -3531.047, -3563.8509999999997, -3596.514, -3629.034, -3661.41, -3693.639, -3725.7209999999995, -3757.653, -3789.433, -3821.0609999999997, -3852.534, -3883.85, -3915.008, -3946.006, -3976.842, -4007.514, -4038.0209999999997, -4068.36, -4098.53, -4128.529, -4158.354, -4188.004, -4217.477, -4246.771, -4275.885, -4304.815, -4333.56, -4362.1179999999995, -4390.486, -4418.664000000001, -4446.648, -4474.436, -4502.026, -4529.417, -4556.605, -4583.588, -4610.365, -4636.933, -4663.289000000001, -4689.432, -4715.358, -4741.065, -4766.5509999999995, -4791.814, -4816.851, -4841.657999999999, -4866.235, -4890.577, -4914.682, -4938.549, -4962.173, -4985.552, -5008.683, -5031.564, -5054.191, -5076.562, -5098.673, -5120.522, -5142.105, -5163.419, -5184.460999999999, -5205.228, -5225.715999999999, -5245.923000000001, -5265.844, -5285.477, -5304.816999999999, -5323.861999999999, -5342.608, -5361.05, -5379.186, -5397.01, -5414.52, -5431.7119999999995, -5448.581, -5465.124, -5481.335999999999, -5497.2119999999995, -5512.75, -5527.944, -5542.79, -5557.283, -5571.418000000001, -5585.191999999999, -5598.598000000001, -5611.633000000001, -5624.291, -5636.566999999999, -5648.456, -5659.951999999999, -5671.05, -5681.745, -5692.031, -5701.901999999999, -5711.353, -5720.376, -5728.967, -5737.118, -5744.8240000000005, -5752.078, -5758.874, -5765.203, -5771.06, -5776.437, -5781.326999999999, -5785.722, -5789.615, -5792.9980000000005, -5795.861999999999, -5798.201, -5800.004, -5801.264, -5801.972, -5802.119000000001, -5801.695, -5800.691, -5799.097, -5796.904, -5794.1, -5790.6759999999995, -5786.62, -5781.922, -5776.57, -5770.552, -5763.856, -5756.47, -5748.380999999999, -5739.576, -5730.0419999999995, -5719.765, -5708.73, -5696.923000000001, -5684.329000000001, -5670.931, -5656.715999999999, -5641.665, -5625.7609999999995, -5608.986999999999, -5591.326, -5572.757, -5553.262, -5532.821, -5511.414000000001, -5489.019, -5465.6140000000005, -5441.177, -5415.684, -5389.111, -5361.432, -5332.621, -5302.653, -5271.4980000000005, -5239.129, -5205.514, -5170.624, -5134.427, -5096.887, -5057.971, -5017.644, -4975.8679999999995, -4932.604, -4887.814, -4841.4529999999995, -4793.48, -4743.849, -4692.514, -4639.427, -4584.538, -4527.793, -4469.139, -4408.519, -4345.875, -4281.147, -4214.271, -4145.183, -4073.8140000000003, -4000.097, -3923.958, -3845.322, -3764.114, -3680.257, -3593.6679999999997, -3504.2659999999996, -3411.967, -3316.69, -3218.3459999999995, -3116.8520000000003, -3012.1259999999997, -2904.0840000000003, -2792.6479999999997, -2677.745, -2559.305, -2437.269, -2311.5879999999997, -2182.225, -2049.1620000000003, -1912.3970000000002, -1771.955, -1627.889, -1480.2820000000002, -1329.259, -1174.985, -1017.669, -857.576, -695.0219999999999, -530.377, -364.065, -196.563, -28.394000000000002, 139.881, 307.675, 474.38300000000004, 639.401, 802.135, 962.02, 1118.5339999999999, 1271.2, 1419.606, 1563.402, 1702.3039999999999, 1836.095, 1964.622, 2087.7889999999998, 2205.553, 2317.919, 2424.93, 2526.6620000000003, 2623.219, 2714.723, 2801.3179999999998, 2883.153, 2960.388, 3033.188, 3101.718, 3166.147, 3226.635, 3283.348, 3336.441, 3386.066, 3432.3740000000003, 3475.505, 3515.595, 3552.776, 3587.173, 3618.9040000000005, 3648.2009999999996, 3674.821, 3699.219, 3721.3740000000003, 3741.381, 3759.328, 3775.301, 3789.377, 3801.635, 3812.145, 3820.978, 3828.198, 3833.869, 3838.048, 3840.7929999999997, 3842.157, 3842.192, 3840.946, 3838.466, 3834.796, 3829.9790000000003, 3824.0559999999996, 3817.0640000000003, 3809.04, 3800.0209999999997, 3790.039, 3779.1279999999997, 3767.317, 3754.637, 3741.117, 3726.783, 3711.6620000000003, 3695.778, 3679.156, 3661.8179999999998, 3643.788, 3625.086, 3605.7329999999997, 3585.7490000000003, 3565.153, 3543.9640000000004, 3522.198, 3499.873, 3477.005, 3453.61, 3429.705, 3405.302, 3380.4179999999997, 3355.0640000000003, 3329.2540000000004, 3303.002, 3276.321, 3249.22, 3221.7140000000004, 3193.813, 3165.527, 3136.868, 3107.845, 3078.469, 3048.7490000000003, 3018.695, 2988.316, 2957.62, 2926.616, 2895.313, 2863.718, 2831.8390000000004, 2799.684, 2767.261, 2734.577, 2701.638, 2668.4509999999996, 2635.0240000000003, 2601.362, 2567.473, 2533.361, 2499.033, 2464.496, 2429.754, 2394.814, 2359.68, 2324.3579999999997, 2288.853, 2253.1710000000003, 2217.315, 2181.292, 2145.105, 2108.759, 2072.259, 2035.609, 1998.8139999999999, 1961.8770000000002, 1924.8029999999999, 1887.596, 1850.26, 1812.7979999999998, 1775.215, 1737.513, 1699.6979999999999, 1661.7720000000002, 1623.739, 1585.601, 1547.364, 1509.03, 1470.601, 1432.082, 1393.476, 1354.7839999999999, 1316.0120000000002, 1277.161, 1238.234, 1199.234, 1160.165, 1121.028, 1081.827, 1042.563, 1003.2410000000001, 963.862, 924.429, 884.944, 845.41, 805.83, 766.205, 726.538, 686.831, 647.087, 607.308, 567.497, 527.654, 487.783, 447.88599999999997, 407.964, 368.02, 328.056, 288.074, 248.076, 208.063, 168.03900000000002, 128.004, 87.961, 47.912, 7.858, -32.199, -72.257, -112.31299999999999, -152.36700000000002, -192.416, -232.459, -272.494, -312.519, -352.533, -392.534, -432.519, -472.48800000000006, -512.439, -552.37, -592.28, -632.1669999999999, -672.028, -711.8639999999999, -751.672, -791.45, -831.198, -870.9119999999999, -910.5930000000001, -950.238, -989.846, -1029.415, -1068.945, -1108.432, -1147.876, -1187.276, -1226.629, -1265.935, -1305.192, -1344.398, -1383.5529999999999, -1422.654, -1461.7, -1500.6889999999999, -1539.621, -1578.494, -1617.306, -1656.056, -1694.7420000000002, -1733.364, -1771.9189999999999, -1810.406, -1848.825, -1887.172, -1925.4479999999999, -1963.65, -2001.7779999999998, -2039.829, -2077.803, -2115.697, -2153.511, -2191.244, -2228.8920000000003, -2266.4570000000003, -2303.935, -2341.325, -2378.627, -2415.8379999999997, -2452.9570000000003, -2489.9829999999997, -2526.915, -2563.75, -2600.488, -2637.127, -2673.665, -2710.1020000000003, -2746.435, -2782.663, -2818.785, -2854.8, -2890.705, -2926.5, -2962.1820000000002, -2997.7509999999997, -3033.204, -3068.5409999999997, -3103.76, -3138.8590000000004, -3173.837, -3208.692, -3243.422, -3278.027, -3312.5040000000004, -3346.8520000000003, -3381.0690000000004, -3415.155, -3449.1059999999998, -3482.922, -3516.6009999999997, -3550.1409999999996, -3583.5409999999997, -3616.7990000000004, -3649.913, -3682.881, -3715.703, -3748.3759999999997, -3780.8979999999997, -3813.268, -3845.4840000000004, -3877.5440000000003, -3909.446, -3941.1890000000003, -3972.7709999999997, -4004.19, -4035.4429999999998, -4066.53, -4097.4490000000005, -4128.197, -4158.772, -4189.173, -4219.397, -4249.443, -4279.308, -4308.992, -4338.49, -4367.802, -4396.9259999999995, -4425.858, -4454.598, -4483.143, -4511.49, -4539.638, -4567.584, -4595.327, -4622.863, -4650.19, -4677.306, -4704.21, -4730.897, -4757.366, -4783.615, -4809.64, -4835.44, -4861.0109999999995, -4886.352, -4911.459, -4936.33, -4960.963, -4985.353, -5009.499, -5033.398, -5057.0470000000005, -5080.442, -5103.582, -5126.462, -5149.081, -5171.434, -5193.519, -5215.333, -5236.872, -5258.133000000001, -5279.113, -5299.808000000001, -5320.214, -5340.33, -5360.15, -5379.670999999999, -5398.89, -5417.802, -5436.404, -5454.693, -5472.664000000001, -5490.313, -5507.6359999999995, -5524.629, -5541.286999999999, -5557.608, -5573.585, -5589.215, -5604.493, -5619.415, -5633.975, -5648.169, -5661.993, -5675.44, -5688.505999999999, -5701.186, -5713.475, -5725.366999999999, -5736.856, -5747.938, -5758.605, -5768.854, -5778.6759999999995, -5788.068, -5797.021, -5805.53, -5813.589, -5821.19, -5828.326999999999, -5834.993, -5841.181, -5846.884, -5852.094, -5856.804, -5861.005, -5864.69, -5867.851, -5870.48, -5872.566999999999, -5874.105, -5875.0830000000005, -5875.494000000001, -5875.326999999999, -5874.573, -5873.223000000001, -5871.265, -5868.69, -5865.486, -5861.644, -5857.151, -5851.996999999999, -5846.168000000001, -5839.653, -5832.44, -5824.515, -5815.865, -5806.477, -5796.335999999999, -5785.428000000001, -5773.7390000000005, -5761.2519999999995, -5747.953, -5733.8240000000005, -5718.85, -5703.012, -5686.293000000001, -5668.675, -5650.139, -5630.664000000001, -5610.231, -5588.82, -5566.408, -5542.973000000001, -5518.493, -5492.941999999999, -5466.298000000001, -5438.533, -5409.621999999999, -5379.5380000000005, -5348.253000000001, -5315.736, -5281.9580000000005, -5246.888000000001, -5210.492, -5172.737, -5133.588, -5093.008, -5050.959, -5007.403, -4962.3, -4915.605, -4867.276, -4817.266, -4765.53, -4712.017, -4656.677, -4599.456, -4540.299, -4479.149, -4415.947, -4350.6320000000005, -4283.138, -4213.401, -4141.351, -4066.9190000000003, -3990.03, -3910.6090000000004, -3828.578, -3743.8590000000004, -3656.368, -3566.0229999999997, -3472.738, -3376.429, -3277.007, -3174.386, -3068.4840000000004, -2959.212, -2846.493, -2730.2509999999997, -2610.413, -2486.919, -2359.717, -2228.768, -2094.052, -1955.565, -1813.33, -1667.399, -1517.852, -1364.8129999999999, -1208.4460000000001, -1048.96, -886.62, -721.743, -554.6990000000001, -385.917, -215.877, -45.107, 125.82799999999999, 296.329, 465.786, 633.5840000000001, 799.1210000000001, 961.819, 1121.144, 1276.612, 1427.795, 1574.336, 1715.94, 1852.385, 1983.5079999999998, 2109.2070000000003, 2229.436, 2344.195, 2453.5229999999997, 2557.4970000000003, 2656.218, 2749.81, 2838.4120000000003, 2922.18, 3001.2709999999997, 3075.8540000000003, 3146.094, 3212.1620000000003, 3274.2209999999995, 3332.437, 3386.97, 3437.973, 3485.597, 3529.988, 3571.281, 3609.611, 3645.1059999999998, 3677.885, 3708.065, 3735.756, 3761.062, 3784.0840000000003, 3804.9159999999997, 3823.6479999999997, 3840.366, 3855.1540000000005, 3868.085, 3879.235, 3888.675, 3896.47, 3902.684, 3907.3779999999997, 3910.6090000000004, 3912.43, 3912.8959999999997, 3912.055, 3909.955, 3906.6409999999996, 3902.156, 3896.542, 3889.837, 3882.079, 3873.305, 3863.548, 3852.842, 3841.218, 3828.7070000000003, 3815.336, 3801.135, 3786.13, 3770.3459999999995, 3753.808, 3736.539, 3718.562, 3699.8990000000003, 3680.57, 3660.597, 3639.998, 3618.792, 3596.9970000000003, 3574.63, 3551.7090000000003, 3528.2490000000003, 3504.2659999999996, 3479.775, 3454.79, 3429.3259999999996, 3403.395, 3377.012, 3350.1890000000003, 3322.938, 3295.2709999999997, 3267.199, 3238.7340000000004, 3209.886, 3180.667, 3151.085, 3121.152, 3090.875, 3060.2659999999996, 3029.3320000000003, 2998.0820000000003, 2966.526, 2934.67, 2902.5240000000003, 2870.095, 2837.39, 2804.417, 2771.183, 2737.695, 2703.9590000000003, 2669.9840000000004, 2635.7729999999997, 2601.3360000000002, 2566.676, 2531.801, 2496.715, 2461.426, 2425.938, 2390.256, 2354.386, 2318.333, 2282.1020000000003, 2245.699, 2209.127, 2172.391, 2135.4970000000003, 2098.448, 2061.249, 2023.905, 1986.4189999999999, 1948.795, 1911.0379999999998, 1873.152, 1835.14, 1797.006, 1758.754, 1720.388, 1681.911, 1643.326, 1604.6370000000002, 1565.848, 1526.9620000000002, 1487.981, 1448.9089999999999, 1409.75, 1370.506, 1331.18, 1291.776, 1252.296, 1212.742, 1173.119, 1133.428, 1093.673, 1053.855, 1013.9780000000001, 974.045, 934.057, 894.0169999999999, 853.929, 813.793, 773.613, 733.3910000000001, 693.1289999999999, 652.83, 612.496, 572.128, 531.73, 491.30400000000003, 450.851, 410.374, 369.875, 329.356, 288.819, 248.265, 207.69799999999998, 167.11900000000003, 126.529, 85.932, 45.328, 4.72, -35.891, -76.502, -117.11200000000001, -157.719, -198.322, -238.918, -279.505, -320.08299999999997, -360.648, -401.2, -441.73699999999997, -482.25699999999995, -522.758, -563.24, -603.6990000000001, -644.134, -684.545, -724.929, -765.284, -805.61, -845.904, -886.165, -926.3910000000001, -966.581, -1006.7330000000001, -1046.846, -1086.9189999999999, -1126.948, -1166.934, -1206.875, -1246.769, -1286.614, -1326.41, -1366.154, -1405.846, -1445.483, -1485.0639999999999, -1524.588, -1564.0539999999999, -1603.4589999999998, -1642.8029999999999, -1682.0839999999998, -1721.3, -1760.451, -1799.5339999999999, -1838.5479999999998, -1877.4920000000002, -1916.365, -1955.164, -1993.889, -2032.5379999999998, -2071.109, -2109.601, -2148.014, -2186.344, -2224.591, -2262.754, -2300.831, -2338.82, -2376.72, -2414.53, -2452.248, -2489.873, -2527.403, -2564.837, -2602.173, -2639.4109999999996, -2676.547, -2713.5820000000003, -2750.513, -2787.3390000000004, -2824.058, -2860.67, -2897.172, -2933.563, -2969.842, -3006.006, -3042.055, -3077.987, -3113.801, -3149.494, -3185.065, -3220.514, -3255.837, -3291.034, -3326.103, -3361.042, -3395.85, -3430.526, -3465.066, -3499.4709999999995, -3533.737, -3567.865, -3601.8509999999997, -3635.6940000000004, -3669.393, -3702.946, -3736.35, -3769.605, -3802.7090000000003, -3835.659, -3868.455, -3901.093, -3933.573, -3965.893, -3998.05, -4030.0429999999997, -4061.87, -4093.5290000000005, -4125.018, -4156.335999999999, -4187.48, -4218.448, -4249.238, -4279.849, -4310.278, -4340.523, -4370.582, -4400.454000000001, -4430.135, -4459.624, -4488.919, -4518.017, -4546.916, -4575.6140000000005, -4604.109, -4632.398, -4660.479, -4688.35, -4716.008, -4743.451, -4770.677, -4797.682, -4824.465, -4851.023, -4877.354, -4903.454000000001, -4929.321, -4954.9529999999995, -4980.346, -5005.499, -5030.407, -5055.069, -5079.482, -5103.642, -5127.5470000000005, -5151.193, -5174.5779999999995, -5197.6990000000005, -5220.5509999999995, -5243.133000000001, -5265.441, -5287.472, -5309.222, -5330.688, -5351.866999999999, -5372.755, -5393.348000000001, -5413.643, -5433.6359999999995, -5453.3240000000005, -5472.703, -5491.769, -5510.517, -5528.945, -5547.047, -5564.821, -5582.2609999999995, -5599.363, -5616.1230000000005, -5632.536999999999, -5648.6, -5664.307, -5679.655, -5694.637, -5709.25, -5723.486999999999, -5737.344, -5750.816999999999, -5763.899, -5776.585999999999, -5788.871, -5800.75, -5812.217, -5823.265, -5833.89, -5844.084, -5853.842, -5863.156999999999, -5872.023, -5880.434, -5888.383000000001, -5895.861999999999, -5902.865, -5909.384, -5915.4130000000005, -5920.944, -5925.969, -5930.479, -5934.468000000001, -5937.9259999999995, -5940.846, -5943.219, -5945.035, -5946.286999999999, -5946.964, -5947.056, -5946.556, -5945.451, -5943.732, -5941.388000000001, -5938.409000000001, -5934.784000000001, -5930.5, -5925.547, -5919.911999999999, -5913.5830000000005, -5906.547, -5898.791, -5890.3009999999995, -5881.064, -5871.066, -5860.291, -5848.726, -5836.353, -5823.158, -5809.124, -5794.234, -5778.47, -5761.814, -5744.246999999999, -5725.7519999999995, -5706.306, -5685.891, -5664.484, -5642.065, -5618.61, -5594.098000000001, -5568.501, -5541.797, -5513.9580000000005, -5484.959, -5454.772, -5423.369000000001, -5390.718000000001, -5356.79, -5321.555, -5284.975, -5247.02, -5207.652, -5166.835, -5124.531, -5080.7, -5035.3009999999995, -4988.291, -4939.624, -4889.255999999999, -4837.137, -4783.219, -4727.45, -4669.774, -4610.137, -4548.48, -4484.744000000001, -4418.866, -4350.78, -4280.42, -4207.715999999999, -4132.598, -4054.987, -3974.81, -3891.988, -3806.4390000000003, -3718.078, -3626.823, -3532.587, -3435.281, -3334.817, -3231.1090000000004, -3124.067, -3013.607, -2899.647, -2782.1059999999998, -2660.914, -2536.007, -2407.33, -2274.843, -2138.524, -1998.365, -1854.39, -1706.644, -1555.211, -1400.211, -1241.805, -1080.2060000000001, -915.677, -748.5319999999999, -579.1469999999999, -407.95300000000003, -235.43200000000002, -62.117, 111.42, 284.575, 456.728, 627.255, 795.544, 961.008, 1123.099, 1281.322, 1435.243, 1584.49, 1728.763, 1867.826, 2001.514, 2129.717, 2252.384, 2369.511, 2481.134, 2587.3289999999997, 2688.1940000000004, 2783.855, 2874.45, 2960.135, 3041.0690000000004, 3117.422, 3189.361, 3257.0570000000002, 3320.678, 3380.39, 3436.3559999999998, 3488.73, 3537.6659999999997, 3583.3109999999997, 3625.804, 3665.281, 3701.8709999999996, 3735.696, 3766.8740000000003, 3795.5170000000003, 3821.732, 3845.6209999999996, 3867.278, 3886.797, 3904.263, 3919.762, 3933.3709999999996, 3945.164, 3955.2129999999997, 3963.587, 3970.349, 3975.562, 3979.282, 3981.567, 3982.469, 3982.038, 3980.324, 3977.3709999999996, 3973.224, 3967.926, 3961.5159999999996, 3954.031, 3945.509, 3935.9840000000004, 3925.491, 3914.062, 3901.7259999999997, 3888.515, 3874.455, 3859.575, 3843.8990000000003, 3827.454, 3810.262, 3792.347, 3773.732, 3754.438, 3734.4840000000004, 3713.8920000000003, 3692.679, 3670.865, 3648.467, 3625.502, 3601.986, 3577.937, 3553.367, 3528.2940000000003, 3502.73, 3476.6890000000003, 3450.185, 3423.232, 3395.84, 3368.0240000000003, 3339.7929999999997, 3311.16, 3282.136, 3252.73, 3222.955, 3192.8190000000004, 3162.3320000000003, 3131.5040000000004, 3100.344, 3068.861, 3037.063, 3004.9590000000003, 2972.5570000000002, 2939.864, 2906.89, 2873.6409999999996, 2840.1240000000003, 2806.3459999999995, 2772.315, 2738.038, 2703.52, 2668.768, 2633.789, 2598.5879999999997, 2563.172, 2527.5460000000003, 2491.715, 2455.686, 2419.464, 2383.053, 2346.46, 2309.689, 2272.745, 2235.632, 2198.356, 2160.9210000000003, 2123.3320000000003, 2085.592, 2047.707, 2009.68, 1971.515, 1933.217, 1894.79, 1856.236, 1817.5610000000001, 1778.767, 1739.859, 1700.84, 1661.713, 1622.4820000000002, 1583.151, 1543.721, 1504.1979999999999, 1464.5839999999998, 1424.881, 1385.094, 1345.225, 1305.277, 1265.253, 1225.156, 1184.99, 1144.755, 1104.4560000000001, 1064.094, 1023.673, 983.195, 942.663, 902.079, 861.446, 820.7660000000001, 780.041, 739.275, 698.4680000000001, 657.625, 616.746, 575.8340000000001, 534.8919999999999, 493.921, 452.92400000000004, 411.903, 370.85900000000004, 329.796, 288.715, 247.618, 206.507, 165.38400000000001, 124.251, 83.111, 41.964, 0.813, -40.34, -81.494, -122.646, -163.795, -204.93900000000002, -246.076, -287.204, -328.32199999999995, -369.42800000000005, -410.52, -451.596, -492.655, -533.695, -574.714, -615.711, -656.684, -697.6310000000001, -738.551, -779.443, -820.303, -861.132, -901.927, -942.686, -983.409, -1024.094, -1064.738, -1105.3410000000001, -1145.901, -1186.417, -1226.886, -1267.308, -1307.681, -1348.003, -1388.2720000000002, -1428.489, -1468.65, -1508.754, -1548.8010000000002, -1588.7879999999998, -1628.713, -1668.5770000000002, -1708.376, -1748.11, -1787.777, -1827.375, -1866.904, -1906.361, -1945.746, -1985.056, -2024.2910000000002, -2063.448, -2102.527, -2141.526, -2180.444, -2219.278, -2258.028, -2296.692, -2335.268, -2373.756, -2412.153, -2450.459, -2488.6710000000003, -2526.7889999999998, -2564.81, -2602.734, -2640.558, -2678.282, -2715.9040000000005, -2753.422, -2790.835, -2828.1409999999996, -2865.3390000000004, -2902.427, -2939.4040000000005, -2976.268, -3013.018, -3049.652, -3086.1690000000003, -3122.566, -3158.843, -3194.998, -3231.0290000000005, -3266.935, -3302.7140000000004, -3338.364, -3373.885, -3409.2729999999997, -3444.528, -3479.6479999999997, -3514.631, -3549.4759999999997, -3584.18, -3618.743, -3653.163, -3687.437, -3721.5640000000003, -3755.542, -3789.37, -3823.045, -3856.567, -3889.9320000000002, -3923.14, -3956.188, -3989.075, -4021.7990000000004, -4054.357, -4086.748, -4118.971, -4151.022, -4182.901, -4214.604, -4246.130999999999, -4277.479, -4308.646, -4339.63, -4370.429, -4401.041, -4431.463, -4461.695, -4491.731, -4521.5740000000005, -4551.217000000001, -4580.66, -4609.901, -4638.936, -4667.765, -4696.384, -4724.791, -4752.983, -4780.959, -4808.715999999999, -4836.25, -4863.561, -4890.644, -4917.498, -4944.12, -4970.5070000000005, -4996.657, -5022.566, -5048.232, -5073.652, -5098.8240000000005, -5123.744000000001, -5148.409000000001, -5172.817, -5196.964, -5220.847, -5244.464, -5267.81, -5290.884, -5313.681, -5336.198, -5358.432, -5380.379, -5402.036, -5423.4, -5444.467, -5465.233, -5485.694, -5505.846, -5525.687, -5545.210999999999, -5564.416, -5583.295999999999, -5601.848000000001, -5620.068, -5637.951, -5655.493, -5672.69, -5689.536999999999, -5706.03, -5722.1630000000005, -5737.933000000001, -5753.334, -5768.361999999999, -5783.0109999999995, -5797.276, -5811.151999999999, -5824.635, -5837.717, -5850.395, -5862.661999999999, -5874.512, -5885.94, -5896.939, -5907.503000000001, -5917.6269999999995, -5927.303000000001, -5936.526, -5945.2880000000005, -5953.5830000000005, -5961.404, -5968.744000000001, -5975.595, -5981.95, -5987.802, -5993.142, -5997.9619999999995, -6002.255999999999, -6006.014, -6009.226, -6011.8859999999995, -6013.983, -6015.509, -6016.454000000001, -6016.809, -6016.563, -6015.706999999999, -6014.23, -6012.121999999999, -6009.37, -6005.965, -6001.896, -5997.148, -5991.710999999999, -5985.571999999999, -5978.717, -5971.135, -5962.811, -5953.731, -5943.880999999999, -5933.246, -5921.81, -5909.559, -5896.476, -5882.543000000001, -5867.745, -5852.062, -5835.477, -5817.971, -5799.525, -5780.118, -5759.73, -5738.339, -5715.923000000001, -5692.459, -5667.923000000001, -5642.2919999999995, -5615.539000000001, -5587.639, -5558.565, -5528.289000000001, -5496.78, -5464.01, -5429.946999999999, -5394.559, -5357.812, -5319.672, -5280.103, -5239.066, -5196.524, -5152.435, -5106.759, -5059.452, -5010.468, -4959.7609999999995, -4907.281, -4852.979, -4796.803, -4738.696, -4678.602, -4616.463, -4552.218, -4485.803, -4417.152, -4346.196, -4272.867, -4197.09, -4118.789000000001, -4037.888, -3954.305, -3867.958, -3778.764, -3686.634, -3591.4809999999998, -3493.217, -3391.75, -3286.992, -3178.8540000000003, -3067.248, -2952.0890000000004, -2833.296, -2710.797, -2584.524, -2454.4210000000003, -2320.448, -2182.575, -2040.7979999999998, -1895.134, -1745.632, -1592.369, -1435.464, -1275.0810000000001, -1111.427, -944.7669999999999, -775.4169999999999, -603.753, -430.20599999999996, -255.264, -79.464, 96.617, 272.368, 447.162, 620.364, 791.3530000000001, 959.5319999999999, 1124.3419999999999, 1285.278, 1441.8929999999998, 1593.808, 1740.71, 1882.359, 2018.578, 2149.256, 2274.333, 2393.802, 2507.698, 2616.092, 2719.0820000000003, 2816.7929999999997, 2909.366, 2996.952, 3079.717, 3157.8259999999996, 3231.453, 3300.768, 3365.942, 3427.1420000000003, 3484.533, 3538.2729999999997, 3588.515, 3635.4109999999996, 3679.099, 3719.72, 3757.402, 3792.2709999999997, 3824.455, 3854.0429999999997, 3881.1659999999997, 3905.921, 3928.405, 3948.712, 3966.929, 3983.1409999999996, 3997.429, 4009.869, 4020.532, 4029.488, 4036.802, 4042.5370000000003, 4046.7540000000004, 4049.506, 4050.85, 4050.836, 4049.513, 4046.928, 4043.127, 4038.151, 4032.0409999999997, 4024.836, 4016.574, 4007.29, 3997.018, 3985.7909999999997, 3973.64, 3960.5959999999995, 3946.6859999999997, 3931.9390000000003, 3916.381, 3900.0370000000003, 3882.9320000000002, 3865.09, 3846.532, 3827.281, 3807.3579999999997, 3786.782, 3765.574, 3743.7509999999997, 3721.3320000000003, 3698.3340000000003, 3674.7740000000003, 3650.667, 3626.03, 3600.8779999999997, 3575.225, 3549.086, 3522.473, 3495.4, 3467.88, 3439.925, 3411.547, 3382.758, 3353.5690000000004, 3323.99, 3294.032, 3263.7059999999997, 3233.0209999999997, 3201.987, 3170.613, 3138.908, 3106.881, 3074.5409999999997, 3041.895, 3008.953, 2975.7209999999995, 2942.208, 2908.421, 2874.367, 2840.053, 2805.486, 2770.673, 2735.62, 2700.3340000000003, 2664.821, 2629.086, 2593.136, 2556.9770000000003, 2520.614, 2484.052, 2447.297, 2410.354, 2373.229, 2335.926, 2298.45, 2260.805, 2222.998, 2185.031, 2146.91, 2108.638, 2070.221, 2031.6629999999998, 1992.9660000000001, 1954.1370000000002, 1915.1770000000001, 1876.092, 1836.885, 1797.559, 1758.119, 1718.567, 1678.908, 1639.145, 1599.281, 1559.319, 1519.263, 1479.116, 1438.881, 1398.5610000000001, 1358.1589999999999, 1317.6779999999999, 1277.121, 1236.491, 1195.7910000000002, 1155.0230000000001, 1114.19, 1073.296, 1032.3410000000001, 991.33, 950.265, 909.1469999999999, 867.9810000000001, 826.7669999999999, 785.51, 744.21, 702.87, 661.493, 620.082, 578.637, 537.1619999999999, 495.658, 454.12800000000004, 412.574, 370.99800000000005, 329.403, 287.789, 246.16, 204.518, 162.863, 121.199, 79.527, 37.849000000000004, -3.833, -45.516000000000005, -87.2, -128.882, -170.56099999999998, -212.234, -253.9, -295.556, -337.20300000000003, -378.836, -420.455, -462.059, -503.644, -545.21, -586.755, -628.2769999999999, -669.775, -711.247, -752.69, -794.105, -835.488, -876.8389999999999, -918.155, -959.435, -1000.678, -1041.882, -1083.046, -1124.167, -1165.244, -1206.276, -1247.262, -1288.1989999999998, -1329.086, -1369.921, -1410.704, -1451.4370000000001, -1492.109, -1532.724, -1573.28, -1613.775, -1654.2079999999999, -1694.578, -1734.8829999999998, -1775.121, -1815.2910000000002, -1855.392, -1895.422, -1935.38, -1975.263, -2015.0720000000001, -2054.803, -2094.456, -2134.029, -2173.522, -2212.931, -2252.256, -2291.495, -2330.647, -2369.71, -2408.683, -2447.565, -2486.353, -2525.047, -2563.644, -2602.143, -2640.5440000000003, -2678.843, -2717.0409999999997, -2755.134, -2793.1220000000003, -2831.0040000000004, -2868.777, -2906.44, -2943.992, -2981.43, -3018.7540000000004, -3055.962, -3093.052, -3130.0229999999997, -3166.873, -3203.6009999999997, -3240.204, -3276.6820000000002, -3313.032, -3349.2529999999997, -3385.344, -3421.302, -3457.127, -3492.816, -3528.367, -3563.7790000000005, -3599.051, -3634.18, -3669.165, -3704.0040000000004, -3738.696, -3773.238, -3807.6279999999997, -3841.866, -3875.949, -3909.875, -3943.6420000000003, -3977.2490000000003, -4010.6940000000004, -4043.974, -4077.0879999999997, -4110.035, -4142.811, -4175.415, -4207.846, -4240.1, -4272.1759999999995, -4304.073, -4335.787, -4367.317, -4398.661, -4429.817, -4460.782, -4491.553, -4522.130999999999, -4552.5109999999995, -4582.691, -4612.670999999999, -4642.445, -4672.014, -4701.374, -4730.522, -4759.457, -4788.177, -4816.677, -4844.957, -4873.013, -4900.844, -4928.445, -4955.816, -4982.952, -5009.852, -5036.512, -5062.93, -5089.104, -5115.029, -5140.7029999999995, -5166.124, -5191.288, -5216.193, -5240.834, -5265.21, -5289.316999999999, -5313.151, -5336.71, -5359.99, -5382.986999999999, -5405.7, -5428.1230000000005, -5450.253000000001, -5472.0869999999995, -5493.621999999999, -5514.853, -5535.776999999999, -5556.39, -5576.687, -5596.666, -5616.321999999999, -5635.65, -5654.648, -5673.31, -5691.632, -5709.61, -5727.24, -5744.516, -5761.435, -5777.991999999999, -5794.181, -5809.9980000000005, -5825.438, -5840.495, -5855.166, -5869.443, -5883.323, -5896.799, -5909.866999999999, -5922.519, -5934.751, -5946.556, -5957.928000000001, -5968.861, -5979.35, -5989.3859999999995, -5998.964, -6008.078, -6016.719, -6024.880999999999, -6032.557, -6039.74, -6046.420999999999, -6052.594, -6058.25, -6063.382, -6067.98, -6072.0380000000005, -6075.545, -6078.493, -6080.871999999999, -6082.675, -6083.89, -6084.509, -6084.521, -6083.9169999999995, -6082.684, -6080.814, -6078.294, -6075.113, -6071.26, -6066.722, -6061.486999999999, -6055.5419999999995, -6048.875, -6041.472, -6033.319, -6024.401, -6014.705, -6004.215999999999, -5992.9169999999995, -5980.794, -5967.829000000001, -5954.005, -5939.306, -5923.713000000001, -5907.206999999999, -5889.77, -5871.382, -5852.023, -5831.670999999999, -5810.306, -5787.903, -5764.441, -5739.895, -5714.24, -5687.451, -5659.5019999999995, -5630.365, -5600.012, -5568.411999999999, -5535.536, -5501.353, -5465.828, -5428.929, -5390.62, -5350.865, -5309.626, -5266.863, -5222.535, -5176.601, -5129.017, -5079.735, -5028.709, -4975.89, -4921.226, -4864.665, -4806.149, -4745.623, -4683.026, -4618.298, -4551.372, -4482.182, -4410.66, -4336.734, -4260.3279999999995, -4181.367, -4099.773, -4015.4629999999997, -3928.3520000000003, -3838.357, -3745.388, -3649.3559999999998, -3550.172, -3447.741, -3341.975, -3232.782, -3120.071, -3003.758, -2883.759, -2759.9990000000003, -2632.408, -2500.93, -2365.518, -2226.146, -2082.804, -1935.5079999999998, -1784.3039999999999, -1629.269, -1470.52, -1308.2169999999999, -1142.5710000000001, -973.842, -802.3480000000001, -628.465, -452.63, -275.33, -97.10600000000001, 81.459, 259.746, 437.121, 612.943, 786.578, 957.419, 1124.899, 1288.499, 1447.764, 1602.3020000000001, 1751.796, 1895.9920000000002, 2034.71, 2167.8289999999997, 2295.286, 2417.07, 2533.212, 2643.78, 2748.875, 2848.616, 2943.145, 3032.618, 3117.195, 3197.048, 3272.349, 3343.272, 3409.988, 3472.667, 3531.474, 3586.571, 3638.113, 3686.2529999999997, 3731.132, 3772.8909999999996, 3811.663, 3847.574, 3880.744, 3911.2909999999997, 3939.322, 3964.9429999999998, 3988.2540000000004, 4009.349, 4028.317, 4045.2459999999996, 4060.215, 4073.303, 4084.583, 4094.1240000000003, 4101.995, 4108.2570000000005, 4112.973, 4116.1990000000005, 4117.9890000000005, 4118.396, 4117.471, 4115.26, 4111.81, 4107.164000000001, 4101.362, 4094.4440000000004, 4086.449, 4077.413, 4067.37, 4056.353, 4044.395, 4031.527, 4017.776, 4003.171, 3987.739, 3971.507, 3954.498, 3936.737, 3918.2470000000003, 3899.0490000000004, 3879.1659999999997, 3858.617, 3837.423, 3815.6020000000003, 3793.172, 3770.152, 3746.558, 3722.406, 3697.7129999999997, 3672.494, 3646.764, 3620.5370000000003, 3593.8259999999996, 3566.6459999999997, 3539.009, 3510.928, 3482.415, 3453.4809999999998, 3424.139, 3394.3979999999997, 3364.2709999999997, 3333.7670000000003, 3302.8959999999997, 3271.6679999999997, 3240.092, 3208.178, 3175.935, 3143.3709999999996, 3110.495, 3077.316, 3043.84, 3010.0759999999996, 2976.032, 2941.7140000000004, 2907.13, 2872.2870000000003, 2837.192, 2801.8520000000003, 2766.272, 2730.46, 2694.42, 2658.1609999999996, 2621.6859999999997, 2585.002, 2548.114, 2511.029, 2473.75, 2436.284, 2398.636, 2360.81, 2322.811, 2284.644, 2246.314, 2207.825, 2169.1820000000002, 2130.389, 2091.45, 2052.369, 2013.151, 1973.799, 1934.318, 1894.711, 1854.9820000000002, 1815.135, 1775.1729999999998, 1735.099, 1694.9189999999999, 1654.634, 1614.2479999999998, 1573.764, 1533.1860000000001, 1492.5179999999998, 1451.761, 1410.9189999999999, 1369.995, 1328.993, 1287.914, 1246.762, 1205.54, 1164.25, 1122.896, 1081.479, 1040.003, 998.47, 956.883, 915.2439999999999, 873.556, 831.821, 790.0419999999999, 748.221, 706.36, 664.462, 622.529, 580.564, 538.568, 496.543, 454.49300000000005, 412.41900000000004, 370.32300000000004, 328.207, 286.074, 243.925, 201.763, 159.59, 117.40700000000001, 75.21600000000001, 33.02, -9.18, -51.382, -93.583, -135.782, -177.977, -220.167, -262.349, -304.522, -346.68300000000005, -388.832, -430.965, -473.083, -515.182, -557.261, -599.319, -641.3530000000001, -683.363, -725.345, -767.3, -809.2239999999999, -851.1160000000001, -892.9760000000001, -934.8, -976.5880000000001, -1018.3380000000001, -1060.049, -1101.7169999999999, -1143.343, -1184.925, -1226.46, -1267.948, -1309.387, -1350.775, -1392.111, -1433.3929999999998, -1474.62, -1515.79, -1556.901, -1597.953, -1638.943, -1679.87, -1720.733, -1761.529, -1802.259, -1842.9189999999999, -1883.509, -1924.026, -1964.471, -2004.84, -2045.132, -2085.347, -2125.482, -2165.536, -2205.508, -2245.396, -2285.198, -2324.9120000000003, -2364.5389999999998, -2404.075, -2443.52, -2482.8720000000003, -2522.129, -2561.29, -2600.353, -2639.317, -2678.18, -2716.941, -2755.598, -2794.15, -2832.595, -2870.9309999999996, -2909.158, -2947.272, -2985.2740000000003, -3023.16, -3060.9309999999996, -3098.583, -3136.116, -3173.527, -3210.816, -3247.98, -3285.018, -3321.928, -3358.7090000000003, -3395.3590000000004, -3431.877, -3468.259, -3504.506, -3540.615, -3576.5840000000003, -3612.4120000000003, -3648.097, -3683.637, -3719.031, -3754.276, -3789.3709999999996, -3824.3140000000003, -3859.103, -3893.737, -3928.2129999999997, -3962.53, -3996.685, -4030.678, -4064.505, -4098.165, -4131.657, -4164.977, -4198.125, -4231.097, -4263.893, -4296.509, -4328.945, -4361.197, -4393.264, -4425.144, -4456.833, -4488.332, -4519.6359999999995, -4550.744000000001, -4581.654, -4612.363, -4642.869000000001, -4673.168, -4703.262, -4733.144, -4762.814, -4792.269, -4821.5070000000005, -4850.525, -4879.32, -4907.89, -4936.232, -4964.344, -4992.223, -5019.866, -5047.271, -5074.435, -5101.355, -5128.028, -5154.451, -5180.621, -5206.536, -5232.192, -5257.585999999999, -5282.715999999999, -5307.576999999999, -5332.1669999999995, -5356.483, -5380.521, -5404.278, -5427.75, -5450.935, -5473.828, -5496.4259999999995, -5518.725, -5540.722, -5562.4130000000005, -5583.794, -5604.861, -5625.611, -5646.039000000001, -5666.141, -5685.914000000001, -5705.352, -5724.451999999999, -5743.209, -5761.619000000001, -5779.678000000001, -5797.38, -5814.721, -5831.696999999999, -5848.302, -5864.531, -5880.38, -5895.844, -5910.916, -5925.592, -5939.866999999999, -5953.734, -5967.188, -5980.224, -5992.835, -6005.015, -6016.759, -6028.06, -6038.911999999999, -6049.307, -6059.24, -6068.703, -6077.69, -6086.193, -6094.205, -6101.719, -6108.727, -6115.221, -6121.194, -6126.637, -6131.541, -6135.899, -6139.701999999999, -6142.939, -6145.603, -6147.684, -6149.172, -6150.057, -6150.329000000001, -6149.979, -6148.994000000001, -6147.3640000000005, -6145.079000000001, -6142.126, -6138.493, -6134.17, -6129.141, -6123.396, -6116.920999999999, -6109.701, -6101.724, -6092.975, -6083.44, -6073.102, -6061.946999999999, -6049.9580000000005, -6037.119000000001, -6023.411, -6008.819, -5993.3240000000005, -5976.906, -5959.547, -5941.227, -5921.9259999999995, -5901.62, -5880.289000000001, -5857.911, -5834.460999999999, -5809.916, -5784.25, -5757.438, -5729.453, -5700.266, -5669.849, -5638.172, -5605.205, -5570.916, -5535.271, -5498.235, -5459.774, -5419.85, -5378.4259999999995, -5335.460999999999, -5290.9130000000005, -5244.74, -5196.897, -5147.339, -5096.016, -5042.879, -4987.876, -4930.9529999999995, -4872.054, -4811.12, -4748.090999999999, -4682.905, -4615.496, -4545.795999999999, -4473.736, -4399.242, -4322.2390000000005, -4242.651, -4160.396, -4075.3909999999996, -3987.553, -3896.7929999999997, -3803.022, -3706.15, -3606.083, -3502.7309999999998, -3395.9970000000003, -3285.792, -3172.022, -3054.6009999999997, -2933.442, -2808.47, -2679.612, -2546.8089999999997, -2410.014, -2269.196, -2124.345, -1975.475, -1822.6270000000002, -1665.88, -1505.3470000000002, -1341.1879999999999, -1173.61, -1002.8760000000001, -829.303, -653.268, -475.207, -295.613, -115.03, 65.954, 246.715, 426.611, 604.992, 781.2139999999999, 954.663, 1124.758, 1290.973, 1452.838, 1609.957, 1761.997, 1908.701, 2049.879, 2185.404, 2315.208, 2439.276, 2557.636, 2670.3540000000003, 2777.527, 2879.276, 2975.743, 3067.08, 3153.455, 3235.0359999999996, 3311.9959999999996, 3384.513, 3452.758, 3516.905, 3577.119, 3633.565, 3686.3990000000003, 3735.776, 3781.84, 3824.7340000000004, 3864.59, 3901.538, 3935.7009999999996, 3967.196, 3996.133, 4022.62, 4046.757, 4068.64, 4088.361, 4106.0070000000005, 4121.66, 4135.398, 4147.2970000000005, 4157.428, 4165.858, 4172.652, 4177.871, 4181.5740000000005, 4183.816, 4184.651, 4184.129, 4182.298, 4179.205, 4174.895, 4169.407999999999, 4162.785, 4155.064, 4146.282999999999, 4136.477, 4125.68, 4113.923, 4101.238, 4087.655, 4073.2009999999996, 4057.905, 4041.7929999999997, 4024.89, 4007.2209999999995, 3988.808, 3969.675, 3949.842, 3929.3309999999997, 3908.1609999999996, 3886.3520000000003, 3863.923, 3840.8909999999996, 3817.2740000000003, 3793.0879999999997, 3768.3509999999997, 3743.0759999999996, 3717.28, 3690.9770000000003, 3664.1820000000002, 3636.907, 3609.165, 3580.97, 3552.333, 3523.268, 3493.785, 3463.895, 3433.61, 3402.941, 3371.8959999999997, 3340.487, 3308.723, 3276.613, 3244.167, 3211.393, 3178.3, 3144.8959999999997, 3111.1890000000003, 3077.1890000000003, 3042.901, 3008.333, 2973.493, 2938.388, 2903.025, 2867.4109999999996, 2831.551, 2795.454, 2759.1240000000003, 2722.5679999999998, 2685.7909999999997, 2648.801, 2611.6020000000003, 2574.2, 2536.6, 2498.8070000000002, 2460.828, 2422.666, 2384.327, 2345.815, 2307.136, 2268.294, 2229.2929999999997, 2190.137, 2150.8320000000003, 2111.382, 2071.79, 2032.06, 1992.1979999999999, 1952.205, 1912.0870000000002, 1871.848, 1831.49, 1791.017, 1750.433, 1709.7420000000002, 1668.9470000000001, 1628.0510000000002, 1587.057, 1545.969, 1504.79, 1463.523, 1422.171, 1380.7379999999998, 1339.225, 1297.636, 1255.975, 1214.243, 1172.444, 1130.58, 1088.653, 1046.6680000000001, 1004.6260000000001, 962.53, 920.382, 878.184, 835.941, 793.653, 751.323, 708.954, 666.547, 624.106, 581.632, 539.128, 496.596, 454.038, 411.457, 368.85400000000004, 326.231, 283.591, 240.93599999999998, 198.268, 155.588, 112.899, 70.203, 27.502, -15.202, -57.908, -100.61399999999999, -143.317, -186.015, -228.708, -271.393, -314.068, -356.731, -399.381, -442.01599999999996, -484.63300000000004, -527.2330000000001, -569.811, -612.368, -654.901, -697.408, -739.888, -782.3389999999999, -824.76, -867.148, -909.503, -951.821, -994.1030000000001, -1036.346, -1078.549, -1120.7089999999998, -1162.826, -1204.8980000000001, -1246.923, -1288.899, -1330.826, -1372.701, -1414.523, -1456.2910000000002, -1498.0020000000002, -1539.655, -1581.249, -1622.783, -1664.254, -1705.661, -1747.0020000000002, -1788.277, -1829.483, -1870.619, -1911.684, -1952.675, -1993.592, -2034.432, -2075.195, -2115.879, -2156.482, -2197.0029999999997, -2237.44, -2277.792, -2318.056, -2358.2329999999997, -2398.32, -2438.315, -2478.217, -2518.025, -2557.736, -2597.351, -2636.865, -2676.28, -2715.592, -2754.8, -2793.902, -2832.8979999999997, -2871.785, -2910.562, -2949.2270000000003, -2987.7790000000005, -3026.216, -3064.5370000000003, -3102.739, -3140.821, -3178.782, -3216.62, -3254.333, -3291.92, -3329.3790000000004, -3366.708, -3403.905, -3440.97, -3477.8990000000003, -3514.692, -3551.347, -3587.861, -3624.2340000000004, -3660.4640000000004, -3696.547, -3732.4840000000004, -3768.272, -3803.909, -3839.3940000000002, -3874.724, -3909.897, -3944.913, -3979.768, -4014.462, -4048.992, -4083.355, -4117.5509999999995, -4151.5779999999995, -4185.432, -4219.112, -4252.617, -4285.944, -4319.09, -4352.055, -4384.835, -4417.429, -4449.835, -4482.049, -4514.071, -4545.898, -4577.528, -4608.957, -4640.185, -4671.209, -4702.025, -4732.633, -4763.029, -4793.212, -4823.178, -4852.925, -4882.451, -4911.753, -4940.8279999999995, -4969.674, -4998.288, -5026.667, -5054.81, -5082.712, -5110.371, -5137.785, -5164.95, -5191.863, -5218.522, -5244.924, -5271.064, -5296.941, -5322.5509999999995, -5347.892, -5372.9580000000005, -5397.749, -5422.259, -5446.486, -5470.427, -5494.076999999999, -5517.434, -5540.493, -5563.251, -5585.705, -5607.849, -5629.682, -5651.198, -5672.395, -5693.266, -5713.81, -5734.021, -5753.895, -5773.428000000001, -5792.615, -5811.453, -5829.936, -5848.06, -5865.819, -5883.21, -5900.227, -5916.866, -5933.12, -5948.986, -5964.456999999999, -5979.528, -5994.195, -6008.45, -6022.289000000001, -6035.706, -6048.694, -6061.2480000000005, -6073.361, -6085.026999999999, -6096.24, -6106.993, -6117.279, -6127.090999999999, -6136.422, -6145.265, -6153.613, -6161.456999999999, -6168.7919999999995, -6175.607, -6181.896, -6187.651, -6192.861999999999, -6197.521, -6201.62, -6205.148, -6208.098000000001, -6210.4580000000005, -6212.22, -6213.374, -6213.909000000001, -6213.815, -6213.08, -6211.695, -6209.647, -6206.925, -6203.517, -6199.411, -6194.594, -6189.053000000001, -6182.774, -6175.744000000001, -6167.948, -6159.3730000000005, -6150.004, -6139.8240000000005, -6128.819, -6116.972, -6104.265, -6090.682, -6076.205, -6060.815, -6044.494000000001, -6027.222, -6008.979, -5989.744000000001, -5969.495, -5948.21, -5925.866999999999, -5902.441, -5877.908, -5852.241999999999, -5825.419, -5797.41, -5768.187, -5737.72, -5705.981, -5672.937, -5638.558000000001, -5602.808000000001, -5565.651999999999, -5527.056, -5486.981, -5445.389, -5402.24, -5357.491, -5311.099, -5263.02, -5213.206, -5161.607, -5108.175, -5052.855, -4995.596, -4936.337, -4875.02, -4811.585999999999, -4745.97, -4678.105, -4607.923, -4535.355, -4460.3240000000005, -4382.755999999999, -4302.573, -4219.69, -4134.027, -4045.4959999999996, -3954.008, -3859.474, -3761.8, -3660.893, -3556.659, -3449.002, -3337.829, -3223.046, -3104.5640000000003, -2982.295, -2856.16, -2726.087, -2592.013, -2453.888, -2311.6820000000002, -2165.379, -2014.993, -1860.5639999999999, -1702.1660000000002, -1539.912, -1373.961, -1204.518, -1031.846, -856.2610000000001, -678.14, -497.923, -316.10200000000003, -133.227, 50.11, 233.27900000000002, 415.63199999999995, 596.508, 775.2589999999999, 951.2560000000001, 1123.912, 1292.6860000000001, 1457.1029999999998, 1616.751, 1771.293, 1920.463, 2064.06, 2201.9539999999997, 2334.071, 2460.39, 2580.937, 2695.776, 2805.0009999999997, 2908.735, 3007.115, 3100.2990000000004, 3188.4509999999996, 3271.741, 3350.3459999999995, 3424.442, 3494.204, 3559.8059999999996, 3621.4159999999997, 3679.2009999999996, 3733.3190000000004, 3783.925, 3831.167, 3875.1890000000003, 3916.125, 3954.1059999999998, 3989.2, 4021.698, 4051.539, 4078.89, 4103.853, 4126.524, 4146.997, 4165.361, 4181.698, 4196.089, 4208.61, 4219.333, 4228.325, 4235.654, 4241.380999999999, 4245.567, 4248.265, 4249.532, 4249.419, 4247.974, 4245.245, 4241.277, 4236.112, 4229.79, 4222.352, 4213.834, 4204.272, 4193.702, 4182.155, 4169.663, 4156.255999999999, 4141.963, 4126.812, 4110.83, 4094.0429999999997, 4076.474, 4058.1490000000003, 4039.09, 4019.3179999999998, 3998.8540000000003, 3977.72, 3955.935, 3933.5170000000003, 3910.485, 3886.857, 3862.6490000000003, 3837.8779999999997, 3812.56, 3786.711, 3760.344, 3733.475, 3706.116, 3678.282, 3649.985, 3621.238, 3592.054, 3562.4429999999998, 3532.4179999999997, 3501.988, 3471.1659999999997, 3439.962, 3408.385, 3376.446, 3344.1540000000005, 3311.518, 3278.547, 3245.25, 3211.636, 3177.7129999999997, 3143.489, 3108.9709999999995, 3074.167, 3039.085, 3003.732, 2968.115, 2932.241, 2896.116, 2859.748, 2823.1409999999996, 2786.304, 2749.24, 2711.958, 2674.462, 2636.757, 2598.851, 2560.7470000000003, 2522.451, 2483.968, 2445.303, 2406.462, 2367.448, 2328.268, 2288.924, 2249.422, 2209.766, 2169.9610000000002, 2130.01, 2089.9179999999997, 2049.689, 2009.3270000000002, 1968.835, 1928.2179999999998, 1887.479, 1846.622, 1805.651, 1764.568, 1723.379, 1682.085, 1640.691, 1599.1989999999998, 1557.6129999999998, 1515.9370000000001, 1474.172, 1432.3229999999999, 1390.391, 1348.382, 1306.296, 1264.137, 1221.9080000000001, 1179.612, 1137.252, 1094.829, 1052.347, 1009.809, 967.216, 924.572, 881.8789999999999, 839.14, 796.3560000000001, 753.5310000000001, 710.666, 667.765, 624.8290000000001, 581.861, 538.862, 495.836, 452.784, 409.709, 366.61199999999997, 323.496, 280.363, 237.21599999999998, 194.055, 150.88299999999998, 107.70200000000001, 64.515, 21.322, -21.873, -65.069, -108.265, -151.458, -194.646, -237.827, -281.0, -324.163, -367.314, -410.45099999999996, -453.57300000000004, -496.67699999999996, -539.762, -582.826, -625.867, -668.8839999999999, -711.875, -754.8380000000001, -797.7710000000001, -840.674, -883.543, -926.378, -969.177, -1011.938, -1054.66, -1097.34, -1139.978, -1182.5710000000001, -1225.118, -1267.618, -1310.069, -1352.469, -1394.816, -1437.11, -1479.348, -1521.529, -1563.652, -1605.714, -1647.715, -1689.652, -1731.524, -1773.33, -1815.067, -1856.736, -1898.3329999999999, -1939.8570000000002, -1981.308, -2022.682, -2063.98, -2105.198, -2146.3360000000002, -2187.3920000000003, -2228.365, -2269.2529999999997, -2310.054, -2350.7670000000003, -2391.391, -2431.923, -2472.362, -2512.7070000000003, -2552.956, -2593.1079999999997, -2633.16, -2673.112, -2712.962, -2752.708, -2792.348, -2831.882, -2871.3070000000002, -2910.6209999999996, -2949.824, -2988.914, -3027.888, -3066.7459999999996, -3105.485, -3144.105, -3182.603, -3220.9770000000003, -3259.2270000000003, -3297.35, -3335.344, -3373.2090000000003, -3410.942, -3448.5409999999997, -3486.005, -3523.3320000000003, -3560.5209999999997, -3597.5690000000004, -3634.475, -3671.236, -3707.8520000000003, -3744.321, -3780.639, -3816.8070000000002, -3852.821, -3888.6809999999996, -3924.383, -3959.927, -3995.309, -4030.5290000000005, -4065.585, -4100.474, -4135.194, -4169.744000000001, -4204.121, -4238.3240000000005, -4272.35, -4306.197, -4339.863, -4373.346, -4406.644, -4439.755, -4472.6759999999995, -4505.405, -4537.941, -4570.28, -4602.420999999999, -4634.361, -4666.098, -4697.63, -4728.9529999999995, -4760.067, -4790.967000000001, -4821.653, -4852.121, -4882.3679999999995, -4912.393, -4942.192, -4971.764, -5001.105, -5030.212, -5059.083, -5087.715999999999, -5116.107, -5144.253, -5172.152, -5199.8009999999995, -5227.196, -5254.335999999999, -5281.215999999999, -5307.8330000000005, -5334.185, -5360.269, -5386.08, -5411.616, -5436.874, -5461.85, -5486.54, -5510.941999999999, -5535.0509999999995, -5558.865, -5582.379, -5605.589, -5628.493, -5651.085999999999, -5673.3640000000005, -5695.3240000000005, -5716.96, -5738.271, -5759.25, -5779.894, -5800.198, -5820.159000000001, -5839.772, -5859.031, -5877.934, -5896.475, -5914.648, -5932.45, -5949.875, -5966.918000000001, -5983.5740000000005, -5999.838000000001, -6015.704000000001, -6031.168000000001, -6046.222, -6060.863, -6075.084, -6088.878000000001, -6102.241, -6115.166, -6127.646, -6139.675, -6151.2480000000005, -6162.356, -6172.993, -6183.153, -6192.826999999999, -6202.009, -6210.691999999999, -6218.866999999999, -6226.526999999999, -6233.664000000001, -6240.269, -6246.335, -6251.853, -6256.814, -6261.21, -6265.031, -6268.266, -6270.908, -6272.946, -6274.37, -6275.17, -6275.335, -6274.853, -6273.715, -6271.908, -6269.420999999999, -6266.241, -6262.357, -6257.755, -6252.422, -6246.344, -6239.508000000001, -6231.9, -6223.505, -6214.307, -6204.2919999999995, -6193.443, -6181.744000000001, -6169.178000000001, -6155.726, -6141.371999999999, -6126.097, -6109.880999999999, -6092.704000000001, -6074.548000000001, -6055.389, -6035.206999999999, -6013.979, -5991.681, -5968.29, -5943.781999999999, -5918.129, -5891.308000000001, -5863.2880000000005, -5834.0419999999995, -5803.54, -5771.753000000001, -5738.648, -5704.193, -5668.354, -5631.095, -5592.380999999999, -5552.173000000001, -5510.433000000001, -5467.119000000001, -5422.188, -5375.598000000001, -5327.302, -5277.254, -5225.402, -5171.697, -5116.085, -5058.513, -4998.919, -4937.247, -4873.433, -4807.415, -4739.123, -4668.49, -4595.443, -4519.907, -4441.806, -4361.061, -4277.585999999999, -4191.299, -4102.112, -4009.934, -3914.676, -3816.24, -3714.534, -3609.462, -3500.926, -3388.8309999999997, -3273.0809999999997, -3153.587, -3030.257, -2903.013, -2771.776, -2636.486, -2497.089, -2353.55, -2205.856, -2054.015, -1898.066, -1738.0810000000001, -1574.1729999999998, -1406.495, -1235.255, -1060.712, -883.183, -703.048, -520.743, -336.76599999999996, -151.668, 33.953, 219.463, 404.205, 587.512, 768.727, 947.212, 1122.367, 1293.646, 1460.559, 1622.6870000000001, 1779.684, 1931.2720000000002, 2077.245, 2217.467, 2351.859, 2480.394, 2603.095, 2720.0240000000003, 2831.2740000000003, 2936.965, 3037.235, 3132.241, 3222.1490000000003, 3307.1290000000004, 3387.361, 3463.0190000000002, 3534.283, 3601.327, 3664.321, 3723.4320000000002, 3778.823, 3830.65, 3879.062, 3924.203, 3966.2129999999997, 4005.222, 4041.357, 4074.738, 4105.481, 4133.693, 4159.479, 4182.938, 4204.163, 4223.245, 4240.268, 4255.312, 4268.456, 4279.772, 4289.331, 4297.198, 4303.436, 4308.107, 4311.267, 4312.972, 4313.272, 4312.219, 4309.86, 4306.24, 4301.403, 4295.39, 4288.241, 4279.9929999999995, 4270.685, 4260.349, 4249.02, 4236.729, 4223.5070000000005, 4209.384, 4194.388, 4178.545999999999, 4161.884, 4144.427, 4126.1990000000005, 4107.223, 4087.522, 4067.118, 4046.03, 4024.2790000000005, 4001.884, 3978.864, 3955.236, 3931.018, 3906.2259999999997, 3880.8759999999997, 3854.985, 3828.566, 3801.635, 3774.2059999999997, 3746.292, 3717.907, 3689.062, 3659.7709999999997, 3630.046, 3599.8979999999997, 3569.3379999999997, 3538.3779999999997, 3507.027, 3475.296, 3443.195, 3410.7340000000004, 3377.923, 3344.7690000000002, 3311.283, 3277.472, 3243.3459999999995, 3208.9120000000003, 3174.179, 3139.1540000000005, 3103.844, 3068.258, 3032.401, 2996.282, 2959.907, 2923.282, 2886.415, 2849.31, 2811.975, 2774.415, 2736.637, 2698.6459999999997, 2660.447, 2622.047, 2583.45, 2544.661, 2505.687, 2466.531, 2427.198, 2387.695, 2348.024, 2308.19, 2268.199, 2228.054, 2187.76, 2147.321, 2106.742, 2066.025, 2025.175, 1984.1960000000001, 1943.0929999999998, 1901.8670000000002, 1860.524, 1819.066, 1777.4979999999998, 1735.8229999999999, 1694.0439999999999, 1652.164, 1610.1870000000001, 1568.1170000000002, 1525.955, 1483.7060000000001, 1441.372, 1398.957, 1356.463, 1313.8929999999998, 1271.251, 1228.539, 1185.759, 1142.915, 1100.009, 1057.045, 1014.023, 970.948, 927.822, 884.6469999999999, 841.426, 798.1610000000001, 754.8539999999999, 711.508, 668.1260000000001, 624.7090000000001, 581.26, 537.7819999999999, 494.275, 450.744, 407.189, 363.61300000000006, 320.019, 276.407, 232.78099999999998, 189.142, 145.493, 101.835, 58.17100000000001, 14.502, -29.17, -72.842, -116.51299999999999, -160.181, -203.84400000000002, -247.49900000000002, -291.14599999999996, -334.783, -378.406, -422.01599999999996, -465.60900000000004, -509.184, -552.74, -596.274, -639.785, -683.2719999999999, -726.7310000000001, -770.1619999999999, -813.563, -856.932, -900.268, -943.568, -986.832, -1030.057, -1073.242, -1116.385, -1159.484, -1202.539, -1245.547, -1288.506, -1331.4160000000002, -1374.274, -1417.078, -1459.828, -1502.5220000000002, -1545.158, -1587.734, -1630.249, -1672.701, -1715.089, -1757.412, -1799.6660000000002, -1841.852, -1883.967, -1926.01, -1967.979, -2009.8729999999998, -2051.69, -2093.429, -2135.0879999999997, -2176.665, -2218.159, -2259.569, -2300.8920000000003, -2342.127, -2383.2729999999997, -2424.328, -2465.29, -2506.158, -2546.931, -2587.606, -2628.1820000000002, -2668.658, -2709.031, -2749.301, -2789.466, -2829.5229999999997, -2869.472, -2909.3109999999997, -2949.038, -2988.652, -3028.15, -3067.532, -3106.795, -3145.9390000000003, -3184.96, -3223.8579999999997, -3262.631, -3301.277, -3339.7940000000003, -3378.1809999999996, -3416.437, -3454.558, -3492.5440000000003, -3530.393, -3568.1020000000003, -3605.671, -3643.097, -3680.3790000000004, -3717.515, -3754.502, -3791.34, -3828.026, -3864.558, -3900.934, -3937.153, -3973.2129999999997, -4009.111, -4044.8459999999995, -4080.4159999999997, -4115.818, -4151.052, -4186.113, -4221.002, -4255.715, -4290.251, -4324.607, -4358.781, -4392.772, -4426.576, -4460.193, -4493.619000000001, -4526.852, -4559.89, -4592.731, -4625.373, -4657.813, -4690.049, -4722.0779999999995, -4753.898, -4785.5070000000005, -4816.902, -4848.081, -4879.041, -4909.779, -4940.293, -4970.581, -5000.639, -5030.465999999999, -5060.057, -5089.411, -5118.525, -5147.395, -5176.02, -5204.395, -5232.519, -5260.388000000001, -5287.999, -5315.349, -5342.435, -5369.254, -5395.802, -5422.076999999999, -5448.0740000000005, -5473.7919999999995, -5499.225, -5524.371, -5549.227, -5573.7880000000005, -5598.0509999999995, -5622.013000000001, -5645.67, -5669.017, -5692.052, -5714.769, -5737.165, -5759.236, -5780.978, -5802.387, -5823.459, -5844.188, -5864.571, -5884.603, -5904.28, -5923.597, -5942.548000000001, -5961.130999999999, -5979.338000000001, -5997.166, -6014.61, -6031.6630000000005, -6048.321999999999, -6064.58, -6080.431, -6095.871, -6110.893, -6125.491999999999, -6139.661999999999, -6153.396, -6166.689, -6179.533, -6191.924, -6203.853, -6215.314, -6226.3009999999995, -6236.806, -6246.823, -6256.343000000001, -6265.358, -6273.863, -6281.848000000001, -6289.305, -6296.227, -6302.605, -6308.43, -6313.693, -6318.3859999999995, -6322.499, -6326.022, -6328.946999999999, -6331.263000000001, -6332.959, -6334.025, -6334.451, -6334.225, -6333.335999999999, -6331.773, -6329.524, -6326.576999999999, -6322.918000000001, -6318.535, -6313.414000000001, -6307.543000000001, -6300.906, -6293.49, -6285.28, -6276.2609999999995, -6266.416, -6255.731, -6244.186, -6231.767, -6218.455, -6204.232, -6189.078, -6172.977, -6155.906, -6137.844, -6118.772, -6098.666, -6077.505, -6055.264, -6031.920999999999, -6007.4490000000005, -5981.821, -5955.013000000001, -5926.996, -5897.741999999999, -5867.219, -5835.398, -5802.246999999999, -5767.733, -5731.821, -5694.477, -5655.661999999999, -5615.339, -5573.468000000001, -5530.009, -5484.9169999999995, -5438.148, -5389.658, -5339.397, -5287.315, -5233.361, -5177.482, -5119.62, -5059.719, -4997.717000000001, -4933.552, -4867.159000000001, -4798.47, -4727.415, -4653.920999999999, -4577.913, -4499.312, -4418.038, -4334.0070000000005, -4247.133, -4157.3279999999995, -4064.4990000000003, -3968.5559999999996, -3869.401, -3766.9390000000003, -3661.072, -3551.703, -3438.732, -3322.066, -3201.6079999999997, -3077.27, -2948.968, -2816.6240000000003, -2680.173, -2539.56, -2394.75, -2245.725, -2092.492, -1935.088, -1773.5829999999999, -1608.086, -1438.7520000000002, -1265.7839999999999, -1089.442, -910.0419999999999, -727.9639999999999, -543.645, -357.585, -170.33700000000002, 17.495, 205.274, 392.335, 578.005, 761.617, 942.5239999999999, 1120.119, 1293.84, 1463.193, 1627.747, 1787.144, 1941.102, 2089.407, 2231.915, 2368.54, 2499.254, 2624.074, 2743.06, 2856.302, 2963.922, 3066.0559999999996, 3162.861, 3254.502, 3341.152, 3422.99, 3500.1940000000004, 3572.9429999999998, 3641.413, 3705.778, 3766.204, 3822.857, 3875.893, 3925.466, 3971.72, 4014.796, 4054.827, 4091.942, 4126.26, 4157.9, 4186.971, 4213.5779999999995, 4237.823, 4259.799, 4279.598, 4297.307, 4313.0070000000005, 4326.775, 4338.687, 4348.814, 4357.222, 4363.976, 4369.1359999999995, 4372.762, 4374.907999999999, 4375.628, 4374.972, 4372.9890000000005, 4369.724, 4365.222, 4359.524, 4352.6720000000005, 4344.7029999999995, 4335.654, 4325.563, 4314.46, 4302.379, 4289.352, 4275.407, 4260.575, 4244.883, 4228.356, 4211.02, 4192.901, 4174.02, 4154.401, 4134.066, 4113.036, 4091.3309999999997, 4068.97, 4045.973, 4022.3579999999997, 3998.1409999999996, 3973.34, 3947.972, 3922.051, 3895.594, 3868.615, 3841.1279999999997, 3813.147, 3784.6859999999997, 3755.758, 3726.3740000000003, 3696.548, 3666.2909999999997, 3635.614, 3604.5290000000005, 3573.045, 3541.175, 3508.927, 3476.312, 3443.3379999999997, 3410.0170000000003, 3376.355, 3342.364, 3308.0490000000004, 3273.421, 3238.487, 3203.255, 3167.7329999999997, 3131.928, 3095.848, 3059.4990000000003, 3022.888, 2986.0229999999997, 2948.909, 2911.553, 2873.962, 2836.1409999999996, 2798.0959999999995, 2759.8340000000003, 2721.3590000000004, 2682.678, 2643.796, 2604.718, 2565.449, 2525.994, 2486.359, 2446.548, 2406.5660000000003, 2366.4179999999997, 2326.107, 2285.639, 2245.018, 2204.249, 2163.334, 2122.28, 2081.0879999999997, 2039.764, 1998.3120000000001, 1956.734, 1915.035, 1873.219, 1831.289, 1789.249, 1747.101, 1704.85, 1662.499, 1620.0510000000002, 1577.509, 1534.876, 1492.156, 1449.352, 1406.467, 1363.503, 1320.464, 1277.3519999999999, 1234.17, 1190.922, 1147.609, 1104.235, 1060.802, 1017.312, 973.7689999999999, 930.175, 886.533, 842.845, 799.112, 755.3389999999999, 711.5269999999999, 667.678, 623.7959999999999, 579.881, 535.937, 491.966, 447.97, 403.95099999999996, 359.911, 315.85200000000003, 271.777, 227.688, 183.58700000000002, 139.475, 95.355, 51.229, 7.099, -37.034, -81.167, -125.29799999999999, -169.425, -213.547, -257.661, -301.76599999999996, -345.86, -389.941, -434.00800000000004, -478.05699999999996, -522.0880000000001, -566.099, -610.0880000000001, -654.053, -697.993, -741.905, -785.789, -829.6410000000001, -873.461, -917.247, -960.998, -1004.71, -1048.384, -1092.016, -1135.606, -1179.152, -1222.652, -1266.105, -1309.508, -1352.861, -1396.161, -1439.4070000000002, -1482.598, -1525.731, -1568.806, -1611.82, -1654.7720000000002, -1697.66, -1740.483, -1783.239, -1825.9270000000001, -1868.545, -1911.0910000000001, -1953.5639999999999, -1995.9620000000002, -2038.2839999999999, -2080.528, -2122.692, -2164.775, -2206.775, -2248.6910000000003, -2290.522, -2332.264, -2373.9179999999997, -2415.481, -2456.951, -2498.328, -2539.609, -2580.7929999999997, -2621.8779999999997, -2662.863, -2703.7459999999996, -2744.526, -2785.2, -2825.7670000000003, -2866.2259999999997, -2906.575, -2946.812, -2986.9359999999997, -3026.9440000000004, -3066.836, -3106.6090000000004, -3146.262, -3185.7929999999997, -3225.2009999999996, -3264.4829999999997, -3303.639, -3342.6659999999997, -3381.562, -3420.3259999999996, -3458.9559999999997, -3497.45, -3535.8070000000002, -3574.025, -3612.1009999999997, -3650.035, -3687.824, -3725.466, -3762.9590000000003, -3800.303, -3837.494, -3874.531, -3911.4120000000003, -3948.135, -3984.699, -4021.1, -4057.3379999999997, -4093.409, -4129.313, -4165.0470000000005, -4200.609, -4235.997, -4271.209, -4306.242, -4341.096, -4375.767, -4410.253, -4444.553, -4478.664000000001, -4512.583, -4546.309, -4579.839, -4613.170999999999, -4646.303, -4679.232, -4711.955, -4744.472, -4776.778, -4808.872, -4840.75, -4872.412, -4903.853, -4935.072, -4966.065, -4996.831, -5027.366, -5057.668, -5087.734, -5117.561, -5147.146, -5176.487, -5205.581, -5234.424, -5263.014, -5291.347, -5319.420999999999, -5347.233, -5374.779, -5402.056, -5429.061, -5455.791, -5482.241999999999, -5508.41, -5534.294, -5559.888000000001, -5585.189, -5610.195, -5634.9, -5659.303000000001, -5683.397, -5707.181, -5730.65, -5753.8, -5776.626, -5799.125, -5821.293000000001, -5843.125, -5864.618, -5885.766, -5906.566, -5927.012, -5947.1, -5966.826, -5986.184, -6005.17, -6023.779, -6042.005, -6059.844, -6077.291, -6094.339, -6110.984, -6127.22, -6143.041, -6158.441, -6173.415, -6187.956, -6202.059, -6215.717, -6228.923000000001, -6241.672, -6253.956, -6265.769, -6277.103, -6287.951999999999, -6298.309, -6308.165, -6317.513000000001, -6326.346, -6334.655, -6342.433000000001, -6349.670999999999, -6356.36, -6362.493, -6368.059, -6373.05, -6377.456, -6381.268, -6384.477, -6387.071999999999, -6389.0419999999995, -6390.3769999999995, -6391.066, -6391.099, -6390.463000000001, -6389.147, -6387.139, -6384.428000000001, -6380.999, -6376.839, -6371.936, -6366.275, -6359.844, -6352.626, -6344.607, -6335.772, -6326.105, -6315.589, -6304.2080000000005, -6291.943, -6278.778, -6264.695, -6249.673000000001, -6233.694, -6216.738, -6198.781999999999, -6179.807, -6159.789000000001, -6138.706, -6116.534000000001, -6093.25, -6068.826, -6043.238, -6016.456999999999, -5988.456999999999, -5959.2080000000005, -5928.681, -5896.842, -5863.661999999999, -5829.105, -5793.139, -5755.726, -5716.83, -5676.411, -5634.43, -5590.846, -5545.6140000000005, -5498.69, -5450.026999999999, -5399.576999999999, -5347.289000000001, -5293.111999999999, -5236.99, -5178.8679999999995, -5118.685, -5056.383, -4991.896, -4925.159000000001, -4856.104, -4784.66, -4710.752, -4634.306, -4555.241, -4473.476, -4388.9259999999995, -4301.504, -4211.121, -4117.684, -4021.099, -3921.2690000000002, -3818.097, -3711.4829999999997, -3601.329, -3487.534, -3370.0009999999997, -3248.635, -3123.343, -2994.0409999999997, -2860.647, -2723.0959999999995, -2581.3320000000003, -2435.313, -2285.0229999999997, -2130.466, -1971.675, -1808.72, -1641.7060000000001, -1470.789, -1296.167, -1118.1019999999999, -936.9069999999999, -752.962, -566.706, -378.64, -189.32, 0.649, 190.622, 379.92900000000003, 567.891, 753.831, 937.095, 1117.063, 1293.1689999999999, 1464.9029999999998, 1631.8270000000002, 1793.575, 1949.855, 2100.445, 2245.195, 2384.014, 2516.869, 2643.7729999999997, 2764.784, 2879.991, 2989.511, 3093.4829999999997, 3192.062, 3285.414, 3373.7140000000004, 3457.1409999999996, 3535.8720000000003, 3610.091, 3679.974, 3745.695, 3807.426, 3865.3309999999997, 3919.5679999999998, 3970.2929999999997, 4017.652, 4061.789, 4102.835999999999, 4140.914000000001, 4176.1759999999995, 4208.709, 4238.637, 4266.065, 4291.094, 4313.822, 4334.339, 4352.734, 4369.090999999999, 4383.486, 4395.997, 4406.695, 4415.648, 4422.920999999999, 4428.575, 4432.6720000000005, 4435.266, 4436.411, 4436.157999999999, 4434.557, 4431.655, 4427.495, 4422.12, 4415.572, 4407.89, 4399.11, 4389.271, 4378.404, 4366.543, 4353.719, 4339.964, 4325.306, 4309.773, 4293.392, 4276.189, 4258.188, 4239.414000000001, 4219.889, 4199.635, 4178.675, 4157.028, 4134.714, 4111.752, 4088.1620000000003, 4063.9590000000003, 4039.1620000000003, 4013.788, 3987.8509999999997, 3961.369, 3934.355, 3906.824, 3878.79, 3850.268, 3821.2690000000002, 3791.8070000000002, 3761.8940000000002, 3731.542, 3700.763, 3669.567, 3637.966, 3605.97, 3573.59, 3540.835, 3507.716, 3474.241, 3440.42, 3406.262, 3371.775, 3336.968, 3301.849, 3266.426, 3230.7070000000003, 3194.7, 3158.4109999999996, 3121.848, 3085.018, 3047.928, 3010.5840000000003, 2972.993, 2935.1620000000003, 2897.0959999999995, 2858.801, 2820.284, 2781.5490000000004, 2742.6040000000003, 2703.453, 2664.1020000000003, 2624.555, 2584.819, 2544.897, 2504.7960000000003, 2464.52, 2424.073, 2383.46, 2342.686, 2301.755, 2260.6710000000003, 2219.44, 2178.064, 2136.547, 2094.895, 2053.111, 2011.1989999999998, 1969.162, 1927.004, 1884.729, 1842.34, 1799.842, 1757.236, 1714.5279999999998, 1671.719, 1628.8139999999999, 1585.816, 1542.727, 1499.5520000000001, 1456.2920000000001, 1412.951, 1369.5320000000002, 1326.0379999999998, 1282.472, 1238.836, 1195.134, 1151.367, 1107.539, 1063.653, 1019.711, 975.716, 931.669, 887.575, 843.435, 799.2510000000001, 755.0269999999999, 710.7639999999999, 666.465, 622.132, 577.7669999999999, 533.374, 488.95300000000003, 444.50800000000004, 400.04, 355.55199999999996, 311.045, 266.52299999999997, 221.986, 177.438, 132.88, 88.314, 43.742, -0.833, -45.411, -89.988, -134.563, -179.13400000000001, -223.69799999999998, -268.255, -312.803, -357.338, -401.86, -446.36699999999996, -490.85699999999997, -535.327, -579.7769999999999, -624.205, -668.6080000000001, -712.9839999999999, -757.3330000000001, -801.6519999999999, -845.94, -890.195, -934.415, -978.5989999999999, -1022.7439999999999, -1066.85, -1110.913, -1154.934, -1198.9089999999999, -1242.838, -1286.719, -1330.55, -1374.329, -1418.055, -1461.726, -1505.3410000000001, -1548.8970000000002, -1592.394, -1635.83, -1679.2020000000002, -1722.51, -1765.7520000000002, -1808.925, -1852.03, -1895.0629999999999, -1938.024, -1980.91, -2023.721, -2066.4539999999997, -2109.1079999999997, -2151.681, -2194.172, -2236.5789999999997, -2278.901, -2321.135, -2363.281, -2405.3360000000002, -2447.3, -2489.169, -2530.944, -2572.6220000000003, -2614.201, -2655.68, -2697.0570000000002, -2738.3309999999997, -2779.5, -2820.563, -2861.5159999999996, -2902.36, -2943.092, -2983.711, -3024.215, -3064.6020000000003, -3104.8709999999996, -3145.0190000000002, -3185.046, -3224.949, -3264.7259999999997, -3304.377, -3343.8990000000003, -3383.29, -3422.5490000000004, -3461.6740000000004, -3500.663, -3539.514, -3578.2259999999997, -3616.797, -3655.224, -3693.506, -3731.6409999999996, -3769.6279999999997, -3807.4629999999997, -3845.147, -3882.675, -3920.048, -3957.262, -3994.315, -4031.2070000000003, -4067.934, -4104.494000000001, -4140.887, -4177.109, -4213.157999999999, -4249.032999999999, -4284.731, -4320.251, -4355.589, -4390.745, -4425.715, -4460.498, -4495.090999999999, -4529.492, -4563.698, -4597.709, -4631.52, -4665.13, -4698.537, -4731.737, -4764.729, -4797.5109999999995, -4830.0779999999995, -4862.43, -4894.563, -4926.476, -4958.164000000001, -4989.626, -5020.86, -5051.861, -5082.628, -5113.157999999999, -5143.448, -5173.495, -5203.2970000000005, -5232.849, -5262.15, -5291.196999999999, -5319.985, -5348.513000000001, -5376.776999999999, -5404.774, -5432.5, -5459.953, -5487.13, -5514.025, -5540.638000000001, -5566.9619999999995, -5592.996, -5618.736, -5644.178000000001, -5669.318, -5694.153, -5718.679, -5742.891, -5766.786999999999, -5790.361, -5813.611, -5836.531, -5859.118, -5881.366999999999, -5903.274, -5924.835, -5946.045, -5966.9, -5987.394, -6007.523, -6027.281999999999, -6046.6669999999995, -6065.670999999999, -6084.291, -6102.521, -6120.356, -6137.79, -6154.816999999999, -6171.433000000001, -6187.630999999999, -6203.405, -6218.751, -6233.661, -6248.129, -6262.149, -6275.714, -6288.818, -6301.455, -6313.616999999999, -6325.295999999999, -6336.486999999999, -6347.182, -6357.3730000000005, -6367.053000000001, -6376.213000000001, -6384.847, -6392.944, -6400.4980000000005, -6407.499, -6413.938, -6419.808000000001, -6425.097, -6429.798000000001, -6433.901, -6437.395, -6440.27, -6442.516, -6444.1230000000005, -6445.078, -6445.371, -6444.991, -6443.9259999999995, -6442.1630000000005, -6439.691, -6436.496, -6432.565, -6427.884, -6422.44, -6416.218000000001, -6409.204000000001, -6401.383000000001, -6392.7390000000005, -6383.257, -6372.918000000001, -6361.706999999999, -6349.606, -6336.597, -6322.661, -6307.781, -6291.934, -6275.102, -6257.263000000001, -6238.395, -6218.477, -6197.485, -6175.394, -6152.181, -6127.819, -6102.283, -6075.545999999999, -6047.578, -6018.349, -5987.831, -5955.991999999999, -5922.8, -5888.219, -5852.215999999999, -5814.753000000001, -5775.795999999999, -5735.3009999999995, -5693.231, -5649.543000000001, -5604.194, -5557.137, -5508.326, -5457.7119999999995, -5405.244000000001, -5350.869000000001, -5294.531999999999, -5236.1759999999995, -5175.742, -5113.169, -5048.39, -4981.340999999999, -4911.954000000001, -4840.153, -4765.8679999999995, -4689.019, -4609.527, -4527.309, -4442.28, -4354.352, -4263.432, -4169.43, -4072.248, -3971.79, -3867.955, -3760.6440000000002, -3649.756, -3535.1890000000003, -3416.845, -3294.6259999999997, -3168.437, -3038.1940000000004, -2903.813, -2765.225, -2622.3720000000003, -2475.2129999999997, -2323.726, -2167.913, -2007.808, -1843.476, -1675.021, -1502.596, -1326.4, -1146.688, -963.779, -778.047, -589.934, -399.941, -208.628, -16.602, 175.488, 366.967, 557.146, 745.3439999999999, 930.8939999999999, 1113.171, 1291.597, 1465.651, 1634.889, 1798.933, 1957.484, 2110.312, 2257.259, 2398.231, 2533.187, 2662.14, 2785.1420000000003, 2902.281, 3013.673, 3119.4559999999997, 3219.784, 3314.825, 3404.7529999999997, 3489.748, 3569.991, 3645.663, 3716.9429999999998, 3784.008, 3847.0290000000005, 3906.173, 3961.6020000000003, 4013.4709999999995, 4061.928, 4107.117, 4149.174, 4188.232, 4224.413, 4257.838, 4288.6179999999995, 4316.8640000000005, 4342.677, 4366.155, 4387.392, 4406.474, 4423.487, 4438.513, 4451.625, 4462.896, 4472.398, 4480.194, 4486.348, 4490.919, 4493.967000000001, 4495.542, 4495.6990000000005, 4494.487, 4491.954000000001, 4488.143, 4483.1, 4476.8640000000005, 4469.477, 4460.976, 4451.397, 4440.774, 4429.142, 4416.532999999999, 4402.977, 4388.503, 4373.141, 4356.917, 4339.857, 4321.987, 4303.33, 4283.91, 4263.75, 4242.872, 4221.295999999999, 4199.041, 4176.127, 4152.5740000000005, 4128.399, 4103.619000000001, 4078.252, 4052.313, 4025.8190000000004, 3998.784, 3971.224, 3943.152, 3914.5820000000003, 3885.527, 3856.0009999999997, 3826.0159999999996, 3795.583, 3764.716, 3733.425, 3701.7209999999995, 3669.616, 3637.119, 3604.24, 3570.991, 3537.3790000000004, 3503.414, 3469.105, 3434.462, 3399.492, 3364.204, 3328.607, 3292.7070000000003, 3256.513, 3220.032, 3183.272, 3146.239, 3108.94, 3071.383, 3033.574, 2995.5190000000002, 2957.224, 2918.696, 2879.941, 2840.965, 2801.7729999999997, 2762.37, 2722.763, 2682.9559999999997, 2642.955, 2602.765, 2562.39, 2521.837, 2481.109, 2440.2110000000002, 2399.149, 2357.925, 2316.545, 2275.014, 2233.334, 2191.511, 2149.548, 2107.45, 2065.22, 2022.8629999999998, 1980.381, 1937.779, 1895.06, 1852.2279999999998, 1809.287, 1766.239, 1723.088, 1679.838, 1636.4920000000002, 1593.0520000000001, 1549.523, 1505.9070000000002, 1462.207, 1418.4260000000002, 1374.568, 1330.635, 1286.63, 1242.555, 1198.415, 1154.211, 1109.945, 1065.622, 1021.243, 976.811, 932.329, 887.798, 843.222, 798.6039999999999, 753.944, 709.247, 664.5139999999999, 619.747, 574.9490000000001, 530.122, 485.269, 440.39099999999996, 395.491, 350.57099999999997, 305.633, 260.68, 215.713, 170.734, 125.74600000000001, 80.751, 35.75, -9.254, -54.25899999999999, -99.264, -144.266, -189.263, -234.25400000000002, -279.237, -324.209, -369.17, -414.116, -459.046, -503.959, -548.852, -593.724, -638.573, -683.3960000000001, -728.193, -772.962, -817.7, -862.4060000000001, -907.079, -951.716, -996.316, -1040.876, -1085.397, -1129.875, -1174.309, -1218.697, -1263.038, -1307.33, -1351.5710000000001, -1395.759, -1439.894, -1483.973, -1527.995, -1571.957, -1615.859, -1659.6989999999998, -1703.475, -1747.185, -1790.828, -1834.402, -1877.906, -1921.338, -1964.6960000000001, -2007.979, -2051.1839999999997, -2094.312, -2137.359, -2180.324, -2223.206, -2266.0029999999997, -2308.7129999999997, -2351.334, -2393.866, -2436.306, -2478.653, -2520.905, -2563.06, -2605.118, -2647.075, -2688.9309999999996, -2730.684, -2772.3320000000003, -2813.873, -2855.3059999999996, -2896.63, -2937.842, -2978.94, -3019.9240000000004, -3060.7909999999997, -3101.54, -3142.1690000000003, -3182.675, -3223.059, -3263.317, -3303.448, -3343.45, -3383.321, -3423.06, -3462.665, -3502.134, -3541.465, -3580.656, -3619.7059999999997, -3658.613, -3697.3740000000003, -3735.988, -3774.453, -3812.768, -3850.929, -3888.935, -3926.785, -3964.4759999999997, -4002.007, -4039.375, -4076.578, -4113.6140000000005, -4150.482, -4187.178, -4223.702, -4260.0509999999995, -4296.223, -4332.215, -4368.026, -4403.653, -4439.094, -4474.347, -4509.41, -4544.28, -4578.955, -4613.433, -4647.712, -4681.788, -4715.66, -4749.325, -4782.781, -4816.026, -4849.056, -4881.869000000001, -4914.463, -4946.835, -4978.982, -5010.902, -5042.592000000001, -5074.049, -5105.271, -5136.254, -5166.997, -5197.495, -5227.747, -5257.7480000000005, -5287.496999999999, -5316.99, -5346.224, -5375.196, -5403.901999999999, -5432.340999999999, -5460.507, -5488.398, -5516.012, -5543.343000000001, -5570.39, -5597.147, -5623.613, -5649.781999999999, -5675.651999999999, -5701.218000000001, -5726.478, -5751.4259999999995, -5776.06, -5800.375, -5824.366999999999, -5848.031999999999, -5871.366, -5894.365, -5917.024, -5939.339, -5961.306, -5982.919, -6004.1759999999995, -6025.069, -6045.596, -6065.75, -6085.528, -6104.923000000001, -6123.931, -6142.547, -6160.764, -6178.579000000001, -6195.985, -6212.976, -6229.547, -6245.691, -6261.404, -6276.678000000001, -6291.508000000001, -6305.887, -6319.809, -6333.266, -6346.2519999999995, -6358.76, -6370.783, -6382.314, -6393.346, -6403.87, -6413.879, -6423.366, -6432.321999999999, -6440.7390000000005, -6448.607, -6455.92, -6462.6669999999995, -6468.84, -6474.429, -6479.425, -6483.818, -6487.599, -6490.757, -6493.281, -6495.16, -6496.384, -6496.941999999999, -6496.82, -6496.009, -6494.495, -6492.266, -6489.309, -6485.611, -6481.158, -6475.935, -6469.929, -6463.125, -6455.508000000001, -6447.061, -6437.77, -6427.616, -6416.5830000000005, -6404.653, -6391.809, -6378.03, -6363.3, -6347.596, -6330.899, -6313.187, -6294.438, -6274.63, -6253.741, -6231.744000000001, -6208.616, -6184.33, -6158.86, -6132.18, -6104.258000000001, -6075.066999999999, -6044.576, -6012.753000000001, -5979.565, -5944.978, -5908.956999999999, -5871.465, -5832.465, -5791.916, -5749.778, -5706.009, -5660.565, -5613.399, -5564.464, -5513.7119999999995, -5461.089, -5406.543000000001, -5350.019, -5291.459, -5230.803, -5167.9890000000005, -5102.951, -5035.623, -4965.935, -4893.815, -4819.187, -4741.972, -4662.092000000001, -4579.460999999999, -4493.9929999999995, -4405.6, -4314.189, -4219.666, -4121.934, -4020.8940000000002, -3916.447, -3808.489, -3696.92, -3581.636, -3462.5359999999996, -3339.522, -3212.4970000000003, -3081.373, -2946.0679999999998, -2806.508, -2662.634, -2514.402, -2361.7889999999998, -2204.795, -2043.45, -1877.817, -1707.999, -1534.145, -1356.453, -1175.1789999999999, -990.635, -803.2, -613.314, -421.478, -228.253, -34.251999999999995, 159.874, 353.444, 545.764, 736.1419999999999, 923.908, 1108.424, 1289.1019999999999, 1465.415, 1636.906, 1803.19, 1963.957, 2118.973, 2268.07, 2411.15, 2548.167, 2679.1290000000004, 2804.086, 2923.1240000000003, 3036.357, 3143.921, 3245.973, 3342.677, 3434.211, 3520.7540000000004, 3602.488, 3679.595, 3752.256, 3820.651, 3884.95, 3945.322, 4001.9309999999996, 4054.933, 4104.479, 4150.714, 4193.775, 4233.795, 4270.901, 4305.212, 4336.844, 4365.905, 4392.501, 4416.728, 4438.683, 4458.454000000001, 4476.126, 4491.782, 4505.497, 4517.346, 4527.399, 4535.723, 4542.38, 4547.432, 4550.938, 4552.95, 4553.523, 4552.706, 4550.549, 4547.096, 4542.391, 4536.476, 4529.392, 4521.177, 4511.869000000001, 4501.501, 4490.108, 4477.723, 4464.376, 4450.097, 4434.917, 4418.86, 4401.955, 4384.227, 4365.7, 4346.398, 4326.344, 4305.56, 4284.067, 4261.884, 4239.032, 4215.529, 4191.395, 4166.646, 4141.3, 4115.373, 4088.882, 4061.84, 4034.265, 4006.1679999999997, 3977.566, 3948.47, 3918.895, 3888.853, 3858.3559999999998, 3827.417, 3796.046, 3764.255, 3732.0559999999996, 3699.458, 3666.4709999999995, 3633.107, 3599.3740000000003, 3565.281, 3530.8390000000004, 3496.055, 3460.9390000000003, 3425.4990000000003, 3389.744, 3353.68, 3317.317, 3280.6609999999996, 3243.72, 3206.502, 3169.012, 3131.259, 3093.2490000000003, 3054.988, 3016.4829999999997, 2977.739, 2938.764, 2899.563, 2860.1409999999996, 2820.5040000000004, 2780.659, 2740.6090000000004, 2700.362, 2659.921, 2619.291, 2578.479, 2537.488, 2496.324, 2454.99, 2413.493, 2371.835, 2330.022, 2288.0570000000002, 2245.945, 2203.69, 2161.297, 2118.768, 2076.1079999999997, 2033.3210000000001, 1990.411, 1947.38, 1904.234, 1860.974, 1817.606, 1774.131, 1730.555, 1686.879, 1643.1070000000002, 1599.243, 1555.289, 1511.249, 1467.126, 1422.922, 1378.641, 1334.285, 1289.858, 1245.362, 1200.8, 1156.174, 1111.489, 1066.745, 1021.946, 977.0939999999999, 932.193, 887.2439999999999, 842.2489999999999, 797.212, 752.135, 707.02, 661.87, 616.686, 571.472, 526.229, 480.96, 435.667, 390.353, 345.01800000000003, 299.66700000000003, 254.3, 208.919, 163.528, 118.12799999999999, 72.721, 27.309, -18.105999999999998, -63.522, -108.93700000000001, -154.34799999999998, -199.755, -245.155, -290.546, -335.925, -381.293, -426.64599999999996, -471.98199999999997, -517.3, -562.5980000000001, -607.874, -653.126, -698.3530000000001, -743.552, -788.7230000000001, -833.862, -878.9689999999999, -924.041, -969.077, -1014.076, -1059.0339999999999, -1103.952, -1148.826, -1193.656, -1238.4389999999999, -1283.174, -1327.859, -1372.493, -1417.0729999999999, -1461.599, -1506.068, -1550.4779999999998, -1594.829, -1639.119, -1683.345, -1727.506, -1771.601, -1815.628, -1859.585, -1903.47, -1947.283, -1991.02, -2034.682, -2078.265, -2121.769, -2165.1910000000003, -2208.531, -2251.786, -2294.9539999999997, -2338.035, -2381.026, -2423.926, -2466.734, -2509.446, -2552.063, -2594.5820000000003, -2637.0009999999997, -2679.3190000000004, -2721.534, -2763.645, -2805.6490000000003, -2847.545, -2889.3320000000003, -2931.008, -2972.57, -3014.018, -3055.349, -3096.562, -3137.655, -3178.6259999999997, -3219.474, -3260.197, -3300.792, -3341.259, -3381.595, -3421.7990000000004, -3461.869, -3501.802, -3541.598, -3581.2529999999997, -3620.768, -3660.138, -3699.364, -3738.442, -3777.3709999999996, -3816.1490000000003, -3854.7740000000003, -3893.244, -3931.5559999999996, -3969.71, -4007.703, -4045.533, -4083.198, -4120.696, -4158.025, -4195.183, -4232.167, -4268.976, -4305.608, -4342.06, -4378.329000000001, -4414.415, -4450.314, -4486.024, -4521.544, -4556.87, -4592.001, -4626.934, -4661.667, -4696.197, -4730.522, -4764.639, -4798.5470000000005, -4832.242, -4865.722, -4898.985, -4932.027, -4964.847, -4997.441, -5029.807, -5061.942, -5093.843, -5125.508, -5156.934, -5188.1179999999995, -5219.057, -5249.7480000000005, -5280.188, -5310.374, -5340.303000000001, -5369.972, -5399.378000000001, -5428.517, -5457.3859999999995, -5485.983, -5514.303000000001, -5542.344, -5570.101, -5597.573, -5624.753000000001, -5651.641, -5678.231, -5704.519, -5730.504, -5756.179, -5781.5419999999995, -5806.589, -5831.315, -5855.717, -5879.791, -5903.531, -5926.934, -5949.996, -5972.7119999999995, -5995.076999999999, -6017.088000000001, -6038.7390000000005, -6060.025, -6080.943, -6101.486, -6121.651, -6141.431, -6160.821999999999, -6179.816999999999, -6198.4130000000005, -6216.603, -6234.382, -6251.744000000001, -6268.683000000001, -6285.194, -6301.269, -6316.904, -6332.092, -6346.826, -6361.1, -6374.906999999999, -6388.24, -6401.092, -6413.456, -6425.325, -6436.691, -6447.547, -6457.884, -6467.696, -6476.973000000001, -6485.706999999999, -6493.891, -6501.515, -6508.57, -6515.045999999999, -6520.935, -6526.228, -6530.9130000000005, -6534.981, -6538.423000000001, -6541.227, -6543.382, -6544.8769999999995, -6545.7, -6545.840999999999, -6545.286999999999, -6544.025, -6542.044, -6539.33, -6535.869000000001, -6531.648, -6526.651999999999, -6520.868, -6514.28, -6506.8730000000005, -6498.630999999999, -6489.5380000000005, -6479.576, -6468.729, -6456.979, -6444.308000000001, -6430.696999999999, -6416.126, -6400.5740000000005, -6384.022, -6366.448, -6347.83, -6328.146, -6307.371, -6285.481, -6262.451, -6238.255999999999, -6212.868, -6186.258000000001, -6158.4, -6129.262, -6098.815, -6067.025, -6033.86, -5999.285, -5963.266, -5925.765, -5886.743, -5846.161, -5803.978, -5760.151, -5714.635, -5667.3859999999995, -5618.352, -5567.486, -5514.736999999999, -5460.049, -5403.366, -5344.632, -5283.784000000001, -5220.7609999999995, -5155.498, -5087.924, -5017.972, -4945.567, -4870.634, -4793.093, -4712.8640000000005, -4629.861, -4543.998, -4455.184, -4363.326, -4268.329000000001, -4170.096, -4068.526, -3963.5159999999996, -3854.965, -3742.7690000000002, -3626.824, -3507.027, -3383.278, -3255.4790000000003, -3123.54, -2987.3759999999997, -2846.9120000000003, -2702.086, -2552.854, -2399.189, -2241.089, -2078.581, -1911.726, -1740.626, -1565.4260000000002, -1386.3229999999999, -1203.57, -1017.48, -828.427, -636.854, -443.26199999999994, -248.213, -52.321999999999996, 143.756, 339.334, 533.714, 726.196, 916.1010000000001, 1102.7830000000001, 1285.644, 1464.149, 1637.83, 1806.2939999999999, 1969.2220000000002, 2126.3720000000003, 2277.571, 2422.712, 2561.7470000000003, 2694.678, 2821.553, 2942.455, 3057.4959999999996, 3166.813, 3270.559, 3368.902, 3462.018, 3550.086, 3633.29, 3711.8140000000003, 3785.841, 3855.548, 3921.111, 3982.698, 4040.4759999999997, 4094.6020000000003, 4145.227, 4192.499, 4236.556, 4277.688, 4315.56, 4350.754, 4383.232, 4413.108, 4440.483, 4465.459, 4488.130999999999, 4508.590999999999, 4526.923, 4543.210999999999, 4557.532999999999, 4569.962, 4580.569, 4589.424, 4596.59, 4602.127, 4606.096, 4608.5509999999995, 4609.545999999999, 4609.1320000000005, 4607.357, 4604.269, 4599.911, 4594.325, 4587.554, 4579.635, 4570.606, 4560.502, 4549.358, 4537.207, 4524.08, 4510.008, 4495.02, 4479.143, 4462.404, 4444.83, 4426.445, 4407.273, 4387.338, 4366.661, 4345.263, 4323.166, 4300.389, 4276.951, 4252.872, 4228.169, 4202.858, 4176.958, 4150.483, 4123.45, 4095.873, 4067.768, 4039.1479999999997, 4010.027, 3980.4179999999997, 3950.335, 3919.79, 3888.795, 3857.361, 3825.4990000000003, 3793.222, 3760.539, 3727.461, 3693.998, 3660.1609999999996, 3625.9570000000003, 3591.3979999999997, 3556.491, 3521.2459999999996, 3485.671, 3449.775, 3413.566, 3377.051, 3340.238, 3303.135, 3265.748, 3228.086, 3190.155, 3151.961, 3113.512, 3074.8140000000003, 3035.873, 2996.696, 2957.288, 2917.655, 2877.803, 2837.738, 2797.4640000000004, 2756.988, 2716.315, 2675.45, 2634.397, 2593.163, 2551.75, 2510.166, 2468.413, 2426.496, 2384.42, 2342.189, 2299.808, 2257.28, 2214.61, 2171.802, 2128.859, 2085.786, 2042.586, 1999.263, 1955.8210000000001, 1912.263, 1868.5929999999998, 1824.815, 1780.931, 1736.945, 1692.861, 1648.681, 1604.4089999999999, 1560.0479999999998, 1515.601, 1471.0710000000001, 1426.461, 1381.775, 1337.014, 1292.182, 1247.282, 1202.316, 1157.287, 1112.198, 1067.052, 1021.85, 976.597, 931.294, 885.943, 840.548, 795.1110000000001, 749.6339999999999, 704.1189999999999, 658.57, 612.987, 567.375, 521.734, 476.06800000000004, 430.37800000000004, 384.666, 338.936, 293.188, 247.426, 201.65099999999998, 155.865, 110.071, 64.27, 18.465, -27.343000000000004, -73.15100000000001, -118.95700000000001, -164.76, -210.558, -256.347, -302.128, -347.897, -393.653, -439.394, -485.11699999999996, -530.822, -576.507, -622.168, -667.806, -713.4169999999999, -759.0, -804.554, -850.076, -895.565, -941.0189999999999, -986.435, -1031.8139999999999, -1077.152, -1122.447, -1167.7, -1212.906, -1258.066, -1303.1760000000002, -1348.236, -1393.244, -1438.1970000000001, -1483.095, -1527.9360000000001, -1572.717, -1617.4379999999999, -1662.096, -1706.69, -1751.2179999999998, -1795.6789999999999, -1840.0710000000001, -1884.3929999999998, -1928.641, -1972.816, -2016.915, -2060.936, -2104.879, -2148.741, -2192.52, -2236.215, -2279.825, -2323.347, -2366.78, -2410.123, -2453.373, -2496.529, -2539.589, -2582.552, -2625.4159999999997, -2668.179, -2710.8390000000004, -2753.395, -2795.8459999999995, -2838.188, -2880.422, -2922.5440000000003, -2964.553, -3006.448, -3048.2270000000003, -3089.888, -3131.429, -3172.848, -3214.1440000000002, -3255.315, -3296.3590000000004, -3337.275, -3378.059, -3418.712, -3459.23, -3499.612, -3539.8559999999998, -3579.961, -3619.9240000000004, -3659.743, -3699.417, -3738.9440000000004, -3778.322, -3817.548, -3856.6209999999996, -3895.539, -3934.3, -3972.901, -4011.342, -4049.619, -4087.732, -4125.6759999999995, -4163.452, -4201.056, -4238.486, -4275.741, -4312.818, -4349.715, -4386.429, -4422.959, -4459.302, -4495.456, -4531.419, -4567.187, -4602.76, -4638.135, -4673.308, -4708.279, -4743.044, -4777.601, -4811.947, -4846.08, -4879.998, -4913.697, -4947.175, -4980.43, -5013.459, -5046.259, -5078.827, -5111.161, -5143.2570000000005, -5175.1140000000005, -5206.727, -5238.095, -5269.214, -5300.081, -5330.693, -5361.047, -5391.14, -5420.969, -5450.53, -5479.82, -5508.8369999999995, -5537.576, -5566.034000000001, -5594.2080000000005, -5622.094, -5649.688, -5676.988, -5703.9890000000005, -5730.688, -5757.08, -5783.1630000000005, -5808.932, -5834.383000000001, -5859.512, -5884.315, -5908.7880000000005, -5932.927, -5956.727, -5980.183000000001, -6003.2919999999995, -6026.049, -6048.4490000000005, -6070.488, -6092.161, -6113.463000000001, -6134.388000000001, -6154.933000000001, -6175.090999999999, -6194.859, -6214.229, -6233.196999999999, -6251.757, -6269.904, -6287.632, -6304.934, -6321.806, -6338.241, -6354.232, -6369.773, -6384.859, -6399.481, -6413.635, -6427.311, -6440.505, -6453.206999999999, -6465.411, -6477.109, -6488.295, -6498.959, -6509.094, -6518.691, -6527.743, -6536.24, -6544.174, -6551.536, -6558.316999999999, -6564.505999999999, -6570.095, -6575.073, -6579.431, -6583.156999999999, -6586.243, -6588.675, -6590.444, -6591.536, -6591.941999999999, -6591.648, -6590.643, -6588.9130000000005, -6586.446, -6583.228, -6579.244000000001, -6574.481, -6568.923000000001, -6562.557, -6555.366999999999, -6547.3369999999995, -6538.4490000000005, -6528.688, -6518.035, -6506.474, -6493.985, -6480.549, -6466.148, -6450.76, -6434.3640000000005, -6416.94, -6398.464, -6378.915, -6358.268, -6336.4980000000005, -6313.58, -6289.4890000000005, -6264.196999999999, -6237.675, -6209.895, -6180.828, -6150.441, -6118.703, -6085.58, -6051.036999999999, -6015.039000000001, -5977.549, -5938.528, -5897.935, -5855.73, -5811.868, -5766.306, -5718.996999999999, -5669.892, -5618.941, -5566.092, -5511.29, -5454.479, -5395.601, -5334.594, -5271.396, -5205.939, -5138.156, -5067.975, -4995.323, -4920.124, -4842.295999999999, -4761.76, -4678.427, -4592.212, -4503.022, -4410.765, -4315.342000000001, -4216.657, -4114.607, -4009.0890000000004, -3900.0, -3787.2340000000004, -3670.6859999999997, -3550.252, -3425.83, -3297.321, -3164.632, -3027.677, -2886.3790000000004, -2740.675, -2590.515, -2435.874, -2276.746, -2113.155, -1945.161, -1772.862, -1596.401, -1415.974, -1231.83, -1044.282, -853.703, -660.5319999999999, -465.273, -268.49, -70.798, 127.14299999999999, 324.645, 521.0, 715.503, 907.4689999999999, 1096.24, 1281.212, 1461.84, 1637.645, 1808.226, 1973.256, 2132.484, 2285.732, 2432.886, 2573.8920000000003, 2708.7490000000003, 2837.502, 2960.2290000000003, 3077.045, 3188.0809999999997, 3293.492, 3393.446, 3488.116, 3577.6859999999997, 3662.34, 3742.261, 3817.633, 3888.636, 3955.447, 4018.236, 4077.1690000000003, 4132.406, 4184.101, 4232.401, 4277.447, 4319.375, 4358.313, 4394.385, 4427.707, 4458.392, 4486.545, 4512.268, 4535.657, 4556.805, 4575.798, 4592.719, 4607.647, 4620.659000000001, 4631.825, 4641.214, 4648.893, 4654.92, 4659.357, 4662.2609999999995, 4663.684, 4663.679, 4662.294, 4659.579000000001, 4655.575, 4650.327, 4643.876, 4636.262, 4627.522, 4617.692, 4606.807, 4594.9, 4582.004, 4568.15, 4553.365, 4537.679, 4521.119000000001, 4503.710999999999, 4485.48, 4466.451, 4446.648, 4426.090999999999, 4404.803, 4382.805, 4360.117, 4336.758, 4312.747, 4288.104, 4262.843, 4236.984, 4210.541, 4183.531, 4155.969, 4127.871, 4099.249, 4070.119, 4040.493, 4010.385, 3979.8070000000002, 3948.772, 3917.2909999999997, 3885.3759999999997, 3853.0370000000003, 3820.2870000000003, 3787.135, 3753.591, 3719.6659999999997, 3685.37, 3650.711, 3615.699, 3580.343, 3544.651, 3508.632, 3472.2940000000003, 3435.645, 3398.6929999999998, 3361.446, 3323.91, 3286.093, 3248.002, 3209.6440000000002, 3171.026, 3132.1540000000005, 3093.035, 3053.6740000000004, 3014.078, 2974.2540000000004, 2934.205, 2893.9390000000003, 2853.461, 2812.777, 2771.8909999999996, 2730.808, 2689.535, 2648.0759999999996, 2606.435, 2564.618, 2522.629, 2480.473, 2438.154, 2395.677, 2353.0460000000003, 2310.265, 2267.3379999999997, 2224.27, 2181.064, 2137.725, 2094.256, 2050.661, 2006.943, 1963.1070000000002, 1919.156, 1875.0929999999998, 1830.922, 1786.646, 1742.269, 1697.7939999999999, 1653.224, 1608.5620000000001, 1563.8120000000001, 1518.977, 1474.059, 1429.0610000000001, 1383.987, 1338.84, 1293.621, 1248.335, 1202.984, 1157.57, 1112.096, 1066.566, 1020.9810000000001, 975.3439999999999, 929.658, 883.925, 838.148, 792.329, 746.471, 700.575, 654.646, 608.683, 562.691, 516.672, 470.62699999999995, 424.55800000000005, 378.469, 332.361, 286.237, 240.09799999999998, 193.947, 147.786, 101.617, 55.441, 9.262, -36.919000000000004, -83.1, -129.279, -175.454, -221.623, -267.784, -313.934, -360.07300000000004, -406.199, -452.30800000000005, -498.4, -544.4730000000001, -590.525, -636.553, -682.556, -728.533, -774.4810000000001, -820.398, -866.284, -912.135, -957.951, -1003.7289999999999, -1049.468, -1095.1660000000002, -1140.8210000000001, -1186.432, -1231.997, -1277.513, -1322.98, -1368.395, -1413.7579999999998, -1459.065, -1504.316, -1549.509, -1594.642, -1639.713, -1684.721, -1729.664, -1774.54, -1819.348, -1864.086, -1908.7520000000002, -1953.345, -1997.8629999999998, -2042.3039999999999, -2086.666, -2130.949, -2175.149, -2219.2670000000003, -2263.299, -2307.244, -2351.101, -2394.867, -2438.542, -2482.123, -2525.609, -2568.998, -2612.288, -2655.478, -2698.566, -2741.55, -2784.428, -2827.199, -2869.861, -2912.413, -2954.8520000000003, -2997.176, -3039.385, -3081.4759999999997, -3123.447, -3165.297, -3207.0240000000003, -3248.6259999999997, -3290.1020000000003, -3331.449, -3372.665, -3413.75, -3454.7, -3495.514, -3536.191, -3576.7270000000003, -3617.123, -3657.3740000000003, -3697.4809999999998, -3737.44, -3777.25, -3816.908, -3856.414, -3895.764, -3934.9570000000003, -3973.99, -4012.863, -4051.572, -4090.116, -4128.492, -4166.6990000000005, -4204.734, -4242.596, -4280.281, -4317.788, -4355.115, -4392.259, -4429.219, -4465.991, -4502.5740000000005, -4538.965, -4575.162, -4611.163, -4646.965, -4682.566, -4717.963, -4753.154, -4788.137, -4822.907999999999, -4857.465999999999, -4891.807, -4925.93, -4959.831, -4993.508, -5026.959, -5060.18, -5093.168, -5125.9220000000005, -5158.437, -5190.712, -5222.7429999999995, -5254.526999999999, -5286.062, -5317.344, -5348.37, -5379.138000000001, -5409.643, -5439.884, -5469.856, -5499.556, -5528.981, -5558.128000000001, -5586.991999999999, -5615.571999999999, -5643.863, -5671.861, -5699.563, -5726.965999999999, -5754.065, -5780.856, -5807.3369999999995, -5833.5019999999995, -5859.348000000001, -5884.871, -5910.066, -5934.93, -5959.4580000000005, -5983.646, -6007.4890000000005, -6030.983, -6054.1230000000005, -6076.906, -6099.325, -6121.3769999999995, -6143.056, -6164.357, -6185.275, -6205.805, -6225.941999999999, -6245.681, -6265.015, -6283.939, -6302.4490000000005, -6320.536999999999, -6338.198, -6355.4259999999995, -6372.215, -6388.558000000001, -6404.4490000000005, -6419.880999999999, -6434.849, -6449.344, -6463.361, -6476.892, -6489.929, -6502.465999999999, -6514.495, -6526.007, -6536.996, -6547.453, -6557.369000000001, -6566.736, -6575.545999999999, -6583.791, -6591.459, -6598.543000000001, -6605.033, -6610.919, -6616.191, -6620.839, -6624.852, -6628.22, -6630.932, -6632.976, -6634.340999999999, -6635.014, -6634.985, -6634.2390000000005, -6632.764, -6630.548000000001, -6627.576999999999, -6623.835999999999, -6619.31, -6613.986, -6607.849, -6600.882, -6593.07, -6584.396, -6574.842, -6564.392, -6553.028, -6540.73, -6527.481, -6513.259, -6498.044, -6481.816, -6464.553000000001, -6446.232, -6426.83, -6406.323, -6384.688, -6361.897, -6337.925, -6312.743, -6286.326, -6258.642, -6229.661999999999, -6199.353, -6167.685, -6134.6230000000005, -6100.132, -6064.177, -6026.719, -5987.72, -5947.139, -5904.935, -5861.064, -5815.48, -5768.139, -5718.988, -5667.98, -5615.06, -5560.175, -5503.267, -5444.276999999999, -5383.143, -5319.803000000001, -5254.188, -5186.232, -5115.86, -5043.001, -4967.5740000000005, -4889.502, -4808.7, -4725.082, -4638.561, -4549.042, -4456.433, -4360.635, -4261.55, -4159.0740000000005, -4053.103, -3943.532, -3830.255, -3713.165, -3592.157, -3467.1259999999997, -3337.974, -3204.6040000000003, -3066.929, -2924.87, -2778.362, -2627.3540000000003, -2471.815, -2311.74, -2147.15, -1978.102, -1804.691, -1627.059, -1445.398, -1259.955, -1071.0410000000002, -879.029, -684.355, -487.525, -289.101, -89.7, 110.01299999999999, 309.347, 507.59, 704.03, 897.972, 1088.754, 1275.76, 1458.4370000000001, 1636.297, 1808.93, 1976.0, 2137.249, 2292.491, 2441.606, 2584.535, 2721.2740000000003, 2851.863, 2976.3779999999997, 3094.93, 3207.652, 3314.697, 3416.2309999999998, 3512.4309999999996, 3603.478, 3689.5570000000002, 3770.8540000000003, 3847.553, 3919.835, 3987.877, 4051.853, 4111.927, 4168.264, 4221.018, 4270.335999999999, 4316.363, 4359.234, 4399.0779999999995, 4436.022, 4470.183, 4501.674, 4530.601, 4557.07, 4581.175, 4603.0109999999995, 4622.664000000001, 4640.22, 4655.758, 4669.355, 4681.082, 4691.01, 4699.204000000001, 4705.726, 4710.638, 4713.996, 4715.853, 4716.264, 4715.277, 4712.941, 4709.3, 4704.398, 4698.276, 4690.976, 4682.535, 4672.9890000000005, 4662.374, 4650.723, 4638.069, 4624.443, 4609.874, 4594.391, 4578.021, 4560.793, 4542.73, 4523.856, 4504.197, 4483.774, 4462.609, 4440.725, 4418.14, 4394.875, 4370.948, 4346.378, 4321.183, 4295.38, 4268.985, 4242.015, 4214.484, 4186.407999999999, 4157.8009999999995, 4128.677, 4099.0509999999995, 4068.934, 4038.341, 4007.282, 3975.7709999999997, 3943.8190000000004, 3911.438, 3878.637, 3845.429, 3811.823, 3777.829, 3743.4570000000003, 3708.717, 3673.618, 3638.1690000000003, 3602.3779999999997, 3566.255, 3529.8070000000002, 3493.0440000000003, 3455.9709999999995, 3418.598, 3380.9320000000002, 3342.98, 3304.7490000000003, 3266.2470000000003, 3227.4790000000003, 3188.452, 3149.1740000000004, 3109.65, 3069.886, 3029.889, 2989.664, 2949.217, 2908.554, 2867.6809999999996, 2826.6020000000003, 2785.323, 2743.849, 2702.185, 2660.336, 2618.3070000000002, 2576.103, 2533.728, 2491.186, 2448.4829999999997, 2405.623, 2362.609, 2319.447, 2276.14, 2232.6910000000003, 2189.107, 2145.389, 2101.542, 2057.57, 2013.476, 1969.264, 1924.9379999999999, 1880.501, 1835.9560000000001, 1791.308, 1746.558, 1701.711, 1656.77, 1611.737, 1566.6170000000002, 1521.412, 1476.125, 1430.7579999999998, 1385.316, 1339.8010000000002, 1294.2160000000001, 1248.563, 1202.845, 1157.066, 1111.2269999999999, 1065.3310000000001, 1019.382, 973.3810000000001, 927.332, 881.2360000000001, 835.097, 788.916, 742.696, 696.439, 650.149, 603.826, 557.474, 511.095, 464.691, 418.265, 371.81800000000004, 325.35200000000003, 278.871, 232.37599999999998, 185.86900000000003, 139.352, 92.82700000000001, 46.297, -0.23600000000000002, -46.771, -93.305, -139.836, -186.363, -232.88400000000001, -279.39599999999996, -325.897, -372.38599999999997, -418.861, -465.319, -511.76, -558.18, -604.578, -650.953, -697.302, -743.6239999999999, -789.9169999999999, -836.179, -882.4069999999999, -928.602, -974.7589999999999, -1020.8789999999999, -1066.9589999999998, -1112.997, -1158.991, -1204.94, -1250.8419999999999, -1296.6960000000001, -1342.499, -1388.25, -1433.9470000000001, -1479.589, -1525.1729999999998, -1570.6979999999999, -1616.162, -1661.5639999999999, -1706.901, -1752.1729999999998, -1797.378, -1842.513, -1887.5770000000002, -1932.568, -1977.485, -2022.326, -2067.089, -2111.7729999999997, -2156.376, -2200.896, -2245.331, -2289.68, -2333.942, -2378.113, -2422.194, -2466.181, -2510.073, -2553.869, -2597.567, -2641.165, -2684.6620000000003, -2728.055, -2771.343, -2814.5240000000003, -2857.5959999999995, -2900.559, -2943.409, -2986.145, -3028.7659999999996, -3071.2690000000002, -3113.653, -3155.9159999999997, -3198.0559999999996, -3240.071, -3281.96, -3323.7209999999995, -3365.3509999999997, -3406.85, -3448.2140000000004, -3489.4429999999998, -3530.535, -3571.486, -3612.297, -3652.9640000000004, -3693.485, -3733.86, -3774.085, -3814.159, -3854.08, -3893.8459999999995, -3933.454, -3972.9040000000005, -4012.192, -4051.317, -4090.276, -4129.068, -4167.69, -4206.14, -4244.417, -4282.517, -4320.439, -4358.181, -4395.74, -4433.1140000000005, -4470.3, -4507.2970000000005, -4544.101, -4580.712, -4617.125, -4653.34, -4689.353, -4725.162, -4760.765, -4796.159000000001, -4831.340999999999, -4866.309, -4901.061, -4935.593, -4969.904, -5003.99, -5037.848, -5071.477, -5104.873, -5138.032999999999, -5170.955, -5203.635, -5236.071, -5268.259, -5300.196999999999, -5331.882, -5363.311, -5394.479, -5425.385, -5456.025, -5486.396, -5516.495, -5546.316999999999, -5575.86, -5605.121, -5634.095, -5662.779, -5691.170999999999, -5719.264, -5747.058000000001, -5774.545999999999, -5801.727, -5828.595, -5855.147, -5881.378000000001, -5907.285, -5932.8640000000005, -5958.109, -5983.018, -6007.585, -6031.806, -6055.677, -6079.193, -6102.349, -6125.141, -6147.564, -6169.611999999999, -6191.281, -6212.566, -6233.460999999999, -6253.960999999999, -6274.061, -6293.755, -6313.0380000000005, -6331.903, -6350.346, -6368.36, -6385.938, -6403.076, -6419.766, -6436.0019999999995, -6451.778, -6467.085999999999, -6481.92, -6496.273, -6510.138000000001, -6523.507, -6536.374, -6548.73, -6560.566999999999, -6571.878000000001, -6582.654, -6592.887, -6602.569, -6611.691, -6620.244000000001, -6628.219, -6635.607, -6642.397, -6648.58, -6654.146, -6659.085, -6663.3859999999995, -6667.039000000001, -6670.031999999999, -6672.354, -6673.993, -6674.938, -6675.175, -6674.693, -6673.478, -6671.517, -6668.797, -6665.303000000001, -6661.021, -6655.937, -6650.034000000001, -6643.297, -6635.71, -6627.257, -6617.919, -6607.681, -6596.522, -6584.4259999999995, -6571.371, -6557.339, -6542.309, -6526.26, -6509.17, -6491.016, -6471.774, -6451.422, -6429.934, -6407.285, -6383.446999999999, -6358.393, -6332.095, -6304.524, -6275.649, -6245.438, -6213.858, -6180.878000000001, -6146.459, -6110.566999999999, -6073.164000000001, -6034.21, -5993.664000000001, -5951.486, -5907.63, -5862.0509999999995, -5814.704000000001, -5765.536, -5714.499, -5661.539000000001, -5606.6, -5549.6269999999995, -5490.558000000001, -5429.331999999999, -5365.885, -5300.149, -5232.057, -5161.532999999999, -5088.505, -5012.893, -4934.6179999999995, -4853.596, -4769.738, -4682.957, -4593.157999999999, -4500.248, -4404.127, -4304.694, -4201.847, -4095.48, -3985.486, -3871.759, -3754.19, -3632.672, -3507.1, -3377.373, -3243.393, -3105.071, -2962.327, -2815.092, -2663.3140000000003, -2506.9610000000002, -2346.0229999999997, -2180.521, -2010.506, -1836.0739999999998, -1657.3629999999998, -1474.5610000000001, -1287.915, -1097.731, -904.382, -708.304, -509.999, -310.031, -109.01899999999999, 92.37100000000001, 293.444, 493.481, 691.768, 887.6010000000001, 1080.3110000000001, 1269.272, 1453.921, 1633.763, 1808.379, 1977.424, 2140.632, 2297.81, 2448.8320000000003, 2593.634, 2732.2070000000003, 2864.586, 2990.847, 3111.098, 3225.47, 3334.115, 3437.2, 3534.8990000000003, 3627.397, 3714.877, 3797.526, 3875.531, 3949.072, 4018.328, 4083.473, 4144.6759999999995, 4202.1, 4255.899, 4306.225, 4353.223, 4397.037, 4437.772, 4475.582, 4510.576, 4542.869000000001, 4572.568, 4599.78, 4624.599, 4647.122, 4667.436, 4685.627, 4701.776, 4715.959, 4728.251, 4738.72, 4747.434, 4754.456, 4759.846, 4763.664000000001, 4765.963, 4766.795999999999, 4766.214, 4764.264, 4760.995, 4756.447, 4750.665, 4743.688, 4735.556, 4726.304, 4715.968, 4704.584, 4692.183, 4678.7970000000005, 4664.455, 4649.188, 4633.022, 4615.985, 4598.102, 4579.398, 4559.897, 4539.622, 4518.595, 4496.838, 4474.371, 4451.214, 4427.3859999999995, 4402.906, 4377.792, 4352.06, 4325.729, 4298.814, 4271.331, 4243.294, 4214.719, 4185.619000000001, 4156.008, 4125.901, 4095.309, 4064.245, 4032.722, 4000.7509999999997, 3968.344, 3935.512, 3902.2659999999996, 3868.615, 3834.57, 3800.1420000000003, 3765.3390000000004, 3730.172, 3694.6490000000003, 3658.7790000000005, 3622.571, 3586.033, 3549.1740000000004, 3512.0009999999997, 3474.522, 3436.745, 3398.678, 3360.3259999999996, 3321.698, 3282.801, 3243.64, 3204.223, 3164.555, 3124.6440000000002, 3084.495, 3044.114, 3003.507, 2962.68, 2921.639, 2880.388, 2838.933, 2797.2790000000005, 2755.4309999999996, 2713.395, 2671.176, 2628.777, 2586.2039999999997, 2543.462, 2500.554, 2457.486, 2414.261, 2370.883, 2327.3579999999997, 2283.689, 2239.88, 2195.935, 2151.8579999999997, 2107.653, 2063.323, 2018.8729999999998, 1974.305, 1929.6229999999998, 1884.832, 1839.933, 1794.931, 1749.828, 1704.629, 1659.336, 1613.953, 1568.4820000000002, 1522.9270000000001, 1477.2910000000002, 1431.576, 1385.786, 1339.9229999999998, 1293.99, 1247.991, 1201.927, 1155.802, 1109.619, 1063.379, 1017.085, 970.7410000000001, 924.3489999999999, 877.91, 831.429, 784.9060000000001, 738.345, 691.748, 645.117, 598.455, 551.764, 505.046, 458.30400000000003, 411.54, 364.755, 317.953, 271.135, 224.304, 177.46200000000002, 130.61, 83.751, 36.887, -9.979, -56.847, -103.713, -150.577, -197.435, -244.28599999999997, -291.128, -337.959, -384.777, -431.58099999999996, -478.36699999999996, -525.135, -571.882, -618.607, -665.307, -711.982, -758.628, -805.2439999999999, -851.829, -898.38, -944.8960000000001, -991.375, -1037.816, -1084.215, -1130.572, -1176.885, -1223.152, -1269.371, -1315.5410000000002, -1361.66, -1407.726, -1453.737, -1499.691, -1545.588, -1591.424, -1637.1989999999998, -1682.911, -1728.558, -1774.138, -1819.649, -1865.0910000000001, -1910.46, -1955.756, -2000.977, -2046.121, -2091.186, -2136.17, -2181.073, -2225.891, -2270.624, -2315.27, -2359.827, -2404.2929999999997, -2448.667, -2492.946, -2537.13, -2581.216, -2625.202, -2669.0879999999997, -2712.8709999999996, -2756.5490000000004, -2800.12, -2843.5840000000003, -2886.938, -2930.18, -2973.309, -3016.322, -3059.219, -3101.9959999999996, -3144.653, -3187.188, -3229.598, -3271.882, -3314.038, -3356.0640000000003, -3397.9590000000003, -3439.72, -3481.345, -3522.833, -3564.1820000000002, -3605.389, -3646.453, -3687.373, -3728.145, -3768.768, -3809.24, -3849.559, -3889.723, -3929.73, -3969.578, -4009.264, -4048.788, -4088.1459999999997, -4127.335999999999, -4166.357, -4205.206, -4243.880999999999, -4282.38, -4320.7, -4358.84, -4396.7970000000005, -4434.569, -4472.154, -4509.549, -4546.751, -4583.759, -4620.57, -4657.182, -4693.592000000001, -4729.798, -4765.798, -4801.588, -4837.166, -4872.53, -4907.677, -4942.605, -4977.31, -5011.79, -5046.043, -5080.065, -5113.854, -5147.407, -5180.721, -5213.793, -5246.62, -5279.2, -5311.528, -5343.602, -5375.42, -5406.977, -5438.271, -5469.299, -5500.056, -5530.541, -5560.7480000000005, -5590.6759999999995, -5620.32, -5649.678000000001, -5678.744000000001, -5707.517, -5735.991999999999, -5764.165, -5792.031999999999, -5819.590999999999, -5846.835999999999, -5873.764, -5900.37, -5926.651, -5952.603, -5978.221, -6003.501, -6028.438, -6053.028, -6077.267, -6101.149, -6124.670999999999, -6147.826, -6170.611999999999, -6193.021, -6215.05, -6236.694, -6257.946999999999, -6278.803000000001, -6299.258000000001, -6319.305, -6338.939, -6358.155, -6376.946, -6395.306, -6413.23, -6430.710999999999, -6447.741999999999, -6464.318, -6480.432, -6496.076999999999, -6511.245, -6525.931, -6540.126, -6553.823, -6567.016, -6579.695, -6591.855, -6603.486, -6614.58, -6625.128000000001, -6635.1230000000005, -6644.555, -6653.416, -6661.696, -6669.3859999999995, -6676.477, -6682.9580000000005, -6688.819, -6694.05, -6698.64, -6702.579000000001, -6705.855, -6708.456999999999, -6710.3730000000005, -6711.590999999999, -6712.099, -6711.883000000001, -6710.932, -6709.232, -6706.768, -6703.526999999999, -6699.493, -6694.654, -6688.991, -6682.491999999999, -6675.138000000001, -6666.9130000000005, -6657.8, -6647.78, -6636.8369999999995, -6624.951, -6612.102, -6598.271, -6583.436, -6567.576999999999, -6550.672, -6532.696999999999, -6513.63, -6493.446, -6472.121, -6449.6269999999995, -6425.939, -6401.029, -6374.868, -6347.427, -6318.675, -6288.58, -6257.11, -6224.229, -6189.905, -6154.098000000001, -6116.771, -6077.8859999999995, -6037.4, -5995.272, -5951.4580000000005, -5905.911, -5858.585, -5809.43, -5758.393, -5705.424, -5650.464, -5593.456999999999, -5534.343000000001, -5473.061, -5409.543000000001, -5343.724, -5275.531999999999, -5204.897, -5131.741, -5055.988, -4977.553, -4896.355, -4812.305, -4725.312, -4635.284000000001, -4542.124, -4445.732, -4346.008, -4242.847, -4136.142, -4025.7870000000003, -3911.672, -3793.688, -3671.7270000000003, -3545.683, -3415.452, -3280.935, -3142.042, -2998.6890000000003, -2850.8070000000002, -2698.343, -2541.26, -2379.5460000000003, -2213.219, -2042.33, -1866.97, -1687.275, -1503.4289999999999, -1315.6779999999999, -1124.325, -929.7389999999999, -732.357, -532.678, -331.26800000000003, -128.746, 74.223, 276.936, 478.675, 678.715, 876.3489999999999, 1070.897, 1261.729, 1448.2720000000002, 1630.02, 1806.546, 1977.4979999999998, 2142.6, 2301.653, 2454.524, 2601.145, 2741.5009999999997, 2875.6240000000003, 3003.587, 3125.494, 3241.478, 3351.688, 3456.289, 3555.4570000000003, 3649.3759999999997, 3738.23, 3822.208, 3901.494, 3976.2729999999997, 4046.725, 4113.023, 4175.338, 4233.833, 4288.666, 4339.988, 4387.945, 4432.675, 4474.31, 4512.979, 4548.8, 4581.89, 4612.358, 4640.307, 4665.839, 4689.0470000000005, 4710.022, 4728.848, 4745.608, 4760.38, 4773.237, 4784.252, 4793.4890000000005, 4801.015, 4806.89, 4811.1720000000005, 4813.918, 4815.18, 4815.01, 4813.456, 4810.565, 4806.38, 4800.945, 4794.302, 4786.487, 4777.539000000001, 4767.495, 4756.388, 4744.252, 4731.117, 4717.015, 4701.975, 4686.025, 4669.193, 4651.503, 4632.982, 4613.653, 4593.54, 4572.666, 4551.0509999999995, 4528.717000000001, 4505.683, 4481.97, 4457.595, 4432.5779999999995, 4406.935, 4380.684, 4353.840999999999, 4326.420999999999, 4298.44, 4269.913, 4240.855, 4211.278, 4181.198, 4150.626, 4119.575, 4088.058, 4056.087, 4023.672, 3990.827, 3957.56, 3923.884, 3889.808, 3855.343, 3820.4970000000003, 3785.281, 3749.704, 3713.7740000000003, 3677.5009999999997, 3640.893, 3603.958, 3566.704, 3529.14, 3491.2729999999997, 3453.11, 3414.659, 3375.926, 3336.92, 3297.6459999999997, 3258.111, 3218.321, 3178.283, 3138.0040000000004, 3097.488, 3056.742, 3015.7729999999997, 2974.5840000000003, 2933.1820000000002, 2891.573, 2849.761, 2807.752, 2765.55, 2723.1620000000003, 2680.59, 2637.841, 2594.919, 2551.8289999999997, 2508.574, 2465.16, 2421.591, 2377.87, 2334.002, 2289.992, 2245.842, 2201.558, 2157.1420000000003, 2112.599, 2067.931, 2023.144, 1978.241, 1933.224, 1888.098, 1842.866, 1797.531, 1752.0970000000002, 1706.566, 1660.942, 1615.229, 1569.4289999999999, 1523.545, 1477.58, 1431.537, 1385.42, 1339.23, 1292.972, 1246.647, 1200.259, 1153.809, 1107.302, 1060.738, 1014.122, 967.456, 920.7410000000001, 873.982, 827.179, 780.337, 733.456, 686.54, 639.59, 592.61, 545.601, 498.566, 451.50699999999995, 404.426, 357.32599999999996, 310.209, 263.07599999999996, 215.93099999999998, 168.774, 121.609, 74.438, 27.261999999999997, -19.917, -67.096, -114.273, -161.446, -208.614, -255.774, -302.925, -350.064, -397.189, -444.3, -491.392, -538.466, -585.518, -632.547, -679.552, -726.529, -773.4780000000001, -820.3969999999999, -867.283, -914.1360000000001, -960.952, -1007.73, -1054.469, -1101.167, -1147.822, -1194.431, -1240.995, -1287.509, -1333.974, -1380.386, -1426.745, -1473.049, -1519.295, -1565.4820000000002, -1611.609, -1657.6729999999998, -1703.6729999999998, -1749.608, -1795.474, -1841.2720000000002, -1886.9979999999998, -1932.652, -1978.231, -2023.734, -2069.159, -2114.504, -2159.768, -2204.949, -2250.045, -2295.055, -2339.976, -2384.8070000000002, -2429.547, -2474.192, -2518.743, -2563.197, -2607.552, -2651.8059999999996, -2695.958, -2740.006, -2783.949, -2827.784, -2871.509, -2915.123, -2958.625, -3002.011, -3045.281, -3088.433, -3131.4640000000004, -3174.373, -3217.159, -3259.8179999999998, -3302.35, -3344.7529999999997, -3387.0240000000003, -3429.1620000000003, -3471.165, -3513.031, -3554.758, -3596.344, -3637.7870000000003, -3679.085, -3720.236, -3761.239, -3802.091, -3842.79, -3883.3340000000003, -3923.7209999999995, -3963.949, -4004.0159999999996, -4043.92, -4083.659, -4123.231, -4162.633, -4201.863, -4240.919, -4279.8, -4318.502, -4357.023, -4395.361, -4433.515, -4471.48, -4509.255999999999, -4546.84, -4584.23, -4621.4220000000005, -4658.415, -4695.206, -4731.793, -4768.173, -4804.344, -4840.303, -4876.0470000000005, -4911.5740000000005, -4946.8820000000005, -4981.965999999999, -5016.826, -5051.458, -5085.859, -5120.027, -5153.958, -5187.65, -5221.099, -5254.304, -5287.26, -5319.965, -5352.415, -5384.608, -5416.541, -5448.21, -5479.611, -5510.743, -5541.6, -5572.181, -5602.481, -5632.496999999999, -5662.225, -5691.661999999999, -5720.804, -5749.648, -5778.189, -5806.424, -5834.349, -5861.96, -5889.254, -5916.225, -5942.869000000001, -5969.184, -5995.164000000001, -6020.805, -6046.103, -6071.052, -6095.649, -6119.888000000001, -6143.766, -6167.276999999999, -6190.4169999999995, -6213.179, -6235.56, -6257.555, -6279.156999999999, -6300.361999999999, -6321.164000000001, -6341.557, -6361.535, -6381.094, -6400.227, -6418.928000000001, -6437.19, -6455.009, -6472.376, -6489.286999999999, -6505.734, -6521.71, -6537.2080000000005, -6552.221, -6566.743, -6580.765, -6594.28, -6607.281, -6619.759, -6631.706999999999, -6643.116, -6653.978, -6664.283, -6674.025, -6683.191999999999, -6691.776, -6699.769, -6707.159000000001, -6713.938, -6720.094, -6725.616999999999, -6730.4980000000005, -6734.724, -6738.284000000001, -6741.168000000001, -6743.3640000000005, -6744.859, -6745.64, -6745.695, -6745.0109999999995, -6743.575, -6741.371999999999, -6738.389, -6734.61, -6730.021, -6724.606, -6718.351, -6711.236999999999, -6703.2480000000005, -6694.366999999999, -6684.576, -6673.857, -6662.191999999999, -6649.558000000001, -6635.938, -6621.31, -6605.654, -6588.946, -6571.164000000001, -6552.284000000001, -6532.281999999999, -6511.134, -6488.812, -6465.29, -6440.54, -6414.534000000001, -6387.241, -6358.630999999999, -6328.670999999999, -6297.33, -6264.571999999999, -6230.361999999999, -6194.6630000000005, -6157.437, -6118.645, -6078.244000000001, -6036.191999999999, -5992.446999999999, -5946.96, -5899.684, -5850.57, -5799.565, -5746.616999999999, -5691.669, -5634.664000000001, -5575.54, -5514.236, -5450.686, -5384.821999999999, -5316.573, -5245.866999999999, -5172.627, -5096.775, -5018.227, -4936.901, -4852.707, -4765.553, -4675.348, -4581.992, -4485.385, -4385.427, -4282.0109999999995, -4175.03, -4064.375, -3949.938, -3831.607, -3709.2729999999997, -3582.828, -3452.167, -3317.191, -3177.805, -3033.925, -2885.4809999999998, -2732.415, -2574.69, -2412.291, -2245.234, -2073.5660000000003, -1897.375, -1716.795, -1532.007, -1343.253, -1150.8339999999998, -955.118, -756.5369999999999, -555.591, -352.844, -148.915, 55.528, 259.781, 463.119, 664.817, 864.1569999999999, 1060.455, 1253.0710000000001, 1441.4229999999998, 1624.9979999999998, 1803.359, 1976.146, 2143.075, 2303.94, 2458.6020000000003, 2606.986, 2749.073, 2884.89, 3014.51, 3138.032, 3255.587, 3367.324, 3473.408, 3574.013, 3669.324, 3759.526, 3844.8059999999996, 3925.3520000000003, 4001.348, 4072.974, 4140.407, 4203.816, 4263.369000000001, 4319.22, 4371.527, 4420.433, 4466.0779999999995, 4508.596, 4548.116, 4584.758, 4618.64, 4649.872, 4678.557, 4704.799, 4728.691, 4750.325, 4769.787, 4787.159000000001, 4802.522, 4815.948, 4827.51, 4837.275, 4845.309, 4851.673, 4856.4259999999995, 4859.624, 4861.323, 4861.572, 4860.42, 4857.916, 4854.103, 4849.025, 4842.724, 4835.238, 4826.605, 4816.862, 4806.044, 4794.184, 4781.313, 4767.463, 4752.664000000001, 4736.943, 4720.329000000001, 4702.847, 4684.522, 4665.38, 4645.444, 4624.737, 4603.28, 4581.094, 4558.1990000000005, 4534.616, 4510.363, 4485.459, 4459.9220000000005, 4433.768, 4407.013, 4379.675, 4351.768, 4323.307, 4294.307, 4264.782999999999, 4234.747, 4204.214, 4173.195, 4141.7029999999995, 4109.75, 4077.348, 4044.508, 4011.241, 3977.559, 3943.472, 3908.989, 3874.12, 3838.875, 3803.264, 3767.295, 3730.9770000000003, 3694.3190000000004, 3657.33, 3620.0170000000003, 3582.388, 3544.4509999999996, 3506.2140000000004, 3467.685, 3428.869, 3389.775, 3350.409, 3310.778, 3270.888, 3230.745, 3190.357, 3149.728, 3108.866, 3067.776, 3026.462, 2984.9320000000002, 2943.191, 2901.243, 2859.095, 2816.7509999999997, 2774.215, 2731.494, 2688.592, 2645.513, 2602.263, 2558.845, 2515.265, 2471.526, 2427.633, 2383.589, 2339.4, 2295.069, 2250.599, 2205.996, 2161.262, 2116.402, 2071.419, 2026.317, 1981.099, 1935.769, 1890.33, 1844.786, 1799.139, 1753.394, 1707.5539999999999, 1661.621, 1615.599, 1569.491, 1523.3, 1477.029, 1430.68, 1384.2579999999998, 1337.764, 1291.201, 1244.573, 1197.881, 1151.13, 1104.32, 1057.4560000000001, 1010.539, 963.573, 916.559, 869.5, 822.3989999999999, 775.258, 728.08, 680.867, 633.621, 586.345, 539.0409999999999, 491.711, 444.35699999999997, 396.983, 349.589, 302.17900000000003, 254.75400000000002, 207.317, 159.869, 112.413, 64.952, 17.486, -29.982, -77.449, -124.915, -172.37599999999998, -219.831, -267.278, -314.714, -362.139, -409.54900000000004, -456.944, -504.32, -551.677, -599.012, -646.323, -693.6089999999999, -740.868, -788.097, -835.295, -882.46, -929.591, -976.685, -1023.7410000000001, -1070.756, -1117.729, -1164.6589999999999, -1211.5430000000001, -1258.38, -1305.1680000000001, -1351.905, -1398.589, -1445.2179999999998, -1491.7920000000001, -1538.308, -1584.763, -1631.158, -1677.489, -1723.756, -1769.955, -1816.0870000000002, -1862.148, -1908.1370000000002, -1954.0529999999999, -1999.8929999999998, -2045.656, -2091.34, -2136.944, -2182.466, -2227.903, -2273.254, -2318.518, -2363.6929999999998, -2408.777, -2453.768, -2498.6639999999998, -2543.464, -2588.166, -2632.768, -2677.268, -2721.665, -2765.9570000000003, -2810.1420000000003, -2854.218, -2898.184, -2942.0370000000003, -2985.776, -3029.3990000000003, -3072.9040000000005, -3116.29, -3159.554, -3202.6940000000004, -3245.7090000000003, -3288.597, -3331.3559999999998, -3373.985, -3416.48, -3458.841, -3501.0640000000003, -3543.15, -3585.095, -3626.897, -3668.555, -3710.066, -3751.429, -3792.6409999999996, -3833.7009999999996, -3874.607, -3915.355, -3955.945, -3996.3740000000003, -4036.6409999999996, -4076.742, -4116.6759999999995, -4156.441, -4196.034000000001, -4235.4529999999995, -4274.697, -4313.763, -4352.648, -4391.35, -4429.867, -4468.197, -4506.337, -4544.285, -4582.039000000001, -4619.595, -4656.9529999999995, -4694.108, -4731.059, -4767.804, -4804.339, -4840.662, -4876.77, -4912.661, -4948.333, -4983.781, -5019.005, -5054.0, -5088.765, -5123.295999999999, -5157.59, -5191.645, -5225.457, -5259.024, -5292.342, -5325.409000000001, -5358.222, -5390.776, -5423.07, -5455.099, -5486.861, -5518.353, -5549.57, -5580.51, -5611.169, -5641.543000000001, -5671.63, -5701.425, -5730.924, -5760.124, -5789.022, -5817.611999999999, -5845.893, -5873.858, -5901.505, -5928.829000000001, -5955.826999999999, -5982.493, -6008.8240000000005, -6034.815, -6060.463000000001, -6085.7609999999995, -6110.706, -6135.294, -6159.519, -6183.375, -6206.86, -6229.967, -6252.691, -6275.026999999999, -6296.971, -6318.515, -6339.656, -6360.387, -6380.704000000001, -6400.599, -6420.066999999999, -6439.101, -6457.696, -6475.846, -6493.544, -6510.783, -6527.557, -6543.859, -6559.681, -6575.018, -6589.861999999999, -6604.205, -6618.039000000001, -6631.356, -6644.15, -6656.411999999999, -6668.133000000001, -6679.306, -6689.920999999999, -6699.969, -6709.441, -6718.329000000001, -6726.6230000000005, -6734.312, -6741.388000000001, -6747.84, -6753.656, -6758.826999999999, -6763.342, -6767.189, -6770.357, -6772.834, -6774.608, -6775.665, -6775.994000000001, -6775.581999999999, -6774.414000000001, -6772.477, -6769.757, -6766.238, -6761.906, -6756.745, -6750.74, -6743.874, -6736.129, -6727.4890000000005, -6717.935, -6707.45, -6696.014, -6683.607, -6670.209, -6655.8, -6640.358, -6623.86, -6606.283, -6587.605, -6567.8009999999995, -6546.844, -6524.709, -6501.369000000001, -6476.797, -6450.9619999999995, -6423.835999999999, -6395.387, -6365.5830000000005, -6334.391, -6301.776999999999, -6267.704000000001, -6232.1359999999995, -6195.034000000001, -6156.359, -6116.069, -6074.121, -6030.47, -5985.071999999999, -5937.876, -5888.834, -5837.893, -5784.999, -5730.097, -5673.1269999999995, -5614.03, -5552.741, -5489.196999999999, -5423.326999999999, -5355.062, -5284.326999999999, -5211.048, -5135.143, -5056.529, -4975.122, -4890.834, -4803.571, -4713.241, -4619.744000000001, -4522.981, -4422.846, -4319.236, -4212.042, -4101.154, -3986.461, -3867.8509999999997, -3745.216, -3618.4429999999998, -3487.428, -3352.07, -3212.2709999999997, -3067.948, -2919.028, -2765.448, -2607.172, -2444.181, -2276.489, -2104.14, -1927.2179999999998, -1745.855, -1560.229, -1370.578, -1177.201, -980.462, -780.791, -578.687, -374.712, -169.486, 36.323, 242.00900000000001, 446.845, 650.0980000000001, 851.046, 1048.998, 1243.306, 1433.38, 1618.6979999999999, 1798.815, 1973.361, 2142.0460000000003, 2304.655, 2461.044, 2611.131, 2754.893, 2892.353, 3023.579, 3148.67, 3267.7529999999997, 3380.978, 3488.506, 3590.514, 3687.184, 3778.703, 3865.258, 3947.0370000000003, 4024.2259999999997, 4097.005, 4165.552, 4230.038, 4290.63, 4347.486, 4400.762, 4450.605, 4497.138, 4540.545999999999, 4580.907999999999, 4618.365, 4653.031, 4685.02, 4714.438, 4741.3859999999995, 4765.96, 4788.251, 4808.348, 4826.333, 4842.287, 4856.284000000001, 4868.396, 4878.692, 4887.237, 4894.095, 4899.3240000000005, 4902.981, 4905.122, 4905.795999999999, 4905.055, 4902.946, 4899.514, 4894.802, 4888.852, 4881.705, 4873.397, 4863.967000000001, 4853.448, 4841.876, 4829.281, 4815.696, 4801.15, 4785.6720000000005, 4769.289000000001, 4752.028, 4733.915, 4714.974, 4695.23, 4674.705, 4653.42, 4631.398, 4608.659000000001, 4585.222, 4561.108, 4536.334, 4510.919, 4484.878, 4458.23, 4430.991, 4403.1759999999995, 4374.8, 4345.878, 4316.424, 4286.452, 4255.975, 4225.005999999999, 4193.558, 4161.643, 4129.273, 4096.46, 4063.2140000000004, 4029.545, 3995.466, 3960.986, 3926.114, 3890.862, 3855.237, 3819.25, 3782.909, 3746.223, 3709.2009999999996, 3671.849, 3634.178, 3596.1929999999998, 3557.9040000000005, 3519.3179999999998, 3480.441, 3441.281, 3401.845, 3362.14, 3322.172, 3281.947, 3241.473, 3200.7540000000004, 3159.798, 3118.61, 3077.195, 3035.56, 2993.71, 2951.65, 2909.385, 2866.921, 2824.263, 2781.415, 2738.383, 2695.172, 2651.785, 2608.228, 2564.504, 2520.619, 2476.577, 2432.382, 2388.038, 2343.548, 2298.9179999999997, 2254.152, 2209.252, 2164.222, 2119.067, 2073.79, 2028.395, 1982.885, 1937.264, 1891.535, 1845.701, 1799.767, 1753.734, 1707.606, 1661.3870000000002, 1615.08, 1568.6860000000001, 1522.211, 1475.656, 1429.025, 1382.32, 1335.5439999999999, 1288.701, 1241.792, 1194.82, 1147.789, 1100.701, 1053.559, 1006.365, 959.1210000000001, 911.831, 864.4960000000001, 817.12, 769.704, 722.252, 674.765, 627.246, 579.697, 532.121, 484.519, 436.895, 389.25, 341.586, 293.907, 246.213, 198.507, 150.791, 103.068, 55.34, 7.608, -40.126, -87.859, -135.589, -183.31400000000002, -231.033, -278.743, -326.442, -374.129, -421.801, -469.45599999999996, -517.0930000000001, -564.7090000000001, -612.303, -659.873, -707.4169999999999, -754.933, -802.419, -849.8739999999999, -897.295, -944.68, -992.029, -1039.338, -1086.607, -1133.833, -1181.014, -1228.149, -1275.237, -1322.274, -1369.26, -1416.192, -1463.07, -1509.89, -1556.652, -1603.3529999999998, -1649.993, -1696.568, -1743.0770000000002, -1789.52, -1835.892, -1882.194, -1928.4229999999998, -1974.578, -2020.6570000000002, -2066.657, -2112.578, -2158.417, -2204.173, -2249.845, -2295.429, -2340.925, -2386.33, -2431.644, -2476.863, -2521.987, -2567.014, -2611.942, -2656.7690000000002, -2701.493, -2746.112, -2790.625, -2835.03, -2879.3259999999996, -2923.509, -2967.579, -3011.533, -3055.3709999999996, -3099.0890000000004, -3142.6859999999997, -3186.16, -3229.51, -3272.7329999999997, -3315.827, -3358.792, -3401.6240000000003, -3444.321, -3486.883, -3529.3059999999996, -3571.5890000000004, -3613.7309999999998, -3655.728, -3697.579, -3739.282, -3780.835, -3822.236, -3863.4829999999997, -3904.574, -3945.506, -3986.278, -4026.887, -4067.3309999999997, -4107.609, -4147.717000000001, -4187.655, -4227.418, -4267.005999999999, -4306.417, -4345.647, -4384.694, -4423.557, -4462.232, -4500.718, -4539.012, -4577.112, -4615.015, -4652.719, -4690.221, -4727.519, -4764.611, -4801.4929999999995, -4838.163, -4874.619000000001, -4910.858, -4946.876, -4982.6720000000005, -5018.2429999999995, -5053.585999999999, -5088.698, -5123.576, -5158.217000000001, -5192.619000000001, -5226.778, -5260.691999999999, -5294.357, -5327.771, -5360.931, -5393.831999999999, -5426.472, -5458.848000000001, -5490.956, -5522.793000000001, -5554.356, -5585.641, -5616.645, -5647.365, -5677.795, -5707.934, -5737.778, -5767.321999999999, -5796.562, -5825.496, -5854.119000000001, -5882.427, -5910.416, -5938.081999999999, -5965.42, -5992.427, -6019.098000000001, -6045.428000000001, -6071.414000000001, -6097.0509999999995, -6122.334, -6147.258000000001, -6171.82, -6196.013000000001, -6219.831999999999, -6243.274, -6266.331999999999, -6289.001, -6311.276999999999, -6333.154, -6354.625, -6375.686, -6396.331, -6416.555, -6436.35, -6455.7119999999995, -6474.632, -6493.107, -6511.128000000001, -6528.689, -6545.785, -6562.406999999999, -6578.549, -6594.204000000001, -6609.365, -6624.023, -6638.172, -6651.803000000001, -6664.908, -6677.481, -6689.5109999999995, -6700.991, -6711.9130000000005, -6722.266, -6732.0419999999995, -6741.231, -6749.825, -6757.813, -6765.185, -6771.932, -6778.0419999999995, -6783.504, -6788.308000000001, -6792.443, -6795.896, -6798.656999999999, -6800.7119999999995, -6802.05, -6802.656, -6802.518, -6801.6230000000005, -6799.956, -6797.504, -6794.251, -6790.181, -6785.281, -6779.533, -6772.922, -6765.429, -6757.0380000000005, -6747.73, -6737.488, -6726.2919999999995, -6714.121, -6700.956999999999, -6686.776999999999, -6671.562, -6655.286, -6637.929, -6619.465, -6599.871999999999, -6579.1230000000005, -6557.191, -6534.05, -6509.672, -6484.028, -6457.085999999999, -6428.819, -6399.19, -6368.168000000001, -6335.719, -6301.807, -6266.393, -6229.44, -6190.906999999999, -6150.753000000001, -6108.936, -6065.409000000001, -6020.1269999999995, -5973.0419999999995, -5924.102, -5873.257, -5820.45, -5765.628000000001, -5708.73, -5649.696, -5588.460999999999, -5524.9619999999995, -5459.1269999999995, -5390.888000000001, -5320.168000000001, -5246.893, -5170.981, -5092.348, -5010.912, -4926.58, -4839.2609999999995, -4748.861, -4655.28, -4558.417, -4458.167, -4354.425, -4247.081, -4136.025, -4021.145, -3902.328, -3779.4640000000004, -3652.4390000000003, -3521.1479999999997, -3385.488, -3245.36, -3100.679, -2951.369, -2797.367, -2638.632, -2475.145, -2306.915, -2133.985, -1956.4360000000001, -1774.395, -1588.0379999999998, -1397.599, -1203.375, -1005.7239999999999, -805.076, -601.928, -396.837, -190.426, 16.637999999999998, 223.64700000000002, 429.871, 634.573, 837.0269999999999, 1036.5339999999999, 1232.438, 1424.141, 1611.114, 1792.902, 1969.1270000000002, 2139.493, 2303.774, 2461.822, 2613.548, 2758.925, 2897.972, 3030.7509999999997, 3157.362, 3277.927, 3392.595, 3501.528, 3604.9, 3702.8940000000002, 3795.697, 3883.4970000000003, 3966.482, 4044.837, 4118.745, 4188.384, 4253.9259999999995, 4315.539000000001, 4373.383, 4427.613, 4478.378, 4525.819, 4570.072, 4611.267, 4649.528, 4684.972, 4717.714, 4747.857, 4775.5070000000005, 4800.759, 4823.706, 4844.436, 4863.034000000001, 4879.5779999999995, 4894.147, 4906.811, 4917.641, 4926.702, 4934.057, 4939.767, 4943.888, 4946.476, 4947.584, 4947.26, 4945.554, 4942.51, 4938.173, 4932.584, 4925.785, 4917.813, 4908.706, 4898.499, 4887.226, 4874.919, 4861.611, 4847.331, 4832.109, 4815.971, 4798.945, 4781.058, 4762.333, 4742.795999999999, 4722.468, 4701.372, 4679.53, 4656.962, 4633.689, 4609.73, 4585.103, 4559.827, 4533.919, 4507.395, 4480.272, 4452.567, 4424.295, 4395.469, 4366.104, 4336.215, 4305.815, 4274.916, 4243.532, 4211.675, 4179.357, 4146.59, 4113.384, 4079.7509999999997, 4045.7009999999996, 4011.245, 3976.3920000000003, 3941.153, 3905.5359999999996, 3869.552, 3833.21, 3796.5170000000003, 3759.4840000000004, 3722.116, 3684.4240000000004, 3646.415, 3608.0959999999995, 3569.475, 3530.56, 3491.3579999999997, 3451.875, 3412.119, 3372.0959999999995, 3331.812, 3291.275, 3250.49, 3209.4629999999997, 3168.2009999999996, 3126.708, 3084.992, 3043.0559999999996, 3000.907, 2958.551, 2915.991, 2873.2340000000004, 2830.284, 2787.147, 2743.8259999999996, 2700.327, 2656.655, 2612.814, 2568.8070000000002, 2524.641, 2480.319, 2435.844, 2391.222, 2346.456, 2301.551, 2256.509, 2211.3360000000002, 2166.034, 2120.6079999999997, 2075.06, 2029.396, 1983.6170000000002, 1937.7279999999998, 1891.7320000000002, 1845.6329999999998, 1799.433, 1753.136, 1706.745, 1660.263, 1613.693, 1567.039, 1520.3029999999999, 1473.4879999999998, 1426.5970000000002, 1379.634, 1332.6, 1285.499, 1238.3339999999998, 1191.107, 1143.82, 1096.478, 1049.0810000000001, 1001.633, 954.137, 906.5939999999999, 859.008, 811.3810000000001, 763.715, 716.012, 668.2760000000001, 620.508, 572.711, 524.886, 477.038, 429.166, 381.275, 333.366, 285.441, 237.503, 189.553, 141.594, 93.62700000000001, 45.656000000000006, -2.318, -50.293, -98.26700000000001, -146.237, -194.202, -242.16, -290.10900000000004, -338.04699999999997, -385.971, -433.88, -481.772, -529.645, -577.497, -625.326, -673.13, -720.908, -768.6569999999999, -816.375, -864.062, -911.7139999999999, -959.331, -1006.909, -1054.448, -1101.9460000000001, -1149.4, -1196.809, -1244.171, -1291.485, -1338.7479999999998, -1385.9589999999998, -1433.115, -1480.2160000000001, -1527.26, -1574.244, -1621.1660000000002, -1668.026, -1714.8210000000001, -1761.55, -1808.211, -1854.8010000000002, -1901.32, -1947.765, -1994.135, -2040.4279999999999, -2086.6420000000003, -2132.776, -2178.827, -2224.794, -2270.675, -2316.469, -2362.173, -2407.786, -2453.306, -2498.731, -2544.0589999999997, -2589.29, -2634.42, -2679.448, -2724.3720000000003, -2769.191, -2813.903, -2858.505, -2902.9959999999996, -2947.375, -2991.638, -3035.785, -3079.8140000000003, -3123.722, -3167.509, -3211.171, -3254.7070000000003, -3298.115, -3341.3940000000002, -3384.5409999999997, -3427.554, -3470.4309999999996, -3513.171, -3555.772, -3598.2309999999998, -3640.546, -3682.716, -3724.739, -3766.612, -3808.333, -3849.901, -3891.312, -3932.566, -3973.66, -4014.592, -4055.36, -4095.96, -4136.393, -4176.654, -4216.7429999999995, -4256.656, -4296.391, -4335.947, -4375.321, -4414.51, -4453.512, -4492.325, -4530.946, -4569.374, -4607.605, -4645.637, -4683.467000000001, -4721.094, -4758.514, -4795.725, -4832.725, -4869.51, -4906.0779999999995, -4942.4259999999995, -4978.552, -5014.4529999999995, -5050.126, -5085.568, -5120.776, -5155.748, -5190.481, -5224.971, -5259.215999999999, -5293.213000000001, -5326.9580000000005, -5360.448, -5393.68, -5426.651, -5459.357, -5491.795999999999, -5523.965, -5555.858, -5587.474, -5618.809, -5649.859, -5680.62, -5711.09, -5741.264, -5771.138000000001, -5800.7080000000005, -5829.971, -5858.924, -5887.561, -5915.879, -5943.8730000000005, -5971.54, -5998.875, -6025.874, -6052.531999999999, -6078.846, -6104.81, -6130.42, -6155.67, -6180.557, -6205.075, -6229.22, -6252.986, -6276.368, -6299.361, -6321.96, -6344.16, -6365.953, -6387.335999999999, -6408.302, -6428.845, -6448.96, -6468.639, -6487.878000000001, -6506.670999999999, -6525.008000000001, -6542.8859999999995, -6560.297, -6577.234, -6593.689, -6609.656999999999, -6625.129, -6640.098000000001, -6654.556, -6668.496999999999, -6681.911, -6694.79, -6707.126, -6718.911, -6730.135, -6740.791, -6750.868, -6760.358, -6769.25, -6777.536, -6785.204000000001, -6792.245, -6798.649, -6804.403, -6809.4980000000005, -6813.920999999999, -6817.661999999999, -6820.7080000000005, -6823.047, -6824.6669999999995, -6825.554, -6825.695, -6825.076, -6823.684, -6821.505, -6818.523, -6814.722, -6810.088000000001, -6804.606, -6798.255999999999, -6791.023, -6782.889, -6773.8369999999995, -6763.848000000001, -6752.901, -6740.978, -6728.058000000001, -6714.121, -6699.143, -6683.104, -6665.98, -6647.746, -6628.379, -6607.852, -6586.14, -6563.215, -6539.049, -6513.6140000000005, -6486.878000000001, -6458.809, -6429.378000000001, -6398.549, -6366.286999999999, -6332.558000000001, -6297.323, -6260.543000000001, -6222.18, -6182.19, -6140.531, -6097.156999999999, -6052.022, -6005.078, -5956.273, -5905.557, -5852.8730000000005, -5798.166, -5741.376, -5682.443, -5621.303000000001, -5557.888000000001, -5492.132, -5423.960999999999, -5353.303000000001, -5280.078, -5204.207, -5125.607, -5044.192, -4959.87, -4872.55, -4782.137, -4688.53, -4591.629, -4491.327, -4387.517, -4280.090999999999, -4168.937, -4053.941, -3934.991, -3811.974, -3684.776, -3553.2909999999997, -3417.4120000000003, -3277.0429999999997, -3132.093, -2982.4840000000004, -2828.1540000000005, -2669.059, -2505.176, -2336.512, -2163.107, -1985.037, -1802.4279999999999, -1615.4520000000002, -1424.339, -1229.382, -1030.938, -829.431, -625.355, -419.26800000000003, -211.78900000000002, -3.5860000000000003, 204.63099999999997, 412.131, 618.173, 822.025, 1022.9830000000001, 1220.383, 1413.621, 1602.1589999999999, 1785.531, 1963.3529999999998, 2135.32, 2301.201, 2460.8379999999997, 2614.139, 2761.0690000000004, 2901.6440000000002, 3035.9240000000004, 3164.0040000000004, 3286.0040000000004, 3402.072, 3512.368, 3617.066, 3716.349, 3810.403, 3899.4159999999997, 3983.578, 4063.073, 4138.085999999999, 4208.794, 4275.372, 4337.987, 4396.8009999999995, 4451.97, 4503.643, 4551.962, 4597.066, 4639.084, 4678.14, 4714.355, 4747.840999999999, 4778.706, 4807.053, 4832.98, 4856.58, 4877.943, 4897.152, 4914.289000000001, 4929.429, 4942.648, 4954.014, 4963.594, 4971.451, 4977.646, 4982.237, 4985.28, 4986.827, 4986.928, 4985.633, 4982.986, 4979.032999999999, 4973.816, 4967.375, 4959.75, 4950.977, 4941.093, 4930.130999999999, 4918.125, 4905.107, 4891.107, 4876.153, 4860.275, 4843.499, 4825.852, 4807.359, 4788.044, 4767.929, 4747.038, 4725.393, 4703.014, 4679.920999999999, 4656.134, 4631.6720000000005, 4606.553, 4580.795, 4554.415, 4527.428, 4499.852, 4471.701, 4442.99, 4413.735, 4383.9490000000005, 4353.645, 4322.837, 4291.538, 4259.76, 4227.515, 4194.814, 4161.67, 4128.093, 4094.094, 4059.684, 4024.8720000000003, 3989.6679999999997, 3954.0820000000003, 3918.1240000000003, 3881.802, 3845.125, 3808.1020000000003, 3770.742, 3733.052, 3695.0409999999997, 3656.716, 3618.085, 3579.155, 3539.934, 3500.428, 3460.645, 3420.591, 3380.2729999999997, 3339.696, 3298.869, 3257.796, 3216.4829999999997, 3174.938, 3133.163, 3091.1679999999997, 3048.9559999999997, 3006.531, 2963.901, 2921.07, 2878.0429999999997, 2834.825, 2791.421, 2747.836, 2704.074, 2660.139, 2616.0370000000003, 2571.772, 2527.348, 2482.769, 2438.04, 2393.1639999999998, 2348.145, 2302.988, 2257.696, 2212.2729999999997, 2166.723, 2121.05, 2075.257, 2029.3470000000002, 1983.3239999999998, 1937.192, 1890.954, 1844.6129999999998, 1798.172, 1751.635, 1705.005, 1658.285, 1611.4779999999998, 1564.5870000000002, 1517.615, 1470.565, 1423.44, 1376.243, 1328.977, 1281.643, 1234.246, 1186.788, 1139.272, 1091.6989999999998, 1044.0739999999998, 996.398, 948.673, 900.904, 853.091, 805.237, 757.346, 709.419, 661.4580000000001, 613.466, 565.446, 517.399, 469.32800000000003, 421.235, 373.12300000000005, 324.993, 276.848, 228.69099999999997, 180.52200000000002, 132.344, 84.16, 35.972, -12.219000000000001, -60.41, -108.59899999999999, -156.785, -204.965, -253.137, -301.29900000000004, -349.45, -397.586, -445.707, -493.811, -541.894, -589.957, -637.995, -686.0089999999999, -733.995, -781.952, -829.878, -877.7719999999999, -925.63, -973.452, -1021.2360000000001, -1068.979, -1116.681, -1164.338, -1211.95, -1259.514, -1307.029, -1354.493, -1401.904, -1449.26, -1496.56, -1543.8010000000002, -1590.9820000000002, -1638.102, -1685.1570000000002, -1732.148, -1779.0710000000001, -1825.925, -1872.7089999999998, -1919.42, -1966.057, -2012.6170000000002, -2059.1, -2105.5029999999997, -2151.825, -2198.064, -2244.217, -2290.284, -2336.263, -2382.151, -2427.947, -2473.649, -2519.256, -2564.765, -2610.175, -2655.4829999999997, -2700.6890000000003, -2745.79, -2790.784, -2835.67, -2880.446, -2925.1090000000004, -2969.659, -3014.093, -3058.409, -3102.605, -3146.68, -3190.632, -3234.4590000000003, -3278.158, -3321.728, -3365.1679999999997, -3408.474, -3451.645, -3494.68, -3537.575, -3580.33, -3622.942, -3665.409, -3707.7290000000003, -3749.8990000000003, -3791.9190000000003, -3833.7870000000003, -3875.4990000000003, -3917.052, -3958.448, -3999.6809999999996, -4040.75, -4081.6540000000005, -4122.389, -4162.954000000001, -4203.347, -4243.565, -4283.605, -4323.465999999999, -4363.146, -4402.641, -4441.95, -4481.07, -4520.0, -4558.735, -4597.274, -4635.615, -4673.755, -4711.692, -4749.4220000000005, -4786.944, -4824.254, -4861.35, -4898.229, -4934.889, -4971.327, -5007.54, -5043.526, -5079.281, -5114.802, -5150.087, -5185.133, -5219.937, -5254.496, -5288.807, -5322.866, -5356.67, -5390.217, -5423.503000000001, -5456.525, -5489.279, -5521.762, -5553.971, -5585.903, -5617.553000000001, -5648.918000000001, -5679.995, -5710.78, -5741.27, -5771.459, -5801.346, -5830.9259999999995, -5860.194, -5889.147, -5917.78, -5946.09, -5974.073, -6001.723000000001, -6029.036999999999, -6056.0109999999995, -6082.64, -6108.919, -6134.843000000001, -6160.409000000001, -6185.61, -6210.443, -6234.901999999999, -6258.982, -6282.678000000001, -6305.984, -6328.896, -6351.408, -6373.515, -6395.21, -6416.486999999999, -6437.342, -6457.768, -6477.758000000001, -6497.307, -6516.409000000001, -6535.056, -6553.243, -6570.9619999999995, -6588.206999999999, -6604.97, -6621.244000000001, -6637.022, -6652.295999999999, -6667.06, -6681.304, -6695.022, -6708.204000000001, -6720.842, -6732.928000000001, -6744.453, -6755.408, -6765.784000000001, -6775.571999999999, -6784.7609999999995, -6793.343000000001, -6801.306, -6808.641, -6815.3369999999995, -6821.384, -6826.77, -6831.483, -6835.512, -6838.845, -6841.47, -6843.375, -6844.545999999999, -6844.969, -6844.630999999999, -6843.518, -6841.616999999999, -6838.91, -6835.385, -6831.024, -6825.811, -6819.732, -6812.767, -6804.899, -6796.11, -6786.383000000001, -6775.696999999999, -6764.031, -6751.366999999999, -6737.683000000001, -6722.956999999999, -6707.166, -6690.2880000000005, -6672.299, -6653.173000000001, -6632.885, -6611.409000000001, -6588.718000000001, -6564.781999999999, -6539.573, -6513.061, -6485.214, -6455.999, -6425.385, -6393.3330000000005, -6359.811, -6324.779, -6288.1990000000005, -6250.03, -6210.231, -6168.758000000001, -6125.566999999999, -6080.609, -6033.838000000001, -5985.201, -5934.647, -5882.12, -5827.565, -5770.920999999999, -5712.128000000001, -5651.121, -5587.834, -5522.198, -5454.14, -5383.588000000001, -5310.4619999999995, -5234.681, -5156.163, -5074.821, -4990.563, -4903.298, -4812.929, -4719.356, -4622.477, -4522.186, -4418.375, -4310.935, -4199.752, -4084.7140000000004, -3965.705, -3842.611, -3715.321, -3583.723, -3447.711, -3307.187, -3162.058, -3012.245, -2857.683, -2698.325, -2534.147, -2365.153, -2191.3779999999997, -2012.898, -1829.8329999999999, -1642.352, -1450.682, -1255.11, -1055.99, -853.745, -648.863, -441.901, -233.475, -24.254, 185.053, 393.711, 600.977, 806.1160000000001, 1008.416, 1207.208, 1401.878, 1591.881, 1776.745, 1956.0770000000002, 2129.561, 2296.9610000000002, 2458.112, 2612.916, 2761.333, 2903.373, 3039.094, 3168.586, 3291.969, 3409.387, 3521.0, 3626.9809999999998, 3727.513, 3822.78, 3912.972, 3998.277, 4078.883, 4154.971, 4226.724, 4294.313, 4357.907999999999, 4417.6720000000005, 4473.7609999999995, 4526.3240000000005, 4575.4259999999995, 4621.448, 4664.275, 4704.117, 4741.092000000001, 4775.315, 4806.894, 4835.932, 4862.529, 4886.778, 4908.771, 4928.589, 4946.317, 4962.03, 4975.804, 4987.707, 4997.809, 5006.170999999999, 5012.855, 5017.9220000000005, 5021.424, 5023.417, 5023.9490000000005, 5023.072, 5020.831, 5017.271, 5012.434, 5006.361, 4999.092000000001, 4990.665, 4981.115, 4970.477, 4958.784000000001, 4946.068, 4932.36, 4917.69, 4902.085, 4885.5740000000005, 4868.182, 4849.935, 4830.857, 4810.972, 4790.302, 4768.87, 4746.696, 4723.8009999999995, 4700.204000000001, 4675.925, 4650.981, 4625.392, 4599.173, 4572.340999999999, 4544.913, 4516.903, 4488.3279999999995, 4459.202, 4429.538, 4399.352, 4368.655, 4337.460999999999, 4305.782999999999, 4273.6320000000005, 4241.02, 4207.959, 4174.46, 4140.534000000001, 4106.192, 4071.4429999999998, 4036.297, 4000.764, 3964.8540000000003, 3928.5759999999996, 3891.9390000000003, 3854.9509999999996, 3817.6209999999996, 3779.9570000000003, 3741.968, 3703.66, 3665.0429999999997, 3626.1220000000003, 3586.906, 3547.402, 3507.616, 3467.555, 3427.2270000000003, 3386.637, 3345.792, 3304.698, 3263.36, 3221.7870000000003, 3179.98, 3137.949, 3095.698, 3053.2329999999997, 3010.558, 2967.678, 2924.6, 2881.328, 2837.866, 2794.22, 2750.3940000000002, 2706.393, 2662.222, 2617.884, 2573.385, 2528.728, 2483.917, 2438.9570000000003, 2393.853, 2348.606, 2303.223, 2257.706, 2212.0589999999997, 2166.286, 2120.391, 2074.377, 2028.247, 1982.006, 1935.656, 1889.201, 1842.644, 1795.9879999999998, 1749.237, 1702.394, 1655.461, 1608.442, 1561.34, 1514.1589999999999, 1466.899, 1419.566, 1372.161, 1324.6870000000001, 1277.1480000000001, 1229.545, 1181.882, 1134.162, 1086.386, 1038.557, 990.678, 942.752, 894.7819999999999, 846.768, 798.715, 750.6239999999999, 702.498, 654.339, 606.15, 557.932, 509.689, 461.42199999999997, 413.134, 364.827, 316.503, 268.165, 219.81400000000002, 171.453, 123.083, 74.708, 26.328000000000003, -22.053, -70.434, -118.81299999999999, -167.188, -215.55599999999998, -263.916, -312.26599999999996, -360.603, -408.926, -457.23199999999997, -505.52099999999996, -553.789, -602.036, -650.258, -698.454, -746.623, -794.762, -842.87, -890.944, -938.982, -986.9839999999999, -1034.947, -1082.869, -1130.748, -1178.583, -1226.371, -1274.112, -1321.8020000000001, -1369.441, -1417.026, -1464.555, -1512.0279999999998, -1559.442, -1606.795, -1654.085, -1701.3110000000001, -1748.471, -1795.5629999999999, -1842.586, -1889.537, -1936.414, -1983.217, -2029.943, -2076.59, -2123.157, -2169.6420000000003, -2216.0429999999997, -2262.3579999999997, -2308.5860000000002, -2354.724, -2400.771, -2446.725, -2492.585, -2538.347, -2584.012, -2629.5759999999996, -2675.038, -2720.397, -2765.6490000000003, -2810.7940000000003, -2855.829, -2900.7540000000004, -2945.565, -2990.261, -3034.841, -3079.302, -3123.6420000000003, -3167.8590000000004, -3211.953, -3255.9190000000003, -3299.758, -3343.466, -3387.042, -3430.4840000000004, -3473.789, -3516.9570000000003, -3559.985, -3602.87, -3645.611, -3688.2059999999997, -3730.652, -3772.949, -3815.092, -3857.0820000000003, -3898.914, -3940.5879999999997, -3982.1, -4023.45, -4064.634, -4105.651, -4146.498, -4187.173, -4227.674, -4267.998, -4308.144, -4348.108, -4387.889, -4427.484, -4466.891, -4506.108, -4545.130999999999, -4583.959, -4622.589, -4661.018, -4699.244000000001, -4737.264, -4775.076, -4812.677, -4850.065, -4887.236, -4924.189, -4960.92, -4997.4259999999995, -5033.705, -5069.755, -5105.571, -5141.151, -5176.4929999999995, -5211.593, -5246.448, -5281.054, -5315.41, -5349.512, -5383.356, -5416.94, -5450.26, -5483.312, -5516.094, -5548.603, -5580.834, -5612.784000000001, -5644.4490000000005, -5675.826, -5706.911999999999, -5737.701, -5768.191999999999, -5798.379, -5828.26, -5857.829000000001, -5887.0830000000005, -5916.018, -5944.630999999999, -5972.915, -6000.868, -6028.485, -6055.7609999999995, -6082.691999999999, -6109.273, -6135.5, -6161.368, -6186.871999999999, -6212.007, -6236.769, -6261.151999999999, -6285.151, -6308.76, -6331.974, -6354.789000000001, -6377.196999999999, -6399.194, -6420.775, -6441.932, -6462.66, -6482.953, -6502.804, -6522.206999999999, -6541.155, -6559.643, -6577.6630000000005, -6595.209, -6612.273, -6628.847, -6644.925, -6660.499, -6675.562, -6690.105, -6704.121, -6717.601, -6730.536999999999, -6742.920999999999, -6754.743, -6765.994000000001, -6776.666, -6786.749, -6796.234, -6805.11, -6813.366999999999, -6820.995, -6827.984, -6834.321999999999, -6839.999, -6845.003000000001, -6849.321999999999, -6852.944, -6855.857, -6858.049, -6859.505999999999, -6860.214, -6860.16, -6859.331, -6857.7119999999995, -6855.2880000000005, -6852.0419999999995, -6847.96, -6843.026999999999, -6837.224, -6830.534000000001, -6822.94, -6814.425, -6804.969, -6794.553000000001, -6783.156, -6770.759, -6757.340999999999, -6742.878000000001, -6727.35, -6710.732, -6693.001, -6674.132, -6654.099, -6632.876, -6610.434, -6586.746999999999, -6561.785, -6535.517, -6507.911, -6478.936, -6448.557, -6416.741, -6383.4490000000005, -6348.645, -6312.291, -6274.344, -6234.764, -6193.507, -6150.528, -6105.779, -6059.213000000001, -6010.776999999999, -5960.420999999999, -5908.0869999999995, -5853.721, -5797.2609999999995, -5738.648, -5677.816, -5614.6990000000005, -5549.227, -5481.329000000001, -5410.929, -5337.95, -5262.311, -5183.927, -5102.712, -5018.575, -4931.4220000000005, -4841.157, -4747.679, -4650.8859999999995, -4550.673, -4446.929, -4339.544, -4228.406, -4113.399, -3994.409, -3871.321, -3744.02, -3612.395, -3476.3390000000004, -3335.75, -3190.5359999999996, -3040.616, -2885.921, -2726.403, -2562.035, -2392.82, -2218.7870000000003, -2040.01, -1856.605, -1668.7379999999998, -1476.631, -1280.567, -1080.896, -878.0369999999999, -672.475, -464.764, -255.518, -45.403999999999996, 164.868, 374.56300000000005, 582.936, 789.243, 992.7719999999999, 1192.846, 1388.845, 1580.214, 1766.473, 1947.2220000000002, 2122.136, 2290.974, 2453.56, 2609.7929999999997, 2759.627, 2903.0679999999998, 3040.167, 3171.015, 3295.7259999999997, 3414.4440000000004, 3527.327, 3634.547, 3736.285, 3832.7270000000003, 3924.0609999999997, 4010.4770000000003, 4092.1609999999996, 4169.2970000000005, 4242.066, 4310.642, 4375.194, 4435.8859999999995, 4492.876, 4546.314, 4596.345, 4643.107, 4686.732, 4727.347, 4765.072, 4800.022, 4832.307, 4862.031, 4889.293, 4914.188, 4936.805, 4957.232, 4975.549, 4991.835, 5006.164000000001, 5018.607, 5029.231, 5038.103, 5045.281, 5050.826, 5054.794, 5057.238, 5058.21, 5057.758, 5055.931, 5052.771, 5048.3240000000005, 5042.63, 5035.728, 5027.656, 5018.452, 5008.149, 4996.781, 4984.3820000000005, 4970.98, 4956.606, 4941.289000000001, 4925.057, 4907.936, 4889.951, 4871.126, 4851.486, 4831.055, 4809.853, 4787.901, 4765.221, 4741.832, 4717.754, 4693.005, 4667.602, 4641.563, 4614.906, 4587.645, 4559.798, 4531.379, 4502.402, 4472.883, 4442.834, 4412.269, 4381.202, 4349.645, 4317.61, 4285.109, 4252.154, 4218.755999999999, 4184.925, 4150.673, 4116.01, 4080.945, 4045.49, 4009.652, 3973.441, 3936.867, 3899.938, 3862.6620000000003, 3825.0490000000004, 3787.105, 3748.84, 3710.26, 3671.3740000000003, 3632.1890000000003, 3592.711, 3552.948, 3512.906, 3472.593, 3432.015, 3391.178, 3350.0879999999997, 3308.752, 3267.176, 3225.365, 3183.325, 3141.062, 3098.5809999999997, 3055.887, 3012.986, 2969.883, 2926.583, 2883.09, 2839.4109999999996, 2795.548, 2751.508, 2707.2940000000003, 2662.9109999999996, 2618.363, 2573.655, 2528.791, 2483.775, 2438.611, 2393.304, 2347.856, 2302.272, 2256.556, 2210.712, 2164.742, 2118.651, 2072.4429999999998, 2026.12, 1979.6860000000001, 1933.144, 1886.499, 1839.7520000000002, 1792.908, 1745.97, 1698.94, 1651.8220000000001, 1604.618, 1557.3329999999999, 1509.9679999999998, 1462.526, 1415.011, 1367.425, 1319.7720000000002, 1272.053, 1224.272, 1176.431, 1128.5330000000001, 1080.58, 1032.576, 984.5219999999999, 936.421, 888.2769999999999, 840.09, 791.8639999999999, 743.6010000000001, 695.303, 646.9730000000001, 598.614, 550.227, 501.814, 453.379, 404.92199999999997, 356.44800000000004, 307.957, 259.452, 210.935, 162.408, 113.874, 65.334, 16.791, -31.754, -80.298, -128.839, -177.375, -225.90400000000002, -274.425, -322.935, -371.43199999999996, -419.914, -468.379, -516.825, -565.251, -613.655, -662.033, -710.3860000000001, -758.71, -807.0039999999999, -855.2660000000001, -903.4939999999999, -951.686, -999.84, -1047.955, -1096.028, -1144.058, -1192.0439999999999, -1239.982, -1287.872, -1335.711, -1383.4979999999998, -1431.23, -1478.9070000000002, -1526.526, -1574.085, -1621.5829999999999, -1669.0179999999998, -1716.388, -1763.691, -1810.9260000000002, -1858.09, -1905.182, -1952.2, -1999.1429999999998, -2046.0079999999998, -2092.7929999999997, -2139.498, -2186.119, -2232.656, -2279.106, -2325.468, -2371.74, -2417.92, -2464.007, -2509.9970000000003, -2555.891, -2601.685, -2647.3779999999997, -2692.968, -2738.453, -2783.8320000000003, -2829.103, -2874.263, -2919.3109999999997, -2964.244, -3009.062, -3053.762, -3098.343, -3142.801, -3187.136, -3231.3459999999995, -3275.428, -3319.381, -3363.202, -3406.89, -3450.4429999999998, -3493.8579999999997, -3537.135, -3580.2690000000002, -3623.261, -3666.107, -3708.805, -3751.3540000000003, -3793.752, -3835.995, -3878.083, -3920.012, -3961.781, -4003.388, -4044.8309999999997, -4086.1059999999998, -4127.213, -4168.148, -4208.91, -4249.496, -4289.904, -4330.130999999999, -4370.1759999999995, -4410.035, -4449.707, -4489.189, -4528.479, -4567.5740000000005, -4606.471, -4645.169, -4683.664000000001, -4721.9529999999995, -4760.036, -4797.907999999999, -4835.567, -4873.01, -4910.235, -4947.2390000000005, -4984.02, -5020.573, -5056.897, -5092.9890000000005, -5128.845, -5164.463, -5199.84, -5234.973, -5269.858, -5304.491999999999, -5338.8730000000005, -5372.996999999999, -5406.861, -5440.460999999999, -5473.795, -5506.858, -5539.649, -5572.161999999999, -5604.395, -5636.343000000001, -5668.004, -5699.374, -5730.4490000000005, -5761.224, -5791.696999999999, -5821.863, -5851.718000000001, -5881.259, -5910.481, -5939.380999999999, -5967.953, -5996.194, -6024.099, -6051.664000000001, -6078.883000000001, -6105.754, -6132.27, -6158.428000000001, -6184.222, -6209.648, -6234.7, -6259.374, -6283.664000000001, -6307.564, -6331.07, -6354.1759999999995, -6376.8769999999995, -6399.166, -6421.0380000000005, -6442.488, -6463.509, -6484.094, -6504.238, -6523.934, -6543.1759999999995, -6561.956999999999, -6580.27, -6598.109, -6615.465999999999, -6632.334, -6648.705, -6664.573, -6679.929, -6694.765, -6709.075, -6722.848000000001, -6736.076999999999, -6748.754, -6760.869000000001, -6772.414000000001, -6783.379, -6793.754, -6803.531, -6812.7, -6821.249, -6829.169, -6836.4490000000005, -6843.079000000001, -6849.047, -6854.342, -6858.951, -6862.8640000000005, -6866.066, -6868.547, -6870.293000000001, -6871.291, -6871.525, -6870.984, -6869.651, -6867.514, -6864.554, -6860.758000000001, -6856.108, -6850.59, -6844.184, -6836.8730000000005, -6828.639, -6819.465, -6809.328, -6798.210999999999, -6786.093000000001, -6772.951999999999, -6758.766, -6743.513000000001, -6727.17, -6709.713000000001, -6691.115, -6671.353, -6650.4, -6628.227, -6604.807, -6580.111, -6554.106, -6526.764, -6498.05, -6467.93, -6436.371, -6403.335, -6368.785, -6332.683000000001, -6294.986, -6255.654, -6214.642, -6171.906999999999, -6127.399, -6081.07, -6032.871, -5982.746999999999, -5930.643, -5876.504, -5820.268, -5761.876, -5701.2609999999995, -5638.357, -5573.096, -5505.403, -5435.205, -5362.424, -5286.976, -5208.78, -5127.748, -5043.788, -4956.807, -4866.707, -4773.388, -4676.747, -4576.678, -4473.071, -4365.815, -4254.795, -4139.898, -4021.006, -3898.005, -3770.7790000000005, -3639.2140000000004, -3503.204, -3362.645, -3217.442, -3067.514, -2912.789, -2753.216, -2588.7670000000003, -2419.4410000000003, -2245.264, -2066.308, -1882.683, -1694.5510000000002, -1502.131, -1305.702, -1105.609, -902.2660000000001, -696.154, -487.825, -277.889, -67.012, 144.09799999999998, 354.70300000000003, 564.056, 771.413, 976.054, 1177.296, 1374.5120000000002, 1567.141, 1754.695, 1936.764, 2113.018, 2283.205, 2447.146, 2604.731, 2755.908, 2900.679, 3039.093, 3171.2340000000004, 3297.216, 3417.18, 3531.282, 3639.6929999999998, 3742.593, 3840.1679999999997, 3932.6059999999998, 4020.0959999999995, 4102.826, 4180.978, 4254.735, 4324.27, 4389.755, 4451.353, 4509.223, 4563.515, 4614.376, 4661.944, 4706.352, 4747.727, 4786.192, 4821.86, 4854.842000000001, 4885.2429999999995, 4913.164000000001, 4938.698, 4961.938, 4982.969, 5001.874, 5018.732, 5033.616, 5046.6, 5057.75, 5067.1320000000005, 5074.807, 5080.835999999999, 5085.274, 5088.1759999999995, 5089.593, 5089.5740000000005, 5088.168, 5085.419, 5081.37, 5076.064, 5069.539000000001, 5061.835, 5052.988, 5043.032, 5032.002, 5019.931, 5006.849, 4992.786, 4977.771, 4961.832, 4944.997, 4927.289000000001, 4908.735, 4889.357, 4869.18, 4848.225, 4826.514, 4804.067, 4780.904, 4757.045, 4732.509, 4707.313, 4681.475, 4655.0109999999995, 4627.939, 4600.274, 4572.031, 4543.225, 4513.87, 4483.98, 4453.57, 4422.651, 4391.238, 4359.340999999999, 4326.974, 4294.147, 4260.872, 4227.161, 4193.023, 4158.469, 4123.51, 4088.155, 4052.413, 4016.295, 3979.808, 3942.962, 3905.7659999999996, 3868.228, 3830.3559999999998, 3792.158, 3753.6420000000003, 3714.815, 3675.6859999999997, 3636.26, 3596.546, 3556.5490000000004, 3516.278, 3475.738, 3434.935, 3393.877, 3352.5690000000004, 3311.0170000000003, 3269.2270000000003, 3227.2059999999997, 3184.9570000000003, 3142.488, 3099.804, 3056.908, 3013.808, 2970.508, 2927.012, 2883.3259999999996, 2839.455, 2795.402, 2751.1740000000004, 2706.7740000000003, 2662.2059999999997, 2617.475, 2572.5860000000002, 2527.542, 2482.348, 2437.007, 2391.524, 2345.902, 2300.145, 2254.257, 2208.242, 2162.104, 2115.845, 2069.469, 2022.98, 1976.382, 1929.6770000000001, 1882.869, 1835.961, 1788.9560000000001, 1741.858, 1694.6689999999999, 1647.3929999999998, 1600.0320000000002, 1552.5910000000001, 1505.07, 1457.474, 1409.806, 1362.067, 1314.261, 1266.391, 1218.4589999999998, 1170.468, 1122.421, 1074.32, 1026.1680000000001, 977.967, 929.72, 881.429, 833.097, 784.7260000000001, 736.319, 687.878, 639.406, 590.905, 542.376, 493.82199999999995, 445.246, 396.65, 348.036, 299.407, 250.763, 202.109, 153.445, 104.774, 56.098, 7.419, -41.26, -89.939, -138.614, -187.28400000000002, -235.946, -284.599, -333.241, -381.869, -430.48199999999997, -479.07800000000003, -527.655, -576.21, -624.742, -673.25, -721.73, -770.181, -818.602, -866.99, -915.3439999999999, -963.6619999999999, -1011.941, -1060.18, -1108.377, -1156.53, -1204.638, -1252.6989999999998, -1300.71, -1348.67, -1396.5770000000002, -1444.43, -1492.226, -1539.963, -1587.641, -1635.256, -1682.808, -1730.2939999999999, -1777.713, -1825.0620000000001, -1872.3410000000001, -1919.547, -1966.6779999999999, -2013.733, -2060.71, -2107.607, -2154.422, -2201.153, -2247.799, -2294.3579999999997, -2340.828, -2387.206, -2433.493, -2479.6839999999997, -2525.78, -2571.777, -2617.674, -2663.47, -2709.1609999999996, -2754.748, -2800.2259999999997, -2845.5959999999995, -2890.8540000000003, -2936.0, -2981.03, -3025.9429999999998, -3070.738, -3115.4120000000003, -3159.9640000000004, -3204.39, -3248.691, -3292.863, -3336.9040000000005, -3380.813, -3424.5879999999997, -3468.2259999999997, -3511.7259999999997, -3555.085, -3598.302, -3641.375, -3684.3, -3727.078, -3769.704, -3812.177, -3854.4959999999996, -3896.657, -3938.659, -3980.5, -4022.176, -4063.687, -4105.03, -4146.202, -4187.202, -4228.027, -4268.674, -4309.142, -4349.427, -4389.529, -4429.443, -4469.168, -4508.702, -4548.042, -4587.185, -4626.129, -4664.871, -4703.409000000001, -4741.74, -4779.862, -4817.771, -4855.465999999999, -4892.943, -4930.2, -4967.233, -5004.041, -5040.619000000001, -5076.965999999999, -5113.079000000001, -5148.9529999999995, -5184.587, -5219.978, -5255.121999999999, -5290.016, -5324.656999999999, -5359.0419999999995, -5393.1669999999995, -5427.03, -5460.6269999999995, -5493.954000000001, -5527.008000000001, -5559.786, -5592.284000000001, -5624.499, -5656.4259999999995, -5688.063, -5719.405, -5750.45, -5781.191999999999, -5811.628000000001, -5841.754, -5871.565, -5901.059, -5930.23, -5959.075, -5987.588000000001, -6015.767, -6043.606, -6071.1, -6098.246, -6125.039000000001, -6151.473000000001, -6177.544, -6203.246999999999, -6228.576999999999, -6253.528, -6278.097, -6302.276999999999, -6326.063, -6349.4490000000005, -6372.431, -6395.001, -6417.155, -6438.887, -6460.189, -6481.057, -6501.485, -6521.465, -6540.991, -6560.057, -6578.655, -6596.778, -6614.420999999999, -6631.5740000000005, -6648.233, -6664.387, -6680.03, -6695.154, -6709.751, -6723.812, -6737.329000000001, -6750.295, -6762.6990000000005, -6774.531999999999, -6785.786, -6796.451, -6806.518, -6815.976, -6824.816, -6833.026999999999, -6840.597, -6847.518, -6853.776, -6859.361999999999, -6864.263000000001, -6868.465999999999, -6871.96, -6874.732, -6876.77, -6878.058000000001, -6878.585, -6878.334, -6877.294, -6875.446999999999, -6872.779, -6869.274, -6864.916, -6859.689, -6853.5740000000005, -6846.554, -6838.611, -6829.727, -6819.882, -6809.055, -6797.226, -6784.375, -6770.479, -6755.515, -6739.460999999999, -6722.291, -6703.982, -6684.508000000001, -6663.840999999999, -6641.954000000001, -6618.821, -6594.409000000001, -6568.689, -6541.630999999999, -6513.2, -6483.363, -6452.085999999999, -6419.33, -6385.061, -6349.236999999999, -6311.819, -6272.763000000001, -6232.028, -6189.566, -6145.331999999999, -6099.276, -6051.347, -6001.491, -5949.656, -5895.781999999999, -5839.811, -5781.68, -5721.325, -5658.68, -5593.674, -5526.236, -5456.289000000001, -5383.755, -5308.554, -5230.6, -5149.807, -5066.083, -4979.333, -4889.460999999999, -4796.366, -4699.944, -4600.088, -4496.689, -4389.635, -4278.81, -4164.101, -4045.39, -3922.56, -3795.494, -3664.08, -3528.208, -3387.775, -3242.683, -3092.847, -2938.197, -2778.678, -2614.259, -2444.936, -2270.7329999999997, -2091.717, -1907.995, -1719.725, -1527.12, -1330.455, -1130.072, -926.378, -719.852, -511.038, -300.548, -89.042, 122.771, 334.156, 544.361, 752.64, 958.2689999999999, 1160.56, 1358.88, 1552.6589999999999, 1741.401, 1924.6889999999999, 2102.186, 2273.631, 2438.839, 2597.6929999999998, 2750.135, 2896.164, 3035.823, 3169.192, 3296.384, 3417.535, 3532.803, 3642.3540000000003, 3746.369, 3845.032, 3938.533, 4027.058, 4110.795999999999, 4189.932, 4264.644, 4335.111, 4401.501, 4463.98, 4522.706, 4577.832, 4629.3240000000005, 4677.86, 4723.036, 4765.157, 4804.347, 4840.721, 4874.391, 4905.462, 4934.032999999999, 4960.201, 4984.058, 5005.69, 5025.18, 5042.607, 5058.0470000000005, 5071.571, 5083.248, 5093.143, 5101.319, 5107.834, 5112.748, 5116.112, 5117.98, 5118.401, 5117.424, 5115.093, 5111.451, 5106.543, 5100.406, 5093.079000000001, 5084.6, 5075.004, 5064.325, 5052.595, 5039.846, 5026.108, 5011.41, 4995.78, 4979.245, 4961.831, 4943.562, 4924.463, 4904.558, 4883.8679999999995, 4862.414000000001, 4840.218, 4817.3009999999995, 4793.681, 4769.376, 4744.406, 4718.788, 4692.539000000001, 4665.6759999999995, 4638.213, 4610.167, 4581.553, 4552.385, 4522.6759999999995, 4492.442, 4461.695, 4430.448, 4398.713, 4366.502, 4333.827, 4300.6990000000005, 4267.13, 4233.130999999999, 4198.710999999999, 4163.880999999999, 4128.651, 4093.03, 4057.028, 4020.6540000000005, 3983.917, 3946.8259999999996, 3909.389, 3871.615, 3833.51, 3795.0840000000003, 3756.343, 3717.296, 3677.949, 3638.31, 3598.386, 3558.183, 3517.708, 3476.967, 3435.968, 3394.716, 3353.216, 3311.4759999999997, 3269.5, 3227.2940000000003, 3184.865, 3142.217, 3099.3559999999998, 3056.2859999999996, 3013.014, 2969.5440000000003, 2925.88, 2882.028, 2837.993, 2793.7790000000005, 2749.39, 2704.8320000000003, 2660.1079999999997, 2615.223, 2570.18, 2524.984, 2479.64, 2434.151, 2388.52, 2342.752, 2296.851, 2250.82, 2204.663, 2158.383, 2111.985, 2065.471, 2018.845, 1972.11, 1925.27, 1878.328, 1831.287, 1784.15, 1736.921, 1689.6029999999998, 1642.1970000000001, 1594.7089999999998, 1547.14, 1499.493, 1451.771, 1403.9779999999998, 1356.115, 1308.187, 1260.194, 1212.141, 1164.029, 1115.862, 1067.641, 1019.3710000000001, 971.052, 922.687, 874.28, 825.832, 777.346, 728.824, 680.2689999999999, 631.683, 583.069, 534.427, 485.76199999999994, 437.075, 388.369, 339.645, 290.905, 242.153, 193.39, 144.618, 95.84, 47.056999999999995, -1.7280000000000002, -50.513999999999996, -99.29799999999999, -148.078, -196.852, -245.618, -294.374, -343.119, -391.85, -440.564, -489.26199999999994, -537.939, -586.595, -635.227, -683.8330000000001, -732.413, -780.9630000000001, -829.4810000000001, -878.065, -926.5160000000001, -974.93, -1023.305, -1071.639, -1119.931, -1168.1789999999999, -1216.381, -1264.535, -1312.639, -1360.691, -1408.69, -1456.634, -1504.52, -1552.348, -1600.115, -1647.819, -1695.46, -1743.0339999999999, -1790.54, -1837.976, -1885.3410000000001, -1932.632, -1979.849, -2026.9879999999998, -2074.048, -2121.028, -2167.926, -2214.739, -2261.466, -2308.105, -2354.655, -2401.113, -2447.478, -2493.7470000000003, -2539.92, -2585.993, -2631.966, -2677.836, -2723.6020000000003, -2769.262, -2814.813, -2860.2540000000004, -2905.5840000000003, -2950.7990000000004, -2995.8990000000003, -3040.881, -3085.743, -3130.4840000000004, -3175.1009999999997, -3219.593, -3263.9570000000003, -3308.192, -3352.296, -3396.2659999999996, -3440.1009999999997, -3483.798, -3527.3559999999998, -3570.7729999999997, -3614.046, -3657.173, -3700.153, -3742.9829999999997, -3785.6609999999996, -3828.185, -3870.553, -3912.762, -3954.8109999999997, -3996.698, -4038.4190000000003, -4079.973, -4121.358, -4162.571, -4203.61, -4244.472, -4285.156, -4325.659000000001, -4365.978, -4406.111, -4446.056, -4485.811, -4525.372, -4564.738, -4603.905, -4642.872, -4681.635, -4720.192, -4758.541, -4796.678, -4834.602, -4872.309, -4909.795999999999, -4947.061, -4984.101, -5020.913, -5057.494000000001, -5093.840999999999, -5129.952, -5165.823, -5201.451, -5236.833, -5271.965999999999, -5306.847, -5341.473000000001, -5375.84, -5409.946, -5443.786, -5477.357, -5510.656, -5543.68, -5576.425, -5608.887, -5641.063, -5672.9490000000005, -5704.541, -5735.835999999999, -5766.829000000001, -5797.518, -5827.897, -5857.963000000001, -5887.710999999999, -5917.137, -5946.238, -5975.009, -6003.445, -6031.543000000001, -6059.297, -6086.703, -6113.755999999999, -6140.451999999999, -6166.785, -6192.751, -6218.345, -6243.562, -6268.395, -6292.840999999999, -6316.894, -6340.548000000001, -6363.798000000001, -6386.638000000001, -6409.061, -6431.063, -6452.637, -6473.776999999999, -6494.477, -6514.73, -6534.531, -6553.871, -6572.744000000001, -6591.144, -6609.063, -6626.494000000001, -6643.43, -6659.8640000000005, -6675.786999999999, -6691.191, -6706.068, -6720.411, -6734.21, -6747.4580000000005, -6760.145, -6772.263000000001, -6783.802, -6794.7519999999995, -6805.104, -6814.849, -6823.976, -6832.474, -6840.334, -6847.543000000001, -6854.090999999999, -6859.965999999999, -6865.158, -6869.653, -6873.439, -6876.503000000001, -6878.8330000000005, -6880.416, -6881.236, -6881.28, -6880.534000000001, -6878.983, -6876.611999999999, -6873.403, -6869.342, -6864.411999999999, -6858.596, -6851.874, -6844.23, -6835.645, -6826.1, -6815.573, -6804.045, -6791.495, -6777.9, -6763.238, -6747.486, -6730.619000000001, -6712.613, -6693.441, -6673.079000000001, -6651.496, -6628.666, -6604.559, -6579.144, -6552.39, -6524.264, -6494.732, -6463.76, -6431.31, -6397.347, -6361.828, -6324.715, -6285.965999999999, -6245.536, -6203.38, -6159.451, -6113.701, -6066.076999999999, -6016.526999999999, -5964.996, -5911.427, -5855.76, -5797.933000000001, -5737.882, -5675.539000000001, -5610.835, -5543.698, -5474.052, -5401.816999999999, -5326.914000000001, -5249.258000000001, -5168.7609999999995, -5085.331, -4998.873, -4909.292, -4816.485, -4720.349, -4620.776, -4517.657, -4410.878, -4300.326, -4185.884, -4067.435, -3944.86, -3818.0440000000003, -3686.8709999999996, -3551.2309999999998, -3411.0190000000002, -3266.137, -3116.4970000000003, -2962.028, -2802.672, -2638.395, -2469.19, -2295.0789999999997, -2116.124, -1932.43, -1744.148, -1551.489, -1354.7220000000002, -1154.183, -950.275, -743.4730000000001, -534.316, -323.411, -111.416, 100.962, 312.987, 523.909, 732.9780000000001, 939.465, 1142.6789999999999, 1341.98, 1536.7920000000001, 1726.611, 1911.013, 2089.651, 2262.259, 2428.643, 2588.678, 2742.304, 2889.512, 3030.341, 3164.868, 3293.203, 3415.48, 3531.8520000000003, 3642.488, 3747.565, 3847.2670000000003, 3941.783, 4031.3, 4116.005, 4196.084, 4271.718, 4343.081, 4410.346, 4473.677, 4533.233, 4589.167, 4641.626, 4690.75, 4736.673, 4779.523, 4819.423, 4856.49, 4890.834, 4922.561, 4951.773, 4978.567, 5003.032999999999, 5025.259, 5045.33, 5063.322, 5079.314, 5093.376, 5105.579000000001, 5115.987, 5124.664000000001, 5131.669, 5137.06, 5140.891, 5143.214, 5144.081, 5143.538, 5141.6320000000005, 5138.405, 5133.902, 5128.161, 5121.222, 5113.121, 5103.895, 5093.577, 5082.2, 5069.7970000000005, 5056.397, 5042.029, 5026.721, 5010.502, 4993.396, 4975.428, 4956.624, 4937.0070000000005, 4916.598, 4895.419, 4873.492, 4850.838, 4827.474, 4803.420999999999, 4778.696, 4753.318, 4727.302, 4700.667, 4673.427, 4645.6, 4617.1990000000005, 4588.238, 4558.733, 4528.697, 4498.142, 4467.083, 4435.532, 4403.501, 4371.001, 4338.044, 4304.641, 4270.804, 4236.541, 4201.865, 4166.785, 4131.31, 4095.45, 4059.2140000000004, 4022.612, 3985.651, 3948.34, 3910.6890000000003, 3872.704, 3834.3940000000002, 3795.765, 3756.827, 3717.586, 3678.0490000000004, 3638.224, 3598.116, 3557.7340000000004, 3517.0820000000003, 3476.1690000000003, 3435.0, 3393.58, 3351.917, 3310.015, 3267.881, 3225.52, 3182.937, 3140.138, 3097.1279999999997, 3053.913, 3010.4970000000003, 2966.885, 2923.0820000000003, 2879.093, 2834.922, 2790.574, 2746.054, 2701.366, 2656.514, 2611.502, 2566.335, 2521.016, 2475.551, 2429.9410000000003, 2384.192, 2338.3070000000002, 2292.291, 2246.145, 2199.875, 2153.484, 2106.976, 2060.353, 2013.619, 1966.777, 1919.832, 1872.785, 1825.641, 1778.402, 1731.0720000000001, 1683.6529999999998, 1636.148, 1588.5610000000001, 1540.894, 1493.151, 1445.3339999999998, 1397.4460000000001, 1349.489, 1301.4669999999999, 1253.382, 1205.237, 1157.035, 1108.777, 1060.4669999999999, 1012.1080000000001, 963.701, 915.2489999999999, 866.755, 818.222, 769.65, 721.044, 672.405, 623.735, 575.038, 526.314, 477.56800000000004, 428.79900000000004, 380.01199999999994, 331.208, 282.39, 233.558, 184.717, 135.86700000000002, 87.012, 38.152, -10.709000000000001, -59.571000000000005, -108.43, -157.284, -206.13299999999998, -254.97299999999998, -303.802, -352.62, -401.423, -450.209, -498.978, -547.726, -596.452, -645.154, -693.83, -742.4789999999999, -791.097, -839.684, -888.237, -936.755, -985.235, -1033.6760000000002, -1082.076, -1130.434, -1178.746, -1227.012, -1275.23, -1323.3970000000002, -1371.5120000000002, -1419.5739999999998, -1467.579, -1515.527, -1563.4160000000002, -1611.243, -1659.007, -1706.707, -1754.34, -1801.904, -1849.398, -1896.82, -1944.168, -1991.44, -2038.635, -2085.751, -2132.785, -2179.736, -2226.603, -2273.382, -2320.074, -2366.675, -2413.1839999999997, -2459.599, -2505.9179999999997, -2552.139, -2598.261, -2644.281, -2690.198, -2736.01, -2781.715, -2827.3109999999997, -2872.797, -2918.1690000000003, -2963.427, -3008.5690000000004, -3053.592, -3098.494, -3143.275, -3187.9309999999996, -3232.46, -3276.862, -3321.133, -3365.272, -3409.276, -3453.145, -3496.875, -3540.4640000000004, -3583.9120000000003, -3627.215, -3670.3709999999996, -3713.3779999999997, -3756.235, -3798.9390000000003, -3841.487, -3883.8790000000004, -3926.111, -3968.1809999999996, -4010.087, -4051.828, -4093.4, -4134.8009999999995, -4176.03, -4217.083, -4257.958, -4298.654, -4339.167, -4379.495, -4419.6359999999995, -4459.587, -4499.347, -4538.911, -4578.279, -4617.446, -4656.412, -4695.1720000000005, -4733.725, -4772.068, -4810.198, -4848.112, -4885.808, -4923.282, -4960.532999999999, -4997.556, -5034.35, -5070.911, -5107.236, -5143.322, -5179.167, -5214.767, -5250.12, -5285.221, -5320.066999999999, -5354.656, -5388.984, -5423.048000000001, -5456.844, -5490.369000000001, -5523.62, -5556.593000000001, -5589.284000000001, -5621.69, -5653.807, -5685.630999999999, -5717.159000000001, -5748.3859999999995, -5779.31, -5809.924, -5840.227, -5870.213000000001, -5899.879, -5929.22, -5958.232, -5986.91, -6015.251, -6043.249, -6070.9, -6098.1990000000005, -6125.142, -6151.724, -6177.939, -6203.783, -6229.25, -6254.335999999999, -6279.036, -6303.343000000001, -6327.2519999999995, -6350.758000000001, -6373.854, -6396.536999999999, -6418.798000000001, -6440.633000000001, -6462.034000000001, -6482.996, -6503.512, -6523.576, -6543.182, -6562.321999999999, -6580.9890000000005, -6599.177, -6616.878000000001, -6634.084, -6650.7880000000005, -6666.983, -6682.661, -6697.813, -6712.432, -6726.508000000001, -6740.033, -6752.999, -6765.396, -6777.215999999999, -6788.448, -6799.0830000000005, -6809.111999999999, -6818.523, -6827.307, -6835.453, -6842.951, -6849.7880000000005, -6855.954000000001, -6861.437, -6866.224, -6870.303000000001, -6873.661, -6876.286999999999, -6878.166, -6879.284000000001, -6879.6269999999995, -6879.18, -6877.93, -6875.86, -6872.955, -6869.198, -6864.573, -6859.062, -6852.648, -6845.313, -6837.0380000000005, -6827.802, -6817.5869999999995, -6806.371999999999, -6794.1359999999995, -6780.856, -6766.51, -6751.075, -6734.526999999999, -6716.84, -6697.9890000000005, -6677.948, -6656.688, -6634.183000000001, -6610.401, -6585.312, -6558.885, -6531.089, -6501.887, -6471.245, -6439.128000000001, -6405.496999999999, -6370.314, -6333.536999999999, -6295.124, -6255.031999999999, -6213.215999999999, -6169.6269999999995, -6124.219, -6076.937, -6027.731, -5976.545999999999, -5923.323, -5868.003000000001, -5810.525, -5750.821999999999, -5688.83, -5624.478, -5557.694, -5488.4, -5416.521, -5341.973000000001, -5264.673000000001, -5184.531, -5101.459, -5015.359, -4926.135, -4833.687, -4737.907999999999, -4638.693, -4535.93, -4429.5070000000005, -4319.309, -4205.22, -4087.12, -3964.8920000000003, -3838.4190000000003, -3707.5840000000003, -3572.276, -3432.389, -3287.823, -3138.49, -2984.3140000000003, -2825.238, -2661.223, -2492.26, -2318.369, -2139.605, -1956.0710000000001, -1767.914, -1575.339, -1378.61, -1178.058, -974.081, -767.145, -557.789, -346.61300000000006, -134.274, 78.527, 291.05400000000003, 502.55400000000003, 712.2769999999999, 919.492, 1123.503, 1323.6629999999998, 1519.389, 1710.171, 1895.576, 2075.251, 2248.9210000000003, 2416.386, 2577.514, 2732.24, 2880.548, 3022.473, 3158.0890000000004, 3287.502, 3410.843, 3528.263, 3639.93, 3746.0190000000002, 3846.7140000000004, 3942.2009999999996, 4032.67, 4118.305, 4199.293, 4275.814, 4348.045, 4416.156, 4480.313, 4540.6759999999995, 4597.397, 4650.625, 4700.498, 4747.152, 4790.715999999999, 4831.313, 4869.06, 4904.069, 4936.445, 4966.291, 4993.7029999999995, 5018.774, 5041.592000000001, 5062.2390000000005, 5080.795999999999, 5097.339, 5111.942, 5124.670999999999, 5135.596, 5144.777, 5152.276, 5158.15, 5162.4529999999995, 5165.2390000000005, 5166.559, 5166.459, 5164.987, 5162.185, 5158.098, 5152.765, 5146.225, 5138.516, 5129.6720000000005, 5119.729, 5108.72, 5096.677, 5083.629, 5069.607, 5054.639, 5038.751, 5021.97, 5004.322, 4985.831, 4966.519, 4946.411, 4925.526, 4903.888, 4881.516, 4858.43, 4834.648, 4810.19, 4785.072, 4759.313, 4732.928, 4705.934, 4678.347, 4650.182, 4621.4529999999995, 4592.175, 4562.36, 4532.023, 4501.177, 4469.835, 4438.008, 4405.709, 4372.948, 4339.737, 4306.087, 4272.009, 4237.513, 4202.609, 4167.306, 4131.615, 4095.545, 4059.103, 4022.3, 3985.1440000000002, 3947.6440000000002, 3909.8059999999996, 3871.64, 3833.153, 3794.3520000000003, 3755.245, 3715.8390000000004, 3676.1420000000003, 3636.159, 3595.8979999999997, 3555.366, 3514.5679999999998, 3473.511, 3432.202, 3390.645, 3348.847, 3306.8140000000003, 3264.551, 3222.0640000000003, 3179.3579999999997, 3136.4390000000003, 3093.3109999999997, 3049.9790000000003, 3006.449, 2962.7259999999997, 2918.8140000000003, 2874.718, 2830.442, 2785.992, 2741.3709999999996, 2696.583, 2651.634, 2606.526, 2561.265, 2515.855, 2470.298, 2424.6, 2378.763, 2332.792, 2286.6910000000003, 2240.4629999999997, 2194.111, 2147.639, 2101.051, 2054.351, 2007.54, 1960.6229999999998, 1913.6029999999998, 1866.484, 1819.267, 1771.957, 1724.557, 1677.069, 1629.496, 1581.842, 1534.109, 1486.3010000000002, 1438.4189999999999, 1390.467, 1342.4479999999999, 1294.365, 1246.219, 1198.014, 1149.752, 1101.4360000000001, 1053.068, 1004.6510000000001, 956.188, 907.681, 859.132, 810.543, 761.918, 713.2589999999999, 664.567, 615.846, 567.097, 518.323, 469.526, 420.708, 371.87199999999996, 323.019, 274.153, 225.274, 176.386, 127.49, 78.58800000000001, 29.683000000000003, -19.223, -68.128, -117.031, -165.929, -214.821, -263.703, -312.575, -361.434, -410.278, -459.105, -507.914, -556.702, -605.467, -654.2080000000001, -702.923, -751.6089999999999, -800.265, -848.8889999999999, -897.4789999999999, -946.0319999999999, -994.549, -1043.025, -1091.46, -1139.8519999999999, -1188.1989999999998, -1236.498, -1284.749, -1332.9489999999998, -1381.096, -1429.19, -1477.226, -1525.205, -1573.124, -1620.9820000000002, -1668.775, -1716.504, -1764.165, -1811.7579999999998, -1859.279, -1906.7279999999998, -1954.1029999999998, -2001.402, -2048.6220000000003, -2095.763, -2142.822, -2189.797, -2236.687, -2283.49, -2330.2039999999997, -2376.827, -2423.357, -2469.7929999999997, -2516.132, -2562.373, -2608.514, -2654.553, -2700.488, -2746.317, -2792.039, -2837.651, -2883.151, -2928.539, -2973.8109999999997, -3018.966, -3064.0009999999997, -3108.9159999999997, -3153.7070000000003, -3198.3740000000003, -3242.913, -3287.323, -3331.603, -3375.7490000000003, -3419.76, -3463.635, -3507.37, -3550.9629999999997, -3594.414, -3637.719, -3680.877, -3723.885, -3766.741, -3809.4440000000004, -3851.99, -3894.3790000000004, -3936.6059999999998, -3978.671, -4020.572, -4062.305, -4103.8679999999995, -4145.26, -4186.478, -4227.52, -4268.3820000000005, -4309.063, -4349.561, -4389.873, -4429.996, -4469.929, -4509.667, -4549.21, -4588.555, -4627.698, -4666.638, -4705.371, -4743.895, -4782.207, -4820.305, -4858.186, -4895.847, -4933.285, -4970.497, -5007.481, -5044.233, -5080.75, -5117.03, -5153.07, -5188.866, -5224.415, -5259.714, -5294.76, -5329.55, -5364.08, -5398.347, -5432.347, -5466.078, -5499.535, -5532.715999999999, -5565.616, -5598.232, -5630.561, -5662.598000000001, -5694.34, -5725.783, -5756.923000000001, -5787.755999999999, -5818.276999999999, -5848.484, -5878.371, -5907.934, -5937.17, -5966.0740000000005, -5994.641, -6022.866999999999, -6050.746999999999, -6078.276999999999, -6105.451, -6132.265, -6158.714, -6184.794, -6210.4980000000005, -6235.821999999999, -6260.76, -6285.308000000001, -6309.459, -6333.2080000000005, -6356.549, -6379.476, -6401.985, -6424.068, -6445.719, -6466.932, -6487.7, -6508.018, -6527.879, -6547.275, -6566.2, -6584.647, -6602.608, -6620.076, -6637.044, -6653.503000000001, -6669.446999999999, -6684.866, -6699.754, -6714.1, -6727.897, -6741.1359999999995, -6753.807, -6765.903, -6777.411999999999, -6788.326999999999, -6798.635, -6808.328, -6817.396, -6825.826999999999, -6833.611, -6840.736, -6847.191, -6852.964, -6858.044, -6862.4169999999995, -6866.071, -6868.994000000001, -6871.170999999999, -6872.59, -6873.235, -6873.092, -6872.147, -6870.384, -6867.786999999999, -6864.34, -6860.026999999999, -6854.83, -6848.732, -6841.714, -6833.757, -6824.843000000001, -6814.95, -6804.06, -6792.149, -6779.196999999999, -6765.181, -6750.079000000001, -6733.8640000000005, -6716.512, -6698.0, -6678.298000000001, -6657.38, -6635.218000000001, -6611.781999999999, -6587.0419999999995, -6560.965, -6533.52, -6504.672, -6474.387, -6442.629, -6409.359, -6374.5380000000005, -6338.1269999999995, -6300.081999999999, -6260.36, -6218.9169999999995, -6175.703, -6130.672, -6083.77, -6034.946999999999, -5984.146, -5931.311, -5876.382, -5819.295999999999, -5759.99, -5698.396, -5634.444, -5568.063, -5499.177, -5427.706999999999, -5353.571, -5276.685, -5196.960999999999, -5114.31, -5028.6320000000005, -4939.834, -4847.813, -4752.464, -4653.68, -4551.351, -4445.363, -4335.601, -4221.9490000000005, -4104.287, -3982.4970000000003, -3856.46, -3726.06, -3591.185, -3451.7259999999997, -3307.583, -3158.6659999999997, -3004.897, -2846.217, -2682.586, -2513.989, -2340.444, -2162.0029999999997, -1978.763, -1790.8670000000002, -1598.516, -1401.967, -1201.546, -997.6439999999999, -790.725, -581.318, -370.02, -157.484, 55.591, 268.472, 480.407, 690.6439999999999, 898.449, 1103.121, 1304.008, 1500.523, 1692.1470000000002, 1878.441, 2059.042, 2233.669, 2402.114, 2564.241, 2719.975, 2869.298, 3012.238, 3148.867, 3279.285, 3403.623, 3522.028, 3634.665, 3741.71, 3843.344, 3939.7529999999997, 4031.127, 4117.648, 4199.505, 4276.875, 4349.938, 4418.863, 4483.816, 4544.956, 4602.439, 4656.359, 4707.01, 4754.377, 4798.637, 4839.914000000001, 4878.326, 4913.985, 4946.999, 4977.468, 5005.49, 5031.157999999999, 5054.56, 5075.78, 5094.897, 5111.99, 5127.129, 5140.387, 5151.8279999999995, 5161.514, 5169.51, 5175.869000000001, 5180.65, 5183.904, 5185.683, 5186.032999999999, 5185.002, 5182.634, 5178.972, 5174.057, 5167.9259999999995, 5160.6179999999995, 5152.17, 5142.615, 5131.986, 5120.317, 5107.6359999999995, 5093.975, 5079.361, 5063.821, 5047.3820000000005, 5030.07, 5011.909000000001, 4992.9220000000005, 4973.130999999999, 4952.561, 4931.23, 4909.16, 4886.371, 4862.8820000000005, 4838.71, 4813.875, 4788.393, 4762.28, 4735.555, 4708.232, 4680.325, 4651.85, 4622.822, 4593.253, 4563.159000000001, 4532.55, 4501.441, 4469.843, 4437.768, 4405.229, 4372.236, 4338.8009999999995, 4304.933, 4270.643, 4235.942, 4200.838, 4165.343, 4129.465, 4093.212, 4056.595, 4019.6220000000003, 3982.3, 3944.638, 3906.6440000000002, 3868.3259999999996, 3829.692, 3790.748, 3751.5029999999997, 3711.9629999999997, 3672.134, 3632.025, 3591.6409999999996, 3550.988, 3510.074, 3468.9040000000005, 3427.4840000000004, 3385.821, 3343.9190000000003, 3301.7859999999996, 3259.425, 3216.843, 3174.045, 3131.035, 3087.82, 3044.4040000000005, 3000.792, 2956.988, 2912.998, 2868.8259999999996, 2824.4770000000003, 2779.954, 2735.264, 2690.408, 2645.393, 2600.221, 2554.8979999999997, 2509.426, 2463.811, 2418.055, 2372.163, 2326.138, 2279.984, 2233.705, 2187.303, 2140.783, 2094.1479999999997, 2047.402, 2000.547, 1953.586, 1906.524, 1859.3629999999998, 1812.1070000000002, 1764.7579999999998, 1717.32, 1669.795, 1622.1870000000001, 1574.4979999999998, 1526.731, 1478.89, 1430.977, 1382.994, 1334.945, 1286.8319999999999, 1238.657, 1190.424, 1142.136, 1093.7930000000001, 1045.4, 996.959, 948.472, 899.941, 851.3689999999999, 802.7589999999999, 754.113, 705.433, 656.721, 607.98, 559.212, 510.42, 461.605, 412.77099999999996, 363.918, 315.04900000000004, 266.16700000000003, 217.274, 168.37099999999998, 119.461, 70.546, 21.628, -27.291, -76.208, -125.12299999999999, -174.032, -222.93400000000003, -271.82599999999996, -320.70799999999997, -369.57599999999996, -418.42900000000003, -467.265, -516.081, -564.877, -613.65, -662.3969999999999, -711.118, -759.81, -808.472, -857.1010000000001, -905.695, -954.2539999999999, -1002.7739999999999, -1051.254, -1099.692, -1148.087, -1196.435, -1244.737, -1292.989, -1341.19, -1389.338, -1437.432, -1485.469, -1533.4470000000001, -1581.365, -1629.221, -1677.013, -1724.74, -1772.398, -1819.9879999999998, -1867.506, -1914.9520000000002, -1962.3220000000001, -2009.616, -2056.831, -2103.966, -2151.019, -2197.988, -2244.871, -2291.666, -2338.3720000000003, -2384.987, -2431.508, -2477.935, -2524.264, -2570.495, -2616.625, -2662.653, -2708.5759999999996, -2754.393, -2800.1009999999997, -2845.7, -2891.1859999999997, -2936.559, -2981.815, -3026.954, -3071.973, -3116.87, -3161.6440000000002, -3206.2909999999997, -3250.812, -3295.202, -3339.461, -3383.586, -3427.575, -3471.427, -3515.139, -3558.7090000000003, -3602.134, -3645.414, -3688.545, -3731.526, -3774.355, -3817.0290000000005, -3859.545, -3901.903, -3944.099, -3986.132, -4027.9990000000003, -4069.698, -4111.226, -4152.581, -4193.762, -4234.765, -4275.588, -4316.229, -4356.685, -4396.954000000001, -4437.034000000001, -4476.920999999999, -4516.6140000000005, -4556.11, -4595.406, -4634.5, -4673.388, -4712.069, -4750.54, -4788.7970000000005, -4826.839, -4864.661, -4902.263, -4939.64, -4976.789000000001, -5013.709, -5050.396, -5086.846, -5123.057, -5159.026, -5194.75, -5230.225, -5265.448, -5300.416, -5335.126, -5369.575, -5403.758000000001, -5437.673000000001, -5471.316999999999, -5504.685, -5537.774, -5570.58, -5603.1, -5635.33, -5667.266, -5698.905, -5730.241999999999, -5761.273, -5791.995, -5822.403, -5852.493, -5882.262, -5911.704000000001, -5940.815, -5969.592, -5998.028, -6026.12, -6053.863, -6081.253000000001, -6108.284000000001, -6134.951999999999, -6161.251, -6187.1759999999995, -6212.723000000001, -6237.8859999999995, -6262.659000000001, -6287.0380000000005, -6311.016, -6334.588000000001, -6357.749, -6380.491, -6402.809, -6424.696999999999, -6446.15, -6467.16, -6487.72, -6507.8240000000005, -6527.465999999999, -6546.639, -6565.334, -6583.545999999999, -6601.267, -6618.49, -6635.205, -6651.406999999999, -6667.085999999999, -6682.234, -6696.844, -6710.906, -6724.411999999999, -6737.353, -6749.718000000001, -6761.501, -6772.69, -6783.275, -6793.246, -6802.594, -6811.307, -6819.375, -6826.786, -6833.529, -6839.593000000001, -6844.964, -6849.632, -6853.5830000000005, -6856.804, -6859.281999999999, -6861.004, -6861.954000000001, -6862.119000000001, -6861.483, -6860.031999999999, -6857.75, -6854.619000000001, -6850.625, -6845.749, -6839.974, -6833.281999999999, -6825.654, -6817.07, -6807.5109999999995, -6796.956, -6785.385, -6772.774, -6759.102, -6744.345, -6728.48, -6711.481, -6693.323, -6673.978, -6653.422, -6631.6230000000005, -6608.553000000001, -6584.182, -6558.478, -6531.409000000001, -6502.94, -6473.0380000000005, -6441.664000000001, -6408.784000000001, -6374.355, -6338.34, -6300.694, -6261.376, -6220.338000000001, -6177.535, -6132.9169999999995, -6086.434, -6038.033, -5987.658, -5935.253000000001, -5880.757, -5824.109, -5765.246, -5704.099, -5640.6, -5574.674, -5506.2480000000005, -5435.243, -5361.576999999999, -5285.165, -5205.92, -5123.752, -5038.563, -4950.258, -4858.735, -4763.889, -4665.613, -4563.795999999999, -4458.325, -4349.084, -4235.955, -4118.821, -3997.5609999999997, -3872.0559999999996, -3742.191, -3607.85, -3468.925, -3325.3140000000003, -3176.926, -3023.6809999999996, -2865.5170000000003, -2702.39, -2534.2870000000003, -2361.217, -2183.2329999999997, -2000.425, -1812.93, -1620.9460000000001, -1424.723, -1224.5810000000001, -1020.905, -814.154, -604.85, -393.583, -181.00400000000002, 32.193000000000005, 245.27700000000002, 457.49699999999996, 668.1010000000001, 876.352, 1081.545, 1283.025, 1480.1970000000001, 1672.537, 1859.5970000000002, 2041.0079999999998, 2216.481, 2385.802, 2548.825, 2705.473, 2855.72, 2999.591, 3137.15, 3268.498, 3393.76, 3513.0820000000003, 3626.627, 3734.567, 3837.0840000000003, 3934.363, 4026.591, 4113.9529999999995, 4196.634, 4274.814, 4348.67, 4418.373, 4484.088, 4545.977, 4604.191, 4658.88, 4710.184, 4758.24, 4803.175, 4845.1140000000005, 4884.1759999999995, 4920.471, 4954.108, 4985.189, 5013.81, 5040.066, 5064.045, 5085.831, 5105.504, 5123.142, 5138.817, 5152.6, 5164.557, 5174.751, 5183.2429999999995, 5190.093, 5195.354, 5199.081, 5201.323, 5202.13, 5201.548, 5199.622, 5196.393, 5191.905, 5186.194, 5179.299, 5171.258, 5162.102, 5151.867, 5140.585999999999, 5128.286, 5115.001, 5100.755999999999, 5085.58, 5069.499, 5052.54, 5034.726, 5016.081, 4996.628, 4976.389, 4955.3859999999995, 4933.638, 4911.166, 4887.99, 4864.127, 4839.595, 4814.411, 4788.594, 4762.159000000001, 4735.122, 4707.497, 4679.3, 4650.545999999999, 4621.248, 4591.418, 4561.073, 4530.222, 4498.879, 4467.055, 4434.763, 4402.014, 4368.819, 4335.188, 4301.1320000000005, 4266.661, 4231.784000000001, 4196.512, 4160.854, 4124.819, 4088.4159999999997, 4051.653, 4014.539, 3977.0820000000003, 3939.289, 3901.17, 3862.732, 3823.9809999999998, 3784.926, 3745.573, 3705.929, 3666.0009999999997, 3625.795, 3585.3190000000004, 3544.578, 3503.579, 3462.328, 3420.83, 3379.091, 3337.118, 3294.915, 3252.489, 3209.843, 3166.985, 3123.9179999999997, 3080.647, 3037.178, 2993.5159999999996, 2949.664, 2905.6290000000004, 2861.413, 2817.0229999999997, 2772.461, 2727.7329999999997, 2682.842, 2637.7940000000003, 2592.591, 2547.238, 2501.739, 2456.097, 2410.317, 2364.402, 2318.356, 2272.1820000000002, 2225.885, 2179.466, 2132.931, 2086.282, 2039.523, 1992.656, 1945.6860000000001, 1898.614, 1851.4460000000001, 1804.183, 1756.829, 1709.386, 1661.858, 1614.247, 1566.557, 1518.79, 1470.9489999999998, 1423.0379999999998, 1375.057, 1327.011, 1278.902, 1230.733, 1182.506, 1134.224, 1085.889, 1037.504, 989.072, 940.5939999999999, 892.074, 843.513, 794.914, 746.28, 697.613, 648.915, 600.188, 551.436, 502.659, 453.86, 405.041, 356.20599999999996, 307.355, 258.491, 209.61599999999999, 160.732, 111.84200000000001, 62.946999999999996, 14.049000000000001, -34.848, -83.745, -132.637, -181.524, -230.403, -279.27299999999997, -328.131, -376.975, -425.80300000000005, -474.61400000000003, -523.406, -572.1759999999999, -620.922, -669.6439999999999, -718.3380000000001, -767.003, -815.637, -864.238, -912.804, -961.334, -1009.825, -1058.276, -1106.685, -1155.049, -1203.368, -1251.638, -1299.86, -1348.029, -1396.146, -1444.207, -1492.211, -1540.1570000000002, -1588.0420000000001, -1635.864, -1683.622, -1731.315, -1778.9389999999999, -1826.493, -1873.976, -1921.386, -1968.72, -2015.977, -2063.156, -2110.254, -2157.269, -2204.2, -2251.044, -2297.801, -2344.468, -2391.0429999999997, -2437.524, -2483.91, -2530.199, -2576.388, -2622.4759999999997, -2668.462, -2714.342, -2760.116, -2805.781, -2851.335, -2896.777, -2942.1040000000003, -2987.315, -3032.408, -3077.38, -3122.23, -3166.9559999999997, -3211.5559999999996, -3256.027, -3300.368, -3344.577, -3388.652, -3432.59, -3476.39, -3520.0490000000004, -3563.566, -3606.938, -3650.163, -3693.239, -3736.165, -3778.937, -3821.553, -3864.012, -3906.3109999999997, -3948.448, -3990.42, -4032.2259999999997, -4073.863, -4115.3279999999995, -4156.62, -4197.736, -4238.673, -4279.43, -4320.004, -4360.392, -4400.592000000001, -4440.601, -4480.417, -4520.038, -4559.46, -4598.681, -4637.6990000000005, -4676.5109999999995, -4715.1140000000005, -4753.505999999999, -4791.682, -4829.642, -4867.3820000000005, -4904.899, -4942.19, -4979.253, -5016.084, -5052.681, -5089.04, -5125.157999999999, -5161.032, -5196.66, -5232.038, -5267.161999999999, -5302.03, -5336.637, -5370.981, -5405.058000000001, -5438.865, -5472.399, -5505.655, -5538.63, -5571.32, -5603.722, -5635.831999999999, -5667.647, -5699.161, -5730.371, -5761.274, -5791.8640000000005, -5822.138000000001, -5852.092, -5881.722, -5911.023, -5939.99, -5968.619000000001, -5996.905, -6024.845, -6052.432, -6079.6630000000005, -6106.531999999999, -6133.035, -6159.166, -6184.92, -6210.293000000001, -6235.276999999999, -6259.868, -6284.061, -6307.85, -6331.229, -6354.191999999999, -6376.733, -6398.845, -6420.524, -6441.762, -6462.552, -6482.89, -6502.766, -6522.175, -6541.11, -6559.562, -6577.526, -6594.994000000001, -6611.956999999999, -6628.406999999999, -6644.338000000001, -6659.74, -6674.605, -6688.925, -6702.691999999999, -6715.895, -6728.526, -6740.575, -6752.033, -6762.891, -6773.137, -6782.7609999999995, -6791.754, -6800.103, -6807.799, -6814.829000000001, -6821.182, -6826.845, -6831.807, -6836.056, -6839.576999999999, -6842.357, -6844.384, -6845.642, -6846.118, -6845.795999999999, -6844.661, -6842.698, -6839.89, -6836.221, -6831.674, -6826.23, -6819.8730000000005, -6812.581999999999, -6804.34, -6795.125, -6784.918000000001, -6773.696999999999, -6761.44, -6748.126, -6733.731, -6718.23, -6701.6, -6683.814, -6664.846, -6644.668000000001, -6623.253000000001, -6600.571, -6576.590999999999, -6551.283, -6524.6140000000005, -6496.549, -6467.055, -6436.095, -6403.630999999999, -6369.624, -6334.035, -6296.821, -6257.938, -6217.342, -6174.985, -6130.819, -6084.7919999999995, -6036.853, -5986.945, -5935.013000000001, -5880.996, -5824.834, -5766.460999999999, -5705.81, -5642.814, -5577.398, -5509.486999999999, -5439.005, -5365.866999999999, -5289.991, -5211.29, -5129.67, -5045.039000000001, -4957.298, -4866.346, -4772.0779999999995, -4674.388, -4573.163, -4468.292, -4359.657, -4247.142, -4130.627, -4009.992, -3885.119, -3755.889, -3622.188, -3483.906, -3340.9390000000003, -3193.195, -3040.594, -2883.0679999999998, -2720.575, -2553.094, -2380.635, -2203.245, -2021.0079999999998, -1834.06, -1642.59, -1446.844, -1247.134, -1043.84, -837.413, -628.369, -417.29400000000004, -204.83, 8.331, 221.46099999999998, 433.81199999999995, 644.629, 853.177, 1058.747, 1260.68, 1458.3729999999998, 1651.2979999999998, 1838.9979999999998, 2021.099, 2197.303, 2367.388, 2531.205, 2688.6679999999997, 2839.745, 2984.458, 3122.865, 3255.063, 3381.1740000000004, 3501.342, 3615.7270000000003, 3724.5, 3827.841, 3925.935, 4018.965, 4107.1179999999995, 4190.5779999999995, 4269.525, 4344.134, 4414.579000000001, 4481.022, 4543.626, 4602.544, 4657.923, 4709.906, 4758.626, 4804.215999999999, 4846.798, 4886.49, 4923.405, 4957.651, 4989.331, 5018.541, 5045.376, 5069.923, 5092.268, 5112.492, 5130.670999999999, 5146.878, 5161.185, 5173.656, 5184.358, 5193.35, 5200.691, 5206.436, 5210.64, 5213.352, 5214.622, 5214.495, 5213.018, 5210.233, 5206.18, 5200.9, 5194.429, 5186.806, 5178.063, 5168.235, 5157.354, 5145.45, 5132.554, 5118.695, 5103.899, 5088.193, 5071.604, 5054.155, 5035.871, 5016.773, 4996.8859999999995, 4976.229, 4954.8240000000005, 4932.689, 4909.846, 4886.313, 4862.106, 4837.245, 4811.745, 4785.624, 4758.895, 4731.576, 4703.682, 4675.225, 4646.222, 4616.684, 4586.626, 4556.059, 4524.997, 4493.451, 4461.433, 4428.955, 4396.027, 4362.66, 4328.865, 4294.652, 4260.03, 4225.01, 4189.601, 4153.812, 4117.652, 4081.1290000000004, 4044.252, 4007.0290000000005, 3969.468, 3931.578, 3893.366, 3854.8379999999997, 3816.0029999999997, 3776.868, 3737.4390000000003, 3697.724, 3657.7290000000003, 3617.46, 3576.9240000000004, 3536.1279999999997, 3495.077, 3453.777, 3412.2329999999997, 3370.453, 3328.441, 3286.202, 3243.742, 3201.066, 3158.18, 3115.0879999999997, 3071.796, 3028.308, 2984.6290000000004, 2940.763, 2896.715, 2852.49, 2808.092, 2763.525, 2718.7940000000003, 2673.902, 2628.8540000000003, 2583.653, 2538.305, 2492.812, 2447.178, 2401.407, 2355.5029999999997, 2309.47, 2263.311, 2217.029, 2170.6279999999997, 2124.111, 2077.482, 2030.744, 1983.901, 1936.955, 1889.9089999999999, 1842.767, 1795.5320000000002, 1748.207, 1700.7939999999999, 1653.297, 1605.719, 1558.0620000000001, 1510.33, 1462.524, 1414.649, 1366.705, 1318.6970000000001, 1270.627, 1222.498, 1174.3110000000001, 1126.07, 1077.777, 1029.435, 981.046, 932.613, 884.137, 835.622, 787.07, 738.4830000000001, 689.8639999999999, 641.214, 592.536, 543.832, 495.105, 446.35699999999997, 397.59, 348.806, 300.007, 251.195, 202.37400000000002, 153.54399999999998, 104.70700000000001, 55.867, 7.025, -41.818000000000005, -90.65799999999999, -139.494, -188.325, -237.14700000000002, -285.959, -334.759, -383.54400000000004, -432.314, -481.066, -529.798, -578.509, -627.195, -675.8560000000001, -724.4889999999999, -773.0930000000001, -821.666, -870.205, -918.709, -967.176, -1015.605, -1063.992, -1112.337, -1160.638, -1208.893, -1257.099, -1305.256, -1353.36, -1401.412, -1449.4070000000002, -1497.346, -1545.225, -1593.0439999999999, -1640.8, -1688.491, -1736.116, -1783.672, -1831.1589999999999, -1878.5739999999998, -1925.915, -1973.18, -2020.369, -2067.478, -2114.506, -2161.451, -2208.312, -2255.0860000000002, -2301.771, -2348.366, -2394.87, -2441.279, -2487.592, -2533.808, -2579.924, -2625.9390000000003, -2671.8509999999997, -2717.657, -2763.3559999999998, -2808.946, -2854.425, -2899.7909999999997, -2945.042, -2990.176, -3035.192, -3080.087, -3124.8590000000004, -3169.507, -3214.028, -3258.42, -3302.6820000000002, -3346.81, -3390.804, -3434.6620000000003, -3478.38, -3521.9570000000003, -3565.3909999999996, -3608.68, -3651.821, -3694.813, -3737.653, -3780.3390000000004, -3822.869, -3865.241, -3907.453, -3949.5009999999997, -3991.385, -4033.1009999999997, -4074.6479999999997, -4116.022, -4157.223, -4198.246, -4239.090999999999, -4279.753, -4320.232, -4360.524, -4400.628, -4440.54, -4480.258, -4519.779, -4559.101, -4598.221, -4637.137, -4675.845, -4714.344, -4752.63, -4790.701, -4828.554, -4866.185, -4903.593, -4940.773, -4977.724, -5014.442, -5050.924, -5087.167, -5123.168, -5158.924, -5194.432, -5229.688, -5264.689, -5299.432, -5333.914000000001, -5368.13, -5402.079000000001, -5435.755, -5469.155, -5502.276999999999, -5535.116, -5567.668000000001, -5599.931, -5631.899, -5663.57, -5694.938, -5726.001, -5756.753000000001, -5787.191, -5817.311, -5847.109, -5876.579000000001, -5905.719, -5934.522, -5962.984, -5991.102, -6018.87, -6046.283, -6073.335999999999, -6100.025, -6126.345, -6152.29, -6177.855, -6203.035, -6227.823, -6252.215999999999, -6276.206, -6299.789000000001, -6322.9580000000005, -6345.7080000000005, -6368.031, -6389.923000000001, -6411.376, -6432.385, -6452.941999999999, -6473.041, -6492.6759999999995, -6511.838000000001, -6530.52, -6548.715999999999, -6566.419, -6583.619000000001, -6600.31, -6616.483, -6632.130999999999, -6647.244000000001, -6661.815, -6675.834, -6689.294, -6702.183000000001, -6714.494000000001, -6726.217, -6737.340999999999, -6747.857, -6757.755, -6767.023, -6775.651, -6783.629, -6790.944, -6797.584, -6803.539000000001, -6808.795, -6813.340999999999, -6817.1630000000005, -6820.246999999999, -6822.581, -6824.15, -6824.94, -6824.935, -6824.121, -6822.483, -6820.003000000001, -6816.666, -6812.454000000001, -6807.35, -6801.335, -6794.391, -6786.5, -6777.64, -6767.7919999999995, -6756.935, -6745.045, -6732.103, -6718.0830000000005, -6702.963000000001, -6686.717, -6669.321, -6650.746999999999, -6630.969, -6609.956999999999, -6587.683000000001, -6564.116999999999, -6539.228, -6512.983, -6485.347, -6456.2880000000005, -6425.768, -6393.75, -6360.195, -6325.064, -6288.313, -6249.901, -6209.78, -6167.906, -6124.229, -6078.698, -6031.2609999999995, -5981.863, -5930.448, -5876.956, -5821.3240000000005, -5763.491, -5703.388000000001, -5640.946, -5576.094, -5508.755, -5438.853, -5366.305, -5291.026999999999, -5212.933, -5131.93, -5047.924, -4960.819, -4870.512, -4776.899, -4679.873, -4579.323, -4475.137, -4367.196, -4255.385, -4139.583, -4019.672, -3895.5290000000005, -3767.039, -3634.085, -3496.5559999999996, -3354.348, -3207.367, -3055.5290000000005, -2898.768, -2737.0370000000003, -2570.312, -2398.601, -2221.944, -2040.425, -1854.171, -1663.365, -1468.25, -1269.129, -1066.377, -860.435, -651.814, -441.093, -228.908, -15.946, 197.06799999999998, 409.389, 620.263, 828.954, 1034.749, 1236.987, 1435.06, 1628.432, 1816.642, 1999.306, 2176.12, 2346.856, 2511.357, 2669.5290000000005, 2821.3379999999997, 2966.798, 3105.9640000000004, 3238.928, 3365.81, 3486.7490000000003, 3601.903, 3711.4429999999998, 3815.546, 3914.3940000000002, 4008.171, 4097.064, 4181.254, 4260.9220000000005, 4336.2429999999995, 4407.388, 4474.523, 4537.807, 4597.395, 4653.441, 4706.068, 4755.43, 4801.65, 4844.853, 4885.157, 4922.675, 4957.515, 4989.779, 5019.565, 5046.967000000001, 5072.0740000000005, 5094.97, 5115.737, 5134.451, 5151.187, 5166.014, 5179.0, 5190.208, 5199.7, 5207.535, 5213.767, 5218.451, 5221.637, 5223.376, 5223.710999999999, 5222.691, 5220.356, 5216.749, 5211.909000000001, 5205.873, 5198.679, 5190.36, 5180.952, 5170.486, 5158.992, 5146.501, 5133.042, 5118.642, 5103.3279999999995, 5087.125, 5070.06, 5052.154, 5033.431, 5013.914000000001, 4993.624, 4972.581, 4950.805, 4928.317, 4905.135, 4881.276, 4856.758, 4831.598, 4805.814, 4779.419, 4752.43, 4724.862, 4696.728, 4668.045, 4638.8240000000005, 4609.079000000001, 4578.822, 4548.067, 4516.825, 4485.109, 4452.929, 4420.295999999999, 4387.221, 4353.715, 4319.788, 4285.45, 4250.710999999999, 4215.58, 4180.066, 4144.179, 4107.9259999999995, 4071.316, 4034.3579999999997, 3997.059, 3959.428, 3921.473, 3883.2, 3844.617, 3805.7309999999998, 3766.5490000000004, 3727.079, 3687.3259999999996, 3647.297, 3606.9990000000003, 3566.437, 3525.619, 3484.5490000000004, 3443.2340000000004, 3401.68, 3359.8909999999996, 3317.8740000000003, 3275.633, 3233.175, 3190.5029999999997, 3147.6240000000003, 3104.542, 3061.262, 3017.789, 2974.1279999999997, 2930.282, 2886.257, 2842.0570000000002, 2797.6859999999997, 2753.1479999999997, 2708.448, 2663.59, 2618.577, 2573.415, 2528.105, 2482.654, 2437.063, 2391.337, 2345.481, 2299.496, 2253.386, 2207.155, 2160.8070000000002, 2114.345, 2067.772, 2021.0910000000001, 1974.305, 1927.4189999999999, 1880.434, 1833.355, 1786.183, 1738.922, 1691.575, 1644.145, 1596.635, 1549.047, 1501.384, 1453.649, 1405.845, 1357.975, 1310.0410000000002, 1262.045, 1213.991, 1165.881, 1117.7169999999999, 1069.502, 1021.2389999999999, 972.929, 924.576, 876.181, 827.748, 779.278, 730.773, 682.237, 633.6709999999999, 585.078, 536.46, 487.81800000000004, 439.157, 390.476, 341.779, 293.068, 244.345, 195.612, 146.872, 98.125, 49.375, 0.623, -48.128, -96.87700000000001, -145.622, -194.36, -243.08900000000003, -291.808, -340.515, -389.207, -437.88300000000004, -486.541, -535.178, -583.793, -632.385, -680.95, -729.487, -777.995, -826.471, -874.913, -923.321, -971.691, -1020.0210000000001, -1068.3110000000001, -1116.558, -1164.761, -1212.917, -1261.024, -1309.0819999999999, -1357.0870000000002, -1405.0379999999998, -1452.934, -1500.773, -1548.5520000000001, -1596.269, -1643.924, -1691.514, -1739.0379999999998, -1786.493, -1833.878, -1881.19, -1928.4289999999999, -1975.592, -2022.6779999999999, -2069.6839999999997, -2116.609, -2163.45, -2210.2070000000003, -2256.877, -2303.458, -2349.949, -2396.348, -2442.652, -2488.86, -2534.971, -2580.981, -2626.89, -2672.695, -2718.3940000000002, -2763.987, -2809.47, -2854.841, -2900.1, -2945.243, -2990.2690000000002, -3035.176, -3079.962, -3124.625, -3169.163, -3213.574, -3257.8559999999998, -3302.006, -3346.0240000000003, -3389.906, -3433.651, -3477.257, -3520.7209999999995, -3564.042, -3607.217, -3650.245, -3693.1220000000003, -3735.847, -3778.4179999999997, -3820.8320000000003, -3863.0879999999997, -3905.1820000000002, -3947.113, -3988.8790000000004, -4030.4759999999997, -4071.9040000000005, -4113.157999999999, -4154.238, -4195.141, -4235.863, -4276.404, -4316.759, -4356.928, -4396.907, -4436.694, -4476.286, -4515.681, -4554.876, -4593.8679999999995, -4632.655, -4671.233, -4709.601, -4747.755999999999, -4785.694, -4823.413, -4860.91, -4898.182, -4935.226, -4972.039000000001, -5008.6179999999995, -5044.960999999999, -5081.063, -5116.9220000000005, -5152.535, -5187.898, -5223.008, -5257.861999999999, -5292.456999999999, -5326.789000000001, -5360.854, -5394.65, -5428.172, -5461.418000000001, -5494.383000000001, -5527.063, -5559.455, -5591.556, -5623.36, -5654.865, -5686.066, -5716.959, -5747.541, -5777.806, -5807.751, -5837.371999999999, -5866.6630000000005, -5895.62, -5924.24, -5952.517, -5980.446, -6008.023, -6035.243, -6062.1, -6088.590999999999, -6114.709, -6140.45, -6165.808000000001, -6190.778, -6215.354, -6239.531, -6263.302, -6286.661999999999, -6309.605, -6332.126, -6354.217, -6375.871999999999, -6397.085, -6417.849, -6438.159000000001, -6458.005, -6477.383000000001, -6496.284000000001, -6514.701999999999, -6532.629, -6550.056, -6566.977, -6583.384, -6599.268, -6614.62, -6629.433000000001, -6643.698, -6657.406, -6670.548000000001, -6683.1140000000005, -6695.095, -6706.481, -6717.262, -6727.429, -6736.969, -6745.8730000000005, -6754.129, -6761.727, -6768.654, -6774.898, -6780.448, -6785.29, -6789.4130000000005, -6792.803000000001, -6795.445, -6797.326999999999, -6798.434, -6798.75, -6798.2609999999995, -6796.951999999999, -6794.806, -6791.807, -6787.937, -6783.18, -6777.517, -6770.929, -6763.398, -6754.904, -6745.4259999999995, -6734.944, -6723.435, -6710.878000000001, -6697.249, -6682.524, -6666.68, -6649.69, -6631.529, -6612.168000000001, -6591.58, -6569.736999999999, -6546.607, -6522.16, -6496.361999999999, -6469.182, -6440.584, -6410.531999999999, -6378.9890000000005, -6345.9169999999995, -6311.274, -6275.02, -6237.111, -6197.5019999999995, -6156.147, -6112.996999999999, -6068.0019999999995, -6021.108, -5972.263000000001, -5921.409000000001, -5868.486999999999, -5813.435, -5756.191, -5696.686, -5634.853, -5570.619000000001, -5503.909000000001, -5434.646, -5362.749, -5288.133000000001, -5210.710999999999, -5130.392, -5047.083, -4960.685, -4871.098, -4778.219, -4681.938, -4582.146, -4478.73, -4371.573, -4260.558, -4145.565, -4026.475, -3903.1659999999997, -3775.52, -3643.422, -3506.76, -3365.426, -3219.328, -3068.3790000000004, -2912.51, -2751.673, -2585.841, -2415.016, -2239.237, -2058.5820000000003, -1873.172, -1683.1870000000001, -1488.86, -1290.489, -1088.44, -883.148, -675.118, -464.918, -253.18099999999998, -40.586999999999996, 172.145, 384.27, 595.039, 803.711, 1009.577, 1211.9669999999999, 1410.2720000000002, 1603.9489999999998, 1792.529, 1975.625, 2152.923, 2324.188, 2489.257, 2648.031, 2800.467, 2946.575, 3086.406, 3220.048, 3347.615, 3469.2459999999996, 3585.0959999999995, 3695.3309999999997, 3800.1290000000004, 3899.6690000000003, 3994.135, 4083.712, 4168.581, 4248.92, 4324.906, 4396.71, 4464.495, 4528.424, 4588.648, 4645.316, 4698.569, 4748.545, 4795.37, 4839.170999999999, 4880.065, 4918.167, 4953.582, 4986.415, 5016.763, 5044.721, 5070.376, 5093.814, 5115.116, 5134.36, 5151.6179999999995, 5166.962, 5180.459, 5192.173, 5202.165, 5210.494000000001, 5217.215, 5222.3820000000005, 5226.0470000000005, 5228.259, 5229.063, 5228.505, 5226.63, 5223.477, 5219.085999999999, 5213.495, 5206.741, 5198.86, 5189.883, 5179.845, 5168.775, 5156.704000000001, 5143.661, 5129.673, 5114.766, 5098.969, 5082.304, 5064.794, 5046.465999999999, 5027.338, 5007.434, 4986.774, 4965.378, 4943.267, 4920.457, 4896.968, 4872.817, 4848.021, 4822.596, 4796.559, 4769.924, 4742.707, 4714.9220000000005, 4686.584, 4657.706, 4628.3, 4598.38, 4567.96, 4537.049, 4505.661, 4473.807, 4441.497, 4408.7429999999995, 4375.556, 4341.945, 4307.92, 4273.491, 4238.667, 4203.458, 4167.873, 4131.920999999999, 4095.6090000000004, 4058.947, 4021.942, 3984.6020000000003, 3946.935, 3908.948, 3870.6490000000003, 3832.045, 3793.143, 3753.95, 3714.472, 3674.716, 3634.688, 3594.395, 3553.843, 3513.0370000000003, 3471.9840000000004, 3430.6890000000003, 3389.158, 3347.397, 3305.41, 3263.203, 3220.781, 3178.15, 3135.3140000000003, 3092.277, 3049.046, 3005.623, 2962.015, 2918.225, 2874.259, 2830.119, 2785.8109999999997, 2741.3390000000004, 2696.7070000000003, 2651.9179999999997, 2606.978, 2561.889, 2516.655, 2471.281, 2425.77, 2380.125, 2334.351, 2288.45, 2242.427, 2196.284, 2150.025, 2103.654, 2057.173, 2010.586, 1963.895, 1917.105, 1870.2179999999998, 1823.2379999999998, 1776.1660000000002, 1729.007, 1681.7620000000002, 1634.4360000000001, 1587.03, 1539.5479999999998, 1491.9920000000002, 1444.365, 1396.67, 1348.9089999999999, 1301.086, 1253.202, 1205.26, 1157.263, 1109.213, 1061.113, 1012.965, 964.7710000000001, 916.535, 868.258, 819.943, 771.592, 723.2080000000001, 674.7919999999999, 626.347, 577.875, 529.379, 480.86, 432.32099999999997, 383.764, 335.19199999999995, 286.605, 238.00799999999998, 189.4, 140.785, 92.165, 43.542, -5.083, -53.706, -102.32700000000001, -150.94299999999998, -199.553, -248.153, -296.743, -345.32, -393.88199999999995, -442.42699999999996, -490.954, -539.461, -587.945, -636.404, -684.8380000000001, -733.243, -781.618, -829.962, -878.2719999999999, -926.546, -974.783, -1022.98, -1071.136, -1119.249, -1167.318, -1215.339, -1263.312, -1311.235, -1359.105, -1406.922, -1454.682, -1502.385, -1550.029, -1597.611, -1645.13, -1692.5839999999998, -1739.971, -1787.29, -1834.5379999999998, -1881.714, -1928.815, -1975.8410000000001, -2022.79, -2069.658, -2116.445, -2163.149, -2209.768, -2256.3, -2302.743, -2349.096, -2395.356, -2441.521, -2487.591, -2533.562, -2579.433, -2625.202, -2670.868, -2716.428, -2761.88, -2807.223, -2852.454, -2897.572, -2942.574, -2987.4590000000003, -3032.225, -3076.87, -3121.3909999999996, -3165.7870000000003, -3210.0559999999996, -3254.195, -3298.203, -3342.078, -3385.817, -3429.4179999999997, -3472.88, -3516.2009999999996, -3559.377, -3602.408, -3645.29, -3688.022, -3730.6020000000003, -3773.027, -3815.2940000000003, -3857.403, -3899.35, -3941.134, -3982.7509999999997, -4024.2009999999996, -4065.4790000000003, -4106.585, -4147.515, -4188.267, -4228.839, -4269.228, -4309.432, -4349.4490000000005, -4389.275, -4428.907999999999, -4468.347, -4507.587, -4546.626, -4585.463, -4624.093, -4662.515, -4700.725, -4738.721, -4776.499, -4814.058, -4851.394, -4888.504, -4925.3859999999995, -4962.036, -4998.451, -5034.628, -5070.564, -5106.255999999999, -5141.7, -5176.894, -5211.834, -5246.517, -5280.939, -5315.097, -5348.988, -5382.607, -5415.951999999999, -5449.019, -5481.804, -5514.303000000001, -5546.512, -5578.428000000001, -5610.047, -5641.3640000000005, -5672.3769999999995, -5703.08, -5733.469, -5763.54, -5793.289000000001, -5822.7119999999995, -5851.803000000001, -5880.56, -5908.976, -5937.047, -5964.769, -5992.1359999999995, -6019.143, -6045.786999999999, -6072.06, -6097.959, -6123.478, -6148.611999999999, -6173.355, -6197.701, -6221.645, -6245.181, -6268.302, -6291.004, -6313.28, -6335.1230000000005, -6356.526, -6377.484, -6397.99, -6418.036999999999, -6437.618, -6456.726, -6475.353, -6493.493, -6511.137, -6528.278, -6544.908, -6561.018, -6576.601, -6591.648, -6606.15, -6620.099, -6633.485, -6646.3, -6658.533, -6670.175, -6681.215999999999, -6691.646, -6701.454000000001, -6710.629, -6719.161, -6727.039000000001, -6734.25, -6740.781999999999, -6746.625, -6751.764, -6756.188, -6759.884, -6762.835999999999, -6765.033, -6766.459, -6767.1, -6766.94, -6765.965, -6764.158, -6761.5019999999995, -6757.982, -6753.579000000001, -6748.275, -6742.052, -6734.892, -6726.774, -6717.677, -6707.5830000000005, -6696.467, -6684.309, -6671.085999999999, -6656.773, -6641.346, -6624.781, -6607.05, -6588.128000000001, -6567.984, -6546.592, -6523.92, -6499.939, -6474.615, -6447.915, -6419.806, -6390.25, -6359.210999999999, -6326.651999999999, -6292.53, -6256.805, -6219.435, -6180.374, -6139.575, -6096.991999999999, -6052.573, -6006.265, -5958.016, -5907.769, -5855.464, -5801.04, -5744.435, -5685.581999999999, -5624.411, -5560.852, -5494.83, -5426.267, -5355.081999999999, -5281.191999999999, -5204.51, -5124.946, -5042.404, -4956.79, -4868.0, -4775.933, -4680.48, -4581.532999999999, -4478.975, -4372.694, -4262.572, -4148.487, -4030.3190000000004, -3907.949, -3781.258, -3650.127, -3514.447, -3374.1079999999997, -3229.0159999999996, -3079.083, -2924.239, -2764.4309999999996, -2599.631, -2429.837, -2255.084, -2075.444, -1891.036, -1702.029, -1508.6529999999998, -1311.1970000000001, -1110.02, -905.55, -698.2819999999999, -488.777, -277.661, -65.608, 146.66899999999998, 358.42800000000005, 568.922, 777.4119999999999, 983.185, 1185.572, 1383.9560000000001, 1577.79, 1766.601, 1949.9920000000002, 2127.643, 2299.313, 2464.8320000000003, 2624.093, 2777.0490000000004, 2923.704, 3064.103, 3198.3309999999997, 3326.498, 3448.739, 3565.2070000000003, 3676.065, 3781.489, 3881.656, 3976.7509999999997, 4066.954, 4152.447, 4233.407999999999, 4310.013, 4382.43, 4450.826, 4515.359, 4576.183, 4633.447, 4687.29, 4737.849, 4785.254, 4829.629, 4871.090999999999, 4909.755999999999, 4945.729, 4979.1140000000005, 5010.01, 5038.509, 5064.701, 5088.6720000000005, 5110.501, 5130.266, 5148.043, 5163.9, 5177.905, 5190.122, 5200.613, 5209.437, 5216.649, 5222.302, 5226.45, 5229.139, 5230.418, 5230.331, 5228.9220000000005, 5226.232, 5222.3, 5217.165, 5210.863, 5203.429, 5194.898, 5185.3, 5174.668, 5163.031, 5150.42, 5136.86, 5122.379, 5107.003, 5090.755999999999, 5073.663, 5055.747, 5037.029, 5017.531, 4997.275, 4976.281, 4954.567, 4932.152, 4909.056, 4885.295, 4860.8859999999995, 4835.845, 4810.19, 4783.935, 4757.094, 4729.683, 4701.717000000001, 4673.207, 4644.168, 4614.613, 4584.553, 4554.002, 4522.97, 4491.47, 4459.513, 4427.109, 4394.269, 4361.002, 4327.32, 4293.232, 4258.747, 4223.875, 4188.624, 4153.003, 4117.021, 4080.6859999999997, 4044.006, 4006.99, 3969.643, 3931.975, 3893.993, 3855.704, 3817.115, 3778.232, 3739.063, 3699.614, 3659.8909999999996, 3619.9, 3579.6490000000003, 3539.1409999999996, 3498.385, 3457.385, 3416.147, 3374.676, 3332.978, 3291.058, 3248.921, 3206.573, 3164.018, 3121.261, 3078.3070000000002, 3035.16, 2991.8259999999996, 2948.308, 2904.612, 2860.74, 2816.699, 2772.491, 2728.1220000000003, 2683.594, 2638.913, 2594.081, 2549.103, 2503.9829999999997, 2458.724, 2413.33, 2367.804, 2322.15, 2276.371, 2230.472, 2184.4539999999997, 2138.323, 2092.08, 2045.729, 1999.273, 1952.7160000000001, 1906.06, 1859.309, 1812.465, 1765.5320000000002, 1718.511, 1671.408, 1624.223, 1576.96, 1529.621, 1482.21, 1434.729, 1387.181, 1339.568, 1291.893, 1244.1589999999999, 1196.367, 1148.521, 1100.624, 1052.6760000000002, 1004.682, 956.643, 908.562, 860.441, 812.2819999999999, 764.0880000000001, 715.8610000000001, 667.6030000000001, 619.317, 571.005, 522.668, 474.31, 425.93199999999996, 377.537, 329.12699999999995, 280.703, 232.268, 183.824, 135.373, 86.917, 38.458, -10.002, -58.46, -106.916, -155.366, -203.80900000000003, -252.24200000000002, -300.665, -349.075, -397.469, -445.847, -494.20599999999996, -542.544, -590.86, -639.15, -687.415, -735.6510000000001, -783.857, -832.0310000000001, -880.171, -928.275, -976.342, -1024.369, -1072.355, -1120.297, -1168.195, -1216.045, -1263.847, -1311.599, -1359.2979999999998, -1406.943, -1454.533, -1502.0639999999999, -1549.536, -1596.9460000000001, -1644.293, -1691.575, -1738.79, -1785.9370000000001, -1833.013, -1880.016, -1926.9460000000001, -1973.799, -2020.575, -2067.271, -2113.885, -2160.416, -2206.862, -2253.221, -2299.491, -2345.67, -2391.757, -2437.749, -2483.645, -2529.4429999999998, -2575.14, -2620.736, -2666.228, -2711.614, -2756.8920000000003, -2802.0609999999997, -2847.118, -2892.062, -2936.89, -2981.6009999999997, -3026.192, -3070.6620000000003, -3115.009, -3159.23, -3203.323, -3247.288, -3291.12, -3334.82, -3378.383, -3421.809, -3465.095, -3508.24, -3551.24, -3594.094, -3636.8, -3679.3559999999998, -3721.758, -3764.006, -3806.0959999999995, -3848.027, -3889.797, -3931.402, -3972.841, -4014.112, -4055.211, -4096.138, -4136.888, -4177.46, -4217.852, -4258.061, -4298.084, -4337.919, -4377.564, -4417.015, -4456.271, -4495.3279999999995, -4534.184, -4572.837, -4611.282999999999, -4649.519, -4687.544, -4725.354, -4762.946, -4800.318, -4837.465999999999, -4874.388, -4911.08, -4947.541, -4983.765, -5019.751, -5055.495, -5090.994000000001, -5126.246, -5161.245, -5195.99, -5230.477, -5264.701999999999, -5298.6630000000005, -5332.355, -5365.774, -5398.918000000001, -5431.781999999999, -5464.3640000000005, -5496.658, -5528.6630000000005, -5560.371999999999, -5591.783, -5622.891, -5653.691999999999, -5684.183000000001, -5714.358, -5744.214, -5773.746999999999, -5802.951, -5831.823, -5860.358, -5888.5509999999995, -5916.397, -5943.891, -5971.03, -5997.806, -6024.217, -6050.255999999999, -6075.918000000001, -6101.198, -6126.09, -6150.588000000001, -6174.688, -6198.383000000001, -6221.6669999999995, -6244.534000000001, -6266.978, -6288.994000000001, -6310.573, -6331.710999999999, -6352.401, -6372.634, -6392.405, -6411.706, -6430.531, -6448.871, -6466.721, -6484.07, -6500.9130000000005, -6517.24, -6533.043000000001, -6548.315, -6563.045999999999, -6577.227, -6590.85, -6603.906, -6616.385, -6628.276, -6639.571, -6650.259, -6660.329000000001, -6669.772, -6678.576, -6686.73, -6694.222, -6701.041, -6707.175, -6712.61, -6717.335, -6721.3369999999995, -6724.601, -6727.113, -6728.861999999999, -6729.829000000001, -6730.0019999999995, -6729.365, -6727.901999999999, -6725.596, -6722.431, -6718.39, -6713.454000000001, -6707.605, -6700.8240000000005, -6693.092, -6684.389, -6674.693, -6663.984, -6652.2390000000005, -6639.435, -6625.55, -6610.558000000001, -6594.434, -6577.153, -6558.687, -6539.008000000001, -6518.089, -6495.898, -6472.406, -6447.58, -6421.387, -6393.793000000001, -6364.762, -6334.257, -6302.241, -6268.673000000001, -6233.5109999999995, -6196.715, -6158.238, -6118.034000000001, -6076.056, -6032.253000000001, -5986.575, -5938.965999999999, -5889.37, -5837.73, -5783.984, -5728.07, -5669.92, -5609.467, -5546.64, -5481.3640000000005, -5413.562, -5343.153, -5270.055, -5194.181, -5115.44, -5033.74, -4948.984, -4861.071, -4769.896, -4675.355, -4577.338, -4475.73, -4370.416, -4261.279, -4148.2, -4031.058, -3909.7309999999998, -3784.103, -3654.054, -3519.473, -3380.2509999999997, -3236.29, -3087.502, -2933.815, -2775.1740000000004, -2611.548, -2442.931, -2269.354, -2090.883, -1907.6329999999998, -1719.767, -1527.506, -1331.134, -1131.001, -927.525, -721.195, -512.563, -302.246, -90.911, 120.73200000000001, 331.949, 541.994, 750.1310000000001, 955.6439999999999, 1157.863, 1356.1670000000001, 1550.005, 1738.8970000000002, 1922.44, 2100.3070000000002, 2272.251, 2438.094, 2597.723, 2751.085, 2898.177, 3039.0429999999997, 3173.759, 3302.433, 3425.197, 3542.199, 3653.603, 3759.579, 3860.305, 3955.962, 4046.7290000000003, 4132.789000000001, 4214.317, 4291.4890000000005, 4364.473, 4433.433, 4498.53, 4559.915, 4617.644, 4672.137, 4723.249, 4771.2029999999995, 4816.125, 4858.130999999999, 4897.335999999999, 4933.846, 4967.765, 4999.191, 5028.217000000001, 5054.933, 5079.424, 5101.77, 5122.05, 5140.335999999999, 5156.7, 5171.209, 5183.928, 5194.916, 5204.234, 5211.937, 5218.079000000001, 5222.712, 5225.883, 5227.642, 5228.031, 5227.095, 5224.876, 5221.412, 5216.742, 5210.902, 5203.929, 5195.854, 5186.710999999999, 5176.53, 5165.343, 5153.178, 5140.062, 5126.022, 5111.085, 5095.275, 5078.616, 5061.130999999999, 5042.843, 5023.772, 5003.94, 4983.3679999999995, 4962.075, 4940.0779999999995, 4917.396, 4894.048, 4870.05, 4845.418, 4820.169, 4794.318, 4767.88, 4740.869000000001, 4713.3, 4685.187, 4656.541, 4627.377, 4597.707, 4567.543, 4536.897, 4505.78, 4474.204000000001, 4442.179, 4409.715999999999, 4376.825, 4343.516, 4309.8, 4275.684, 4241.179, 4206.294, 4171.036, 4135.416, 4099.441, 4063.119, 4026.458, 3989.466, 3952.15, 3914.5190000000002, 3876.578, 3838.335, 3799.797, 3760.9709999999995, 3721.863, 3682.4790000000003, 3642.8259999999996, 3602.91, 3562.737, 3522.313, 3481.643, 3440.7329999999997, 3399.5890000000004, 3358.216, 3316.619, 3274.804, 3232.775, 3190.538, 3148.097, 3105.458, 3062.6240000000003, 3019.6009999999997, 2976.3920000000003, 2933.0029999999997, 2889.438, 2845.7, 2801.795, 2757.7259999999997, 2713.498, 2669.113, 2624.577, 2579.893, 2535.065, 2490.097, 2444.991, 2399.752, 2354.384, 2308.89, 2263.272, 2217.535, 2171.6820000000002, 2125.716, 2079.641, 2033.4589999999998, 1987.174, 1940.7879999999998, 1894.306, 1847.729, 1801.0610000000001, 1754.305, 1707.463, 1660.5379999999998, 1613.5339999999999, 1566.453, 1519.2979999999998, 1472.07, 1424.774, 1377.412, 1329.986, 1282.499, 1234.953, 1187.351, 1139.6960000000001, 1091.989, 1044.234, 996.432, 948.586, 900.699, 852.773, 804.81, 756.812, 708.7819999999999, 660.722, 612.633, 564.52, 516.382, 468.224, 420.046, 371.851, 323.64099999999996, 275.41900000000004, 227.18599999999998, 178.94400000000002, 130.695, 82.44200000000001, 34.187, -14.069, -62.323, -110.574, -158.82, -207.058, -255.28599999999997, -303.503, -351.707, -399.89599999999996, -448.06800000000004, -496.22, -544.352, -592.46, -640.544, -688.602, -736.6310000000001, -784.6289999999999, -832.595, -880.528, -928.424, -976.283, -1024.1019999999999, -1071.879, -1119.613, -1167.303, -1214.945, -1262.538, -1310.0810000000001, -1357.5720000000001, -1405.0079999999998, -1452.389, -1499.711, -1546.974, -1594.1760000000002, -1641.3139999999999, -1688.3870000000002, -1735.3929999999998, -1782.3310000000001, -1829.1979999999999, -1875.9920000000002, -1922.713, -1969.3570000000002, -2015.924, -2062.411, -2108.8160000000003, -2155.139, -2201.376, -2247.526, -2293.587, -2339.5570000000002, -2385.435, -2431.219, -2476.906, -2522.495, -2567.984, -2613.371, -2658.6540000000005, -2703.8309999999997, -2748.901, -2793.86, -2838.7090000000003, -2883.4440000000004, -2928.063, -2972.565, -3016.948, -3061.2090000000003, -3105.347, -3149.36, -3193.245, -3237.0009999999997, -3280.625, -3324.116, -3367.4709999999995, -3410.6890000000003, -3453.7659999999996, -3496.702, -3539.493, -3582.139, -3624.636, -3666.982, -3709.176, -3751.2140000000004, -3793.0959999999995, -3834.8179999999998, -3876.3779999999997, -3917.7740000000003, -3959.0040000000004, -4000.065, -4040.955, -4081.671, -4122.212, -4162.5740000000005, -4202.755, -4242.753, -4282.566, -4322.19, -4361.623, -4400.863, -4439.907, -4478.753, -4517.397, -4555.837, -4594.07, -4632.093, -4669.904, -4707.5, -4744.878, -4782.035, -4818.968, -4855.675, -4892.151, -4928.395, -4964.402, -5000.170999999999, -5035.697, -5070.978, -5106.01, -5140.79, -5175.315, -5209.58, -5243.584, -5277.321, -5310.79, -5343.986, -5376.905, -5409.544, -5441.899, -5473.965999999999, -5505.741, -5537.221, -5568.401, -5599.278, -5629.847, -5660.104, -5690.045, -5719.665, -5748.96, -5777.925, -5806.557, -5834.85, -5862.8, -5890.401, -5917.65, -5944.54, -5971.066999999999, -5997.227, -6023.013000000001, -6048.42, -6073.443, -6098.076, -6122.313, -6146.149, -6169.579000000001, -6192.595, -6215.191999999999, -6237.365, -6259.105, -6280.406999999999, -6301.264, -6321.67, -6341.616999999999, -6361.099, -6380.108, -6398.637, -6416.679, -6434.226, -6451.27, -6467.803000000001, -6483.816, -6499.302, -6514.2519999999995, -6528.658, -6542.509, -6555.797, -6568.513000000001, -6580.647, -6592.189, -6603.13, -6613.4580000000005, -6623.1630000000005, -6632.235, -6640.661999999999, -6648.432, -6655.534000000001, -6661.956999999999, -6667.687, -6672.7119999999995, -6677.019, -6680.595, -6683.425, -6685.496999999999, -6686.795, -6687.303000000001, -6687.008000000001, -6685.893, -6683.943, -6681.139, -6677.465999999999, -6672.905, -6667.438, -6661.047, -6653.710999999999, -6645.411, -6636.1269999999995, -6625.835999999999, -6614.518, -6602.149, -6588.705, -6574.164000000001, -6558.499, -6541.685, -6523.695, -6504.5019999999995, -6484.076999999999, -6462.39, -6439.411, -6415.107, -6389.446999999999, -6362.395, -6333.918000000001, -6303.977, -6272.535, -6239.552, -6204.988, -6168.799, -6130.941999999999, -6091.371, -6050.039000000001, -6006.894, -5961.887, -5914.9619999999995, -5866.065, -5815.137, -5762.118, -5706.945, -5649.553000000001, -5589.874, -5527.835, -5463.365, -5396.3859999999995, -5326.818, -5254.578, -5179.58, -5101.735, -5020.9490000000005, -4937.127, -4850.167, -4759.969, -4666.424, -4569.424, -4468.855, -4364.603, -4256.55, -4144.5779999999995, -4028.565, -3908.3909999999996, -3783.937, -3655.085, -3521.722, -3383.739, -3241.0359999999996, -3093.525, -2941.131, -2783.796, -2621.487, -2454.196, -2281.946, -2104.802, -1922.871, -1736.31, -1545.3339999999998, -1350.2179999999998, -1151.3039999999999, -949.0010000000001, -743.789, -536.211, -326.876, -116.443, 94.385, 304.878, 514.2959999999999, 721.9, 926.9810000000001, 1128.862, 1326.921, 1520.6029999999998, 1709.421, 1892.967, 2070.908, 2242.988, 2409.024, 2568.895, 2722.5440000000003, 2869.962, 3011.185, 3146.2870000000003, 3275.3720000000003, 3398.567, 3516.0170000000003, 3627.883, 3734.3340000000003, 3835.545, 3931.695, 4022.9629999999997, 4109.527, 4191.565, 4269.25, 4342.749, 4412.227, 4477.842000000001, 4539.746, 4598.088, 4653.0070000000005, 4704.639, 4753.112, 4798.552, 4841.077, 4880.7970000000005, 4917.822, 4952.255, 4984.193, 5013.73, 5040.955, 5065.952, 5088.804, 5109.588, 5128.376, 5145.241, 5160.249, 5173.463, 5184.948, 5194.759, 5202.9529999999995, 5209.585, 5214.705, 5218.362, 5220.605, 5221.476, 5221.02, 5219.279, 5216.291, 5212.096, 5206.729, 5200.226, 5192.62, 5183.944, 5174.229, 5163.505999999999, 5151.802, 5139.146, 5125.564, 5111.083, 5095.728, 5079.521, 5062.487, 5044.648, 5026.024, 5006.639, 4986.51, 4965.657999999999, 4944.101, 4921.859, 4898.947, 4875.384, 4851.185, 4826.367, 4800.946, 4774.936, 4748.351, 4721.207, 4693.516, 4665.292, 4636.548, 4607.295, 4577.5470000000005, 4547.316, 4516.612, 4485.447, 4453.831, 4421.775, 4389.291, 4356.3859999999995, 4323.072, 4289.358, 4255.252, 4220.764, 4185.903, 4150.677, 4115.094, 4079.163, 4042.8920000000003, 4006.2870000000003, 3969.3579999999997, 3932.111, 3894.553, 3856.691, 3818.533, 3780.0840000000003, 3741.353, 3702.344, 3663.0640000000003, 3623.52, 3583.717, 3543.6609999999996, 3503.3579999999997, 3462.813, 3422.032, 3381.0209999999997, 3339.785, 3298.329, 3256.657, 3214.776, 3172.6890000000003, 3130.401, 3087.9179999999997, 3045.243, 3002.382, 2959.3390000000004, 2916.118, 2872.724, 2829.16, 2785.43, 2741.54, 2697.492, 2653.29, 2608.94, 2564.4429999999998, 2519.804, 2475.027, 2430.115, 2385.072, 2339.9, 2294.605, 2249.188, 2203.654, 2158.006, 2112.246, 2066.3779999999997, 2020.405, 1974.3310000000001, 1928.1570000000002, 1881.888, 1835.526, 1789.0739999999998, 1742.535, 1695.912, 1649.207, 1602.424, 1555.565, 1508.632, 1461.629, 1414.559, 1367.422, 1320.223, 1272.964, 1225.647, 1178.275, 1130.85, 1083.375, 1035.8519999999999, 988.283, 940.671, 893.0189999999999, 845.327, 797.6, 749.8380000000001, 702.045, 654.222, 606.372, 558.497, 510.599, 462.68, 414.74199999999996, 366.788, 318.819, 270.83799999999997, 222.847, 174.847, 126.84100000000001, 78.831, 30.819000000000003, -17.194000000000003, -65.204, -113.211, -161.21200000000002, -209.205, -257.189, -305.161, -353.12, -401.06300000000005, -448.98900000000003, -496.89599999999996, -544.781, -592.644, -640.482, -688.293, -736.075, -783.827, -831.547, -879.232, -926.882, -974.493, -1022.066, -1069.596, -1117.083, -1164.526, -1211.921, -1259.267, -1306.563, -1353.807, -1400.996, -1448.13, -1495.205, -1542.221, -1589.1760000000002, -1636.067, -1682.894, -1729.6529999999998, -1776.344, -1822.965, -1869.513, -1915.987, -1962.386, -2008.7060000000001, -2054.947, -2101.107, -2147.183, -2193.175, -2239.0789999999997, -2284.895, -2330.62, -2376.2529999999997, -2421.791, -2467.2329999999997, -2512.577, -2557.822, -2602.964, -2648.002, -2692.935, -2737.761, -2782.4770000000003, -2827.0809999999997, -2871.572, -2915.948, -2960.2070000000003, -3004.3459999999995, -3048.364, -3092.259, -3136.0290000000005, -3179.671, -3223.184, -3266.566, -3309.8140000000003, -3352.927, -3395.902, -3438.738, -3481.4309999999996, -3523.9809999999998, -3566.384, -3608.639, -3650.744, -3692.696, -3734.493, -3776.133, -3817.614, -3858.933, -3900.0879999999997, -3941.077, -3981.8959999999997, -4022.545, -4063.02, -4103.32, -4143.441, -4183.380999999999, -4223.139, -4262.71, -4302.093, -4341.286, -4380.284000000001, -4419.087, -4457.691, -4496.094, -4534.292, -4572.282999999999, -4610.065, -4647.634, -4684.988, -4722.124, -4759.038, -4795.729, -4832.192, -4868.4259999999995, -4904.4259999999995, -4940.19, -4975.715, -5010.997, -5046.032999999999, -5080.82, -5115.354, -5149.633, -5183.652, -5217.409000000001, -5250.9, -5284.121, -5317.068, -5349.7390000000005, -5382.128000000001, -5414.233, -5446.049, -5477.573, -5508.8009999999995, -5539.728, -5570.351, -5600.666, -5630.6669999999995, -5660.352, -5689.714, -5718.751, -5747.456999999999, -5775.829000000001, -5803.86, -5831.547, -5858.885, -5885.868, -5912.491999999999, -5938.7519999999995, -5964.642, -5990.156999999999, -6015.291, -6040.04, -6064.397, -6088.357, -6111.914000000001, -6135.062, -6157.795, -6180.108, -6201.991999999999, -6223.443, -6244.453, -6265.016, -6285.125, -6304.774, -6323.954000000001, -6342.658, -6360.88, -6378.611, -6395.844, -6412.571, -6428.784000000001, -6444.474, -6459.633000000001, -6474.253000000001, -6488.323, -6501.835999999999, -6514.781, -6527.15, -6538.933000000001, -6550.12, -6560.6990000000005, -6570.661999999999, -6579.996, -6588.691999999999, -6596.736999999999, -6604.12, -6610.829000000001, -6616.852, -6622.1759999999995, -6626.789000000001, -6630.677, -6633.825, -6636.222, -6637.852, -6638.6990000000005, -6638.75, -6637.986999999999, -6636.397, -6633.960999999999, -6630.6630000000005, -6626.484, -6621.408, -6615.414000000001, -6608.485, -6600.6, -6591.738, -6581.879, -6571.0, -6559.08, -6546.094, -6532.02, -6516.831999999999, -6500.503000000001, -6483.01, -6464.321999999999, -6444.4130000000005, -6423.2519999999995, -6400.81, -6377.054, -6351.951999999999, -6325.471, -6297.575, -6268.228, -6237.392, -6205.026999999999, -6171.094, -6135.55, -6098.35, -6059.451, -6018.803000000001, -5976.358, -5932.065, -5885.871, -5837.718000000001, -5787.552, -5735.311, -5680.933000000001, -5624.352, -5565.5019999999995, -5504.311, -5440.706999999999, -5374.613, -5305.951, -5234.637, -5160.585, -5083.708, -5003.912, -4921.102, -4835.178, -4746.037, -4653.575, -4557.682, -4458.245, -4355.151, -4248.282, -4137.518, -4022.741, -3903.83, -3780.663, -3653.1259999999997, -3521.1020000000003, -3384.4829999999997, -3243.1690000000003, -3097.0679999999998, -2946.1059999999998, -2790.2209999999995, -2629.3759999999997, -2463.561, -2292.7960000000003, -2117.139, -1936.692, -1751.605, -1562.086, -1368.4029999999998, -1170.887, -969.939, -766.029, -559.692, -351.526, -142.184, 67.64, 277.224, 485.82800000000003, 692.72, 897.188, 1098.557, 1296.201, 1489.5620000000001, 1678.1470000000002, 1861.5420000000001, 2039.408, 2211.4829999999997, 2377.576, 2537.561, 2691.373, 2838.998, 2980.467, 3115.85, 3245.244, 3368.7740000000003, 3486.583, 3598.827, 3705.672, 3807.2909999999997, 3903.862, 3995.562, 4082.567, 4165.055, 4243.196, 4317.157999999999, 4387.103, 4453.191, 4515.571, 4574.392, 4629.793, 4681.909000000001, 4730.869000000001, 4776.795999999999, 4819.81, 4860.021, 4897.537, 4932.462, 4964.893, 4994.923, 5022.641, 5048.133, 5071.478, 5092.755, 5112.037, 5129.395, 5144.895, 5158.602, 5170.5779999999995, 5180.88, 5189.565, 5196.687, 5202.295999999999, 5206.443, 5209.173, 5210.532, 5210.562, 5209.306, 5206.803, 5203.092000000001, 5198.207, 5192.186, 5185.061, 5176.865, 5167.629, 5157.383, 5146.156, 5133.976, 5120.869000000001, 5106.862, 5091.978, 5076.2429999999995, 5059.679, 5042.309, 5024.153, 5005.234, 4985.571, 4965.183, 4944.089, 4922.308, 4899.857, 4876.753, 4853.013, 4828.652, 4803.686, 4778.13, 4751.999, 4725.306, 4698.066, 4670.29, 4641.994000000001, 4613.188, 4583.8859999999995, 4554.098, 4523.835999999999, 4493.112, 4461.937, 4430.32, 4398.273, 4365.804, 4332.924, 4299.643, 4265.969, 4231.912, 4197.48, 4162.681, 4127.525, 4092.0190000000002, 4056.171, 4019.989, 3983.4809999999998, 3946.653, 3909.513, 3872.0679999999998, 3834.325, 3796.2909999999997, 3757.9709999999995, 3719.373, 3680.5029999999997, 3641.367, 3601.9709999999995, 3562.32, 3522.421, 3482.2790000000005, 3441.8990000000003, 3401.288, 3360.449, 3319.389, 3278.113, 3236.625, 3194.93, 3153.034, 3110.94, 3068.6540000000005, 3026.18, 2983.522, 2940.684, 2897.672, 2854.489, 2811.138, 2767.625, 2723.954, 2680.127, 2636.1490000000003, 2592.024, 2547.756, 2503.347, 2458.803, 2414.125, 2369.3179999999998, 2324.386, 2279.331, 2234.156, 2188.866, 2143.4629999999997, 2097.95, 2052.331, 2006.608, 1960.785, 1914.865, 1868.851, 1822.745, 1776.55, 1730.269, 1683.906, 1637.4620000000002, 1590.941, 1544.345, 1497.6779999999999, 1450.94, 1404.136, 1357.267, 1310.337, 1263.347, 1216.3, 1169.1989999999998, 1122.046, 1074.844, 1027.595, 980.3, 932.9630000000001, 885.586, 838.172, 790.721, 743.237, 695.722, 648.178, 600.607, 553.012, 505.394, 457.756, 410.099, 362.42699999999996, 314.74, 267.041, 219.333, 171.61599999999999, 123.89399999999999, 76.168, 28.439, -19.289, -67.015, -114.73700000000001, -162.453, -210.16099999999997, -257.85900000000004, -305.546, -353.219, -400.876, -448.51599999999996, -496.13599999999997, -543.736, -591.312, -638.863, -686.388, -733.8839999999999, -781.3489999999999, -828.7819999999999, -876.181, -923.544, -970.8689999999999, -1018.155, -1065.399, -1112.599, -1159.755, -1206.864, -1253.924, -1300.934, -1347.891, -1394.795, -1441.642, -1488.432, -1535.162, -1581.8310000000001, -1628.4370000000001, -1674.9779999999998, -1721.453, -1767.859, -1814.194, -1860.4579999999999, -1906.6470000000002, -1952.761, -1998.7979999999998, -2044.755, -2090.631, -2136.423, -2182.131, -2227.7529999999997, -2273.286, -2318.728, -2364.078, -2409.335, -2454.495, -2499.5570000000002, -2544.52, -2589.381, -2634.139, -2678.7909999999997, -2723.337, -2767.772, -2812.097, -2856.308, -2900.405, -2944.384, -2988.245, -3031.9840000000004, -3075.6, -3119.092, -3162.4559999999997, -3205.692, -3248.796, -3291.7670000000003, -3334.603, -3377.302, -3419.861, -3462.2790000000005, -3504.553, -3546.6809999999996, -3588.6609999999996, -3630.491, -3672.1679999999997, -3713.69, -3755.0559999999996, -3796.263, -3837.308, -3878.1890000000003, -3918.9040000000005, -3959.45, -3999.8259999999996, -4040.0290000000005, -4080.0559999999996, -4119.904, -4159.573, -4199.058, -4238.358, -4277.469, -4316.39, -4355.117, -4393.649, -4431.982, -4470.113, -4508.04, -4545.7609999999995, -4583.272, -4620.57, -4657.654, -4694.519, -4731.163, -4767.583, -4803.776, -4839.7390000000005, -4875.468, -4910.962, -4946.215, -4981.226, -5015.991, -5050.5070000000005, -5084.771, -5118.778, -5152.526, -5186.0109999999995, -5219.229, -5252.178000000001, -5284.852, -5317.25, -5349.366, -5381.198, -5412.74, -5443.99, -5474.943, -5505.594, -5535.941, -5565.979, -5595.704000000001, -5625.111, -5654.195, -5682.953, -5711.379, -5739.47, -5767.22, -5794.625, -5821.68, -5848.379, -5874.718000000001, -5900.691, -5926.293000000001, -5951.52, -5976.365, -6000.823, -6024.888000000001, -6048.554, -6071.816, -6094.668000000001, -6117.103, -6139.115, -6160.698, -6181.845, -6202.549, -6222.805, -6242.604, -6261.94, -6280.806, -6299.195, -6317.098000000001, -6334.508000000001, -6351.4169999999995, -6367.816999999999, -6383.7, -6399.058000000001, -6413.880999999999, -6428.161, -6441.889, -6455.056, -6467.651999999999, -6479.668000000001, -6491.093000000001, -6501.918000000001, -6512.132, -6521.724, -6530.684, -6538.999, -6546.659000000001, -6553.651999999999, -6559.965999999999, -6565.5869999999995, -6570.504, -6574.704000000001, -6578.170999999999, -6580.894, -6582.857, -6584.045999999999, -6584.446, -6584.04, -6582.814, -6580.7519999999995, -6577.834, -6574.045999999999, -6569.366999999999, -6563.781, -6557.268, -6549.807, -6541.38, -6531.964, -6521.5380000000005, -6510.081999999999, -6497.569, -6483.978, -6469.283, -6453.459, -6436.48, -6418.319, -6398.946, -6378.334, -6356.453, -6333.269, -6308.753000000001, -6282.869000000001, -6255.584, -6226.861, -6196.661, -6164.9490000000005, -6131.68, -6096.816, -6060.312, -6022.121999999999, -5982.2, -5940.496, -5896.960999999999, -5851.5419999999995, -5804.182, -5754.826, -5703.4130000000005, -5649.882, -5594.168000000001, -5536.204000000001, -5475.92, -5413.243, -5348.099, -5280.406999999999, -5210.085999999999, -5137.052, -5061.215999999999, -4982.485, -4900.765, -4815.957, -4727.959, -4636.667, -4541.971, -4443.76, -4341.92, -4236.334, -4126.884, -4013.449, -3895.91, -3774.147, -3648.042, -3517.4809999999998, -3382.3540000000003, -3242.559, -3098.005, -2948.613, -2794.323, -2635.092, -2470.907, -2301.784, -2127.777, -1948.98, -1765.539, -1577.6529999999998, -1385.5810000000001, -1189.647, -990.24, -787.821, -582.9159999999999, -376.11199999999997, -168.05200000000002, 40.576, 249.05700000000002, 456.659, 662.65, 866.321, 1066.997, 1264.0510000000002, 1456.918, 1645.104, 1828.1879999999999, 2005.826, 2177.748, 2343.755, 2503.718, 2657.5640000000003, 2805.2729999999997, 2946.8709999999996, 3082.422, 3212.02, 3335.785, 3453.857, 3566.387, 3673.5409999999997, 3775.489, 3872.405, 3964.465, 4051.845, 4134.717000000001, 4213.255, 4287.623, 4357.983, 4424.4929999999995, 4487.302, 4546.63, 4602.401, 4654.963, 4704.374, 4750.7570000000005, 4794.23, 4834.903, 4872.885, 4908.279, 4941.181, 4971.685, 4999.879, 5025.848, 5049.673, 5071.432, 5091.196, 5109.038, 5125.024, 5139.218, 5151.681, 5162.472, 5171.646, 5179.2570000000005, 5185.357, 5189.995, 5193.215999999999, 5195.066, 5195.589, 5194.8240000000005, 5192.814, 5189.594, 5185.2029999999995, 5179.673, 5173.041, 5165.337, 5156.593, 5146.839, 5136.103, 5124.415, 5111.798, 5098.282, 5083.888, 5068.643, 5052.568, 5035.686, 5018.019, 4999.588, 4980.411, 4960.51, 4939.902, 4918.606, 4896.639, 4874.019, 4850.762, 4826.883, 4802.399, 4777.3240000000005, 4751.6720000000005, 4725.458, 4698.696, 4671.399, 4643.579000000001, 4615.248, 4586.42, 4557.107, 4527.318, 4497.066, 4466.361, 4435.214, 4403.6359999999995, 4371.635, 4339.222, 4306.407, 4273.197, 4239.604, 4205.634, 4171.298, 4136.602, 4101.556, 4066.1659999999997, 4030.441, 3994.389, 3958.0159999999996, 3921.33, 3884.3379999999997, 3847.046, 3809.462, 3771.592, 3733.441, 3695.018, 3656.327, 3617.375, 3578.1679999999997, 3538.711, 3499.009, 3459.0690000000004, 3418.895, 3378.494, 3337.869, 3297.027, 3255.972, 3214.7090000000003, 3173.243, 3131.578, 3089.72, 3047.672, 3005.4390000000003, 2963.025, 2920.435, 2877.673, 2834.743, 2791.6479999999997, 2748.393, 2704.982, 2661.4190000000003, 2617.7070000000003, 2573.85, 2529.8520000000003, 2485.715, 2441.445, 2397.044, 2352.516, 2307.864, 2263.091, 2218.201, 2173.197, 2128.081, 2082.8579999999997, 2037.53, 1992.1, 1946.5710000000001, 1900.9470000000001, 1855.229, 1809.421, 1763.526, 1717.547, 1671.486, 1625.346, 1579.129, 1532.839, 1486.4779999999998, 1440.049, 1393.5529999999999, 1346.994, 1300.375, 1253.697, 1206.963, 1160.1760000000002, 1113.337, 1066.45, 1019.5160000000001, 972.539, 925.5189999999999, 878.46, 831.3639999999999, 784.2330000000001, 737.069, 689.8739999999999, 642.651, 595.4019999999999, 548.129, 500.833, 453.51800000000003, 406.185, 358.836, 311.473, 264.099, 216.715, 169.324, 121.927, 74.52600000000001, 27.124000000000002, -20.278, -67.678, -115.073, -162.46200000000002, -209.84400000000002, -257.215, -304.574, -351.92, -399.25, -446.56199999999995, -493.855, -541.127, -588.376, -635.599, -682.796, -729.965, -777.102, -824.2080000000001, -871.279, -918.315, -965.313, -1012.2710000000001, -1059.188, -1106.062, -1152.89, -1199.672, -1246.406, -1293.089, -1339.72, -1386.2979999999998, -1432.819, -1479.283, -1525.6879999999999, -1572.0320000000002, -1618.3120000000001, -1664.529, -1710.6779999999999, -1756.76, -1802.771, -1848.711, -1894.5770000000002, -1940.368, -1986.0810000000001, -2031.7160000000001, -2077.269, -2122.74, -2168.126, -2213.426, -2258.638, -2303.76, -2348.79, -2393.726, -2438.567, -2483.31, -2527.953, -2572.496, -2616.936, -2661.27, -2705.4970000000003, -2749.616, -2793.6240000000003, -2837.5190000000002, -2881.2990000000004, -2924.9629999999997, -2968.509, -3011.933, -3055.235, -3098.413, -3141.4640000000004, -3184.386, -3227.178, -3269.837, -3312.361, -3354.748, -3396.9970000000003, -3439.1040000000003, -3481.067, -3522.885, -3564.5559999999996, -3606.077, -3647.445, -3688.66, -3729.718, -3770.617, -3811.355, -3851.93, -3892.3390000000004, -3932.579, -3972.65, -4012.547, -4052.27, -4091.8140000000003, -4131.179, -4170.361, -4209.357, -4248.166, -4286.784000000001, -4325.21, -4363.439, -4401.471, -4439.3009999999995, -4476.927, -4514.347, -4551.558, -4588.557, -4625.340999999999, -4661.906, -4698.251, -4734.372, -4770.266, -4805.931, -4841.362, -4876.557, -4911.512, -4946.227, -4980.693, -5014.912, -5048.878, -5082.588, -5116.039000000001, -5149.226, -5182.148, -5214.8, -5247.177, -5279.278, -5311.096, -5342.63, -5373.875, -5404.826999999999, -5435.483, -5465.835999999999, -5495.8859999999995, -5525.625, -5555.05, -5584.158, -5612.943, -5641.401, -5669.528, -5697.318, -5724.767, -5751.87, -5778.6230000000005, -5805.019, -5831.055, -5856.724, -5882.022, -5906.941999999999, -5931.48, -5955.63, -5979.387, -6002.744000000001, -6025.694, -6048.235, -6070.356, -6092.054, -6113.321999999999, -6134.151, -6154.5380000000005, -6174.473000000001, -6193.95, -6212.963000000001, -6231.504, -6249.565, -6267.138000000001, -6284.215999999999, -6300.791, -6316.855, -6332.4, -6347.416, -6361.896, -6375.829000000001, -6389.209, -6402.023, -6414.263000000001, -6425.919, -6436.983, -6447.441, -6457.285, -6466.503000000001, -6475.084, -6483.017, -6490.29, -6496.891, -6502.808000000001, -6508.029, -6512.539000000001, -6516.325, -6519.374, -6521.672, -6523.204000000001, -6523.956, -6523.911999999999, -6523.055, -6521.37, -6518.84, -6515.448, -6511.175, -6506.004, -6499.915, -6492.89, -6484.908, -6475.946999999999, -6465.988, -6455.007, -6442.983, -6429.89, -6415.706, -6400.405, -6383.959, -6366.344, -6347.53, -6327.4890000000005, -6306.191999999999, -6283.607, -6259.701999999999, -6234.443, -6207.797, -6179.727, -6150.196999999999, -6119.1669999999995, -6086.598000000001, -6052.45, -6016.6759999999995, -5979.236, -5940.079000000001, -5899.16, -5856.427, -5811.828, -5765.307, -5716.81, -5666.278, -5613.646, -5558.854, -5501.8330000000005, -5442.514, -5380.826999999999, -5316.694, -5250.04, -5180.782, -5108.834, -5034.113, -4956.523, -4875.973, -4792.3640000000005, -4705.593, -4615.558, -4522.15, -4425.259, -4324.77, -4220.569, -4112.535, -4000.552, -3884.4970000000003, -3764.2529999999997, -3639.7009999999996, -3510.7259999999997, -3377.218, -3239.075, -3096.204, -2948.526, -2795.975, -2638.508, -2476.109, -2308.788, -2136.595, -1959.619, -1777.997, -1591.922, -1401.6429999999998, -1207.476, -1009.799, -809.064, -605.784, -400.538, -193.959, 13.276, 220.458, 426.861, 631.758, 834.442, 1034.237, 1230.517, 1422.714, 1610.329, 1792.935, 1970.182, 2141.797, 2307.572, 2467.37, 2621.114, 2768.778, 2910.381, 3045.9840000000004, 3175.6740000000004, 3299.5690000000004, 3417.802, 3530.525, 3637.8979999999997, 3740.0879999999997, 3837.2690000000002, 3929.613, 4017.2940000000003, 4100.486, 4179.356, 4254.07, 4324.789000000001, 4391.667, 4454.856, 4514.502, 4570.742, 4623.710999999999, 4673.535, 4720.338, 4764.238, 4805.343, 4843.764, 4879.602, 4912.952, 4943.907999999999, 4972.558, 4998.988, 5023.279, 5045.505, 5065.74, 5084.057, 5100.52, 5115.193, 5128.137, 5139.413, 5149.0740000000005, 5157.173, 5163.764, 5168.892, 5172.608, 5174.9529999999995, 5175.973, 5175.707, 5174.196, 5171.477, 5167.585999999999, 5162.559, 5156.43, 5149.23, 5140.991, 5131.742, 5121.512, 5110.33, 5098.221, 5085.210999999999, 5071.326, 5056.588, 5041.023, 5024.649, 5007.49, 4989.568, 4970.9, 4951.5070000000005, 4931.407999999999, 4910.621, 4889.163, 4867.0509999999995, 4844.302, 4820.931, 4796.955, 4772.388, 4747.2429999999995, 4721.536, 4695.28, 4668.488, 4641.174, 4613.349, 4585.025, 4556.215, 4526.93, 4497.181, 4466.979, 4436.333, 4405.255999999999, 4373.755999999999, 4341.842000000001, 4309.525, 4276.815, 4243.719, 4210.247, 4176.406, 4142.206, 4107.654, 4072.757, 4037.525, 4001.965, 3966.083, 3929.887, 3893.384, 3856.5809999999997, 3819.485, 3782.1009999999997, 3744.4359999999997, 3706.4970000000003, 3668.289, 3629.82, 3591.094, 3552.117, 3512.895, 3473.4320000000002, 3433.736, 3393.8109999999997, 3353.6620000000003, 3313.2940000000003, 3272.712, 3231.921, 3190.926, 3149.7309999999998, 3108.34, 3066.76, 3024.993, 2983.0429999999997, 2940.917, 2898.617, 2856.1479999999997, 2813.513, 2770.717, 2727.763, 2684.656, 2641.3990000000003, 2597.996, 2554.45, 2510.765, 2466.945, 2422.992, 2378.91, 2334.7039999999997, 2290.376, 2245.928, 2201.366, 2156.6910000000003, 2111.907, 2067.016, 2022.023, 1976.9279999999999, 1931.737, 1886.4520000000002, 1841.075, 1795.609, 1750.057, 1704.422, 1658.707, 1612.914, 1567.046, 1521.105, 1475.094, 1429.016, 1382.8729999999998, 1336.668, 1290.403, 1244.08, 1197.702, 1151.2730000000001, 1104.7910000000002, 1058.263, 1011.688, 965.072, 918.413, 871.716, 824.9810000000001, 778.212, 731.4119999999999, 684.581, 637.722, 590.837, 543.929, 497.0, 450.05, 403.084, 356.102, 309.106, 262.1, 215.084, 168.06, 121.031, 74.0, 26.965999999999998, -20.066, -67.097, -114.124, -161.144, -208.155, -255.15599999999998, -302.147, -349.12300000000005, -396.082, -443.025, -489.94800000000004, -536.851, -583.73, -630.5830000000001, -677.41, -724.21, -770.977, -817.7130000000001, -864.415, -911.082, -957.711, -1004.301, -1050.849, -1097.354, -1143.8139999999999, -1190.229, -1236.595, -1282.91, -1329.174, -1375.384, -1421.539, -1467.6370000000002, -1513.675, -1559.6529999999998, -1605.568, -1651.4189999999999, -1697.204, -1742.921, -1788.569, -1834.145, -1879.6470000000002, -1925.075, -1970.4260000000002, -2015.6979999999999, -2060.89, -2105.999, -2151.024, -2195.964, -2240.815, -2285.578, -2330.248, -2374.826, -2419.3089999999997, -2463.694, -2507.98, -2552.166, -2596.249, -2640.228, -2684.1009999999997, -2727.864, -2771.518, -2815.06, -2858.487, -2901.798, -2944.992, -2988.065, -3031.0159999999996, -3073.843, -3116.5440000000003, -3159.118, -3201.5609999999997, -3243.8720000000003, -3286.048, -3328.0879999999997, -3369.99, -3411.7509999999997, -3453.369, -3494.843, -3536.1690000000003, -3577.347, -3618.373, -3659.245, -3699.961, -3740.5190000000002, -3780.917, -3821.151, -3861.2209999999995, -3901.123, -3940.855, -3980.4159999999997, -4019.801, -4059.009, -4098.038, -4136.884, -4175.545999999999, -4214.02, -4252.305, -4290.397, -4328.294, -4365.994000000001, -4403.4929999999995, -4440.789000000001, -4477.878, -4514.759, -4551.428, -4587.883, -4624.121, -4660.138, -4695.931, -4731.498, -4766.835999999999, -4801.941, -4836.811, -4871.443, -4905.831, -4939.974, -4973.869000000001, -5007.5109999999995, -5040.898, -5074.025, -5106.891, -5139.49, -5171.819, -5203.876, -5235.654, -5267.151999999999, -5298.365, -5329.289000000001, -5359.920999999999, -5390.255999999999, -5420.289000000001, -5450.018, -5479.438, -5508.543000000001, -5537.331, -5565.795999999999, -5593.933000000001, -5621.7390000000005, -5649.209, -5676.338000000001, -5703.12, -5729.552, -5755.6269999999995, -5781.340999999999, -5806.689, -5831.664000000001, -5856.262, -5880.477, -5904.303000000001, -5927.735, -5950.767, -5973.394, -5995.606, -6017.401, -6038.771, -6059.709, -6080.209, -6100.264, -6119.866999999999, -6139.0109999999995, -6157.689, -6175.894, -6193.616999999999, -6210.851, -6227.588000000001, -6243.821999999999, -6259.541, -6274.7390000000005, -6289.406999999999, -6303.536, -6317.116999999999, -6330.14, -6342.596, -6354.476, -6365.77, -6376.465999999999, -6386.555, -6396.026, -6404.869000000001, -6413.07, -6420.62, -6427.505, -6433.715999999999, -6439.236, -6444.056, -6448.16, -6451.536999999999, -6454.170999999999, -6456.048000000001, -6457.155, -6457.473000000001, -6456.9890000000005, -6455.688, -6453.55, -6450.56, -6446.701999999999, -6441.954000000001, -6436.3, -6429.72, -6422.193, -6413.701, -6404.221, -6393.731, -6382.209, -6369.630999999999, -6355.975, -6341.213000000001, -6325.321999999999, -6308.273, -6290.039000000001, -6270.592, -6249.903, -6227.94, -6204.672, -6180.066, -6154.088000000001, -6126.701999999999, -6097.8730000000005, -6067.561, -6035.726, -6002.329000000001, -5967.326, -5930.674, -5892.325, -5852.231, -5810.345, -5766.611999999999, -5720.98, -5673.392, -5623.79, -5572.113, -5518.298000000001, -5462.279, -5403.986999999999, -5343.351, -5280.297, -5214.746, -5146.62, -5075.834, -5002.3009999999995, -4925.931, -4846.63, -4764.302, -4678.846, -4590.157999999999, -4498.1320000000005, -4402.657, -4303.619000000001, -4200.905, -4094.3959999999997, -3983.975, -3869.52, -3750.913, -3628.0359999999996, -3500.7740000000003, -3369.018, -3232.663, -3091.615, -2945.7940000000003, -2795.132, -2639.586, -2479.131, -2313.777, -2143.567, -1968.5839999999998, -1788.961, -1604.878, -1416.58, -1224.37, -1028.618, -829.763, -628.308, -424.82099999999997, -219.923, -14.284, 191.39700000000002, 396.4, 600.005, 801.5060000000001, 1000.2310000000001, 1195.5510000000002, 1386.895, 1573.7620000000002, 1755.72, 1932.415, 2103.562, 2268.953, 2428.442, 2581.945, 2729.4320000000002, 2870.9159999999997, 3006.449, 3136.118, 3260.034, 3378.328, 3491.1459999999997, 3598.645, 3700.992, 3798.3540000000003, 3890.905, 3978.815, 4062.255, 4141.392, 4216.391, 4287.41, 4354.604, 4418.122, 4478.11, 4534.7029999999995, 4588.035, 4638.235, 4685.4220000000005, 4729.714, 4771.222, 4810.052, 4846.306, 4880.081, 4911.467000000001, 4940.555, 4967.428, 4992.166, 5014.846, 5035.541, 5054.319, 5071.251, 5086.396, 5099.817, 5111.572, 5121.715999999999, 5130.303, 5137.383, 5143.005999999999, 5147.217000000001, 5150.061, 5151.582, 5151.82, 5150.815, 5148.604, 5145.224, 5140.71, 5135.094, 5128.41, 5120.689, 5111.959, 5102.25, 5091.59, 5080.003, 5067.519, 5054.157999999999, 5039.947, 5024.907999999999, 5009.063, 4992.434, 4975.041, 4956.904, 4938.042, 4918.476, 4898.221, 4877.295, 4855.717000000001, 4833.501, 4810.665, 4787.222, 4763.189, 4738.579000000001, 4713.407, 4687.685, 4661.428, 4634.649, 4607.359, 4579.57, 4551.295, 4522.544, 4493.329000000001, 4463.661, 4433.55, 4403.005999999999, 4372.039000000001, 4340.659000000001, 4308.875, 4276.697, 4244.133, 4211.192, 4177.8820000000005, 4144.212, 4110.19, 4075.824, 4041.1209999999996, 4006.0879999999997, 3970.7340000000004, 3935.065, 3899.0890000000004, 3862.8109999999997, 3826.24, 3789.38, 3752.24, 3714.823, 3677.138, 3639.19, 3600.9840000000004, 3562.527, 3523.824, 3484.88, 3445.7009999999996, 3406.292, 3366.659, 3326.805, 3286.736, 3246.458, 3205.974, 3165.289, 3124.408, 3083.336, 3042.077, 3000.635, 2959.014, 2917.218, 2875.252, 2833.12, 2790.825, 2748.3709999999996, 2705.763, 2663.0029999999997, 2620.096, 2577.0460000000003, 2533.855, 2490.527, 2447.067, 2403.476, 2359.759, 2315.919, 2271.958, 2227.881, 2183.6910000000003, 2139.389, 2094.98, 2050.467, 2005.852, 1961.138, 1916.329, 1871.4270000000001, 1826.435, 1781.355, 1736.191, 1690.945, 1645.62, 1600.2179999999998, 1554.743, 1509.1960000000001, 1463.58, 1417.898, 1372.152, 1326.345, 1280.479, 1234.556, 1188.579, 1142.55, 1096.472, 1050.346, 1004.176, 957.9630000000001, 911.709, 865.418, 819.09, 772.7280000000001, 726.335, 679.9119999999999, 633.462, 586.987, 540.488, 493.968, 447.42900000000003, 400.87300000000005, 354.30199999999996, 307.717, 261.122, 214.518, 167.907, 121.29, 74.67, 28.049, -18.570999999999998, -65.189, -111.802, -158.409, -205.00799999999998, -251.597, -298.173, -344.736, -391.283, -437.81300000000005, -484.32300000000004, -530.812, -577.278, -623.72, -670.135, -716.5210000000001, -762.877, -809.201, -855.492, -901.7460000000001, -947.9639999999999, -994.1419999999999, -1040.28, -1086.374, -1132.425, -1178.4289999999999, -1224.385, -1270.2910000000002, -1316.146, -1361.9470000000001, -1407.694, -1453.384, -1499.015, -1544.585, -1590.094, -1635.539, -1680.918, -1726.229, -1771.4720000000002, -1816.6429999999998, -1861.7420000000002, -1906.766, -1951.714, -1996.5839999999998, -2041.3729999999998, -2086.081, -2130.706, -2175.245, -2219.697, -2264.06, -2308.3320000000003, -2352.512, -2396.597, -2440.585, -2484.476, -2528.266, -2571.955, -2615.5389999999998, -2659.018, -2702.389, -2745.651, -2788.801, -2831.837, -2874.758, -2917.562, -2960.2470000000003, -3002.81, -3045.2490000000003, -3087.5640000000003, -3129.7509999999997, -3171.809, -3213.735, -3255.528, -3297.185, -3338.705, -3380.085, -3421.322, -3462.4159999999997, -3503.363, -3544.1620000000003, -3584.81, -3625.3059999999996, -3665.6459999999997, -3705.828, -3745.8509999999997, -3785.712, -3825.409, -3864.9390000000003, -3904.2990000000004, -3943.489, -3982.5040000000004, -4021.343, -4060.0040000000004, -4098.482, -4136.777, -4174.8859999999995, -4212.805, -4250.532999999999, -4288.066, -4325.403, -4362.539000000001, -4399.474, -4436.2029999999995, -4472.724, -4509.035, -4545.130999999999, -4581.0109999999995, -4616.670999999999, -4652.109, -4687.32, -4722.304, -4757.055, -4791.571, -4825.85, -4859.887, -4893.679, -4927.223, -4960.515, -4993.553, -5026.332, -5058.849, -5091.101, -5123.083, -5154.793, -5186.227, -5217.379, -5248.2480000000005, -5278.828, -5309.115, -5339.107, -5368.798000000001, -5398.185, -5427.262, -5456.026999999999, -5484.473000000001, -5512.597, -5540.394, -5567.861, -5594.991, -5621.78, -5648.222, -5674.314, -5700.05, -5725.424, -5750.433000000001, -5775.069, -5799.328, -5823.204000000001, -5846.691, -5869.783, -5892.475, -5914.7609999999995, -5936.634, -5958.088000000001, -5979.116, -5999.7119999999995, -6019.87, -6039.581999999999, -6058.842, -6077.641, -6095.974, -6113.831999999999, -6131.209, -6148.095, -6164.483, -6180.365, -6195.732, -6210.576999999999, -6224.89, -6238.661999999999, -6251.885, -6264.548000000001, -6276.642, -6288.158, -6299.084, -6309.411999999999, -6319.13, -6328.226, -6336.691, -6344.513000000001, -6351.68, -6358.179, -6363.999, -6369.1269999999995, -6373.548000000001, -6377.251, -6380.222, -6382.445, -6383.906999999999, -6384.593000000001, -6384.486, -6383.571, -6381.831999999999, -6379.251, -6375.812, -6371.496, -6366.285, -6360.159000000001, -6353.099, -6345.085999999999, -6336.097, -6326.111, -6315.106, -6303.059, -6289.946, -6275.741999999999, -6260.423000000001, -6243.96, -6226.328, -6207.496999999999, -6187.439, -6166.1230000000005, -6143.519, -6119.593000000001, -6094.311, -6067.64, -6039.541, -6009.979, -5978.914000000001, -5946.304, -5912.108, -5876.281999999999, -5838.781, -5799.557, -5758.561, -5715.74, -5671.044, -5624.415, -5575.795999999999, -5525.1269999999995, -5472.345, -5417.385, -5360.179, -5300.656, -5238.745, -5174.366, -5107.441, -5037.887, -4965.619000000001, -4890.545999999999, -4812.576, -4731.612, -4647.556, -4560.305, -4469.752, -4375.788, -4278.302, -4177.178, -4072.3, -3963.55, -3850.809, -3733.9570000000003, -3612.8790000000004, -3487.4570000000003, -3357.5820000000003, -3223.15, -3084.067, -2940.2470000000003, -2791.625, -2638.151, -2479.801, -2316.578, -2148.52, -1975.705, -1798.2579999999998, -1616.3529999999998, -1430.223, -1240.162, -1046.531, -849.755, -650.328, -448.80400000000003, -245.795, -41.958, 162.016, 365.414, 567.523, 767.64, 965.096, 1159.26, 1349.5639999999999, 1535.499, 1716.631, 1892.599, 2063.115, 2227.962, 2386.99, 2540.107, 2687.276, 2828.505, 2963.844, 3093.3709999999996, 3217.1940000000004, 3335.438, 3448.2470000000003, 3555.775, 3658.185, 3755.6409999999996, 3848.315, 3936.375, 4019.989, 4099.3240000000005, 4174.541, 4245.798, 4313.249, 4377.041, 4437.393, 4494.215999999999, 4547.867, 4598.398, 4645.931, 4690.579000000001, 4732.455, 4771.663, 4808.305, 4842.476, 4874.27, 4903.772, 4931.068, 4956.236, 4979.353, 5000.492, 5019.722, 5037.11, 5052.718, 5066.607, 5078.835999999999, 5089.46, 5098.53, 5106.099, 5112.214, 5116.9220000000005, 5120.267, 5122.292, 5123.039000000001, 5122.545999999999, 5120.85, 5117.9890000000005, 5113.995, 5108.905, 5102.747, 5095.555, 5087.358, 5078.183, 5068.059, 5057.012, 5045.067, 5032.25, 5018.583, 5004.09, 4988.793, 4972.713, 4955.87, 4938.286, 4919.978, 4900.965, 4881.266, 4860.898, 4839.877, 4818.221, 4795.944, 4773.062, 4749.589, 4725.542, 4700.932, 4675.774, 4650.081, 4623.866, 4597.14, 4569.917, 4542.207, 4514.022, 4485.373, 4456.271, 4426.726, 4396.749, 4366.348, 4335.535, 4304.318, 4272.706, 4240.708, 4208.334, 4175.59, 4142.486, 4109.03, 4075.2290000000003, 4041.092, 4006.625, 3971.836, 3936.7309999999998, 3901.3190000000004, 3865.605, 3829.5959999999995, 3793.3, 3756.7209999999995, 3719.867, 3682.744, 3645.3559999999998, 3607.711, 3569.813, 3531.6679999999997, 3493.283, 3454.6620000000003, 3415.81, 3376.732, 3337.434, 3297.92, 3258.196, 3218.265, 3178.133, 3137.803, 3097.282, 3056.572, 3015.679, 2974.6059999999998, 2933.357, 2891.938, 2850.35, 2808.6, 2766.69, 2724.623, 2682.405, 2640.039, 2597.527, 2554.874, 2512.084, 2469.159, 2426.103, 2382.919, 2339.612, 2296.183, 2252.636, 2208.974, 2165.2, 2121.3179999999998, 2077.33, 2033.239, 1989.0479999999998, 1944.761, 1900.379, 1855.906, 1811.344, 1766.6960000000001, 1721.965, 1677.154, 1632.264, 1587.3, 1542.2620000000002, 1497.154, 1451.979, 1406.7379999999998, 1361.435, 1316.0710000000001, 1270.649, 1225.171, 1179.64, 1134.058, 1088.427, 1042.75, 997.029, 951.2660000000001, 905.4630000000001, 859.622, 813.7460000000001, 767.837, 721.8960000000001, 675.926, 629.93, 583.908, 537.864, 491.79900000000004, 445.715, 399.615, 353.499, 307.371, 261.232, 215.085, 168.93, 122.77, 76.608, 30.444000000000003, -15.719000000000001, -61.88, -108.036, -154.186, -200.327, -246.458, -292.578, -338.68300000000005, -384.773, -430.846, -476.899, -522.932, -568.941, -614.9259999999999, -660.885, -706.815, -752.715, -798.584, -844.419, -890.2189999999999, -935.982, -981.706, -1027.389, -1073.03, -1118.627, -1164.1789999999999, -1209.682, -1255.136, -1300.539, -1345.89, -1391.1860000000001, -1436.425, -1481.606, -1526.7279999999998, -1571.7879999999998, -1616.7839999999999, -1661.7160000000001, -1706.58, -1751.376, -1796.102, -1840.755, -1885.3339999999998, -1929.838, -1974.264, -2018.612, -2062.877, -2107.061, -2151.159, -2195.1710000000003, -2239.095, -2282.928, -2326.67, -2370.3179999999998, -2413.87, -2457.325, -2500.68, -2543.935, -2587.0860000000002, -2630.132, -2673.071, -2715.902, -2758.6220000000003, -2801.2290000000003, -2843.7209999999995, -2886.098, -2928.355, -2970.493, -3012.507, -3054.3979999999997, -3096.1620000000003, -3137.797, -3179.302, -3220.675, -3261.9120000000003, -3303.013, -3343.975, -3384.796, -3425.474, -3466.006, -3506.3909999999996, -3546.6259999999997, -3586.7090000000003, -3626.638, -3666.4109999999996, -3706.025, -3745.4770000000003, -3784.7670000000003, -3823.8909999999996, -3862.8459999999995, -3901.632, -3940.244, -3978.6809999999996, -4016.94, -4055.018, -4092.914, -4130.624, -4168.146, -4205.478, -4242.616, -4279.558, -4316.302, -4352.844, -4389.182, -4425.313, -4461.234, -4496.943, -4532.435, -4567.71, -4602.762, -4637.59, -4672.19, -4706.559, -4740.694, -4774.592000000001, -4808.25, -4841.664000000001, -4874.831, -4907.747, -4940.409000000001, -4972.814, -5004.958, -5036.837, -5068.447, -5099.786, -5130.85, -5161.633, -5192.134, -5222.347, -5252.268, -5281.894, -5311.22, -5340.241999999999, -5368.956, -5397.357, -5425.441999999999, -5453.205, -5480.642, -5507.7480000000005, -5534.518, -5560.948, -5587.033, -5612.767, -5638.146, -5663.164000000001, -5687.816, -5712.096, -5736.0, -5759.521, -5782.653, -5805.391, -5827.729, -5849.66, -5871.179, -5892.279, -5912.954000000001, -5933.196, -5953.0, -5972.358, -5991.263000000001, -6009.7080000000005, -6027.686, -6045.189, -6062.209, -6078.7390000000005, -6094.769, -6110.294, -6125.303000000001, -6139.7880000000005, -6153.741, -6167.151, -6180.0109999999995, -6192.31, -6204.039000000001, -6215.187, -6225.745, -6235.703, -6245.048000000001, -6253.77, -6261.859, -6269.302, -6276.0869999999995, -6282.201999999999, -6287.635, -6292.371999999999, -6296.401, -6299.7080000000005, -6302.278, -6304.097, -6305.151, -6305.424, -6304.9, -6303.563, -6301.396, -6298.383000000001, -6294.505999999999, -6289.745, -6284.0830000000005, -6277.5, -6269.976, -6261.491, -6252.022, -6241.548000000001, -6230.045999999999, -6217.493, -6203.8640000000005, -6189.134, -6173.276999999999, -6156.266, -6138.073, -6118.67, -6098.026999999999, -6076.111, -6052.892, -6028.335, -6002.406999999999, -5975.071999999999, -5946.2919999999995, -5916.029, -5884.241999999999, -5850.89, -5815.93, -5779.316999999999, -5741.004, -5700.941999999999, -5659.08, -5615.366999999999, -5569.746, -5522.161, -5472.553000000001, -5420.86, -5367.017, -5310.956999999999, -5252.611, -5191.906, -5128.766, -5063.112, -4994.863, -4923.933, -4850.234, -4773.675, -4694.16, -4611.590999999999, -4525.866, -4436.879, -4344.523, -4248.687, -4149.255999999999, -4046.117, -3939.1490000000003, -3828.236, -3713.259, -3594.1, -3470.647, -3342.7859999999996, -3210.413, -3073.434, -2931.763, -2785.3309999999997, -2634.086, -2478.0, -2317.073, -2151.339, -1980.868, -1805.777, -1626.234, -1442.463, -1254.747, -1063.434, -868.941, -671.7460000000001, -472.394, -271.483, -69.65899999999999, 132.39600000000002, 333.97900000000004, 534.382, 732.909, 928.8910000000001, 1121.702, 1310.769, 1495.5829999999999, 1675.705, 1850.7679999999998, 2020.48, 2184.619, 2343.025, 2495.604, 2642.31, 2783.147, 2918.158, 3047.4159999999997, 3171.025, 3289.1059999999998, 3401.798, 3509.252, 3611.6259999999997, 3709.085, 3801.7940000000003, 3889.921, 3973.632, 4053.09, 4128.456, 4199.885, 4267.531, 4331.538, 4392.05, 4449.202, 4503.125, 4553.943, 4601.778, 4646.744000000001, 4688.951, 4728.504, 4765.502, 4800.042, 4832.215, 4862.108, 4889.804, 4915.383, 4938.92, 4960.487, 4980.154, 4997.987, 5014.0470000000005, 5028.396, 5041.090999999999, 5052.187, 5061.737, 5069.792, 5076.398, 5081.603, 5085.45, 5087.983, 5089.242, 5089.266, 5088.090999999999, 5085.755, 5082.292, 5077.734, 5072.115, 5065.463, 5057.81, 5049.183, 5039.61, 5029.117, 5017.728, 5005.47, 4992.366, 4978.437, 4963.707, 4948.197, 4931.925, 4914.914000000001, 4897.182, 4878.747, 4859.627, 4839.84, 4819.402, 4798.329000000001, 4776.638, 4754.343, 4731.459, 4708.001, 4683.982, 4659.416, 4634.315, 4608.694, 4582.563, 4555.935, 4528.821, 4501.234, 4473.183, 4444.679, 4415.733, 4386.355, 4356.555, 4326.342000000001, 4295.726, 4264.715, 4233.319, 4201.545999999999, 4169.404, 4136.902, 4104.049, 4070.85, 4037.315, 4003.45, 3969.263, 3934.761, 3899.9509999999996, 3864.8390000000004, 3829.433, 3793.738, 3757.761, 3721.508, 3684.985, 3648.198, 3611.153, 3573.855, 3536.3109999999997, 3498.5240000000003, 3460.502, 3422.248, 3383.768, 3345.067, 3306.15, 3267.0209999999997, 3227.6859999999997, 3188.1479999999997, 3148.413, 3108.485, 3068.368, 3028.067, 2987.585, 2946.927, 2906.097, 2865.099, 2823.937, 2782.614, 2741.134, 2699.5009999999997, 2657.719, 2615.791, 2573.721, 2531.513, 2489.1679999999997, 2446.692, 2404.087, 2361.357, 2318.505, 2275.533, 2232.446, 2189.245, 2145.935, 2102.518, 2058.998, 2015.376, 1971.655, 1927.84, 1883.932, 1839.934, 1795.849, 1751.6789999999999, 1707.4279999999999, 1663.0970000000002, 1618.69, 1574.2089999999998, 1529.656, 1485.0339999999999, 1440.345, 1395.592, 1350.777, 1305.903, 1260.971, 1215.985, 1170.947, 1125.858, 1080.721, 1035.539, 990.313, 945.045, 899.7389999999999, 854.3960000000001, 809.0169999999999, 763.6060000000001, 718.164, 672.694, 627.197, 581.6759999999999, 536.132, 490.56800000000004, 444.985, 399.38599999999997, 353.772, 308.14599999999996, 262.509, 216.863, 171.21099999999998, 125.554, 79.893, 34.232, -11.427999999999999, -57.086000000000006, -102.74, -148.387, -194.02599999999998, -239.65400000000002, -285.27099999999996, -330.875, -376.463, -422.033, -467.585, -513.116, -558.624, -604.1080000000001, -649.566, -694.9960000000001, -740.3960000000001, -785.765, -831.1, -876.4010000000001, -921.665, -966.8910000000001, -1012.077, -1057.22, -1102.32, -1147.375, -1192.383, -1237.3410000000001, -1282.25, -1327.106, -1371.9070000000002, -1416.654, -1461.342, -1505.9720000000002, -1550.54, -1595.046, -1639.487, -1683.8629999999998, -1728.17, -1772.408, -1816.5739999999998, -1860.6670000000001, -1904.685, -1948.626, -1992.489, -2036.271, -2079.972, -2123.5879999999997, -2167.119, -2210.562, -2253.917, -2297.18, -2340.35, -2383.425, -2426.404, -2469.285, -2512.065, -2554.743, -2597.317, -2639.785, -2682.145, -2724.3959999999997, -2766.535, -2808.5609999999997, -2850.4709999999995, -2892.263, -2933.9359999999997, -2975.488, -3016.917, -3058.22, -3099.395, -3140.441, -3181.3559999999998, -3222.137, -3262.782, -3303.29, -3343.657, -3383.883, -3423.965, -3463.9, -3503.6859999999997, -3543.322, -3582.804, -3622.132, -3661.301, -3700.3109999999997, -3739.159, -3777.842, -3816.3579999999997, -3854.7059999999997, -3892.881, -3930.882, -3968.7070000000003, -4006.353, -4043.817, -4081.0959999999995, -4118.189, -4155.092000000001, -4191.804, -4228.321, -4264.64, -4300.759, -4336.675, -4372.3859999999995, -4407.888, -4443.178, -4478.254, -4513.113, -4547.751, -4582.166, -4616.355, -4650.313, -4684.04, -4717.53, -4750.781, -4783.79, -4816.552, -4849.066, -4881.326, -4913.331, -4945.075, -4976.557, -5007.771, -5038.715, -5069.384, -5099.775, -5129.884, -5159.706, -5189.238, -5218.475, -5247.414000000001, -5276.0509999999995, -5304.38, -5332.398, -5360.1, -5387.481, -5414.5380000000005, -5441.264, -5467.656, -5493.709, -5519.418000000001, -5544.776999999999, -5569.781, -5594.425, -5618.704000000001, -5642.613, -5666.145, -5689.295999999999, -5712.059, -5734.428000000001, -5756.398, -5777.9619999999995, -5799.1140000000005, -5819.847, -5840.156, -5860.034000000001, -5879.472, -5898.465999999999, -5917.005999999999, -5935.0869999999995, -5952.701, -5969.840999999999, -5986.496999999999, -6002.6630000000005, -6018.33, -6033.491, -6048.1359999999995, -6062.257, -6075.844, -6088.89, -6101.384, -6113.316, -6124.678000000001, -6135.4580000000005, -6145.647, -6155.234, -6164.206999999999, -6172.557, -6180.271, -6187.3369999999995, -6193.744000000001, -6199.48, -6204.531, -6208.883000000001, -6212.525, -6215.441999999999, -6217.62, -6219.043000000001, -6219.698, -6219.569, -6218.639, -6216.891, -6214.31, -6210.878000000001, -6206.576, -6201.3859999999995, -6195.289000000001, -6188.266, -6180.295, -6171.355, -6161.4259999999995, -6150.485, -6138.507, -6125.47, -6111.348000000001, -6096.116, -6079.746999999999, -6062.214, -6043.488, -6023.54, -6002.339, -5979.853, -5956.05, -5930.895, -5904.354, -5876.389, -5846.9619999999995, -5816.034000000001, -5783.564, -5749.509, -5713.825, -5676.465, -5637.380999999999, -5596.524, -5553.840999999999, -5509.279, -5462.781, -5414.2880000000005, -5363.7390000000005, -5311.071999999999, -5256.219, -5199.111, -5139.678, -5077.844, -5013.532, -4946.66, -4877.145, -4804.899, -4729.832, -4651.85, -4570.855, -4486.747, -4399.42, -4308.77, -4214.685, -4117.053, -4015.759, -3910.6859999999997, -3801.718, -3688.736, -3571.623, -3450.2659999999996, -3324.552, -3194.377, -3059.645, -2920.27, -2776.1809999999996, -2627.323, -2473.666, -2315.2039999999997, -2151.966, -1984.017, -1811.4679999999998, -1634.477, -1453.257, -1268.0839999999998, -1079.2930000000001, -887.2869999999999, -692.535, -495.566, -296.967, -97.37100000000001, 102.54899999999999, 302.10200000000003, 500.586, 697.312, 891.613, 1082.866, 1270.496, 1453.994, 1632.9170000000001, 1806.894, 1975.6270000000002, 2138.887, 2296.511, 2448.394, 2594.489, 2734.7909999999997, 2869.3379999999997, 2998.198, 3121.47, 3239.27, 3351.7340000000004, 3459.008, 3561.248, 3658.613, 3751.268, 3839.377, 3923.103, 4002.6090000000004, 4078.052, 4149.585999999999, 4217.363, 4281.526, 4342.215999999999, 4399.569, 4453.713, 4504.772, 4552.866, 4598.109, 4640.609, 4680.471, 4717.794, 4752.6720000000005, 4785.198, 4815.456, 4843.53, 4869.497, 4893.434, 4915.413, 4935.501, 4953.765, 4970.266, 4985.065, 4998.218, 5009.782, 5019.806, 5028.342000000001, 5035.438, 5041.14, 5045.49, 5048.532, 5050.306, 5050.851, 5050.204000000001, 5048.4, 5045.475, 5041.46, 5036.388, 5030.288, 5023.191, 5015.125, 5006.116, 4996.192, 4985.377, 4973.695, 4961.17, 4947.8240000000005, 4933.68, 4918.758, 4903.079000000001, 4886.663, 4869.528, 4851.693, 4833.1759999999995, 4813.994000000001, 4794.163, 4773.7, 4752.619000000001, 4730.938, 4708.669, 4685.8279999999995, 4662.428, 4638.482, 4614.004, 4589.005999999999, 4563.5, 4537.498, 4511.012, 4484.053, 4456.6320000000005, 4428.759, 4400.445, 4371.6990000000005, 4342.532999999999, 4312.955, 4282.974, 4252.599, 4221.84, 4190.704000000001, 4159.201, 4127.337, 4095.1220000000003, 4062.563, 4029.667, 3996.4429999999998, 3962.8959999999997, 3929.034, 3894.865, 3860.3940000000002, 3825.6279999999997, 3790.575, 3755.239, 3719.627, 3683.745, 3647.599, 3611.195, 3574.538, 3537.634, 3500.488, 3463.105, 3425.491, 3387.651, 3349.59, 3311.3109999999997, 3272.821, 3234.1240000000003, 3195.224, 3156.1259999999997, 3116.835, 3077.3540000000003, 3037.688, 2997.842, 2957.8179999999998, 2917.6220000000003, 2877.257, 2836.7270000000003, 2796.0359999999996, 2755.187, 2714.185, 2673.032, 2631.7329999999997, 2590.291, 2548.71, 2506.992, 2465.141, 2423.161, 2381.054, 2338.824, 2296.474, 2254.007, 2211.427, 2168.735, 2125.935, 2083.031, 2040.024, 1996.918, 1953.7160000000001, 1910.42, 1867.0320000000002, 1823.557, 1779.996, 1736.352, 1692.6270000000002, 1648.8239999999998, 1604.9460000000001, 1560.996, 1516.974, 1472.885, 1428.73, 1384.5120000000002, 1340.233, 1295.896, 1251.503, 1207.055, 1162.556, 1118.007, 1073.412, 1028.771, 984.087, 939.363, 894.6, 849.801, 804.967, 760.1010000000001, 715.205, 670.2810000000001, 625.331, 580.356, 535.359, 490.343, 445.30800000000005, 400.256, 355.191, 310.113, 265.024, 219.92700000000002, 174.824, 129.715, 84.604, 39.491, -5.621, -50.73, -95.835, -140.933, -186.023, -231.104, -276.173, -321.228, -366.269, -411.292, -456.296, -501.28, -546.242, -591.18, -636.091, -680.9760000000001, -725.831, -770.655, -815.446, -860.203, -904.924, -949.607, -994.25, -1038.8519999999999, -1083.411, -1127.925, -1172.392, -1216.8110000000001, -1261.181, -1305.499, -1349.763, -1393.973, -1438.125, -1482.219, -1526.253, -1570.225, -1614.134, -1657.976, -1701.7520000000002, -1745.4589999999998, -1789.095, -1832.6589999999999, -1876.149, -1919.5629999999999, -1962.9, -2006.1570000000002, -2049.333, -2092.426, -2135.4339999999997, -2178.356, -2221.189, -2263.933, -2306.584, -2349.1420000000003, -2391.604, -2433.97, -2476.235, -2518.4, -2560.462, -2602.419, -2644.27, -2686.012, -2727.643, -2769.1620000000003, -2810.567, -2851.8559999999998, -2893.026, -2934.0759999999996, -2975.0040000000004, -3015.808, -3056.486, -3097.035, -3137.454, -3177.741, -3217.8940000000002, -3257.91, -3297.7870000000003, -3337.5240000000003, -3377.118, -3416.567, -3455.868, -3495.02, -3534.0209999999997, -3572.867, -3611.558, -3650.09, -3688.461, -3726.67, -3764.7129999999997, -3802.5879999999997, -3840.2929999999997, -3877.825, -3915.1820000000002, -3952.361, -3989.36, -4026.176, -4062.8070000000002, -4099.25, -4135.503, -4171.563, -4207.4259999999995, -4243.090999999999, -4278.555, -4313.814, -4348.867, -4383.709, -4418.339, -4452.753, -4486.947, -4520.920999999999, -4554.669, -4588.189, -4621.478, -4654.532999999999, -4687.35, -4719.927, -4752.258, -4784.343, -4816.1759999999995, -4847.754, -4879.0740000000005, -4910.133, -4940.9259999999995, -4971.45, -5001.701, -5031.675, -5061.369000000001, -5090.778, -5119.898, -5148.725, -5177.255, -5205.484, -5233.407999999999, -5261.021, -5288.32, -5315.3009999999995, -5341.956999999999, -5368.285, -5394.28, -5419.937, -5445.251, -5470.218000000001, -5494.831, -5519.085, -5542.975, -5566.496, -5589.642, -5612.408, -5634.786999999999, -5656.774, -5678.363, -5699.545999999999, -5720.319, -5740.675, -5760.606, -5780.108, -5799.170999999999, -5817.791, -5835.9580000000005, -5853.6669999999995, -5870.909000000001, -5887.677, -5903.963000000001, -5919.759, -5935.057, -5949.849, -5964.125, -5977.878000000001, -5991.098000000001, -6003.775, -6015.901, -6027.465999999999, -6038.459, -6048.871999999999, -6058.691999999999, -6067.909000000001, -6076.513000000001, -6084.493, -6091.835999999999, -6098.53, -6104.564, -6109.9259999999995, -6114.6, -6118.576, -6121.839, -6124.375, -6126.169, -6127.2080000000005, -6127.475, -6126.955, -6125.630999999999, -6123.486999999999, -6120.505999999999, -6116.67, -6111.96, -6106.359, -6099.845, -6092.4, -6084.003000000001, -6074.630999999999, -6064.263000000001, -6052.8769999999995, -6040.448, -6026.951999999999, -6012.363, -5996.656, -5979.803000000001, -5961.776999999999, -5942.548000000001, -5922.085999999999, -5900.36, -5877.338000000001, -5852.986, -5827.268, -5800.15, -5771.594, -5741.56, -5710.008000000001, -5676.897, -5642.181, -5605.815, -5567.754, -5527.946999999999, -5486.342, -5442.888000000001, -5397.526999999999, -5350.201999999999, -5300.855, -5249.42, -5195.834, -5140.028, -5081.931, -5021.471, -4958.57, -4893.148, -4825.122, -4754.407999999999, -4680.914000000001, -4604.548, -4525.214, -4442.813, -4357.241, -4268.393, -4176.16, -4080.43, -3981.09, -3878.0240000000003, -3771.116, -3660.2490000000003, -3545.3059999999996, -3426.1740000000004, -3302.741, -3174.902, -3042.5609999999997, -2905.631, -2764.0370000000003, -2617.724, -2466.658, -2310.83, -2150.262, -1985.016, -1815.192, -1640.942, -1462.47, -1280.038, -1093.973, -904.665, -712.567, -518.196, -322.126, -124.977, 72.589, 269.892, 466.23900000000003, 660.947, 853.3539999999999, 1042.838, 1228.827, 1410.809, 1588.3370000000002, 1761.039, 1928.61, 2090.8160000000003, 2247.487, 2398.514, 2543.841, 2683.46, 2817.401, 2945.728, 3068.534, 3185.9309999999996, 3298.0490000000004, 3405.033, 3507.033, 3604.205, 3696.71, 3784.712, 3868.369, 3947.842, 4023.2859999999996, 4094.8540000000003, 4162.693, 4226.9490000000005, 4287.734, 4345.255, 4399.567, 4450.817, 4499.124, 4544.601, 4587.354, 4627.488, 4665.1, 4700.284000000001, 4733.1320000000005, 4763.728, 4792.154, 4818.488, 4842.805, 4865.1759999999995, 4885.668, 4904.349, 4921.278, 4936.515, 4950.117, 4962.139, 4972.6320000000005, 4981.645, 4989.227, 4995.4220000000005, 5000.275, 5003.8279999999995, 5006.119000000001, 5007.189, 5007.0740000000005, 5005.808, 5003.427, 4999.963, 4995.447, 4989.911, 4983.380999999999, 4975.888, 4967.457, 4958.115, 4947.888, 4936.798, 4924.87, 4912.124, 4898.585, 4884.272, 4869.204000000001, 4853.404, 4836.888, 4819.675, 4801.782999999999, 4783.23, 4764.03, 4744.202, 4723.759, 4702.715999999999, 4681.09, 4658.893, 4636.14, 4612.843, 4589.015, 4564.67, 4539.819, 4514.474, 4488.647, 4462.348, 4435.588, 4408.379, 4380.73, 4352.65, 4324.151, 4295.241, 4265.93, 4236.227, 4206.14, 4175.677, 4144.847, 4113.659000000001, 4082.119, 4050.236, 4018.018, 3985.4709999999995, 3952.603, 3919.42, 3885.93, 3852.139, 3818.054, 3783.68, 3749.025, 3714.095, 3678.8940000000002, 3643.43, 3607.708, 3571.7329999999997, 3535.511, 3499.047, 3462.3459999999995, 3425.414, 3388.256, 3350.8759999999997, 3313.2790000000005, 3275.4709999999995, 3237.455, 3199.237, 3160.82, 3122.208, 3083.408, 3044.422, 3005.2540000000004, 2965.909, 2926.3909999999996, 2886.704, 2846.8520000000003, 2806.837, 2766.665, 2726.3379999999997, 2685.861, 2645.236, 2604.468, 2563.5589999999997, 2522.514, 2481.334, 2440.025, 2398.5879999999997, 2357.027, 2315.346, 2273.5460000000003, 2231.632, 2189.606, 2147.471, 2105.23, 2062.886, 2020.441, 1977.899, 1935.2620000000002, 1892.533, 1849.715, 1806.81, 1763.8210000000001, 1720.75, 1677.6, 1634.3729999999998, 1591.0720000000001, 1547.7, 1504.2579999999998, 1460.75, 1417.1770000000001, 1373.5420000000001, 1329.8470000000002, 1286.094, 1242.286, 1198.4260000000002, 1154.514, 1110.553, 1066.546, 1022.495, 978.4019999999999, 934.268, 890.097, 845.8889999999999, 801.648, 757.375, 713.072, 668.742, 624.385, 580.005, 535.6030000000001, 491.181, 446.741, 402.285, 357.814, 313.332, 268.839, 224.338, 179.83, 135.317, 90.801, 46.285, 1.768, -42.745, -87.255, -131.75799999999998, -176.253, -220.739, -265.214, -309.675, -354.121, -398.551, -442.962, -487.353, -531.722, -576.067, -620.387, -664.68, -708.945, -753.178, -797.38, -841.548, -885.68, -929.775, -973.83, -1017.846, -1061.818, -1105.747, -1149.63, -1193.465, -1237.251, -1280.986, -1324.6689999999999, -1368.297, -1411.87, -1455.384, -1498.84, -1542.234, -1585.566, -1628.8329999999999, -1672.0339999999999, -1715.1660000000002, -1758.23, -1801.2220000000002, -1844.14, -1886.984, -1929.7520000000002, -1972.441, -2015.05, -2057.577, -2100.021, -2142.379, -2184.65, -2226.8320000000003, -2268.924, -2310.923, -2352.827, -2394.636, -2436.347, -2477.958, -2519.467, -2560.873, -2602.173, -2643.366, -2684.45, -2725.423, -2766.283, -2807.028, -2847.656, -2888.1659999999997, -2928.554, -2968.82, -3008.961, -3048.9759999999997, -3088.861, -3128.616, -3168.238, -3207.725, -3247.075, -3286.2859999999996, -3325.3559999999998, -3364.282, -3403.062, -3441.695, -3480.178, -3518.508, -3556.683, -3594.702, -3632.562, -3670.26, -3707.795, -3745.163, -3782.363, -3819.3920000000003, -3856.248, -3892.928, -3929.429, -3965.7490000000003, -4001.886, -4037.837, -4073.599, -4109.169, -4144.545999999999, -4179.725, -4214.705, -4249.483, -4284.055, -4318.419, -4352.572, -4386.5109999999995, -4420.234, -4453.736, -4487.016, -4520.069, -4552.893, -4585.485, -4617.840999999999, -4649.957, -4681.831, -4713.46, -4744.839, -4775.965999999999, -4806.837, -4837.447, -4867.795, -4897.875, -4927.683, -4957.217000000001, -4986.472, -5015.444, -5044.13, -5072.525, -5100.625, -5128.425, -5155.9220000000005, -5183.11, -5209.986, -5236.545, -5262.783, -5288.694, -5314.274, -5339.518, -5364.42, -5388.977, -5413.182, -5437.03, -5460.516, -5483.634, -5506.379, -5528.746, -5550.728, -5572.319, -5593.513000000001, -5614.304, -5634.687, -5654.653, -5674.196999999999, -5693.312, -5711.991, -5730.227, -5748.013000000001, -5765.342, -5782.205, -5798.596, -5814.505, -5829.9259999999995, -5844.85, -5859.269, -5873.173000000001, -5886.555, -5899.404, -5911.7119999999995, -5923.469, -5934.666, -5945.2919999999995, -5955.3369999999995, -5964.791, -5973.642, -5981.88, -5989.494000000001, -5996.471, -6002.798000000001, -6008.465999999999, -6013.46, -6017.767, -6021.375, -6024.268, -6026.434, -6027.857, -6028.522, -6028.415, -6027.518, -6025.816, -6023.291, -6019.927, -6015.705, -6010.606, -6004.611999999999, -5997.703, -5989.858, -5981.056, -5971.276, -5960.494000000001, -5948.689, -5935.834, -5921.906999999999, -5906.88, -5890.729, -5873.424, -5854.937, -5835.238, -5814.297, -5792.0830000000005, -5768.561, -5743.698, -5717.459, -5689.805, -5660.6990000000005, -5630.101, -5597.97, -5564.262, -5528.933000000001, -5491.937, -5453.224, -5412.744000000001, -5370.445, -5326.273, -5280.169, -5232.076, -5181.931, -5129.670999999999, -5075.228, -5018.532, -4959.5109999999995, -4898.09, -4834.19, -4767.729, -4698.622, -4626.781, -4552.1140000000005, -4474.528, -4393.9220000000005, -4310.197, -4223.247, -4132.965, -4039.241, -3941.962, -3841.014, -3736.282, -3627.6479999999997, -3514.9990000000003, -3398.219, -3277.199, -3151.8340000000003, -3022.026, -2887.685, -2748.739, -2605.129, -2456.817, -2303.79, -2146.067, -1983.701, -1816.7879999999998, -1645.4679999999998, -1469.9379999999999, -1290.45, -1107.316, -920.913, -731.682, -540.127, -346.806, -152.327, 42.663000000000004, 237.493, 431.47900000000004, 623.947, 814.2410000000001, 1001.7410000000001, 1185.877, 1366.135, 1542.069, 1713.299, 1879.5179999999998, 2040.486, 2196.028, 2346.029, 2490.427, 2629.2059999999997, 2762.3920000000003, 2890.0440000000003, 3012.248, 3129.112, 3240.763, 3347.3390000000004, 3448.987, 3545.861, 3638.117, 3725.9159999999997, 3809.414, 3888.7690000000002, 3964.134, 4035.659, 4103.491, 4167.77, 4228.634, 4286.215, 4340.639, 4392.028, 4440.498, 4486.161, 4529.123, 4569.487, 4607.351, 4642.807, 4675.944, 4706.847, 4735.597, 4762.272, 4786.946, 4809.688, 4830.566, 4849.646, 4866.987, 4882.65, 4896.69, 4909.16, 4920.112, 4929.597, 4937.66, 4944.346, 4949.7, 4953.762, 4956.572, 4958.168, 4958.588, 4957.866, 4956.035, 4953.129, 4949.178, 4944.213, 4938.262, 4931.353, 4923.513, 4914.768, 4905.142, 4894.659000000001, 4883.343, 4871.215999999999, 4858.298, 4844.612, 4830.177, 4815.012, 4799.137, 4782.568, 4765.325, 4747.423, 4728.878, 4709.708, 4689.928, 4669.5509999999995, 4648.593, 4627.067, 4604.9890000000005, 4582.369000000001, 4559.221, 4535.558, 4511.392, 4486.735, 4461.597, 4435.99, 4409.924, 4383.41, 4356.458, 4329.0779999999995, 4301.281, 4273.0740000000005, 4244.467000000001, 4215.469, 4186.089, 4156.335, 4126.215, 4095.738, 4064.9109999999996, 4033.742, 4002.238, 3970.407, 3938.255, 3905.79, 3873.018, 3839.946, 3806.5809999999997, 3772.928, 3738.994, 3704.785, 3670.3070000000002, 3635.565, 3600.566, 3565.315, 3529.816, 3494.0759999999996, 3458.1, 3421.893, 3385.4590000000003, 3348.804, 3311.9320000000002, 3274.848, 3237.5570000000002, 3200.063, 3162.3709999999996, 3124.4840000000004, 3086.408, 3048.1459999999997, 3009.703, 2971.0820000000003, 2932.288, 2893.324, 2854.1940000000004, 2814.902, 2775.4509999999996, 2735.8459999999995, 2696.09, 2656.185, 2616.137, 2575.947, 2535.621, 2495.159, 2454.567, 2413.847, 2373.002, 2332.036, 2290.951, 2249.751, 2208.438, 2167.015, 2125.485, 2083.8520000000003, 2042.1170000000002, 2000.283, 1958.354, 1916.332, 1874.219, 1832.0179999999998, 1789.7320000000002, 1747.364, 1704.915, 1662.388, 1619.786, 1577.111, 1534.366, 1491.5529999999999, 1448.674, 1405.731, 1362.7279999999998, 1319.665, 1276.546, 1233.372, 1190.146, 1146.871, 1103.547, 1060.177, 1016.7639999999999, 973.309, 929.815, 886.283, 842.716, 799.115, 755.4839999999999, 711.822, 668.133, 624.419, 580.681, 536.922, 493.14300000000003, 449.346, 405.533, 361.70599999999996, 317.867, 274.018, 230.16, 186.295, 142.42600000000002, 98.554, 54.68, 10.807, -33.064, -76.93, -120.791, -164.644, -208.488, -252.321, -296.14099999999996, -339.94599999999997, -383.735, -427.506, -471.25800000000004, -514.987, -558.694, -602.376, -646.031, -689.659, -733.2560000000001, -776.822, -820.3539999999999, -863.852, -907.313, -950.735, -994.118, -1037.4589999999998, -1080.756, -1124.009, -1167.215, -1210.373, -1253.48, -1296.536, -1339.539, -1382.486, -1425.3770000000002, -1468.21, -1510.9820000000002, -1553.692, -1596.34, -1638.922, -1681.4370000000001, -1723.8829999999998, -1766.26, -1808.5639999999999, -1850.795, -1892.95, -1935.0279999999998, -1977.0279999999998, -2018.9460000000001, -2060.783, -2102.535, -2144.202, -2185.781, -2227.27, -2268.669, -2309.974, -2351.185, -2392.299, -2433.315, -2474.231, -2515.044, -2555.754, -2596.357, -2636.853, -2677.24, -2717.515, -2757.677, -2797.724, -2837.653, -2877.4629999999997, -2917.152, -2956.719, -2996.16, -3035.474, -3074.658, -3113.712, -3152.632, -3191.417, -3230.065, -3268.573, -3306.94, -3345.1620000000003, -3383.238, -3421.167, -3458.945, -3496.57, -3534.04, -3571.353, -3608.506, -3645.498, -3682.3259999999996, -3718.987, -3755.478, -3791.7990000000004, -3827.945, -3863.915, -3899.7070000000003, -3935.316, -3970.742, -4005.9809999999998, -4041.03, -4075.888, -4110.55, -4145.015, -4179.28, -4213.342000000001, -4247.198, -4280.845, -4314.28, -4347.501, -4380.503, -4413.285, -4445.844, -4478.174, -4510.275, -4542.142, -4573.772, -4605.163, -4636.309, -4667.209, -4697.859, -4728.254, -4758.392, -4788.269, -4817.880999999999, -4847.223, -4876.294, -4905.088, -4933.601, -4961.831, -4989.771, -5017.419, -5044.77, -5071.819, -5098.563, -5124.996, -5151.115, -5176.915, -5202.391, -5227.537, -5252.35, -5276.8240000000005, -5300.954000000001, -5324.735, -5348.161, -5371.228, -5393.93, -5416.26, -5438.214, -5459.786, -5480.969, -5501.757, -5522.145, -5542.126, -5561.693, -5580.84, -5599.56, -5617.846, -5635.691, -5653.088000000001, -5670.03, -5686.508000000001, -5702.515, -5718.044, -5733.085, -5747.632, -5761.674, -5775.205, -5788.214, -5800.691999999999, -5812.630999999999, -5824.02, -5834.85, -5845.111, -5854.7919999999995, -5863.882, -5872.371999999999, -5880.249, -5887.5019999999995, -5894.12, -5900.089, -5905.399, -5910.035, -5913.984, -5917.234, -5919.771, -5921.578, -5922.644, -5922.951, -5922.485, -5921.228, -5919.164000000001, -5916.278, -5912.55, -5907.9619999999995, -5902.496, -5896.132, -5888.85, -5880.63, -5871.45, -5861.286999999999, -5850.121, -5837.925, -5824.6759999999995, -5810.349, -5794.918000000001, -5778.355, -5760.633000000001, -5741.721, -5721.590999999999, -5700.210999999999, -5677.548000000001, -5653.568, -5628.238, -5601.52, -5573.376, -5543.768, -5512.655, -5479.995, -5445.743, -5409.854, -5372.28, -5332.972, -5291.878000000001, -5248.944, -5204.115, -5157.332, -5108.534000000001, -5057.657999999999, -5004.64, -4949.409000000001, -4891.895, -4832.023, -4769.715999999999, -4704.894, -4637.474, -4567.366, -4494.483, -4418.731, -4340.0109999999995, -4258.227, -4173.272, -4085.042, -3993.428, -3898.3179999999998, -3799.599, -3697.158, -3590.88, -3480.6479999999997, -3366.3509999999997, -3247.8779999999997, -3125.125, -2997.993, -2866.393, -2730.2490000000003, -2589.5, -2444.106, -2294.052, -2139.349, -1980.046, -1816.23, -1648.035, -1475.644, -1299.302, -1119.306, -936.0219999999999, -749.8760000000001, -561.356, -371.00699999999995, -179.422, 12.764000000000001, 204.893, 396.293, 586.297, 774.255, 959.552, 1141.619, 1319.944, 1494.0770000000002, 1663.6370000000002, 1828.3129999999999, 1987.858, 2142.092, 2290.894, 2434.197, 2571.979, 2704.259, 2831.091, 2952.5559999999996, 3068.757, 3179.8140000000003, 3285.863, 3387.047, 3483.515, 3575.421, 3662.921, 3746.1690000000003, 3825.3190000000004, 3900.522, 3971.927, 4039.677, 4103.911, 4164.765, 4222.3679999999995, 4276.846, 4328.318, 4376.9, 4422.702, 4465.829000000001, 4506.383, 4544.459, 4580.149, 4613.542, 4644.721, 4673.767, 4700.7570000000005, 4725.762, 4748.854, 4770.099, 4789.56, 4807.298, 4823.371, 4837.835999999999, 4850.745, 4862.149, 4872.097, 4880.635, 4887.809, 4893.661, 4898.231, 4901.56, 4903.685, 4904.643, 4904.468, 4903.193, 4900.851, 4897.473, 4893.088, 4887.726, 4881.413, 4874.175, 4866.039000000001, 4857.029, 4847.168, 4836.48, 4824.987, 4812.71, 4799.669, 4785.885, 4771.376, 4756.162, 4740.259, 4723.685, 4706.458, 4688.593, 4670.106, 4651.013, 4631.327, 4611.065, 4590.238, 4568.861, 4546.947, 4524.5070000000005, 4501.556, 4478.105, 4454.165, 4429.747, 4404.862, 4379.522, 4353.736, 4327.515, 4300.8679999999995, 4273.806, 4246.335999999999, 4218.468, 4190.210999999999, 4161.573, 4132.564, 4103.191, 4073.462, 4043.384, 4012.966, 3982.2140000000004, 3951.136, 3919.74, 3888.031, 3856.0170000000003, 3823.703, 3791.097, 3758.205, 3725.032, 3691.585, 3657.87, 3623.8920000000003, 3589.657, 3555.171, 3520.438, 3485.465, 3450.255, 3414.815, 3379.1490000000003, 3343.261, 3307.158, 3270.842, 3234.3190000000004, 3197.594, 3160.671, 3123.553, 3086.2459999999996, 3048.7529999999997, 3011.079, 2973.2270000000003, 2935.2009999999996, 2897.006, 2858.645, 2820.1209999999996, 2781.438, 2742.6009999999997, 2703.611, 2664.474, 2625.192, 2585.769, 2546.208, 2506.512, 2466.685, 2426.729, 2386.6479999999997, 2346.444, 2306.1220000000003, 2265.683, 2225.131, 2184.468, 2143.698, 2102.823, 2061.845, 2020.769, 1979.596, 1938.329, 1896.97, 1855.523, 1813.989, 1772.371, 1730.6729999999998, 1688.895, 1647.0410000000002, 1605.114, 1563.114, 1521.045, 1478.91, 1436.7089999999998, 1394.4470000000001, 1352.124, 1309.743, 1267.306, 1224.816, 1182.274, 1139.684, 1097.045, 1054.362, 1011.6360000000001, 968.8689999999999, 926.063, 883.22, 840.342, 797.43, 754.488, 711.5169999999999, 668.5189999999999, 625.496, 582.4490000000001, 539.381, 496.293, 453.18800000000005, 410.06699999999995, 366.93199999999996, 323.785, 280.627, 237.46099999999998, 194.28799999999998, 151.11, 107.929, 64.747, 21.565, -21.615, -64.791, -107.962, -151.125, -194.28, -237.423, -280.55400000000003, -323.671, -366.772, -409.856, -452.92, -495.964, -538.985, -581.982, -624.953, -667.8960000000001, -710.81, -753.694, -796.544, -839.3610000000001, -882.1419999999999, -924.885, -967.5889999999999, -1010.252, -1052.873, -1095.45, -1137.981, -1180.465, -1222.899, -1265.2830000000001, -1307.615, -1349.8929999999998, -1392.115, -1434.28, -1476.385, -1518.431, -1560.4129999999998, -1602.332, -1644.1860000000001, -1685.9720000000002, -1727.6889999999999, -1769.335, -1810.9089999999999, -1852.4089999999999, -1893.8329999999999, -1935.18, -1976.4470000000001, -2017.634, -2058.737, -2099.757, -2140.69, -2181.535, -2222.291, -2262.955, -2303.527, -2344.0029999999997, -2384.382, -2424.663, -2464.843, -2504.9210000000003, -2544.895, -2584.763, -2624.5229999999997, -2664.173, -2703.712, -2743.137, -2782.447, -2821.64, -2860.7129999999997, -2899.665, -2938.494, -2977.197, -3015.7729999999997, -3054.22, -3092.5359999999996, -3130.718, -3168.765, -3206.675, -3244.4440000000004, -3282.072, -3319.5559999999996, -3356.8940000000002, -3394.083, -3431.1220000000003, -3468.008, -3504.739, -3541.312, -3577.7259999999997, -3613.978, -3650.065, -3685.986, -3721.737, -3757.317, -3792.722, -3827.9509999999996, -3863.0009999999997, -3897.869, -3932.552, -3967.0490000000004, -4001.3559999999998, -4035.4709999999995, -4069.39, -4103.112, -4136.633, -4169.95, -4203.061, -4235.963, -4268.652, -4301.126, -4333.3820000000005, -4365.417, -4397.227, -4428.809, -4460.161, -4491.278, -4522.157999999999, -4552.795999999999, -4583.191, -4613.338, -4643.233, -4672.874, -4702.255999999999, -4731.376, -4760.229, -4788.813, -4817.123, -4845.156, -4872.906, -4900.371, -4927.545999999999, -4954.427, -4981.009, -5007.289000000001, -5033.2609999999995, -5058.920999999999, -5084.264, -5109.286, -5133.982, -5158.347, -5182.376, -5206.064, -5229.406, -5252.396, -5275.029, -5297.299, -5319.201, -5340.73, -5361.879, -5382.643, -5403.014, -5422.988, -5442.557, -5461.715999999999, -5480.456, -5498.773, -5516.658, -5534.106, -5551.108, -5567.656, -5583.744000000001, -5599.3640000000005, -5614.507, -5629.1669999999995, -5643.3330000000005, -5656.999, -5670.154, -5682.789000000001, -5694.897, -5706.468000000001, -5717.491, -5727.956999999999, -5737.855, -5747.177, -5755.91, -5764.043000000001, -5771.565, -5778.465999999999, -5784.732, -5790.353, -5795.314, -5799.603, -5803.206999999999, -5806.111999999999, -5808.305, -5809.77, -5810.493, -5810.4580000000005, -5809.65, -5808.052, -5805.647, -5802.419, -5798.349, -5793.418000000001, -5787.609, -5780.9, -5773.272, -5764.704000000001, -5755.174, -5744.659000000001, -5733.137, -5720.5830000000005, -5706.974, -5692.281999999999, -5676.481, -5659.545, -5641.443, -5622.148, -5601.6269999999995, -5579.85, -5556.781999999999, -5532.39, -5506.639, -5479.491, -5450.906999999999, -5420.849, -5389.274, -5356.138000000001, -5321.399, -5285.007, -5246.916, -5207.073, -5165.428, -5121.923, -5076.503, -5029.109, -4979.677, -4928.142, -4874.439, -4818.497, -4760.242, -4699.599, -4636.4890000000005, -4570.829000000001, -4502.534000000001, -4431.516, -4357.682, -4280.937, -4201.183, -4118.319, -4032.239, -3942.837, -3850.002, -3753.623, -3653.5879999999997, -3549.782, -3442.091, -3330.403, -3214.6090000000004, -3094.6040000000003, -2970.289, -2841.5759999999996, -2708.385, -2570.656, -2428.344, -2281.429, -2129.92, -1973.859, -1813.325, -1648.445, -1479.392, -1306.397, -1129.748, -949.795, -766.951, -581.688, -394.536, -206.07299999999998, -16.919, 172.27900000000002, 360.86300000000006, 548.172, 733.566, 916.435, 1096.212, 1272.387, 1444.507, 1612.191, 1775.122, 1933.0510000000002, 2085.79, 2233.215, 2375.251, 2511.869, 2643.085, 2768.945, 2889.526, 3004.925, 3115.258, 3220.655, 3321.255, 3417.203, 3508.651, 3595.748, 3678.6490000000003, 3757.502, 3832.4570000000003, 3903.659, 3971.2490000000003, 4035.364, 4096.157999999999, 4153.698, 4208.168, 4259.666, 4308.305, 4354.194, 4397.437, 4438.135, 4476.38, 4512.266, 4545.878, 4577.3, 4606.61, 4633.885, 4659.196, 4682.613, 4704.201, 4724.023, 4742.14, 4758.608, 4773.484, 4786.819, 4798.663, 4809.065, 4818.072, 4825.727, 4832.072, 4837.149, 4840.995, 4843.649, 4845.146, 4845.521, 4844.807, 4843.034000000001, 4840.235, 4836.439, 4831.6720000000005, 4825.965, 4819.340999999999, 4811.826, 4803.444, 4794.22, 4784.1759999999995, 4773.333, 4761.712, 4749.334, 4736.219, 4722.3859999999995, 4707.852, 4692.6359999999995, 4676.755, 4660.224, 4643.062, 4625.282, 4606.9, 4587.931, 4568.389, 4548.287, 4527.639, 4506.458, 4484.755999999999, 4462.545, 4439.837, 4416.645, 4392.978, 4368.847, 4344.264, 4319.238, 4293.78, 4267.899, 4241.604, 4214.905, 4187.811, 4160.33, 4132.471, 4104.241, 4075.65, 4046.705, 4017.414, 3987.784, 3957.823, 3927.5370000000003, 3896.933, 3866.0190000000002, 3834.801, 3803.285, 3771.478, 3739.386, 3707.015, 3674.3709999999996, 3641.46, 3608.2870000000003, 3574.857, 3541.178, 3507.2529999999997, 3473.087, 3438.687, 3404.0559999999996, 3369.2009999999996, 3334.1240000000003, 3298.8320000000003, 3263.329, 3227.619, 3191.7070000000003, 3155.597, 3119.2929999999997, 3082.7990000000004, 3046.12, 3009.26, 2972.222, 2935.011, 2897.63, 2860.083, 2822.373, 2784.505, 2746.482, 2708.3070000000002, 2669.9829999999997, 2631.515, 2592.905, 2554.157, 2515.2729999999997, 2476.259, 2437.115, 2397.845, 2358.452, 2318.94, 2279.31, 2239.567, 2199.7129999999997, 2159.751, 2119.683, 2079.512, 2039.241, 1998.8729999999998, 1958.4089999999999, 1917.854, 1877.2089999999998, 1836.477, 1795.66, 1754.761, 1713.7820000000002, 1672.726, 1631.594, 1590.39, 1549.116, 1507.774, 1466.365, 1424.8929999999998, 1383.36, 1341.7679999999998, 1300.118, 1258.414, 1216.657, 1174.849, 1132.993, 1091.09, 1049.143, 1007.154, 965.123, 923.055, 880.95, 838.81, 796.638, 754.436, 712.204, 669.946, 627.6619999999999, 585.356, 543.028, 500.681, 458.316, 415.936, 373.542, 331.135, 288.718, 246.292, 203.86, 161.422, 116.477, 74.032, 31.588, -10.855, -53.294, -95.727, -138.154, -180.572, -222.979, -265.375, -307.757, -350.12300000000005, -392.473, -434.80300000000005, -477.11400000000003, -519.4019999999999, -561.6669999999999, -603.9069999999999, -646.119, -688.303, -730.457, -772.579, -814.668, -856.722, -898.7389999999999, -940.7180000000001, -982.6560000000001, -1024.5539999999999, -1066.4080000000001, -1108.2169999999999, -1149.98, -1191.695, -1233.361, -1274.975, -1316.536, -1358.0420000000001, -1399.493, -1440.885, -1482.2179999999998, -1523.49, -1564.7, -1605.845, -1646.9229999999998, -1687.935, -1728.876, -1769.747, -1810.545, -1851.269, -1891.9160000000002, -1932.486, -1972.977, -2013.386, -2053.712, -2093.9539999999997, -2134.109, -2174.176, -2214.154, -2254.0389999999998, -2293.8320000000003, -2333.529, -2373.13, -2412.631, -2452.032, -2491.331, -2530.525, -2569.614, -2608.594, -2647.465, -2686.225, -2724.87, -2763.4, -2801.813, -2840.107, -2878.2790000000005, -2916.328, -2954.252, -2992.0490000000004, -3029.716, -3067.252, -3104.655, -3141.922, -3179.052, -3216.042, -3252.89, -3289.595, -3326.153, -3362.562, -3398.822, -3434.928, -3470.8790000000004, -3506.6740000000004, -3542.308, -3577.78, -3613.0879999999997, -3648.2290000000003, -3683.2009999999996, -3718.0009999999997, -3752.627, -3787.0759999999996, -3821.3459999999995, -3855.434, -3889.3379999999997, -3923.055, -3956.5809999999997, -3989.9159999999997, -4023.055, -4055.9959999999996, -4088.736, -4121.272, -4153.602, -4185.722, -4217.63, -4249.323, -4280.7970000000005, -4312.049, -4343.076, -4373.874, -4404.443, -4434.775, -4464.87, -4494.724, -4524.333, -4553.693, -4582.802, -4611.654, -4640.248, -4668.579000000001, -4696.642, -4724.436, -4751.954000000001, -4779.193, -4806.15, -4832.82, -4859.1990000000005, -4885.282999999999, -4911.067, -4936.545999999999, -4961.717000000001, -4986.5740000000005, -5011.1140000000005, -5035.33, -5059.218, -5082.774, -5105.991, -5128.866, -5151.392, -5173.565, -5195.378, -5216.827, -5237.904, -5258.606, -5278.925, -5298.855, -5318.391, -5337.526, -5356.253000000001, -5374.566, -5392.456999999999, -5409.92, -5426.9490000000005, -5443.535, -5459.672, -5475.351, -5490.565, -5505.305, -5519.565, -5533.334, -5546.605, -5559.37, -5571.618, -5583.340999999999, -5594.529, -5605.173000000001, -5615.263000000001, -5624.7880000000005, -5633.7390000000005, -5642.103, -5649.87, -5657.03, -5663.57, -5669.478, -5674.741999999999, -5679.349, -5683.286, -5686.541, -5689.098000000001, -5690.944, -5692.065, -5692.445, -5692.069, -5690.92, -5688.982, -5686.2390000000005, -5682.673000000001, -5678.265, -5672.9980000000005, -5666.852, -5659.807, -5651.840999999999, -5642.935, -5633.066, -5622.2119999999995, -5610.348000000001, -5597.451999999999, -5583.496, -5568.456999999999, -5552.306, -5535.014, -5516.555, -5496.898, -5476.009, -5453.86, -5430.4130000000005, -5405.638000000001, -5379.494000000001, -5351.946999999999, -5322.956, -5292.48, -5260.477, -5226.904, -5191.715, -5154.861, -5116.293, -5075.960999999999, -5033.808, -4989.781, -4943.819, -4895.863, -4845.849, -4793.710999999999, -4739.380999999999, -4682.785, -4623.851, -4562.5, -4498.652, -4432.224, -4363.127, -4291.272, -4216.564, -4138.907999999999, -4058.203, -3974.3459999999995, -3887.2329999999997, -3796.7540000000004, -3702.8, -3605.258, -3504.018, -3398.966, -3289.99, -3176.9829999999997, -3059.8390000000004, -2938.46, -2812.756, -2682.6490000000003, -2548.074, -2408.984, -2265.3579999999997, -2117.197, -1964.5379999999998, -1807.455, -1646.0639999999999, -1480.53, -1311.0720000000001, -1137.965, -961.545, -782.211, -600.419, -416.684, -231.56900000000002, -45.678000000000004, 140.357, 325.887, 510.265, 692.857, 873.06, 1050.31, 1224.099, 1393.976, 1559.556, 1720.519, 1876.612, 2027.644, 2173.4829999999997, 2314.049, 2449.3089999999997, 2579.271, 2703.9770000000003, 2823.4959999999996, 2937.923, 3047.367, 3151.953, 3251.8179999999998, 3347.1, 3437.948, 3524.509, 3606.9309999999996, 3685.363, 3759.949, 3830.8320000000003, 3898.152, 3962.042, 4022.634, 4080.053, 4134.420999999999, 4185.854, 4234.464, 4280.357, 4323.638, 4364.403, 4402.746, 4438.7570000000005, 4472.522, 4504.123, 4533.637, 4561.138, 4586.7, 4610.389, 4632.27, 4652.405, 4670.855, 4687.675, 4702.92, 4716.641, 4728.889, 4739.710999999999, 4749.153, 4757.2570000000005, 4764.067, 4769.621, 4773.959, 4777.117, 4779.13, 4780.034000000001, 4779.86, 4778.639, 4776.402, 4773.178, 4768.994000000001, 4763.879, 4757.857, 4750.9529999999995, 4743.192, 4734.596, 4725.189, 4714.99, 4704.022, 4692.304, 4679.857, 4666.697, 4652.844, 4638.315, 4623.128, 4607.298, 4590.842000000001, 4573.773, 4556.109, 4537.862, 4519.048, 4499.679, 4479.77, 4459.331, 4438.376, 4416.917, 4394.965, 4372.532999999999, 4349.63, 4326.268, 4302.456, 4278.207, 4253.527, 4228.429, 4202.92, 4177.01, 4150.708, 4124.022, 4096.960999999999, 4069.532, 4041.745, 4013.6059999999998, 3985.1240000000003, 3956.305, 3927.157, 3897.6859999999997, 3867.901, 3837.805, 3807.409, 3776.717, 3745.736, 3714.4709999999995, 3682.929, 3651.115, 3619.0359999999996, 3586.697, 3554.1020000000003, 3521.259, 3488.171, 3454.844, 3421.284, 3387.494, 3353.48, 3319.2470000000003, 3284.7990000000004, 3250.14, 3215.276, 3180.21, 3144.947, 3109.491, 3073.8459999999995, 3038.0159999999996, 3002.005, 2965.817, 2929.455, 2892.925, 2856.228, 2819.37, 2782.3520000000003, 2745.18, 2707.857, 2670.385, 2632.768, 2595.01, 2557.114, 2519.0820000000003, 2480.9179999999997, 2442.625, 2404.206, 2365.6639999999998, 2327.002, 2288.223, 2249.33, 2210.325, 2171.212, 2131.992, 2092.67, 2053.246, 2013.725, 1974.108, 1934.399, 1894.599, 1854.711, 1814.7379999999998, 1774.682, 1734.545, 1694.33, 1654.039, 1613.675, 1573.239, 1532.734, 1492.1629999999998, 1451.527, 1410.828, 1370.07, 1329.253, 1288.38, 1247.453, 1206.474, 1165.4460000000001, 1124.37, 1083.248, 1042.083, 1000.875, 959.628, 918.3430000000001, 877.0219999999999, 835.6669999999999, 794.28, 752.863, 711.4169999999999, 669.945, 628.448, 586.929, 545.388, 503.82800000000003, 462.25, 420.657, 379.05, 337.431, 295.801, 254.162, 212.517, 170.86599999999999, 129.21200000000002, 87.556, 45.9, 4.245, -37.406, -79.053, -120.693, -162.325, -203.947, -245.558, -287.155, -328.73800000000006, -370.30400000000003, -411.853, -453.38199999999995, -494.889, -536.374, -577.8340000000001, -619.268, -660.675, -702.052, -743.3989999999999, -784.7130000000001, -825.993, -867.237, -908.444, -949.613, -990.74, -1031.826, -1072.869, -1113.866, -1154.816, -1195.7169999999999, -1236.569, -1277.369, -1318.116, -1358.808, -1399.444, -1440.0220000000002, -1480.54, -1520.996, -1561.39, -1601.719, -1641.983, -1682.1779999999999, -1722.3039999999999, -1762.358, -1802.34, -1842.2479999999998, -1882.079, -1921.8329999999999, -1961.507, -2001.101, -2040.611, -2080.0370000000003, -2119.376, -2158.6279999999997, -2197.7889999999998, -2236.86, -2275.837, -2314.719, -2353.504, -2392.1910000000003, -2430.778, -2469.263, -2507.643, -2545.9179999999997, -2584.085, -2622.143, -2660.0890000000004, -2697.923, -2735.6409999999996, -2773.242, -2810.724, -2848.085, -2885.323, -2922.4359999999997, -2959.422, -2996.2790000000005, -3033.006, -3069.599, -3106.058, -3142.3790000000004, -3178.5609999999997, -3214.6009999999997, -3250.498, -3286.25, -3321.853, -3357.3059999999996, -3392.607, -3427.7529999999997, -3462.742, -3497.572, -3532.24, -3566.744, -3601.0820000000003, -3635.2509999999997, -3669.248, -3703.072, -3736.719, -3770.187, -3803.474, -3836.577, -3869.493, -3902.219, -3934.7529999999997, -3967.093, -3999.2340000000004, -4031.175, -4062.913, -4094.4440000000004, -4125.766, -4156.876, -4187.77, -4218.446, -4248.9, -4279.13, -4309.130999999999, -4338.9, -4368.436, -4397.733, -4426.789000000001, -4455.6, -4484.163, -4512.473, -4540.528, -4568.323, -4595.855, -4623.12, -4650.113, -4676.832, -4703.271, -4729.428, -4755.2970000000005, -4780.874, -4806.155, -4831.135, -4855.811, -4880.177, -4904.228, -4927.96, -4951.369000000001, -4974.4490000000005, -4997.194, -5019.6, -5041.662, -5063.374, -5084.73, -5105.726, -5126.354, -5146.611, -5166.4890000000005, -5185.982, -5205.085, -5223.79, -5242.092000000001, -5259.984, -5277.4580000000005, -5294.508000000001, -5311.1269999999995, -5327.308000000001, -5343.043000000001, -5358.325, -5373.145, -5387.496, -5401.37, -5414.758000000001, -5427.651999999999, -5440.043000000001, -5451.920999999999, -5463.278, -5474.104, -5484.39, -5494.125, -5503.3, -5511.903, -5519.924, -5527.351, -5534.174, -5540.380999999999, -5545.96, -5550.897, -5555.182, -5558.8, -5561.738, -5563.982, -5565.518, -5566.331, -5566.406, -5565.728, -5564.279, -5562.044, -5559.005999999999, -5555.147, -5550.448, -5544.891, -5538.456999999999, -5531.124, -5522.8730000000005, -5513.682, -5503.529, -5492.391, -5480.243, -5467.063, -5452.823, -5437.496999999999, -5421.058000000001, -5403.478, -5384.729, -5364.778, -5343.593000000001, -5321.143, -5297.394, -5272.309, -5245.852, -5217.985, -5188.667, -5157.858, -5125.515, -5091.590999999999, -5056.042, -5018.818, -4979.8679999999995, -4939.141, -4896.581, -4852.13, -4805.73, -4757.319, -4706.831, -4654.1990000000005, -4599.354, -4542.222, -4482.726, -4420.789000000001, -4356.3279999999995, -4289.2570000000005, -4219.487, -4146.927, -4071.4829999999997, -3993.055, -3911.5429999999997, -3826.843, -3738.849, -3647.452, -3552.542, -3454.007, -3351.738, -3245.623, -3135.5559999999996, -3021.4320000000002, -2903.152, -2780.625, -2653.7729999999997, -2522.53, -2386.845, -2246.694, -2102.074, -1953.016, -1799.586, -1641.892, -1480.089, -1314.385, -1145.042, -972.3810000000001, -796.7860000000001, -618.698, -438.61400000000003, -257.08099999999996, -74.687, 107.949, 290.193, 471.408, 650.971, 828.285, 1002.7919999999999, 1173.985, 1341.4129999999998, 1504.693, 1663.499, 1817.576, 1966.727, 2110.815, 2249.755, 2383.508, 2512.076, 2635.495, 2753.828, 2867.164, 2975.6079999999997, 3079.28, 3178.3109999999997, 3272.837, 3363.0, 3448.9440000000004, 3530.815, 3608.755, 3682.909, 3753.4159999999997, 3820.41, 3884.026, 3944.39, 4001.627, 4055.8540000000003, 4107.189, 4155.7390000000005, 4201.61, 4244.903, 4285.714, 4324.137, 4360.258, 4394.163, 4425.932, 4455.641, 4483.365, 4509.173, 4533.1320000000005, 4555.307, 4575.758, 4594.545999999999, 4611.723, 4627.345, 4641.463, 4654.126, 4665.38, 4675.271, 4683.842000000001, 4691.1320000000005, 4697.183, 4702.032, 4705.715999999999, 4708.268, 4709.724, 4710.1140000000005, 4709.471, 4707.823, 4705.1990000000005, 4701.627, 4697.134, 4691.744000000001, 4685.483, 4678.373, 4670.439, 4661.702, 4652.183, 4641.903, 4630.880999999999, 4619.137, 4606.689, 4593.555, 4579.753, 4565.299, 4550.208, 4534.498, 4518.183, 4501.277, 4483.795, 4465.752, 4447.159000000001, 4428.031, 4408.379, 4388.215999999999, 4367.554, 4346.403, 4324.777, 4302.685, 4280.137, 4257.145, 4233.718, 4209.866, 4185.598, 4160.923, 4135.85, 4110.389, 4084.548, 4058.3340000000003, 4031.756, 4004.822, 3977.54, 3949.9159999999997, 3921.9590000000003, 3893.675, 3865.072, 3836.155, 3806.9320000000002, 3777.41, 3747.594, 3717.49, 3687.105, 3656.4440000000004, 3625.514, 3594.3190000000004, 3562.867, 3531.1609999999996, 3499.2070000000003, 3467.011, 3434.577, 3401.91, 3369.0159999999996, 3335.8979999999997, 3302.562, 3269.012, 3235.2529999999997, 3201.289, 3167.1240000000003, 3132.762, 3098.2090000000003, 3063.467, 3028.5409999999997, 2993.434, 2958.151, 2922.696, 2887.071, 2851.281, 2815.329, 2779.219, 2742.954, 2706.538, 2669.973, 2633.264, 2596.413, 2559.424, 2522.3, 2485.0429999999997, 2447.657, 2410.146, 2372.511, 2334.756, 2296.883, 2258.896, 2220.797, 2182.589, 2144.274, 2105.855, 2067.3360000000002, 2028.7179999999998, 1990.004, 1951.1960000000001, 1912.297, 1873.31, 1834.237, 1795.08, 1755.8410000000001, 1716.523, 1677.129, 1637.66, 1598.119, 1558.5079999999998, 1518.829, 1479.0839999999998, 1439.276, 1399.4070000000002, 1359.4779999999998, 1319.4920000000002, 1279.451, 1239.357, 1199.212, 1159.018, 1118.777, 1078.49, 1038.161, 997.79, 957.38, 916.933, 876.45, 835.933, 795.385, 754.806, 714.2, 673.567, 632.91, 592.229, 551.528, 510.80800000000005, 470.07, 429.316, 388.548, 347.76800000000003, 306.978, 266.178, 225.37099999999998, 184.55900000000003, 143.743, 102.92399999999999, 62.105, 21.288, -19.528, -60.339, -101.14299999999999, -141.941, -182.729, -223.50599999999997, -264.27099999999996, -305.022, -345.75699999999995, -386.475, -427.17400000000004, -467.853, -508.51, -549.143, -589.752, -630.3330000000001, -670.887, -711.41, -751.9019999999999, -792.3610000000001, -832.7860000000001, -873.175, -913.5260000000001, -953.837, -994.1080000000001, -1034.337, -1074.522, -1114.661, -1154.753, -1194.797, -1234.79, -1274.732, -1314.62, -1354.453, -1394.23, -1433.9489999999998, -1473.608, -1513.2060000000001, -1552.741, -1592.2120000000002, -1631.616, -1670.953, -1710.22, -1749.4170000000001, -1788.54, -1827.59, -1866.5639999999999, -1905.46, -1944.277, -1983.013, -2021.6670000000001, -2060.236, -2098.719, -2137.115, -2175.422, -2213.637, -2251.759, -2289.7870000000003, -2327.719, -2365.553, -2403.286, -2440.9179999999997, -2478.447, -2515.87, -2553.186, -2590.393, -2627.49, -2664.473, -2701.342, -2738.095, -2774.7290000000003, -2811.243, -2847.634, -2883.901, -2920.042, -2956.055, -2991.937, -3027.687, -3063.303, -3098.782, -3134.123, -3169.322, -3204.3790000000004, -3239.2909999999997, -3274.0559999999996, -3308.671, -3343.134, -3377.4429999999998, -3411.5959999999995, -3445.59, -3479.4240000000004, -3513.094, -3546.598, -3579.934, -3613.1, -3646.092, -3678.909, -3711.548, -3744.005, -3776.28, -3808.368, -3840.2670000000003, -3871.975, -3903.489, -3934.805, -3965.921, -3996.835, -4027.542, -4058.0409999999997, -4088.328, -4118.401, -4148.255, -4177.889, -4207.298, -4236.479, -4265.43, -4294.146, -4322.625, -4350.863, -4378.856, -4406.601, -4434.094, -4461.332, -4488.31, -4515.025, -4541.473, -4567.65, -4593.552, -4619.175, -4644.515, -4669.567, -4694.3279999999995, -4718.791, -4742.955, -4766.813, -4790.361, -4813.594, -4836.5070000000005, -4859.096, -4881.355, -4903.28, -4924.8640000000005, -4946.103, -4966.991, -4987.522, -5007.692, -5027.494000000001, -5046.9220000000005, -5065.969, -5084.630999999999, -5102.9, -5120.77, -5138.234, -5155.286, -5171.918, -5188.125, -5203.897, -5219.228, -5234.111, -5248.536999999999, -5262.4980000000005, -5275.986999999999, -5288.995, -5301.514, -5313.534000000001, -5325.045999999999, -5336.041, -5346.5109999999995, -5356.445, -5365.8330000000005, -5374.664000000001, -5382.929, -5390.616, -5397.715, -5404.213000000001, -5410.1, -5415.361999999999, -5419.9890000000005, -5423.967, -5427.281999999999, -5429.920999999999, -5431.871, -5433.116, -5433.643, -5433.436, -5432.478, -5430.754, -5428.2480000000005, -5424.941999999999, -5420.818, -5415.857, -5410.041, -5403.351, -5395.765, -5387.263000000001, -5377.823, -5367.424, -5356.04, -5343.649, -5330.226, -5315.745, -5300.178000000001, -5283.5, -5265.679, -5246.689, -5226.495, -5205.068, -5182.374, -5158.377, -5133.042, -5106.331, -5078.207, -5048.628, -5017.5509999999995, -4984.935, -4950.731, -4914.894, -4877.374, -4838.119000000001, -4797.076, -4754.189, -4709.4, -4662.647, -4613.8679999999995, -4562.997, -4509.965, -4454.7, -4397.13, -4337.175, -4274.755, -4209.788, -4142.185, -4071.8579999999997, -3998.712, -3922.653, -3843.579, -3761.3909999999996, -3675.982, -3587.2470000000003, -3495.077, -3399.362, -3299.994, -3196.864, -3089.863, -2978.889, -2863.844, -2744.637, -2621.187, -2493.428, -2361.3070000000002, -2224.795, -2083.886, -1938.604, -1789.01, -1635.2020000000002, -1477.3239999999998, -1315.5739999999998, -1150.201, -981.512, -809.8739999999999, -635.7130000000001, -459.50699999999995, -281.78700000000003, -103.126, 75.874, 254.59400000000002, 432.409, 608.705, 782.8939999999999, 954.424, 1122.79, 1287.546, 1448.3029999999999, 1604.7379999999998, 1756.59, 1903.658, 2045.8, 2182.927, 2314.991, 2441.991, 2563.955, 2680.9429999999998, 2793.0359999999996, 2900.335, 3002.954, 3101.0190000000002, 3194.6609999999996, 3284.018, 3369.232, 3450.442, 3527.789, 3601.413, 3671.449, 3738.0290000000005, 3801.2859999999996, 3861.425, 3918.322, 3972.34, 4023.508, 4071.935, 4117.723, 4160.973, 4201.779, 4240.23, 4276.415, 4310.417, 4342.312, 4372.179, 4400.089, 4426.111, 4450.311, 4472.752, 4493.494000000001, 4512.594, 4530.109, 4546.09, 4560.587, 4573.649, 4585.322, 4595.65, 4604.675, 4612.439, 4618.981, 4624.335, 4628.54, 4631.63, 4633.6359999999995, 4634.592000000001, 4634.527, 4633.472, 4631.452, 4628.498, 4624.633, 4619.884, 4614.274, 4607.827, 4600.566, 4592.5109999999995, 4583.684, 4574.106, 4563.795999999999, 4552.771, 4541.052, 4528.655, 4515.597, 4501.896, 4487.566, 4472.623, 4457.082, 4440.958, 4424.265, 4407.016, 4389.225, 4370.903, 4352.063, 4332.719, 4312.880999999999, 4292.56, 4271.768, 4250.516, 4228.813, 4206.669, 4184.096, 4161.102, 4137.696, 4113.888, 4089.6859999999997, 4065.1, 4040.136, 4014.804, 3989.112, 3963.066, 3936.676, 3909.948, 3882.889, 3855.506, 3827.8059999999996, 3799.797, 3771.4829999999997, 3742.873, 3713.9709999999995, 3684.784, 3655.3179999999998, 3625.578, 3595.572, 3565.303, 3534.778, 3504.0009999999997, 3472.9790000000003, 3441.715, 3410.215, 3378.485, 3346.527, 3314.349, 3281.953, 3249.345, 3216.528, 3183.508, 3150.289, 3116.873, 3083.2670000000003, 3049.473, 3015.4959999999996, 2981.3390000000004, 2947.007, 2912.502, 2877.829, 2842.991, 2807.992, 2772.835, 2737.5240000000003, 2702.062, 2666.4509999999996, 2630.697, 2594.801, 2558.766, 2522.597, 2486.2960000000003, 2449.865, 2413.3089999999997, 2376.629, 2339.8289999999997, 2302.911, 2265.8779999999997, 2228.7329999999997, 2191.479, 2154.118, 2116.653, 2079.087, 2041.421, 2003.6589999999999, 1965.8029999999999, 1927.855, 1889.818, 1851.694, 1813.486, 1775.195, 1736.825, 1698.378, 1659.854, 1621.2579999999998, 1582.5910000000001, 1543.855, 1505.0529999999999, 1466.1860000000001, 1427.256, 1388.267, 1349.219, 1310.114, 1270.9560000000001, 1231.745, 1192.484, 1153.175, 1113.819, 1074.4180000000001, 1034.975, 995.492, 955.9689999999999, 916.41, 876.815, 837.187, 797.528, 757.8380000000001, 718.1210000000001, 678.378, 638.61, 598.819, 559.007, 519.1759999999999, 479.32800000000003, 439.463, 399.585, 359.694, 319.791, 279.88, 239.96099999999998, 200.037, 160.108, 120.176, 80.243, 40.311, 0.381, -39.545, -79.46600000000001, -119.38, -159.286, -199.18099999999998, -239.065, -278.935, -318.791, -358.63, -398.452, -438.254, -478.035, -517.794, -557.529, -597.238, -636.92, -676.573, -716.196, -755.7869999999999, -795.345, -834.868, -874.355, -913.804, -953.2139999999999, -992.582, -1031.9080000000001, -1071.191, -1110.427, -1149.617, -1188.758, -1227.848, -1266.887, -1305.873, -1344.8039999999999, -1383.6789999999999, -1422.495, -1461.2520000000002, -1499.9479999999999, -1538.582, -1577.151, -1615.654, -1654.09, -1692.457, -1730.754, -1768.9779999999998, -1807.128, -1845.203, -1883.201, -1921.12, -1958.9579999999999, -1996.715, -2034.388, -2071.975, -2109.475, -2146.887, -2184.208, -2221.437, -2258.572, -2295.612, -2332.554, -2369.396, -2406.138, -2442.777, -2479.312, -2515.74, -2552.06, -2588.27, -2624.368, -2660.353, -2696.2209999999995, -2731.972, -2767.6040000000003, -2803.114, -2838.5, -2873.762, -2908.8959999999997, -2943.9, -2978.7729999999997, -3013.513, -3048.117, -3082.5840000000003, -3116.9109999999996, -3151.095, -3185.136, -3219.031, -3252.777, -3286.3720000000003, -3319.8140000000003, -3353.1009999999997, -3386.2309999999998, -3419.2, -3452.007, -3484.65, -3517.125, -3549.4309999999996, -3581.5640000000003, -3613.5229999999997, -3645.304, -3676.906, -3708.3259999999996, -3739.56, -3770.6059999999998, -3801.462, -3832.125, -3862.592, -3892.86, -3922.925, -3952.7859999999996, -3982.4390000000003, -4011.881, -4041.11, -4070.1209999999996, -4098.912, -4127.48, -4155.821, -4183.932, -4211.81, -4239.451, -4266.852, -4294.009, -4320.918, -4347.576, -4373.98, -4400.124, -4426.005999999999, -4451.622, -4476.967000000001, -4502.038, -4526.83, -4551.34, -4575.562, -4599.4929999999995, -4623.128, -4646.462, -4669.491, -4692.209, -4714.613, -4736.698, -4758.458, -4779.888, -4800.983, -4821.738, -4842.147, -4862.205, -4881.905, -4901.2429999999995, -4920.212, -4938.806, -4957.02, -4974.846, -4992.279, -5009.311, -5025.937, -5042.148, -5057.938, -5073.3, -5088.226, -5102.709, -5116.741, -5130.314, -5143.42, -5156.0509999999995, -5168.197, -5179.85, -5191.001, -5201.642, -5211.762, -5221.351, -5230.4, -5238.898, -5246.835, -5254.201, -5260.983, -5267.17, -5272.751, -5277.714, -5282.045999999999, -5285.734, -5288.765, -5291.126, -5292.8009999999995, -5293.779, -5294.0419999999995, -5293.576999999999, -5292.366, -5290.394, -5287.644, -5284.1, -5279.741, -5274.5509999999995, -5268.51, -5261.598000000001, -5253.795, -5245.08, -5235.43, -5224.8240000000005, -5213.238, -5200.648, -5187.028, -5172.352, -5156.593, -5139.725, -5121.715999999999, -5102.537, -5082.157999999999, -5060.545, -5037.664000000001, -5013.481, -4987.959, -4961.061, -4932.746, -4902.973, -4871.7, -4838.883, -4804.476, -4768.429, -4730.693, -4691.215, -4649.941, -4606.814, -4561.775, -4514.762, -4465.71, -4414.554, -4361.222, -4305.642, -4247.74, -4187.435, -4124.646, -4059.288, -3991.275, -3920.512, -3846.908, -3770.365, -3690.782, -3608.058, -3522.0879999999997, -3432.764, -3339.9809999999998, -3243.6279999999997, -3143.6, -3039.79, -2932.0959999999995, -2820.4190000000003, -2704.67, -2584.7670000000003, -2460.641, -2332.239, -2199.526, -2062.495, -1921.1629999999998, -1775.5829999999999, -1625.845, -1472.086, -1314.4879999999998, -1153.29, -988.783, -821.318, -651.305, -479.204, -305.53, -130.836, 44.291000000000004, 219.247, 393.42, 566.2080000000001, 737.034, 905.3489999999999, 1070.655, 1232.507, 1390.5179999999998, 1544.361, 1693.774, 1838.5520000000001, 1978.549, 2113.667, 2243.8579999999997, 2369.11, 2489.449, 2604.926, 2715.619, 2821.6209999999996, 2923.0429999999997, 3020.0040000000004, 3112.631, 3201.059, 3285.423, 3365.86, 3442.506, 3515.4970000000003, 3584.966, 3651.042, 3713.853, 3773.52, 3830.163, 3883.8959999999997, 3934.827, 3983.065, 4028.708, 4071.855, 4112.6, 4151.028, 4187.228, 4221.279, 4253.259, 4283.2429999999995, 4311.302, 4337.503, 4361.911, 4384.587, 4405.592000000001, 4424.981, 4442.808, 4459.126, 4473.983, 4487.428, 4499.504, 4510.255999999999, 4519.726, 4527.952, 4534.975, 4540.829000000001, 4545.55, 4549.1720000000005, 4551.728, 4553.248, 4553.763, 4553.3009999999995, 4551.89, 4549.556, 4546.326, 4542.225, 4537.274, 4531.498, 4524.92, 4517.559, 4509.438, 4500.5740000000005, 4490.9890000000005, 4480.7, 4469.725, 4458.081, 4445.786, 4432.856, 4419.306, 4405.151, 4390.406, 4375.085, 4359.2029999999995, 4342.772, 4325.805, 4308.315, 4290.314, 4271.814, 4252.826, 4233.362, 4213.433, 4193.048, 4172.219, 4150.954000000001, 4129.265, 4107.159000000001, 4084.647, 4061.737, 4038.438, 4014.759, 3990.7070000000003, 3966.2909999999997, 3941.518, 3916.3959999999997, 3890.9320000000002, 3865.135, 3839.009, 3812.5640000000003, 3785.805, 3758.74, 3731.373, 3703.7129999999997, 3675.764, 3647.532, 3619.025, 3590.2459999999996, 3561.203, 3531.8990000000003, 3502.342, 3472.535, 3442.4840000000004, 3412.195, 3381.672, 3350.9190000000003, 3319.942, 3288.744, 3257.3320000000003, 3225.708, 3193.8779999999997, 3161.845, 3129.614, 3097.1890000000003, 3064.574, 3031.772, 2998.789, 2965.6259999999997, 2932.289, 2898.781, 2865.1059999999998, 2831.2659999999996, 2797.2659999999996, 2763.1079999999997, 2728.797, 2694.335, 2659.7259999999997, 2624.973, 2590.0789999999997, 2555.047, 2519.88, 2484.581, 2449.154, 2413.6, 2377.923, 2342.126, 2306.2110000000002, 2270.181, 2234.04, 2197.788, 2161.43, 2124.967, 2088.402, 2051.739, 2014.9779999999998, 1978.122, 1941.175, 1904.138, 1867.014, 1829.8039999999999, 1792.5120000000002, 1755.14, 1717.6889999999999, 1680.1629999999998, 1642.5620000000001, 1604.889, 1567.1470000000002, 1529.338, 1491.4620000000002, 1453.524, 1415.524, 1377.465, 1339.348, 1301.1760000000002, 1262.951, 1224.674, 1186.348, 1147.974, 1109.5539999999999, 1071.09, 1032.5839999999998, 994.038, 955.454, 916.832, 878.176, 839.487, 800.7669999999999, 762.0169999999999, 723.2389999999999, 684.434, 645.606, 606.755, 567.882, 528.991, 490.08099999999996, 451.156, 412.216, 373.26300000000003, 334.29900000000004, 295.32599999999996, 256.344, 217.357, 178.364, 139.368, 100.37100000000001, 61.373999999999995, 22.378, -16.615, -55.603, -94.585, -133.559, -172.524, -211.479, -250.42, -289.349, -328.26099999999997, -367.157, -406.035, -444.892, -483.728, -522.5419999999999, -561.33, -600.0930000000001, -638.8290000000001, -677.535, -716.212, -754.8560000000001, -793.467, -832.043, -870.582, -909.084, -947.546, -985.9680000000001, -1024.347, -1062.682, -1100.971, -1139.214, -1177.4080000000001, -1215.553, -1253.646, -1291.6860000000001, -1329.671, -1367.6, -1405.4720000000002, -1443.2839999999999, -1481.036, -1518.726, -1556.352, -1593.9129999999998, -1631.406, -1668.832, -1706.1870000000001, -1743.47, -1780.681, -1817.816, -1854.876, -1891.8570000000002, -1928.7579999999998, -1965.578, -2002.315, -2038.9679999999998, -2075.534, -2112.012, -2148.401, -2184.699, -2220.903, -2257.012, -2293.026, -2328.94, -2364.755, -2400.468, -2436.078, -2471.5820000000003, -2506.979, -2542.2670000000003, -2577.445, -2612.509, -2647.4590000000003, -2682.2929999999997, -2717.008, -2751.603, -2786.0759999999996, -2820.425, -2854.647, -2888.742, -2922.7059999999997, -2956.538, -2990.236, -3023.797, -3057.22, -3090.502, -3123.6409999999996, -3156.636, -3189.4829999999997, -3222.1809999999996, -3254.7270000000003, -3287.119, -3319.355, -3351.4320000000002, -3383.349, -3415.1020000000003, -3446.6890000000003, -3478.1079999999997, -3509.3559999999998, -3540.4309999999996, -3571.3309999999997, -3602.052, -3632.591, -3662.948, -3693.118, -3723.098, -3752.887, -3782.4809999999998, -3811.8779999999997, -3841.074, -3870.066, -3898.8520000000003, -3927.429, -3955.7929999999997, -3983.941, -4011.87, -4039.578, -4067.06, -4094.313, -4121.335, -4148.121, -4174.667, -4200.971, -4227.029, -4252.837, -4278.392, -4303.688, -4328.723, -4353.4929999999995, -4377.994000000001, -4402.22, -4426.17, -4449.837, -4473.219, -4496.309, -4519.104, -4541.6, -4563.791, -4585.673, -4607.24, -4628.4890000000005, -4649.413, -4670.0070000000005, -4690.268, -4710.188, -4729.763, -4748.986, -4767.853, -4786.356, -4804.491, -4822.251, -4839.629, -4856.62, -4873.217000000001, -4889.412, -4905.2, -4920.573, -4935.524, -4950.045999999999, -4964.13, -4977.77, -4990.957, -5003.683, -5015.94, -5027.719, -5039.012, -5049.81, -5060.103, -5069.8820000000005, -5079.1359999999995, -5087.857, -5096.034000000001, -5103.656, -5110.713, -5117.193, -5123.085, -5128.377, -5133.057, -5137.113, -5140.532, -5143.3009999999995, -5145.404, -5146.83, -5147.564, -5147.59, -5146.894, -5145.459, -5143.268, -5140.306, -5136.555, -5131.996, -5126.611, -5120.380999999999, -5113.287, -5105.307, -5096.419, -5086.603, -5075.835, -5064.092000000001, -5051.349, -5037.581, -5022.762, -5006.865, -4989.86, -4971.719, -4952.412, -4931.906, -4910.169, -4887.167, -4862.863, -4837.223, -4810.206, -4781.773, -4751.883, -4720.491, -4687.553, -4653.023, -4616.85, -4578.985, -4539.373, -4497.96, -4454.688, -4409.497, -4362.323, -4313.103, -4261.767, -4208.245, -4152.463, -4094.343, -4033.808, -3970.7729999999997, -3905.152, -3836.857, -3765.796, -3691.8740000000003, -3614.991, -3535.0490000000004, -3451.945, -3365.574, -3275.83, -3182.607, -3085.8, -2985.303, -2881.0159999999996, -2772.841, -2660.687, -2544.473, -2424.1279999999997, -2299.598, -2170.846, -2037.858, -1900.6470000000002, -1759.259, -1613.7779999999998, -1464.3270000000002, -1311.079, -1154.259, -994.1439999999999, -831.068, -665.425, -497.656, -328.259, -157.767, 13.249, 184.2, 354.491, 523.5319999999999, 690.752, 855.615, 1017.6260000000001, 1176.343, 1331.38, 1482.411, 1629.1689999999999, 1771.4479999999999, 1909.096, 2042.0120000000002, 2170.139, 2293.4629999999997, 2412.002, 2525.802, 2634.934, 2739.488, 2839.566, 2935.284, 3026.764, 3114.135, 3197.5290000000005, 3277.0759999999996, 3352.9120000000003, 3425.1659999999997, 3493.969, 3559.446, 3621.722, 3680.915, 3737.1420000000003, 3790.514, 3841.138, 3889.117, 3934.552, 3977.5359999999996, 4018.1620000000003, 4056.514, 4092.677, 4126.731, 4158.751, 4188.811, 4216.979, 4243.323, 4267.905, 4290.786, 4312.024, 4331.675, 4349.791, 4366.423, 4381.62, 4395.429, 4407.892, 4419.054, 4428.954000000001, 4437.633, 4445.127, 4451.473, 4456.7029999999995, 4460.854, 4463.956, 4466.038, 4467.1320000000005, 4467.265, 4466.464, 4464.755, 4462.165, 4458.715999999999, 4454.432, 4449.335999999999, 4443.4490000000005, 4436.793, 4429.387, 4421.252, 4412.405, 4402.865, 4392.65, 4381.777, 4370.262, 4358.12, 4345.3679999999995, 4332.021, 4318.092000000001, 4303.596, 4288.545999999999, 4272.955, 4256.837, 4240.202, 4223.064, 4205.434, 4187.323, 4168.742, 4149.7029999999995, 4130.214, 4110.286, 4089.93, 4069.153, 4047.967, 4026.3790000000004, 4004.3990000000003, 3982.034, 3959.2940000000003, 3936.187, 3912.719, 3888.8990000000003, 3864.735, 3840.2329999999997, 3815.401, 3790.245, 3764.7740000000003, 3738.992, 3712.907, 3686.5240000000003, 3659.8509999999997, 3632.893, 3605.655, 3578.1440000000002, 3550.365, 3522.324, 3494.026, 3465.4759999999997, 3436.68, 3407.6420000000003, 3378.367, 3348.861, 3319.1279999999997, 3289.172, 3258.9990000000003, 3228.611, 3198.015, 3167.2140000000004, 3136.212, 3105.013, 3073.6220000000003, 3042.042, 3010.277, 2978.3309999999997, 2946.208, 2913.9109999999996, 2881.4440000000004, 2848.8109999999997, 2816.015, 2783.059, 2749.947, 2716.6820000000002, 2683.2670000000003, 2649.705, 2616.0, 2582.155, 2548.172, 2514.055, 2479.8070000000002, 2445.429, 2410.926, 2376.301, 2341.554, 2306.6910000000003, 2271.712, 2236.6220000000003, 2201.422, 2166.114, 2130.703, 2095.189, 2059.576, 2023.865, 1988.06, 1952.162, 1916.175, 1880.099, 1843.9389999999999, 1807.695, 1771.369, 1734.965, 1698.485, 1661.9289999999999, 1625.3020000000001, 1588.6029999999998, 1551.8370000000002, 1515.004, 1478.1070000000002, 1441.148, 1404.128, 1367.05, 1329.915, 1292.726, 1255.485, 1218.193, 1180.851, 1143.463, 1106.03, 1068.553, 1031.0339999999999, 993.4760000000001, 955.88, 918.247, 880.58, 842.88, 805.148, 767.388, 729.5989999999999, 691.784, 653.945, 616.0830000000001, 578.2, 540.297, 502.37699999999995, 464.44, 426.48800000000006, 388.523, 350.54699999999997, 312.561, 274.566, 236.56400000000002, 198.55700000000002, 160.547, 122.53399999999999, 84.52, 46.507, 8.497, -29.51, -67.512, -105.506, -143.49200000000002, -181.46900000000002, -219.43400000000003, -257.38599999999997, -295.324, -333.246, -371.151, -409.038, -446.904, -484.74800000000005, -522.57, -560.367, -598.137, -635.881, -673.595, -711.279, -748.931, -786.549, -824.133, -861.68, -899.19, -936.6610000000001, -974.091, -1011.4780000000001, -1048.822, -1086.121, -1123.374, -1160.578, -1197.733, -1234.837, -1271.888, -1308.885, -1345.8270000000002, -1382.7120000000002, -1419.5379999999998, -1456.3039999999999, -1493.009, -1529.651, -1566.2279999999998, -1602.7379999999998, -1639.182, -1675.555, -1711.859, -1748.089, -1784.246, -1820.3270000000002, -1856.3310000000001, -1892.257, -1928.102, -1963.865, -1999.545, -2035.139, -2070.646, -2106.065, -2141.394, -2176.631, -2211.774, -2246.822, -2281.7729999999997, -2316.625, -2351.377, -2386.027, -2420.572, -2455.012, -2489.344, -2523.567, -2557.678, -2591.676, -2625.56, -2659.3259999999996, -2692.973, -2726.5, -2759.9040000000005, -2793.184, -2826.337, -2859.361, -2892.2540000000004, -2925.015, -2957.6409999999996, -2990.13, -3022.48, -3054.6890000000003, -3086.7540000000004, -3118.6740000000004, -3150.447, -3182.0690000000004, -3213.539, -3244.855, -3276.014, -3307.013, -3337.8509999999997, -3368.525, -3399.033, -3429.3709999999996, -3459.539, -3489.532, -3519.348, -3548.985, -3578.441, -3607.712, -3636.795, -3665.688, -3694.389, -3722.893, -3751.199, -3779.303, -3807.203, -3834.895, -3862.3759999999997, -3889.643, -3916.6940000000004, -3943.5240000000003, -3970.131, -3996.51, -4022.659, -4048.575, -4074.2529999999997, -4099.69, -4124.883, -4149.827, -4174.519, -4198.955, -4223.1320000000005, -4247.045, -4270.69, -4294.063, -4317.16, -4339.976, -4362.508, -4384.751, -4406.6990000000005, -4428.349, -4449.696, -4470.735, -4491.46, -4511.8679999999995, -4531.9529999999995, -4551.71, -4571.1320000000005, -4590.215999999999, -4608.955, -4627.343, -4645.375, -4663.045, -4680.346, -4697.273, -4713.82, -4729.978, -4745.7429999999995, -4761.107, -4776.062, -4790.603, -4804.721, -4818.409000000001, -4831.659000000001, -4844.464, -4856.816, -4868.705, -4880.125, -4891.065, -4901.517, -4911.472, -4920.919, -4929.851, -4938.255999999999, -4946.124, -4953.446, -4960.21, -4966.405, -4972.019, -4977.04, -4981.458, -4985.259, -4988.431, -4990.96, -4992.832, -4994.034000000001, -4994.5509999999995, -4994.3679999999995, -4993.471, -4991.840999999999, -4989.465, -4986.3240000000005, -4982.402, -4977.679, -4972.138, -4965.759, -4958.523, -4950.407999999999, -4941.392, -4931.455, -4920.573, -4908.723, -4895.879, -4882.016, -4867.108, -4851.128, -4834.045999999999, -4815.833, -4796.459, -4775.891, -4754.097, -4731.042, -4706.69, -4681.003, -4653.944, -4625.47, -4595.542, -4564.1140000000005, -4531.14, -4496.575, -4460.366, -4422.465, -4382.815, -4341.362, -4298.045, -4252.807, -4205.58, -4156.3009999999995, -4104.9, -4051.305, -3995.44, -3937.23, -3876.592, -3813.4429999999998, -3747.696, -3679.262, -3608.047, -3533.9559999999997, -3456.8909999999996, -3376.7509999999997, -3293.434, -3206.837, -3116.8540000000003, -3023.383, -2926.3190000000004, -2825.563, -2721.0170000000003, -2612.593, -2500.2070000000003, -2383.7889999999998, -2263.281, -2138.645, -2009.862, -1876.941, -1739.921, -1598.875, -1453.92, -1305.2169999999999, -1152.976, -997.459, -838.987, -677.932, -514.72, -349.829, -183.774, -17.107, 149.601, 315.767, 480.81699999999995, 644.191, 805.3610000000001, 963.8389999999999, 1119.1860000000001, 1271.02, 1419.0120000000002, 1562.8970000000002, 1702.464, 1837.557, 1968.069, 2093.9410000000003, 2215.151, 2331.712, 2443.6639999999998, 2551.072, 2654.018, 2752.603, 2846.934, 2937.13, 3023.3140000000003, 3105.612, 3184.153, 3259.0640000000003, 3330.474, 3398.509, 3463.29, 3524.938, 3583.8340000000003, 3639.297, 3692.2290000000003, 3742.4709999999995, 3790.1220000000003, 3835.281, 3878.039, 3918.485, 3956.705, 3992.7790000000005, 4026.7859999999996, 4058.7990000000004, 4088.8909999999996, 4117.127, 4143.575, 4168.295, 4191.347, 4212.788, 4232.670999999999, 4251.05, 4267.972, 4283.487, 4297.638, 4310.471, 4322.026, 4332.343, 4341.46, 4349.415, 4356.2429999999995, 4361.976, 4366.649, 4370.291, 4372.934, 4374.604, 4375.331, 4375.142, 4374.06, 4372.111, 4369.32, 4365.709, 4361.299, 4356.112, 4350.169, 4343.49, 4336.093, 4327.997, 4319.22, 4309.778, 4299.69, 4288.971, 4277.6359999999995, 4265.7, 4253.178, 4240.085, 4226.432, 4212.236, 4197.5070000000005, 4182.259, 4166.503, 4150.252, 4133.516, 4116.307, 4098.635, 4080.511, 4061.945, 4042.947, 4023.526, 4003.6929999999998, 3983.454, 3962.821, 3941.8, 3920.401, 3898.631, 3876.5, 3854.013, 3831.18, 3808.007, 3784.5, 3760.6679999999997, 3736.5170000000003, 3712.053, 3687.284, 3662.215, 3636.853, 3611.204, 3585.2740000000003, 3559.067, 3532.591, 3505.85, 3478.85, 3451.5959999999995, 3424.094, 3396.347, 3368.362, 3340.1420000000003, 3311.6940000000004, 3283.0209999999997, 3254.1279999999997, 3225.0190000000002, 3195.699, 3166.172, 3136.442, 3106.513, 3076.389, 3046.075, 3015.574, 2984.889, 2954.025, 2922.986, 2891.7740000000003, 2860.393, 2828.847, 2797.139, 2765.2729999999997, 2733.2509999999997, 2701.078, 2668.756, 2636.2870000000003, 2603.677, 2570.926, 2538.0389999999998, 2505.018, 2471.866, 2438.5860000000002, 2405.181, 2371.653, 2338.006, 2304.241, 2270.362, 2236.371, 2202.27, 2168.062, 2133.75, 2099.3360000000002, 2064.822, 2030.211, 1995.505, 1960.707, 1925.818, 1890.8410000000001, 1855.7779999999998, 1820.631, 1785.4029999999998, 1750.095, 1714.711, 1679.251, 1643.7179999999998, 1608.114, 1572.44, 1536.7, 1500.895, 1465.026, 1429.0970000000002, 1393.108, 1357.0610000000001, 1320.9589999999998, 1284.803, 1248.596, 1212.338, 1176.0330000000001, 1139.681, 1103.2839999999999, 1066.844, 1030.363, 993.8430000000001, 957.284, 920.69, 884.062, 847.4, 810.7080000000001, 773.9860000000001, 737.237, 700.461, 663.6610000000001, 626.8380000000001, 589.994, 553.13, 516.247, 479.348, 442.434, 405.506, 368.56699999999995, 331.61699999999996, 294.657, 257.691, 220.718, 183.74099999999999, 146.762, 109.78, 72.79899999999999, 35.819, -1.158, -38.131, -75.097, -112.057, -149.007, -185.94799999999998, -222.87599999999998, -259.79200000000003, -296.693, -333.57800000000003, -370.44599999999997, -407.29400000000004, -444.12300000000005, -480.93, -517.7130000000001, -554.472, -591.206, -627.911, -664.5880000000001, -701.235, -737.85, -774.431, -810.9789999999999, -847.49, -883.9639999999999, -920.3989999999999, -956.794, -993.1469999999999, -1029.4569999999999, -1065.722, -1101.942, -1138.114, -1174.237, -1210.31, -1246.3310000000001, -1282.298, -1318.211, -1354.068, -1389.8670000000002, -1425.6070000000002, -1461.286, -1496.9029999999998, -1532.457, -1567.945, -1603.366, -1638.72, -1674.003, -1709.2160000000001, -1744.355, -1779.42, -1814.41, -1849.3210000000001, -1884.154, -1918.906, -1953.576, -1988.161, -2022.662, -2057.075, -2091.399, -2125.633, -2159.775, -2193.823, -2227.775, -2261.63, -2295.386, -2329.042, -2362.595, -2396.044, -2429.387, -2462.6220000000003, -2495.748, -2528.762, -2561.6620000000003, -2594.448, -2627.117, -2659.6659999999997, -2692.095, -2724.401, -2756.583, -2788.637, -2820.563, -2852.3579999999997, -2884.02, -2915.547, -2946.937, -2978.188, -3009.298, -3040.264, -3071.085, -3101.758, -3132.28, -3162.65, -3192.866, -3222.9240000000004, -3252.823, -3282.56, -3312.132, -3341.538, -3370.7740000000003, -3399.8390000000004, -3428.7290000000003, -3457.4429999999998, -3485.9759999999997, -3514.327, -3542.493, -3570.4709999999995, -3598.259, -3625.853, -3653.25, -3680.449, -3707.445, -3734.235, -3760.817, -3787.188, -3813.344, -3839.281, -3864.998, -3890.49, -3915.7529999999997, -3940.785, -3965.5820000000003, -3990.14, -4014.4559999999997, -4038.526, -4062.3459999999995, -4085.9120000000003, -4109.221, -4132.268, -4155.05, -4177.561, -4199.799, -4221.758, -4243.435, -4264.8240000000005, -4285.920999999999, -4306.721, -4327.22, -4347.414000000001, -4367.295999999999, -4386.862, -4406.106, -4425.024, -4443.61, -4461.858, -4479.763, -4497.318, -4514.519, -4531.359, -4547.832, -4563.931, -4579.651, -4594.984, -4609.924, -4624.464, -4638.596, -4652.313, -4665.609, -4678.475, -4690.904, -4702.887, -4714.417, -4725.484, -4736.08, -4746.197, -4755.825, -4764.954000000001, -4773.575, -4781.679, -4789.255, -4796.292, -4802.78, -4808.707, -4814.063, -4818.835999999999, -4823.013, -4826.583, -4829.531, -4831.846, -4833.513, -4834.519, -4834.849, -4834.4890000000005, -4833.4220000000005, -4831.6320000000005, -4829.105, -4825.822, -4821.767, -4816.92, -4811.264, -4804.778, -4797.444, -4789.24, -4780.145, -4770.1359999999995, -4759.192, -4747.287, -4734.397, -4720.495, -4705.558, -4689.555, -4672.458, -4654.2390000000005, -4634.865, -4614.305, -4592.524, -4569.49, -4545.164000000001, -4519.51, -4492.488, -4464.058, -4434.177, -4402.8009999999995, -4369.8820000000005, -4335.375, -4299.228, -4261.389, -4221.803, -4180.415, -4137.164000000001, -4091.989, -4044.825, -3995.607, -3944.262, -3890.72, -3834.9040000000005, -3776.736, -3716.134, -3653.014, -3587.288, -3518.866, -3447.655, -3373.558, -3296.4790000000003, -3216.316, -3132.969, -3046.336, -2956.312, -2862.797, -2765.6929999999998, -2664.9040000000005, -2560.34, -2451.919, -2339.569, -2223.231, -2102.863, -1978.445, -1849.9779999999998, -1717.496, -1581.065, -1440.7910000000002, -1296.823, -1149.359, -998.6469999999999, -844.988, -688.738, -530.307, -370.15, -208.764, -46.681999999999995, 115.542, 277.343, 438.159, 597.445, 754.681, 909.388, 1061.131, 1209.529, 1354.257, 1495.047, 1631.6860000000001, 1764.014, 1891.9229999999998, 2015.344, 2134.2529999999997, 2248.654, 2358.583, 2464.1, 2565.281, 2662.219, 2755.018, 2843.79, 2928.653, 3009.7290000000003, 3087.1420000000003, 3161.015, 3231.4709999999995, 3298.632, 3362.617, 3423.5440000000003, 3481.5240000000003, 3536.667, 3589.078, 3638.861, 3686.112, 3730.926, 3773.3920000000003, 3813.599, 3851.627, 3887.558, 3921.465, 3953.4240000000004, 3983.5, 4011.763, 4038.2740000000003, 4063.0959999999995, 4086.284, 4107.895, 4127.981, 4146.593, 4163.781, 4179.59, 4194.063, 4207.245, 4219.175, 4229.892, 4239.435, 4247.839, 4255.137, 4261.3640000000005, 4266.5509999999995, 4270.729, 4273.9259999999995, 4276.170999999999, 4277.49, 4277.911, 4277.457, 4276.154, 4274.023, 4271.088, 4267.371, 4262.892, 4257.67, 4251.726, 4245.077, 4237.7429999999995, 4229.741, 4221.087, 4211.798, 4201.888, 4191.374, 4180.271, 4168.593, 4156.353, 4143.565, 4130.241, 4116.395, 4102.038, 4087.183, 4071.841, 4056.0229999999997, 4039.74, 4023.002, 4005.82, 3988.203, 3970.1609999999996, 3951.703, 3932.8390000000004, 3913.577, 3893.927, 3873.8959999999997, 3853.493, 3832.725, 3811.6, 3790.1259999999997, 3768.3109999999997, 3746.16, 3723.6820000000002, 3700.884, 3677.7709999999997, 3654.35, 3630.6290000000004, 3606.612, 3582.3059999999996, 3557.717, 3532.85, 3507.712, 3482.308, 3456.6420000000003, 3430.7209999999995, 3404.5490000000004, 3378.132, 3351.474, 3324.5809999999997, 3297.4559999999997, 3270.1059999999998, 3242.533, 3214.743, 3186.74, 3158.528, 3130.112, 3101.495, 3072.6809999999996, 3043.675, 3014.48, 2985.1, 2955.538, 2925.7990000000004, 2895.886, 2865.802, 2835.551, 2805.137, 2774.562, 2743.829, 2712.9429999999998, 2681.906, 2650.722, 2619.3920000000003, 2587.9210000000003, 2556.312, 2524.5660000000003, 2492.688, 2460.679, 2428.544, 2396.283, 2363.9, 2331.3979999999997, 2298.78, 2266.047, 2233.202, 2200.249, 2167.188, 2134.0229999999997, 2100.757, 2067.39, 2033.9270000000001, 2000.368, 1966.717, 1932.975, 1899.145, 1865.229, 1831.229, 1797.1470000000002, 1762.985, 1728.745, 1694.43, 1660.0410000000002, 1625.58, 1591.05, 1556.4520000000002, 1521.7879999999998, 1487.0610000000001, 1452.271, 1417.421, 1382.513, 1347.5479999999998, 1312.529, 1277.4569999999999, 1242.333, 1207.161, 1171.94, 1136.674, 1101.364, 1066.011, 1030.617, 995.185, 959.7139999999999, 924.2080000000001, 888.668, 853.095, 817.492, 781.8589999999999, 746.198, 710.51, 674.799, 639.064, 603.307, 567.53, 531.735, 495.923, 460.095, 424.254, 388.399, 352.534, 316.659, 280.776, 244.887, 208.99200000000002, 173.093, 137.192, 101.29, 65.389, 29.49, -6.406000000000001, -42.297, -78.182, -114.059, -149.928, -185.785, -221.63099999999997, -257.464, -293.282, -329.084, -364.869, -400.634, -436.38, -472.10400000000004, -507.805, -543.482, -579.133, -614.757, -650.352, -685.918, -721.452, -756.954, -792.421, -827.8530000000001, -863.2489999999999, -898.6060000000001, -933.923, -969.2, -1004.434, -1039.624, -1074.769, -1109.867, -1144.9180000000001, -1179.9180000000001, -1214.868, -1249.766, -1284.61, -1319.399, -1354.131, -1388.805, -1423.4189999999999, -1457.9720000000002, -1492.463, -1526.89, -1561.2520000000002, -1595.547, -1629.773, -1663.9289999999999, -1698.014, -1732.026, -1765.964, -1799.825, -1833.609, -1867.3139999999999, -1900.9379999999999, -1934.479, -1967.9370000000001, -2001.309, -2034.595, -2067.791, -2100.897, -2133.911, -2166.8320000000003, -2199.657, -2232.384, -2265.014, -2297.542, -2329.968, -2362.291, -2394.507, -2426.616, -2458.615, -2490.5029999999997, -2522.279, -2553.939, -2585.482, -2616.907, -2648.211, -2679.3920000000003, -2710.449, -2741.38, -2772.1809999999996, -2802.853, -2833.3909999999996, -2863.795, -2894.062, -2924.191, -2954.178, -2984.022, -3013.72, -3043.2709999999997, -3072.672, -3101.921, -3131.015, -3159.952, -3188.73, -3217.3459999999995, -3245.798, -3274.083, -3302.199, -3330.1440000000002, -3357.914, -3385.506, -3412.92, -3440.15, -3467.196, -3494.053, -3520.72, -3547.1929999999998, -3573.47, -3599.547, -3625.422, -3651.09, -3676.55, -3701.798, -3726.8309999999997, -3751.645, -3776.237, -3800.6040000000003, -3824.742, -3848.6479999999997, -3872.3179999999998, -3895.7490000000003, -3918.9359999999997, -3941.8759999999997, -3964.565, -3987.0, -4009.175, -4031.087, -4052.7329999999997, -4074.107, -4095.205, -4116.023, -4136.557, -4156.8009999999995, -4176.751, -4196.403, -4215.751, -4234.79, -4253.515, -4271.9220000000005, -4290.004, -4307.755999999999, -4325.173, -4342.25, -4358.979, -4375.355, -4391.373, -4407.026, -4422.306, -4437.209, -4451.727, -4465.854, -4479.581, -4492.903, -4505.812, -4518.3, -4530.359, -4541.982, -4553.16, -4563.8859999999995, -4574.149, -4583.942, -4593.255, -4602.08, -4610.407, -4618.225, -4625.525, -4632.295999999999, -4638.527, -4644.209, -4649.329000000001, -4653.875, -4657.835999999999, -4661.1990000000005, -4663.952, -4666.08, -4667.572, -4668.413, -4668.588, -4668.083, -4666.8820000000005, -4664.969, -4662.3279999999995, -4658.943, -4654.795, -4649.867, -4644.14, -4637.594, -4630.21, -4621.965999999999, -4612.842000000001, -4602.815, -4591.862, -4579.959, -4567.081, -4553.2029999999995, -4538.298, -4522.338, -4505.294, -4487.1359999999995, -4467.834, -4447.355, -4425.664000000001, -4402.728, -4378.51, -4352.972, -4326.0740000000005, -4297.776, -4268.032999999999, -4236.802, -4204.037, -4169.688, -4133.705, -4096.036, -4056.6240000000003, -4015.414, -3972.343, -3927.353, -3880.375, -3831.343, -3780.187, -3726.833, -3671.204, -3613.222, -3552.805, -3489.866, -3424.32, -3356.074, -3285.035, -3211.1090000000004, -3134.197, -3054.199, -2971.0170000000003, -2884.55, -2794.698, -2701.364, -2604.453, -2503.876, -2399.552, -2291.408, -2179.383, -2063.433, -1943.5339999999999, -1819.683, -1691.9070000000002, -1560.265, -1424.852, -1285.808, -1143.315, -997.607, -848.9689999999999, -697.74, -544.308, -389.11, -232.62400000000002, -75.362, 82.141, 239.33599999999998, 395.67699999999996, 550.633, 703.694, 854.39, 1002.2919999999999, 1147.022, 1288.257, 1425.729, 1559.223, 1688.5770000000002, 1813.6760000000002, 1934.45, 2050.866, 2162.925, 2270.657, 2374.113, 2473.366, 2568.5029999999997, 2659.62, 2746.8259999999996, 2830.2329999999997, 2909.9570000000003, 2986.118, 3058.8340000000003, 3128.224, 3194.405, 3257.493, 3317.6009999999997, 3374.8379999999997, 3429.308, 3481.116, 3530.361, 3577.136, 3621.535, 3663.643, 3703.546, 3741.323, 3777.054, 3810.809, 3842.6609999999996, 3872.676, 3900.92, 3927.453, 3952.336, 3975.6240000000003, 3997.37, 4017.6279999999997, 4036.445, 4053.87, 4069.947, 4084.719, 4098.229, 4110.515, 4121.616, 4131.568, 4140.406, 4148.164000000001, 4154.873, 4160.566, 4165.271, 4169.017, 4171.832, 4173.74, 4174.77, 4174.944, 4174.286, 4172.819, 4170.564, 4167.543, 4163.776, 4159.282999999999, 4154.082, 4148.191, 4141.629, 4134.411, 4126.556, 4118.0779999999995, 4108.9929999999995, 4099.316, 4089.0609999999997, 4078.242, 4066.8720000000003, 4054.966, 4042.534, 4029.591, 4016.1459999999997, 4002.212, 3987.801, 3972.923, 3957.5890000000004, 3941.808, 3925.592, 3908.949, 3891.889, 3874.421, 3856.554, 3838.296, 3819.657, 3800.643, 3781.264, 3761.527, 3741.44, 3721.01, 3700.243, 3679.1479999999997, 3657.7309999999998, 3635.998, 3613.9559999999997, 3591.612, 3568.9709999999995, 3546.04, 3522.8259999999996, 3499.3320000000003, 3475.565, 3451.531, 3427.2340000000004, 3402.6809999999996, 3377.8759999999997, 3352.824, 3327.53, 3301.9990000000003, 3276.235, 3250.245, 3224.03, 3197.598, 3170.95, 3144.093, 3117.03, 3089.764, 3062.301, 3034.6440000000002, 3006.796, 2978.762, 2950.545, 2922.1490000000003, 2893.577, 2864.833, 2835.921, 2806.843, 2777.603, 2748.204, 2718.651, 2688.9429999999998, 2659.0879999999997, 2629.0840000000003, 2598.939, 2568.653, 2538.229, 2507.67, 2476.979, 2446.16, 2415.2129999999997, 2384.143, 2352.952, 2321.6420000000003, 2290.215, 2258.675, 2227.024, 2195.265, 2163.3979999999997, 2131.428, 2099.356, 2067.185, 2034.9170000000001, 2002.5529999999999, 1970.0970000000002, 1937.5510000000002, 1904.9160000000002, 1872.195, 1839.389, 1806.5020000000002, 1773.5339999999999, 1740.489, 1707.3670000000002, 1674.171, 1640.9029999999998, 1607.565, 1574.1589999999999, 1540.6860000000001, 1507.148, 1473.5479999999998, 1439.886, 1406.1660000000002, 1372.388, 1338.555, 1304.6680000000001, 1270.728, 1236.738, 1202.7, 1168.614, 1134.483, 1100.309, 1066.0919999999999, 1031.835, 997.539, 963.206, 928.837, 894.435, 859.9989999999999, 825.533, 791.0369999999999, 756.513, 721.9630000000001, 687.388, 652.79, 618.17, 583.529, 548.87, 514.193, 479.5, 444.793, 410.07199999999995, 375.339, 340.597, 305.845, 271.086, 236.321, 201.55200000000002, 166.77900000000002, 132.004, 97.229, 62.455, 27.683000000000003, -7.086, -41.849, -76.60600000000001, -111.355, -146.095, -180.825, -215.542, -250.247, -284.937, -319.611, -354.26800000000003, -388.907, -423.525, -458.12199999999996, -492.69699999999995, -527.248, -561.773, -596.2719999999999, -630.743, -665.185, -699.596, -733.975, -768.32, -802.6310000000001, -836.9060000000001, -871.143, -905.342, -939.5010000000001, -973.618, -1007.692, -1041.722, -1075.7069999999999, -1109.644, -1143.5339999999999, -1177.373, -1211.161, -1244.897, -1278.579, -1312.2060000000001, -1345.776, -1379.287, -1412.739, -1446.13, -1479.4589999999998, -1512.724, -1545.9229999999998, -1579.056, -1612.12, -1645.114, -1678.0379999999998, -1710.888, -1743.664, -1776.364, -1808.987, -1841.531, -1873.995, -1906.3770000000002, -1938.675, -1970.888, -2003.014, -2035.0520000000001, -2067.0, -2098.856, -2130.619, -2162.2870000000003, -2193.859, -2225.3320000000003, -2256.705, -2287.9770000000003, -2319.144, -2350.2070000000003, -2381.163, -2412.01, -2442.745, -2473.369, -2503.8779999999997, -2534.271, -2564.5460000000003, -2594.702, -2624.735, -2654.6440000000002, -2684.427, -2714.0820000000003, -2743.6079999999997, -2773.0009999999997, -2802.26, -2831.384, -2860.369, -2889.2129999999997, -2917.915, -2946.473, -2974.883, -3003.1440000000002, -3031.2529999999997, -3059.208, -3087.007, -3114.647, -3142.1259999999997, -3169.442, -3196.591, -3223.571, -3250.381, -3277.0159999999996, -3303.475, -3329.755, -3355.8520000000003, -3381.765, -3407.491, -3433.025, -3458.367, -3483.512, -3508.458, -3533.202, -3557.74, -3582.0690000000004, -3606.187, -3630.0890000000004, -3653.7729999999997, -3677.235, -3700.4709999999995, -3723.4790000000003, -3746.2540000000004, -3768.7929999999997, -3791.091, -3813.147, -3834.954, -3856.511, -3877.8109999999997, -3898.8520000000003, -3919.6290000000004, -3940.138, -3960.375, -3980.336, -4000.014, -4019.407, -4038.509, -4057.316, -4075.823, -4094.0229999999997, -4111.914000000001, -4129.488, -4146.741, -4163.668, -4180.262, -4196.518, -4212.43, -4227.992, -4243.1990000000005, -4258.043, -4272.518, -4286.6179999999995, -4300.335, -4313.664000000001, -4326.596, -4339.125, -4351.242, -4362.941, -4374.213, -4385.0509999999995, -4395.446, -4405.39, -4414.874, -4423.888, -4432.425, -4440.473, -4448.024, -4455.067, -4461.592000000001, -4467.589, -4473.0470000000005, -4477.954000000001, -4482.3, -4486.071, -4489.255, -4491.840999999999, -4493.814, -4495.162, -4495.87, -4495.925, -4495.312, -4494.014, -4492.017, -4489.304, -4485.859, -4481.663, -4476.6990000000005, -4470.948, -4464.391, -4457.0070000000005, -4448.777, -4439.679, -4429.69, -4418.787, -4406.947, -4394.144, -4380.354, -4365.548, -4349.6990000000005, -4332.779, -4314.758, -4295.603, -4275.282999999999, -4253.764, -4231.01, -4206.986, -4181.652, -4154.97, -4126.898, -4097.392, -4066.408, -4033.8990000000003, -3999.8140000000003, -3964.1059999999998, -3926.719, -3887.598, -3846.6859999999997, -3803.921, -3759.242, -3712.5820000000003, -3663.873, -3613.046, -3560.0240000000003, -3504.732, -3447.09, -3387.0159999999996, -3324.4240000000004, -3259.2259999999997, -3191.3320000000003, -3120.6479999999997, -3047.08, -2970.53, -2890.901, -2808.0959999999995, -2722.0159999999996, -2632.565, -2539.652, -2443.187, -2343.089, -2239.284, -2131.712, -2020.326, -1905.098, -1786.021, -1663.115, -1536.431, -1406.057, -1272.119, -1134.787, -994.2810000000001, -850.8689999999999, -704.87, -556.655, -406.639, -255.28, -103.07, 49.475, 201.827, 353.454, 503.839, 652.485, 798.931, 942.7560000000001, 1083.586, 1221.101, 1355.0320000000002, 1485.164, 1611.3310000000001, 1733.4160000000002, 1851.3429999999998, 1965.075, 2074.607, 2179.9629999999997, 2281.189, 2378.351, 2471.529, 2560.815, 2646.312, 2728.125, 2806.367, 2881.151, 2952.59, 3020.8, 3085.8940000000002, 3147.9809999999998, 3207.172, 3263.705, 3317.281, 3368.402, 3417.028, 3463.252, 3507.1620000000003, 3548.844, 3588.3779999999997, 3625.844, 3661.315, 3694.863, 3726.5570000000002, 3756.462, 3784.6409999999996, 3811.153, 3836.0570000000002, 3859.406, 3881.2529999999997, 3901.6479999999997, 3920.64, 3938.2729999999997, 3954.592, 3969.639, 3983.454, 3996.077, 4007.5409999999997, 4017.886, 4027.1440000000002, 4035.348, 4042.528, 4048.716, 4053.94, 4058.228, 4061.6059999999998, 4064.1, 4065.735, 4066.535, 4066.5229999999997, 4065.72, 4064.147, 4061.8259999999996, 4058.776, 4055.0159999999996, 4050.565, 4045.44, 4039.658, 4033.236, 4026.19, 4018.535, 4010.2870000000003, 4001.46, 3992.067, 3982.123, 3971.64, 3960.631, 3949.1090000000004, 3937.086, 3924.573, 3911.5809999999997, 3898.1220000000003, 3884.205, 3869.842, 3855.0409999999997, 3839.8140000000003, 3824.1690000000003, 3808.115, 3791.6609999999996, 3774.816, 3757.5890000000004, 3739.988, 3722.02, 3703.6940000000004, 3685.0159999999996, 3665.995, 3646.638, 3626.9509999999996, 3606.941, 3586.615, 3565.98, 3545.0409999999997, 3523.805, 3502.2790000000005, 3480.467, 3458.3759999999997, 3436.012, 3413.3790000000004, 3390.4829999999997, 3367.33, 3343.9240000000004, 3320.2709999999997, 3296.375, 3272.241, 3247.8740000000003, 3223.278, 3198.4590000000003, 3173.42, 3148.165, 3122.699, 3097.026, 3071.15, 3045.0759999999996, 3018.8059999999996, 2992.345, 2965.696, 2938.863, 2911.8509999999997, 2884.6609999999996, 2857.298, 2829.7659999999996, 2802.066, 2774.204, 2746.1809999999996, 2718.0009999999997, 2689.6679999999997, 2661.184, 2632.552, 2603.775, 2574.856, 2545.799, 2516.605, 2487.278, 2457.819, 2428.2329999999997, 2398.521, 2368.687, 2338.731, 2308.659, 2278.47, 2248.169, 2217.757, 2187.237, 2156.611, 2125.882, 2095.051, 2064.1220000000003, 2033.095, 2001.974, 1970.76, 1939.4560000000001, 1908.0629999999999, 1876.585, 1845.0220000000002, 1813.376, 1781.651, 1749.8470000000002, 1717.967, 1686.0120000000002, 1653.985, 1621.8870000000002, 1589.721, 1557.487, 1525.1879999999999, 1492.826, 1460.402, 1427.918, 1395.376, 1362.7779999999998, 1330.125, 1297.4180000000001, 1264.661, 1231.854, 1198.998, 1166.096, 1133.149, 1100.1589999999999, 1067.127, 1034.056, 1000.945, 967.797, 934.6139999999999, 901.3969999999999, 868.148, 834.867, 801.557, 768.2189999999999, 734.8539999999999, 701.4639999999999, 668.05, 634.614, 601.158, 567.682, 534.188, 500.67699999999996, 467.151, 433.61199999999997, 400.06, 366.496, 332.92400000000004, 299.343, 265.754, 232.16099999999997, 198.563, 164.96200000000002, 131.36, 97.757, 64.155, 30.555999999999997, -3.0389999999999997, -36.629, -70.21300000000001, -103.79, -137.357, -170.91400000000002, -204.46, -237.99200000000002, -271.51, -305.013, -338.499, -371.967, -405.415, -438.843, -472.249, -505.631, -538.989, -572.321, -605.626, -638.9019999999999, -672.148, -705.3639999999999, -738.546, -771.696, -804.81, -837.887, -870.928, -903.929, -936.8889999999999, -969.809, -1002.685, -1035.517, -1068.303, -1101.042, -1133.733, -1166.374, -1198.965, -1231.502, -1263.987, -1296.415, -1328.7879999999998, -1361.102, -1393.3570000000002, -1425.5520000000001, -1457.684, -1489.753, -1521.757, -1553.694, -1585.5629999999999, -1617.3629999999998, -1649.0929999999998, -1680.75, -1712.3329999999999, -1743.8410000000001, -1775.273, -1806.626, -1837.899, -1869.0910000000001, -1900.201, -1931.225, -1962.164, -1993.015, -2023.777, -2054.448, -2085.026, -2115.511, -2145.9, -2176.1910000000003, -2206.383, -2236.474, -2266.4629999999997, -2296.348, -2326.126, -2355.7960000000003, -2385.357, -2414.8070000000002, -2444.143, -2473.363, -2502.467, -2531.452, -2560.3160000000003, -2589.0570000000002, -2617.673, -2646.1620000000003, -2674.5229999999997, -2702.7529999999997, -2730.849, -2758.8109999999997, -2786.635, -2814.32, -2841.864, -2869.264, -2896.518, -2923.623, -2950.578, -2977.381, -3004.028, -3030.5170000000003, -3056.8459999999995, -3083.012, -3109.014, -3134.847, -3160.511, -3186.0009999999997, -3211.317, -3236.453, -3261.409, -3286.1809999999996, -3310.7670000000003, -3335.163, -3359.366, -3383.3740000000003, -3407.183, -3430.7909999999997, -3454.1940000000004, -3477.388, -3500.3720000000003, -3523.1409999999996, -3545.692, -3568.0209999999997, -3590.1259999999997, -3612.002, -3633.6459999999997, -3655.054, -3676.222, -3697.147, -3717.824, -3738.25, -3758.42, -3778.3309999999997, -3797.9770000000003, -3817.3559999999998, -3836.461, -3855.29, -3873.836, -3892.0959999999995, -3910.0640000000003, -3927.736, -3945.1059999999998, -3962.17, -3978.921, -3995.3559999999998, -4011.467, -4027.25, -4042.699, -4057.808, -4072.571, -4086.982, -4101.032999999999, -4114.72, -4128.034000000001, -4140.97, -4153.521, -4165.678, -4177.435, -4188.784000000001, -4199.717000000001, -4210.227, -4220.306, -4229.944, -4239.134, -4247.866, -4256.1320000000005, -4263.920999999999, -4271.225, -4278.032999999999, -4284.335, -4290.121, -4295.38, -4300.101, -4304.273, -4307.883, -4310.919, -4313.369000000001, -4315.22, -4316.458, -4317.071, -4317.043, -4316.36, -4315.005999999999, -4312.967000000001, -4310.225, -4306.765, -4302.568, -4297.6179999999995, -4291.894, -4285.377, -4278.05, -4269.889, -4260.875, -4250.985, -4240.195, -4228.481, -4215.82, -4202.186, -4187.5509999999995, -4171.888, -4155.167, -4137.36, -4118.434, -4098.357, -4077.094, -4054.613, -4030.8740000000003, -4005.84, -3979.47, -3951.725, -3922.559, -3891.928, -3859.785, -3826.0809999999997, -3790.763, -3753.7790000000005, -3715.074, -3674.587, -3632.261, -3588.0290000000005, -3541.828, -3493.5879999999997, -3443.237, -3390.703, -3335.907, -3278.77, -3219.2090000000003, -3157.138, -3092.4709999999995, -3025.116, -2954.982, -2881.973, -2805.9959999999996, -2726.955, -2644.7529999999997, -2559.297, -2470.496, -2378.262, -2282.514, -2183.18, -2080.197, -1973.515, -1863.104, -1748.953, -1631.0770000000002, -1509.519, -1384.355, -1255.703, -1123.719, -988.6080000000001, -850.6210000000001, -710.06, -567.273, -422.658, -276.651, -129.722, 17.634, 164.90599999999998, 311.58099999999996, 457.157, 601.15, 743.11, 882.623, 1019.321, 1152.887, 1283.0539999999999, 1409.606, 1532.375, 1651.24, 1766.122, 1876.977, 1983.797, 2086.598, 2185.423, 2280.328, 2371.39, 2458.694, 2542.337, 2622.4190000000003, 2699.045, 2772.325, 2842.369, 2909.284, 2973.179, 3034.1620000000003, 3092.337, 3147.804, 3200.663, 3251.009, 3298.9359999999997, 3344.53, 3387.88, 3429.0640000000003, 3468.164, 3505.255, 3540.407, 3573.6929999999998, 3605.175, 3634.92, 3662.987, 3689.434, 3714.316, 3737.688, 3759.599, 3780.097, 3799.23, 3817.0429999999997, 3833.5759999999996, 3848.8709999999996, 3862.968, 3875.9040000000005, 3887.7140000000004, 3898.433, 3908.094, 3916.7290000000003, 3924.368, 3931.039, 3936.772, 3941.593, 3945.528, 3948.6020000000003, 3950.8390000000004, 3952.261, 3952.893, 3952.7529999999997, 3951.864, 3950.245, 3947.915, 3944.893, 3941.197, 3936.844, 3931.85, 3926.232, 3920.0040000000004, 3913.183, 3905.783, 3897.817, 3889.3, 3880.245, 3870.664, 3860.5690000000004, 3849.974, 3838.888, 3827.323, 3815.292, 3802.803, 3789.868, 3776.4959999999996, 3762.698, 3748.4809999999998, 3733.857, 3718.833, 3703.4179999999997, 3687.62, 3671.449, 3654.9109999999996, 3638.015, 3620.768, 3603.177, 3585.25, 3566.994, 3548.415, 3529.52, 3510.316, 3490.808, 3471.0040000000004, 3450.908, 3430.527, 3409.867, 3388.933, 3367.73, 3346.264, 3324.5409999999997, 3302.565, 3280.341, 3257.875, 3235.17, 3212.232, 3189.065, 3165.673, 3142.0609999999997, 3118.2340000000004, 3094.195, 3069.948, 3045.498, 3020.848, 2996.0029999999997, 2970.965, 2945.74, 2920.329, 2894.738, 2868.969, 2843.026, 2816.9120000000003, 2790.631, 2764.1859999999997, 2737.579, 2710.815, 2683.8959999999997, 2656.8259999999996, 2629.6059999999998, 2602.241, 2574.732, 2547.084, 2519.297, 2491.377, 2463.324, 2435.141, 2406.8320000000003, 2378.399, 2349.844, 2321.169, 2292.3779999999997, 2263.472, 2234.455, 2205.327, 2176.092, 2146.752, 2117.3089999999997, 2087.765, 2058.123, 2028.384, 1998.5510000000002, 1968.626, 1938.61, 1908.506, 1878.316, 1848.0420000000001, 1817.6860000000001, 1787.249, 1756.734, 1726.142, 1695.476, 1664.737, 1633.9270000000001, 1603.047, 1572.1, 1541.088, 1510.011, 1478.872, 1447.6729999999998, 1416.415, 1385.1, 1353.729, 1322.3039999999999, 1290.827, 1259.299, 1227.722, 1196.098, 1164.427, 1132.712, 1100.954, 1069.155, 1037.316, 1005.438, 973.5239999999999, 941.574, 909.59, 877.574, 845.5260000000001, 813.449, 781.3439999999999, 749.211, 717.053, 684.872, 652.6669999999999, 620.441, 588.195, 555.931, 523.649, 491.352, 459.04, 426.715, 394.37699999999995, 362.03, 329.673, 297.308, 264.936, 232.55900000000003, 200.178, 167.794, 135.409, 103.024, 70.639, 38.257, 5.879, -26.495, -58.861999999999995, -91.22200000000001, -123.574, -155.915, -188.245, -220.563, -252.86700000000002, -285.156, -317.42900000000003, -349.685, -381.92199999999997, -414.13800000000003, -446.334, -478.50699999999995, -510.656, -542.781, -574.879, -606.95, -638.992, -671.0039999999999, -702.9839999999999, -734.933, -766.847, -798.7260000000001, -830.569, -862.3739999999999, -894.1410000000001, -925.867, -957.552, -989.194, -1020.7919999999999, -1052.344, -1083.85, -1115.308, -1146.7160000000001, -1178.0739999999998, -1209.38, -1240.633, -1271.8310000000001, -1302.973, -1334.058, -1365.0829999999999, -1396.049, -1426.954, -1457.795, -1488.5729999999999, -1519.2839999999999, -1549.9289999999999, -1580.505, -1611.011, -1641.4460000000001, -1671.808, -1702.095, -1732.307, -1762.442, -1792.4979999999998, -1822.473, -1852.3670000000002, -1882.1770000000001, -1911.9029999999998, -1941.5420000000001, -1971.0929999999998, -2000.5539999999999, -2029.925, -2059.202, -2088.385, -2117.471, -2146.46, -2175.349, -2204.137, -2232.822, -2261.402, -2289.876, -2318.241, -2346.4970000000003, -2374.64, -2402.67, -2430.584, -2458.381, -2486.058, -2513.614, -2541.0460000000003, -2568.354, -2595.534, -2622.5840000000003, -2649.5029999999997, -2676.289, -2702.9390000000003, -2729.4509999999996, -2755.823, -2782.053, -2808.139, -2834.078, -2859.868, -2885.506, -2910.991, -2936.32, -2961.491, -2986.5, -3011.3459999999995, -3036.026, -3060.5370000000003, -3084.877, -3109.042, -3133.031, -3156.841, -3180.468, -3203.91, -3227.163, -3250.2259999999997, -3273.095, -3295.7659999999996, -3318.237, -3340.5040000000004, -3362.565, -3384.4159999999997, -3406.053, -3427.474, -3448.6740000000004, -3469.65, -3490.3979999999997, -3510.9159999999997, -3531.198, -3551.242, -3571.0429999999997, -3590.598, -3609.901, -3628.95, -3647.74, -3666.2659999999996, -3684.5240000000003, -3702.509, -3720.217, -3737.643, -3754.783, -3771.631, -3788.1820000000002, -3804.4320000000002, -3820.375, -3836.005, -3851.317, -3866.305, -3880.9640000000004, -3895.2870000000003, -3909.2690000000002, -3922.903, -3936.183, -3949.1020000000003, -3961.6540000000005, -3973.8320000000003, -3985.6279999999997, -3997.0359999999996, -4008.048, -4018.656, -4028.853, -4038.631, -4047.98, -4056.8940000000002, -4065.362, -4073.377, -4080.928, -4088.007, -4094.603, -4100.707, -4106.309, -4111.397, -4115.96, -4119.988, -4123.468, -4126.388, -4128.737, -4130.501, -4131.668, -4132.223, -4132.153, -4131.442, -4130.076, -4128.04, -4125.316, -4121.889, -4117.742, -4112.857, -4107.214, -4100.795999999999, -4093.5809999999997, -4085.55, -4076.6820000000002, -4066.954, -4056.343, -4044.827, -4032.3779999999997, -4018.973, -4004.5840000000003, -3989.185, -3972.745, -3955.2340000000004, -3936.623, -3916.877, -3895.9640000000004, -3873.848, -3850.491, -3825.857, -3799.905, -3772.593, -3743.877, -3713.7140000000004, -3682.054, -3648.849, -3614.047, -3577.5959999999995, -3539.437, -3499.514, -3457.7659999999996, -3414.127, -3368.535, -3320.917, -3271.204, -3219.322, -3165.192, -3108.735, -3049.868, -2988.508, -2924.565, -2857.952, -2788.575, -2716.343, -2641.163, -2562.9410000000003, -2481.5879999999997, -2397.01, -2309.123, -2217.847, -2123.109, -2024.844, -1923.005, -1817.5539999999999, -1708.4779999999998, -1595.786, -1479.514, -1359.729, -1236.538, -1110.0839999999998, -980.555, -848.189, -713.2669999999999, -576.118, -437.11800000000005, -296.681, -155.257, -13.32, 128.64, 270.13, 410.661, 549.766, 687.0039999999999, 821.972, 954.309, 1083.701, 1209.882, 1332.6370000000002, 1451.797, 1567.2379999999998, 1678.876, 1786.664, 1890.5870000000002, 1990.656, 2086.906, 2179.391, 2268.179, 2353.349, 2434.993, 2513.2039999999997, 2588.083, 2659.7340000000004, 2728.26, 2793.764, 2856.3520000000003, 2916.125, 2973.1820000000002, 3027.6220000000003, 3079.539, 3129.026, 3176.17, 3221.0570000000002, 3263.77, 3304.388, 3342.986, 3379.637, 3414.4120000000003, 3447.3759999999997, 3478.594, 3508.127, 3536.033, 3562.369, 3587.188, 3610.5409999999997, 3632.4770000000003, 3653.0440000000003, 3672.2859999999996, 3690.245, 3706.9640000000004, 3722.482, 3736.836, 3750.062, 3762.195, 3773.2690000000002, 3783.316, 3792.366, 3800.448, 3807.591, 3813.822, 3819.1659999999997, 3823.65, 3827.297, 3830.1290000000004, 3832.171, 3833.4429999999998, 3833.966, 3833.76, 3832.844, 3831.236, 3828.955, 3826.018, 3822.441, 3818.242, 3813.434, 3808.034, 3802.0559999999996, 3795.514, 3788.422, 3780.7909999999997, 3772.637, 3763.9709999999995, 3754.804, 3745.15, 3735.018, 3724.4190000000003, 3713.365, 3701.866, 3689.9309999999996, 3677.57, 3664.7929999999997, 3651.6079999999997, 3638.026, 3624.053, 3609.7, 3594.973, 3579.881, 3564.4309999999996, 3548.632, 3532.49, 3516.012, 3499.2059999999997, 3482.077, 3464.634, 3446.882, 3428.827, 3410.4759999999997, 3391.835, 3372.909, 3353.705, 3334.2270000000003, 3314.4809999999998, 3294.472, 3274.2059999999997, 3253.688, 3232.922, 3211.914, 3190.667, 3169.188, 3147.4790000000003, 3125.547, 3103.3940000000002, 3081.025, 3058.445, 3035.658, 3012.6659999999997, 2989.475, 2966.0879999999997, 2942.509, 2918.741, 2894.788, 2870.655, 2846.343, 2821.857, 2797.199, 2772.3740000000003, 2747.384, 2722.2329999999997, 2696.923, 2671.4570000000003, 2645.8390000000004, 2620.072, 2594.158, 2568.1, 2541.901, 2515.563, 2489.09, 2462.484, 2435.748, 2408.884, 2381.894, 2354.782, 2327.549, 2300.199, 2272.732, 2245.152, 2217.462, 2189.6620000000003, 2161.756, 2133.745, 2105.633, 2077.42, 2049.109, 2020.703, 1992.2020000000002, 1963.61, 1934.9279999999999, 1906.158, 1877.3020000000001, 1848.3629999999998, 1819.3410000000001, 1790.239, 1761.058, 1731.8010000000002, 1702.469, 1673.0639999999999, 1643.588, 1614.0420000000001, 1584.4289999999999, 1554.749, 1525.005, 1495.1979999999999, 1465.33, 1435.4029999999998, 1405.4170000000001, 1375.376, 1345.279, 1315.13, 1284.9289999999999, 1254.678, 1224.378, 1194.032, 1163.639, 1133.203, 1102.724, 1072.204, 1041.645, 1011.047, 980.4119999999999, 949.742, 919.0369999999999, 888.3, 857.5319999999999, 826.7339999999999, 795.908, 765.054, 734.174, 703.27, 672.3430000000001, 641.394, 610.424, 579.435, 548.428, 517.404, 486.365, 455.31199999999995, 424.24699999999996, 393.16900000000004, 362.08099999999996, 330.985, 299.88, 268.769, 237.653, 206.532, 175.40900000000002, 144.284, 113.15899999999999, 82.03399999999999, 50.912, 19.793, -11.321, -42.43, -73.532, -104.626, -135.71, -166.78400000000002, -197.84599999999998, -228.895, -259.93, -290.949, -321.952, -352.93699999999995, -383.903, -414.849, -445.774, -476.676, -507.55400000000003, -538.4069999999999, -569.234, -600.033, -630.804, -661.544, -692.2539999999999, -722.931, -753.575, -784.184, -814.757, -845.293, -875.79, -906.247, -936.664, -967.038, -997.3689999999999, -1027.655, -1057.894, -1088.087, -1118.231, -1148.325, -1178.368, -1208.359, -1238.295, -1268.177, -1298.002, -1327.77, -1357.4779999999998, -1387.126, -1416.7120000000002, -1446.235, -1475.693, -1505.086, -1534.411, -1563.668, -1592.854, -1621.969, -1651.011, -1679.9779999999998, -1708.87, -1737.684, -1766.4189999999999, -1795.0739999999998, -1823.6470000000002, -1852.1370000000002, -1880.5420000000001, -1908.86, -1937.09, -1965.231, -1993.28, -2021.236, -2049.098, -2076.864, -2104.532, -2132.101, -2159.5679999999998, -2186.933, -2214.1929999999998, -2241.346, -2268.391, -2295.326, -2322.15, -2348.859, -2375.453, -2401.93, -2428.2870000000003, -2454.5229999999997, -2480.636, -2506.623, -2532.4829999999997, -2558.2129999999997, -2583.812, -2609.278, -2634.6079999999997, -2659.8, -2684.8520000000003, -2709.761, -2734.526, -2759.1440000000002, -2783.613, -2807.9309999999996, -2832.094, -2856.1009999999997, -2879.949, -2903.636, -2927.158, -2950.514, -2973.7009999999996, -2996.716, -3019.5559999999996, -3042.219, -3064.7009999999996, -3087.0009999999997, -3109.114, -3131.038, -3152.77, -3174.3070000000002, -3195.645, -3216.782, -3237.715, -3258.4390000000003, -3278.9509999999996, -3299.248, -3319.327, -3339.184, -3358.815, -3378.216, -3397.384, -3416.315, -3435.005, -3453.449, -3471.6440000000002, -3489.585, -3507.268, -3524.6890000000003, -3541.842, -3558.725, -3575.3309999999997, -3591.656, -3607.696, -3623.4440000000004, -3638.8959999999997, -3654.047, -3668.8909999999996, -3683.422, -3697.636, -3711.525, -3725.085, -3738.309, -3751.19, -3763.724, -3775.901, -3787.718, -3799.1659999999997, -3810.237, -3820.926, -3831.224, -3841.1240000000003, -3850.618, -3859.697, -3868.3540000000003, -3876.58, -3884.365, -3891.7009999999996, -3898.58, -3904.99, -3910.923, -3916.367, -3921.313, -3925.75, -3929.6659999999997, -3933.05, -3935.889, -3938.1740000000004, -3939.889, -3941.0229999999997, -3941.562, -3941.491, -3940.798, -3939.466, -3937.48, -3934.824, -3931.482, -3927.438, -3922.672, -3917.1679999999997, -3910.906, -3903.866, -3896.028, -3887.3720000000003, -3877.8740000000003, -3867.513, -3856.264, -3844.103, -3831.0040000000004, -3816.941, -3801.887, -3785.813, -3768.687, -3750.4809999999998, -3731.16, -3710.6929999999998, -3689.042, -3666.17, -3642.0409999999997, -3616.615, -3589.849, -3561.699, -3532.1220000000003, -3501.0690000000004, -3468.491, -3434.337, -3398.552, -3361.08, -3321.865, -3280.843, -3237.952, -3193.125, -3146.295, -3097.387, -3046.3309999999997, -2993.046, -2937.4559999999997, -2879.4759999999997, -2819.0240000000003, -2756.012, -2690.3520000000003, -2621.954, -2550.729, -2476.584, -2399.4320000000002, -2319.183, -2235.7529999999997, -2149.064, -2059.04, -1965.62, -1868.7520000000002, -1768.3970000000002, -1664.5379999999998, -1557.1789999999999, -1446.3470000000002, -1332.102, -1214.539, -1093.789, -970.0269999999999, -843.4689999999999, -714.3810000000001, -583.072, -449.89599999999996, -315.248, -179.549, -43.255, 93.166, 229.239, 364.49300000000005, 498.477, 630.762, 760.955, 888.701, 1013.694, 1135.6680000000001, 1254.41, 1369.751, 1481.5610000000001, 1589.757, 1694.285, 1795.125, 1892.2820000000002, 1985.786, 2075.685, 2162.0389999999998, 2244.924, 2324.422, 2400.6220000000003, 2473.62, 2543.512, 2610.3979999999997, 2674.375, 2735.5429999999997, 2793.9990000000003, 2849.837, 2903.173, 2954.035, 3002.574, 3048.8520000000003, 3092.9509999999996, 3134.953, 3174.93, 3212.958, 3249.105, 3283.44, 3316.0240000000003, 3346.922, 3376.19, 3403.886, 3430.063, 3454.7740000000003, 3478.067, 3499.99, 3520.586, 3539.902, 3557.9770000000003, 3574.8509999999997, 3590.5609999999997, 3605.145, 3618.638, 3631.073, 3642.4809999999998, 3652.895, 3662.342, 3670.8520000000003, 3678.452, 3685.1679999999997, 3691.025, 3696.047, 3700.259, 3703.6809999999996, 3706.335, 3708.244, 3709.426, 3709.9, 3709.6859999999997, 3708.801, 3707.263, 3705.0879999999997, 3702.2909999999997, 3698.89, 3694.8990000000003, 3690.333, 3685.205, 3679.5290000000005, 3673.3190000000004, 3666.587, 3659.345, 3651.6059999999998, 3643.381, 3634.68, 3625.5159999999996, 3615.8979999999997, 3605.837, 3595.343, 3584.426, 3573.094, 3561.3579999999997, 3549.225, 3536.704, 3523.804, 3510.533, 3496.8979999999997, 3482.908, 3468.5690000000004, 3453.889, 3438.8759999999997, 3423.535, 3407.875, 3391.901, 3375.619, 3359.0370000000003, 3342.159, 3324.993, 3307.5429999999997, 3289.815, 3271.815, 3253.5490000000004, 3235.0209999999997, 3216.236, 3197.2, 3177.9179999999997, 3158.393, 3138.632, 3118.638, 3098.4159999999997, 3077.97, 3057.305, 3036.425, 3015.333, 2994.034, 2972.532, 2950.8309999999997, 2928.934, 2906.8459999999995, 2884.5690000000004, 2862.107, 2839.4640000000004, 2816.6440000000002, 2793.6490000000003, 2770.482, 2747.1479999999997, 2723.6490000000003, 2699.988, 2676.1679999999997, 2652.1929999999998, 2628.065, 2603.7870000000003, 2579.362, 2554.792, 2530.0820000000003, 2505.232, 2480.246, 2455.126, 2429.876, 2404.4970000000003, 2378.992, 2353.363, 2327.613, 2301.744, 2275.758, 2249.659, 2223.447, 2197.125, 2170.696, 2144.161, 2117.5229999999997, 2090.784, 2063.945, 2037.009, 2009.9779999999998, 1982.854, 1955.639, 1928.3339999999998, 1900.942, 1873.464, 1845.9029999999998, 1818.259, 1790.536, 1762.735, 1734.856, 1706.904, 1678.878, 1650.78, 1622.6129999999998, 1594.378, 1566.076, 1537.71, 1509.281, 1480.79, 1452.2379999999998, 1423.629, 1394.9620000000002, 1366.24, 1337.465, 1308.636, 1279.757, 1250.829, 1221.8519999999999, 1192.829, 1163.761, 1134.649, 1105.494, 1076.299, 1047.0639999999999, 1017.791, 988.4810000000001, 959.1360000000001, 929.757, 900.345, 870.9010000000001, 841.427, 811.924, 782.3939999999999, 752.837, 723.2560000000001, 693.65, 664.023, 634.374, 604.705, 575.0169999999999, 545.311, 515.59, 485.853, 456.103, 426.34, 396.565, 366.781, 336.98699999999997, 307.185, 277.377, 247.56400000000002, 217.74599999999998, 187.925, 158.102, 128.278, 98.455, 68.634, 38.815, 9.0, -20.81, -50.613, -80.40899999999999, -110.197, -139.975, -169.74099999999999, -199.49599999999998, -229.238, -258.965, -288.677, -318.372, -348.05, -377.708, -407.346, -436.963, -466.55800000000005, -496.129, -525.675, -555.195, -584.688, -614.153, -643.589, -672.993, -702.3660000000001, -731.706, -761.012, -790.283, -819.5169999999999, -848.7130000000001, -877.87, -906.987, -936.063, -965.096, -994.085, -1023.029, -1051.927, -1080.778, -1109.579, -1138.3310000000001, -1167.031, -1195.6789999999999, -1224.2730000000001, -1252.812, -1281.2939999999999, -1309.719, -1338.085, -1366.39, -1394.6329999999998, -1422.8139999999999, -1450.93, -1478.981, -1506.964, -1534.879, -1562.724, -1590.4979999999998, -1618.1989999999998, -1645.826, -1673.3770000000002, -1700.852, -1728.2479999999998, -1755.5629999999999, -1782.7979999999998, -1809.9489999999998, -1837.016, -1863.997, -1890.891, -1917.695, -1944.408, -1971.029, -1997.556, -2023.9879999999998, -2050.322, -2076.558, -2102.692, -2128.725, -2154.653, -2180.475, -2206.19, -2231.795, -2257.2889999999998, -2282.67, -2307.936, -2333.084, -2358.114, -2383.024, -2407.81, -2432.472, -2457.007, -2481.413, -2505.688, -2529.8289999999997, -2553.8360000000002, -2577.705, -2601.435, -2625.0229999999997, -2648.466, -2671.763, -2694.9109999999996, -2717.908, -2740.7509999999997, -2763.438, -2785.967, -2808.3340000000003, -2830.5370000000003, -2852.573, -2874.441, -2896.136, -2917.657, -2939.0, -2960.163, -2981.1420000000003, -3001.935, -3022.538, -3042.949, -3063.164, -3083.18, -3102.995, -3122.603, -3142.0029999999997, -3161.19, -3180.1609999999996, -3198.9120000000003, -3217.44, -3235.741, -3253.8109999999997, -3271.6459999999997, -3289.242, -3306.594, -3323.7, -3340.554, -3357.152, -3373.49, -3389.563, -3405.366, -3420.8940000000002, -3436.143, -3451.1079999999997, -3465.783, -3480.163, -3494.243, -3508.018, -3521.4809999999998, -3534.627, -3547.45, -3559.9429999999998, -3572.1020000000003, -3583.9179999999997, -3595.386, -3606.4990000000003, -3617.2490000000003, -3627.631, -3637.636, -3647.257, -3656.486, -3665.315, -3673.736, -3681.742, -3689.322, -3696.469, -3703.173, -3709.425, -3715.215, -3720.533, -3725.369, -3729.711, -3733.55, -3736.8740000000003, -3739.671, -3741.929, -3743.636, -3744.78, -3745.3459999999995, -3745.321, -3744.691, -3743.441, -3741.5570000000002, -3739.022, -3735.8190000000004, -3731.934, -3727.347, -3722.042, -3715.9990000000003, -3709.198, -3701.6209999999996, -3693.244, -3684.048, -3674.009, -3663.105, -3651.31, -3638.6, -3624.948, -3610.325, -3594.705, -3578.058, -3560.3520000000003, -3541.555, -3521.633, -3500.551, -3478.2740000000003, -3454.762, -3429.9770000000003, -3403.875, -3376.414, -3347.55, -3317.2340000000004, -3285.417, -3252.048, -3217.074, -3180.437, -3142.08, -3101.942, -3059.96, -3016.0679999999998, -2970.195, -2922.2729999999997, -2872.2259999999997, -2819.978, -2765.4509999999996, -2708.562, -2649.23, -2587.367, -2522.887, -2455.7039999999997, -2385.728, -2312.873, -2237.052, -2158.1839999999997, -2076.189, -1990.995, -1902.5379999999998, -1810.765, -1715.6370000000002, -1617.131, -1515.245, -1410.0020000000002, -1301.452, -1189.678, -1074.8010000000002, -956.9780000000001, -836.413, -713.3480000000001, -588.075, -460.925, -332.26800000000003, -202.50799999999998, -72.075, 58.583999999999996, 189.014, 318.764, 447.397, 574.501, 699.69, 822.6210000000001, 942.9910000000001, 1060.539, 1175.055, 1286.365, 1394.344, 1498.898, 1599.974, 1697.545, 1791.612, 1882.1989999999998, 1969.344, 2053.107, 2133.552, 2210.758, 2284.8070000000002, 2355.7889999999998, 2423.794, 2488.916, 2551.248, 2610.884, 2667.914, 2722.433, 2774.526, 2824.281, 2871.781, 2917.1079999999997, 2960.34, 3001.552, 3040.816, 3078.204, 3113.781, 3147.612, 3179.757, 3210.277, 3239.228, 3266.6620000000003, 3292.633, 3317.19, 3340.38, 3362.248, 3382.837, 3402.19, 3420.3459999999995, 3437.343, 3453.217, 3468.0040000000004, 3481.737, 3494.449, 3506.17, 3516.929, 3526.755, 3535.675, 3543.717, 3550.9040000000005, 3557.261, 3562.8109999999997, 3567.577, 3571.5809999999997, 3574.841, 3577.38, 3579.216, 3580.368, 3580.8540000000003, 3580.69, 3579.895, 3578.482, 3576.469, 3573.87, 3570.699, 3566.972, 3562.7, 3557.8979999999997, 3552.578, 3546.752, 3540.433, 3533.631, 3526.3579999999997, 3518.6240000000003, 3510.441, 3501.817, 3492.764, 3483.2909999999997, 3473.407, 3463.12, 3452.441, 3441.377, 3429.937, 3418.1279999999997, 3405.958, 3393.4359999999997, 3380.5679999999998, 3367.362, 3353.825, 3339.9629999999997, 3325.783, 3311.2909999999997, 3296.495, 3281.4, 3266.011, 3250.336, 3234.38, 3218.1479999999997, 3201.645, 3184.8779999999997, 3167.8509999999997, 3150.5690000000004, 3133.0370000000003, 3115.26, 3097.242, 3078.989, 3060.505, 3041.7940000000003, 3022.861, 3003.7090000000003, 2984.343, 2964.7670000000003, 2944.985, 2925.0009999999997, 2904.8179999999998, 2884.44, 2863.8709999999996, 2843.115, 2822.1740000000004, 2801.053, 2779.7540000000004, 2758.282, 2736.638, 2714.827, 2692.8520000000003, 2670.715, 2648.4190000000003, 2625.968, 2603.365, 2580.611, 2557.7110000000002, 2534.666, 2511.479, 2488.153, 2464.6910000000003, 2441.095, 2417.368, 2393.512, 2369.529, 2345.423, 2321.194, 2296.846, 2272.381, 2247.801, 2223.1079999999997, 2198.305, 2173.393, 2148.375, 2123.252, 2098.028, 2072.703, 2047.28, 2021.761, 1996.1470000000002, 1970.442, 1944.645, 1918.76, 1892.7879999999998, 1866.731, 1840.5910000000001, 1814.369, 1788.067, 1761.6879999999999, 1735.2320000000002, 1708.701, 1682.0970000000002, 1655.422, 1628.6770000000001, 1601.864, 1574.985, 1548.04, 1521.0320000000002, 1493.961, 1466.8310000000001, 1439.641, 1412.394, 1385.0910000000001, 1357.733, 1330.3220000000001, 1302.86, 1275.347, 1247.785, 1220.1760000000002, 1192.521, 1164.8210000000001, 1137.077, 1109.292, 1081.465, 1053.6, 1025.6960000000001, 997.755, 969.778, 941.768, 913.7239999999999, 885.6489999999999, 857.543, 829.408, 801.2439999999999, 773.054, 744.8389999999999, 716.5980000000001, 688.335, 660.05, 631.744, 603.418, 575.0740000000001, 546.7130000000001, 518.336, 489.94300000000004, 461.537, 433.119, 404.689, 376.24800000000005, 347.798, 319.341, 290.876, 262.406, 233.93099999999998, 205.452, 176.97099999999998, 148.489, 120.006, 91.525, 63.045, 34.569, 6.097, -22.37, -50.83, -79.283, -107.727, -136.162, -164.585, -192.99599999999998, -221.395, -249.77900000000002, -278.14799999999997, -306.5, -334.835, -363.152, -391.44800000000004, -419.724, -447.978, -476.209, -504.415, -532.597, -560.752, -588.879, -616.9780000000001, -645.047, -673.085, -701.091, -729.064, -757.002, -784.905, -812.7710000000001, -840.6, -868.3889999999999, -896.138, -923.846, -951.512, -979.1339999999999, -1006.711, -1034.241, -1061.725, -1089.16, -1116.545, -1143.879, -1171.162, -1198.39, -1225.5639999999999, -1252.682, -1279.743, -1306.745, -1333.6870000000001, -1360.569, -1387.388, -1414.1429999999998, -1440.8329999999999, -1467.4560000000001, -1494.0120000000002, -1520.499, -1546.915, -1573.259, -1599.53, -1625.726, -1651.8470000000002, -1677.889, -1703.852, -1729.735, -1755.536, -1781.253, -1806.885, -1832.431, -1857.888, -1883.256, -1908.5320000000002, -1933.715, -1958.8039999999999, -1983.796, -2008.691, -2033.486, -2058.18, -2082.77, -2107.256, -2131.636, -2155.907, -2180.067, -2204.116, -2228.051, -2251.87, -2275.571, -2299.153, -2322.613, -2345.949, -2369.16, -2392.243, -2415.195, -2438.016, -2460.703, -2483.2529999999997, -2505.665, -2527.935, -2550.063, -2572.045, -2593.879, -2615.563, -2637.093, -2658.469, -2679.6859999999997, -2700.743, -2721.637, -2742.365, -2762.925, -2783.313, -2803.527, -2823.565, -2843.422, -2863.0959999999995, -2882.5840000000003, -2901.883, -2920.99, -2939.901, -2958.613, -2977.123, -2995.428, -3013.5229999999997, -3031.406, -3049.072, -3066.518, -3083.74, -3100.7340000000004, -3117.4959999999996, -3134.0229999999997, -3150.31, -3166.3520000000003, -3182.1459999999997, -3197.6859999999997, -3212.969, -3227.99, -3242.744, -3257.2259999999997, -3271.4309999999996, -3285.3540000000003, -3298.99, -3312.3340000000003, -3325.38, -3338.1220000000003, -3350.554, -3362.672, -3374.468, -3385.9359999999997, -3397.07, -3407.864, -3418.31, -3428.402, -3438.133, -3447.495, -3456.48, -3465.0820000000003, -3473.292, -3481.1020000000003, -3488.5040000000004, -3495.488, -3502.046, -3508.17, -3513.848, -3519.072, -3523.8309999999997, -3528.116, -3531.914, -3535.216, -3538.01, -3540.284, -3542.026, -3543.223, -3543.863, -3543.9320000000002, -3543.4159999999997, -3542.301, -3540.572, -3538.212, -3535.2070000000003, -3531.54, -3527.1940000000004, -3522.151, -3516.393, -3509.9, -3502.653, -3494.63, -3485.8109999999997, -3476.173, -3465.6929999999998, -3454.347, -3442.11, -3428.9570000000003, -3414.8579999999997, -3399.7870000000003, -3383.7140000000004, -3366.6090000000004, -3348.438, -3329.17, -3308.7690000000002, -3287.198, -3264.421, -3240.397, -3215.086, -3188.442, -3160.423, -3130.982, -3100.0679999999998, -3067.631, -3033.617, -2997.9709999999995, -2960.635, -2921.547, -2880.6440000000002, -2837.862, -2793.132, -2746.382, -2697.5409999999997, -2646.531, -2593.275, -2537.694, -2479.703, -2419.221, -2356.161, -2290.44, -2221.973, -2150.675, -2076.467, -1999.27, -1919.013, -1835.632, -1749.0729999999999, -1659.2939999999999, -1566.271, -1469.993, -1370.48, -1267.772, -1161.943, -1053.099, -941.385, -826.9860000000001, -710.128, -591.0790000000001, -470.151, -347.69, -224.076, -99.71799999999999, 24.962, 149.53, 273.553, 396.61300000000006, 518.31, 638.273, 756.1669999999999, 871.696, 984.6030000000001, 1094.68, 1201.755, 1305.6989999999998, 1406.4170000000001, 1503.852, 1597.971, 1688.7720000000002, 1776.2679999999998, 1860.4979999999998, 1941.509, 2019.3629999999998, 2094.131, 2165.89, 2234.722, 2300.7129999999997, 2363.948, 2424.518, 2482.508, 2538.009, 2591.103, 2641.8759999999997, 2690.41, 2736.783, 2781.075, 2823.357, 2863.703, 2902.1809999999996, 2938.8590000000004, 2973.798, 3007.062, 3038.708, 3068.7940000000003, 3097.3720000000003, 3124.493, 3150.208, 3174.565, 3197.607, 3219.3790000000004, 3239.921, 3259.275, 3277.4770000000003, 3294.565, 3310.572, 3325.533, 3339.48, 3352.4429999999998, 3364.453, 3375.5359999999996, 3385.722, 3395.035, 3403.5, 3411.143, 3417.987, 3424.052, 3429.362, 3433.9359999999997, 3437.795, 3440.9570000000003, 3443.442, 3445.2659999999996, 3446.448, 3447.0040000000004, 3446.949, 3446.3, 3445.07, 3443.275, 3440.928, 3438.042, 3434.632, 3430.7090000000003, 3426.285, 3421.373, 3415.9840000000004, 3410.1279999999997, 3403.817, 3397.06, 3389.869, 3382.252, 3374.22, 3365.781, 3356.9429999999998, 3347.717, 3338.111, 3328.132, 3317.788, 3307.0879999999997, 3296.039, 3284.647, 3272.921, 3260.867, 3248.492, 3235.802, 3222.804, 3209.5040000000004, 3195.908, 3182.022, 3167.8520000000003, 3153.403, 3138.6809999999996, 3123.691, 3108.4390000000003, 3092.929, 3077.167, 3061.157, 3044.905, 3028.414, 3011.69, 2994.736, 2977.558, 2960.159, 2942.5429999999997, 2924.715, 2906.678, 2888.437, 2869.995, 2851.355, 2832.5229999999997, 2813.5, 2794.2909999999997, 2774.8990000000003, 2755.328, 2735.58, 2715.659, 2695.5679999999998, 2675.31, 2654.888, 2634.3059999999996, 2613.565, 2592.67, 2571.6220000000003, 2550.425, 2529.0820000000003, 2507.594, 2485.965, 2464.197, 2442.2929999999997, 2420.255, 2398.0860000000002, 2375.788, 2353.364, 2330.815, 2308.144, 2285.354, 2262.446, 2239.423, 2216.286, 2193.0389999999998, 2169.683, 2146.22, 2122.652, 2098.981, 2075.21, 2051.339, 2027.372, 2003.309, 1979.1529999999998, 1954.905, 1930.568, 1906.1429999999998, 1881.632, 1857.036, 1832.358, 1807.599, 1782.76, 1757.844, 1732.852, 1707.785, 1682.645, 1657.434, 1632.1529999999998, 1606.805, 1581.389, 1555.908, 1530.364, 1504.757, 1479.089, 1453.362, 1427.578, 1401.736, 1375.84, 1349.889, 1323.8870000000002, 1297.833, 1271.729, 1245.578, 1219.379, 1193.134, 1166.845, 1140.513, 1114.138, 1087.723, 1061.269, 1034.777, 1008.247, 981.682, 955.082, 928.449, 901.784, 875.0880000000001, 848.363, 821.6080000000001, 794.827, 768.0189999999999, 741.186, 714.329, 687.449, 660.548, 633.626, 606.685, 579.725, 552.748, 525.755, 498.74699999999996, 471.725, 444.69, 417.644, 390.587, 363.52, 336.445, 309.363, 282.274, 255.18, 228.082, 200.98, 173.877, 146.77200000000002, 119.66799999999999, 92.564, 65.46300000000001, 38.365, 11.270999999999999, -15.817, -42.898999999999994, -69.97399999999999, -97.04, -124.09700000000001, -151.143, -178.178, -205.2, -232.208, -259.202, -286.18, -313.14099999999996, -340.084, -367.00800000000004, -393.912, -420.79400000000004, -447.655, -474.49300000000005, -501.306, -528.094, -554.855, -581.589, -608.294, -634.97, -661.6139999999999, -688.227, -714.807, -741.3530000000001, -767.8639999999999, -794.3380000000001, -820.775, -847.173, -873.5319999999999, -899.85, -926.1260000000001, -952.3580000000001, -978.547, -1004.69, -1030.786, -1056.835, -1082.835, -1108.7839999999999, -1134.682, -1160.528, -1186.32, -1212.056, -1237.737, -1263.36, -1288.924, -1314.4279999999999, -1339.871, -1365.251, -1390.567, -1415.818, -1441.0020000000002, -1466.119, -1491.1660000000002, -1516.142, -1541.047, -1565.878, -1590.634, -1615.3139999999999, -1639.9160000000002, -1664.44, -1688.882, -1713.243, -1737.52, -1761.711, -1785.817, -1809.8339999999998, -1833.761, -1857.596, -1881.339, -1904.987, -1928.539, -1951.993, -1975.3470000000002, -1998.6, -2021.75, -2044.795, -2067.7329999999997, -2090.563, -2113.282, -2135.89, -2158.383, -2180.76, -2203.019, -2225.159, -2247.176, -2269.069, -2290.837, -2312.476, -2333.984, -2355.361, -2376.6020000000003, -2397.7070000000003, -2418.672, -2439.496, -2460.175, -2480.709, -2501.094, -2521.327, -2541.407, -2561.33, -2581.094, -2600.697, -2620.135, -2639.406, -2658.507, -2677.435, -2696.188, -2714.761, -2733.153, -2751.36, -2769.3790000000004, -2787.2059999999997, -2804.8379999999997, -2822.2729999999997, -2839.506, -2856.534, -2873.353, -2889.96, -2906.3520000000003, -2922.5229999999997, -2938.4709999999995, -2954.191, -2969.679, -2984.9309999999996, -2999.9429999999998, -3014.71, -3029.228, -3043.493, -3057.498, -3071.241, -3084.715, -3097.9159999999997, -3110.8390000000004, -3123.478, -3135.828, -3147.883, -3159.637, -3171.085, -3182.2209999999995, -3193.038, -3203.53, -3213.69, -3223.512, -3232.99, -3242.115, -3250.881, -3259.2790000000005, -3267.303, -3274.9440000000004, -3282.195, -3289.046, -3295.489, -3301.5159999999996, -3307.116, -3312.28, -3317.0, -3321.263, -3325.0609999999997, -3328.382, -3331.2140000000004, -3333.548, -3335.3709999999996, -3336.67, -3337.433, -3337.6459999999997, -3337.297, -3336.3709999999996, -3334.853, -3332.728, -3329.9809999999998, -3326.595, -3322.554, -3317.841, -3312.4359999999997, -3306.323, -3299.4790000000003, -3291.887, -3283.5240000000003, -3274.368, -3264.397, -3253.587, -3241.913, -3229.35, -3215.8709999999996, -3201.449, -3186.052, -3169.653, -3152.217, -3133.7140000000004, -3114.1090000000004, -3093.366, -3071.446, -3048.31, -3023.9190000000003, -2998.2290000000003, -2971.196, -2942.7729999999997, -2912.9109999999996, -2881.559, -2848.665, -2814.173, -2778.025, -2740.1609999999996, -2700.5190000000002, -2659.034, -2615.637, -2570.26, -2522.8289999999997, -2473.27, -2421.506, -2367.458, -2311.0460000000003, -2252.187, -2190.802, -2126.805, -2060.119, -1990.6629999999998, -1918.36, -1843.142, -1764.942, -1683.7089999999998, -1599.395, -1511.975, -1421.434, -1327.785, -1231.06, -1131.3210000000001, -1028.665, -923.2189999999999, -815.154, -704.677, -592.034, -477.515, -361.445, -244.178, -126.09899999999999, -7.608, 110.883, 228.96400000000003, 346.23199999999997, 462.30400000000003, 576.823, 689.462, 799.934, 907.9910000000001, 1013.421, 1116.057, 1215.767, 1312.4579999999999, 1406.0639999999999, 1496.55, 1583.908, 1668.146, 1749.297, 1827.4, 1902.514, 1974.6989999999998, 2044.029, 2110.578, 2174.425, 2235.653, 2294.343, 2350.578, 2404.44, 2456.008, 2505.468, 2552.583, 2597.741, 2640.91, 2682.163, 2721.565, 2759.1820000000002, 2795.079, 2829.315, 2861.948, 2893.033, 2922.625, 2950.775, 2977.532, 3002.942, 3027.05, 3049.901, 3071.534, 3091.99, 3111.3059999999996, 3129.5190000000002, 3146.663, 3162.7709999999997, 3177.877, 3192.009, 3205.198, 3217.472, 3228.8579999999997, 3239.381, 3249.066, 3257.9390000000003, 3266.0209999999997, 3273.335, 3279.903, 3285.744, 3290.8779999999997, 3295.325, 3299.103, 3302.228, 3304.719, 3306.592, 3307.863, 3308.546, 3308.658, 3308.211, 3307.219, 3305.697, 3303.657, 3301.11, 3298.07, 3294.547, 3290.555, 3286.1020000000003, 3281.2, 3275.8590000000004, 3270.0879999999997, 3263.8990000000003, 3257.2990000000004, 3250.298, 3242.9040000000005, 3235.127, 3226.975, 3218.455, 3209.5759999999996, 3200.344, 3190.768, 3180.855, 3170.611, 3160.0429999999997, 3149.159, 3137.965, 3126.466, 3114.6690000000003, 3102.58, 3090.205, 3077.55, 3064.619, 3051.4190000000003, 3037.954, 3024.23, 3010.2509999999997, 2996.0229999999997, 2981.551, 2966.8379999999997, 2951.89, 2936.711, 2921.3059999999996, 2905.678, 2889.8320000000003, 2873.7709999999997, 2857.5009999999997, 2841.0240000000003, 2824.344, 2807.466, 2790.3920000000003, 2773.127, 2755.6740000000004, 2738.0359999999996, 2720.216, 2702.219, 2684.047, 2665.703, 2647.191, 2628.513, 2609.672, 2590.672, 2571.515, 2552.2039999999997, 2532.742, 2513.131, 2493.375, 2473.475, 2453.4339999999997, 2433.255, 2412.94, 2392.492, 2371.9139999999998, 2351.206, 2330.373, 2309.415, 2288.3360000000002, 2267.137, 2245.82, 2224.389, 2202.844, 2181.188, 2159.423, 2137.551, 2115.574, 2093.494, 2071.312, 2049.031, 2026.652, 2004.1779999999999, 1981.61, 1958.95, 1936.1989999999998, 1913.359, 1890.433, 1867.421, 1844.326, 1821.149, 1797.891, 1774.555, 1751.141, 1727.652, 1704.089, 1680.453, 1656.746, 1632.97, 1609.125, 1585.214, 1561.237, 1537.1970000000001, 1513.094, 1488.931, 1464.707, 1440.4260000000002, 1416.0870000000002, 1391.693, 1367.244, 1342.7420000000002, 1318.1889999999999, 1293.585, 1268.932, 1244.231, 1219.484, 1194.691, 1169.854, 1144.973, 1120.0510000000002, 1095.089, 1070.087, 1045.047, 1019.9689999999999, 994.8560000000001, 969.7080000000001, 944.5260000000001, 919.312, 894.066, 868.79, 843.485, 818.1519999999999, 792.7919999999999, 767.4060000000001, 741.9960000000001, 716.561, 691.1039999999999, 665.6260000000001, 640.127, 614.6080000000001, 589.071, 563.5169999999999, 537.947, 512.361, 486.76099999999997, 461.147, 435.522, 409.885, 384.23900000000003, 358.583, 332.91900000000004, 307.248, 281.57099999999997, 255.889, 230.202, 204.513, 178.822, 153.129, 127.43700000000001, 101.745, 76.055, 50.368, 24.686, -0.992, -26.664, -52.33, -77.987, -103.635, -129.274, -154.901, -180.517, -206.12, -231.709, -257.283, -282.841, -308.383, -333.906, -359.411, -384.89599999999996, -410.35900000000004, -435.801, -461.22, -486.615, -511.985, -537.3290000000001, -562.646, -587.935, -613.194, -638.424, -663.622, -688.788, -713.92, -739.0189999999999, -764.081, -789.107, -814.096, -839.045, -863.955, -888.824, -913.6510000000001, -938.434, -963.174, -987.868, -1012.515, -1037.115, -1061.665, -1086.1660000000002, -1110.615, -1135.012, -1159.356, -1183.644, -1207.877, -1232.052, -1256.1689999999999, -1280.226, -1304.222, -1328.156, -1352.026, -1375.832, -1399.5710000000001, -1423.243, -1446.846, -1470.378, -1493.84, -1517.2279999999998, -1540.5420000000001, -1563.78, -1586.941, -1610.024, -1633.026, -1655.9470000000001, -1678.785, -1701.539, -1724.2060000000001, -1746.786, -1769.276, -1791.6760000000002, -1813.983, -1836.1970000000001, -1858.3139999999999, -1880.335, -1902.256, -1924.076, -1945.7939999999999, -1967.4070000000002, -1988.915, -2010.3139999999999, -2031.6029999999998, -2052.781, -2073.845, -2094.7929999999997, -2115.624, -2136.3360000000002, -2156.925, -2177.391, -2197.732, -2217.944, -2238.027, -2257.9770000000003, -2277.792, -2297.471, -2317.01, -2336.408, -2355.6620000000003, -2374.769, -2393.7270000000003, -2412.534, -2431.187, -2449.683, -2468.02, -2486.194, -2504.2039999999997, -2522.045, -2539.716, -2557.2129999999997, -2574.533, -2591.673, -2608.631, -2625.402, -2641.9829999999997, -2658.3720000000003, -2674.5640000000003, -2690.5559999999996, -2706.344, -2721.926, -2737.297, -2752.452, -2767.39, -2782.1040000000003, -2796.592, -2810.849, -2824.87, -2838.652, -2852.1890000000003, -2865.478, -2878.512, -2891.289, -2903.801, -2916.046, -2928.0159999999996, -2939.708, -2951.115, -2962.2309999999998, -2973.051, -2983.57, -2993.78, -3003.675, -3013.2490000000003, -3022.4959999999996, -3031.408, -3039.978, -3048.199, -3056.065, -3063.566, -3070.695, -3077.4440000000004, -3083.805, -3089.768, -3095.3259999999996, -3100.468, -3105.185, -3109.467, -3113.305, -3116.687, -3119.6040000000003, -3122.0440000000003, -3123.995, -3125.445, -3126.382, -3126.7929999999997, -3126.6659999999997, -3125.985, -3124.738, -3122.909, -3120.4829999999997, -3117.4440000000004, -3113.776, -3109.461, -3104.4829999999997, -3098.823, -3092.461, -3085.3779999999997, -3077.553, -3068.9640000000004, -3059.59, -3049.406, -3038.39, -3026.514, -3013.7529999999997, -3000.08, -2985.467, -2969.883, -2953.296, -2935.675, -2916.986, -2897.1929999999998, -2876.258, -2854.1440000000002, -2830.8109999999997, -2806.215, -2780.312, -2753.0570000000002, -2724.402, -2694.295, -2662.685, -2629.518, -2594.735, -2558.278, -2520.084, -2480.089, -2438.2270000000003, -2394.43, -2348.624, -2300.737, -2250.694, -2198.417, -2143.8289999999997, -2086.85, -2027.402, -1965.406, -1900.7839999999999, -1833.463, -1763.375, -1690.453, -1614.645, -1535.905, -1454.1979999999999, -1369.5120000000002, -1281.85, -1191.235, -1097.724, -1001.398, -902.3710000000001, -800.796, -696.863, -590.799, -482.86699999999996, -373.37199999999996, -262.644, -151.041, -38.942, 73.267, 185.19400000000002, 296.45799999999997, 406.691, 515.5509999999999, 622.7230000000001, 727.928, 830.923, 931.502, 1029.497, 1124.778, 1217.247, 1306.836, 1393.509, 1477.249, 1558.06, 1635.9679999999998, 1711.0079999999998, 1783.227, 1852.6860000000001, 1919.4460000000001, 1983.578, 2045.154, 2104.251, 2160.9429999999998, 2215.3089999999997, 2267.424, 2317.364, 2365.202, 2411.012, 2454.864, 2496.826, 2536.965, 2575.344, 2612.026, 2647.0690000000004, 2680.532, 2712.469, 2742.9309999999996, 2771.9709999999995, 2799.636, 2825.974, 2851.027, 2874.84, 2897.452, 2918.903, 2939.23, 2958.469, 2976.655, 2993.821, 3009.9970000000003, 3025.215, 3039.5040000000004, 3052.8909999999996, 3065.402, 3077.065, 3087.903, 3097.941, 3107.2, 3115.704, 3123.472, 3130.525, 3136.884, 3142.565, 3147.5879999999997, 3151.97, 3155.728, 3158.8779999999997, 3161.435, 3163.415, 3164.8320000000003, 3165.7009999999996, 3166.034, 3165.845, 3165.147, 3163.9509999999996, 3162.27, 3160.115, 3157.498, 3154.428, 3150.9159999999997, 3146.973, 3142.6079999999997, 3137.83, 3132.65, 3127.075, 3121.114, 3114.777, 3108.07, 3101.002, 3093.5809999999997, 3085.813, 3077.7070000000003, 3069.2690000000002, 3060.506, 3051.425, 3042.033, 3032.335, 3022.337, 3012.047, 3001.469, 2990.61, 2979.474, 2968.0679999999998, 2956.3959999999997, 2944.4640000000004, 2932.276, 2919.8379999999997, 2907.1540000000005, 2894.23, 2881.0690000000004, 2867.676, 2854.0559999999996, 2840.212, 2826.1490000000003, 2811.8709999999996, 2797.382, 2782.685, 2767.785, 2752.685, 2737.389, 2721.9, 2706.222, 2690.3579999999997, 2674.312, 2658.087, 2641.685, 2625.111, 2608.367, 2591.456, 2574.382, 2557.146, 2539.7529999999997, 2522.2039999999997, 2504.5029999999997, 2486.651, 2468.653, 2450.51, 2432.225, 2413.8, 2395.238, 2376.541, 2357.712, 2338.752, 2319.665, 2300.452, 2281.116, 2261.659, 2242.083, 2222.389, 2202.581, 2182.66, 2162.6279999999997, 2142.487, 2122.239, 2101.886, 2081.429, 2060.8720000000003, 2040.215, 2019.46, 1998.609, 1977.664, 1956.626, 1935.497, 1914.28, 1892.975, 1871.5839999999998, 1850.109, 1828.5510000000002, 1806.912, 1785.193, 1763.3970000000002, 1741.523, 1719.575, 1697.5529999999999, 1675.4589999999998, 1653.295, 1631.0610000000001, 1608.759, 1586.39, 1563.9560000000001, 1541.4589999999998, 1518.899, 1496.2779999999998, 1473.5970000000002, 1450.8570000000002, 1428.06, 1405.2079999999999, 1382.3, 1359.339, 1336.325, 1313.261, 1290.146, 1266.983, 1243.772, 1220.515, 1197.213, 1173.867, 1150.478, 1127.047, 1103.576, 1080.065, 1056.516, 1032.93, 1009.307, 985.6489999999999, 961.957, 938.232, 914.4760000000001, 890.688, 866.8710000000001, 843.0239999999999, 819.15, 795.25, 771.323, 747.372, 723.398, 699.4, 675.3810000000001, 651.342, 627.283, 603.205, 579.109, 554.996, 530.868, 506.725, 482.569, 458.399, 434.218, 410.025, 385.82300000000004, 361.61199999999997, 337.392, 313.166, 288.933, 264.695, 240.453, 216.208, 191.96, 167.71, 143.461, 119.211, 94.963, 70.717, 46.475, 22.236, -1.9969999999999999, -26.224, -50.443999999999996, -74.656, -98.86, -123.054, -147.236, -171.408, -195.56599999999997, -219.71099999999998, -243.84099999999998, -267.95599999999996, -292.055, -316.13599999999997, -340.199, -364.24199999999996, -388.265, -412.267, -436.24699999999996, -460.204, -484.13599999999997, -508.043, -531.925, -555.779, -579.605, -603.401, -627.168, -650.904, -674.607, -698.2769999999999, -721.913, -745.5139999999999, -769.079, -792.6060000000001, -816.095, -839.544, -862.953, -886.32, -909.645, -932.926, -956.1619999999999, -979.352, -1002.495, -1025.59, -1048.635, -1071.63, -1094.5739999999998, -1117.464, -1140.3010000000002, -1163.0819999999999, -1185.807, -1208.475, -1231.083, -1253.632, -1276.119, -1298.5439999999999, -1320.905, -1343.201, -1365.43, -1387.5910000000001, -1409.684, -1431.7060000000001, -1453.656, -1475.5339999999999, -1497.336, -1519.0629999999999, -1540.7120000000002, -1562.2820000000002, -1583.7720000000002, -1605.181, -1626.505, -1647.746, -1668.899, -1689.965, -1710.941, -1731.826, -1752.618, -1773.316, -1793.918, -1814.422, -1834.826, -1855.129, -1875.329, -1895.424, -1915.412, -1935.2920000000001, -1955.0610000000001, -1974.7179999999998, -1994.26, -2013.6860000000001, -2032.993, -2052.18, -2071.244, -2090.1839999999997, -2108.996, -2127.679, -2146.231, -2164.65, -2182.9320000000002, -2201.076, -2219.0789999999997, -2236.938, -2254.652, -2272.218, -2289.632, -2306.893, -2323.998, -2340.9429999999998, -2357.7270000000003, -2374.345, -2390.7960000000003, -2407.076, -2423.1820000000002, -2439.111, -2454.86, -2470.425, -2485.803, -2500.992, -2515.986, -2530.783, -2545.379, -2559.77, -2573.953, -2587.923, -2601.676, -2615.209, -2628.5170000000003, -2641.5959999999995, -2654.441, -2667.048, -2679.4120000000003, -2691.528, -2703.3920000000003, -2714.9990000000003, -2726.344, -2737.42, -2748.223, -2758.7470000000003, -2768.986, -2778.935, -2788.5879999999997, -2797.937, -2806.978, -2815.702, -2824.1040000000003, -2832.177, -2839.913, -2847.305, -2854.345, -2861.025, -2867.3379999999997, -2873.275, -2878.827, -2883.986, -2888.742, -2893.085, -2897.007, -2900.4970000000003, -2903.5440000000003, -2906.139, -2908.268, -2909.922, -2911.0879999999997, -2911.7529999999997, -2911.905, -2911.531, -2910.616, -2909.147, -2907.1090000000004, -2904.485, -2901.261, -2897.4190000000003, -2892.942, -2887.8140000000003, -2882.014, -2875.5240000000003, -2868.323, -2860.39, -2851.704, -2842.242, -2831.98, -2820.8940000000002, -2808.9559999999997, -2796.1409999999996, -2782.421, -2767.7670000000003, -2752.1479999999997, -2735.531, -2717.884, -2699.172, -2679.3579999999997, -2658.405, -2636.2709999999997, -2612.916, -2588.298, -2562.369, -2535.084, -2506.391, -2476.239, -2444.575, -2411.343, -2376.484, -2339.937, -2301.637, -2261.522, -2219.522, -2175.5679999999998, -2129.5879999999997, -2081.507, -2031.253, -1978.749, -1923.918, -1866.685, -1806.977, -1744.721, -1679.8470000000002, -1612.295, -1542.0079999999998, -1468.9379999999999, -1393.0529999999999, -1314.332, -1232.772, -1148.392, -1061.236, -971.375, -878.909, -783.9739999999999, -686.742, -587.418, -486.245, -383.50199999999995, -279.495, -174.558, -69.043, 36.684, 142.257, 247.312, 351.50199999999995, 454.49800000000005, 555.997, 655.73, 753.462, 848.99, 942.15, 1032.81, 1120.873, 1206.267, 1288.9489999999998, 1368.901, 1446.1229999999998, 1520.628, 1592.451, 1661.631, 1728.22, 1792.275, 1853.86, 1913.0410000000002, 1969.886, 2024.4660000000001, 2076.8520000000003, 2127.115, 2175.323, 2221.548, 2265.856, 2308.313, 2348.9829999999997, 2387.927, 2425.206, 2460.8779999999997, 2494.998, 2527.62, 2558.795, 2588.573, 2617.002, 2644.127, 2669.992, 2694.638, 2718.1059999999998, 2740.4320000000002, 2761.657, 2781.8140000000003, 2800.937, 2819.059, 2836.21, 2852.421, 2867.72, 2882.134, 2895.691, 2908.414, 2920.329, 2931.458, 2941.8259999999996, 2951.4509999999996, 2960.357, 2968.562, 2976.085, 2982.945, 2989.16, 2994.7470000000003, 2999.723, 3004.1020000000003, 3007.901, 3011.135, 3013.817, 3015.962, 3017.583, 3018.692, 3019.303, 3019.426, 3019.074, 3018.258, 3016.989, 3015.277, 3013.133, 3010.566, 3007.585, 3004.2009999999996, 3000.422, 2996.257, 2991.7140000000004, 2986.801, 2981.528, 2975.9, 2969.926, 2963.613, 2956.968, 2949.9990000000003, 2942.71, 2935.111, 2927.205, 2919.0009999999997, 2910.5029999999997, 2901.717, 2892.65, 2883.3070000000002, 2873.6929999999998, 2863.8140000000003, 2853.6740000000004, 2843.278, 2832.633, 2821.741, 2810.6090000000004, 2799.24, 2787.639, 2775.81, 2763.758, 2751.486, 2738.998, 2726.3, 2713.3940000000002, 2700.284, 2686.974, 2673.467, 2659.768, 2645.8790000000004, 2631.803, 2617.545, 2603.1079999999997, 2588.494, 2573.706, 2558.749, 2543.624, 2528.334, 2512.883, 2497.274, 2481.508, 2465.589, 2449.52, 2433.302, 2416.939, 2400.433, 2383.7870000000003, 2367.002, 2350.0820000000003, 2333.028, 2315.843, 2298.529, 2281.089, 2263.524, 2245.8360000000002, 2228.029, 2210.103, 2192.061, 2173.905, 2155.636, 2137.257, 2118.77, 2100.176, 2081.478, 2062.677, 2043.774, 2024.7720000000002, 2005.6729999999998, 1986.4779999999998, 1967.1879999999999, 1947.806, 1928.3329999999999, 1908.77, 1889.12, 1869.384, 1849.5629999999999, 1829.6589999999999, 1809.6729999999998, 1789.6070000000002, 1769.463, 1749.241, 1728.944, 1708.5720000000001, 1688.1270000000002, 1667.61, 1647.024, 1626.368, 1605.645, 1584.855, 1564.0, 1543.082, 1522.101, 1501.059, 1479.9579999999999, 1458.797, 1437.579, 1416.3039999999999, 1394.975, 1373.5910000000001, 1352.155, 1330.6670000000001, 1309.128, 1287.5410000000002, 1265.905, 1244.221, 1222.492, 1200.718, 1178.9, 1157.039, 1135.136, 1113.193, 1091.21, 1069.1889999999999, 1047.13, 1025.0339999999999, 1002.903, 980.738, 958.539, 936.307, 914.044, 891.75, 869.427, 847.075, 824.696, 802.29, 779.8580000000001, 757.4019999999999, 734.921, 712.418, 689.893, 667.347, 644.781, 622.195, 599.591, 576.97, 554.3330000000001, 531.68, 509.01199999999994, 486.33099999999996, 463.63699999999994, 440.931, 418.214, 395.486, 372.75, 350.005, 327.253, 304.494, 281.73, 258.96, 236.187, 213.41099999999997, 190.632, 167.852, 145.072, 122.292, 99.514, 76.738, 53.965, 31.195999999999998, 8.431000000000001, -14.327, -37.079, -59.823, -82.559, -105.286, -128.003, -150.708, -173.40200000000002, -196.083, -218.75, -241.40200000000002, -264.039, -286.66, -309.263, -331.848, -354.414, -376.96, -399.48400000000004, -421.98699999999997, -444.467, -466.92400000000004, -489.355, -511.76099999999997, -534.14, -556.492, -578.815, -601.109, -623.372, -645.604, -667.804, -689.97, -712.102, -734.198, -756.2589999999999, -778.2810000000001, -800.265, -822.21, -844.115, -865.977, -887.798, -909.574, -931.306, -952.992, -974.6310000000001, -996.222, -1017.7639999999999, -1039.256, -1060.6960000000001, -1082.0839999999998, -1103.4180000000001, -1124.698, -1145.921, -1167.087, -1188.194, -1209.242, -1230.229, -1251.154, -1272.016, -1292.813, -1313.543, -1334.207, -1354.8020000000001, -1375.3270000000002, -1395.78, -1416.161, -1436.4679999999998, -1456.6989999999998, -1476.8529999999998, -1496.9289999999999, -1516.9260000000002, -1536.84, -1556.672, -1576.42, -1596.0810000000001, -1615.655, -1635.14, -1654.5339999999999, -1673.835, -1693.043, -1712.155, -1731.1689999999999, -1750.0839999999998, -1768.8970000000002, -1787.608, -1806.214, -1824.714, -1843.104, -1861.385, -1879.5529999999999, -1897.606, -1915.543, -1933.361, -1951.059, -1968.6329999999998, -1986.0829999999999, -2003.405, -2020.598, -2037.658, -2054.584, -2071.374, -2088.024, -2104.533, -2120.897, -2137.114, -2153.1820000000002, -2169.097, -2184.857, -2200.46, -2215.901, -2231.178, -2246.2889999999998, -2261.23, -2275.9970000000003, -2290.589, -2305.0, -2319.229, -2333.27, -2347.1220000000003, -2360.78, -2374.241, -2387.5, -2400.554, -2413.3979999999997, -2426.03, -2438.4429999999998, -2450.636, -2462.6020000000003, -2474.337, -2485.837, -2497.096, -2508.111, -2518.876, -2529.385, -2539.633, -2549.616, -2559.327, -2568.76, -2577.91, -2586.771, -2595.3360000000002, -2603.598, -2611.552, -2619.19, -2626.505, -2633.489, -2640.137, -2646.438, -2652.387, -2657.973, -2663.19, -2668.027, -2672.4759999999997, -2676.527, -2680.172, -2683.3990000000003, -2686.199, -2688.56, -2690.472, -2691.922, -2692.9, -2693.3920000000003, -2693.386, -2692.869, -2691.8259999999996, -2690.244, -2688.107, -2685.4, -2682.107, -2678.21, -2673.6940000000004, -2668.54, -2662.7290000000003, -2656.242, -2649.0570000000002, -2641.155, -2632.512, -2623.1059999999998, -2612.9120000000003, -2601.906, -2590.061, -2577.35, -2563.744, -2549.214, -2533.729, -2517.255, -2499.758, -2481.2039999999997, -2461.554, -2440.77, -2418.81, -2395.633, -2371.195, -2345.447, -2318.343, -2289.83, -2259.856, -2228.367, -2195.304, -2160.6079999999997, -2124.217, -2086.067, -2046.092, -2004.224, -1960.392, -1914.527, -1866.5539999999999, -1816.402, -1763.9979999999998, -1709.271, -1652.148, -1592.566, -1530.4620000000002, -1465.7779999999998, -1398.469, -1328.4979999999998, -1255.839, -1180.486, -1102.452, -1021.768, -938.4939999999999, -852.7189999999999, -764.561, -674.173, -581.74, -487.48400000000004, -391.658, -294.545, -196.452, -97.70700000000001, 1.35, 100.374, 199.025, 296.972, 393.903, 489.529, 583.592, 675.862, 766.1439999999999, 854.2769999999999, 940.128, 1023.5980000000001, 1104.617, 1183.136, 1259.132, 1332.595, 1403.543, 1471.995, 1537.9879999999998, 1601.566, 1662.78, 1721.6870000000001, 1778.345, 1832.817, 1885.1689999999999, 1935.465, 1983.7679999999998, 2030.144, 2074.658, 2117.369, 2158.341, 2197.632, 2235.3, 2271.4, 2305.985, 2339.11, 2370.822, 2401.1710000000003, 2430.202, 2457.959, 2484.485, 2509.822, 2534.007, 2557.08, 2579.076, 2600.029, 2619.972, 2638.937, 2656.9559999999997, 2674.055, 2690.265, 2705.611, 2720.119, 2733.815, 2746.7209999999995, 2758.862, 2770.258, 2780.9309999999996, 2790.901, 2800.187, 2808.809, 2816.784, 2824.1290000000004, 2830.862, 2836.998, 2842.553, 2847.542, 2851.98, 2855.88, 2859.256, 2862.1209999999996, 2864.487, 2866.367, 2867.772, 2868.7129999999997, 2869.202, 2869.2490000000003, 2868.864, 2868.0570000000002, 2866.8379999999997, 2865.216, 2863.2, 2860.8, 2858.022, 2854.877, 2851.37, 2847.512, 2843.308, 2838.7659999999996, 2833.893, 2828.696, 2823.183, 2817.3579999999997, 2811.23, 2804.803, 2798.0840000000003, 2791.079, 2783.7929999999997, 2776.232, 2768.401, 2760.3059999999996, 2751.952, 2743.343, 2734.4840000000004, 2725.381, 2716.038, 2706.458, 2696.6479999999997, 2686.611, 2676.3509999999997, 2665.8720000000003, 2655.178, 2644.2740000000003, 2633.163, 2621.848, 2610.334, 2598.624, 2586.721, 2574.629, 2562.3520000000003, 2549.8920000000003, 2537.252, 2524.437, 2511.448, 2498.2889999999998, 2484.9629999999997, 2471.472, 2457.82, 2444.01, 2430.0429999999997, 2415.923, 2401.652, 2387.2329999999997, 2372.6679999999997, 2357.96, 2343.111, 2328.124, 2313.001, 2297.743, 2282.354, 2266.8360000000002, 2251.1910000000003, 2235.42, 2219.527, 2203.512, 2187.3779999999997, 2171.1279999999997, 2154.762, 2138.284, 2121.694, 2104.995, 2088.188, 2071.275, 2054.259, 2037.14, 2019.921, 2002.6029999999998, 1985.1879999999999, 1967.6770000000001, 1950.0720000000001, 1932.375, 1914.588, 1896.711, 1878.746, 1860.695, 1842.559, 1824.3410000000001, 1806.04, 1787.6589999999999, 1769.1989999999998, 1750.661, 1732.047, 1713.358, 1694.596, 1675.761, 1656.856, 1637.88, 1618.8370000000002, 1599.726, 1580.549, 1561.308, 1542.003, 1522.635, 1503.207, 1483.719, 1464.172, 1444.567, 1424.906, 1405.1889999999999, 1385.418, 1365.594, 1345.7179999999998, 1325.7910000000002, 1305.8139999999999, 1285.788, 1265.714, 1245.593, 1225.4260000000002, 1205.215, 1184.96, 1164.662, 1144.323, 1123.942, 1103.522, 1083.063, 1062.566, 1042.032, 1021.462, 1000.8580000000001, 980.2189999999999, 959.547, 938.842, 918.107, 897.341, 876.545, 855.721, 834.8689999999999, 813.99, 793.086, 772.1560000000001, 751.202, 730.225, 709.225, 688.204, 667.1619999999999, 646.1, 625.019, 603.92, 582.803, 561.6709999999999, 540.5219999999999, 519.359, 498.18199999999996, 476.991, 455.789, 434.574, 413.35, 392.115, 370.871, 349.62, 328.361, 307.095, 285.824, 264.547, 243.267, 221.984, 200.69799999999998, 179.41, 158.122, 136.833, 115.546, 94.26, 72.977, 51.696999999999996, 30.421, 9.15, -12.115, -33.374, -54.625, -75.868, -97.102, -118.32600000000001, -139.539, -160.741, -181.93, -203.106, -224.268, -245.415, -266.546, -287.66, -308.757, -329.835, -350.895, -371.934, -392.952, -413.94800000000004, -434.921, -455.871, -476.796, -497.69599999999997, -518.569, -539.415, -560.2330000000001, -581.0219999999999, -601.781, -622.508, -643.2040000000001, -663.867, -684.4960000000001, -705.09, -725.6489999999999, -746.171, -766.655, -787.1, -807.505, -827.87, -848.193, -868.4730000000001, -888.709, -908.9, -929.046, -949.1439999999999, -969.194, -989.194, -1009.145, -1029.0439999999999, -1048.89, -1068.682, -1088.4189999999999, -1108.101, -1127.725, -1147.29, -1166.796, -1186.241, -1205.623, -1224.942, -1244.1960000000001, -1263.384, -1282.505, -1301.557, -1320.539, -1339.45, -1358.287, -1377.0510000000002, -1395.7379999999998, -1414.349, -1432.881, -1451.3329999999999, -1469.703, -1487.99, -1506.192, -1524.308, -1542.336, -1560.275, -1578.122, -1595.876, -1613.536, -1631.099, -1648.5639999999999, -1665.9279999999999, -1683.191, -1700.351, -1717.404, -1734.35, -1751.1870000000001, -1767.911, -1784.5220000000002, -1801.017, -1817.395, -1833.652, -1849.787, -1865.797, -1881.68, -1897.434, -1913.056, -1928.545, -1943.896, -1959.108, -1974.1789999999999, -1989.105, -2003.8829999999998, -2018.5120000000002, -2032.9879999999998, -2047.308, -2061.469, -2075.469, -2089.304, -2102.97, -2116.466, -2129.786, -2142.929, -2155.889, -2168.665, -2181.252, -2193.646, -2205.843, -2217.84, -2229.632, -2241.216, -2252.5860000000002, -2263.74, -2274.6710000000003, -2285.375, -2295.849, -2306.0860000000002, -2316.081, -2325.831, -2335.328, -2344.569, -2353.5460000000003, -2362.255, -2370.69, -2378.843, -2386.71, -2394.283, -2401.556, -2408.521, -2415.172, -2421.501, -2427.501, -2433.163, -2438.48, -2443.4429999999998, -2448.044, -2452.2729999999997, -2456.1220000000003, -2459.581, -2462.639, -2465.2870000000003, -2467.513, -2469.308, -2470.658, -2471.553, -2471.981, -2471.928, -2471.381, -2470.326, -2468.749, -2466.636, -2463.97, -2460.736, -2456.917, -2452.496, -2447.453, -2441.771, -2435.431, -2428.41, -2420.689, -2412.244, -2403.052, -2393.089, -2382.3289999999997, -2370.7470000000003, -2358.314, -2345.0, -2330.777, -2315.61, -2299.47, -2282.32, -2264.123, -2244.842, -2224.438, -2202.868, -2180.089, -2156.055, -2130.72, -2104.033, -2075.9429999999998, -2046.3970000000002, -2015.3370000000002, -1982.707, -1948.445, -1912.489, -1874.775, -1835.237, -1793.807, -1750.4170000000001, -1704.997, -1657.477, -1607.789, -1555.865, -1501.641, -1445.0529999999999, -1386.049, -1324.58, -1260.605, -1194.098, -1125.047, -1053.4560000000001, -979.35, -902.775, -823.81, -742.554, -659.1439999999999, -573.744, -486.551, -397.79699999999997, -307.73900000000003, -216.658, -124.85600000000001, -32.649, 59.644, 151.702, 243.21599999999998, 333.89099999999996, 423.452, 511.652, 598.27, 683.117, 766.0360000000001, 846.8960000000001, 925.597, 1002.065, 1076.25, 1148.124, 1217.675, 1284.9080000000001, 1349.8410000000001, 1412.504, 1472.933, 1531.172, 1587.271, 1641.2839999999999, 1693.266, 1743.275, 1791.371, 1837.61, 1882.0529999999999, 1924.7579999999998, 1965.781, 2005.18, 2043.007, 2079.3160000000003, 2114.159, 2147.585, 2179.6420000000003, 2210.376, 2239.8320000000003, 2268.052, 2295.078, 2320.948, 2345.702, 2369.376, 2392.0029999999997, 2413.619, 2434.254, 2453.94, 2472.7070000000003, 2490.581, 2507.592, 2523.764, 2539.123, 2553.6929999999998, 2567.498, 2580.558, 2592.897, 2604.533, 2615.487, 2625.778, 2635.423, 2644.441, 2652.848, 2660.6609999999996, 2667.8940000000002, 2674.5640000000003, 2680.685, 2686.27, 2691.3340000000003, 2695.889, 2699.948, 2703.5229999999997, 2706.6259999999997, 2709.2690000000002, 2711.461, 2713.215, 2714.539, 2715.445, 2715.941, 2716.0370000000003, 2715.742, 2715.065, 2714.014, 2712.597, 2710.823, 2708.699, 2706.232, 2703.43, 2700.3, 2696.849, 2693.083, 2689.009, 2684.633, 2679.962, 2675.0, 2669.755, 2664.2309999999998, 2658.435, 2652.3720000000003, 2646.045, 2639.462, 2632.6259999999997, 2625.5429999999997, 2618.217, 2610.652, 2602.854, 2594.826, 2586.573, 2578.099, 2569.409, 2560.505, 2551.391, 2542.073, 2532.552, 2522.834, 2512.9210000000003, 2502.8160000000003, 2492.524, 2482.0460000000003, 2471.388, 2460.551, 2449.5389999999998, 2438.355, 2427.002, 2415.482, 2403.799, 2391.955, 2379.953, 2367.7960000000003, 2355.486, 2343.025, 2330.417, 2317.6639999999998, 2304.768, 2291.731, 2278.556, 2265.245, 2251.801, 2238.225, 2224.519, 2210.687, 2196.729, 2182.6479999999997, 2168.446, 2154.125, 2139.686, 2125.132, 2110.465, 2095.686, 2080.798, 2065.801, 2050.698, 2035.49, 2020.18, 2004.7679999999998, 1989.257, 1973.648, 1957.942, 1942.142, 1926.2479999999998, 1910.2620000000002, 1894.1870000000001, 1878.0220000000002, 1861.77, 1845.433, 1829.01, 1812.505, 1795.918, 1779.25, 1762.504, 1745.68, 1728.779, 1711.8029999999999, 1694.754, 1677.631, 1660.4379999999999, 1643.174, 1625.8410000000001, 1608.441, 1590.974, 1573.441, 1555.844, 1538.184, 1520.4620000000002, 1502.6789999999999, 1484.8370000000002, 1466.935, 1448.976, 1430.96, 1412.889, 1394.763, 1376.5839999999998, 1358.352, 1340.069, 1321.735, 1303.3519999999999, 1284.92, 1266.441, 1247.9160000000002, 1229.344, 1210.728, 1192.069, 1173.366, 1154.622, 1135.836, 1117.011, 1098.147, 1079.244, 1060.3039999999999, 1041.327, 1022.315, 1003.268, 984.187, 965.073, 945.927, 926.75, 907.5419999999999, 888.304, 869.038, 849.743, 830.422, 811.074, 791.7, 772.302, 752.8789999999999, 733.434, 713.966, 694.477, 674.966, 655.436, 635.887, 616.319, 596.734, 577.132, 557.513, 537.879, 518.231, 498.569, 478.894, 459.207, 439.50800000000004, 419.798, 400.079, 380.35, 360.61300000000006, 340.86800000000005, 321.116, 301.358, 281.595, 261.827, 242.055, 222.27900000000002, 202.502, 182.722, 162.942, 143.162, 123.382, 103.604, 83.82799999999999, 64.055, 44.285, 24.52, 4.76, -14.994000000000002, -34.741, -54.481, -74.212, -93.934, -113.647, -133.349, -153.039, -172.717, -192.38299999999998, -212.03400000000002, -231.671, -251.292, -270.89799999999997, -290.486, -310.056, -329.608, -349.14, -368.652, -388.14300000000003, -407.61199999999997, -427.05800000000005, -446.48, -465.87800000000004, -485.25, -504.596, -523.915, -543.206, -562.4680000000001, -581.7, -600.9019999999999, -620.071, -639.2090000000001, -658.312, -677.382, -696.416, -715.413, -734.3739999999999, -753.296, -772.178, -791.0210000000001, -809.822, -828.581, -847.297, -865.9689999999999, -884.595, -903.174, -921.707, -940.19, -958.6239999999999, -977.007, -995.3380000000001, -1013.617, -1031.8410000000001, -1050.009, -1068.121, -1086.175, -1104.171, -1122.106, -1139.979, -1157.79, -1175.537, -1193.219, -1210.8339999999998, -1228.381, -1245.859, -1263.265, -1280.6, -1297.862, -1315.0479999999998, -1332.158, -1349.19, -1366.142, -1383.014, -1399.8020000000001, -1416.507, -1433.126, -1449.6570000000002, -1466.1, -1482.451, -1498.71, -1514.874, -1530.942, -1546.9129999999998, -1562.783, -1578.5520000000001, -1594.2160000000001, -1609.775, -1625.227, -1640.568, -1655.7979999999998, -1670.9129999999998, -1685.9129999999998, -1700.793, -1715.5529999999999, -1730.19, -1744.7020000000002, -1759.085, -1773.338, -1787.4579999999999, -1801.443, -1815.289, -1828.995, -1842.557, -1855.9720000000002, -1869.2379999999998, -1882.352, -1895.31, -1908.109, -1920.747, -1933.22, -1945.524, -1957.6570000000002, -1969.614, -1981.392, -1992.9879999999998, -2004.3970000000002, -2015.616, -2026.64, -2037.4660000000001, -2048.089, -2058.505, -2068.709, -2078.698, -2088.465, -2098.007, -2107.3179999999998, -2116.393, -2125.2270000000003, -2133.815, -2142.15, -2150.2270000000003, -2158.04, -2165.583, -2172.85, -2179.834, -2186.528, -2192.926, -2199.019, -2204.801, -2210.265, -2215.401, -2220.202, -2224.659, -2228.764, -2232.508, -2235.88, -2238.8720000000003, -2241.473, -2243.672, -2245.459, -2246.823, -2247.751, -2248.232, -2248.2529999999997, -2247.801, -2246.861, -2245.4210000000003, -2243.465, -2240.978, -2237.9429999999998, -2234.344, -2230.1639999999998, -2225.385, -2219.987, -2213.951, -2207.257, -2199.882, -2191.804, -2183.001, -2173.447, -2163.117, -2151.984, -2140.019, -2127.195, -2113.479, -2098.84, -2083.245, -2066.657, -2049.04, -2030.356, -2010.5639999999999, -1989.622, -1967.485, -1944.108, -1919.443, -1893.44, -1866.045, -1837.205, -1806.8629999999998, -1774.961, -1741.4379999999999, -1706.2320000000002, -1669.2779999999998, -1630.513, -1589.871, -1547.285, -1502.6879999999999, -1456.017, -1407.2079999999999, -1356.201, -1302.942, -1247.381, -1189.478, -1129.203, -1066.538, -1001.4810000000001, -934.047, -864.2760000000001, -792.2280000000001, -717.99, -641.679, -563.44, -483.449, -401.91, -319.056, -235.144, -150.44899999999998, -65.26, 20.127, 105.417, 190.31799999999998, 274.55400000000003, 357.86699999999996, 440.02, 520.805, 600.0369999999999, 677.564, 753.257, 827.0169999999999, 898.768, 968.456, 1036.049, 1101.531, 1164.901, 1226.172, 1285.364, 1342.509, 1397.645, 1450.8120000000001, 1502.059, 1551.435, 1598.991, 1644.78, 1688.854, 1731.266, 1772.068, 1811.3129999999999, 1849.05, 1885.33, 1920.2020000000002, 1953.711, 1985.9029999999998, 2016.8220000000001, 2046.511, 2075.009, 2102.357, 2128.592, 2153.751, 2177.868, 2200.976, 2223.1079999999997, 2244.2960000000003, 2264.5679999999998, 2283.953, 2302.478, 2320.17, 2337.053, 2353.152, 2368.49, 2383.09, 2396.971, 2410.156, 2422.6639999999998, 2434.513, 2445.723, 2456.31, 2466.291, 2475.6839999999997, 2484.5029999999997, 2492.763, 2500.479, 2507.666, 2514.3360000000002, 2520.5029999999997, 2526.179, 2531.377, 2536.107, 2540.382, 2544.2129999999997, 2547.609, 2550.581, 2553.14, 2555.294, 2557.052, 2558.425, 2559.42, 2560.0460000000003, 2560.311, 2560.222, 2559.7889999999998, 2559.0170000000003, 2557.9139999999998, 2556.488, 2554.745, 2552.6910000000003, 2550.333, 2547.677, 2544.73, 2541.496, 2537.9829999999997, 2534.194, 2530.137, 2525.815, 2521.235, 2516.401, 2511.3179999999998, 2505.99, 2500.423, 2494.621, 2488.5879999999997, 2482.328, 2475.846, 2469.146, 2462.231, 2455.106, 2447.774, 2440.239, 2432.505, 2424.575, 2416.453, 2408.141, 2399.644, 2390.964, 2382.105, 2373.07, 2363.861, 2354.481, 2344.935, 2335.223, 2325.35, 2315.317, 2305.1279999999997, 2294.785, 2284.29, 2273.646, 2262.856, 2251.9210000000003, 2240.845, 2229.629, 2218.276, 2206.788, 2195.167, 2183.415, 2171.534, 2159.527, 2147.395, 2135.141, 2122.766, 2110.272, 2097.661, 2084.935, 2072.096, 2059.146, 2046.085, 2032.9170000000001, 2019.642, 2006.263, 1992.78, 1979.1970000000001, 1965.513, 1951.731, 1937.852, 1923.878, 1909.8110000000001, 1895.651, 1881.4, 1867.059, 1852.631, 1838.116, 1823.516, 1808.832, 1794.065, 1779.217, 1764.289, 1749.2820000000002, 1734.1970000000001, 1719.036, 1703.8, 1688.49, 1673.108, 1657.654, 1642.129, 1626.536, 1610.874, 1595.145, 1579.351, 1563.491, 1547.568, 1531.582, 1515.5339999999999, 1499.4260000000002, 1483.2579999999998, 1467.0320000000002, 1450.7479999999998, 1434.4070000000002, 1418.011, 1401.56, 1385.056, 1368.4979999999998, 1351.889, 1335.229, 1318.519, 1301.761, 1284.954, 1268.099, 1251.1989999999998, 1234.253, 1217.262, 1200.228, 1183.15, 1166.031, 1148.871, 1131.67, 1114.4289999999999, 1097.15, 1079.833, 1062.479, 1045.089, 1027.663, 1010.203, 992.709, 975.181, 957.622, 940.03, 922.408, 904.7560000000001, 887.075, 869.365, 851.627, 833.862, 816.071, 798.255, 780.414, 762.548, 744.66, 726.748, 708.815, 690.8610000000001, 672.8860000000001, 654.891, 636.878, 618.846, 600.7959999999999, 582.73, 564.6469999999999, 546.549, 528.436, 510.309, 492.16900000000004, 474.01599999999996, 455.85, 437.67400000000004, 419.48699999999997, 401.29, 383.084, 364.869, 346.647, 328.417, 310.181, 291.939, 273.692, 255.44, 237.185, 218.92700000000002, 200.667, 182.405, 164.142, 145.879, 127.617, 109.355, 91.096, 72.839, 54.585, 36.336, 18.090999999999998, -0.14800000000000002, -18.382, -36.608000000000004, -54.827, -73.03699999999999, -91.23899999999999, -109.43, -127.611, -145.781, -163.93900000000002, -182.084, -200.21599999999998, -218.333, -236.43599999999998, -254.52200000000002, -272.593, -290.645, -308.68, -326.69599999999997, -344.69300000000004, -362.668, -380.62300000000005, -398.556, -416.465, -434.352, -452.213, -470.04900000000004, -487.86, -505.64300000000003, -523.398, -541.124, -558.821, -576.488, -594.123, -611.726, -629.295, -646.831, -664.331, -681.796, -699.2239999999999, -716.6139999999999, -733.965, -751.2760000000001, -768.547, -785.775, -802.961, -820.1039999999999, -837.201, -854.252, -871.257, -888.2130000000001, -905.1210000000001, -921.9780000000001, -938.783, -955.5360000000001, -972.2360000000001, -988.8810000000001, -1005.4689999999999, -1022.0010000000001, -1038.473, -1054.887, -1071.239, -1087.529, -1103.755, -1119.917, -1136.012, -1152.04, -1167.999, -1183.887, -1199.704, -1215.447, -1231.115, -1246.7069999999999, -1262.222, -1277.657, -1293.011, -1308.282, -1323.469, -1338.57, -1353.5839999999998, -1368.5079999999998, -1383.3410000000001, -1398.0810000000001, -1412.726, -1427.274, -1441.723, -1456.0720000000001, -1470.318, -1484.46, -1498.494, -1512.42, -1526.234, -1539.935, -1553.52, -1566.987, -1580.3339999999998, -1593.558, -1606.656, -1619.6270000000002, -1632.467, -1645.174, -1657.745, -1670.1770000000001, -1682.467, -1694.6129999999998, -1706.611, -1718.4579999999999, -1730.152, -1741.6879999999999, -1753.0639999999999, -1764.276, -1775.32, -1786.193, -1796.892, -1807.411, -1817.749, -1827.899, -1837.859, -1847.624, -1857.19, -1866.5510000000002, -1875.704, -1884.644, -1893.365, -1901.8629999999998, -1910.132, -1918.168, -1925.964, -1933.514, -1940.8129999999999, -1947.855, -1954.634, -1961.142, -1967.374, -1973.3210000000001, -1978.9779999999998, -1984.336, -1989.388, -1994.125, -1998.5410000000002, -2002.625, -2006.369, -2009.764, -2012.8010000000002, -2015.469, -2017.7579999999998, -2019.658, -2021.1570000000002, -2022.245, -2022.908, -2023.135, -2022.9129999999998, -2022.2279999999998, -2021.066, -2019.4129999999998, -2017.253, -2014.57, -2011.349, -2007.5710000000001, -2003.219, -1998.273, -1992.715, -1986.524, -1979.6779999999999, -1972.154, -1963.9289999999999, -1954.98, -1945.28, -1934.8010000000002, -1923.517, -1911.3970000000002, -1898.411, -1884.526, -1869.7079999999999, -1853.921, -1837.129, -1819.293, -1800.371, -1780.3220000000001, -1759.1, -1736.6589999999999, -1712.95, -1687.9229999999998, -1661.526, -1633.704, -1604.4, -1573.556, -1541.1129999999998, -1507.009, -1471.182, -1433.568, -1394.106, -1352.733, -1309.389, -1264.014, -1216.556, -1166.964, -1115.197, -1061.22, -1005.0139999999999, -946.569, -885.8939999999999, -823.015, -757.98, -690.863, -621.76, -550.799, -478.13199999999995, -403.941, -328.431, -251.833, -174.396, -96.382, -18.062, 60.292, 138.41, 216.03599999999997, 292.927, 368.861, 443.63800000000003, 517.082, 589.0459999999999, 659.404, 728.056, 794.928, 859.961, 923.1210000000001, 984.385, 1043.748, 1101.215, 1156.802, 1210.532, 1262.437, 1312.5520000000001, 1360.9170000000001, 1407.5739999999998, 1452.569, 1495.9470000000001, 1537.754, 1578.0379999999998, 1616.899, 1654.2220000000002, 1690.214, 1724.865, 1758.22, 1790.319, 1821.205, 1850.9170000000001, 1879.493, 1906.97, 1933.3829999999998, 1958.769, 1983.158, 2006.582, 2029.0739999999998, 2050.6620000000003, 2071.373, 2091.236, 2110.276, 2128.519, 2145.987, 2162.7039999999997, 2178.6929999999998, 2193.974, 2208.569, 2222.495, 2235.7729999999997, 2248.4210000000003, 2260.456, 2271.894, 2282.752, 2293.0460000000003, 2302.79, 2311.999, 2320.687, 2328.867, 2336.551, 2343.754, 2350.486, 2356.759, 2362.585, 2367.973, 2372.936, 2377.482, 2381.621, 2385.363, 2388.718, 2391.6929999999998, 2394.297, 2396.54, 2398.428, 2399.969, 2401.172, 2402.042, 2402.589, 2402.817, 2402.734, 2402.347, 2401.6620000000003, 2400.6839999999997, 2399.42, 2397.876, 2396.0570000000002, 2393.968, 2391.615, 2389.0029999999997, 2386.137, 2383.022, 2379.663, 2376.063, 2372.229, 2368.1639999999998, 2363.8720000000003, 2359.3579999999997, 2354.626, 2349.679, 2344.521, 2339.157, 2333.59, 2327.824, 2321.861, 2315.7070000000003, 2309.363, 2302.833, 2296.12, 2289.228, 2282.159, 2274.917, 2267.504, 2259.923, 2252.177, 2244.269, 2236.202, 2227.9770000000003, 2219.599, 2211.0679999999998, 2202.388, 2193.561, 2184.59, 2175.476, 2166.222, 2156.83, 2147.303, 2137.6420000000003, 2127.85, 2117.928, 2107.879, 2097.705, 2087.407, 2076.987, 2066.448, 2055.792, 2045.019, 2034.132, 2023.132, 2012.0220000000002, 2000.8020000000001, 1989.475, 1978.043, 1966.506, 1954.866, 1943.126, 1931.285, 1919.3470000000002, 1907.3120000000001, 1895.182, 1882.9579999999999, 1870.642, 1858.235, 1845.7379999999998, 1833.1529999999998, 1820.481, 1807.724, 1794.882, 1781.957, 1768.95, 1755.8629999999998, 1742.6960000000001, 1729.451, 1716.128, 1702.73, 1689.2579999999998, 1675.711, 1662.092, 1648.402, 1634.641, 1620.8120000000001, 1606.914, 1592.9479999999999, 1578.9170000000001, 1564.8210000000001, 1550.66, 1536.4360000000001, 1522.151, 1507.8039999999999, 1493.3970000000002, 1478.93, 1464.406, 1449.8239999999998, 1435.185, 1420.491, 1405.7420000000002, 1390.94, 1376.0839999999998, 1361.1770000000001, 1346.2179999999998, 1331.2089999999998, 1316.151, 1301.0430000000001, 1285.888, 1270.687, 1255.438, 1240.145, 1224.807, 1209.425, 1194.0, 1178.5330000000001, 1163.024, 1147.475, 1131.587, 1115.958, 1100.2910000000002, 1084.586, 1068.844, 1053.066, 1037.252, 1021.404, 1005.5210000000001, 989.6060000000001, 973.6569999999999, 957.676, 941.665, 925.622, 909.55, 893.448, 877.318, 861.1610000000001, 844.975, 828.7639999999999, 812.5260000000001, 796.2639999999999, 779.977, 763.666, 747.332, 730.975, 714.596, 698.196, 681.7760000000001, 665.335, 648.875, 632.3969999999999, 615.9, 599.387, 582.856, 566.309, 549.747, 533.169, 516.578, 499.973, 483.355, 466.724, 450.082, 433.42900000000003, 416.765, 400.091, 383.409, 366.717, 350.01800000000003, 333.311, 316.598, 299.878, 283.153, 266.423, 249.69, 232.952, 216.21200000000002, 199.46900000000002, 182.72400000000002, 165.979, 149.233, 132.488, 115.743, 99.0, 82.259, 65.521, 48.787, 32.056, 15.331, -1.389, -18.102999999999998, -34.81, -51.51, -68.20100000000001, -84.884, -101.557, -118.22, -134.872, -151.512, -168.14, -184.755, -201.356, -217.94299999999998, -234.515, -251.071, -267.61, -284.132, -300.63599999999997, -317.122, -333.587, -350.032, -366.45599999999996, -382.858, -399.23800000000006, -415.594, -431.926, -448.233, -464.51300000000003, -480.76800000000003, -496.994, -513.192, -529.362, -545.5, -561.6080000000001, -577.685, -593.7280000000001, -609.738, -625.7130000000001, -641.653, -657.557, -673.423, -689.2510000000001, -705.039, -720.7869999999999, -736.4939999999999, -752.159, -767.7810000000001, -783.3580000000001, -798.89, -814.375, -829.813, -845.202, -860.5419999999999, -875.83, -891.067, -906.25, -921.3789999999999, -936.452, -951.4680000000001, -966.426, -981.325, -996.163, -1010.939, -1025.652, -1040.3, -1054.882, -1069.396, -1083.8419999999999, -1098.2169999999999, -1112.52, -1126.749, -1140.904, -1154.982, -1168.982, -1182.902, -1196.74, -1210.495, -1224.165, -1237.749, -1251.244, -1264.6480000000001, -1277.96, -1291.177, -1304.299, -1317.3220000000001, -1330.244, -1343.0639999999999, -1355.78, -1368.388, -1380.8870000000002, -1393.275, -1405.5479999999998, -1417.7060000000001, -1429.744, -1441.661, -1453.454, -1465.121, -1476.6570000000002, -1488.0620000000001, -1499.3310000000001, -1510.4620000000002, -1521.4520000000002, -1532.297, -1542.995, -1553.5410000000002, -1563.934, -1574.168, -1584.241, -1594.149, -1603.888, -1613.454, -1622.8429999999998, -1632.0510000000002, -1641.0739999999998, -1649.9070000000002, -1658.546, -1666.986, -1675.2220000000002, -1683.25, -1691.0629999999999, -1698.658, -1706.0279999999998, -1713.1670000000001, -1720.0710000000001, -1726.7320000000002, -1733.145, -1739.3029999999999, -1745.1989999999998, -1750.8270000000002, -1756.1789999999999, -1761.249, -1766.027, -1770.507, -1774.68, -1778.5379999999998, -1782.0710000000001, -1785.271, -1788.1270000000002, -1790.63, -1792.77, -1794.536, -1795.9160000000002, -1796.898, -1797.4720000000002, -1797.624, -1797.34, -1796.608, -1795.412, -1793.739, -1791.5720000000001, -1788.894, -1785.69, -1781.941, -1777.628, -1772.733, -1767.234, -1761.111, -1754.3410000000001, -1746.901, -1738.766, -1729.911, -1720.309, -1709.93, -1698.7479999999998, -1686.73, -1673.844, -1660.055, -1645.328, -1629.6270000000002, -1612.91, -1595.139, -1576.269, -1556.257, -1535.056, -1512.616, -1488.888, -1463.819, -1437.355, -1409.44, -1380.017, -1349.0279999999998, -1316.4129999999998, -1282.113, -1246.069, -1208.222, -1168.516, -1126.8980000000001, -1083.318, -1037.733, -990.1080000000001, -940.416, -888.6439999999999, -834.7919999999999, -778.877, -720.935, -661.0239999999999, -599.2230000000001, -535.64, -470.405, -403.676, -335.63300000000004, -266.48, -196.43900000000002, -125.744, -54.641000000000005, 16.621, 87.79700000000001, 158.65, 228.953, 298.5, 367.101, 434.591, 500.825, 565.683, 629.067, 690.8989999999999, 751.122, 809.694, 866.591, 921.801, 975.324, 1027.1680000000001, 1077.351, 1125.8980000000001, 1172.837, 1218.2, 1262.0230000000001, 1304.345, 1345.204, 1384.642, 1422.6979999999999, 1459.415, 1494.8310000000001, 1528.9879999999998, 1561.925, 1593.68, 1624.29, 1653.7920000000001, 1682.223, 1709.615, 1736.0020000000002, 1761.4160000000002, 1785.888, 1809.4470000000001, 1832.122, 1853.94, 1874.9279999999999, 1895.112, 1914.515, 1933.162, 1951.0739999999998, 1968.274, 1984.783, 2000.62, 2015.8039999999999, 2030.355, 2044.29, 2057.626, 2070.38, 2082.567, 2094.203, 2105.303, 2115.88, 2125.948, 2135.521, 2144.611, 2153.23, 2161.391, 2169.104, 2176.38, 2183.231, 2189.666, 2195.694, 2201.327, 2206.572, 2211.44, 2215.938, 2220.074, 2223.8579999999997, 2227.2960000000003, 2230.397, 2233.167, 2235.615, 2237.746, 2239.567, 2241.0860000000002, 2242.3070000000002, 2243.238, 2243.885, 2244.252, 2244.346, 2244.173, 2243.736, 2243.042, 2242.096, 2240.902, 2239.466, 2237.791, 2235.882, 2233.744, 2231.381, 2228.797, 2225.996, 2222.982, 2219.759, 2216.331, 2212.7, 2208.8720000000003, 2204.849, 2200.634, 2196.232, 2191.644, 2186.876, 2181.928, 2176.805, 2171.509, 2166.044, 2160.4120000000003, 2154.616, 2148.658, 2142.541, 2136.268, 2129.842, 2123.264, 2116.5370000000003, 2109.6639999999998, 2102.647, 2095.488, 2088.189, 2080.752, 2073.181, 2065.476, 2057.639, 2049.674, 2041.5810000000001, 2033.3629999999998, 2025.0220000000002, 2016.559, 2007.976, 1999.276, 1990.4589999999998, 1981.5279999999998, 1972.484, 1963.329, 1954.0639999999999, 1944.692, 1935.214, 1925.63, 1915.944, 1906.156, 1896.267, 1886.28, 1876.1960000000001, 1866.015, 1855.74, 1845.372, 1834.912, 1824.362, 1813.7220000000002, 1802.994, 1792.18, 1781.28, 1770.296, 1759.2279999999998, 1748.079, 1736.85, 1725.54, 1714.152, 1702.6870000000001, 1691.146, 1679.529, 1667.839, 1656.075, 1644.24, 1632.3329999999999, 1620.356, 1608.3110000000001, 1596.1970000000001, 1584.017, 1571.77, 1559.4589999999998, 1547.0829999999999, 1534.644, 1522.1429999999998, 1509.58, 1496.957, 1484.274, 1471.5320000000002, 1458.7320000000002, 1445.876, 1432.963, 1419.994, 1406.971, 1393.895, 1380.765, 1367.5829999999999, 1354.35, 1341.066, 1327.733, 1314.35, 1300.9189999999999, 1287.44, 1273.915, 1260.344, 1246.7269999999999, 1233.065, 1219.36, 1205.612, 1191.8210000000001, 1177.988, 1164.114, 1150.2, 1136.245, 1122.252, 1108.221, 1094.151, 1080.045, 1065.902, 1051.723, 1037.51, 1023.2610000000001, 1008.9789999999999, 994.664, 980.316, 965.936, 951.525, 937.0830000000001, 922.6110000000001, 908.1089999999999, 893.579, 879.02, 864.433, 849.82, 835.179, 820.513, 805.822, 791.1060000000001, 776.365, 761.602, 746.815, 732.005, 717.174, 702.322, 687.449, 672.556, 657.643, 642.711, 627.761, 612.793, 597.808, 582.806, 567.7869999999999, 552.754, 537.705, 522.641, 507.564, 492.474, 477.37, 462.255, 447.12699999999995, 431.98900000000003, 416.84, 401.681, 386.51300000000003, 371.336, 356.15, 340.957, 325.757, 310.55, 295.336, 280.118, 264.894, 249.667, 234.435, 219.2, 203.963, 188.72400000000002, 173.483, 158.241, 142.999, 127.757, 112.51700000000001, 97.277, 82.04, 66.806, 51.574, 36.347, 21.124000000000002, 5.906000000000001, -9.306000000000001, -24.511999999999997, -39.71, -54.902, -70.084, -85.259, -100.42299999999999, -115.57799999999999, -130.721, -145.85299999999998, -160.97299999999998, -176.081, -191.174, -206.25400000000002, -221.31900000000002, -236.368, -251.40099999999998, -266.41700000000003, -281.416, -296.39599999999996, -311.357, -326.298, -341.219, -356.11800000000005, -370.995, -385.85, -400.68, -415.48699999999997, -430.26800000000003, -445.023, -459.751, -474.452, -489.124, -503.767, -518.38, -532.961, -547.511, -562.028, -576.511, -590.9590000000001, -605.372, -619.748, -634.087, -648.387, -662.648, -676.868, -691.047, -705.183, -719.275, -733.323, -747.325, -761.28, -775.188, -789.046, -802.8530000000001, -816.6089999999999, -830.312, -843.961, -857.555, -871.0930000000001, -884.573, -897.9939999999999, -911.3539999999999, -924.6519999999999, -937.887, -951.058, -964.1619999999999, -977.198, -990.166, -1003.062, -1015.8860000000001, -1028.637, -1041.3110000000001, -1053.9080000000001, -1066.4260000000002, -1078.864, -1091.218, -1103.488, -1115.672, -1127.767, -1139.772, -1151.685, -1163.503, -1175.224, -1186.847, -1198.369, -1209.787, -1221.1, -1232.3039999999999, -1243.3980000000001, -1254.379, -1265.245, -1275.991, -1286.617, -1297.118, -1307.493, -1317.7379999999998, -1327.85, -1337.826, -1347.662, -1357.356, -1366.904, -1376.3010000000002, -1385.546, -1394.634, -1403.56, -1412.3220000000001, -1420.914, -1429.3339999999998, -1437.575, -1445.635, -1453.507, -1461.1879999999999, -1468.672, -1475.954, -1483.03, -1489.892, -1496.536, -1502.9560000000001, -1509.145, -1515.098, -1520.808, -1526.267, -1531.469, -1536.4070000000002, -1541.0729999999999, -1545.4589999999998, -1549.557, -1553.358, -1556.854, -1560.035, -1562.892, -1565.414, -1567.5929999999998, -1569.4160000000002, -1570.872, -1571.95, -1572.638, -1572.922, -1572.789, -1572.226, -1571.2179999999998, -1569.749, -1567.8039999999999, -1565.366, -1562.4170000000001, -1558.941, -1554.9160000000002, -1550.3229999999999, -1545.142, -1539.35, -1532.925, -1525.8410000000001, -1518.0739999999998, -1509.5970000000002, -1500.382, -1490.399, -1479.619, -1468.0079999999998, -1455.533, -1442.158, -1427.846, -1412.557, -1396.2520000000002, -1378.888, -1360.4189999999999, -1340.8, -1319.9820000000002, -1297.9160000000002, -1274.549, -1249.829, -1223.701, -1196.11, -1166.998, -1136.312, -1103.995, -1069.991, -1034.25, -996.7230000000001, -957.365, -916.1389999999999, -873.0139999999999, -827.9730000000001, -781.007, -732.123, -681.346, -628.719, -574.305, -518.191, -460.48699999999997, -401.325, -340.86199999999997, -279.27299999999997, -216.753, -153.51, -89.762, -25.733, 38.354, 102.28399999999999, 165.84799999999998, 228.85299999999998, 291.125, 352.505, 412.858, 472.065, 530.031, 586.679, 641.948, 695.795, 748.191, 799.117, 848.569, 896.549, 943.068, 988.1419999999999, 1031.7930000000001, 1074.048, 1114.935, 1154.485, 1192.732, 1229.7089999999998, 1265.45, 1299.991, 1333.366, 1365.611, 1396.7579999999998, 1426.8410000000001, 1455.8929999999998, 1483.9460000000001, 1511.031, 1537.1789999999999, 1562.4170000000001, 1586.774, 1610.2779999999998, 1632.955, 1654.829, 1675.9260000000002, 1696.269, 1715.88, 1734.781, 1752.993, 1770.537, 1787.431, 1803.694, 1819.345, 1834.399, 1848.875, 1862.7879999999998, 1876.1529999999998, 1888.985, 1901.2979999999998, 1913.106, 1924.4229999999998, 1935.261, 1945.631, 1955.547, 1965.019, 1974.059, 1982.6770000000001, 1990.8829999999998, 1998.6870000000001, 2006.1, 2013.129, 2019.7839999999999, 2026.0739999999998, 2032.007, 2037.59, 2042.8329999999999, 2047.7420000000002, 2052.325, 2056.589, 2060.54, 2064.186, 2067.532, 2070.5860000000002, 2073.353, 2075.8379999999997, 2078.049, 2079.99, 2081.667, 2083.085, 2084.248, 2085.163, 2085.834, 2086.265, 2086.4610000000002, 2086.427, 2086.167, 2085.6839999999997, 2084.984, 2084.069, 2082.945, 2081.614, 2080.081, 2078.349, 2076.4210000000003, 2074.301, 2071.992, 2069.498, 2066.822, 2063.966, 2060.9339999999997, 2057.728, 2054.3520000000003, 2050.8089999999997, 2047.101, 2043.23, 2039.2, 2035.013, 2030.672, 2026.1779999999999, 2021.535, 2016.745, 2011.81, 2006.7320000000002, 2001.513, 1996.1570000000002, 1990.664, 1985.037, 1979.2779999999998, 1973.388, 1967.371, 1961.227, 1954.9589999999998, 1948.569, 1942.058, 1935.4270000000001, 1928.68, 1921.817, 1914.84, 1907.751, 1900.5510000000002, 1893.2420000000002, 1885.826, 1878.3039999999999, 1870.6770000000001, 1862.9479999999999, 1855.1170000000002, 1847.185, 1839.155, 1831.0279999999998, 1822.8039999999999, 1814.486, 1806.075, 1797.5710000000001, 1788.977, 1780.293, 1771.52, 1762.661, 1753.715, 1744.685, 1735.5710000000001, 1726.374, 1717.096, 1707.737, 1698.3, 1688.7839999999999, 1679.191, 1669.521, 1659.777, 1649.9589999999998, 1640.067, 1630.1029999999998, 1620.068, 1609.963, 1599.789, 1589.546, 1579.236, 1568.859, 1558.4160000000002, 1547.9089999999999, 1537.3370000000002, 1526.703, 1516.006, 1505.2479999999998, 1494.4289999999999, 1483.55, 1472.6129999999998, 1461.6170000000002, 1450.5629999999999, 1439.453, 1428.2879999999998, 1417.067, 1405.7910000000002, 1394.4620000000002, 1383.08, 1371.646, 1360.161, 1348.624, 1337.0379999999998, 1325.402, 1313.717, 1301.985, 1290.205, 1278.378, 1266.505, 1254.587, 1242.624, 1230.618, 1218.567, 1206.474, 1194.339, 1182.162, 1169.944, 1157.685, 1145.387, 1133.05, 1120.674, 1108.26, 1095.809, 1083.3210000000001, 1070.797, 1058.237, 1045.642, 1033.012, 1020.3489999999999, 1007.6519999999999, 994.922, 982.16, 969.3660000000001, 956.54, 943.684, 930.798, 917.883, 904.938, 891.9639999999999, 878.9630000000001, 865.934, 852.878, 839.795, 826.687, 813.553, 800.3939999999999, 787.211, 774.003, 760.773, 747.5189999999999, 734.243, 720.945, 707.6260000000001, 694.2860000000001, 680.925, 667.544, 654.144, 640.725, 627.288, 613.8330000000001, 600.36, 586.87, 573.364, 559.842, 546.304, 532.752, 519.185, 505.603, 492.009, 478.401, 464.781, 451.149, 437.505, 423.85, 410.185, 396.51, 382.825, 369.131, 355.42800000000005, 341.718, 327.999, 314.274, 300.543, 286.805, 273.061, 259.313, 245.56, 231.803, 218.043, 204.28, 190.514, 176.747, 162.97799999999998, 149.208, 135.438, 121.66799999999999, 107.899, 94.131, 80.365, 66.602, 52.841, 39.084, 25.331999999999997, 11.583, -2.16, -15.897, -29.627, -43.351000000000006, -57.067, -70.775, -84.47399999999999, -98.164, -111.844, -125.51299999999999, -139.171, -152.817, -166.45, -180.07, -193.67700000000002, -207.269, -220.845, -234.40599999999998, -247.95, -261.47700000000003, -274.986, -288.47700000000003, -301.948, -315.399, -328.829, -342.23699999999997, -355.62300000000005, -368.986, -382.325, -395.639, -408.92800000000005, -422.19, -435.425, -448.63199999999995, -461.81, -474.959, -488.07599999999996, -501.162, -514.216, -527.237, -540.2230000000001, -553.173, -566.0880000000001, -578.965, -591.804, -604.6030000000001, -617.362, -630.08, -642.755, -655.387, -667.9730000000001, -680.5139999999999, -693.008, -705.453, -717.8489999999999, -730.194, -742.488, -754.727, -766.9119999999999, -779.041, -791.113, -803.125, -815.078, -826.9680000000001, -838.796, -850.558, -862.2539999999999, -873.882, -885.441, -896.928, -908.341, -919.68, -930.942, -942.1260000000001, -953.2289999999999, -964.2489999999999, -975.185, -986.035, -996.795, -1007.465, -1018.041, -1028.5230000000001, -1038.906, -1049.1889999999999, -1059.369, -1069.445, -1079.412, -1089.268, -1099.011, -1108.638, -1118.146, -1127.531, -1136.7910000000002, -1145.922, -1154.921, -1163.785, -1172.509, -1181.0910000000001, -1189.527, -1197.812, -1205.942, -1213.914, -1221.723, -1229.365, -1236.835, -1244.128, -1251.239, -1258.164, -1264.896, -1271.431, -1277.762, -1283.885, -1289.7910000000002, -1295.4769999999999, -1300.934, -1306.155, -1311.135, -1315.864, -1320.3370000000002, -1324.543, -1328.476, -1332.1270000000002, -1335.485, -1338.543, -1341.29, -1343.715, -1345.808, -1347.559, -1348.954, -1349.9820000000002, -1350.63, -1350.885, -1350.7320000000002, -1350.158, -1349.145, -1347.68, -1345.743, -1343.319, -1340.388, -1336.93, -1332.9260000000002, -1328.3529999999998, -1323.1889999999999, -1317.411, -1310.993, -1303.9089999999999, -1296.132, -1287.633, -1278.381, -1268.344, -1257.489, -1245.781, -1233.183, -1219.656, -1205.16, -1189.652, -1173.089, -1155.425, -1136.613, -1116.603, -1095.346, -1072.789, -1048.88, -1023.566, -996.794, -968.513, -938.671, -907.22, -874.117, -839.32, -802.798, -764.5260000000001, -724.49, -682.687, -639.13, -593.8480000000001, -546.889, -498.319, -448.227, -396.722, -343.934, -290.012, -235.12400000000002, -179.45, -123.182, -66.516, -9.652000000000001, 47.215, 103.898, 160.218, 216.015, 271.14, 325.465, 378.87699999999995, 431.282, 482.60400000000004, 532.781, 581.7669999999999, 629.5269999999999, 676.041, 721.297, 765.29, 808.025, 849.512, 889.7660000000001, 928.806, 966.653, 1003.332, 1038.869, 1073.292, 1106.629, 1138.9489999999998, 1170.1589999999999, 1200.41, 1229.69, 1258.027, 1285.45, 1311.984, 1337.6570000000002, 1362.495, 1386.5220000000002, 1409.763, 1432.2420000000002, 1453.98, 1475.0, 1495.3239999999998, 1514.971, 1533.961, 1552.3139999999999, 1570.047, 1587.1789999999999, 1603.725, 1619.703, 1635.129, 1650.017, 1664.382, 1678.2379999999998, 1691.598, 1704.476, 1716.885, 1728.836, 1740.3410000000001, 1751.411, 1762.058, 1772.2910000000002, 1782.121, 1791.558, 1800.61, 1809.2879999999998, 1817.6, 1825.5539999999999, 1833.1589999999999, 1840.422, 1847.352, 1853.9560000000001, 1860.24, 1866.2120000000002, 1871.879, 1877.2479999999998, 1882.3239999999998, 1887.1129999999998, 1891.6229999999998, 1895.8570000000002, 1899.8229999999999, 1903.525, 1906.97, 1910.161, 1913.1029999999998, 1915.8029999999999, 1918.264, 1920.491, 1922.489, 1924.261, 1925.8120000000001, 1927.146, 1928.2679999999998, 1929.18, 1929.8870000000002, 1930.392, 1930.6989999999998, 1930.8120000000001, 1930.733, 1930.4660000000001, 1930.015, 1929.3829999999998, 1928.5710000000001, 1927.585, 1926.4260000000002, 1925.0970000000002, 1923.602, 1921.942, 1920.121, 1918.141, 1916.005, 1913.714, 1911.273, 1908.682, 1905.945, 1903.0629999999999, 1900.039, 1896.875, 1893.5729999999999, 1890.135, 1886.5629999999999, 1882.859, 1879.025, 1875.0639999999999, 1870.976, 1866.764, 1862.43, 1857.975, 1853.401, 1848.7089999999998, 1843.902, 1838.981, 1833.9479999999999, 1828.8039999999999, 1823.55, 1818.1889999999999, 1812.7220000000002, 1807.149, 1801.473, 1795.695, 1789.817, 1783.839, 1777.764, 1771.5910000000001, 1765.3239999999998, 1758.9620000000002, 1752.507, 1745.961, 1739.3239999999998, 1732.598, 1725.7839999999999, 1718.8829999999998, 1711.896, 1704.825, 1697.67, 1690.432, 1683.112, 1675.7120000000002, 1668.233, 1660.675, 1653.04, 1645.328, 1637.5410000000002, 1629.6789999999999, 1621.743, 1613.735, 1605.655, 1597.504, 1589.283, 1580.9920000000002, 1572.6329999999998, 1564.207, 1555.714, 1547.155, 1538.531, 1529.8429999999998, 1521.0910000000001, 1512.277, 1503.4, 1494.463, 1485.465, 1476.4070000000002, 1467.2910000000002, 1458.116, 1448.884, 1439.595, 1430.249, 1420.848, 1411.3929999999998, 1401.8829999999998, 1392.32, 1382.704, 1373.036, 1363.317, 1353.547, 1343.726, 1333.856, 1323.9370000000001, 1313.969, 1303.954, 1293.891, 1283.782, 1273.626, 1263.4260000000002, 1253.18, 1242.89, 1232.556, 1222.1789999999999, 1211.76, 1201.298, 1190.795, 1180.25, 1169.6660000000002, 1159.0410000000002, 1148.376, 1137.673, 1126.931, 1116.152, 1105.335, 1094.481, 1083.59, 1072.664, 1061.702, 1050.7060000000001, 1039.674, 1028.609, 1017.5110000000001, 1006.3789999999999, 995.215, 984.018, 972.79, 961.5310000000001, 950.2410000000001, 938.921, 927.571, 916.192, 904.784, 893.347, 881.883, 870.3910000000001, 858.8710000000001, 847.325, 835.753, 824.155, 812.5319999999999, 800.8839999999999, 789.211, 777.5139999999999, 765.794, 754.05, 742.284, 730.495, 718.684, 706.852, 694.9989999999999, 683.125, 671.2310000000001, 659.317, 647.384, 635.432, 623.461, 611.472, 599.465, 587.441, 575.401, 563.344, 551.27, 539.182, 527.078, 514.9590000000001, 502.82599999999996, 490.67900000000003, 478.519, 466.345, 454.159, 441.961, 429.751, 417.53, 405.298, 393.055, 380.80300000000005, 368.54, 356.269, 343.98900000000003, 331.7, 319.404, 307.101, 294.79, 282.473, 270.15, 257.82099999999997, 245.488, 233.149, 220.80700000000002, 208.46099999999998, 196.111, 183.75900000000001, 171.40400000000002, 159.048, 146.69, 134.33100000000002, 121.973, 109.61399999999999, 97.256, 84.899, 72.544, 60.191, 47.84, 35.493, 23.15, 10.811, -1.5230000000000001, -13.852, -26.175, -38.491, -50.8, -63.102, -75.395, -87.679, -99.954, -112.219, -124.473, -136.716, -148.947, -161.166, -173.37099999999998, -185.562, -197.739, -209.90099999999998, -222.047, -234.176, -246.28799999999998, -258.382, -270.457, -282.513, -294.54900000000004, -306.563, -318.556, -330.526, -342.473, -354.39599999999996, -366.29400000000004, -378.165, -390.01, -401.82800000000003, -413.616, -425.376, -437.105, -448.80199999999996, -460.468, -472.1, -483.69800000000004, -495.26, -506.786, -518.275, -529.725, -541.135, -552.504, -563.832, -575.116, -586.356, -597.55, -608.697, -619.7959999999999, -630.846, -641.844, -652.79, -663.682, -674.518, -685.298, -696.02, -706.681, -717.2810000000001, -727.817, -738.289, -748.694, -759.03, -769.295, -779.488, -789.607, -799.65, -809.6139999999999, -819.497, -829.298, -839.013, -848.6410000000001, -858.179, -867.625, -876.9760000000001, -886.23, -895.383, -904.434, -913.378, -922.2130000000001, -930.937, -939.545, -948.035, -956.403, -964.6460000000001, -972.76, -980.7410000000001, -988.585, -996.289, -1003.847, -1011.257, -1018.512, -1025.61, -1032.5439999999999, -1039.31, -1045.903, -1052.316, -1058.546, -1064.585, -1070.427, -1076.067, -1081.497, -1086.712, -1091.703, -1096.463, -1100.985, -1105.26, -1109.28, -1113.036, -1116.519, -1119.719, -1122.626, -1125.23, -1127.519, -1129.482, -1131.106, -1132.38, -1133.289, -1133.8210000000001, -1133.9589999999998, -1133.688, -1132.993, -1131.857, -1130.261, -1128.187, -1125.614, -1122.5230000000001, -1118.891, -1114.695, -1109.911, -1104.513, -1098.474, -1091.767, -1084.361, -1076.225, -1067.327, -1057.631, -1047.101, -1035.7, -1023.387, -1010.122, -995.862, -980.56, -964.173, -946.65, -927.945, -908.008, -886.788, -864.2360000000001, -840.303, -814.942, -788.1080000000001, -759.76, -729.863, -698.3860000000001, -665.31, -630.623, -594.327, -556.437, -516.984, -476.01800000000003, -433.60400000000004, -389.829, -344.79699999999997, -298.632, -251.472, -203.47, -154.791, -105.604, -56.085, -6.405, 43.266000000000005, 92.77, 141.957, 190.692, 238.852, 286.33299999999997, 333.043, 378.906, 423.86, 467.856, 510.85699999999997, 552.835, 593.774, 633.664, 672.503, 710.2919999999999, 747.0419999999999, 782.7639999999999, 817.472, 851.184, 883.919, 915.698, 946.543, 976.477, 1005.523, 1033.703, 1061.0410000000002, 1087.559, 1113.281, 1138.229, 1162.425, 1185.89, 1208.646, 1230.711, 1252.107, 1272.853, 1292.9660000000001, 1312.465, 1331.3670000000002, 1349.6889999999999, 1367.4470000000001, 1384.656, 1401.3329999999999, 1417.49, 1433.1429999999998, 1448.305, 1462.9879999999998, 1477.2060000000001, 1490.97, 1504.293, 1517.185, 1529.6570000000002, 1541.72, 1553.384, 1564.6589999999999, 1575.5539999999999, 1586.078, 1596.241, 1606.05, 1615.513, 1624.64, 1633.4370000000001, 1641.912, 1650.0720000000001, 1657.924, 1665.475, 1672.731, 1679.6989999999998, 1686.384, 1692.793, 1698.932, 1704.805, 1710.4189999999999, 1715.7779999999998, 1720.888, 1725.754, 1730.38, 1734.771, 1738.932, 1742.8670000000002, 1746.58, 1750.075, 1753.356, 1756.4289999999999, 1759.295, 1761.9589999999998, 1764.424, 1766.695, 1768.774, 1770.665, 1772.37, 1773.894, 1775.24, 1776.4089999999999, 1777.406, 1778.233, 1778.8929999999998, 1779.388, 1779.7220000000002, 1779.8970000000002, 1779.915, 1779.779, 1779.491, 1779.0539999999999, 1778.47, 1777.741, 1776.87, 1775.858, 1774.7079999999999, 1773.422, 1772.0020000000002, 1770.4489999999998, 1768.766, 1766.955, 1765.017, 1762.955, 1760.769, 1758.463, 1756.037, 1753.493, 1750.8329999999999, 1748.058, 1745.17, 1742.171, 1739.0620000000001, 1735.844, 1732.52, 1729.089, 1725.555, 1721.918, 1718.1789999999999, 1714.34, 1710.402, 1706.3670000000002, 1702.235, 1698.0079999999998, 1693.6870000000001, 1689.274, 1684.769, 1680.174, 1675.489, 1670.7160000000001, 1665.856, 1660.91, 1655.879, 1650.765, 1645.567, 1640.287, 1634.9270000000001, 1629.486, 1623.967, 1618.369, 1612.694, 1606.943, 1601.1170000000002, 1595.2160000000001, 1589.2420000000002, 1583.195, 1577.076, 1570.886, 1564.625, 1558.296, 1551.8970000000002, 1545.431, 1538.898, 1532.2979999999998, 1525.6329999999998, 1518.902, 1512.108, 1505.25, 1498.33, 1491.348, 1484.3039999999999, 1477.1989999999998, 1470.035, 1462.8120000000001, 1455.529, 1448.1889999999999, 1440.7910000000002, 1433.3370000000002, 1425.8270000000002, 1418.261, 1410.64, 1402.964, 1395.236, 1387.454, 1379.619, 1371.733, 1363.795, 1355.806, 1347.767, 1339.6779999999999, 1331.54, 1323.3529999999998, 1315.118, 1306.836, 1298.506, 1290.13, 1281.708, 1273.24, 1264.7269999999999, 1256.1689999999999, 1247.568, 1238.922, 1230.234, 1221.502, 1212.729, 1203.913, 1195.057, 1186.1589999999999, 1177.221, 1168.244, 1159.226, 1150.17, 1141.075, 1131.941, 1122.77, 1113.5610000000001, 1104.316, 1095.0339999999999, 1085.7160000000001, 1076.362, 1066.973, 1057.549, 1048.09, 1038.598, 1029.072, 1019.512, 1009.919, 1000.294, 990.637, 980.948, 971.2280000000001, 961.477, 951.695, 941.883, 932.041, 922.17, 912.2689999999999, 902.34, 892.382, 882.3960000000001, 872.383, 862.342, 852.275, 842.181, 832.06, 821.914, 811.743, 801.546, 791.324, 781.078, 770.808, 760.5139999999999, 750.197, 739.857, 729.4939999999999, 719.1089999999999, 708.702, 698.273, 687.823, 677.352, 666.86, 656.3480000000001, 645.816, 635.265, 624.695, 614.105, 603.498, 592.872, 582.2280000000001, 571.567, 560.889, 550.194, 539.482, 528.755, 518.012, 507.25300000000004, 496.48, 485.69199999999995, 474.89, 464.074, 453.244, 442.401, 431.546, 420.67800000000005, 409.798, 398.906, 388.00300000000004, 377.089, 366.164, 355.22900000000004, 344.285, 333.33099999999996, 322.368, 311.39599999999996, 300.416, 289.428, 278.433, 267.431, 256.422, 245.407, 234.386, 223.36, 212.329, 201.293, 190.253, 179.209, 168.162, 157.113, 146.061, 135.007, 123.95200000000001, 112.895, 101.839, 90.78200000000001, 79.726, 68.67, 57.61600000000001, 46.56399999999999, 35.515, 24.468000000000004, 13.425999999999998, 2.387, -8.648, -19.677, -30.701, -41.718, -52.728, -63.731, -74.727, -85.713, -96.69, -107.65799999999999, -118.615, -129.561, -140.495, -151.416, -162.325, -173.21900000000002, -184.1, -194.96400000000003, -205.813, -216.646, -227.46, -238.257, -249.03400000000002, -259.791, -270.528, -281.243, -291.936, -302.605, -313.25, -323.87, -334.464, -345.031, -355.57, -366.079, -376.559, -387.00699999999995, -397.423, -407.806, -418.154, -428.467, -438.74199999999996, -448.97900000000004, -459.17699999999996, -469.335, -479.45, -489.52099999999996, -499.548, -509.529, -519.461, -529.345, -539.177, -548.957, -558.683, -568.3530000000001, -577.965, -587.518, -597.009, -606.437, -615.8, -625.095, -634.321, -643.475, -652.556, -661.56, -670.485, -679.329, -688.0889999999999, -696.763, -705.347, -713.84, -722.237, -730.5360000000001, -738.7339999999999, -746.828, -754.813, -762.687, -770.445, -778.085, -785.602, -792.9910000000001, -800.2489999999999, -807.3710000000001, -814.3530000000001, -821.189, -827.875, -834.405, -840.7739999999999, -846.977, -853.0060000000001, -858.857, -864.523, -869.9960000000001, -875.2710000000001, -880.3380000000001, -885.192, -889.823, -894.2230000000001, -898.3839999999999, -902.296, -905.948, -909.332, -912.437, -915.25, -917.76, -919.955, -921.822, -923.347, -924.515, -925.311, -925.7180000000001, -925.721, -925.301, -924.439, -923.115, -921.309, -918.998, -916.159, -912.7660000000001, -908.796, -904.2180000000001, -899.0060000000001, -893.1289999999999, -886.554, -879.247, -871.175, -862.298, -852.58, -841.9789999999999, -830.454, -817.96, -804.454, -789.8889999999999, -774.2180000000001, -757.395, -739.373, -720.105, -699.547, -677.6569999999999, -654.395, -629.73, -603.634, -576.087, -547.082, -516.619, -484.715, -451.399, -416.717, -380.733, -343.527, -305.193, -265.844, -225.604, -184.609, -143.004, -100.93700000000001, -58.556999999999995, -16.012999999999998, 26.554000000000002, 69.01, 111.23100000000001, 153.105, 194.53099999999998, 235.423, 275.705, 315.316, 354.204, 392.32800000000003, 429.658, 466.17, 501.85, 536.687, 570.679, 603.827, 636.135, 667.6110000000001, 698.2669999999999, 728.113, 757.165, 785.438, 812.948, 839.712, 865.747, 891.072, 915.703, 939.658, 962.956, 985.612, 1007.645, 1029.0710000000001, 1049.905, 1070.165, 1089.864, 1109.02, 1127.645, 1145.755, 1163.362, 1180.481, 1197.124, 1213.303, 1229.032, 1244.32, 1259.18, 1273.622, 1287.6580000000001, 1301.296, 1314.547, 1327.42, 1339.925, 1352.07, 1363.864, 1375.315, 1386.431, 1397.219, 1407.6879999999999, 1417.845, 1427.6960000000001, 1437.2479999999998, 1446.5079999999998, 1455.4820000000002, 1464.1760000000002, 1472.596, 1480.7479999999998, 1488.638, 1496.27, 1503.651, 1510.785, 1517.6770000000001, 1524.332, 1530.754, 1536.9489999999998, 1542.92, 1548.672, 1554.2079999999999, 1559.5339999999999, 1564.652, 1569.566, 1574.281, 1578.8, 1583.126, 1587.2620000000002, 1591.213, 1594.981, 1598.569, 1601.98, 1605.2179999999998, 1608.285, 1611.185, 1613.9189999999999, 1616.491, 1618.902, 1621.1570000000002, 1623.257, 1625.204, 1627.0020000000002, 1628.651, 1630.156, 1631.517, 1632.737, 1633.818, 1634.763, 1635.5720000000001, 1636.249, 1636.795, 1637.211, 1637.501, 1637.665, 1637.705, 1637.624, 1637.422, 1637.102, 1636.665, 1636.1129999999998, 1635.4460000000001, 1634.668, 1633.7779999999998, 1632.78, 1631.6729999999998, 1630.46, 1629.142, 1627.72, 1626.1960000000001, 1624.57, 1622.845, 1621.021, 1619.1, 1617.0829999999999, 1614.97, 1612.764, 1610.465, 1608.075, 1605.594, 1603.024, 1600.365, 1597.619, 1594.787, 1591.869, 1588.8670000000002, 1585.7820000000002, 1582.615, 1579.366, 1576.037, 1572.628, 1569.14, 1565.575, 1561.932, 1558.214, 1554.42, 1550.5520000000001, 1546.61, 1542.595, 1538.5079999999998, 1534.35, 1530.122, 1525.8229999999999, 1521.4560000000001, 1517.02, 1512.517, 1507.9460000000001, 1503.31, 1498.608, 1493.8410000000001, 1489.01, 1484.115, 1479.158, 1474.138, 1469.056, 1463.914, 1458.711, 1453.4479999999999, 1448.1270000000002, 1442.746, 1437.307, 1431.8110000000001, 1426.2579999999998, 1420.649, 1414.984, 1409.263, 1403.4879999999998, 1397.6589999999999, 1391.776, 1385.839, 1379.85, 1373.809, 1367.7160000000001, 1361.5720000000001, 1355.3770000000002, 1349.132, 1342.8370000000002, 1336.493, 1330.099, 1323.658, 1317.168, 1310.631, 1304.047, 1297.417, 1290.74, 1284.017, 1277.249, 1270.4360000000001, 1263.578, 1256.6760000000002, 1249.731, 1242.742, 1235.71, 1228.636, 1221.519, 1214.361, 1207.161, 1199.92, 1192.639, 1185.317, 1177.955, 1170.5539999999999, 1163.113, 1155.634, 1148.116, 1140.56, 1132.9660000000001, 1125.335, 1117.6660000000002, 1109.961, 1102.219, 1094.441, 1086.627, 1078.778, 1070.893, 1062.974, 1055.02, 1047.032, 1039.01, 1030.954, 1022.8660000000001, 1014.7439999999999, 1006.5889999999999, 998.4019999999999, 990.183, 981.933, 973.65, 965.337, 956.993, 948.618, 940.2130000000001, 931.778, 923.313, 914.819, 906.295, 897.743, 889.1619999999999, 880.553, 871.916, 863.2510000000001, 854.558, 845.8389999999999, 837.092, 828.319, 819.52, 810.695, 801.8430000000001, 792.966, 784.064, 775.137, 766.186, 757.21, 748.209, 739.185, 730.137, 721.066, 711.972, 702.855, 693.715, 684.553, 675.37, 666.164, 656.937, 647.689, 638.42, 629.13, 619.82, 610.49, 601.14, 591.771, 582.382, 572.975, 563.548, 554.104, 544.641, 535.16, 525.6619999999999, 516.1469999999999, 506.61400000000003, 497.065, 487.5, 477.918, 468.32099999999997, 458.708, 449.079, 439.436, 429.779, 420.10699999999997, 410.421, 400.721, 391.00800000000004, 381.282, 371.543, 361.792, 352.029, 342.254, 332.468, 322.67, 312.862, 303.043, 293.215, 283.376, 273.528, 263.672, 253.80700000000002, 243.933, 234.05200000000002, 224.16299999999998, 214.267, 204.364, 194.456, 184.541, 174.62099999999998, 164.695, 154.765, 144.83100000000002, 134.893, 124.95200000000001, 115.008, 105.061, 95.113, 85.163, 75.212, 65.26100000000001, 55.31, 45.358999999999995, 35.409, 25.461, 15.515, 5.572, -4.368, -14.304, -24.235, -34.161, -44.082, -53.997, -63.903999999999996, -73.804, -83.695, -93.57799999999999, -103.45, -113.31200000000001, -123.163, -133.002, -142.829, -152.641, -162.44, -172.22299999999998, -181.989, -191.739, -201.47099999999998, -211.18400000000003, -220.877, -230.55, -240.2, -249.828, -259.432, -269.01, -278.562, -288.087, -297.58299999999997, -307.04900000000004, -316.48400000000004, -325.88599999999997, -335.255, -344.588, -353.884, -363.142, -372.36, -381.537, -390.67, -399.759, -408.801, -417.79400000000004, -426.73699999999997, -435.62699999999995, -444.463, -453.24199999999996, -461.963, -470.62199999999996, -479.218, -487.74800000000005, -496.21, -504.6, -512.9169999999999, -521.156, -529.316, -537.393, -545.384, -553.286, -561.095, -568.807, -576.419, -583.9259999999999, -591.325, -598.611, -605.78, -612.827, -619.746, -626.534, -633.184, -639.691, -646.048, -652.251, -658.291, -664.163, -669.8589999999999, -675.372, -680.693, -685.814, -690.727, -695.423, -699.8910000000001, -704.1210000000001, -708.1030000000001, -711.826, -715.2760000000001, -718.442, -721.311, -723.867, -726.096, -727.9830000000001, -729.51, -730.66, -731.414, -731.753, -731.655, -731.0980000000001, -730.058, -728.512, -726.432, -723.791, -720.56, -716.707, -712.2, -707.005, -701.085, -694.404, -686.922, -678.5980000000001, -669.39, -659.2539999999999, -648.1469999999999, -636.024, -622.839, -608.55, -593.112, -576.485, -558.632, -539.52, -519.123, -497.42, -474.403, -450.07099999999997, -424.436, -397.524, -369.375, -340.04400000000004, -309.601, -278.129, -245.72400000000002, -212.495, -178.55900000000003, -144.037, -109.056, -73.742, -38.219, -2.603, 32.992, 68.465, 103.723, 138.683, 173.271, 207.426, 241.09599999999998, 274.235, 306.809, 338.79, 370.157, 400.894, 430.991, 460.44199999999995, 489.245, 517.401, 544.913, 571.7869999999999, 598.031, 623.653, 648.844, 673.072, 696.8919999999999, 720.135, 742.812, 764.937, 786.5210000000001, 807.578, 828.12, 848.158, 867.707, 886.7760000000001, 905.3789999999999, 923.5260000000001, 941.2289999999999, 958.4989999999999, 975.347, 991.7819999999999, 1007.815, 1023.456, 1038.715, 1053.6, 1068.12, 1082.2839999999999, 1096.101, 1109.578, 1122.723, 1135.545, 1148.05, 1160.246, 1172.14, 1183.737, 1195.046, 1206.0710000000001, 1216.82, 1227.298, 1237.51, 1247.463, 1257.162, 1266.611, 1275.817, 1284.7830000000001, 1293.515, 1302.018, 1310.295, 1318.351, 1326.191, 1333.818, 1341.237, 1348.45, 1355.463, 1362.279, 1368.901, 1375.332, 1381.5770000000002, 1387.638, 1393.519, 1399.2220000000002, 1404.751, 1410.109, 1415.297, 1420.3210000000001, 1425.181, 1429.881, 1434.422, 1438.809, 1443.043, 1447.126, 1451.0610000000001, 1454.85, 1458.496, 1462.0, 1465.365, 1468.592, 1471.684, 1474.6429999999998, 1477.471, 1480.1689999999999, 1482.739, 1485.184, 1487.504, 1489.7020000000002, 1491.779, 1493.7379999999998, 1495.578, 1497.3029999999999, 1498.914, 1500.412, 1501.7979999999998, 1503.0739999999998, 1504.2420000000002, 1505.3029999999999, 1506.2579999999998, 1507.109, 1507.8570000000002, 1508.503, 1509.0479999999998, 1509.494, 1509.8410000000001, 1510.092, 1510.247, 1510.307, 1510.274, 1510.148, 1509.931, 1509.624, 1509.227, 1508.7420000000002, 1508.1689999999999, 1507.51, 1506.766, 1505.9379999999999, 1505.026, 1504.031, 1502.955, 1501.797, 1500.56, 1499.244, 1497.849, 1496.3770000000002, 1494.829, 1493.204, 1491.505, 1489.731, 1487.8829999999998, 1485.963, 1483.97, 1481.906, 1479.7720000000002, 1477.567, 1475.293, 1472.951, 1470.54, 1468.0629999999999, 1465.5179999999998, 1462.9070000000002, 1460.231, 1457.49, 1454.685, 1451.817, 1448.885, 1445.891, 1442.8339999999998, 1439.717, 1436.5379999999998, 1433.3, 1430.001, 1426.644, 1423.227, 1419.753, 1416.221, 1412.631, 1408.985, 1405.283, 1401.525, 1397.7120000000002, 1393.844, 1389.921, 1385.945, 1381.915, 1377.832, 1373.6970000000001, 1369.509, 1365.27, 1360.979, 1356.638, 1352.246, 1347.8029999999999, 1343.3120000000001, 1338.77, 1334.18, 1329.5410000000002, 1324.855, 1320.12, 1315.338, 1310.508, 1305.632, 1300.71, 1295.741, 1290.7269999999999, 1285.6680000000001, 1280.563, 1275.414, 1270.22, 1264.983, 1259.701, 1254.377, 1249.009, 1243.598, 1238.145, 1232.65, 1227.113, 1221.5339999999999, 1215.914, 1210.253, 1204.5510000000002, 1198.809, 1193.027, 1187.204, 1181.343, 1175.442, 1169.501, 1163.5230000000001, 1157.505, 1151.4489999999998, 1145.356, 1139.224, 1133.055, 1126.849, 1120.606, 1114.326, 1108.009, 1101.657, 1095.268, 1088.843, 1082.383, 1075.888, 1069.357, 1062.792, 1056.192, 1049.557, 1042.889, 1036.1860000000001, 1029.45, 1022.68, 1015.877, 1009.041, 1002.172, 995.27, 988.336, 981.37, 974.3710000000001, 967.341, 960.279, 953.186, 946.062, 938.9060000000001, 931.72, 924.503, 917.2560000000001, 909.9789999999999, 902.671, 895.334, 887.967, 880.571, 873.145, 865.691, 858.2080000000001, 850.696, 843.155, 835.586, 827.99, 820.365, 812.712, 805.033, 797.325, 789.591, 781.83, 774.0419999999999, 766.227, 758.3860000000001, 750.5189999999999, 742.6260000000001, 734.707, 726.763, 718.793, 710.797, 702.7769999999999, 694.732, 686.6619999999999, 678.568, 670.449, 662.307, 654.14, 645.95, 637.736, 629.499, 621.238, 612.955, 604.649, 596.321, 587.97, 579.597, 571.202, 562.786, 554.347, 545.888, 537.408, 528.906, 520.384, 511.842, 503.279, 494.69599999999997, 486.093, 477.471, 468.83, 460.16900000000004, 451.49, 442.792, 434.075, 425.34, 416.588, 407.81800000000004, 399.03, 390.225, 381.404, 372.565, 363.711, 354.84, 345.95300000000003, 337.051, 328.134, 319.202, 310.255, 301.29400000000004, 292.319, 283.33, 274.328, 265.312, 256.285, 247.24400000000003, 238.192, 229.128, 220.053, 210.967, 201.87, 192.763, 183.64700000000002, 174.521, 165.386, 156.243, 147.092, 137.933, 128.768, 119.595, 110.417, 101.23299999999999, 92.044, 82.85, 73.653, 64.452, 55.248000000000005, 46.042, 36.834, 27.625, 18.416, 9.207, 0.0, -9.206, -18.409000000000002, -27.61, -36.806, -45.997, -55.181999999999995, -64.361, -73.532, -82.695, -91.84899999999999, -100.992, -110.124, -119.243, -128.349, -137.44, -146.515, -155.57299999999998, -164.613, -173.63299999999998, -182.63099999999997, -191.607, -200.55900000000003, -209.486, -218.385, -227.255, -236.095, -244.90200000000002, -253.675, -262.41200000000003, -271.11, -279.768, -288.382, -296.952, -305.475, -313.947, -322.366, -330.731, -339.036, -347.28, -355.46, -363.57099999999997, -371.611, -379.57599999999996, -387.462, -395.264, -402.98, -410.603, -418.13, -425.555, -432.874, -440.08099999999996, -447.16900000000004, -454.134, -460.968, -467.665, -474.217, -480.61699999999996, -486.85699999999997, -492.92900000000003, -498.82300000000004, -504.53, -510.041, -515.3430000000001, -520.4259999999999, -525.279, -529.887, -534.238, -538.318, -542.11, -545.599, -548.7669999999999, -551.597, -554.068, -556.159, -557.849, -559.114, -559.93, -560.268, -560.1030000000001, -559.403, -558.138, -556.273, -553.775, -550.607, -546.729, -542.1030000000001, -536.688, -530.44, -523.317, -515.275, -506.27099999999996, -496.264, -485.21, -473.07300000000004, -459.819, -445.41900000000004, -429.85, -413.098, -395.159, -376.038, -355.75199999999995, -334.333, -311.822, -288.277, -263.76599999999996, -238.36700000000002, -212.171, -185.273, -157.774, -129.78, -101.39200000000001, -72.715, -43.843999999999994, -14.873, 14.114, 43.038000000000004, 71.829, 100.427, 128.775, 156.829, 184.549, 211.90200000000002, 238.861, 265.405, 291.51599999999996, 317.183, 342.395, 367.147, 391.435, 415.25800000000004, 438.61699999999996, 461.514, 483.952, 505.93699999999995, 527.474, 548.569, 569.229, 589.46, 609.2719999999999, 628.67, 647.664, 666.262, 684.47, 702.298, 719.753, 736.8439999999999, 753.577, 769.961, 786.0039999999999, 801.712, 817.0930000000001, 832.154, 846.9019999999999, 861.3439999999999, 875.4860000000001, 889.335, 902.8969999999999, 916.178, 929.184, 941.921, 954.3939999999999, 966.6089999999999, 978.571, 990.2860000000001, 1001.757, 1012.9910000000001, 1023.9910000000001, 1034.763, 1045.3110000000001, 1055.639, 1065.752, 1075.653, 1085.346, 1094.835, 1104.125, 1113.218, 1122.118, 1130.829, 1139.354, 1147.6960000000001, 1155.859, 1163.845, 1171.6580000000001, 1179.3, 1186.774, 1194.0839999999998, 1201.231, 1208.219, 1215.05, 1221.726, 1228.25, 1234.624, 1240.851, 1246.933, 1252.872, 1258.67, 1264.329, 1269.8519999999999, 1275.24, 1280.495, 1285.62, 1290.615, 1295.484, 1300.2269999999999, 1304.846, 1309.344, 1313.721, 1317.98, 1322.121, 1326.1470000000002, 1330.059, 1333.858, 1337.547, 1341.125, 1344.596, 1347.9589999999998, 1351.217, 1354.37, 1357.421, 1360.37, 1363.2179999999998, 1365.9660000000001, 1368.6170000000002, 1371.171, 1373.628, 1375.991, 1378.26, 1380.4360000000001, 1382.521, 1384.515, 1386.42, 1388.235, 1389.964, 1391.605, 1393.161, 1394.631, 1396.0179999999998, 1397.3220000000001, 1398.543, 1399.683, 1400.7420000000002, 1401.7220000000002, 1402.622, 1403.444, 1404.1889999999999, 1404.8570000000002, 1405.45, 1405.967, 1406.4089999999999, 1406.7779999999998, 1407.0729999999999, 1407.297, 1407.4479999999999, 1407.5279999999998, 1407.5379999999998, 1407.479, 1407.349, 1407.152, 1406.886, 1406.5529999999999, 1406.1529999999998, 1405.6870000000001, 1405.156, 1404.559, 1403.898, 1403.1729999999998, 1402.384, 1401.5320000000002, 1400.618, 1399.642, 1398.605, 1397.506, 1396.3470000000002, 1395.129, 1393.85, 1392.513, 1391.1170000000002, 1389.662, 1388.151, 1386.5810000000001, 1384.955, 1383.273, 1381.5339999999999, 1379.74, 1377.891, 1375.986, 1374.0279999999998, 1372.015, 1369.9489999999998, 1367.829, 1365.656, 1363.431, 1361.154, 1358.8239999999998, 1356.443, 1354.011, 1351.5279999999998, 1348.995, 1346.412, 1343.7779999999998, 1341.095, 1338.3629999999998, 1335.582, 1332.7520000000002, 1329.874, 1326.9479999999999, 1323.974, 1320.953, 1317.884, 1314.769, 1311.6070000000002, 1308.3980000000001, 1305.144, 1301.844, 1298.498, 1295.107, 1291.671, 1288.19, 1284.665, 1281.095, 1277.481, 1273.8239999999998, 1270.122, 1266.378, 1262.59, 1258.76, 1254.886, 1250.971, 1247.013, 1243.013, 1238.971, 1234.887, 1230.763, 1226.597, 1222.389, 1218.142, 1213.853, 1209.524, 1205.155, 1200.746, 1196.296, 1191.808, 1187.279, 1182.712, 1178.105, 1173.4589999999998, 1168.774, 1164.0510000000002, 1159.289, 1154.489, 1149.651, 1144.774, 1139.86, 1134.9080000000001, 1129.9189999999999, 1124.892, 1119.828, 1114.7269999999999, 1109.589, 1104.414, 1099.202, 1093.954, 1088.67, 1083.349, 1077.992, 1072.6, 1067.171, 1061.7069999999999, 1056.2069999999999, 1050.672, 1045.101, 1039.495, 1033.854, 1028.178, 1022.467, 1016.722, 1010.942, 1005.127, 999.278, 993.395, 987.4780000000001, 981.5260000000001, 975.541, 969.5219999999999, 963.4689999999999, 957.383, 951.263, 945.1089999999999, 938.923, 932.703, 926.45, 920.164, 913.846, 907.4939999999999, 901.11, 894.693, 888.2439999999999, 881.762, 875.248, 868.702, 862.1239999999999, 855.5139999999999, 848.8710000000001, 842.197, 835.492, 828.7539999999999, 821.985, 815.185, 808.3530000000001, 801.49, 794.596, 787.671, 780.7139999999999, 773.727, 766.709, 759.66, 752.581, 745.471, 738.33, 731.159, 723.9580000000001, 716.727, 709.465, 702.174, 694.8530000000001, 687.502, 680.1210000000001, 672.71, 665.27, 657.8, 650.302, 642.773, 635.216, 627.63, 620.015, 612.37, 604.697, 596.996, 589.266, 581.507, 573.721, 565.906, 558.062, 550.191, 542.293, 534.366, 526.4119999999999, 518.43, 510.421, 502.385, 494.32099999999997, 486.231, 478.11400000000003, 469.97, 461.8, 453.603, 445.38, 437.13199999999995, 428.85699999999997, 420.556, 412.231, 403.879, 395.50300000000004, 387.102, 378.676, 370.225, 361.75, 353.251, 344.72900000000004, 336.18199999999996, 327.612, 319.019, 310.403, 301.765, 293.10400000000004, 284.421, 275.717, 266.991, 258.244, 249.476, 240.688, 231.88, 223.05200000000002, 214.205, 205.33900000000003, 196.455, 187.553, 178.63400000000001, 169.697, 160.744, 151.775, 142.79, 133.791, 124.777, 115.75, 106.71, 97.65799999999999, 88.594, 79.51899999999999, 70.434, 61.34, 52.238, 43.128, 34.012, 24.89, 15.764000000000001, 6.6339999999999995, -2.498, -11.632, -20.765, -29.896, -39.025, -48.15, -57.269, -66.381, -75.483, -84.575, -93.654, -102.719, -111.766, -120.795, -129.803, -138.787, -147.745, -156.674, -165.572, -174.435, -183.25900000000001, -192.043, -200.78099999999998, -209.47099999999998, -218.108, -226.688, -235.207, -243.65900000000002, -252.04, -260.343, -268.564, -276.69599999999997, -284.733, -292.66700000000003, -300.491, -308.197, -315.777, -323.221, -330.52, -337.664, -344.64, -351.43800000000005, -358.045, -364.44699999999995, -370.629, -376.57599999999996, -382.272, -387.69699999999995, -392.834, -397.661, -402.157, -406.29699999999997, -410.05699999999996, -413.41, -416.327, -418.778, -420.73, -422.148, -422.99800000000005, -423.24, -422.835, -421.741, -419.917, -417.31800000000004, -413.901, -409.62199999999996, -404.439, -398.31, -391.19800000000004, -383.069, -373.89300000000003, -363.651, -352.327, -339.91900000000004, -326.431, -311.882, -296.3, -279.724, -262.20599999999996, -243.80700000000002, -224.59599999999998, -204.65, -184.05, -162.879, -141.22299999999998, -119.164, -96.78399999999999, -74.15899999999999, -51.363, -28.46, -5.513999999999999, 17.423, 40.301, 63.077, 85.714, 108.179, 130.445, 152.488, 174.28900000000002, 195.831, 217.102, 238.092, 258.791, 279.194, 299.298, 319.098, 338.593, 357.783, 376.66900000000004, 395.251, 413.532, 431.514, 449.199, 466.592, 483.69599999999997, 500.514, 517.0509999999999, 533.311, 549.298, 565.016, 580.47, 595.665, 610.6030000000001, 625.2909999999999, 639.7330000000001, 653.932, 667.8919999999999, 681.6189999999999, 695.117, 708.3889999999999, 721.439, 734.2719999999999, 746.8910000000001, 759.3, 771.502, 783.502, 795.303, 806.909, 818.322, 829.546, 840.585, 851.441, 862.118, 872.618, 882.944, 893.1, 903.0889999999999, 912.9119999999999, 922.572, 932.073, 941.4169999999999, 950.605, 959.6410000000001, 968.5269999999999, 977.265, 985.8580000000001, 994.307, 1002.615, 1010.784, 1018.815, 1026.712, 1034.475, 1042.107, 1049.61, 1056.984, 1064.233, 1071.358, 1078.36, 1085.241, 1092.003, 1098.647, 1105.175, 1111.588, 1117.889, 1124.077, 1130.155, 1136.124, 1141.986, 1147.741, 1153.392, 1158.938, 1164.382, 1169.725, 1174.9669999999999, 1180.111, 1185.157, 1190.105, 1194.9589999999998, 1199.718, 1204.383, 1208.9560000000001, 1213.437, 1217.827, 1222.129, 1226.3410000000001, 1230.4660000000001, 1234.504, 1238.4560000000001, 1242.323, 1246.106, 1249.806, 1253.423, 1256.958, 1260.413, 1263.787, 1267.0819999999999, 1270.299, 1273.437, 1276.498, 1279.483, 1282.393, 1285.2269999999999, 1287.986, 1290.672, 1293.285, 1295.826, 1298.2939999999999, 1300.692, 1303.018, 1305.275, 1307.462, 1309.5810000000001, 1311.631, 1313.6129999999998, 1315.5279999999998, 1317.376, 1319.1589999999999, 1320.875, 1322.527, 1324.1129999999998, 1325.636, 1327.095, 1328.491, 1329.8239999999998, 1331.094, 1332.3029999999999, 1333.451, 1334.537, 1335.5629999999999, 1336.529, 1337.435, 1338.2820000000002, 1339.07, 1339.799, 1340.47, 1341.0839999999998, 1341.64, 1342.139, 1342.582, 1342.9679999999998, 1343.2979999999998, 1343.5729999999999, 1343.7920000000001, 1343.957, 1344.067, 1344.122, 1344.124, 1344.0720000000001, 1343.967, 1343.809, 1343.598, 1343.3339999999998, 1343.019, 1342.651, 1342.2320000000002, 1341.7620000000002, 1341.241, 1340.668, 1340.046, 1339.3729999999998, 1338.65, 1337.8770000000002, 1337.055, 1336.183, 1335.2620000000002, 1334.293, 1333.275, 1332.2089999999998, 1331.094, 1329.932, 1328.7220000000002, 1327.464, 1326.1589999999999, 1324.807, 1323.408, 1321.963, 1320.471, 1318.932, 1317.348, 1315.717, 1314.0410000000002, 1312.319, 1310.552, 1308.739, 1306.882, 1304.979, 1303.032, 1301.0410000000002, 1299.004, 1296.924, 1294.799, 1292.631, 1290.4180000000001, 1288.162, 1285.862, 1283.519, 1281.133, 1278.703, 1276.231, 1273.715, 1271.157, 1268.556, 1265.912, 1263.2269999999999, 1260.498, 1257.728, 1254.9160000000002, 1252.0610000000001, 1249.165, 1246.2269999999999, 1243.247, 1240.226, 1237.163, 1234.058, 1230.913, 1227.726, 1224.498, 1221.229, 1217.92, 1214.569, 1211.177, 1207.745, 1204.272, 1200.758, 1197.204, 1193.61, 1189.975, 1186.3, 1182.585, 1178.829, 1175.0330000000001, 1171.197, 1167.3210000000001, 1163.406, 1159.45, 1155.454, 1151.4189999999999, 1147.343, 1143.228, 1139.0739999999998, 1134.879, 1130.645, 1126.372, 1122.058, 1117.7060000000001, 1113.313, 1108.882, 1104.41, 1099.9, 1095.35, 1090.76, 1086.132, 1081.464, 1076.756, 1072.01, 1067.223, 1062.3980000000001, 1057.5339999999999, 1052.63, 1047.6860000000001, 1042.704, 1037.682, 1032.621, 1027.521, 1022.382, 1017.203, 1011.985, 1006.7280000000001, 1001.431, 996.095, 990.72, 985.305, 979.8510000000001, 974.3580000000001, 968.825, 963.253, 957.6419999999999, 951.9910000000001, 946.301, 940.571, 934.802, 928.993, 923.1439999999999, 917.2560000000001, 911.329, 905.3610000000001, 899.3539999999999, 893.308, 887.221, 881.095, 874.929, 868.7230000000001, 862.477, 856.191, 849.865, 843.4989999999999, 837.0930000000001, 830.6469999999999, 824.16, 817.6339999999999, 811.067, 804.459, 797.812, 791.1239999999999, 784.395, 777.6260000000001, 770.816, 763.965, 757.074, 750.1419999999999, 743.169, 736.155, 729.1, 722.005, 714.868, 707.69, 700.471, 693.21, 685.909, 678.565, 671.181, 663.755, 656.2869999999999, 648.778, 641.227, 633.635, 626.001, 618.3240000000001, 610.606, 602.847, 595.045, 587.201, 579.315, 571.387, 563.4159999999999, 555.404, 547.349, 539.252, 531.113, 522.932, 514.7080000000001, 506.44199999999995, 498.13300000000004, 489.782, 481.389, 472.95300000000003, 464.475, 455.954, 447.39099999999996, 438.786, 430.139, 421.449, 412.717, 403.94300000000004, 395.12699999999995, 386.269, 377.369, 368.42699999999996, 359.444, 350.41900000000004, 341.353, 332.245, 323.097, 313.907, 304.677, 295.407, 286.097, 276.747, 267.357, 257.928, 248.46099999999998, 238.955, 229.41099999999997, 219.83, 210.21200000000002, 200.55700000000002, 190.86700000000002, 181.142, 171.382, 161.588, 151.762, 141.904, 132.014, 122.095, 112.147, 102.171, 92.169, 82.141, 72.09, 62.016999999999996, 51.923, 41.81100000000001, 31.683000000000003, 21.54, 11.385, 1.22, -8.952, -19.127, -29.304000000000002, -39.479, -49.648, -59.806999999999995, -69.952, -80.078, -90.181, -100.256, -110.296, -120.296, -130.249, -140.14700000000002, -149.983, -159.749, -169.435, -179.03099999999998, -188.52599999999998, -197.91, -207.168, -216.28799999999998, -225.25400000000002, -234.051, -242.66, -251.063, -259.23900000000003, -267.166, -274.82, -282.17400000000004, -289.202, -295.871, -302.151, -308.006, -313.399, -318.29200000000003, -322.643, -326.408, -329.543, -332.001, -333.736, -334.70099999999996, -334.848, -334.13300000000004, -332.514, -329.954, -326.421, -321.887, -316.337, -309.762, -302.163, -293.55, -283.948, -273.389, -261.915, -249.577, -236.43200000000002, -222.544, -207.979, -192.80599999999998, -177.09400000000002, -160.91, -144.322, -127.39, -110.176, -92.734, -75.11399999999999, -57.363, -39.523, -21.631, -3.721, 14.177999999999999, 32.039, 49.839, 67.558, 85.179, 102.68700000000001, 120.069, 137.314, 154.39700000000002, 171.358, 188.142, 204.761, 221.209, 237.484, 253.583, 269.503, 285.244, 300.805, 316.184, 331.38300000000004, 346.402, 361.24, 375.899, 390.381, 404.685, 418.814, 432.76800000000003, 446.551, 460.162, 473.605, 486.88, 499.99, 512.937, 525.722, 538.3480000000001, 550.816, 563.129, 575.2869999999999, 587.294, 599.1519999999999, 610.861, 622.425, 633.844, 645.121, 656.258, 667.2560000000001, 678.118, 688.8439999999999, 699.438, 709.9, 720.232, 730.436, 740.513, 750.465, 760.295, 770.002, 779.5889999999999, 789.057, 798.408, 807.643, 816.7639999999999, 825.7710000000001, 834.6669999999999, 843.452, 852.1289999999999, 860.697, 869.159, 877.515, 885.768, 893.9169999999999, 901.965, 909.9119999999999, 917.76, 925.5089999999999, 933.16, 940.716, 948.176, 955.541, 962.814, 969.9939999999999, 977.0830000000001, 984.081, 990.99, 997.811, 1004.543, 1011.189, 1017.7489999999999, 1024.223, 1030.613, 1036.92, 1043.144, 1049.285, 1055.346, 1061.326, 1067.226, 1073.047, 1078.789, 1084.454, 1090.042, 1095.5539999999999, 1100.99, 1106.351, 1111.638, 1116.85, 1121.99, 1127.057, 1132.052, 1136.975, 1141.828, 1146.61, 1151.322, 1155.965, 1160.54, 1165.046, 1169.485, 1173.856, 1178.161, 1182.399, 1186.572, 1190.6789999999999, 1194.721, 1198.6989999999998, 1202.613, 1206.464, 1210.251, 1213.976, 1217.638, 1221.239, 1224.778, 1228.256, 1231.673, 1235.03, 1238.326, 1241.5639999999999, 1244.742, 1247.861, 1250.921, 1253.923, 1256.867, 1259.754, 1262.583, 1265.356, 1268.072, 1270.731, 1273.335, 1275.882, 1278.374, 1280.8110000000001, 1283.194, 1285.521, 1287.7939999999999, 1290.013, 1292.178, 1294.29, 1296.348, 1298.353, 1300.306, 1302.205, 1304.052, 1305.847, 1307.5910000000001, 1309.282, 1310.922, 1312.51, 1314.0479999999998, 1315.535, 1316.97, 1318.356, 1319.691, 1320.976, 1322.211, 1323.396, 1324.5320000000002, 1325.618, 1326.655, 1327.6429999999998, 1328.582, 1329.473, 1330.3139999999999, 1331.108, 1331.8529999999998, 1332.549, 1333.1979999999999, 1333.799, 1334.352, 1334.858, 1335.316, 1335.727, 1336.0910000000001, 1336.4070000000002, 1336.6760000000002, 1336.899, 1337.075, 1337.204, 1337.287, 1337.3229999999999, 1337.3129999999999, 1337.257, 1337.155, 1337.006, 1336.8120000000001, 1336.5710000000001, 1336.285, 1335.953, 1335.576, 1335.1529999999998, 1334.685, 1334.171, 1333.612, 1333.007, 1332.358, 1331.6629999999998, 1330.9229999999998, 1330.138, 1329.308, 1328.433, 1327.514, 1326.549, 1325.54, 1324.486, 1323.3870000000002, 1322.244, 1321.056, 1319.8229999999999, 1318.546, 1317.224, 1315.858, 1314.4470000000001, 1312.9920000000002, 1311.4920000000002, 1309.947, 1308.359, 1306.726, 1305.048, 1303.326, 1301.56, 1299.749, 1297.894, 1295.994, 1294.05, 1292.062, 1290.029, 1287.951, 1285.83, 1283.663, 1281.452, 1279.197, 1276.897, 1274.552, 1272.163, 1269.729, 1267.251, 1264.728, 1262.16, 1259.547, 1256.889, 1254.187, 1251.4389999999999, 1248.647, 1245.809, 1242.927, 1239.999, 1237.026, 1234.008, 1230.944, 1227.835, 1224.681, 1221.481, 1218.235, 1214.943, 1211.606, 1208.223, 1204.7939999999999, 1201.319, 1197.798, 1194.23, 1190.617, 1186.9560000000001, 1183.25, 1179.496, 1175.6960000000001, 1171.849, 1167.955, 1164.014, 1160.026, 1155.991, 1151.9080000000001, 1147.777, 1143.599, 1139.373, 1135.099, 1130.777, 1126.407, 1121.989, 1117.522, 1113.006, 1108.442, 1103.828, 1099.1660000000002, 1094.454, 1089.693, 1084.882, 1080.021, 1075.11, 1070.15, 1065.139, 1060.077, 1054.965, 1049.802, 1044.588, 1039.323, 1034.006, 1028.638, 1023.2180000000001, 1017.7460000000001, 1012.221, 1006.6439999999999, 1001.015, 995.332, 989.596, 983.807, 977.965, 972.068, 966.118, 960.113, 954.054, 947.939, 941.77, 935.545, 929.265, 922.929, 916.5369999999999, 910.0880000000001, 903.5830000000001, 897.0210000000001, 890.4010000000001, 883.7239999999999, 876.9889999999999, 870.196, 863.3439999999999, 856.434, 849.465, 842.436, 835.3480000000001, 828.199, 820.99, 813.721, 806.39, 798.998, 791.545, 784.029, 776.451, 768.81, 761.107, 753.3389999999999, 745.508, 737.613, 729.653, 721.628, 713.538, 705.382, 697.159, 688.8710000000001, 680.515, 672.092, 663.602, 655.043, 646.4159999999999, 637.72, 628.955, 620.12, 611.215, 602.239, 593.192, 584.0740000000001, 574.884, 565.622, 556.288, 546.88, 537.399, 527.844, 518.216, 508.51199999999994, 498.73400000000004, 488.88, 478.95099999999996, 468.945, 458.86400000000003, 448.705, 438.47, 428.157, 417.767, 407.29900000000004, 396.754, 386.129, 375.42699999999996, 364.64599999999996, 353.786, 342.848, 331.83099999999996, 320.735, 309.561, 298.309, 286.978, 275.569, 264.08299999999997, 252.52, 240.88, 229.165, 217.37400000000002, 205.50900000000001, 193.571, 181.562, 169.482, 157.333, 145.11700000000002, 132.836, 120.492, 108.089, 95.62799999999999, 83.113, 70.548, 57.937, 45.284, 32.595, 19.874000000000002, 7.129, -5.632999999999999, -18.406, -31.18, -43.945, -56.692, -69.407, -82.08, -94.693, -107.23299999999999, -119.681, -132.018, -144.221, -156.269, -168.13299999999998, -179.787, -191.199, -202.335, -213.158, -223.628, -233.703, -243.33700000000002, -252.481, -261.085, -269.096, -276.459, -283.119, -289.022, -294.115, -298.346, -301.67, -304.045, -305.438, -305.824, -305.185, -303.517, -300.823, -297.119, -292.428, -286.786, -280.233, -272.816, -264.59, -255.61, -245.935, -235.62400000000002, -224.735, -213.325, -201.449, -189.16, -176.50599999999997, -163.534, -150.287, -136.80200000000002, -123.117, -109.264, -95.274, -81.171, -66.983, -52.729, -38.429, -24.101999999999997, -9.763, 4.574, 18.897000000000002, 33.194, 47.455, 61.672, 75.837, 89.94200000000001, 103.98299999999999, 117.95299999999999, 131.84799999999998, 145.66299999999998, 159.39600000000002, 173.042, 186.6, 200.06599999999997, 213.44, 226.718, 239.90099999999998, 252.986, 265.972, 278.86, 291.647, 304.334, 316.921, 329.407, 341.792, 354.077, 366.26, 378.343, 390.32599999999996, 402.208, 413.99199999999996, 425.676, 437.26099999999997, 448.74800000000005, 460.13699999999994, 471.42900000000003, 482.624, 493.723, 504.727, 515.637, 526.452, 537.173, 547.802, 558.339, 568.784, 579.139, 589.403, 599.578, 609.664, 619.663, 629.573, 639.398, 649.136, 658.789, 668.357, 677.841, 687.2410000000001, 696.559, 705.795, 714.95, 724.0239999999999, 733.0169999999999, 741.931, 750.7660000000001, 759.523, 768.202, 776.803, 785.328, 793.7769999999999, 802.1510000000001, 810.45, 818.674, 826.825, 834.9019999999999, 842.9069999999999, 850.8389999999999, 858.7, 866.4889999999999, 874.2080000000001, 881.8560000000001, 889.435, 896.945, 904.385, 911.758, 919.062, 926.299, 933.4689999999999, 940.573, 947.61, 954.581, 961.488, 968.329, 975.1060000000001, 981.819, 988.4680000000001, 995.054, 1001.576, 1008.0360000000001, 1014.434, 1020.77, 1027.045, 1033.258, 1039.41, 1045.502, 1051.5339999999999, 1057.505, 1063.4180000000001, 1069.271, 1075.065, 1080.8, 1086.4769999999999, 1092.096, 1097.657, 1103.161, 1108.607, 1113.997, 1119.329, 1124.606, 1129.826, 1134.99, 1140.099, 1145.152, 1150.15, 1155.093, 1159.981, 1164.815, 1169.594, 1174.319, 1178.991, 1183.609, 1188.173, 1192.684, 1197.142, 1201.547, 1205.9, 1210.2, 1214.447, 1218.643, 1222.787, 1226.878, 1230.9189999999999, 1234.907, 1238.845, 1242.731, 1246.566, 1250.351, 1254.085, 1257.768, 1261.401, 1264.983, 1268.515, 1271.998, 1275.43, 1278.813, 1282.146, 1285.4289999999999, 1288.664, 1291.848, 1294.984, 1298.07, 1301.108, 1304.097, 1307.036, 1309.927, 1312.77, 1315.5639999999999, 1318.309, 1321.007, 1323.655, 1326.256, 1328.809, 1331.3129999999999, 1333.77, 1336.1779999999999, 1338.539, 1340.852, 1343.1170000000002, 1345.3339999999998, 1347.504, 1349.626, 1351.701, 1353.7279999999998, 1355.7079999999999, 1357.64, 1359.525, 1361.362, 1363.152, 1364.895, 1366.5910000000001, 1368.239, 1369.84, 1371.394, 1372.901, 1374.36, 1375.773, 1377.138, 1378.4560000000001, 1379.727, 1380.95, 1382.1270000000002, 1383.256, 1384.338, 1385.374, 1386.361, 1387.3020000000001, 1388.1960000000001, 1389.0420000000001, 1389.8410000000001, 1390.592, 1391.297, 1391.954, 1392.5629999999999, 1393.126, 1393.64, 1394.108, 1394.5279999999998, 1394.9, 1395.224, 1395.501, 1395.731, 1395.912, 1396.046, 1396.131, 1396.1689999999999, 1396.1589999999999, 1396.101, 1395.994, 1395.84, 1395.6370000000002, 1395.385, 1395.085, 1394.737, 1394.34, 1393.894, 1393.4, 1392.856, 1392.264, 1391.6229999999998, 1390.932, 1390.192, 1389.4029999999998, 1388.5639999999999, 1387.675, 1386.737, 1385.749, 1384.71, 1383.622, 1382.484, 1381.295, 1380.055, 1378.765, 1377.424, 1376.033, 1374.59, 1373.096, 1371.55, 1369.953, 1368.3039999999999, 1366.604, 1364.851, 1363.046, 1361.1889999999999, 1359.279, 1357.317, 1355.3020000000001, 1353.233, 1351.112, 1348.9360000000001, 1346.7079999999999, 1344.425, 1342.088, 1339.6970000000001, 1337.2520000000002, 1334.751, 1332.1960000000001, 1329.586, 1326.92, 1324.1989999999998, 1321.421, 1318.588, 1315.6989999999998, 1312.7520000000002, 1309.749, 1306.6889999999999, 1303.572, 1300.397, 1297.164, 1293.873, 1290.5230000000001, 1287.115, 1283.6480000000001, 1280.121, 1276.535, 1272.889, 1269.182, 1265.415, 1261.588, 1257.6989999999998, 1253.748, 1249.736, 1245.662, 1241.525, 1237.325, 1233.062, 1228.735, 1224.344, 1219.889, 1215.369, 1210.785, 1206.134, 1201.4180000000001, 1196.635, 1191.786, 1186.869, 1181.885, 1176.833, 1171.713, 1166.5230000000001, 1161.264, 1155.935, 1150.536, 1145.067, 1139.525, 1133.913, 1128.2269999999999, 1122.469, 1116.638, 1110.733, 1104.753, 1098.6989999999998, 1092.568, 1086.362, 1080.079, 1073.719, 1067.281, 1060.765, 1054.17, 1047.495, 1040.739, 1033.903, 1026.985, 1019.985, 1012.9019999999999, 1005.735, 998.4830000000001, 991.1469999999999, 983.725, 976.216, 968.62, 960.936, 953.163, 945.3, 937.347, 929.303, 921.1669999999999, 912.937, 904.6139999999999, 896.196, 887.683, 879.073, 870.365, 861.56, 852.655, 843.6489999999999, 834.543, 825.334, 816.0219999999999, 806.6060000000001, 797.085, 787.457, 777.722, 767.878, 757.924, 747.86, 737.684, 727.395, 716.992, 706.4730000000001, 695.837, 685.084, 674.212, 663.22, 652.106, 640.869, 629.508, 618.0219999999999, 606.41, 594.67, 582.8, 570.8, 558.668, 546.404, 534.005, 521.471, 508.8, 495.99, 483.042, 469.954, 456.724, 443.352, 429.836, 416.176, 402.37, 388.41900000000004, 374.32, 360.075, 345.68199999999996, 331.14099999999996, 316.452, 301.615, 286.631, 271.5, 256.223, 240.80200000000002, 225.238, 209.533, 193.69, 177.71200000000002, 161.60299999999998, 145.368, 129.012, 112.541, 95.963, 79.286, 62.521, 45.678000000000004, 28.771, 11.814, -5.176, -22.179000000000002, -39.175, -56.137, -73.04, -89.852, -106.538, -123.06200000000001, -139.381, -155.44799999999998, -171.215, -186.62599999999998, -201.623, -216.145, -230.12599999999998, -243.5, -256.2, -268.156, -279.302, -289.57599999999996, -298.918, -307.276, -314.607, -320.875, -326.057, -330.14099999999996, -333.12300000000005, -335.01300000000003, -335.832, -335.60699999999997, -334.376, -332.18, -329.06800000000004, -325.093, -320.306, -314.762, -308.515, -301.619, -294.126, -286.086, -277.545, -268.54900000000004, -259.139, -249.355, -239.233, -228.80700000000002, -218.108, -207.165, -196.005, -184.65, -173.12400000000002, -161.447, -149.638, -137.713, -125.68799999999999, -113.57700000000001, -101.39399999999999, -89.149, -76.855, -64.52, -52.153999999999996, -39.765, -27.36, -14.947000000000001, -2.532, 9.881, 22.284000000000002, 34.674, 47.047, 59.397, 71.722, 84.01799999999999, 96.28299999999999, 108.512, 120.705, 132.858, 144.969, 157.037, 169.06, 181.035, 192.96200000000002, 204.83900000000003, 216.666, 228.44, 240.16099999999997, 251.829, 263.441, 274.998, 286.5, 297.944, 309.33099999999996, 320.661, 331.93199999999996, 343.145, 354.29900000000004, 365.394, 376.43, 387.407, 398.324, 409.181, 419.978, 430.715, 441.39300000000003, 452.01, 462.56699999999995, 473.064, 483.501, 493.87800000000004, 504.19599999999997, 514.453, 524.651, 534.788, 544.867, 554.885, 564.845, 574.745, 584.586, 594.368, 604.091, 613.755, 623.361, 632.909, 642.398, 651.8290000000001, 661.202, 670.518, 679.7760000000001, 688.9760000000001, 698.12, 707.206, 716.235, 725.2080000000001, 734.1239999999999, 742.9839999999999, 751.7869999999999, 760.535, 769.227, 777.863, 786.443, 794.9689999999999, 803.439, 811.8539999999999, 820.2139999999999, 828.52, 836.7719999999999, 844.9689999999999, 853.112, 861.201, 869.2360000000001, 877.2180000000001, 885.1460000000001, 893.02, 900.842, 908.6110000000001, 916.326, 923.9889999999999, 931.6, 939.158, 946.664, 954.117, 961.5189999999999, 968.8689999999999, 976.1669999999999, 983.413, 990.6080000000001, 997.752, 1004.8439999999999, 1011.885, 1018.8760000000001, 1025.815, 1032.704, 1039.542, 1046.33, 1053.067, 1059.754, 1066.39, 1072.9769999999999, 1079.514, 1086.0, 1092.437, 1098.825, 1105.162, 1111.45, 1117.6889999999999, 1123.878, 1130.018, 1136.109, 1142.151, 1148.144, 1154.087, 1159.982, 1165.828, 1171.625, 1177.374, 1183.073, 1188.725, 1194.327, 1199.882, 1205.387, 1210.845, 1216.254, 1221.615, 1226.927, 1232.191, 1237.4080000000001, 1242.576, 1247.6960000000001, 1252.767, 1257.7910000000002, 1262.767, 1267.695, 1272.575, 1277.407, 1282.191, 1286.927, 1291.615, 1296.255, 1300.848, 1305.392, 1309.889, 1314.338, 1318.739, 1323.092, 1327.3970000000002, 1331.654, 1335.864, 1340.025, 1344.139, 1348.204, 1352.2220000000002, 1356.192, 1360.114, 1363.987, 1367.8129999999999, 1371.59, 1375.32, 1379.001, 1382.634, 1386.219, 1389.756, 1393.244, 1396.684, 1400.075, 1403.418, 1406.713, 1409.9589999999998, 1413.156, 1416.305, 1419.405, 1422.4560000000001, 1425.4579999999999, 1428.412, 1431.316, 1434.171, 1436.977, 1439.734, 1442.441, 1445.099, 1447.7079999999999, 1450.267, 1452.776, 1455.236, 1457.645, 1460.005, 1462.3139999999999, 1464.5739999999998, 1466.783, 1468.942, 1471.05, 1473.1070000000002, 1475.114, 1477.07, 1478.975, 1480.829, 1482.632, 1484.3829999999998, 1486.0829999999999, 1487.731, 1489.3270000000002, 1490.872, 1492.364, 1493.8039999999999, 1495.192, 1496.527, 1497.809, 1499.039, 1500.2160000000001, 1501.339, 1502.4089999999999, 1503.4260000000002, 1504.389, 1505.2979999999998, 1506.1529999999998, 1506.954, 1507.7, 1508.391, 1509.0279999999998, 1509.61, 1510.136, 1510.608, 1511.023, 1511.3829999999998, 1511.6860000000001, 1511.933, 1512.124, 1512.2579999999998, 1512.335, 1512.354, 1512.317, 1512.221, 1512.067, 1511.856, 1511.586, 1511.257, 1510.869, 1510.421, 1509.915, 1509.348, 1508.721, 1508.0339999999999, 1507.287, 1506.4779999999998, 1505.608, 1504.6760000000002, 1503.683, 1502.6270000000002, 1501.5079999999998, 1500.3270000000002, 1499.0829999999999, 1497.775, 1496.4029999999998, 1494.967, 1493.4660000000001, 1491.901, 1490.27, 1488.5729999999999, 1486.81, 1484.981, 1483.085, 1481.122, 1479.0910000000001, 1476.993, 1474.825, 1472.589, 1470.2839999999999, 1467.908, 1465.463, 1462.9470000000001, 1460.36, 1457.701, 1454.971, 1452.168, 1449.2920000000001, 1446.342, 1443.319, 1440.22, 1437.047, 1433.799, 1430.474, 1427.0729999999999, 1423.595, 1420.039, 1416.404, 1412.691, 1408.898, 1405.025, 1401.0720000000001, 1397.037, 1392.92, 1388.721, 1384.4389999999999, 1380.0720000000001, 1375.621, 1371.085, 1366.4620000000002, 1361.753, 1356.957, 1352.0720000000001, 1347.099, 1342.036, 1336.882, 1331.6370000000002, 1326.3, 1320.87, 1315.3470000000002, 1309.729, 1304.015, 1298.205, 1292.298, 1286.2930000000001, 1280.1889999999999, 1273.985, 1267.68, 1261.2730000000001, 1254.763, 1248.149, 1241.43, 1234.605, 1227.672, 1220.632, 1213.482, 1206.221, 1198.849, 1191.364, 1183.765, 1176.05, 1168.219, 1160.27, 1152.202, 1144.013, 1135.702, 1127.268, 1118.7089999999998, 1110.024, 1101.211, 1092.269, 1083.1960000000001, 1073.991, 1064.652, 1055.177, 1045.566, 1035.815, 1025.923, 1015.8889999999999, 1005.711, 995.3860000000001, 984.913, 974.291, 963.5160000000001, 952.587, 941.503, 930.26, 918.8560000000001, 907.291, 895.56, 883.663, 871.596, 859.3580000000001, 846.946, 834.357, 821.5889999999999, 808.64, 795.5060000000001, 782.185, 768.675, 754.9730000000001, 741.076, 726.9810000000001, 712.686, 698.187, 683.482, 668.568, 653.442, 638.101, 622.5419999999999, 606.763, 590.759, 574.529, 558.069, 541.378, 524.451, 507.287, 489.88300000000004, 472.23699999999997, 454.346, 436.209, 417.824, 399.189, 380.305, 361.17, 341.783, 322.147, 302.262, 282.13, 261.754, 241.138, 220.28799999999998, 199.21099999999998, 177.91299999999998, 156.407, 134.703, 112.81700000000001, 90.766, 68.57, 46.253, 23.842, 1.369, -21.131, -43.615, -66.039, -88.351, -110.493, -132.403, -154.012, -175.247, -196.02900000000002, -216.275, -235.90099999999998, -254.821, -272.95, -290.205, -306.508, -321.786, -335.978, -349.032, -360.905, -371.57, -381.01099999999997, -389.226, -396.222, -402.019, -406.648, -410.14300000000003, -412.548, -413.911, -414.284, -413.718, -412.27, -409.991, -406.93699999999995, -403.158, -398.705, -393.624, -387.963, -381.764, -375.066, -367.91, -360.329, -352.35699999999997, -344.024, -335.336, -326.39099999999996, -317.142, -307.63599999999997, -297.893, -287.933, -277.775, -267.435, -256.92900000000003, -246.271, -235.47400000000002, -224.55200000000002, -213.515, -202.37400000000002, -191.14, -179.82, -168.424, -156.959, -145.433, -133.85299999999998, -122.225, -110.555, -98.848, -87.11, -75.345, -63.558, -51.754, -39.935, -28.105, -16.269000000000002, -4.428999999999999, 7.412000000000001, 19.250999999999998, 31.086, 42.913000000000004, 54.731, 66.538, 78.332, 90.11, 101.87100000000001, 113.613, 125.335, 137.035, 148.71200000000002, 160.365, 171.99200000000002, 183.592, 195.16400000000002, 206.707, 218.22099999999998, 229.703, 241.15400000000002, 252.572, 263.957, 275.309, 286.626, 297.908, 309.154, 320.363, 331.536, 342.67199999999997, 353.77, 364.829, 375.85, 386.832, 397.775, 408.67800000000005, 419.54, 430.36300000000006, 441.144, 451.885, 462.585, 473.24300000000005, 483.85900000000004, 494.434, 504.967, 515.457, 525.905, 536.31, 546.673, 556.992, 567.269, 577.502, 587.692, 597.839, 607.942, 618.002, 628.0169999999999, 637.989, 647.9169999999999, 657.801, 667.6410000000001, 677.437, 687.189, 696.8960000000001, 706.559, 716.178, 725.752, 735.2819999999999, 744.7669999999999, 754.2080000000001, 763.6039999999999, 772.955, 782.2610000000001, 791.523, 800.74, 809.913, 819.04, 828.122, 837.16, 846.153, 855.1, 864.003, 872.8610000000001, 881.673, 890.441, 899.164, 907.841, 916.4730000000001, 925.06, 933.602, 942.0989999999999, 950.55, 958.956, 967.317, 975.633, 983.903, 992.128, 1000.307, 1008.441, 1016.53, 1024.573, 1032.57, 1040.522, 1048.4289999999999, 1056.29, 1064.105, 1071.875, 1079.599, 1087.277, 1094.91, 1102.496, 1110.037, 1117.532, 1124.982, 1132.385, 1139.742, 1147.053, 1154.319, 1161.538, 1168.711, 1175.837, 1182.9180000000001, 1189.952, 1196.94, 1203.881, 1210.776, 1217.625, 1224.427, 1231.182, 1237.89, 1244.552, 1251.167, 1257.736, 1264.257, 1270.731, 1277.1580000000001, 1283.538, 1289.871, 1296.157, 1302.395, 1308.586, 1314.729, 1320.8239999999998, 1326.872, 1332.8729999999998, 1338.825, 1344.729, 1350.586, 1356.394, 1362.154, 1367.866, 1373.529, 1379.144, 1384.71, 1390.2279999999998, 1395.6970000000001, 1401.116, 1406.487, 1411.809, 1417.0810000000001, 1422.3039999999999, 1427.4779999999998, 1432.602, 1437.6760000000002, 1442.7, 1447.675, 1452.599, 1457.473, 1462.297, 1467.07, 1471.793, 1476.465, 1481.086, 1485.656, 1490.174, 1494.642, 1499.058, 1503.422, 1507.734, 1511.995, 1516.203, 1520.359, 1524.4620000000002, 1528.513, 1532.511, 1536.4560000000001, 1540.348, 1544.1870000000001, 1547.9720000000002, 1551.703, 1555.38, 1559.004, 1562.5729999999999, 1566.0870000000002, 1569.547, 1572.9520000000002, 1576.3020000000001, 1579.596, 1582.835, 1586.0179999999998, 1589.145, 1592.217, 1595.231, 1598.1889999999999, 1601.09, 1603.934, 1606.721, 1609.45, 1612.122, 1614.735, 1617.29, 1619.786, 1622.223, 1624.601, 1626.92, 1629.1789999999999, 1631.379, 1633.5179999999998, 1635.596, 1637.614, 1639.57, 1641.4660000000001, 1643.299, 1645.0710000000001, 1646.78, 1648.4260000000002, 1650.01, 1651.53, 1652.987, 1654.379, 1655.7079999999999, 1656.971, 1658.17, 1659.3039999999999, 1660.372, 1661.3729999999998, 1662.309, 1663.1770000000001, 1663.9779999999998, 1664.7120000000002, 1665.378, 1665.975, 1666.504, 1666.963, 1667.3529999999998, 1667.6729999999998, 1667.922, 1668.1, 1668.207, 1668.243, 1668.2060000000001, 1668.096, 1667.914, 1667.6570000000002, 1667.3270000000002, 1666.921, 1666.441, 1665.885, 1665.253, 1664.5439999999999, 1663.759, 1662.895, 1661.953, 1660.932, 1659.832, 1658.652, 1657.392, 1656.05, 1654.626, 1653.12, 1651.5320000000002, 1649.859, 1648.102, 1646.261, 1644.3339999999998, 1642.32, 1640.22, 1638.0320000000002, 1635.756, 1633.391, 1630.9360000000001, 1628.391, 1625.754, 1623.025, 1620.204, 1617.289, 1614.279, 1611.175, 1607.974, 1604.6760000000002, 1601.281, 1597.787, 1594.194, 1590.5, 1586.704, 1582.807, 1578.806, 1574.701, 1570.49, 1566.174, 1561.75, 1557.217, 1552.576, 1547.8229999999999, 1542.96, 1537.983, 1532.892, 1527.6860000000001, 1522.364, 1516.925, 1511.366, 1505.6879999999999, 1499.888, 1493.9660000000001, 1487.92, 1481.7479999999998, 1475.4489999999998, 1469.023, 1462.4660000000001, 1455.779, 1448.9579999999999, 1442.004, 1434.9129999999998, 1427.685, 1420.318, 1412.8110000000001, 1405.16, 1397.366, 1389.425, 1381.336, 1373.098, 1364.707, 1356.1629999999998, 1347.464, 1338.606, 1329.589, 1320.41, 1311.066, 1301.556, 1291.877, 1282.027, 1272.003, 1261.803, 1251.425, 1240.866, 1230.123, 1219.193, 1208.075, 1196.764, 1185.258, 1173.5539999999999, 1161.649, 1149.54, 1137.223, 1124.6960000000001, 1111.955, 1098.996, 1085.816, 1072.412, 1058.78, 1044.915, 1030.8139999999999, 1016.4739999999999, 1001.8889999999999, 987.057, 971.972, 956.6310000000001, 941.028, 925.16, 909.0210000000001, 892.6080000000001, 875.915, 858.937, 841.669, 824.107, 806.2460000000001, 788.079, 769.6030000000001, 750.811, 731.698, 712.2589999999999, 692.4889999999999, 672.382, 651.934, 631.138, 609.991, 588.488, 566.623, 544.393, 521.794, 498.82199999999995, 475.475, 451.751, 427.647, 403.165, 378.30300000000005, 353.066, 327.455, 301.47700000000003, 275.14, 248.453, 221.429, 194.085, 166.43900000000002, 138.516, 110.344, 81.958, 53.396, 24.704, -4.064, -32.85, -61.586999999999996, -90.198, -118.604, -146.713, -174.43200000000002, -201.65900000000002, -228.28799999999998, -254.21400000000003, -279.33, -303.531, -326.721, -348.80699999999996, -369.71, -389.36, -407.702, -424.69599999999997, -440.314, -454.546, -467.394, -478.871, -489.00300000000004, -497.82300000000004, -505.37300000000005, -511.70099999999996, -516.859, -520.901, -523.881, -525.857, -526.886, -527.021, -526.316, -524.8240000000001, -522.592, -519.67, -516.101, -511.92699999999996, -507.189, -501.923, -496.165, -489.94699999999995, -483.301, -476.254, -468.835, -461.06699999999995, -452.974, -444.579, -435.901, -426.958, -417.77, -408.353, -398.721, -388.89, -378.87199999999996, -368.681, -358.327, -347.824, -337.17900000000003, -326.404, -315.507, -304.497, -293.381, -282.168, -270.86400000000003, -259.476, -248.01, -236.472, -224.86700000000002, -213.201, -201.479, -189.705, -177.88400000000001, -166.02, -154.116, -142.17700000000002, -130.205, -118.205, -106.179, -94.13, -82.061, -69.975, -57.875, -45.762, -33.639, -21.508000000000003, -9.371, 2.7689999999999997, 14.912, 27.054000000000002, 39.195, 51.333, 63.466, 75.594, 87.713, 99.824, 111.92399999999999, 124.014, 136.09, 148.153, 160.202, 172.234, 184.25, 196.248, 208.22799999999998, 220.18900000000002, 232.12900000000002, 244.048, 255.945, 267.82, 279.672, 291.5, 303.30400000000003, 315.082, 326.835, 338.561, 350.26099999999997, 361.93300000000005, 373.57800000000003, 385.194, 396.781], \"y\": [4704.321, 4745.575, 4784.04, 4819.807, 4852.978, 4883.655, 4911.934, 4937.905, 4961.654, 4983.264, 5002.815, 5020.38, 5036.032, 5049.838, 5061.8640000000005, 5072.1720000000005, 5080.821, 5087.8679999999995, 5093.366, 5097.3679999999995, 5099.923, 5101.079000000001, 5100.880999999999, 5099.372, 5096.593, 5092.585, 5087.3859999999995, 5081.032999999999, 5073.561, 5065.003, 5055.393, 5044.7609999999995, 5033.137, 5020.55, 5007.028, 4992.598, 4977.285, 4961.115, 4944.111, 4926.295999999999, 4907.693, 4888.322, 4868.205, 4847.362, 4825.811, 4803.573, 4780.664000000001, 4757.102, 4732.905, 4708.088, 4682.668, 4656.659000000001, 4630.076, 4602.935, 4575.248, 4547.03, 4518.293, 4489.0509999999995, 4459.315, 4429.097, 4398.41, 4367.265, 4335.673, 4303.644, 4271.189, 4238.318, 4205.041, 4171.367, 4137.306, 4102.867, 4068.058, 4032.889, 3997.368, 3961.5029999999997, 3925.301, 3888.7709999999997, 3851.921, 3814.758, 3777.288, 3739.52, 3701.46, 3663.114, 3624.489, 3585.593, 3546.43, 3507.008, 3467.3320000000003, 3427.408, 3387.243, 3346.841, 3306.2070000000003, 3265.349, 3224.27, 3182.9759999999997, 3141.472, 3099.763, 3057.8540000000003, 3015.75, 2973.455, 2930.974, 2888.3109999999997, 2845.4709999999995, 2802.4590000000003, 2759.278, 2715.9320000000002, 2672.426, 2628.764, 2584.95, 2540.987, 2496.88, 2452.632, 2408.2470000000003, 2363.728, 2319.08, 2274.305, 2229.407, 2184.39, 2139.256, 2094.01, 2048.654, 2003.192, 1957.626, 1911.96, 1866.1970000000001, 1820.34, 1774.392, 1728.356, 1682.234, 1636.03, 1589.746, 1543.385, 1496.95, 1450.444, 1403.869, 1357.2279999999998, 1310.5230000000001, 1263.758, 1216.934, 1170.0539999999999, 1123.12, 1076.136, 1029.103, 982.0239999999999, 934.9019999999999, 887.738, 840.534, 793.295, 746.02, 698.7130000000001, 651.377, 604.012, 556.622, 509.209, 461.774, 414.32099999999997, 366.85, 319.36400000000003, 271.866, 224.356, 176.838, 129.314, 81.78399999999999, 34.253, -13.28, -60.81100000000001, -108.339, -155.861, -203.377, -250.88299999999998, -298.378, -345.86, -393.32800000000003, -440.778, -488.21, -535.622, -583.011, -630.375, -677.7139999999999, -725.025, -772.2769999999999, -819.5260000000001, -866.742, -913.923, -961.067, -1008.172, -1055.236, -1102.258, -1149.236, -1196.1680000000001, -1243.0510000000002, -1289.886, -1336.6689999999999, -1383.399, -1430.0739999999998, -1476.692, -1523.2520000000002, -1569.7520000000002, -1616.19, -1662.5639999999999, -1708.872, -1755.1129999999998, -1801.285, -1847.3870000000002, -1893.4160000000002, -1939.37, -1985.2479999999998, -2031.0479999999998, -2076.769, -2122.408, -2167.964, -2213.4339999999997, -2258.8179999999998, -2304.113, -2349.3179999999998, -2394.43, -2439.449, -2484.371, -2529.196, -2573.9210000000003, -2618.544, -2663.065, -2707.48, -2751.788, -2795.988, -2840.0759999999996, -2884.052, -2927.914, -2971.659, -3015.2859999999996, -3058.792, -3102.177, -3145.437, -3188.571, -3231.577, -3274.452, -3317.196, -3359.8059999999996, -3402.28, -3444.615, -3486.81, -3528.863, -3570.772, -3612.534, -3654.1479999999997, -3695.611, -3736.921, -3778.0759999999996, -3819.075, -3859.913, -3900.59, -3941.103, -3981.45, -4021.6290000000004, -4061.637, -4101.472, -4141.1320000000005, -4180.6140000000005, -4219.915, -4259.034000000001, -4297.969, -4336.715, -4375.272, -4413.6359999999995, -4451.806, -4489.778, -4527.55, -4565.1179999999995, -4602.482, -4639.637, -4676.581, -4713.312, -4749.826, -4786.121, -4822.194, -4858.042, -4893.662, -4929.0509999999995, -4964.206, -4999.124, -5033.802, -5068.236, -5102.425, -5136.363, -5170.049, -5203.479, -5236.649, -5269.557, -5302.198, -5334.569, -5366.6669999999995, -5398.488, -5430.028, -5461.284000000001, -5492.251, -5522.927, -5553.306, -5583.3859999999995, -5613.161999999999, -5642.630999999999, -5671.786999999999, -5700.6269999999995, -5729.146, -5757.340999999999, -5785.206, -5812.738, -5839.931, -5866.781, -5893.283, -5919.433000000001, -5945.225, -5970.654, -5995.715999999999, -6020.405, -6044.715999999999, -6068.643, -6092.182, -6115.326, -6138.069, -6160.406999999999, -6182.331999999999, -6203.839, -6224.922, -6245.5740000000005, -6265.79, -6285.562, -6304.885, -6323.75, -6342.151, -6360.081, -6377.533, -6394.499, -6410.972, -6426.944, -6442.406999999999, -6457.352, -6471.772, -6485.658, -6499.0019999999995, -6511.793000000001, -6524.024, -6535.686, -6546.768, -6557.2609999999995, -6567.155, -6576.439, -6585.103, -6593.1359999999995, -6600.528, -6607.266, -6613.34, -6618.736999999999, -6623.445, -6627.45, -6630.741999999999, -6633.306, -6635.129, -6636.196, -6636.493, -6636.005999999999, -6634.719, -6632.616, -6629.681, -6625.898, -6621.249, -6615.718000000001, -6609.285, -6601.932, -6593.64, -6584.389, -6574.158, -6562.9259999999995, -6550.67, -6537.37, -6523.001, -6507.539000000001, -6490.959, -6473.236, -6454.342, -6434.251, -6412.932, -6390.359, -6366.4980000000005, -6341.32, -6314.79, -6286.876, -6257.541, -6226.746999999999, -6194.46, -6160.637, -6125.2390000000005, -6088.223000000001, -6049.543000000001, -6009.156, -5967.012, -5923.062, -5877.254, -5829.533, -5779.846, -5728.132, -5674.331999999999, -5618.38, -5560.214, -5499.763000000001, -5436.956, -5371.719, -5303.976, -5233.644, -5160.64, -5084.879, -5006.269, -4924.715, -4840.123, -4752.389, -4661.41, -4567.079000000001, -4469.284000000001, -4367.913, -4262.848, -4153.97, -4041.1609999999996, -3924.297, -3803.259, -3677.9240000000004, -3548.176, -3413.901, -3274.992, -3131.3520000000003, -2982.8920000000003, -2829.5440000000003, -2671.255, -2507.998, -2339.775, -2166.625, -1988.626, -1805.9029999999998, -1618.64, -1427.0739999999998, -1231.514, -1032.335, -829.982, -624.974, -417.89599999999996, -209.394, -0.162, 209.065, 417.533, 624.486, 829.18, 1030.906, 1229.004, 1422.8729999999998, 1611.9879999999998, 1795.899, 1974.2379999999998, 2146.718, 2313.125, 2473.32, 2627.2270000000003, 2774.824, 2916.139, 3051.241, 3180.232, 3303.238, 3420.409, 3531.909, 3637.909, 3738.592, 3834.1440000000002, 3924.7470000000003, 4010.5890000000004, 4091.8509999999997, 4168.713, 4241.347, 4309.924, 4374.607, 4435.553, 4492.914000000001, 4546.835, 4597.454000000001, 4644.904, 4689.313, 4730.8009999999995, 4769.483, 4805.471, 4838.8679999999995, 4869.773, 4898.284000000001, 4924.491, 4948.479, 4970.331, 4990.126, 5007.939, 5023.84, 5037.899, 5050.178, 5060.742, 5069.649, 5076.955, 5082.715, 5086.979, 5089.799, 5091.22, 5091.289000000001, 5090.048, 5087.539000000001, 5083.8009999999995, 5078.873, 5072.792, 5065.592000000001, 5057.308, 5047.972, 5037.615, 5026.266, 5013.955, 5000.71, 4986.557, 4971.521, 4955.629, 4938.903, 4921.366, 4903.041, 4883.9490000000005, 4864.111, 4843.5470000000005, 4822.276, 4800.316, 4777.686, 4754.404, 4730.485, 4705.948, 4680.806, 4655.076, 4628.772, 4601.909000000001, 4574.501, 4546.561, 4518.102, 4489.138, 4459.68, 4429.74, 4399.33, 4368.460999999999, 4337.145, 4305.392, 4273.213, 4240.617, 4207.615, 4174.215, 4140.428, 4106.263, 4071.728, 4036.8309999999997, 4001.5820000000003, 3965.989, 3930.059, 3893.8, 3857.22, 3820.3259999999996, 3783.1259999999997, 3745.6259999999997, 3707.8340000000003, 3669.756, 3631.3990000000003, 3592.768, 3553.8720000000003, 3514.715, 3475.303, 3435.6440000000002, 3395.741, 3355.6020000000003, 3315.2309999999998, 3274.634, 3233.816, 3192.782, 3151.5370000000003, 3110.087, 3068.4359999999997, 3026.5890000000004, 2984.551, 2942.3259999999996, 2899.9190000000003, 2857.333, 2814.575, 2771.647, 2728.553, 2685.2990000000004, 2641.888, 2598.324, 2554.611, 2510.752, 2466.752, 2422.614, 2378.341, 2333.938, 2289.408, 2244.754, 2199.98, 2155.0879999999997, 2110.084, 2064.968, 2019.746, 1974.4189999999999, 1928.991, 1883.465, 1837.845, 1792.132, 1746.33, 1700.442, 1654.471, 1608.42, 1562.29, 1516.086, 1469.809, 1423.4620000000002, 1377.049, 1330.5710000000001, 1284.031, 1237.432, 1190.777, 1144.066, 1097.3039999999999, 1050.493, 1003.6339999999999, 956.7310000000001, 909.7860000000001, 862.8, 815.7769999999999, 768.7180000000001, 721.6260000000001, 674.503, 627.352, 580.174, 532.971, 485.746, 438.501, 391.23900000000003, 343.96, 296.66700000000003, 249.363, 202.049, 154.727, 107.4, 60.068999999999996, 12.735999999999999, -34.596, -81.926, -129.252, -176.572, -223.88299999999998, -271.185, -318.474, -365.75, -413.01, -460.25300000000004, -507.476, -554.678, -601.856, -649.01, -696.137, -743.235, -790.303, -837.3380000000001, -884.3389999999999, -931.305, -978.232, -1025.12, -1071.9669999999999, -1118.771, -1165.53, -1212.242, -1258.906, -1305.52, -1352.082, -1398.59, -1445.0420000000001, -1491.4370000000001, -1537.774, -1584.049, -1630.2620000000002, -1676.411, -1722.493, -1768.5079999999998, -1814.453, -1860.3270000000002, -1906.1270000000002, -1951.8529999999998, -1997.5020000000002, -2043.0720000000001, -2088.562, -2133.971, -2179.295, -2224.534, -2269.685, -2314.748, -2359.719, -2404.597, -2449.381, -2494.069, -2538.658, -2583.147, -2627.534, -2671.817, -2715.995, -2760.065, -2804.026, -2847.8759999999997, -2891.612, -2935.2340000000004, -2978.738, -3022.1240000000003, -3065.389, -3108.531, -3151.548, -3194.4390000000003, -3237.2009999999996, -3279.833, -3322.3309999999997, -3364.696, -3406.923, -3449.012, -3490.96, -3532.7659999999996, -3574.426, -3615.94, -3657.304, -3698.5170000000003, -3739.5759999999996, -3780.48, -3821.2259999999997, -3861.812, -3902.236, -3942.495, -3982.5879999999997, -4022.511, -4062.263, -4101.842000000001, -4141.244000000001, -4180.467000000001, -4219.51, -4258.37, -4297.044, -4335.529, -4373.8240000000005, -4411.9259999999995, -4449.832, -4487.539000000001, -4525.045, -4562.348, -4599.444, -4636.332, -4673.0070000000005, -4709.468, -4745.710999999999, -4781.734, -4817.534000000001, -4853.108, -4888.4529999999995, -4923.566, -4958.444, -4993.083, -5027.482, -5061.6359999999995, -5095.542, -5129.198, -5162.599, -5195.744000000001, -5228.627, -5261.246, -5293.597, -5325.677, -5357.482, -5389.009, -5420.253000000001, -5451.210999999999, -5481.879, -5512.254, -5542.331, -5572.107, -5601.578, -5630.738, -5659.585, -5688.113, -5716.319, -5744.198, -5771.746, -5798.9580000000005, -5825.829000000001, -5852.354, -5878.53, -5904.351, -5929.811, -5954.906999999999, -5979.632, -6003.982, -6027.951, -6051.534000000001, -6074.725, -6097.518, -6119.908, -6141.888000000001, -6163.454000000001, -6184.598000000001, -6205.315, -6225.597, -6245.44, -6264.835, -6283.776, -6302.255999999999, -6320.268, -6337.806, -6354.86, -6371.425, -6387.491, -6403.052, -6418.099, -6432.624, -6446.619000000001, -6460.0740000000005, -6472.981, -6485.331, -6497.115, -6508.3240000000005, -6518.946, -6528.974, -6538.395, -6547.201, -6555.38, -6562.92, -6569.812, -6576.043000000001, -6581.601, -6586.475, -6590.65, -6594.116, -6596.859, -6598.865, -6600.12, -6600.609, -6600.319, -6599.233, -6597.3369999999995, -6594.6140000000005, -6591.047, -6586.62, -6581.315, -6575.1140000000005, -6567.999, -6559.9490000000005, -6550.946, -6540.969, -6529.996999999999, -6518.007, -6504.978, -6490.8859999999995, -6475.7080000000005, -6459.419, -6441.991999999999, -6423.401, -6403.62, -6382.619000000001, -6360.368, -6336.838000000001, -6311.9980000000005, -6285.814, -6258.2519999999995, -6229.276999999999, -6198.853, -6166.941999999999, -6133.505, -6098.5, -6061.8859999999995, -6023.618, -5983.65, -5941.935, -5898.424, -5853.065, -5805.804, -5756.584, -5705.35, -5652.04, -5596.590999999999, -5538.936, -5479.01, -5416.74, -5352.0509999999995, -5284.868, -5215.11, -5142.694, -5067.532999999999, -4989.537, -4908.613, -4824.662, -4737.587, -4647.281, -4553.639, -4456.549, -4355.898, -4251.57, -4143.447, -4031.408, -3915.3320000000003, -3795.098, -3670.586, -3541.678, -3408.259, -3270.224, -3127.472, -2979.9179999999997, -2827.488, -2670.131, -2507.8179999999998, -2340.551, -2168.362, -1991.33, -1809.578, -1623.283, -1432.682, -1238.077, -1039.839, -838.41, -634.302, -428.094, -220.429, -11.997, 196.472, 404.228, 610.515, 814.595, 1015.7589999999999, 1213.344, 1406.753, 1595.455, 1779.003, 1957.024, 2129.228, 2295.402, 2455.401, 2609.146, 2756.615, 2897.8320000000003, 3032.864, 3161.809, 3284.796, 3401.967, 3513.486, 3619.527, 3720.265, 3815.888, 3906.577, 3992.518, 4073.8909999999996, 4150.875, 4223.642, 4292.363, 4357.198, 4418.306, 4475.835, 4529.932, 4580.735, 4628.375, 4672.98, 4714.67, 4753.559, 4789.759, 4823.373, 4854.5, 4883.237, 4909.673, 4933.895, 4955.984, 4976.019, 4994.075, 5010.223, 5024.531, 5037.062, 5047.88, 5057.044, 5064.609, 5070.63, 5075.157999999999, 5078.242, 5079.93, 5080.267, 5079.295, 5077.057, 5073.592000000001, 5068.938, 5063.1320000000005, 5056.209, 5048.202, 5039.144, 5029.066, 5017.998, 5005.967000000001, 4993.003, 4979.1320000000005, 4964.38, 4948.771, 4932.329000000001, 4915.077, 4897.037, 4878.23, 4858.678, 4838.4, 4817.415, 4795.742, 4773.398, 4750.403, 4726.772, 4702.521, 4677.667, 4652.224, 4626.208, 4599.6320000000005, 4572.5109999999995, 4544.859, 4516.687, 4488.01, 4458.838, 4429.186, 4399.062, 4368.48, 4337.45, 4305.984, 4274.09, 4241.78, 4209.063, 4175.9490000000005, 4142.446, 4108.565, 4074.3140000000003, 4039.7009999999996, 4004.736, 3969.425, 3933.778, 3897.801, 3861.502, 3824.89, 3787.9709999999995, 3750.7509999999997, 3713.239, 3675.44, 3637.362, 3599.01, 3560.3909999999996, 3521.512, 3482.377, 3442.993, 3403.366, 3363.502, 3323.406, 3283.0820000000003, 3242.5370000000003, 3201.776, 3160.804, 3119.625, 3078.245, 3036.6679999999997, 2994.8990000000003, 2952.9429999999998, 2910.804, 2868.486, 2825.994, 2783.3320000000003, 2740.5040000000004, 2697.515, 2654.368, 2611.067, 2567.616, 2524.019, 2480.28, 2436.402, 2392.389, 2348.245, 2303.973, 2259.576, 2215.058, 2170.423, 2125.673, 2080.812, 2035.842, 1990.7679999999998, 1945.592, 1900.317, 1854.9460000000001, 1809.483, 1763.93, 1718.289, 1672.565, 1626.759, 1580.874, 1534.914, 1488.88, 1442.776, 1396.604, 1350.3670000000002, 1304.067, 1257.7069999999999, 1211.289, 1164.816, 1118.29, 1071.714, 1025.089, 978.42, 931.706, 884.952, 838.16, 791.33, 744.467, 697.572, 650.6469999999999, 603.695, 556.717, 509.716, 462.694, 415.653, 368.595, 321.522, 274.437, 227.34, 180.236, 133.124, 86.008, 38.889, -8.231, -55.349, -102.464, -149.57399999999998, -196.67700000000002, -243.77200000000002, -290.855, -337.925, -384.981, -432.02, -479.041, -526.0419999999999, -573.021, -619.976, -666.905, -713.806, -760.679, -807.52, -854.328, -901.1010000000001, -947.8380000000001, -994.5360000000001, -1041.194, -1087.81, -1134.383, -1180.91, -1227.39, -1273.8210000000001, -1320.201, -1366.5279999999998, -1412.8020000000001, -1459.019, -1505.1779999999999, -1551.2779999999998, -1597.317, -1643.2920000000001, -1689.203, -1735.047, -1780.8220000000001, -1826.5279999999998, -1872.161, -1917.721, -1963.2060000000001, -2008.6129999999998, -2053.942, -2099.189, -2144.354, -2189.435, -2234.43, -2279.337, -2324.154, -2368.88, -2413.513, -2458.05, -2502.491, -2546.833, -2591.074, -2635.2129999999997, -2679.248, -2723.176, -2766.9970000000003, -2810.7070000000003, -2854.3059999999996, -2897.792, -2941.1620000000003, -2984.414, -3027.547, -3070.559, -3113.448, -3156.212, -3198.848, -3241.355, -3283.7309999999998, -3325.974, -3368.0820000000003, -3410.053, -3451.884, -3493.575, -3535.1209999999996, -3576.5229999999997, -3617.777, -3658.881, -3699.833, -3740.631, -3781.2740000000003, -3821.757, -3862.08, -3902.241, -3942.236, -3982.0640000000003, -4021.722, -4061.208, -4100.519, -4139.654, -4178.61, -4217.384, -4255.974, -4294.378, -4332.593, -4370.616, -4408.445, -4446.0779999999995, -4483.512, -4520.744000000001, -4557.771, -4594.590999999999, -4631.201, -4667.598, -4703.78, -4739.744000000001, -4775.486, -4811.004, -4846.295, -4881.357, -4916.185, -4950.777, -4985.13, -5019.24, -5053.105, -5086.721, -5120.085999999999, -5153.195, -5186.045, -5218.633, -5250.956, -5283.009, -5314.79, -5346.294, -5377.519, -5408.46, -5439.113, -5469.475, -5499.5419999999995, -5529.309, -5558.774, -5587.931, -5616.776999999999, -5645.307, -5673.517, -5701.401999999999, -5728.959, -5756.182, -5783.068, -5809.61, -5835.805, -5861.648, -5887.133000000001, -5912.255999999999, -5937.0109999999995, -5961.394, -5985.399, -6009.02, -6032.2519999999995, -6055.089, -6077.526, -6099.557, -6121.175, -6142.376, -6163.151, -6183.496, -6203.404, -6222.866999999999, -6241.88, -6260.435, -6278.525, -6296.144, -6313.283, -6329.935, -6346.094, -6361.749, -6376.895, -6391.522, -6405.621999999999, -6419.187, -6432.206999999999, -6444.673000000001, -6456.578, -6467.91, -6478.661, -6488.82, -6498.378000000001, -6507.3240000000005, -6515.647, -6523.335999999999, -6530.38, -6536.768, -6542.488, -6547.526999999999, -6551.8730000000005, -6555.514, -6558.436, -6560.625, -6562.069, -6562.753000000001, -6562.661, -6561.779, -6560.092, -6557.581999999999, -6554.235, -6550.031999999999, -6544.956999999999, -6538.991999999999, -6532.116999999999, -6524.315, -6515.565, -6505.846, -6495.139, -6483.42, -6470.668000000001, -6456.86, -6441.972, -6425.979, -6408.856, -6390.576, -6371.111999999999, -6350.436, -6328.517, -6305.326999999999, -6280.834, -6255.005999999999, -6227.807, -6199.204000000001, -6169.16, -6137.637, -6104.597, -6069.999, -6033.8, -5995.956999999999, -5956.423000000001, -5915.153, -5872.097, -5827.201999999999, -5780.4169999999995, -5731.684, -5680.946999999999, -5628.146, -5573.217, -5516.095, -5456.714, -5395.0019999999995, -5330.884, -5264.285, -5195.125, -5123.321, -5048.786, -4971.431, -4891.163, -4807.884, -4721.496, -4631.895, -4538.973, -4442.621, -4342.724, -4239.169, -4131.837, -4020.6059999999998, -3905.3579999999997, -3785.969, -3662.322, -3534.296, -3401.7790000000005, -3264.6620000000003, -3122.848, -2976.2470000000003, -2824.7859999999996, -2668.415, -2507.1, -2340.842, -2169.673, -1993.6670000000001, -1812.944, -1627.6789999999999, -1438.1029999999998, -1244.516, -1047.282, -846.84, -643.695, -438.42199999999997, -231.658, -24.089000000000002, 183.56099999999998, 390.543, 596.107, 799.515, 1000.059, 1197.077, 1389.973, 1578.214, 1761.35, 1939.007, 2110.893, 2276.792, 2436.556, 2590.103, 2737.408, 2878.495, 3013.425, 3142.296, 3265.2329999999997, 3382.3790000000004, 3493.8940000000002, 3599.95, 3700.723, 3796.3959999999997, 3887.152, 3973.173, 4054.6409999999996, 4131.732, 4204.6179999999995, 4273.468, 4338.443, 4399.6990000000005, 4457.387, 4511.65, 4562.627, 4610.448, 4655.349, 4697.126, 4736.215999999999, 4772.622, 4806.448, 4837.793, 4866.751, 4893.414000000001, 4917.867, 4940.19, 4960.464, 4978.762, 4995.156, 5009.712, 5022.495, 5033.568, 5042.9890000000005, 5050.815, 5057.098, 5061.89, 5065.241, 5067.198, 5067.806, 5067.108, 5065.145, 5061.956, 5057.58, 5052.053, 5045.411, 5037.686, 5028.911, 5019.1179999999995, 5008.335, 4996.592000000001, 4983.915, 4970.333, 4955.87, 4940.5509999999995, 4924.4, 4907.439, 4889.691, 4871.178, 4851.919, 4831.935, 4811.244000000001, 4789.866, 4767.818, 4745.117, 4721.782, 4697.827, 4673.269, 4648.123, 4622.403, 4596.125, 4569.3009999999995, 4541.945, 4514.07, 4485.69, 4456.816, 4427.46, 4397.634, 4367.349, 4336.615, 4305.445, 4273.848, 4241.834, 4209.414000000001, 4176.595, 4143.389, 4109.803, 4075.847, 4041.53, 4006.8590000000004, 3971.842, 3936.489, 3900.8059999999996, 3864.801, 3828.482, 3791.855, 3754.928, 3717.7070000000003, 3680.2, 3642.413, 3604.3520000000003, 3566.0229999999997, 3527.433, 3488.587, 3449.492, 3410.153, 3370.5759999999996, 3330.7670000000003, 3290.73, 3250.4709999999995, 3209.9959999999996, 3169.308, 3128.414, 3087.317, 3046.0229999999997, 3004.5370000000003, 2962.862, 2921.0040000000004, 2878.967, 2836.755, 2794.3720000000003, 2751.823, 2709.111, 2666.242, 2623.217, 2580.042, 2536.72, 2493.256, 2449.652, 2405.9120000000003, 2362.04, 2318.0389999999998, 2273.913, 2229.666, 2185.299, 2140.8179999999998, 2096.224, 2051.522, 2006.714, 1961.8029999999999, 1916.793, 1871.6860000000001, 1826.485, 1781.194, 1735.815, 1690.351, 1644.805, 1599.1789999999999, 1553.477, 1507.7, 1461.852, 1415.9360000000001, 1369.953, 1323.9070000000002, 1277.799, 1231.633, 1185.411, 1139.135, 1092.808, 1046.432, 1000.0089999999999, 953.5419999999999, 907.033, 860.485, 813.8989999999999, 767.279, 720.625, 673.941, 627.2280000000001, 580.489, 533.726, 486.941, 440.135, 393.31199999999995, 346.473, 299.62, 252.75599999999997, 205.882, 159.0, 112.11200000000001, 65.221, 18.328, -28.565, -75.455, -122.34200000000001, -169.22299999999998, -216.095, -262.95799999999997, -309.81, -356.647, -403.47, -450.275, -497.061, -543.826, -590.568, -637.286, -683.977, -730.64, -777.273, -823.8739999999999, -870.442, -916.9739999999999, -963.4689999999999, -1009.925, -1056.34, -1102.712, -1149.0410000000002, -1195.323, -1241.558, -1287.743, -1333.876, -1379.957, -1425.983, -1471.9520000000002, -1517.8629999999998, -1563.713, -1609.5020000000002, -1655.2279999999998, -1700.888, -1746.48, -1792.004, -1837.4579999999999, -1882.839, -1928.146, -1973.3770000000002, -2018.531, -2063.605, -2108.598, -2153.508, -2198.333, -2243.072, -2287.722, -2332.283, -2376.751, -2421.126, -2465.405, -2509.587, -2553.67, -2597.651, -2641.53, -2685.305, -2728.972, -2772.532, -2815.9809999999998, -2859.3179999999998, -2902.5409999999997, -2945.6479999999997, -2988.637, -3031.507, -3074.2540000000004, -3116.8779999999997, -3159.377, -3201.748, -3243.989, -3286.099, -3328.075, -3369.9159999999997, -3411.619, -3453.1820000000002, -3494.603, -3535.881, -3577.013, -3617.9970000000003, -3658.83, -3699.511, -3740.038, -3780.408, -3820.619, -3860.6690000000003, -3900.555, -3940.276, -3979.829, -4019.212, -4058.422, -4097.456, -4136.314, -4174.992, -4213.488, -4251.799, -4289.923, -4327.858, -4365.6, -4403.148, -4440.498, -4477.649, -4514.596, -4551.339, -4587.874, -4624.197, -4660.308, -4696.202, -4731.877, -4767.329000000001, -4802.557, -4837.557, -4872.326, -4906.861, -4941.157999999999, -4975.215999999999, -5009.03, -5042.598, -5075.916, -5108.98, -5141.789000000001, -5174.337, -5206.622, -5238.641, -5270.388000000001, -5301.863, -5333.059, -5363.974, -5394.604, -5424.944, -5454.993, -5484.744000000001, -5514.195, -5543.340999999999, -5572.178000000001, -5600.701999999999, -5628.909000000001, -5656.793000000001, -5684.351, -5711.579000000001, -5738.471, -5765.023, -5791.231, -5817.089, -5842.592, -5867.736, -5892.515, -5916.924, -5940.9580000000005, -5964.611, -5987.879, -6010.755, -6033.233, -6055.308000000001, -6076.974, -6098.225, -6119.054, -6139.456, -6159.424, -6178.951, -6198.03, -6216.655, -6234.819, -6252.515, -6269.735, -6286.471, -6302.717, -6318.464, -6333.705, -6348.43, -6362.633000000001, -6376.303000000001, -6389.433000000001, -6402.014, -6414.036, -6425.49, -6436.366999999999, -6446.656999999999, -6456.349, -6465.433000000001, -6473.899, -6481.735, -6488.931, -6495.475, -6501.355, -6506.56, -6511.075, -6514.891, -6517.991999999999, -6520.366, -6522.0, -6522.878000000001, -6522.986, -6522.309, -6520.831, -6518.5380000000005, -6515.411999999999, -6511.436, -6506.593000000001, -6500.866, -6494.236, -6486.684, -6478.19, -6468.734, -6458.295, -6446.852, -6434.382, -6420.863, -6406.27, -6390.58, -6373.767, -6355.804, -6336.664000000001, -6316.32, -6294.741, -6271.899, -6247.7609999999995, -6222.297, -6195.471, -6167.249, -6137.594, -6106.47, -6073.838000000001, -6039.656999999999, -6003.8859999999995, -5966.48, -5927.393, -5886.58, -5843.991999999999, -5799.576, -5753.281, -5705.049, -5654.826, -5602.55, -5548.159000000001, -5491.588000000001, -5432.77, -5371.634, -5308.108, -5242.112, -5173.572, -5102.401, -5028.515, -4951.8240000000005, -4872.237, -4789.655, -4703.981, -4615.11, -4522.936, -4427.351, -4328.2390000000005, -4225.488, -4118.978, -4008.5890000000004, -3894.202, -3775.6940000000004, -3652.948, -3525.842, -3394.2659999999996, -3258.1079999999997, -3117.2729999999997, -2971.6679999999997, -2821.223, -2665.882, -2505.612, -2340.413, -2170.313, -1995.385, -1815.745, -1631.5639999999999, -1443.07, -1250.558, -1054.387, -854.9910000000001, -652.87, -448.594, -242.792, -36.148, 170.61900000000003, 376.765, 581.543, 784.217, 984.081, 1180.474, 1372.797, 1560.52, 1743.1889999999999, 1920.4279999999999, 2091.944, 2257.518, 2416.998, 2570.302, 2717.3990000000003, 2858.313, 2993.1009999999997, 3121.86, 3244.712, 3361.798, 3473.276, 3579.317, 3680.094, 3775.79, 3866.586, 3952.664, 4034.202, 4111.378, 4184.362, 4253.322, 4318.418, 4379.807, 4437.6359999999995, 4492.0509999999995, 4543.188, 4591.177, 4636.146, 4678.215, 4717.495, 4754.098, 4788.127, 4819.68, 4848.853, 4875.735, 4900.412, 4922.965, 4943.473, 4962.009, 4978.644, 4993.446, 5006.479, 5017.804, 5027.481, 5035.565, 5042.111, 5047.168, 5050.786, 5053.013, 5053.892, 5053.468, 5051.782, 5048.872, 5044.775, 5039.531, 5033.1720000000005, 5025.733, 5017.246, 5007.741, 4997.248, 4985.795999999999, 4973.412, 4960.123, 4945.955, 4930.932, 4915.077, 4898.414000000001, 4880.965, 4862.751, 4843.792, 4824.108, 4803.719, 4782.643, 4760.898, 4738.5, 4715.469, 4691.818, 4667.564, 4642.723, 4617.308, 4591.335, 4564.817, 4537.767, 4510.1990000000005, 4482.125, 4453.557, 4424.5070000000005, 4394.988, 4365.01, 4334.583, 4303.719, 4272.429, 4240.722, 4208.608, 4176.096, 4143.196, 4109.916, 4076.2670000000003, 4042.255, 4007.89, 3973.179, 3938.131, 3902.7529999999997, 3867.052, 3831.0370000000003, 3794.715, 3758.092, 3721.175, 3683.9709999999995, 3646.486, 3608.7270000000003, 3570.7009999999996, 3532.4120000000003, 3493.868, 3455.074, 3416.035, 3376.758, 3337.248, 3297.51, 3257.55, 3217.3720000000003, 3176.982, 3136.385, 3095.5840000000003, 3054.586, 3013.395, 2972.015, 2930.452, 2888.708, 2846.789, 2804.698, 2762.441, 2720.02, 2677.441, 2634.7059999999997, 2591.82, 2548.7870000000003, 2505.61, 2462.2929999999997, 2418.84, 2375.2529999999997, 2331.538, 2287.696, 2243.732, 2199.6479999999997, 2155.449, 2111.137, 2066.715, 2022.1870000000001, 1977.555, 1932.8229999999999, 1887.994, 1843.07, 1798.055, 1752.951, 1707.761, 1662.4879999999998, 1617.135, 1571.704, 1526.1989999999998, 1480.621, 1434.974, 1389.259, 1343.48, 1297.64, 1251.739, 1205.782, 1159.77, 1113.7060000000001, 1067.5919999999999, 1021.431, 975.2239999999999, 928.975, 882.685, 836.357, 789.993, 743.595, 697.165, 650.706, 604.22, 557.7090000000001, 511.17400000000004, 464.619, 418.04400000000004, 371.45300000000003, 324.847, 278.22900000000004, 231.59900000000002, 184.96099999999998, 138.316, 91.667, 45.013999999999996, -1.639, -48.291000000000004, -94.94, -141.584, -188.222, -234.851, -281.469, -328.074, -374.666, -421.241, -467.798, -514.336, -560.851, -607.344, -653.811, -700.2510000000001, -746.6619999999999, -793.0419999999999, -839.39, -885.704, -931.9810000000001, -978.221, -1024.422, -1070.58, -1116.6960000000001, -1162.767, -1208.792, -1254.768, -1300.694, -1346.568, -1392.389, -1438.154, -1483.8629999999998, -1529.5120000000002, -1575.101, -1620.628, -1666.09, -1711.487, -1756.816, -1802.076, -1847.265, -1892.381, -1937.4229999999998, -1982.388, -2027.275, -2072.083, -2116.808, -2161.451, -2206.008, -2250.479, -2294.86, -2339.152, -2383.351, -2427.456, -2471.465, -2515.376, -2559.188, -2602.8979999999997, -2646.505, -2690.008, -2733.403, -2776.6890000000003, -2819.865, -2862.929, -2905.8779999999997, -2948.71, -2991.425, -3034.0190000000002, -3076.491, -3118.8390000000004, -3161.0609999999997, -3203.156, -3245.12, -3286.952, -3328.65, -3370.2129999999997, -3411.637, -3452.921, -3494.063, -3535.0609999999997, -3575.9120000000003, -3616.615, -3657.167, -3697.567, -3737.8109999999997, -3777.8990000000003, -3817.827, -3857.593, -3897.196, -3936.632, -3975.9, -4014.9959999999996, -4053.92, -4092.6690000000003, -4131.2390000000005, -4169.63, -4207.837, -4245.86, -4283.694, -4321.339, -4358.791, -4396.0470000000005, -4433.105, -4469.963, -4506.6179999999995, -4543.066, -4579.306, -4615.335, -4651.149, -4686.746, -4722.123, -4757.278, -4792.206, -4826.906, -4861.374, -4895.607, -4929.602, -4963.356, -4996.865, -5030.127, -5063.138, -5095.895, -5128.395, -5160.633, -5192.607, -5224.313, -5255.7480000000005, -5286.906999999999, -5317.7880000000005, -5348.385, -5378.696999999999, -5408.718000000001, -5438.445, -5467.874, -5497.001, -5525.821, -5554.331, -5582.526, -5610.401999999999, -5637.954000000001, -5665.179, -5692.07, -5718.625, -5744.838000000001, -5770.703, -5796.218000000001, -5821.375, -5846.170999999999, -5870.6, -5894.656999999999, -5918.3369999999995, -5941.633000000001, -5964.541, -5987.054, -6009.168000000001, -6030.875, -6052.170999999999, -6073.049, -6093.5019999999995, -6113.525, -6133.11, -6152.2519999999995, -6170.941999999999, -6189.175, -6206.943, -6224.2390000000005, -6241.055, -6257.384, -6273.218000000001, -6288.55, -6303.37, -6317.672, -6331.445, -6344.682, -6357.3730000000005, -6369.51, -6381.084, -6392.084, -6402.501, -6412.325, -6421.545999999999, -6430.153, -6438.135, -6445.481, -6452.179, -6458.219, -6463.5869999999995, -6468.273, -6472.263000000001, -6475.544, -6478.102, -6479.925, -6480.9980000000005, -6481.306, -6480.835, -6479.57, -6477.493, -6474.59, -6470.843000000001, -6466.235, -6460.7480000000005, -6454.365, -6447.066, -6438.831999999999, -6429.642, -6419.476, -6408.313, -6396.13, -6382.904, -6368.611999999999, -6353.229, -6336.731, -6319.090999999999, -6300.283, -6280.276999999999, -6259.045999999999, -6236.559, -6212.785, -6187.691999999999, -6161.246999999999, -6133.415, -6104.16, -6073.445, -6041.232, -6007.479, -5972.145, -5935.188, -5896.561, -5856.219, -5814.111999999999, -5770.189, -5724.398, -5676.684, -5626.9890000000005, -5575.255, -5521.419, -5465.415, -5407.178000000001, -5346.638000000001, -5283.721, -5218.351, -5150.45, -5079.935, -5006.721, -4930.717000000001, -4851.834, -4769.975, -4685.041, -4596.927, -4505.53, -4410.7390000000005, -4312.442, -4210.525, -4104.869000000001, -3995.3559999999998, -3881.865, -3764.2729999999997, -3642.4640000000004, -3516.317, -3385.72, -3250.5640000000003, -3110.748, -2966.185, -2816.7990000000004, -2662.535, -2503.36, -2339.268, -2170.2889999999998, -1996.491, -1817.9879999999998, -1634.9470000000001, -1447.592, -1256.213, -1061.1660000000002, -862.875, -661.84, -458.62300000000005, -253.84799999999998, -48.192, 157.629, 362.876, 566.806, 768.684, 967.805, 1163.512, 1355.205, 1542.352, 1724.4979999999998, 1901.266, 2072.36, 2237.558, 2396.7070000000003, 2549.722, 2696.5679999999998, 2837.2659999999996, 2971.8740000000003, 3100.482, 3223.2129999999997, 3340.204, 3451.614, 3557.607, 3658.361, 3754.052, 3844.862, 3930.9709999999995, 4012.558, 4089.797, 4162.859, 4231.91, 4297.109, 4358.612, 4416.568, 4471.119000000001, 4522.402, 4570.548, 4615.681, 4657.920999999999, 4697.3820000000005, 4734.173, 4768.395, 4800.15, 4829.531, 4856.626, 4881.521, 4904.298, 4925.035, 4943.805, 4960.679, 4975.723, 4989.003, 5000.579000000001, 5010.51, 5018.852, 5025.659000000001, 5030.98, 5034.866, 5037.363, 5038.516, 5038.3679999999995, 5036.959, 5034.33, 5030.517, 5025.558, 5019.486, 5012.335999999999, 5004.139, 4994.927, 4984.728, 4973.572, 4961.486, 4948.496, 4934.628, 4919.906, 4904.353, 4887.994000000001, 4870.85, 4852.942, 4834.29, 4814.914000000001, 4794.833, 4774.067, 4752.6320000000005, 4730.545999999999, 4707.826, 4684.487, 4660.545999999999, 4636.018, 4610.917, 4585.258, 4559.054, 4532.319, 4505.066, 4477.307, 4449.055, 4420.322, 4391.119000000001, 4361.457, 4331.348, 4300.8009999999995, 4269.8279999999995, 4238.438, 4206.641, 4174.446, 4141.863, 4108.9, 4075.5679999999998, 4041.873, 4007.824, 3973.43, 3938.698, 3903.636, 3868.252, 3832.553, 3796.546, 3760.238, 3723.637, 3686.748, 3649.578, 3612.134, 3574.421, 3536.447, 3498.216, 3459.735, 3421.009, 3382.045, 3342.847, 3303.42, 3263.7709999999997, 3223.9040000000005, 3183.824, 3143.5359999999996, 3103.045, 3062.355, 3021.472, 2980.4, 2939.143, 2897.7059999999997, 2856.093, 2814.308, 2772.355, 2730.239, 2687.9629999999997, 2645.532, 2602.948, 2560.217, 2517.341, 2474.325, 2431.1710000000003, 2387.884, 2344.467, 2300.923, 2257.256, 2213.469, 2169.565, 2125.548, 2081.4210000000003, 2037.1860000000001, 1992.8470000000002, 1948.4070000000002, 1903.869, 1859.236, 1814.51, 1769.695, 1724.7939999999999, 1679.808, 1634.7420000000002, 1589.5970000000002, 1544.376, 1499.082, 1453.7179999999998, 1408.286, 1362.789, 1317.229, 1271.608, 1225.93, 1180.1960000000001, 1134.4089999999999, 1088.5710000000001, 1042.685, 996.753, 950.7769999999999, 904.76, 858.703, 812.61, 766.482, 720.321, 674.13, 627.91, 581.665, 535.395, 489.10400000000004, 442.792, 396.463, 350.11800000000005, 303.759, 257.389, 211.00900000000001, 164.62099999999998, 118.227, 71.829, 25.43, -20.97, -67.368, -113.76100000000001, -160.149, -206.53, -252.90099999999998, -299.26, -345.60699999999997, -391.93800000000005, -438.25199999999995, -484.548, -530.823, -577.076, -623.305, -669.508, -715.683, -761.829, -807.943, -854.025, -900.071, -946.081, -992.053, -1037.984, -1083.874, -1129.72, -1175.52, -1221.274, -1266.979, -1312.6329999999998, -1358.235, -1403.7820000000002, -1449.274, -1494.7089999999998, -1540.0839999999998, -1585.398, -1630.65, -1675.8370000000002, -1720.9579999999999, -1766.011, -1810.994, -1855.906, -1900.745, -1945.5079999999998, -1990.195, -2034.8039999999999, -2079.3320000000003, -2123.779, -2168.1420000000003, -2212.419, -2256.609, -2300.71, -2344.72, -2388.638, -2432.4610000000002, -2476.188, -2519.8160000000003, -2563.345, -2606.7729999999997, -2650.0959999999995, -2693.315, -2736.426, -2779.428, -2822.3190000000004, -2865.097, -2907.761, -2950.308, -2992.736, -3035.0440000000003, -3077.2290000000003, -3119.29, -3161.225, -3203.031, -3244.7070000000003, -3286.2509999999997, -3327.6609999999996, -3368.934, -3410.0679999999998, -3451.063, -3491.914, -3532.6220000000003, -3573.1820000000002, -3613.594, -3653.8540000000003, -3693.961, -3733.913, -3773.708, -3813.342, -3852.815, -3892.123, -3931.265, -3970.238, -4009.04, -4047.6679999999997, -4086.12, -4124.393, -4162.486, -4200.396, -4238.12, -4275.656, -4313.001, -4350.153, -4387.108, -4423.866, -4460.4220000000005, -4496.774, -4532.92, -4568.856, -4604.58, -4640.089, -4675.38, -4710.451, -4745.298, -4779.918, -4814.309, -4848.468, -4882.39, -4916.0740000000005, -4949.516, -4982.713, -5015.661, -5048.358, -5080.799, -5112.982, -5144.903, -5176.558, -5207.945, -5239.058, -5269.896, -5300.453, -5330.727, -5360.713000000001, -5390.406999999999, -5419.806, -5448.905, -5477.701, -5506.189, -5534.365, -5562.224, -5589.763000000001, -5616.977, -5643.861, -5670.41, -5696.621, -5722.486999999999, -5748.005, -5773.17, -5797.976, -5822.418000000001, -5846.491999999999, -5870.191, -5893.51, -5916.444, -5938.986999999999, -5961.133000000001, -5982.8769999999995, -6004.213000000001, -6025.133000000001, -6045.633000000001, -6065.705, -6085.344, -6104.5419999999995, -6123.293000000001, -6141.590999999999, -6159.427, -6176.794, -6193.686, -6210.095, -6226.012, -6241.431, -6256.342, -6270.7390000000005, -6284.611999999999, -6297.953, -6310.753000000001, -6323.003000000001, -6334.693, -6345.815, -6356.357, -6366.312, -6375.6669999999995, -6384.4130000000005, -6392.539000000001, -6400.035, -6406.887, -6413.085999999999, -6418.618, -6423.473000000001, -6427.637, -6431.098000000001, -6433.840999999999, -6435.855, -6437.124, -6437.634, -6437.37, -6436.316999999999, -6434.46, -6431.781999999999, -6428.266, -6423.896, -6418.653, -6412.52, -6405.478, -6397.508000000001, -6388.588000000001, -6378.7, -6367.821, -6355.93, -6343.003000000001, -6329.018, -6313.9490000000005, -6297.774, -6280.464, -6261.993, -6242.335, -6221.4580000000005, -6199.335, -6175.934, -6151.223000000001, -6125.169, -6097.736999999999, -6068.893, -6038.598000000001, -6006.815, -5973.503000000001, -5938.62, -5902.125, -5863.972, -5824.115, -5782.504, -5739.09, -5693.82, -5646.639, -5597.491, -5546.316999999999, -5493.054, -5437.638000000001, -5380.003000000001, -5320.08, -5257.795, -5193.073, -5125.835, -5056.0, -4983.483, -4908.193, -4830.043, -4748.934, -4664.768, -4577.443, -4486.854, -4392.891, -4295.443, -4194.395, -4089.631, -3981.0290000000005, -3868.472, -3751.8379999999997, -3631.008, -3505.864, -3376.2909999999997, -3242.1820000000002, -3103.434, -2959.961, -2811.685, -2658.551, -2500.5229999999997, -2337.596, -2169.794, -1997.185, -1819.878, -1638.0379999999998, -1451.885, -1261.702, -1067.8419999999999, -870.7230000000001, -670.8380000000001, -468.744, -265.061, -60.458, 144.35299999999998, 348.639, 551.658, 752.68, 951.0010000000001, 1145.9660000000001, 1336.974, 1523.4920000000002, 1705.066, 1881.315, 2051.9410000000003, 2216.721, 2375.4970000000003, 2528.1820000000002, 2674.741, 2815.188, 2949.5809999999997, 3078.008, 3200.587, 3317.4559999999997, 3428.77, 3534.692, 3635.397, 3731.062, 3821.866, 3907.986, 3989.603, 4066.887, 4140.0109999999995, 4209.137, 4274.425, 4336.031, 4394.101, 4448.776, 4500.195, 4548.487, 4593.713, 4636.179, 4675.813, 4712.784000000001, 4747.195, 4779.145, 4808.728, 4836.032, 4861.142, 4884.14, 4905.103, 4924.104, 4941.215, 4956.5, 4970.025, 4981.852, 4992.038, 5000.638, 5007.707, 5013.293, 5017.448, 5020.218, 5021.646, 5021.776, 5020.649, 5018.303, 5014.777, 5010.106, 5004.325, 4997.469, 4989.567, 4980.653, 4970.753, 4959.899, 4948.115, 4935.43, 4921.8679999999995, 4907.454000000001, 4892.210999999999, 4876.162, 4859.329000000001, 4841.734, 4823.396, 4804.335999999999, 4784.572, 4764.122, 4743.005, 4721.2390000000005, 4698.838, 4675.82, 4652.201, 4627.995, 4603.217000000001, 4577.88, 4552.0, 4525.59, 4498.661, 4471.228, 4443.302, 4414.895, 4386.018, 4356.683, 4326.901, 4296.681, 4266.035, 4234.973, 4203.503, 4171.6359999999995, 4139.380999999999, 4106.746, 4073.742, 4040.375, 4006.6540000000005, 3972.5879999999997, 3938.184, 3903.4509999999996, 3868.3940000000002, 3833.0229999999997, 3797.343, 3761.363, 3725.0879999999997, 3688.526, 3651.683, 3614.565, 3577.179, 3539.53, 3501.6259999999997, 3463.47, 3425.07, 3386.43, 3347.5559999999996, 3308.454, 3269.1279999999997, 3229.5840000000003, 3189.827, 3149.862, 3109.6929999999998, 3069.325, 3028.763, 2988.012, 2947.075, 2905.9570000000003, 2864.663, 2823.197, 2781.562, 2739.764, 2697.805, 2655.69, 2613.422, 2571.006, 2528.445, 2485.742, 2442.902, 2399.928, 2356.823, 2313.59, 2270.234, 2226.757, 2183.163, 2139.4539999999997, 2095.635, 2051.7070000000003, 2007.675, 1963.5410000000002, 1919.308, 1874.979, 1830.557, 1786.045, 1741.445, 1696.761, 1651.995, 1607.15, 1562.2279999999998, 1517.233, 1472.1660000000002, 1427.03, 1381.828, 1336.5629999999999, 1291.236, 1245.851, 1200.4089999999999, 1154.913, 1109.366, 1063.769, 1018.1260000000001, 972.438, 926.707, 880.936, 835.128, 789.284, 743.4060000000001, 697.497, 651.558, 605.5930000000001, 559.602, 513.589, 467.55400000000003, 421.501, 375.431, 329.346, 283.249, 237.141, 191.024, 144.9, 98.771, 52.638999999999996, 6.507000000000001, -39.625, -85.75399999999999, -131.879, -177.997, -224.107, -270.20599999999996, -316.293, -362.36699999999996, -408.42400000000004, -454.465, -500.485, -546.485, -592.462, -638.413, -684.3389999999999, -730.2360000000001, -776.1030000000001, -821.938, -867.7389999999999, -913.505, -959.2339999999999, -1004.924, -1050.5739999999998, -1096.181, -1141.744, -1187.261, -1232.731, -1278.151, -1323.521, -1368.8370000000002, -1414.1, -1459.305, -1504.453, -1549.5420000000001, -1594.569, -1639.533, -1684.432, -1729.264, -1774.0279999999998, -1818.7220000000002, -1863.344, -1907.8929999999998, -1952.366, -1996.763, -2041.0810000000001, -2085.3179999999998, -2129.473, -2173.544, -2217.529, -2261.426, -2305.234, -2348.951, -2392.575, -2436.105, -2479.538, -2522.8720000000003, -2566.107, -2609.239, -2652.2670000000003, -2695.19, -2738.006, -2780.712, -2823.3070000000002, -2865.788, -2908.155, -2950.405, -2992.535, -3034.546, -3076.433, -3118.196, -3159.8320000000003, -3201.3390000000004, -3242.716, -3283.961, -3325.07, -3366.0440000000003, -3406.8779999999997, -3447.572, -3488.123, -3528.528, -3568.7870000000003, -3608.897, -3648.855, -3688.66, -3728.309, -3767.8, -3807.132, -3846.3, -3885.304, -3924.1409999999996, -3962.809, -4001.305, -4039.6279999999997, -4077.7729999999997, -4115.74, -4153.526, -4191.129, -4228.545, -4265.772, -4302.808, -4339.65, -4376.295999999999, -4412.7429999999995, -4448.988, -4485.029, -4520.862, -4556.486, -4591.897, -4627.092000000001, -4662.069, -4696.8240000000005, -4731.356, -4765.66, -4799.734, -4833.5740000000005, -4867.179, -4900.543, -4933.665, -4966.541, -4999.167, -5031.541, -5063.659000000001, -5095.517, -5127.113, -5158.442, -5189.501, -5220.286, -5250.794, -5281.021, -5310.963000000001, -5340.616, -5369.976, -5399.04, -5427.803000000001, -5456.26, -5484.409000000001, -5512.244000000001, -5539.762, -5566.956999999999, -5593.825, -5620.363, -5646.564, -5672.424, -5697.939, -5723.103, -5747.9130000000005, -5772.361, -5796.444, -5820.156, -5843.491999999999, -5866.445, -5889.0109999999995, -5911.184, -5932.9580000000005, -5954.326, -5975.284000000001, -5995.8240000000005, -6015.941, -6035.6269999999995, -6054.8769999999995, -6073.684, -6092.04, -6109.94, -6127.374, -6144.3369999999995, -6160.821, -6176.818, -6192.319, -6207.318, -6221.806, -6235.776, -6249.217, -6262.121, -6274.48, -6286.284000000001, -6297.524, -6308.19, -6318.272, -6327.76, -6336.643, -6344.911999999999, -6352.554, -6359.56, -6365.916, -6371.611, -6376.634, -6380.971, -6384.611, -6387.539000000001, -6389.743, -6391.2080000000005, -6391.92, -6391.8640000000005, -6391.026, -6389.388000000001, -6386.937, -6383.654, -6379.523, -6374.526, -6368.646, -6361.863, -6354.159000000001, -6345.513000000001, -6335.906, -6325.315, -6313.72, -6301.097, -6287.423000000001, -6272.673000000001, -6256.825, -6239.851, -6221.724, -6202.418000000001, -6181.904, -6160.151999999999, -6137.130999999999, -6112.809, -6087.154, -6060.130999999999, -6031.706, -6001.840999999999, -5970.4980000000005, -5937.637, -5903.215999999999, -5867.194, -5829.526, -5790.166, -5749.064, -5706.172, -5661.437, -5614.803000000001, -5566.215999999999, -5515.616999999999, -5462.944, -5408.132, -5351.116, -5291.826999999999, -5230.193, -5166.138, -5099.582, -5030.448, -4958.649, -4884.097, -4806.7, -4726.365, -4642.9929999999995, -4556.482, -4466.727, -4373.62, -4277.048, -4176.899, -4073.0559999999996, -3965.3979999999997, -3853.809, -3738.165, -3618.349, -3494.243, -3365.7309999999998, -3232.708, -3095.0690000000004, -2952.7270000000003, -2805.6040000000003, -2653.6440000000002, -2496.8089999999997, -2335.093, -2168.518, -1997.148, -1821.09, -1640.505, -1455.608, -1266.678, -1074.062, -878.175, -679.5010000000001, -478.593, -276.064, -72.578, 131.16, 334.41900000000004, 536.4630000000001, 736.564, 934.0219999999999, 1128.181, 1318.441, 1504.27, 1685.211, 1860.884, 2030.986, 2195.292, 2353.643, 2505.948, 2652.17, 2792.32, 2926.453, 3054.656, 3177.0440000000003, 3293.7509999999997, 3404.9320000000002, 3510.748, 3611.373, 3706.9790000000003, 3797.7459999999996, 3883.8509999999997, 3965.4709999999995, 4042.776, 4115.936, 4185.116, 4250.472, 4312.16, 4370.325, 4425.108, 4476.646, 4525.068, 4570.497, 4613.052, 4652.846, 4689.986, 4724.5740000000005, 4756.71, 4786.486, 4813.99, 4839.307, 4862.519, 4883.701, 4902.929, 4920.271, 4935.793, 4949.56, 4961.634, 4972.071, 4980.927, 4988.255999999999, 4994.107, 4998.53, 5001.571, 5003.275, 5003.684, 5002.838, 5000.778, 4997.539000000001, 4993.159000000001, 4987.6720000000005, 4981.111, 4973.508, 4964.894, 4955.298, 4944.748, 4933.272, 4920.896, 4907.645, 4893.543, 4878.6140000000005, 4862.880999999999, 4846.366, 4829.09, 4811.072, 4792.334, 4772.892, 4752.767, 4731.976, 4710.535, 4688.462, 4665.772, 4642.482, 4618.606, 4594.159000000001, 4569.155, 4543.607, 4517.529, 4490.934, 4463.835, 4436.244000000001, 4408.1720000000005, 4379.630999999999, 4350.6320000000005, 4321.187, 4291.304, 4260.995, 4230.27, 4199.139, 4167.61, 4135.693, 4103.397, 4070.7309999999998, 4037.703, 4004.322, 3970.594, 3936.53, 3902.135, 3867.4179999999997, 3832.385, 3797.045, 3761.403, 3725.467, 3689.244, 3652.739, 3615.96, 3578.9120000000003, 3541.6020000000003, 3504.035, 3466.217, 3428.1540000000005, 3389.8509999999997, 3351.3140000000003, 3312.548, 3273.559, 3234.3509999999997, 3194.929, 3155.2990000000004, 3115.465, 3075.4320000000002, 3035.204, 2994.7859999999996, 2954.1820000000002, 2913.397, 2872.4359999999997, 2831.301, 2789.998, 2748.53, 2706.901, 2665.116, 2623.177, 2581.09, 2538.857, 2496.482, 2453.969, 2411.321, 2368.541, 2325.634, 2282.6020000000003, 2239.449, 2196.178, 2152.792, 2109.294, 2065.688, 2021.976, 1978.162, 1934.2479999999998, 1890.237, 1846.1329999999998, 1801.9370000000001, 1757.654, 1713.285, 1668.8339999999998, 1624.3020000000001, 1579.693, 1535.01, 1490.254, 1445.4289999999999, 1400.537, 1355.5810000000001, 1310.562, 1265.484, 1220.348, 1175.1580000000001, 1129.915, 1084.623, 1039.282, 993.8960000000001, 948.466, 902.9960000000001, 857.4860000000001, 811.94, 766.36, 720.747, 675.1039999999999, 629.433, 583.735, 538.014, 492.27099999999996, 446.509, 400.728, 354.93199999999996, 309.122, 263.3, 217.468, 171.62900000000002, 125.78299999999999, 79.934, 34.082, -11.77, -57.62, -103.46700000000001, -149.308, -195.142, -240.967, -286.781, -332.582, -378.369, -424.139, -469.89099999999996, -515.623, -561.3330000000001, -607.02, -652.681, -698.315, -743.921, -789.495, -835.038, -880.546, -926.018, -971.453, -1016.8480000000001, -1062.202, -1107.514, -1152.78, -1198.001, -1243.174, -1288.296, -1333.368, -1378.386, -1423.35, -1468.256, -1513.105, -1557.8929999999998, -1602.62, -1647.283, -1691.881, -1736.412, -1780.875, -1825.267, -1869.5870000000002, -1913.8329999999999, -1958.004, -2002.0970000000002, -2046.111, -2090.045, -2133.896, -2177.663, -2221.343, -2264.936, -2308.439, -2351.851, -2395.169, -2438.393, -2481.52, -2524.548, -2567.476, -2610.301, -2653.0229999999997, -2695.638, -2738.1459999999997, -2780.545, -2822.8309999999997, -2865.005, -2907.063, -2949.0040000000004, -2990.8259999999996, -3032.527, -3074.105, -3115.558, -3156.885, -3198.0820000000003, -3239.1490000000003, -3280.083, -3320.882, -3361.5440000000003, -3402.067, -3442.45, -3482.6890000000003, -3522.783, -3562.7290000000003, -3602.526, -3642.172, -3681.664, -3720.9990000000003, -3760.177, -3799.1940000000004, -3838.0490000000004, -3876.738, -3915.261, -3953.613, -3991.7940000000003, -4029.8, -4067.63, -4105.281, -4142.75, -4180.035, -4217.133, -4254.043, -4290.76, -4327.284000000001, -4363.61, -4399.737, -4435.662, -4471.3820000000005, -4506.895, -4542.196, -4577.285, -4612.157999999999, -4646.811, -4681.2429999999995, -4715.45, -4749.43, -4783.178, -4816.692, -4849.97, -4883.0070000000005, -4915.8, -4948.347, -4980.643, -5012.687, -5044.473, -5075.999, -5107.262, -5138.2570000000005, -5168.981, -5199.43, -5229.601, -5259.49, -5289.093000000001, -5318.406, -5347.4259999999995, -5376.147, -5404.566, -5432.679, -5460.482, -5487.97, -5515.139, -5541.984, -5568.501, -5594.685, -5620.531, -5646.035, -5671.191999999999, -5695.9980000000005, -5720.445, -5744.531, -5768.249, -5791.594, -5814.56, -5837.143, -5859.335999999999, -5881.133000000001, -5902.529, -5923.517, -5944.092, -5964.246999999999, -5983.976, -6003.272, -6022.129, -6040.54, -6058.496999999999, -6075.994000000001, -6093.023, -6109.576999999999, -6125.648, -6141.229, -6156.311, -6170.887, -6184.948, -6198.486, -6211.491999999999, -6223.956999999999, -6235.871, -6247.226, -6258.012, -6268.219, -6277.838000000001, -6286.856, -6295.265, -6303.053000000001, -6310.209, -6316.721, -6322.578, -6327.768, -6332.278, -6336.096, -6339.209, -6341.603, -6343.264, -6344.178000000001, -6344.331, -6343.706999999999, -6342.291, -6340.066999999999, -6337.019, -6333.129, -6328.38, -6322.754, -6316.234, -6308.799, -6300.43, -6291.107, -6280.808000000001, -6269.513000000001, -6257.196999999999, -6243.84, -6229.415, -6213.899, -6197.266, -6179.49, -6160.544, -6140.398, -6119.024, -6096.39, -6072.465999999999, -6047.218000000001, -6020.6140000000005, -5992.616999999999, -5963.191, -5932.298000000001, -5899.898, -5865.951999999999, -5830.414000000001, -5793.243, -5754.392, -5713.813, -5671.456, -5627.269, -5581.198, -5533.188, -5483.18, -5431.113, -5376.923000000001, -5320.544, -5261.908, -5200.943, -5137.575, -5071.724, -5003.312, -4932.253, -4858.460999999999, -4781.843, -4702.307, -4619.755, -4534.084, -4445.191, -4352.968, -4257.303, -4158.084, -4055.1940000000004, -3948.513, -3837.926, -3723.309, -3604.5440000000003, -3481.514, -3354.1040000000003, -3222.2070000000003, -3085.719, -2944.552, -2798.6279999999997, -2647.889, -2492.297, -2331.842, -2166.545, -1996.467, -1821.714, -1642.4389999999999, -1458.856, -1271.239, -1079.9289999999999, -885.335, -687.936, -488.277, -286.965, -84.661, 117.93799999999999, 320.106, 521.11, 720.2260000000001, 916.757, 1110.048, 1299.5, 1484.5810000000001, 1664.8310000000001, 1839.871, 2009.395, 2173.175, 2331.052, 2482.93, 2628.768, 2768.578, 2902.4109999999996, 3030.349, 3152.508, 3269.018, 3380.033, 3485.71, 3586.223, 3681.742, 3772.446, 3858.509, 3940.107, 4017.41, 4090.586, 4159.799, 4225.204000000001, 4286.956, 4345.1990000000005, 4400.0740000000005, 4451.717000000001, 4500.255, 4545.812, 4588.505999999999, 4628.4490000000005, 4665.748, 4700.504, 4732.816, 4762.777, 4790.474, 4815.992, 4839.411, 4860.809, 4880.2570000000005, 4897.826, 4913.582, 4927.588, 4939.906, 4950.592000000001, 4959.7029999999995, 4967.291, 4973.406, 4978.097, 4981.41, 4983.39, 4984.0779999999995, 4983.516, 4981.742, 4978.794, 4974.707, 4969.516, 4963.254, 4955.9529999999995, 4947.643, 4938.354, 4928.1140000000005, 4916.9490000000005, 4904.887, 4891.952, 4878.169, 4863.56, 4848.149, 4831.957, 4815.005999999999, 4797.316, 4778.905, 4759.794, 4740.0, 4719.541, 4698.434, 4676.696, 4654.343, 4631.39, 4607.852, 4583.745, 4559.081, 4533.874, 4508.138, 4481.8859999999995, 4455.130999999999, 4427.883, 4400.156, 4371.960999999999, 4343.308, 4314.209, 4284.673, 4254.712, 4224.335, 4193.552, 4162.372, 4130.804, 4098.857, 4066.5409999999997, 4033.862, 4000.8309999999997, 3967.454, 3933.739, 3899.695, 3865.328, 3830.647, 3795.657, 3760.366, 3724.78, 3688.907, 3652.7529999999997, 3616.324, 3579.627, 3542.667, 3505.45, 3467.982, 3430.268, 3392.315, 3354.1279999999997, 3315.711, 3277.071, 3238.211, 3199.138, 3159.8559999999998, 3120.369, 3080.683, 3040.802, 3000.7309999999998, 2960.474, 2920.035, 2879.4190000000003, 2838.6290000000004, 2797.67, 2756.546, 2715.261, 2673.8190000000004, 2632.223, 2590.478, 2548.587, 2506.553, 2464.38, 2422.072, 2379.632, 2337.064, 2294.37, 2251.554, 2208.62, 2165.571, 2122.409, 2079.137, 2035.76, 1992.279, 1948.6979999999999, 1905.02, 1861.247, 1817.3829999999998, 1773.43, 1729.39, 1685.267, 1641.0639999999999, 1596.7820000000002, 1552.425, 1507.995, 1463.495, 1418.9270000000001, 1374.293, 1329.5970000000002, 1284.84, 1240.025, 1195.155, 1150.231, 1105.256, 1060.232, 1015.1619999999999, 970.048, 924.8919999999999, 879.696, 834.4630000000001, 789.194, 743.8919999999999, 698.558, 653.196, 607.807, 562.393, 516.956, 471.49800000000005, 426.02099999999996, 380.528, 335.019, 289.499, 243.967, 198.426, 152.878, 107.325, 61.769, 16.211, -29.345, -74.9, -120.45, -165.99400000000003, -211.53, -257.057, -302.57099999999997, -348.07300000000004, -393.559, -439.028, -484.478, -529.9069999999999, -575.314, -620.697, -666.054, -711.3839999999999, -756.684, -801.953, -847.189, -892.39, -937.555, -982.682, -1027.769, -1072.815, -1117.817, -1162.775, -1207.685, -1252.548, -1297.36, -1342.12, -1386.8270000000002, -1431.479, -1476.0739999999998, -1520.61, -1565.086, -1609.499, -1653.849, -1698.134, -1742.351, -1786.499, -1830.5770000000002, -1874.582, -1918.513, -1962.369, -2006.146, -2049.845, -2093.462, -2136.9970000000003, -2180.447, -2223.811, -2267.087, -2310.2729999999997, -2353.367, -2396.368, -2439.274, -2482.083, -2524.7929999999997, -2567.402, -2609.909, -2652.312, -2694.6090000000004, -2736.797, -2778.8759999999997, -2820.844, -2862.698, -2904.4359999999997, -2946.0570000000002, -2987.559, -3028.94, -3070.197, -3111.33, -3152.335, -3193.212, -3233.9570000000003, -3274.5690000000004, -3315.047, -3355.387, -3395.5890000000004, -3435.6490000000003, -3475.565, -3515.337, -3554.961, -3594.435, -3633.757, -3672.926, -3711.938, -3750.792, -3789.485, -3828.015, -3866.38, -3904.578, -3942.605, -3980.46, -4018.1409999999996, -4055.645, -4092.969, -4130.112, -4167.07, -4203.842000000001, -4240.424, -4276.814, -4313.009, -4349.008, -4384.806, -4420.402, -4455.792, -4490.975, -4525.947, -4560.705, -4595.246, -4629.568, -4663.668, -4697.542, -4731.188, -4764.603, -4797.782999999999, -4830.725, -4863.427, -4895.884, -4928.094, -4960.053, -4991.758, -5023.206, -5054.392, -5085.314, -5115.968, -5146.35, -5176.456, -5206.284000000001, -5235.8279999999995, -5265.085, -5294.0509999999995, -5322.723000000001, -5351.095, -5379.165, -5406.927, -5434.3769999999995, -5461.5109999999995, -5488.325, -5514.815, -5540.974, -5566.799, -5592.286, -5617.429, -5642.222, -5666.6630000000005, -5690.744000000001, -5714.460999999999, -5737.809, -5760.781999999999, -5783.374, -5805.58, -5827.395, -5848.812, -5869.826, -5890.43, -5910.618, -5930.383000000001, -5949.721, -5968.621999999999, -5987.081999999999, -6005.092, -6022.646, -6039.736999999999, -6056.357, -6072.499, -6088.155, -6103.316999999999, -6117.977, -6132.1269999999995, -6145.758000000001, -6158.861999999999, -6171.43, -6183.451999999999, -6194.92, -6205.8240000000005, -6216.154, -6225.9, -6235.052, -6243.599, -6251.531, -6258.835999999999, -6265.503000000001, -6271.521, -6276.878000000001, -6281.561, -6285.557, -6288.854, -6291.439, -6293.297, -6294.414000000001, -6294.776, -6294.369000000001, -6293.175, -6291.181, -6288.369000000001, -6284.723000000001, -6280.225, -6274.858, -6268.603, -6261.441, -6253.352, -6244.318, -6234.316, -6223.325, -6211.323, -6198.286999999999, -6184.193, -6169.017, -6152.732, -6135.314, -6116.734, -6096.965, -6075.977, -6053.7390000000005, -6030.222, -6005.392, -5979.215, -5951.656999999999, -5922.682, -5892.25, -5860.325, -5826.8640000000005, -5791.825, -5755.165, -5716.8369999999995, -5676.795, -5634.9890000000005, -5591.366999999999, -5545.876, -5498.46, -5449.062, -5397.619000000001, -5344.07, -5288.349, -5230.387, -5170.1140000000005, -5107.455, -5042.333, -4974.666, -4904.374, -4831.3679999999995, -4755.557, -4676.849, -4595.144, -4510.345, -4422.346, -4331.039000000001, -4236.316, -4138.061, -4036.1609999999996, -3930.4970000000003, -3820.95, -3707.3990000000003, -3589.728, -3467.8179999999998, -3341.555, -3210.83, -3075.5429999999997, -2935.6, -2790.927, -2641.462, -2487.167, -2328.029, -2164.0679999999998, -1995.3429999999998, -1821.953, -1644.0520000000001, -1461.8470000000002, -1275.607, -1085.6680000000001, -892.433, -696.3739999999999, -498.032, -298.006, -96.949, 104.445, 305.457, 505.358, 703.428, 898.972, 1091.337, 1279.923, 1464.201, 1643.71, 1818.066, 1986.965, 2150.175, 2307.533, 2458.942, 2604.359, 2743.792, 2877.288, 3004.929, 3126.827, 3243.112, 3353.93, 3459.4440000000004, 3559.8190000000004, 3655.228, 3745.8459999999995, 3831.847, 3913.402, 3990.685, 4063.861, 4133.089, 4198.528, 4260.33, 4318.638, 4373.593, 4425.3279999999995, 4473.972, 4519.673, 4562.471, 4602.554, 4640.003, 4674.920999999999, 4707.404, 4737.544, 4765.429, 4791.143, 4814.766, 4836.374, 4856.041, 4873.835, 4889.822, 4904.066, 4916.627, 4927.563, 4936.928, 4944.774, 4951.154, 4956.1140000000005, 4959.701, 4961.958, 4962.928, 4962.652, 4961.167, 4958.512, 4954.722, 4949.831, 4943.873, 4936.877, 4928.876, 4919.899, 4909.973, 4899.125, 4887.383, 4874.77, 4861.31, 4847.028, 4831.946, 4816.085, 4799.465, 4782.109, 4764.034000000001, 4745.26, 4725.805, 4705.687, 4684.9220000000005, 4663.527, 4641.518, 4618.91, 4595.719, 4571.96, 4547.645, 4522.789000000001, 4497.405, 4471.505, 4445.103, 4418.209, 4390.837, 4362.997, 4334.7, 4305.957, 4276.779, 4247.1759999999995, 4217.157, 4186.733, 4155.912, 4124.704000000001, 4093.118, 4061.1620000000003, 4028.844, 3996.1740000000004, 3963.158, 3929.8059999999996, 3896.123, 3862.119, 3827.7990000000004, 3793.172, 3758.244, 3723.0209999999997, 3687.511, 3651.72, 3615.653, 3579.3179999999998, 3542.7209999999995, 3505.866, 3468.761, 3431.409, 3393.8179999999998, 3355.992, 3317.937, 3279.658, 3241.16, 3202.448, 3163.527, 3124.401, 3085.075, 3045.555, 3005.843, 2965.945, 2925.865, 2885.6079999999997, 2845.176, 2804.5759999999996, 2763.809, 2722.881, 2681.796, 2640.5559999999996, 2599.167, 2557.63, 2515.951, 2474.133, 2432.178, 2390.092, 2347.876, 2305.534, 2263.07, 2220.487, 2177.7870000000003, 2134.975, 2092.053, 2049.024, 2005.891, 1962.6570000000002, 1919.325, 1875.898, 1832.378, 1788.769, 1745.0729999999999, 1701.293, 1657.432, 1613.4920000000002, 1569.475, 1525.385, 1481.223, 1436.994, 1392.6979999999999, 1348.338, 1303.917, 1259.437, 1214.9, 1170.31, 1125.667, 1080.975, 1036.236, 991.451, 946.6239999999999, 901.7560000000001, 856.85, 811.9069999999999, 766.93, 721.921, 676.8810000000001, 631.814, 586.721, 541.605, 496.466, 451.30800000000005, 406.131, 360.939, 315.733, 270.51599999999996, 225.28799999999998, 180.05200000000002, 134.81, 89.56299999999999, 44.315, -0.935, -46.183, -91.427, -136.667, -181.9, -227.12400000000002, -272.33799999999997, -317.54, -362.727, -407.899, -453.05199999999996, -498.18699999999995, -543.3, -588.391, -633.456, -678.4960000000001, -723.507, -768.488, -813.438, -858.3539999999999, -903.235, -948.08, -992.885, -1037.651, -1082.375, -1127.055, -1171.69, -1216.277, -1260.816, -1305.305, -1349.741, -1394.124, -1438.451, -1482.721, -1526.932, -1571.082, -1615.17, -1659.194, -1703.152, -1747.0420000000001, -1790.864, -1834.614, -1878.2920000000001, -1921.896, -1965.424, -2008.8729999999998, -2052.244, -2095.533, -2138.739, -2181.86, -2224.895, -2267.842, -2310.699, -2353.464, -2396.135, -2438.7110000000002, -2481.19, -2523.57, -2565.85, -2608.026, -2650.099, -2692.065, -2733.923, -2775.671, -2817.308, -2858.83, -2900.238, -2941.527, -2982.698, -3023.7470000000003, -3064.673, -3105.473, -3146.147, -3186.691, -3227.105, -3267.385, -3307.53, -3347.538, -3387.406, -3427.134, -3466.717, -3506.156, -3545.446, -3584.587, -3623.5759999999996, -3662.4109999999996, -3701.09, -3739.6090000000004, -3777.968, -3816.164, -3854.195, -3892.0570000000002, -3929.75, -3967.27, -4004.616, -4041.785, -4078.7729999999997, -4115.58, -4152.202, -4188.637, -4224.883, -4260.936, -4296.794, -4332.455, -4367.916, -4403.174, -4438.226, -4473.07, -4507.7029999999995, -4542.121, -4576.323, -4610.305, -4644.064, -4677.597, -4710.902, -4743.974, -4776.812, -4809.411, -4841.769, -4873.8820000000005, -4905.748, -4937.362, -4968.721, -4999.822, -5030.661, -5061.235, -5091.541, -5121.573, -5151.33, -5180.806, -5209.999, -5238.904, -5267.516, -5295.8330000000005, -5323.851, -5351.563, -5378.968000000001, -5406.06, -5432.835, -5459.2880000000005, -5485.415, -5511.210999999999, -5536.672, -5561.7919999999995, -5586.566999999999, -5610.991999999999, -5635.062, -5658.772, -5682.115, -5705.088000000001, -5727.683000000001, -5749.896, -5771.722, -5793.154, -5814.187, -5834.813, -5855.028, -5874.825, -5894.196999999999, -5913.138000000001, -5931.641, -5949.7, -5967.306, -5984.454000000001, -6001.135, -6017.343000000001, -6033.069, -6048.306, -6063.045999999999, -6077.28, -6091.0, -6104.198, -6116.865, -6128.991999999999, -6140.569, -6151.588000000001, -6162.036999999999, -6171.909000000001, -6181.191, -6189.875, -6197.948, -6205.401, -6212.222, -6218.399, -6223.920999999999, -6228.775, -6232.9490000000005, -6236.429, -6239.204000000001, -6241.258000000001, -6242.578, -6243.15, -6242.959, -6241.9890000000005, -6240.225, -6237.651, -6234.25, -6230.004, -6224.897, -6218.91, -6212.023, -6204.218000000001, -6195.475, -6185.773, -6175.09, -6163.405, -6150.695, -6136.936, -6122.103, -6106.173000000001, -6089.116999999999, -6070.91, -6051.524, -6030.928000000001, -6009.094, -5985.991, -5961.585999999999, -5935.845, -5908.735, -5880.218000000001, -5850.258000000001, -5818.816, -5785.851, -5751.321, -5715.183000000001, -5677.39, -5637.898, -5596.655, -5553.611999999999, -5508.714, -5461.906999999999, -5413.132, -5362.33, -5309.437, -5254.39, -5197.12, -5137.557, -5075.626, -5011.251, -4944.352, -4874.846, -4802.647, -4727.666, -4649.808, -4568.977, -4485.073, -4397.994000000001, -4307.6320000000005, -4213.877, -4116.616, -4015.735, -3911.117, -3802.6440000000002, -3690.1929999999998, -3573.65, -3452.8959999999997, -3327.817, -3198.303, -3064.2540000000004, -2925.579, -2782.197, -2634.051, -2481.098, -2323.324, -2160.749, -1993.4260000000002, -1821.453, -1644.979, -1464.207, -1279.402, -1090.891, -899.075, -704.419, -507.45599999999996, -308.779, -109.035, 91.089, 290.878, 489.61, 686.566, 881.057, 1072.43, 1260.086, 1443.497, 1622.201, 1795.8129999999999, 1964.027, 2126.609, 2283.393, 2434.28, 2579.224, 2718.2290000000003, 2851.342, 2978.6409999999996, 3100.235, 3216.252, 3326.836, 3432.1479999999997, 3532.35, 3627.615, 3718.115, 3804.0229999999997, 3885.509, 3962.744, 4035.8920000000003, 4105.113, 4170.563, 4232.392, 4290.745, 4345.7609999999995, 4397.57, 4446.303, 4492.081, 4535.019, 4575.23, 4612.817, 4647.884, 4680.526, 4710.835, 4738.898, 4764.8, 4788.619000000001, 4810.43, 4830.308, 4848.321, 4864.534000000001, 4879.0109999999995, 4891.811, 4902.992, 4912.608, 4920.710999999999, 4927.353, 4932.58, 4936.439, 4938.974, 4940.226, 4940.235, 4939.041, 4936.68, 4933.188, 4928.599, 4922.945, 4916.259, 4908.569, 4899.906, 4890.298, 4879.772, 4868.353, 4856.066, 4842.935, 4828.984, 4814.235, 4798.709, 4782.428, 4765.411, 4747.679, 4729.248, 4710.139, 4690.3679999999995, 4669.952, 4648.907, 4627.25, 4604.996, 4582.16, 4558.755999999999, 4534.799, 4510.302, 4485.277, 4459.738, 4433.698, 4407.167, 4380.159000000001, 4352.683, 4324.752, 4296.376, 4267.565, 4238.329000000001, 4208.679, 4178.624, 4148.173, 4117.335, 4086.119, 4054.534, 4022.5890000000004, 3990.29, 3957.647, 3924.667, 3891.3579999999997, 3857.7270000000003, 3823.781, 3789.528, 3754.973, 3720.125, 3684.989, 3649.572, 3613.881, 3577.92, 3541.697, 3505.217, 3468.486, 3431.51, 3394.2929999999997, 3356.842, 3319.1609999999996, 3281.257, 3243.132, 3204.7940000000003, 3166.2470000000003, 3127.494, 3088.542, 3049.395, 3010.0559999999996, 2970.531, 2930.823, 2890.937, 2850.8779999999997, 2810.6479999999997, 2770.2529999999997, 2729.695, 2688.98, 2648.11, 2607.089, 2565.922, 2524.611, 2483.161, 2441.574, 2399.854, 2358.005, 2316.029, 2273.93, 2231.712, 2189.376, 2146.928, 2104.369, 2061.702, 2018.931, 1976.058, 1933.0870000000002, 1890.019, 1846.859, 1803.609, 1760.27, 1716.848, 1673.342, 1629.7579999999998, 1586.096, 1542.36, 1498.5520000000001, 1454.675, 1410.731, 1366.7220000000002, 1322.651, 1278.521, 1234.333, 1190.09, 1145.795, 1101.4489999999998, 1057.0539999999999, 1012.6139999999999, 968.13, 923.605, 879.04, 834.438, 789.8, 745.13, 700.428, 655.698, 610.941, 566.159, 521.355, 476.529, 431.685, 386.824, 341.94800000000004, 297.058, 252.158, 207.24900000000002, 162.333, 117.411, 72.485, 27.558000000000003, -17.368, -62.293, -107.214, -152.129, -197.03599999999997, -241.935, -286.822, -331.69599999999997, -376.555, -421.398, -466.223, -511.028, -555.811, -600.571, -645.306, -690.0139999999999, -734.693, -779.341, -823.9580000000001, -868.541, -913.0880000000001, -957.5989999999999, -1002.07, -1046.501, -1090.889, -1135.234, -1179.532, -1223.7839999999999, -1267.986, -1312.138, -1356.237, -1400.2820000000002, -1444.271, -1488.203, -1532.075, -1575.8870000000002, -1619.636, -1663.3210000000001, -1706.94, -1750.491, -1793.973, -1837.3829999999998, -1880.721, -1923.985, -1967.172, -2010.281, -2053.311, -2096.259, -2139.125, -2181.905, -2224.599, -2267.2039999999997, -2309.719, -2352.143, -2394.472, -2436.7070000000003, -2478.844, -2520.882, -2562.819, -2604.653, -2646.384, -2688.007, -2729.5229999999997, -2770.929, -2812.223, -2853.403, -2894.467, -2935.414, -2976.242, -3016.948, -3057.531, -3097.988, -3138.3190000000004, -3178.52, -3218.59, -3258.527, -3298.329, -3337.993, -3377.518, -3416.902, -3456.1420000000003, -3495.237, -3534.184, -3572.9809999999998, -3611.6259999999997, -3650.116, -3688.4509999999996, -3726.6259999999997, -3764.6409999999996, -3802.492, -3840.178, -3877.696, -3915.0440000000003, -3952.22, -3989.2209999999995, -4026.0440000000003, -4062.688, -4099.149, -4135.4259999999995, -4171.515, -4207.414000000001, -4243.121, -4278.633, -4313.948, -4349.062, -4383.972, -4418.677, -4453.174, -4487.459, -4521.529, -4555.383, -4589.016, -4622.4259999999995, -4655.61, -4688.564, -4721.287, -4753.774, -4786.022, -4818.029, -4849.79, -4881.303, -4912.564, -4943.57, -4974.317, -5004.802, -5035.021, -5064.971, -5094.647, -5124.0470000000005, -5153.165, -5181.999, -5210.544, -5238.7970000000005, -5266.753000000001, -5294.408, -5321.759, -5348.799, -5375.526999999999, -5401.936, -5428.022, -5453.781, -5479.2080000000005, -5504.299, -5529.047, -5553.45, -5577.5, -5601.195, -5624.526999999999, -5647.491999999999, -5670.0830000000005, -5692.297, -5714.1269999999995, -5735.566999999999, -5756.611999999999, -5777.255, -5797.491, -5817.313, -5836.714, -5855.688, -5874.229, -5892.33, -5909.984, -5927.183000000001, -5943.92, -5960.189, -5975.98, -5991.2880000000005, -6006.103, -6020.4169999999995, -6034.223000000001, -6047.5109999999995, -6060.274, -6072.501, -6084.184, -6095.314, -6105.880999999999, -6115.874, -6125.285, -6134.102, -6142.315, -6149.9130000000005, -6156.885, -6163.22, -6168.906, -6173.93, -6178.28, -6181.943, -6184.906999999999, -6187.156999999999, -6188.68, -6189.4619999999995, -6189.488, -6188.741999999999, -6187.209, -6184.874, -6181.719, -6177.727, -6172.882, -6167.164000000001, -6160.556, -6153.036999999999, -6144.588000000001, -6135.189, -6124.819, -6113.455, -6101.075, -6087.655, -6073.172, -6057.6, -6040.9130000000005, -6023.085, -6004.0869999999995, -5983.892, -5962.469, -5939.786, -5915.814, -5890.518, -5863.8640000000005, -5835.816, -5806.3369999999995, -5775.388000000001, -5742.93, -5708.92, -5673.316, -5636.071, -5597.14, -5556.474, -5514.023, -5469.733, -5423.549, -5375.414000000001, -5325.269, -5273.05, -5218.695, -5162.135, -5103.3, -5042.117, -4978.51, -4912.399, -4843.702, -4772.334, -4698.204000000001, -4621.222, -4541.29, -4458.309, -4372.1759999999995, -4282.787, -4190.03, -4093.7940000000003, -3993.965, -3890.426, -3783.059, -3671.745, -3556.366, -3436.8059999999996, -3312.949, -3184.687, -3051.92, -2914.555, -2772.512, -2625.73, -2474.169, -2317.81, -2156.6710000000003, -1990.8039999999999, -1820.3029999999999, -1645.3129999999999, -1466.0320000000002, -1282.72, -1095.701, -905.367, -712.177, -516.658, -319.39599999999996, -121.031, 77.756, 276.256, 473.75, 669.528, 862.8989999999999, 1053.215, 1239.879, 1422.361, 1600.1989999999998, 1773.009, 1940.481, 2102.38, 2258.5370000000003, 2408.851, 2553.2729999999997, 2691.805, 2824.49, 2951.4040000000005, 3072.6540000000005, 3188.364, 3298.679, 3403.7529999999997, 3503.7509999999997, 3598.84, 3689.1929999999998, 3774.98, 3856.37, 3933.532, 4006.63, 4075.821, 4141.2609999999995, 4203.099, 4261.478, 4316.536, 4368.405, 4417.212, 4463.0779999999995, 4506.1179999999995, 4546.442, 4584.156, 4619.361, 4652.153, 4682.622, 4710.855, 4736.937, 4760.944, 4782.9529999999995, 4803.037, 4821.264, 4837.6990000000005, 4852.405, 4865.441, 4876.8640000000005, 4886.729, 4895.087, 4901.99, 4907.484, 4911.615, 4914.4259999999995, 4915.96, 4916.255999999999, 4915.354, 4913.288, 4910.096, 4905.811, 4900.465, 4894.090999999999, 4886.715999999999, 4878.372, 4869.085999999999, 4858.884, 4847.793, 4835.837, 4823.04, 4809.4259999999995, 4795.016, 4779.832, 4763.894, 4747.224, 4729.839, 4711.76, 4693.002, 4673.585999999999, 4653.526, 4632.84, 4611.543, 4589.65, 4567.177, 4544.138, 4520.545999999999, 4496.416, 4471.76, 4446.590999999999, 4420.920999999999, 4394.763, 4368.128, 4341.027, 4313.471, 4285.471, 4257.037, 4228.179, 4198.907999999999, 4169.232, 4139.161, 4108.704000000001, 4077.87, 4046.667, 4015.1040000000003, 3983.1890000000003, 3950.929, 3918.333, 3885.409, 3852.1620000000003, 3818.6020000000003, 3784.7340000000004, 3750.565, 3716.103, 3681.353, 3646.323, 3611.018, 3575.4440000000004, 3539.6079999999997, 3503.515, 3467.171, 3430.5820000000003, 3393.7529999999997, 3356.6890000000003, 3319.395, 3281.877, 3244.14, 3206.1890000000003, 3168.028, 3129.6620000000003, 3091.0959999999995, 3052.335, 3013.382, 2974.243, 2934.921, 2895.42, 2855.7459999999996, 2815.901, 2775.89, 2735.717, 2695.385, 2654.8979999999997, 2614.261, 2573.476, 2532.548, 2491.479, 2450.2729999999997, 2408.9339999999997, 2367.465, 2325.869, 2284.15, 2242.31, 2200.353, 2158.282, 2116.1, 2073.81, 2031.415, 1988.918, 1946.3210000000001, 1903.628, 1860.8410000000001, 1817.964, 1774.9979999999998, 1731.9460000000001, 1688.8120000000001, 1645.5970000000002, 1602.305, 1558.9379999999999, 1515.4979999999998, 1471.9879999999998, 1428.41, 1384.767, 1341.06, 1297.2939999999999, 1253.469, 1209.589, 1165.655, 1121.6689999999999, 1077.635, 1033.5539999999999, 989.428, 945.2589999999999, 901.051, 856.804, 812.5210000000001, 768.204, 723.855, 679.4760000000001, 635.07, 590.638, 546.182, 501.704, 457.20599999999996, 412.69, 368.159, 323.613, 279.056, 234.488, 189.912, 145.329, 100.742, 56.152, 11.561, -33.029, -77.616, -122.199, -166.775, -211.343, -255.90099999999998, -300.447, -344.98, -389.49800000000005, -433.99800000000005, -478.48, -522.942, -567.381, -611.7959999999999, -656.186, -700.548, -744.882, -789.184, -833.454, -877.69, -921.89, -966.053, -1010.176, -1054.258, -1098.298, -1142.2930000000001, -1186.243, -1230.145, -1273.997, -1317.799, -1361.547, -1405.2420000000002, -1448.88, -1492.461, -1535.9820000000002, -1579.442, -1622.84, -1666.172, -1709.4389999999999, -1752.638, -1795.7679999999998, -1838.826, -1881.8110000000001, -1924.7220000000002, -1967.556, -2010.3129999999999, -2052.989, -2095.584, -2138.096, -2180.5229999999997, -2222.863, -2265.115, -2307.277, -2349.346, -2391.322, -2433.203, -2474.986, -2516.67, -2558.254, -2599.734, -2641.11, -2682.38, -2723.542, -2764.594, -2805.533, -2846.3590000000004, -2887.07, -2927.663, -2968.136, -3008.488, -3048.717, -3088.82, -3128.797, -3168.6440000000002, -3208.36, -3247.9429999999998, -3287.39, -3326.7, -3365.8709999999996, -3404.901, -3443.7870000000003, -3482.528, -3521.12, -3559.563, -3597.8540000000003, -3635.99, -3673.97, -3711.792, -3749.452, -3786.949, -3824.281, -3861.445, -3898.438, -3935.26, -3971.906, -4008.3740000000003, -4044.663, -4080.77, -4116.692, -4152.4259999999995, -4187.971, -4223.323, -4258.479, -4293.438, -4328.197, -4362.752, -4397.101, -4431.241, -4465.17, -4498.884, -4532.380999999999, -4565.657, -4598.71, -4631.536, -4664.133, -4696.498, -4728.627, -4760.517, -4792.164000000001, -4823.566, -4854.719, -4885.62, -4916.266, -4946.652, -4976.775, -5006.6320000000005, -5036.219, -5065.532999999999, -5094.568, -5123.323, -5151.792, -5179.971, -5207.858, -5235.447, -5262.734, -5289.715999999999, -5316.387, -5342.744000000001, -5368.781, -5394.495, -5419.880999999999, -5444.934, -5469.649, -5494.021, -5518.045999999999, -5541.717, -5565.031, -5587.981, -5610.563, -5632.77, -5654.597, -5676.04, -5697.090999999999, -5717.744000000001, -5737.995, -5757.835999999999, -5777.26, -5796.263000000001, -5814.835999999999, -5832.974, -5850.67, -5867.915, -5884.704000000001, -5901.029, -5916.880999999999, -5932.255, -5947.141, -5961.531999999999, -5975.419, -5988.794, -6001.648, -6013.973000000001, -6025.759, -6036.9980000000005, -6047.679, -6057.7919999999995, -6067.329000000001, -6076.278, -6084.629, -6092.37, -6099.491999999999, -6105.984, -6111.831999999999, -6117.025, -6121.5509999999995, -6125.397, -6128.55, -6130.996999999999, -6132.723000000001, -6133.715, -6133.959, -6133.438, -6132.138000000001, -6130.044, -6127.137, -6123.401999999999, -6118.821, -6113.376, -6107.049, -6099.82, -6091.67, -6082.578, -6072.525, -6061.486999999999, -6049.441999999999, -6036.366999999999, -6022.2390000000005, -6007.031999999999, -5990.721, -5973.279, -5954.678000000001, -5934.89, -5913.8859999999995, -5891.634, -5868.104, -5843.263000000001, -5817.075, -5789.507, -5760.52, -5730.076, -5698.137, -5664.66, -5629.603, -5592.92, -5554.565, -5514.491999999999, -5472.648, -5428.982, -5383.438, -5335.960999999999, -5286.491, -5234.965999999999, -5181.322, -5125.4929999999995, -5067.407999999999, -5006.996, -4944.18, -4878.880999999999, -4811.018, -4740.505999999999, -4667.2570000000005, -4591.178, -4512.174, -4430.145, -4344.992, -4256.607, -4164.8820000000005, -4069.7059999999997, -3970.9640000000004, -3868.542, -3762.322, -3652.184, -3538.011, -3419.688, -3297.099, -3170.137, -3038.698, -2902.6929999999998, -2762.04, -2616.676, -2466.56, -2311.673, -2152.028, -1987.6770000000001, -1818.7089999999998, -1645.265, -1467.539, -1285.787, -1100.325, -911.54, -719.883, -525.876, -330.097, -133.179, 64.203, 261.347, 457.539, 652.073, 844.26, 1033.458, 1219.0710000000001, 1400.567, 1577.484, 1749.4389999999999, 1916.119, 2077.286, 2232.771, 2382.468, 2526.326, 2664.345, 2796.5640000000003, 2923.058, 3043.929, 3159.301, 3269.315, 3374.1240000000003, 3473.889, 3568.778, 3658.9590000000003, 3744.6009999999997, 3825.8740000000003, 3902.9429999999998, 3975.9709999999995, 4045.114, 4110.528, 4172.359, 4230.749, 4285.835999999999, 4337.751, 4386.62, 4432.460999999999, 4475.694, 4516.123, 4553.955, 4589.29, 4622.224, 4652.846, 4681.244000000001, 4707.499, 4731.69, 4753.893, 4774.18, 4792.617, 4809.271, 4824.2029999999995, 4837.473, 4849.138, 4859.251, 4867.8640000000005, 4875.027, 4880.788, 4885.192, 4888.282, 4890.099, 4890.684, 4890.075, 4888.309, 4885.419, 4881.441, 4876.407, 4870.348, 4863.293, 4855.272, 4846.312, 4836.441, 4825.683, 4814.063, 4801.606, 4788.334, 4774.269, 4759.433, 4743.846, 4727.529, 4710.5, 4692.778, 4674.38, 4655.326, 4635.63, 4615.31, 4594.380999999999, 4572.859, 4550.7570000000005, 4528.090999999999, 4504.874, 4481.12, 4456.842000000001, 4432.052, 4406.763, 4380.986, 4354.734, 4328.017, 4300.846, 4273.232, 4245.186, 4216.717000000001, 4187.834, 4158.549, 4128.869000000001, 4098.804, 4068.362, 4037.552, 4006.383, 3974.862, 3942.998, 3910.797, 3878.2690000000002, 3845.4190000000003, 3812.255, 3778.785, 3745.014, 3710.95, 3676.599, 3641.967, 3607.0609999999997, 3571.886, 3536.45, 3500.756, 3464.812, 3428.623, 3392.1929999999998, 3355.5290000000005, 3318.636, 3281.518, 3244.1809999999996, 3206.6290000000004, 3168.868, 3130.902, 3092.735, 3054.373, 3015.82, 2977.08, 2938.157, 2899.055, 2859.7790000000005, 2820.3320000000003, 2780.72, 2740.9440000000004, 2701.01, 2660.92, 2620.68, 2580.291, 2539.759, 2499.0860000000002, 2458.275, 2417.331, 2376.256, 2335.054, 2293.728, 2252.282, 2210.717, 2169.038, 2127.248, 2085.348, 2043.3429999999998, 2001.236, 1959.0279999999998, 1916.724, 1874.325, 1831.8339999999998, 1789.255, 1746.589, 1703.84, 1661.01, 1618.102, 1575.118, 1532.06, 1488.932, 1445.735, 1402.4720000000002, 1359.145, 1315.757, 1272.31, 1228.807, 1185.249, 1141.639, 1097.979, 1054.271, 1010.518, 966.721, 922.8839999999999, 879.007, 835.0930000000001, 791.1439999999999, 747.163, 703.15, 659.1089999999999, 615.0409999999999, 570.9490000000001, 526.8330000000001, 482.69699999999995, 438.541, 394.369, 350.18199999999996, 305.982, 261.77, 217.549, 173.32, 129.086, 84.848, 40.608000000000004, -3.633, -47.871, -92.10700000000001, -136.33700000000002, -180.56, -224.774, -268.978, -313.16900000000004, -357.347, -401.509, -445.653, -489.778, -533.882, -577.964, -622.021, -666.052, -710.055, -754.029, -797.971, -841.8810000000001, -885.757, -929.596, -973.3969999999999, -1017.159, -1060.879, -1104.557, -1148.19, -1191.777, -1235.315, -1278.805, -1322.243, -1365.628, -1408.9589999999998, -1452.233, -1495.45, -1538.6070000000002, -1581.7020000000002, -1624.735, -1667.704, -1710.606, -1753.44, -1796.204, -1838.8970000000002, -1881.517, -1924.0629999999999, -1966.5320000000002, -2008.922, -2051.2329999999997, -2093.4629999999997, -2135.609, -2177.6710000000003, -2219.645, -2261.531, -2303.327, -2345.031, -2386.641, -2428.156, -2469.574, -2510.8920000000003, -2552.11, -2593.225, -2634.235, -2675.139, -2715.9359999999997, -2756.6220000000003, -2797.196, -2837.656, -2878.0009999999997, -2918.2290000000003, -2958.337, -2998.324, -3038.187, -3077.926, -3117.5370000000003, -3157.0190000000002, -3196.37, -3235.5879999999997, -3274.671, -3313.616, -3352.422, -3391.087, -3429.6090000000004, -3467.985, -3506.2129999999997, -3544.2909999999997, -3582.217, -3619.99, -3657.605, -3695.062, -3732.3590000000004, -3769.492, -3806.4590000000003, -3843.259, -3879.889, -3916.3459999999995, -3952.6279999999997, -3988.7329999999997, -4024.658, -4060.4, -4095.958, -4131.329000000001, -4166.509, -4201.497, -4236.289000000001, -4270.884, -4305.278, -4339.469, -4373.454000000001, -4407.23, -4440.794, -4474.143, -4507.275, -4540.186, -4572.874, -4605.335, -4637.567, -4669.565, -4701.3279999999995, -4732.852, -4764.133, -4795.168, -4825.954000000001, -4856.488, -4886.766, -4916.784000000001, -4946.539000000001, -4976.027, -5005.245, -5034.188, -5062.854, -5091.237, -5119.335, -5147.143, -5174.657, -5201.872, -5228.786, -5255.393, -5281.689, -5307.67, -5333.33, -5358.6669999999995, -5383.674, -5408.347, -5432.681, -5456.672, -5480.313, -5503.601, -5526.529, -5549.093000000001, -5571.286999999999, -5593.106, -5614.543000000001, -5635.594, -5656.251, -5676.51, -5696.3640000000005, -5715.806, -5734.83, -5753.431, -5771.6, -5789.331, -5806.618, -5823.453, -5839.829000000001, -5855.738, -5871.172, -5886.125, -5900.588000000001, -5914.552, -5928.009, -5940.951999999999, -5953.37, -5965.255999999999, -5976.599, -5987.391, -5997.621999999999, -6007.281, -6016.359, -6024.845, -6032.728, -6039.9980000000005, -6046.644, -6052.653, -6058.014, -6062.714, -6066.741, -6070.0830000000005, -6072.725, -6074.655, -6075.857, -6076.319, -6076.024, -6074.956999999999, -6073.104, -6070.446999999999, -6066.969, -6062.654, -6057.484, -6051.44, -6044.504, -6036.655, -6027.874, -6018.14, -6007.432, -5995.727, -5983.001, -5969.233, -5954.396, -5938.465, -5921.415, -5903.217, -5883.843000000001, -5863.265, -5841.451999999999, -5818.371, -5793.991, -5768.279, -5741.198, -5712.7119999999995, -5682.784000000001, -5651.374, -5618.44, -5583.941, -5547.831999999999, -5510.066, -5470.597, -5429.374, -5386.346, -5341.456999999999, -5294.653, -5245.8730000000005, -5195.058, -5142.142, -5087.061, -5029.744000000001, -4970.121, -4908.116, -4843.65, -4776.643, -4707.008, -4634.661, -4559.509, -4481.457, -4400.407999999999, -4316.258, -4228.905, -4138.24, -4044.153, -3946.53, -3845.256, -3740.2140000000004, -3631.2859999999996, -3518.355, -3401.304, -3280.0209999999997, -3154.397, -3024.328, -2889.724, -2750.5040000000004, -2606.603, -2457.979, -2304.611, -2146.511, -1983.726, -1816.345, -1644.5020000000002, -1468.388, -1288.253, -1104.4080000000001, -917.2330000000001, -727.174, -534.742, -340.51199999999994, -145.108, 50.802, 246.52200000000002, 441.344, 634.564, 825.502, 1013.5139999999999, 1198.008, 1378.451, 1554.384, 1725.42, 1891.247, 2051.6220000000003, 2206.377, 2355.402, 2498.643, 2636.097, 2767.801, 2893.828, 3014.276, 3129.2659999999996, 3238.938, 3343.4429999999998, 3442.9390000000003, 3537.591, 3627.567, 3713.034, 3794.159, 3871.107, 3944.039, 4013.1090000000004, 4078.4709999999995, 4140.272, 4198.653, 4253.749, 4305.691, 4354.604, 4400.606, 4443.813, 4484.333, 4522.269, 4557.722, 4590.786, 4621.55, 4650.101, 4676.522, 4700.888, 4723.276, 4743.758, 4762.399, 4779.266, 4794.419, 4807.919, 4819.821, 4830.179, 4839.044, 4846.465, 4852.491, 4857.166, 4860.532999999999, 4862.634, 4863.508, 4863.192, 4861.725, 4859.139, 4855.47, 4850.749, 4845.008, 4838.275, 4830.579000000001, 4821.9490000000005, 4812.412, 4801.991, 4790.712, 4778.599, 4765.674, 4751.959, 4737.476, 4722.246, 4706.287, 4689.619000000001, 4672.2609999999995, 4654.231, 4635.545, 4616.22, 4596.274, 4575.72, 4554.575, 4532.853, 4510.568, 4487.734, 4464.3640000000005, 4440.472, 4416.07, 4391.17, 4365.785, 4339.924, 4313.601, 4286.825, 4259.607, 4231.958, 4203.887, 4175.404, 4146.519, 4117.24, 4087.577, 4057.539, 4027.133, 3996.368, 3965.2529999999997, 3933.795, 3902.0009999999997, 3869.88, 3837.438, 3804.683, 3771.6209999999996, 3738.26, 3704.605, 3670.665, 3636.4440000000004, 3601.949, 3567.185, 3532.16, 3496.8790000000004, 3461.347, 3425.5690000000004, 3389.552, 3353.301, 3316.82, 3280.115, 3243.191, 3206.052, 3168.704, 3131.151, 3093.397, 3055.448, 3017.3070000000002, 2978.9790000000003, 2940.468, 2901.7790000000005, 2862.915, 2823.88, 2784.679, 2745.315, 2705.792, 2666.113, 2626.283, 2586.305, 2546.183, 2505.919, 2465.518, 2424.982, 2384.3160000000003, 2343.522, 2302.604, 2261.564, 2220.407, 2179.134, 2137.749, 2096.255, 2054.655, 2012.951, 1971.1470000000002, 1929.245, 1887.249, 1845.16, 1802.9820000000002, 1760.717, 1718.368, 1675.9370000000001, 1633.4270000000001, 1590.8410000000001, 1548.18, 1505.4479999999999, 1462.6470000000002, 1419.779, 1376.846, 1333.852, 1290.798, 1247.6860000000001, 1204.519, 1161.299, 1118.029, 1074.7089999999998, 1031.344, 987.934, 944.482, 900.99, 857.461, 813.895, 770.296, 726.665, 683.0039999999999, 639.315, 595.601, 551.863, 508.103, 464.32300000000004, 420.525, 376.711, 332.88300000000004, 289.04200000000003, 245.19099999999997, 201.332, 157.465, 113.594, 69.72, 25.844, -18.031, -61.903999999999996, -105.773, -149.636, -193.49200000000002, -237.338, -281.17400000000004, -324.996, -368.80400000000003, -412.595, -456.369, -500.12300000000005, -543.856, -587.565, -631.25, -674.908, -718.539, -762.1389999999999, -805.7080000000001, -849.2439999999999, -892.745, -936.209, -979.635, -1023.0219999999999, -1066.367, -1109.6689999999999, -1152.9260000000002, -1196.137, -1239.299, -1282.412, -1325.473, -1368.4820000000002, -1411.435, -1454.3329999999999, -1497.172, -1539.951, -1582.67, -1625.325, -1667.915, -1710.4389999999999, -1752.896, -1795.2820000000002, -1837.5970000000002, -1879.839, -1922.007, -1964.098, -2006.11, -2048.0429999999997, -2089.895, -2131.663, -2173.346, -2214.9429999999998, -2256.451, -2297.869, -2339.195, -2380.427, -2421.564, -2462.604, -2503.545, -2544.385, -2585.1220000000003, -2625.755, -2666.282, -2706.7009999999996, -2747.009, -2787.2070000000003, -2827.29, -2867.258, -2907.1090000000004, -2946.84, -2986.4509999999996, -3025.938, -3065.3, -3104.535, -3143.6409999999996, -3182.616, -3221.458, -3260.165, -3298.735, -3337.1659999999997, -3375.455, -3413.6009999999997, -3451.6020000000003, -3489.455, -3527.159, -3564.71, -3602.1079999999997, -3639.349, -3676.4320000000002, -3713.3540000000003, -3750.113, -3786.7070000000003, -3823.133, -3859.389, -3895.472, -3931.381, -3967.112, -4002.664, -4038.033, -4073.218, -4108.215, -4143.022, -4177.637, -4212.056, -4246.278, -4280.299, -4314.117, -4347.729, -4381.1320000000005, -4414.323, -4447.299, -4480.058, -4512.596, -4544.911, -4576.999, -4608.857, -4640.482, -4671.871, -4703.021, -4733.928, -4764.589, -4795.001, -4825.16, -4855.063, -4884.706, -4914.085999999999, -4943.198, -4972.04, -5000.607, -5028.896, -5056.902, -5084.623, -5112.052, -5139.188, -5166.025, -5192.558, -5218.785, -5244.7, -5270.3, -5295.578, -5320.531, -5345.155, -5369.443, -5393.392, -5416.996, -5440.25, -5463.149, -5485.688, -5507.861999999999, -5529.664000000001, -5551.089, -5572.132, -5592.786999999999, -5613.047, -5632.906999999999, -5652.361, -5671.401, -5690.022, -5708.217, -5725.979, -5743.3009999999995, -5760.177, -5776.598000000001, -5792.558000000001, -5808.049, -5823.064, -5837.593000000001, -5851.63, -5865.166, -5878.193, -5890.701, -5902.682, -5914.1269999999995, -5925.026, -5935.37, -5945.15, -5954.354, -5962.973000000001, -5970.995, -5978.41, -5985.2080000000005, -5991.376, -5996.903, -6001.776999999999, -6005.985, -6009.514, -6012.351, -6014.483, -6015.896, -6016.575, -6016.505999999999, -6015.674, -6014.062, -6011.656, -6008.438, -6004.39, -5999.496999999999, -5993.7390000000005, -5987.097, -5979.552, -5971.085, -5961.675, -5951.3, -5939.938, -5927.566999999999, -5914.161999999999, -5899.701, -5884.156, -5867.503000000001, -5849.714, -5830.762, -5810.616, -5789.2480000000005, -5766.625, -5742.715999999999, -5717.486999999999, -5690.904, -5662.929, -5633.526, -5602.655, -5570.276, -5536.347, -5500.823, -5463.659000000001, -5424.807, -5384.219, -5341.843000000001, -5297.624, -5251.508000000001, -5203.435, -5153.346, -5101.1759999999995, -5046.861, -4990.332, -4931.518, -4870.343, -4806.731, -4740.602, -4671.869000000001, -4600.448, -4526.248, -4449.174, -4369.129, -4286.012, -4199.719, -4110.145, -4017.177, -3920.705, -3820.611, -3716.783, -3609.1009999999997, -3497.448, -3381.7090000000003, -3261.7709999999997, -3137.526, -3008.869, -2875.711, -2737.97, -2595.58, -2448.4970000000003, -2296.7, -2140.197, -1979.033, -1813.293, -1643.109, -1468.6660000000002, -1290.2089999999998, -1108.0439999999999, -922.544, -734.1469999999999, -543.3580000000001, -350.74300000000005, -156.921, 37.448, 231.675, 425.05699999999996, 616.896, 806.5160000000001, 993.2760000000001, 1176.5839999999998, 1355.912, 1530.797, 1700.854, 1865.7679999999998, 2025.295, 2179.265, 2327.564, 2470.138, 2606.979, 2738.1220000000003, 2863.637, 2983.619, 3098.188, 3207.4809999999998, 3311.645, 3410.836, 3505.22, 3594.961, 3680.222, 3761.172, 3837.973, 3910.783, 3979.756, 4045.046, 4106.7970000000005, 4165.148, 4220.235, 4272.186, 4321.127, 4367.175, 4410.443, 4451.04, 4489.068, 4524.627, 4557.81, 4588.707, 4617.403, 4643.98, 4668.514, 4691.081, 4711.751, 4730.590999999999, 4747.666, 4763.037, 4776.762, 4788.897, 4799.497, 4808.612, 4816.29, 4822.58, 4827.525, 4831.169, 4833.553, 4834.715999999999, 4834.696, 4833.528, 4831.249, 4827.891, 4823.485, 4818.064, 4811.657, 4804.29, 4795.994000000001, 4786.794, 4776.714, 4765.781, 4754.016, 4741.444, 4728.085, 4713.960999999999, 4699.092000000001, 4683.499, 4667.1990000000005, 4650.212, 4632.554, 4614.244000000001, 4595.298, 4575.732, 4555.562, 4534.802, 4513.467000000001, 4491.572, 4469.13, 4446.153, 4422.656, 4398.651, 4374.149, 4349.164000000001, 4323.705, 4297.785, 4271.414000000001, 4244.602, 4217.36, 4189.697, 4161.624, 4133.149, 4104.282999999999, 4075.032, 4045.408, 4015.417, 3985.0679999999998, 3954.369, 3923.328, 3891.953, 3860.25, 3828.228, 3795.893, 3763.252, 3730.312, 3697.08, 3663.562, 3629.763, 3595.692, 3561.3520000000003, 3526.7509999999997, 3491.8940000000002, 3456.7870000000003, 3421.434, 3385.842, 3350.0159999999996, 3313.961, 3277.6820000000002, 3241.183, 3204.4709999999995, 3167.548, 3130.421, 3093.094, 3055.571, 3017.8559999999998, 2979.954, 2941.869, 2903.605, 2865.167, 2826.558, 2787.782, 2748.843, 2709.745, 2670.491, 2631.086, 2591.532, 2551.833, 2511.994, 2472.016, 2431.903, 2391.66, 2351.288, 2310.792, 2270.174, 2229.437, 2188.585, 2147.62, 2106.545, 2065.364, 2024.079, 1982.693, 1941.2089999999998, 1899.63, 1857.9579999999999, 1816.195, 1774.345, 1732.411, 1690.394, 1648.297, 1606.1229999999998, 1563.875, 1521.5539999999999, 1479.1629999999998, 1436.705, 1394.181, 1351.595, 1308.948, 1266.243, 1223.482, 1180.6680000000001, 1137.8010000000002, 1094.886, 1051.923, 1008.915, 965.8639999999999, 922.7719999999999, 879.6410000000001, 836.4739999999999, 793.2719999999999, 750.0369999999999, 706.7710000000001, 663.477, 620.156, 576.811, 533.442, 490.05300000000005, 446.644, 403.219, 359.778, 316.323, 272.858, 229.382, 185.899, 142.409, 98.916, 55.419, 11.923, -31.573, -75.066, -118.554, -162.036, -205.50900000000001, -248.97299999999998, -292.426, -335.865, -379.289, -422.69599999999997, -466.085, -509.454, -552.8009999999999, -596.124, -639.423, -682.695, -725.938, -769.1510000000001, -812.332, -855.48, -898.5930000000001, -941.669, -984.707, -1027.704, -1070.66, -1113.573, -1156.441, -1199.262, -1242.035, -1284.758, -1327.4289999999999, -1370.047, -1412.611, -1455.118, -1497.566, -1539.955, -1582.283, -1624.5479999999998, -1666.7479999999998, -1708.881, -1750.9470000000001, -1792.942, -1834.8670000000002, -1876.7179999999998, -1918.495, -1960.195, -2001.817, -2043.36, -2084.821, -2126.198, -2167.491, -2208.697, -2249.815, -2290.843, -2331.779, -2372.6220000000003, -2413.369, -2454.019, -2494.57, -2535.021, -2575.369, -2615.613, -2655.75, -2695.78, -2735.7009999999996, -2775.509, -2815.204, -2854.784, -2894.2470000000003, -2933.591, -2972.813, -3011.913, -3050.888, -3089.735, -3128.455, -3167.0429999999997, -3205.498, -3243.8190000000004, -3282.0029999999997, -3320.047, -3357.9509999999996, -3395.712, -3433.327, -3470.795, -3508.114, -3545.281, -3582.2940000000003, -3619.151, -3655.85, -3692.388, -3728.763, -3764.973, -3801.0159999999996, -3836.889, -3872.5890000000004, -3908.115, -3943.4629999999997, -3978.633, -4013.619, -4048.422, -4083.0370000000003, -4117.462, -4151.695, -4185.733, -4219.573, -4253.213, -4286.65, -4319.88, -4352.902, -4385.712, -4418.307, -4450.685, -4482.842000000001, -4514.776, -4546.483, -4577.96, -4609.205, -4640.213, -4670.982, -4701.508, -4731.788, -4761.819, -4791.597, -4821.1179999999995, -4850.379, -4879.377, -4908.108, -4936.567, -4964.752, -4992.657999999999, -5020.281, -5047.6179999999995, -5074.664000000001, -5101.415, -5127.8679999999995, -5154.017, -5179.858, -5205.387, -5230.6, -5255.491, -5280.057, -5304.2919999999995, -5328.191, -5351.749, -5374.963000000001, -5397.825, -5420.331999999999, -5442.478, -5464.257, -5485.664000000001, -5506.693, -5527.338000000001, -5547.594, -5567.454000000001, -5586.911999999999, -5605.963000000001, -5624.599, -5642.813, -5660.601, -5677.953, -5694.8640000000005, -5711.326, -5727.3330000000005, -5742.875, -5757.946999999999, -5772.539000000001, -5786.645, -5800.255, -5813.361999999999, -5825.956, -5838.03, -5849.573, -5860.576999999999, -5871.031999999999, -5880.928000000001, -5890.255999999999, -5899.005, -5907.165, -5914.724, -5921.673000000001, -5927.999, -5933.691, -5938.736999999999, -5943.124, -5946.840999999999, -5949.8730000000005, -5952.206999999999, -5953.831, -5954.729, -5954.887, -5954.289000000001, -5952.922, -5950.767, -5947.81, -5944.033, -5939.419, -5933.9490000000005, -5927.606, -5920.369000000001, -5912.219, -5903.1359999999995, -5893.099, -5882.085999999999, -5870.0740000000005, -5857.04, -5842.96, -5827.808000000001, -5811.559, -5794.187, -5775.661999999999, -5755.9580000000005, -5735.043000000001, -5712.888000000001, -5689.4580000000005, -5664.723000000001, -5638.647, -5611.194, -5582.328, -5552.009, -5520.196999999999, -5486.851, -5451.9259999999995, -5415.378000000001, -5377.159000000001, -5337.221, -5295.513000000001, -5251.981, -5206.57, -5159.223, -5109.879, -5058.475, -5004.947, -4949.227, -4891.2429999999995, -4830.923, -4768.189, -4702.960999999999, -4635.156, -4564.688, -4491.467000000001, -4415.4, -4336.39, -4254.337, -4169.137, -4080.6859999999997, -3988.873, -3893.587, -3794.712, -3692.136, -3585.74, -3475.408, -3361.0229999999997, -3242.4759999999997, -3119.656, -2992.461, -2860.797, -2724.586, -2583.76, -2438.272, -2288.1020000000003, -2133.255, -1973.7720000000002, -1809.736, -1641.274, -1468.568, -1291.854, -1111.435, -927.677, -741.0110000000001, -551.935, -361.006, -168.835, 23.924, 216.588, 408.463, 598.855, 787.091, 972.534, 1154.596, 1332.747, 1506.527, 1675.5479999999998, 1839.495, 1998.1229999999998, 2151.258, 2298.785, 2440.647, 2576.8320000000003, 2707.3740000000003, 2832.3379999999997, 2951.8179999999998, 3065.9309999999996, 3174.8109999999997, 3278.603, 3377.462, 3471.5490000000004, 3561.027, 3646.059, 3726.8109999999997, 3803.441, 3876.1090000000004, 3944.967, 4010.165, 4071.848, 4130.153, 4185.215999999999, 4237.162, 4286.1179999999995, 4332.415, 4375.517, 4416.18, 4454.29, 4489.946, 4523.241, 4554.262, 4583.096, 4609.823, 4634.52, 4657.26, 4678.1140000000005, 4697.149, 4714.429, 4730.014, 4743.962, 4756.33, 4767.17, 4776.534000000001, 4784.468, 4791.022, 4796.238, 4800.16, 4802.8279999999995, 4804.282, 4804.558, 4803.694, 4801.723, 4798.678, 4794.592000000001, 4789.495, 4783.416, 4776.384, 4768.425, 4759.568, 4749.835, 4739.252, 4727.842000000001, 4715.628, 4702.630999999999, 4688.872, 4674.372, 4659.15, 4643.225, 4626.616, 4609.34, 4591.413, 4572.853, 4553.6759999999995, 4533.897, 4513.531, 4492.592000000001, 4471.095, 4449.053, 4426.479, 4403.3859999999995, 4379.787, 4355.694, 4331.1179999999995, 4306.071, 4280.564, 4254.607, 4228.212, 4201.387, 4174.144, 4146.491, 4118.438, 4089.994, 4061.1679999999997, 4031.968, 4002.403, 3972.4809999999998, 3942.211, 3911.599, 3880.653, 3849.381, 3817.79, 3785.888, 3753.68, 3721.173, 3688.375, 3655.292, 3621.929, 3588.2929999999997, 3554.39, 3520.225, 3485.805, 3451.135, 3416.2209999999995, 3381.067, 3345.679, 3310.062, 3274.222, 3238.163, 3201.889, 3165.407, 3128.719, 3091.8309999999997, 3054.748, 3017.473, 2980.011, 2942.365, 2904.5409999999997, 2866.542, 2828.373, 2790.0359999999996, 2751.5359999999996, 2712.877, 2674.062, 2635.095, 2595.98, 2556.72, 2517.3179999999998, 2477.778, 2438.103, 2398.2960000000003, 2358.361, 2318.301, 2278.119, 2237.8179999999998, 2197.4, 2156.87, 2116.23, 2075.4829999999997, 2034.631, 1993.6779999999999, 1952.626, 1911.4779999999998, 1870.237, 1828.905, 1787.486, 1745.98, 1704.392, 1662.724, 1620.9779999999998, 1579.156, 1537.261, 1495.296, 1453.2620000000002, 1411.1629999999998, 1369.0, 1326.776, 1284.493, 1242.153, 1199.758, 1157.3110000000001, 1114.8139999999999, 1072.269, 1029.678, 987.044, 944.367, 901.65, 858.8960000000001, 816.107, 773.283, 730.428, 687.544, 644.631, 601.693, 558.731, 515.748, 472.744, 429.722, 386.68300000000005, 343.63, 300.565, 257.48900000000003, 214.40400000000002, 171.31099999999998, 128.213, 85.11200000000001, 42.00899999999999, -1.094, -44.196000000000005, -87.294, -130.387, -173.47299999999998, -216.55, -259.617, -302.672, -345.713, -388.73900000000003, -431.74800000000005, -474.73800000000006, -517.707, -560.655, -603.578, -646.476, -689.3480000000001, -732.19, -775.002, -817.7819999999999, -860.528, -903.2389999999999, -945.913, -988.548, -1031.143, -1073.697, -1116.2069999999999, -1158.671, -1201.089, -1243.4589999999998, -1285.779, -1328.047, -1370.2620000000002, -1412.421, -1454.525, -1496.57, -1538.556, -1580.48, -1622.3410000000001, -1664.1370000000002, -1705.8670000000002, -1747.529, -1789.121, -1830.642, -1872.09, -1913.464, -1954.761, -1995.98, -2037.119, -2078.177, -2119.152, -2160.042, -2200.846, -2241.562, -2282.187, -2322.721, -2363.1620000000003, -2403.507, -2443.756, -2483.905, -2523.955, -2563.902, -2603.745, -2643.482, -2683.112, -2722.632, -2762.04, -2801.336, -2840.5159999999996, -2879.58, -2918.5240000000003, -2957.348, -2996.0490000000004, -3034.6259999999997, -3073.0759999999996, -3111.397, -3149.5879999999997, -3187.6459999999997, -3225.57, -3263.357, -3301.006, -3338.513, -3375.8779999999997, -3413.098, -3450.171, -3487.095, -3523.867, -3560.486, -3596.949, -3633.2540000000004, -3669.3979999999997, -3705.38, -3741.197, -3776.847, -3812.327, -3847.635, -3882.7690000000002, -3917.7259999999997, -3952.5029999999997, -3987.099, -4021.51, -4055.7340000000004, -4089.7690000000002, -4123.612, -4157.259, -4190.71, -4223.96, -4257.0070000000005, -4289.848, -4322.48, -4354.901, -4387.108, -4419.097, -4450.866, -4482.411, -4513.73, -4544.819, -4575.675, -4606.295, -4636.675, -4666.813, -4696.706, -4726.348, -4755.738, -4784.872, -4813.745, -4842.355, -4870.697, -4898.768, -4926.565, -4954.082, -4981.317, -5008.264, -5034.920999999999, -5061.282999999999, -5087.345, -5113.104, -5138.555, -5163.693, -5188.515, -5213.014, -5237.188, -5261.03, -5284.536, -5307.701, -5330.519, -5352.986999999999, -5375.098000000001, -5396.846, -5418.228, -5439.236, -5459.865, -5480.109, -5499.963000000001, -5519.42, -5538.474, -5557.119000000001, -5575.348000000001, -5593.155, -5610.531999999999, -5627.473000000001, -5643.971, -5660.018, -5675.608, -5690.732, -5705.382, -5719.552, -5733.232, -5746.415, -5759.092, -5771.254, -5782.892, -5793.996999999999, -5804.559, -5814.57, -5824.018, -5832.895, -5841.19, -5848.892, -5855.9890000000005, -5862.472, -5868.326999999999, -5873.544, -5878.11, -5882.013000000001, -5885.24, -5887.776999999999, -5889.611, -5890.727, -5891.111999999999, -5890.751, -5889.628000000001, -5887.727, -5885.033, -5881.528, -5877.195, -5872.016, -5865.974, -5859.048000000001, -5851.219, -5842.468000000001, -5832.773, -5822.111999999999, -5810.464, -5797.805, -5784.111, -5769.358, -5753.52, -5736.57, -5718.481, -5699.225, -5678.771, -5657.090999999999, -5634.151, -5609.918000000001, -5584.359, -5557.439, -5529.119000000001, -5499.363, -5468.129, -5435.3769999999995, -5401.064, -5365.145, -5327.573, -5288.299, -5247.274, -5204.444, -5159.755, -5113.15, -5064.568, -5013.948, -4961.226, -4906.334, -4849.202, -4789.7570000000005, -4727.923, -4663.62, -4596.766, -4527.276, -4455.059, -4380.024, -4302.076, -4221.115, -4137.039000000001, -4049.742, -3959.114, -3865.047, -3767.426, -3666.137, -3561.063, -3452.0890000000004, -3339.098, -3221.9809999999998, -3100.6290000000004, -2974.938, -2844.816, -2710.1809999999996, -2570.967, -2427.126, -2278.634, -2125.494, -1967.7479999999998, -1805.4720000000002, -1638.7910000000002, -1467.88, -1292.973, -1114.364, -932.413, -747.544, -560.247, -371.07300000000004, -180.623, 10.457, 201.49, 391.788, 580.663, 767.447, 951.505, 1132.253, 1309.162, 1481.7720000000002, 1649.6960000000001, 1812.616, 1970.287, 2122.53, 2269.231, 2410.328, 2545.808, 2675.699, 2800.067, 2919.002, 3032.617, 3141.045, 3244.428, 3342.9179999999997, 3436.6740000000004, 3525.857, 3610.63, 3691.153, 3767.587, 3840.086, 3908.803, 3973.887, 4035.48, 4093.72, 4148.738, 4200.662, 4249.615, 4295.712, 4339.065, 4379.781, 4417.960999999999, 4453.702, 4487.096, 4518.231, 4547.193, 4574.062, 4598.912, 4621.819, 4642.851, 4662.0740000000005, 4679.553, 4695.347, 4709.514, 4722.11, 4733.187, 4742.795999999999, 4750.986, 4757.8009999999995, 4763.288, 4767.487, 4770.439, 4772.183, 4772.7570000000005, 4772.196, 4770.535, 4767.806, 4764.041, 4759.27, 4753.523, 4746.8279999999995, 4739.212, 4730.7, 4721.318, 4711.089, 4700.038, 4688.187, 4675.557, 4662.169, 4648.043, 4633.1990000000005, 4617.656, 4601.431, 4584.542, 4567.005999999999, 4548.84, 4530.059, 4510.678, 4490.713, 4470.179, 4449.088, 4427.455, 4405.292, 4382.613, 4359.429, 4335.753, 4311.596, 4286.97, 4261.8859999999995, 4236.354, 4210.384, 4183.987, 4157.173, 4129.95, 4102.329000000001, 4074.3190000000004, 4045.927, 4017.163, 3988.0359999999996, 3958.552, 3928.72, 3898.548, 3868.0440000000003, 3837.2140000000004, 3806.066, 3774.607, 3742.844, 3710.783, 3678.4309999999996, 3645.7940000000003, 3612.8790000000004, 3579.691, 3546.237, 3512.5209999999997, 3478.551, 3444.3309999999997, 3409.867, 3375.164, 3340.228, 3305.063, 3269.675, 3234.0679999999998, 3198.2470000000003, 3162.217, 3125.982, 3089.547, 3052.917, 3016.095, 2979.086, 2941.8940000000002, 2904.5240000000003, 2866.978, 2829.262, 2791.3790000000004, 2753.3320000000003, 2715.1259999999997, 2676.764, 2638.25, 2599.587, 2560.779, 2521.83, 2482.741, 2443.518, 2404.163, 2364.679, 2325.07, 2285.3379999999997, 2245.487, 2205.519, 2165.439, 2125.2470000000003, 2084.948, 2044.545, 2004.039, 1963.434, 1922.733, 1881.9379999999999, 1841.0520000000001, 1800.0770000000002, 1759.016, 1717.871, 1676.646, 1635.342, 1593.9620000000002, 1552.509, 1510.984, 1469.39, 1427.73, 1386.006, 1344.219, 1302.373, 1260.469, 1218.51, 1176.497, 1134.434, 1092.322, 1050.163, 1007.959, 965.7130000000001, 923.426, 881.1, 838.738, 796.342, 753.913, 711.453, 668.965, 626.4490000000001, 583.909, 541.347, 498.76300000000003, 456.159, 413.539, 370.903, 328.25300000000004, 285.592, 242.92, 200.24, 157.554, 114.86200000000001, 72.168, 29.473000000000003, -13.222000000000001, -55.915, -98.603, -141.286, -183.96200000000002, -226.628, -269.284, -311.927, -354.556, -397.16900000000004, -439.765, -482.342, -524.898, -567.431, -609.941, -652.424, -694.8810000000001, -737.308, -779.705, -822.069, -864.4, -906.695, -948.953, -991.172, -1033.351, -1075.488, -1117.5810000000001, -1159.63, -1201.631, -1243.5839999999998, -1285.487, -1327.338, -1369.136, -1410.879, -1452.566, -1494.194, -1535.763, -1577.27, -1618.715, -1660.094, -1701.408, -1742.6529999999998, -1783.829, -1824.934, -1865.9660000000001, -1906.9229999999998, -1947.8039999999999, -1988.608, -2029.332, -2069.974, -2110.534, -2151.009, -2191.3979999999997, -2231.699, -2271.91, -2312.029, -2352.056, -2391.987, -2431.822, -2471.5589999999997, -2511.195, -2550.729, -2590.16, -2629.485, -2668.702, -2707.8109999999997, -2746.808, -2785.692, -2824.462, -2863.115, -2901.6490000000003, -2940.063, -2978.355, -3016.522, -3054.563, -3092.4759999999997, -3130.258, -3167.909, -3205.425, -3242.805, -3280.046, -3317.1479999999997, -3354.1059999999998, -3390.92, -3427.5879999999997, -3464.1059999999998, -3500.474, -3536.688, -3572.7470000000003, -3608.6479999999997, -3644.389, -3679.968, -3715.382, -3750.63, -3785.708, -3820.614, -3855.347, -3889.903, -3924.28, -3958.475, -3992.486, -4026.3109999999997, -4059.946, -4093.39, -4126.639, -4159.691, -4192.543, -4225.192, -4257.6359999999995, -4289.871, -4321.895, -4353.705, -4385.298, -4416.67, -4447.819, -4478.742, -4509.436, -4539.896, -4570.121, -4600.107, -4629.85, -4659.348, -4688.596, -4717.590999999999, -4746.33, -4774.809, -4803.025, -4830.973, -4858.649, -4886.0509999999995, -4913.174, -4940.015, -4966.568, -4992.83, -5018.7970000000005, -5044.464, -5069.8279999999995, -5094.884, -5119.626, -5144.052, -5168.155, -5191.931, -5215.376, -5238.485, -5261.2519999999995, -5283.672, -5305.74, -5327.451, -5348.799, -5369.779, -5390.385, -5410.611999999999, -5430.453, -5449.901999999999, -5468.953, -5487.601, -5505.8369999999995, -5523.656999999999, -5541.053000000001, -5558.019, -5574.545999999999, -5590.63, -5606.2609999999995, -5621.432, -5636.1359999999995, -5650.365, -5664.111, -5677.365, -5690.12, -5702.366, -5714.095, -5725.298000000001, -5735.965, -5746.085999999999, -5755.653, -5764.655, -5773.081, -5780.922, -5788.166, -5794.803000000001, -5800.82, -5806.206999999999, -5810.95, -5815.0380000000005, -5818.4580000000005, -5821.196999999999, -5823.241, -5824.576, -5825.189, -5825.064, -5824.186, -5822.54, -5820.109, -5816.8769999999995, -5812.826999999999, -5807.941999999999, -5802.201999999999, -5795.59, -5788.085999999999, -5779.669, -5770.319, -5760.015, -5748.735, -5736.456, -5723.154, -5708.804, -5693.382, -5676.861, -5659.214, -5640.4130000000005, -5620.429, -5599.23, -5576.786999999999, -5553.066, -5528.034000000001, -5501.654, -5473.892, -5444.709, -5414.064, -5381.919, -5348.229, -5312.951, -5276.039000000001, -5237.444, -5197.116, -5155.003, -5111.0509999999995, -5065.204000000001, -5017.402, -4967.584, -4915.685, -4861.64, -4805.38, -4746.83, -4685.917, -4622.561, -4556.681, -4488.192, -4417.005, -4343.03, -4266.170999999999, -4186.33, -4103.405, -4017.2909999999997, -3927.882, -3835.065, -3738.7309999999998, -3638.764, -3535.048, -3427.47, -3315.9120000000003, -3200.2659999999996, -3080.423, -2956.28, -2827.744, -2694.7309999999998, -2557.178, -2415.033, -2268.271, -2116.893, -1960.9379999999999, -1800.48, -1635.638, -1466.5839999999998, -1293.5439999999999, -1116.809, -936.73, -753.725, -568.276, -380.92400000000004, -192.265, -2.9360000000000004, 186.395, 375.045, 562.332, 747.5939999999999, 930.199, 1109.5639999999999, 1285.165, 1456.54, 1623.3029999999999, 1785.134, 1941.7879999999998, 2093.083, 2238.902, 2379.181, 2513.904, 2643.099, 2766.824, 2885.1690000000003, 2998.244, 3106.179, 3209.114, 3307.2, 3400.59, 3489.446, 3573.928, 3654.1940000000004, 3730.403, 3802.7070000000003, 3871.26, 3936.2059999999997, 3997.687, 4055.84, 4110.795, 4162.678, 4211.61, 4257.708, 4301.081, 4341.835, 4380.07, 4415.884, 4449.367, 4480.606, 4509.686, 4536.686, 4561.683, 4584.748, 4605.95, 4625.356, 4643.028, 4659.026, 4673.407999999999, 4686.229, 4697.54, 4707.392, 4715.833, 4722.909000000001, 4728.664000000001, 4733.139, 4736.375, 4738.411, 4739.282999999999, 4739.026, 4737.6759999999995, 4735.264, 4731.822, 4727.380999999999, 4721.968, 4715.613, 4708.342000000001, 4700.18, 4691.153, 4681.284000000001, 4670.596, 4659.113, 4646.855, 4633.844, 4620.098, 4605.638, 4590.482, 4574.648, 4558.153, 4541.015, 4523.249, 4504.872, 4485.898, 4466.342000000001, 4446.219, 4425.543, 4404.327, 4382.584, 4360.326, 4337.567, 4314.317, 4290.589, 4266.393, 4241.741, 4216.643, 4191.109, 4165.15, 4138.775, 4111.994000000001, 4084.815, 4057.2490000000003, 4029.303, 4000.986, 3972.3059999999996, 3943.272, 3913.8909999999996, 3884.171, 3854.119, 3823.743, 3793.05, 3762.046, 3730.739, 3699.136, 3667.242, 3635.065, 3602.6090000000004, 3569.882, 3536.889, 3503.635, 3470.127, 3436.37, 3402.37, 3368.131, 3333.659, 3298.9590000000003, 3264.0359999999996, 3228.8940000000002, 3193.539, 3157.975, 3122.2059999999997, 3086.238, 3050.074, 3013.719, 2977.178, 2940.453, 2903.5490000000004, 2866.4709999999995, 2829.222, 2791.8059999999996, 2754.2270000000003, 2716.488, 2678.593, 2640.546, 2602.35, 2564.009, 2525.525, 2486.903, 2448.146, 2409.257, 2370.239, 2331.095, 2291.828, 2252.442, 2212.939, 2173.322, 2133.594, 2093.758, 2053.8179999999998, 2013.774, 1973.631, 1933.391, 1893.057, 1852.631, 1812.116, 1771.515, 1730.829, 1690.0620000000001, 1649.2160000000001, 1608.293, 1567.296, 1526.227, 1485.088, 1443.882, 1402.611, 1361.2779999999998, 1319.8829999999998, 1278.431, 1236.923, 1195.36, 1153.746, 1112.0819999999999, 1070.37, 1028.613, 986.813, 944.971, 903.0889999999999, 861.17, 819.216, 777.2280000000001, 735.209, 693.16, 651.0830000000001, 608.98, 566.854, 524.705, 482.537, 440.349, 398.14599999999996, 355.92699999999996, 313.69599999999997, 271.453, 229.201, 186.94099999999997, 144.67600000000002, 102.406, 60.13399999999999, 17.861, -24.41, -66.679, -108.944, -151.202, -193.453, -235.69400000000002, -277.923, -320.14, -362.343, -404.529, -446.69699999999995, -488.847, -530.975, -573.08, -615.161, -657.216, -699.243, -741.2410000000001, -783.209, -825.1439999999999, -867.045, -908.91, -950.7389999999999, -992.528, -1034.277, -1075.984, -1117.647, -1159.265, -1200.836, -1242.359, -1283.8319999999999, -1325.253, -1366.621, -1407.934, -1449.19, -1490.389, -1531.5279999999998, -1572.605, -1613.62, -1654.57, -1695.454, -1736.27, -1777.017, -1817.692, -1858.295, -1898.8239999999998, -1939.277, -1979.652, -2019.9470000000001, -2060.1620000000003, -2100.294, -2140.342, -2180.304, -2220.178, -2259.962, -2299.655, -2339.256, -2378.762, -2418.1710000000003, -2457.482, -2496.694, -2535.804, -2574.81, -2613.7110000000002, -2652.505, -2691.19, -2729.765, -2768.2270000000003, -2806.574, -2844.8059999999996, -2882.9190000000003, -2920.9120000000003, -2958.783, -2996.53, -3034.151, -3071.645, -3109.008, -3146.24, -3183.3379999999997, -3220.3, -3257.125, -3293.809, -3330.3509999999997, -3366.75, -3403.0009999999997, -3439.105, -3475.058, -3510.8579999999997, -3546.5029999999997, -3581.991, -3617.3190000000004, -3652.485, -3687.487, -3722.323, -3756.99, -3791.486, -3825.808, -3859.954, -3893.922, -3927.708, -3961.3109999999997, -3994.7270000000003, -4027.955, -4060.991, -4093.8340000000003, -4126.479, -4158.925, -4191.168, -4223.207, -4255.037, -4286.656, -4318.062, -4349.251, -4380.22, -4410.965, -4441.485, -4471.776, -4501.835, -4531.657999999999, -4561.242, -4590.584, -4619.68, -4648.527, -4677.122, -4705.46, -4733.539000000001, -4761.354, -4788.902, -4816.179, -4843.181, -4869.905, -4896.345, -4922.499, -4948.361, -4973.929, -4999.197, -5024.161, -5048.816, -5073.159000000001, -5097.184, -5120.887, -5144.263, -5167.307, -5190.014, -5212.38, -5234.398, -5256.064, -5277.371999999999, -5298.316999999999, -5318.893, -5339.095, -5358.916, -5378.351, -5397.393, -5416.036999999999, -5434.275, -5452.103, -5469.512, -5486.496, -5503.049, -5519.161999999999, -5534.83, -5550.044, -5564.797, -5579.081, -5592.888000000001, -5606.21, -5619.039000000001, -5631.365, -5643.182, -5654.479, -5665.246999999999, -5675.476, -5685.158, -5694.281999999999, -5702.839, -5710.816999999999, -5718.206, -5724.995, -5731.173000000001, -5736.728, -5741.648, -5745.92, -5749.533, -5752.474, -5754.728, -5756.281999999999, -5757.1230000000005, -5757.235, -5756.604, -5755.214, -5753.048000000001, -5750.092, -5746.328, -5741.738, -5736.305, -5730.009, -5722.8330000000005, -5714.755, -5705.755, -5695.813, -5684.906, -5673.012, -5660.107, -5646.168000000001, -5631.169, -5615.084, -5597.887, -5579.549, -5560.0419999999995, -5539.335, -5517.398, -5494.198, -5469.701999999999, -5443.875, -5416.682, -5388.084, -5358.041, -5326.515, -5293.463000000001, -5258.840999999999, -5222.603, -5184.702, -5145.088, -5103.709, -5060.512, -5015.442, -4968.438, -4919.442, -4868.388, -4815.212, -4759.845, -4702.215, -4642.247, -4579.863, -4514.984, -4447.524, -4377.395, -4304.508, -4228.768, -4150.079000000001, -4068.3379999999997, -3983.4429999999998, -3895.2859999999996, -3803.758, -3708.748, -3610.1420000000003, -3507.827, -3401.6859999999997, -3291.607, -3177.4770000000003, -3059.191, -2936.6440000000002, -2809.745, -2678.409, -2542.57, -2402.177, -2257.203, -2107.649, -1953.546, -1794.9679999999998, -1632.03, -1464.899, -1293.796, -1119.003, -940.867, -759.796, -576.266, -390.809, -204.012, -16.505, 171.05200000000002, 357.98400000000004, 543.614, 727.285, 908.3710000000001, 1086.29, 1260.519, 1430.6, 1596.144, 1756.832, 1912.415, 2062.7110000000002, 2207.6, 2347.016, 2480.938, 2609.393, 2732.4359999999997, 2850.1540000000005, 2962.653, 3070.062, 3172.5170000000003, 3270.167, 3363.164, 3451.6659999999997, 3535.8309999999997, 3615.816, 3691.777, 3763.865, 3832.232, 3897.022, 3958.373, 4016.422, 4071.297, 4123.124, 4172.024, 4218.262, 4261.49, 4302.271, 4340.5509999999995, 4376.428, 4409.99, 4441.325, 4470.516, 4497.642, 4522.778, 4545.996, 4567.3640000000005, 4586.947, 4604.809, 4621.009, 4635.603, 4648.646, 4660.19, 4670.284000000001, 4678.976, 4686.313, 4692.335999999999, 4697.088, 4700.609, 4702.937, 4704.108, 4704.159000000001, 4703.122, 4701.03, 4697.915, 4693.806, 4688.732, 4682.72, 4675.798, 4667.991, 4659.3240000000005, 4649.82, 4639.501, 4628.392, 4616.513, 4603.884, 4590.525, 4576.455, 4561.693, 4546.2570000000005, 4530.164000000001, 4513.431, 4496.0740000000005, 4478.108, 4459.549, 4440.411, 4420.709, 4400.456, 4379.666, 4358.351, 4336.525, 4314.1990000000005, 4291.385, 4268.095, 4244.339, 4220.13, 4195.476, 4170.389, 4144.878, 4118.9529999999995, 4092.623, 4065.8979999999997, 4038.7859999999996, 4011.297, 3983.437, 3955.217, 3926.6440000000002, 3897.725, 3868.468, 3838.881, 3808.9709999999995, 3778.744, 3748.2090000000003, 3717.3709999999996, 3686.237, 3654.8140000000003, 3623.1079999999997, 3591.125, 3558.8709999999996, 3526.3509999999997, 3493.572, 3460.54, 3427.259, 3393.735, 3359.973, 3325.978, 3291.756, 3257.3109999999997, 3222.6490000000003, 3187.7729999999997, 3152.688, 3117.4, 3081.9120000000003, 3046.228, 3010.3540000000003, 2974.2929999999997, 2938.0490000000004, 2901.627, 2865.03, 2828.262, 2791.328, 2754.23, 2716.972, 2679.559, 2641.993, 2604.278, 2566.4179999999997, 2528.416, 2490.275, 2451.998, 2413.589, 2375.051, 2336.387, 2297.6, 2258.6929999999998, 2219.669, 2180.531, 2141.282, 2101.924, 2062.4610000000002, 2022.895, 1983.229, 1943.4660000000001, 1903.608, 1863.6570000000002, 1823.6170000000002, 1783.49, 1743.2779999999998, 1702.985, 1662.611, 1622.16, 1581.635, 1541.037, 1500.368, 1459.632, 1418.83, 1377.964, 1337.0379999999998, 1296.052, 1255.01, 1213.913, 1172.763, 1131.563, 1090.3139999999999, 1049.019, 1007.679, 966.298, 924.8760000000001, 883.416, 841.919, 800.388, 758.824, 717.23, 675.607, 633.9580000000001, 592.283, 550.585, 508.866, 467.12800000000004, 425.37199999999996, 383.6, 341.814, 300.01599999999996, 258.20799999999997, 216.39, 174.56599999999997, 132.736, 90.90299999999999, 49.068000000000005, 7.232, -34.601, -76.432, -118.257, -160.076, -201.887, -243.688, -285.47700000000003, -327.253, -369.015, -410.76, -452.486, -494.194, -535.879, -577.5419999999999, -619.18, -660.793, -702.377, -743.932, -785.456, -826.948, -868.4060000000001, -909.827, -951.212, -992.557, -1033.863, -1075.126, -1116.345, -1157.519, -1198.647, -1239.726, -1280.755, -1321.7320000000002, -1362.6570000000002, -1403.526, -1444.339, -1485.095, -1525.79, -1566.425, -1606.997, -1647.504, -1687.9460000000001, -1728.319, -1768.624, -1808.858, -1849.019, -1889.1070000000002, -1929.118, -1969.0520000000001, -2008.908, -2048.6820000000002, -2088.374, -2127.982, -2167.504, -2206.939, -2246.285, -2285.54, -2324.702, -2363.77, -2402.742, -2441.617, -2480.3920000000003, -2519.065, -2557.636, -2596.1020000000003, -2634.461, -2672.711, -2710.8520000000003, -2748.88, -2786.7940000000003, -2824.592, -2862.2729999999997, -2899.8340000000003, -2937.2740000000003, -2974.59, -3011.781, -3048.844, -3085.778, -3122.5809999999997, -3159.2509999999997, -3195.785, -3232.1809999999996, -3268.4390000000003, -3304.555, -3340.527, -3376.353, -3412.031, -3447.56, -3482.9359999999997, -3518.157, -3553.222, -3588.1279999999997, -3622.873, -3657.454, -3691.869, -3726.115, -3760.191, -3794.094, -3827.821, -3861.3709999999996, -3894.739, -3927.925, -3960.925, -3993.737, -4026.357, -4058.784, -4091.015, -4123.0470000000005, -4154.876, -4186.501, -4217.919, -4249.126, -4280.12, -4310.897, -4341.456, -4371.791, -4401.901, -4431.782999999999, -4461.432, -4490.846, -4520.022, -4548.956, -4577.645, -4606.085, -4634.273, -4662.205, -4689.877, -4717.286, -4744.429, -4771.3, -4797.897, -4824.215999999999, -4850.251, -4876.0, -4901.459, -4926.622, -4951.485, -4976.045, -5000.295999999999, -5024.235, -5047.856, -5071.155, -5094.126, -5116.766, -5139.068, -5161.029, -5182.642, -5203.903, -5224.805, -5245.344, -5265.514, -5285.308000000001, -5304.722, -5323.749, -5342.382, -5360.616, -5378.445, -5395.861, -5412.858, -5429.43, -5445.568, -5461.267, -5476.518, -5491.315, -5505.648, -5519.512, -5532.897, -5545.795999999999, -5558.1990000000005, -5570.099, -5581.486, -5592.352, -5602.686, -5612.48, -5621.724, -5630.408, -5638.521, -5646.052, -5652.991999999999, -5659.328, -5665.049, -5670.144, -5674.6, -5678.405, -5681.545999999999, -5684.01, -5685.783, -5686.852, -5687.201, -5686.816999999999, -5685.683000000001, -5683.785, -5681.106, -5677.629, -5673.335999999999, -5668.210999999999, -5662.235, -5655.389, -5647.653, -5639.007, -5629.43, -5618.901, -5607.397, -5594.895, -5581.371999999999, -5566.8009999999995, -5551.159000000001, -5534.4169999999995, -5516.549, -5497.526, -5477.319, -5455.896, -5433.226, -5409.276, -5384.0109999999995, -5357.395, -5329.393, -5299.963000000001, -5269.068, -5236.666, -5202.712, -5167.161, -5129.968, -5091.081, -5050.452, -5008.026, -4963.747, -4917.56, -4869.402, -4819.212, -4766.924, -4712.47, -4655.78, -4596.778, -4535.389, -4471.532999999999, -4405.125, -4336.08, -4264.307, -4189.714, -4112.2029999999995, -4031.676, -3948.0290000000005, -3861.156, -3770.947, -3677.296, -3580.086, -3479.2059999999997, -3374.5409999999997, -3265.9770000000003, -3153.405, -3036.716, -2915.81, -2790.591, -2660.978, -2526.901, -2388.31, -2245.175, -2097.495, -1945.3, -1788.6589999999999, -1627.684, -1462.535, -1293.43, -1120.644, -944.515, -765.447, -583.904, -400.411, -215.547, -29.933000000000003, 155.779, 340.92, 524.822, 706.831, 886.325, 1062.728, 1235.518, 1404.237, 1568.495, 1727.974, 1882.425, 2031.661, 2175.562, 2314.0570000000002, 2447.125, 2574.788, 2697.099, 2814.1420000000003, 2926.0209999999997, 3032.86, 3134.7940000000003, 3231.969, 3324.535, 3412.647, 3496.461, 3576.133, 3651.815, 3723.66, 3791.8140000000003, 3856.421, 3917.618, 3975.54, 4030.3140000000003, 4082.066, 4130.912, 4176.967000000001, 4220.338, 4261.13, 4299.441, 4335.366, 4368.995, 4400.413, 4429.7029999999995, 4456.944, 4482.21, 4505.572, 4527.097, 4546.851, 4564.896, 4581.291, 4596.090999999999, 4609.352, 4621.124, 4631.456, 4640.397, 4647.991, 4654.281, 4659.308, 4663.112, 4665.732, 4667.2029999999995, 4667.56, 4666.837, 4665.067, 4662.279, 4658.504, 4653.77, 4648.105, 4641.535, 4634.085999999999, 4625.782, 4616.646, 4606.702, 4595.971, 4584.475, 4572.233, 4559.267, 4545.593, 4531.232, 4516.2, 4500.515, 4484.193, 4467.251, 4449.704000000001, 4431.567, 4412.854, 4393.58, 4373.759, 4353.403, 4332.525, 4311.138, 4289.254, 4266.885, 4244.042, 4220.736, 4196.978, 4172.779, 4148.148, 4123.095, 4097.63, 4071.762, 4045.5, 4018.8540000000003, 3991.8320000000003, 3964.441, 3936.691, 3908.59, 3880.1440000000002, 3851.362, 3822.2509999999997, 3792.8179999999998, 3763.07, 3733.014, 3702.657, 3672.005, 3641.0640000000003, 3609.842, 3578.344, 3546.575, 3514.542, 3482.25, 3449.7059999999997, 3416.913, 3383.8790000000004, 3350.607, 3317.103, 3283.3720000000003, 3249.4190000000003, 3215.248, 3180.865, 3146.2740000000003, 3111.4790000000003, 3076.4840000000004, 3041.295, 3005.915, 2970.349, 2934.6, 2898.673, 2862.571, 2826.2990000000004, 2789.8590000000004, 2753.257, 2716.495, 2679.577, 2642.507, 2605.288, 2567.923, 2530.416, 2492.771, 2454.99, 2417.076, 2379.033, 2340.864, 2302.571, 2264.158, 2225.629, 2186.984, 2148.228, 2109.364, 2070.394, 2031.32, 1992.146, 1952.874, 1913.507, 1874.047, 1834.497, 1794.86, 1755.138, 1715.332, 1675.4470000000001, 1635.484, 1595.445, 1555.3329999999999, 1515.151, 1474.9, 1434.582, 1394.2, 1353.757, 1313.254, 1272.693, 1232.076, 1191.407, 1150.6860000000001, 1109.9160000000002, 1069.098, 1028.236, 987.33, 946.3839999999999, 905.398, 864.3739999999999, 823.316, 782.2239999999999, 741.1, 699.947, 658.7660000000001, 617.559, 576.328, 535.075, 493.801, 452.509, 411.199, 369.875, 328.537, 287.188, 245.829, 204.46099999999998, 163.08700000000002, 121.709, 80.327, 38.944, -2.439, -43.818999999999996, -85.196, -126.568, -167.933, -209.28900000000002, -250.635, -291.969, -333.29, -374.595, -415.884, -457.154, -498.405, -539.634, -580.84, -622.021, -663.176, -704.303, -745.4010000000001, -786.467, -827.5010000000001, -868.5010000000001, -909.465, -950.3919999999999, -991.28, -1032.127, -1072.933, -1113.694, -1154.411, -1195.0810000000001, -1235.702, -1276.274, -1316.7939999999999, -1357.261, -1397.674, -1438.03, -1478.329, -1518.568, -1558.746, -1598.862, -1638.914, -1678.9, -1718.818, -1758.668, -1798.4470000000001, -1838.154, -1877.787, -1917.344, -1956.825, -1996.227, -2035.5479999999998, -2074.788, -2113.944, -2153.014, -2191.9970000000003, -2230.8920000000003, -2269.696, -2308.409, -2347.027, -2385.55, -2423.975, -2462.301, -2500.527, -2538.65, -2576.6679999999997, -2614.581, -2652.385, -2690.08, -2727.663, -2765.133, -2802.487, -2839.724, -2876.842, -2913.8390000000004, -2950.7129999999997, -2987.4629999999997, -3024.085, -3060.579, -3096.942, -3133.172, -3169.268, -3205.2270000000003, -3241.047, -3276.7259999999997, -3312.261, -3347.652, -3382.895, -3417.989, -3452.9320000000002, -3487.72, -3522.3520000000003, -3556.8259999999996, -3591.139, -3625.289, -3659.2740000000003, -3693.092, -3726.739, -3760.2129999999997, -3793.513, -3826.635, -3859.577, -3892.337, -3924.9120000000003, -3957.2990000000004, -3989.4959999999996, -4021.5, -4053.308, -4084.917, -4116.326, -4147.53, -4178.527, -4209.315, -4239.89, -4270.248, -4300.389, -4330.306, -4359.999, -4389.465, -4418.698, -4447.697, -4476.458, -4504.978, -4533.253, -4561.28, -4589.054, -4616.5740000000005, -4643.834, -4670.832, -4697.563, -4724.024, -4750.21, -4776.119000000001, -4801.745, -4827.084, -4852.133, -4876.887, -4901.342000000001, -4925.4929999999995, -4949.335999999999, -4972.867, -4996.079000000001, -5018.97, -5041.534000000001, -5063.766, -5085.66, -5107.213, -5128.418, -5149.27, -5169.764, -5189.895, -5209.655, -5229.041, -5248.045, -5266.661, -5284.885, -5302.7080000000005, -5320.125, -5337.129, -5353.713000000001, -5369.871, -5385.595, -5400.878000000001, -5415.7119999999995, -5430.090999999999, -5444.005999999999, -5457.4490000000005, -5470.4130000000005, -5482.888000000001, -5494.866999999999, -5506.340999999999, -5517.3, -5527.735, -5537.638000000001, -5546.9980000000005, -5555.805, -5564.05, -5571.721, -5578.808000000001, -5585.3, -5591.186, -5596.454000000001, -5601.092, -5605.088000000001, -5608.429, -5611.102, -5613.093000000001, -5614.389, -5614.976, -5614.839, -5613.963000000001, -5612.331999999999, -5609.931, -5606.741999999999, -5602.749, -5597.935, -5592.28, -5585.767, -5578.376, -5570.0869999999995, -5560.879, -5550.732, -5539.621999999999, -5527.526999999999, -5514.424, -5500.286999999999, -5485.093000000001, -5468.813, -5451.422, -5432.89, -5413.19, -5392.289000000001, -5370.156999999999, -5346.7609999999995, -5322.068, -5296.041, -5268.644, -5239.839, -5209.585999999999, -5177.844, -5144.571, -5109.722, -5073.249, -5035.105, -4995.2390000000005, -4953.599, -4910.13, -4864.774, -4817.473, -4768.165, -4716.784000000001, -4663.263, -4607.532999999999, -4549.52, -4489.148, -4426.337, -4361.005999999999, -4293.069, -4222.437, -4149.017, -4072.7140000000004, -3993.428, -3911.059, -3825.502, -3736.647, -3644.386, -3548.6090000000004, -3449.2, -3346.048, -3239.04, -3128.066, -3013.018, -2893.795, -2770.303, -2642.4590000000003, -2510.194, -2373.455, -2232.212, -2086.462, -1936.23, -1781.5839999999998, -1622.631, -1459.527, -1292.484, -1121.769, -947.716, -770.717, -591.231, -409.773, -226.91400000000002, -43.266000000000005, 140.528, 323.806, 505.906, 686.18, 864.013, 1038.829, 1210.109, 1377.398, 1540.305, 1698.5120000000002, 1851.7679999999998, 1999.885, 2142.739, 2280.259, 2412.4210000000003, 2539.241, 2660.772, 2777.093, 2888.3070000000002, 2994.534, 3095.908, 3192.5690000000004, 3284.6679999999997, 3372.3559999999998, 3455.7870000000003, 3535.114, 3610.49, 3682.062, 3749.9770000000003, 3814.3759999999997, 3875.3959999999997, 3933.1690000000003, 3987.822, 4039.4770000000003, 4088.252, 4134.259, 4177.605, 4218.392, 4256.72, 4292.68, 4326.363, 4357.854, 4387.232, 4414.5779999999995, 4439.965, 4463.462, 4485.138, 4505.055, 4523.277, 4539.861, 4554.862, 4568.335999999999, 4580.332, 4590.9, 4600.085999999999, 4607.934, 4614.4890000000005, 4619.79, 4623.877, 4626.788, 4628.558, 4629.223, 4628.815, 4627.367, 4624.909000000001, 4621.47, 4617.079000000001, 4611.764, 4605.549, 4598.460999999999, 4590.524, 4581.7609999999995, 4572.195, 4561.847, 4550.7390000000005, 4538.89, 4526.321, 4513.049, 4499.094, 4484.473, 4469.202, 4453.299, 4436.779, 4419.657999999999, 4401.95, 4383.670999999999, 4364.833, 4345.451, 4325.537, 4305.105, 4284.167, 4262.734, 4240.819, 4218.432, 4195.585, 4172.288, 4148.552, 4124.387, 4099.802, 4074.808, 4049.4120000000003, 4023.625, 3997.455, 3970.91, 3943.9990000000003, 3916.7309999999998, 3889.112, 3861.151, 3832.855, 3804.2309999999998, 3775.2870000000003, 3746.03, 3716.465, 3686.6009999999997, 3656.4429999999998, 3625.9970000000003, 3595.2709999999997, 3564.27, 3532.9990000000003, 3501.465, 3469.6740000000004, 3437.63, 3405.3390000000004, 3372.8059999999996, 3340.038, 3307.038, 3273.8109999999997, 3240.363, 3206.698, 3172.821, 3138.736, 3104.448, 3069.961, 3035.2790000000005, 3000.408, 2965.35, 2930.11, 2894.692, 2859.099, 2823.336, 2787.407, 2751.3140000000003, 2715.062, 2678.6540000000005, 2642.094, 2605.385, 2568.531, 2531.534, 2494.3979999999997, 2457.127, 2419.723, 2382.19, 2344.53, 2306.7470000000003, 2268.844, 2230.823, 2192.687, 2154.44, 2116.083, 2077.621, 2039.055, 2000.388, 1961.6229999999998, 1922.7620000000002, 1883.808, 1844.764, 1805.631, 1766.4129999999998, 1727.112, 1687.731, 1648.27, 1608.734, 1569.124, 1529.443, 1489.692, 1449.875, 1409.9920000000002, 1370.047, 1330.0420000000001, 1289.978, 1249.859, 1209.685, 1169.4589999999998, 1129.183, 1088.859, 1048.489, 1008.075, 967.6189999999999, 927.123, 886.5889999999999, 846.0189999999999, 805.414, 764.7769999999999, 724.1089999999999, 683.413, 642.69, 601.941, 561.169, 520.376, 479.56300000000005, 438.73199999999997, 397.885, 357.023, 316.149, 275.264, 234.36900000000003, 193.467, 152.559, 111.646, 70.73100000000001, 29.816, -11.099, -52.012, -92.921, -133.82399999999998, -174.71900000000002, -215.606, -256.482, -297.346, -338.19699999999995, -379.032, -419.85, -460.649, -501.42900000000003, -542.187, -582.9209999999999, -623.631, -664.314, -704.97, -745.596, -786.19, -826.753, -867.2810000000001, -907.773, -948.2280000000001, -988.6439999999999, -1029.02, -1069.354, -1109.644, -1149.889, -1190.088, -1230.238, -1270.339, -1310.388, -1350.385, -1390.3270000000002, -1430.213, -1470.0420000000001, -1509.8110000000001, -1549.52, -1589.1670000000001, -1628.749, -1668.267, -1707.717, -1747.098, -1786.41, -1825.649, -1864.816, -1903.9070000000002, -1942.921, -1981.8570000000002, -2020.713, -2059.488, -2098.179, -2136.785, -2175.305, -2213.736, -2252.078, -2290.327, -2328.484, -2366.545, -2404.51, -2442.376, -2480.1420000000003, -2517.806, -2555.365, -2592.82, -2630.167, -2667.4040000000005, -2704.531, -2741.545, -2778.4440000000004, -2815.2259999999997, -2851.89, -2888.434, -2924.855, -2961.153, -2997.324, -3033.367, -3069.2790000000005, -3105.06, -3140.7070000000003, -3176.217, -3211.59, -3246.822, -3281.9109999999996, -3316.857, -3351.655, -3386.305, -3420.804, -3455.1490000000003, -3489.34, -3523.3720000000003, -3557.245, -3590.955, -3624.5009999999997, -3657.8790000000004, -3691.0890000000004, -3724.1259999999997, -3756.99, -3789.676, -3822.184, -3854.51, -3886.651, -3918.605, -3950.37, -3981.9429999999998, -4013.32, -4044.5, -4075.4790000000003, -4106.255, -4136.8240000000005, -4167.185, -4197.333, -4227.266, -4256.981, -4286.476, -4315.745, -4344.787, -4373.599, -4402.1759999999995, -4430.516, -4458.615, -4486.471, -4514.0779999999995, -4541.434, -4568.536, -4595.379, -4621.96, -4648.275, -4674.32, -4700.090999999999, -4725.584, -4750.795999999999, -4775.721, -4800.357, -4824.698, -4848.74, -4872.479, -4895.91, -4919.028, -4941.83, -4964.309, -4986.462, -5008.282999999999, -5029.767, -5050.909000000001, -5071.704000000001, -5092.146, -5112.229, -5131.9490000000005, -5151.299, -5170.274, -5188.867, -5207.072, -5224.884, -5242.295, -5259.3, -5275.891, -5292.062, -5307.806, -5323.115, -5337.983, -5352.401, -5366.363, -5379.86, -5392.884, -5405.427, -5417.481, -5429.036999999999, -5440.085999999999, -5450.619000000001, -5460.6269999999995, -5470.1, -5479.028, -5487.401999999999, -5495.210999999999, -5502.444, -5509.09, -5515.139, -5520.579000000001, -5525.398, -5529.5830000000005, -5533.1230000000005, -5536.005, -5538.214, -5539.738, -5540.563, -5540.674, -5540.056, -5538.694, -5536.571999999999, -5533.674, -5529.983, -5525.481, -5520.151, -5513.975, -5506.932, -5499.004, -5490.169, -5480.408, -5469.696999999999, -5458.015, -5445.338000000001, -5431.642, -5416.901999999999, -5401.092, -5384.185, -5366.153, -5346.967, -5326.598000000001, -5305.014, -5282.183000000001, -5258.071, -5232.643, -5205.8640000000005, -5177.695, -5148.096, -5117.03, -5084.451, -5050.317, -5014.581, -4977.195, -4938.109, -4897.273, -4854.63, -4810.126, -4763.701, -4715.294, -4664.840999999999, -4612.276, -4557.529, -4500.528, -4441.197, -4379.459, -4315.232, -4248.431, -4178.967000000001, -4106.751, -4031.6859999999997, -3953.676, -3872.619, -3788.4109999999996, -3700.947, -3610.115, -3515.808, -3417.913, -3316.316, -3210.907, -3101.5759999999996, -2988.216, -2870.725, -2749.011, -2622.989, -2492.589, -2357.759, -2218.466, -2074.705, -1926.499, -1773.912, -1617.046, -1456.0539999999999, -1291.14, -1122.567, -950.659, -775.803, -598.446, -419.098, -238.317, -56.708, 125.094, 306.435, 486.662, 665.1310000000001, 841.232, 1014.393, 1184.099, 1349.894, 1511.389, 1668.265, 1820.2679999999998, 1967.2120000000002, 2108.968, 2245.4629999999997, 2376.669, 2502.6020000000003, 2623.309, 2738.868, 2849.3779999999997, 2954.9570000000003, 3055.7340000000004, 3151.849, 3243.448, 3330.6820000000002, 3413.702, 3492.658, 3567.7009999999996, 3638.978, 3706.631, 3770.801, 3831.623, 3889.228, 3943.741, 3995.284, 4043.972, 4089.842, 4133.223, 4173.9929999999995, 4212.325, 4248.31, 4282.036, 4313.589, 4343.048, 4370.491, 4395.991, 4419.617, 4441.436, 4461.512, 4479.906, 4496.674, 4511.874, 4525.557, 4537.775, 4548.576, 4558.005, 4566.108, 4572.9259999999995, 4578.501, 4582.871, 4586.0740000000005, 4588.145, 4589.1179999999995, 4589.027, 4587.903, 4585.777, 4582.678, 4578.633, 4573.67, 4567.815, 4561.092000000001, 4553.526, 4545.141, 4535.957, 4525.998, 4515.282999999999, 4503.833, 4491.667, 4478.804, 4465.262, 4451.058, 4436.209, 4420.732, 4404.641, 4387.954000000001, 4370.683, 4352.845, 4334.452, 4315.517, 4296.055, 4276.077, 4255.596, 4234.624, 4213.1720000000005, 4191.251, 4168.873, 4146.0470000000005, 4122.785, 4099.096, 4074.989, 4050.475, 4025.563, 4000.26, 3974.577, 3948.522, 3922.1020000000003, 3895.3259999999996, 3868.2009999999996, 3840.736, 3812.938, 3784.8140000000003, 3756.37, 3727.615, 3698.554, 3669.195, 3639.5429999999997, 3609.6040000000003, 3579.387, 3548.8959999999997, 3518.135, 3487.113, 3455.835, 3424.304, 3392.528, 3360.511, 3328.259, 3295.776, 3263.067, 3230.137, 3196.991, 3163.634, 3130.0690000000004, 3096.302, 3062.336, 3028.177, 2993.827, 2959.292, 2924.575, 2889.68, 2854.611, 2819.3709999999996, 2783.966, 2748.397, 2712.67, 2676.7859999999996, 2640.7509999999997, 2604.567, 2568.237, 2531.765, 2495.154, 2458.407, 2421.528, 2384.519, 2347.384, 2310.125, 2272.746, 2235.249, 2197.637, 2159.913, 2122.08, 2084.141, 2046.0970000000002, 2007.953, 1969.71, 1931.371, 1892.9379999999999, 1854.415, 1815.8029999999999, 1777.105, 1738.3229999999999, 1699.46, 1660.519, 1621.5, 1582.408, 1543.243, 1504.009, 1464.707, 1425.34, 1385.9089999999999, 1346.4170000000001, 1306.867, 1267.259, 1227.597, 1187.881, 1148.116, 1108.3010000000002, 1068.4389999999999, 1028.5330000000001, 988.584, 948.5939999999999, 908.565, 868.4989999999999, 828.3969999999999, 788.262, 748.096, 707.9, 667.676, 627.4259999999999, 587.1519999999999, 546.855, 506.537, 466.20099999999996, 425.847, 385.477, 345.094, 304.698, 264.29200000000003, 223.878, 183.456, 143.029, 102.598, 62.165, 21.730999999999998, -18.701, -59.131, -99.602, -140.02100000000002, -180.433, -220.835, -261.22700000000003, -301.606, -341.971, -382.32099999999997, -422.654, -462.968, -503.26099999999997, -543.533, -583.7819999999999, -624.006, -664.203, -704.372, -744.512, -784.6210000000001, -824.697, -864.7389999999999, -904.7460000000001, -944.715, -984.645, -1024.535, -1064.383, -1104.188, -1143.948, -1183.662, -1223.327, -1262.943, -1302.508, -1342.021, -1381.479, -1420.881, -1460.226, -1499.513, -1538.739, -1577.9029999999998, -1617.003, -1656.039, -1695.0079999999998, -1733.908, -1772.739, -1811.4979999999998, -1850.184, -1888.796, -1927.3310000000001, -1965.789, -2004.1670000000001, -2042.464, -2080.678, -2118.808, -2156.851, -2194.8070000000002, -2232.674, -2270.449, -2308.132, -2345.72, -2383.2110000000002, -2420.605, -2457.899, -2495.092, -2532.1820000000002, -2569.166, -2606.044, -2642.813, -2679.472, -2716.0190000000002, -2752.4509999999996, -2788.768, -2824.967, -2861.046, -2897.0040000000004, -2932.8379999999997, -2968.547, -3004.1279999999997, -3039.58, -3074.901, -3110.0879999999997, -3145.14, -3180.054, -3214.829, -3249.4629999999997, -3283.952, -3318.296, -3352.492, -3386.5370000000003, -3420.4309999999996, -3454.1690000000003, -3487.7509999999997, -3521.173, -3554.435, -3587.532, -3620.4629999999997, -3653.2259999999997, -3685.817, -3718.235, -3750.478, -3782.542, -3814.425, -3846.1240000000003, -3877.638, -3908.962, -3940.095, -3971.034, -4001.776, -4032.3190000000004, -4062.659, -4092.7929999999997, -4122.718, -4152.434, -4181.934, -4211.217000000001, -4240.28, -4269.119000000001, -4297.731, -4326.1140000000005, -4354.263, -4382.1759999999995, -4409.849, -4437.278, -4464.460999999999, -4491.393, -4518.07, -4544.49, -4570.649, -4596.542, -4622.166, -4647.517, -4672.590999999999, -4697.383, -4721.89, -4746.108, -4770.032, -4793.657, -4816.979, -4839.995, -4862.698, -4885.084, -4907.149, -4928.888, -4950.295, -4971.366, -4992.094, -5012.476, -5032.505, -5052.1759999999995, -5071.483, -5090.420999999999, -5108.983, -5127.163, -5144.956, -5162.355, -5179.354, -5195.946, -5212.124, -5227.880999999999, -5243.21, -5258.105, -5272.557, -5286.56, -5300.105, -5313.185, -5325.791, -5337.915, -5349.548000000001, -5360.683000000001, -5371.309, -5381.418000000001, -5391.0, -5400.045999999999, -5408.545, -5416.488, -5423.8640000000005, -5430.661999999999, -5436.871, -5442.48, -5447.477, -5451.851, -5455.588000000001, -5458.677, -5461.103, -5462.854, -5463.916, -5464.275, -5463.915, -5462.821999999999, -5460.98, -5458.3730000000005, -5454.985, -5450.797, -5445.794, -5439.956, -5433.264, -5425.6990000000005, -5417.241, -5407.869000000001, -5397.561, -5386.295999999999, -5374.05, -5360.799, -5346.519, -5331.183000000001, -5314.766, -5297.24, -5278.576999999999, -5258.746, -5237.717000000001, -5215.458, -5191.937, -5167.1179999999995, -5140.965, -5113.443, -5084.5109999999995, -5054.13, -5022.258, -4988.851, -4953.8640000000005, -4917.25, -4878.959, -4838.94, -4797.14, -4753.503, -4707.971, -4660.483, -4610.977, -4559.3859999999995, -4505.642, -4449.673, -4391.406, -4330.762, -4267.662, -4202.02, -4133.751, -4062.764, -3988.965, -3912.258, -3832.542, -3749.715, -3663.671, -3574.303, -3481.5009999999997, -3385.153, -3285.1490000000003, -3181.377, -3073.728, -2962.0959999999995, -2846.381, -2726.487, -2602.333, -2473.846, -2340.973, -2203.681, -2061.96, -1915.835, -1765.362, -1610.642, -1451.8210000000001, -1289.098, -1122.73, -953.033, -780.385, -605.227, -428.05699999999996, -249.426, -69.928, 109.809, 289.14099999999996, 467.41900000000004, 644.009, 818.304, 989.737, 1157.795, 1322.025, 1482.0379999999998, 1637.514, 1788.2, 1933.906, 2074.502, 2209.91, 2340.103, 2465.091, 2584.9210000000003, 2699.665, 2809.421, 2914.302, 3014.437, 3109.962, 3201.0209999999997, 3287.761, 3370.3309999999997, 3448.88, 3523.555, 3594.5009999999997, 3661.861, 3725.772, 3786.368, 3843.778, 3898.1259999999997, 3949.531, 3998.1090000000004, 4043.968, 4087.2140000000004, 4127.948, 4166.264, 4202.255999999999, 4236.01, 4267.61, 4297.135, 4324.661, 4350.2609999999995, 4374.003, 4395.955, 4416.178, 4434.734, 4451.678, 4467.067, 4480.952, 4493.385, 4504.411, 4514.0779999999995, 4522.43, 4529.5070000000005, 4535.352, 4540.001, 4543.492, 4545.861, 4547.141, 4547.365, 4546.564, 4544.769, 4542.008, 4538.309, 4533.6990000000005, 4528.204000000001, 4521.848, 4514.655, 4506.648, 4497.85, 4488.281, 4477.963, 4466.915, 4455.156, 4442.705, 4429.579000000001, 4415.7970000000005, 4401.374, 4386.327, 4370.6720000000005, 4354.424, 4337.596, 4320.204000000001, 4302.262, 4283.782, 4264.777, 4245.26, 4225.244000000001, 4204.7390000000005, 4183.758, 4162.311, 4140.409000000001, 4118.063, 4095.282, 4072.078, 4048.458, 4024.434, 4000.013, 3975.205, 3950.018, 3924.461, 3898.542, 3872.268, 3845.6479999999997, 3818.6890000000003, 3791.3990000000003, 3763.784, 3735.8520000000003, 3707.6090000000004, 3679.063, 3650.219, 3621.085, 3591.6659999999997, 3561.968, 3531.9970000000003, 3501.76, 3471.261, 3440.507, 3409.5029999999997, 3378.2529999999997, 3346.764, 3315.04, 3283.086, 3250.907, 3218.508, 3185.8940000000002, 3153.0690000000004, 3120.0370000000003, 3086.804, 3053.3720000000003, 3019.7470000000003, 2985.933, 2951.934, 2917.7529999999997, 2883.3940000000002, 2848.862, 2814.16, 2779.292, 2744.262, 2709.072, 2673.7270000000003, 2638.23, 2602.584, 2566.7929999999997, 2530.86, 2494.788, 2458.581, 2422.24, 2385.77, 2349.174, 2312.4539999999997, 2275.613, 2238.655, 2201.5820000000003, 2164.396, 2127.101, 2089.699, 2052.1929999999998, 2014.586, 1976.88, 1939.0770000000002, 1901.181, 1863.194, 1825.1170000000002, 1786.954, 1748.7079999999999, 1710.379, 1671.971, 1633.486, 1594.9260000000002, 1556.2939999999999, 1517.5910000000001, 1478.82, 1439.983, 1401.082, 1362.12, 1323.098, 1284.018, 1244.883, 1205.694, 1166.454, 1127.164, 1087.826, 1048.444, 1009.0169999999999, 969.549, 930.04, 890.4939999999999, 850.9119999999999, 811.295, 771.6460000000001, 731.966, 692.258, 652.5219999999999, 612.761, 572.977, 533.17, 493.344, 453.499, 413.63800000000003, 373.76199999999994, 333.87199999999996, 293.971, 254.06, 214.141, 174.215, 134.284, 94.35, 54.413999999999994, 14.478, -25.456, -65.387, -105.314, -145.234, -185.14700000000002, -225.05, -264.942, -304.822, -344.68699999999995, -384.537, -424.369, -464.18300000000005, -503.976, -543.748, -583.496, -623.219, -662.916, -702.585, -742.2239999999999, -781.8330000000001, -821.409, -860.95, -900.457, -939.926, -979.3560000000001, -1018.7460000000001, -1058.095, -1097.401, -1136.662, -1175.876, -1215.0430000000001, -1254.161, -1293.2269999999999, -1332.2420000000002, -1371.2020000000002, -1410.108, -1448.9560000000001, -1487.746, -1526.476, -1565.144, -1603.749, -1642.289, -1680.764, -1719.17, -1757.507, -1795.773, -1833.9660000000001, -1872.086, -1910.129, -1948.096, -1985.983, -2023.789, -2061.514, -2099.154, -2136.71, -2174.177, -2211.5570000000002, -2248.845, -2286.042, -2323.144, -2360.151, -2397.061, -2433.8720000000003, -2470.581, -2507.189, -2543.692, -2580.089, -2616.3779999999997, -2652.558, -2688.6259999999997, -2724.58, -2760.42, -2796.143, -2831.7459999999996, -2867.2290000000003, -2902.5890000000004, -2937.825, -2972.934, -3007.914, -3042.764, -3077.482, -3112.0640000000003, -3146.511, -3180.8179999999998, -3214.985, -3249.009, -3282.888, -3316.62, -3350.202, -3383.633, -3416.91, -3450.032, -3482.995, -3515.797, -3548.437, -3580.9109999999996, -3613.218, -3645.355, -3677.3190000000004, -3709.1079999999997, -3740.72, -3772.152, -3803.401, -3834.465, -3865.341, -3896.027, -3926.5190000000002, -3956.816, -3986.913, -4016.809, -4046.5009999999997, -4075.985, -4105.259, -4134.319, -4163.164000000001, -4191.788, -4220.19, -4248.366, -4276.313, -4304.028, -4331.5070000000005, -4358.747, -4385.744000000001, -4412.496, -4438.997, -4465.246, -4491.237, -4516.968, -4542.434, -4567.6320000000005, -4592.558, -4617.207, -4641.576, -4665.66, -4689.455, -4712.957, -4736.161, -4759.064, -4781.659000000001, -4803.943, -4825.911, -4847.558, -4868.88, -4889.87, -4910.524, -4930.837, -4950.803, -4970.417, -4989.673, -5008.565, -5027.089, -5045.237, -5063.003, -5080.383, -5097.3679999999995, -5113.9529999999995, -5130.13, -5145.894, -5161.238, -5176.153, -5190.633, -5204.67, -5218.258, -5231.387, -5244.05, -5256.2390000000005, -5267.945, -5279.159000000001, -5289.874, -5300.079000000001, -5309.766, -5318.925, -5327.545999999999, -5335.619000000001, -5343.134, -5350.08, -5356.446999999999, -5362.222, -5367.395, -5371.954000000001, -5375.8859999999995, -5379.18, -5381.821999999999, -5383.798000000001, -5385.096, -5385.701, -5385.599, -5384.775, -5383.2119999999995, -5380.897, -5377.812, -5373.939, -5369.263000000001, -5363.764, -5357.425, -5350.225, -5342.146, -5333.166, -5323.265, -5312.419, -5300.608, -5287.806, -5273.99, -5259.135, -5243.213000000001, -5226.1990000000005, -5208.063, -5188.778, -5168.311, -5146.633, -5123.709, -5099.5070000000005, -5073.991, -5047.124, -5018.8679999999995, -4989.183, -4958.028, -4925.361, -4891.135, -4855.306, -4817.823, -4778.6359999999995, -4737.693, -4694.939, -4650.316, -4603.764, -4555.222, -4504.624, -4451.902, -4396.986, -4339.803, -4280.276, -4218.3240000000005, -4153.867, -4086.817, -4017.085, -3944.578, -3869.202, -3790.8559999999998, -3709.44, -3624.849, -3536.9759999999997, -3445.7129999999997, -3350.948, -3252.573, -3150.4770000000003, -3044.55, -2934.6890000000003, -2820.7909999999997, -2702.764, -2580.524, -2453.998, -2323.133, -2187.894, -2048.27, -1904.28, -1755.981, -1603.467, -1446.88, -1286.413, -1122.317, -954.8989999999999, -784.5310000000001, -611.643, -436.724, -260.317, -83.007, 94.589, 271.835, 448.089, 622.725, 795.1389999999999, 964.7710000000001, 1131.109, 1293.703, 1452.165, 1606.174, 1755.477, 1899.881, 2039.256, 2173.52, 2302.644, 2426.634, 2545.535, 2659.4159999999997, 2768.3709999999996, 2872.512, 2971.9629999999997, 3066.857, 3157.337, 3243.547, 3325.633, 3403.742, 3478.018, 3548.607, 3615.6459999999997, 3679.272, 3739.617, 3796.809, 3850.969, 3902.217, 3950.664, 3996.421, 4039.59, 4080.27, 4118.557, 4154.542, 4188.31, 4219.944, 4249.523, 4277.121, 4302.812, 4326.662, 4348.738, 4369.101, 4387.812, 4404.9259999999995, 4420.498, 4434.581, 4447.223, 4458.472, 4468.373, 4476.971, 4484.306, 4490.417, 4495.345, 4499.124, 4501.79, 4503.376, 4503.916, 4503.439, 4501.977, 4499.556, 4496.205, 4491.951, 4486.819, 4480.832, 4474.016, 4466.392, 4457.983, 4448.81, 4438.893, 4428.252, 4416.905, 4404.872, 4392.169, 4378.815, 4364.825, 4350.215, 4335.002, 4319.1990000000005, 4302.822, 4285.885, 4268.401, 4250.383, 4231.845, 4212.7970000000005, 4193.254, 4173.226, 4152.724, 4131.76, 4110.344, 4088.487, 4066.198, 4043.488, 4020.366, 3996.841, 3972.922, 3948.619, 3923.9390000000003, 3898.8909999999996, 3873.4829999999997, 3847.723, 3821.618, 3795.177, 3768.406, 3741.312, 3713.903, 3686.1859999999997, 3658.1659999999997, 3629.85, 3601.245, 3572.357, 3543.191, 3513.7540000000004, 3484.052, 3454.0890000000004, 3423.8720000000003, 3393.406, 3362.696, 3331.748, 3300.565, 3269.1540000000005, 3237.5190000000002, 3205.664, 3173.595, 3141.316, 3108.8309999999997, 3076.145, 3043.262, 3010.185, 2976.92, 2943.4709999999995, 2909.84, 2876.032, 2842.052, 2807.901, 2773.585, 2739.107, 2704.47, 2669.678, 2634.7340000000004, 2599.641, 2564.404, 2529.024, 2493.506, 2457.8520000000003, 2422.0660000000003, 2386.15, 2350.107, 2313.9410000000003, 2277.654, 2241.25, 2204.73, 2168.098, 2131.356, 2094.507, 2057.554, 2020.5, 1983.346, 1946.095, 1908.751, 1871.315, 1833.79, 1796.1770000000001, 1758.481, 1720.7020000000002, 1682.844, 1644.9070000000002, 1606.896, 1568.8120000000001, 1530.656, 1492.432, 1454.141, 1415.786, 1377.369, 1338.891, 1300.355, 1261.763, 1223.117, 1184.4180000000001, 1145.6689999999999, 1106.872, 1068.028, 1029.14, 990.21, 951.238, 912.2280000000001, 873.181, 834.0989999999999, 794.9830000000001, 755.835, 716.658, 677.453, 638.222, 598.966, 559.687, 520.387, 481.06800000000004, 441.731, 402.37800000000004, 363.01, 323.63, 284.23900000000003, 244.83900000000003, 205.43, 166.016, 126.59700000000001, 87.175, 47.751000000000005, 8.328, -31.093000000000004, -70.51100000000001, -109.92399999999999, -149.33100000000002, -188.729, -228.118, -267.495, -306.86, -346.211, -385.546, -424.86300000000006, -464.162, -503.44, -542.697, -581.93, -621.138, -660.32, -699.4739999999999, -738.5980000000001, -777.692, -816.753, -855.7810000000001, -894.7719999999999, -933.727, -972.6439999999999, -1011.52, -1050.355, -1089.1480000000001, -1127.895, -1166.597, -1205.252, -1243.857, -1282.412, -1320.915, -1359.365, -1397.759, -1436.0970000000002, -1474.3770000000002, -1512.5970000000002, -1550.756, -1588.8529999999998, -1626.885, -1664.851, -1702.751, -1740.5810000000001, -1778.3410000000001, -1816.029, -1853.6429999999998, -1891.182, -1928.644, -1966.0279999999998, -2003.332, -2040.5539999999999, -2077.694, -2114.748, -2151.716, -2188.595, -2225.385, -2262.083, -2298.688, -2335.199, -2371.612, -2407.928, -2444.143, -2480.257, -2516.2670000000003, -2552.172, -2587.97, -2623.659, -2659.237, -2694.703, -2730.054, -2765.289, -2800.407, -2835.4040000000005, -2870.28, -2905.031, -2939.657, -2974.156, -3008.525, -3042.762, -3076.865, -3110.833, -3144.664, -3178.3540000000003, -3211.902, -3245.3070000000002, -3278.565, -3311.675, -3344.635, -3377.441, -3410.093, -3442.587, -3474.922, -3507.095, -3539.1040000000003, -3570.946, -3602.62, -3634.1209999999996, -3665.449, -3696.6009999999997, -3727.573, -3758.364, -3788.9709999999995, -3819.3909999999996, -3849.6209999999996, -3879.659, -3909.5029999999997, -3939.1479999999997, -3968.594, -3997.835, -4026.8709999999996, -4055.697, -4084.31, -4112.709, -4140.889, -4168.847, -4196.581, -4224.085999999999, -4251.36, -4278.4, -4305.201, -4331.7609999999995, -4358.076, -4384.143, -4409.957, -4435.515, -4460.813, -4485.848, -4510.615, -4535.111, -4559.332, -4583.273, -4606.93, -4630.299, -4653.376, -4676.156, -4698.635, -4720.808, -4742.67, -4764.217000000001, -4785.444, -4806.345, -4826.917, -4847.152, -4867.048, -4886.597, -4905.794, -4924.634, -4943.111, -4961.219, -4978.9529999999995, -4996.305, -5013.27, -5029.842000000001, -5046.013, -5061.777, -5077.128, -5092.058, -5106.56, -5120.627, -5134.251, -5147.425, -5160.14, -5172.388, -5184.162, -5195.4529999999995, -5206.252, -5216.55, -5226.338, -5235.606, -5244.345, -5252.545, -5260.196999999999, -5267.2880000000005, -5273.809, -5279.749, -5285.096, -5289.838000000001, -5293.965, -5297.4619999999995, -5300.318, -5302.519, -5304.053000000001, -5304.905, -5305.06, -5304.505, -5303.224, -5301.201, -5298.42, -5294.8640000000005, -5290.517, -5285.361, -5279.3769999999995, -5272.545999999999, -5264.849, -5256.265, -5246.774, -5236.353, -5224.981, -5212.634, -5199.288, -5184.919, -5169.5, -5153.004, -5135.404, -5116.6720000000005, -5096.776, -5075.687, -5053.372, -5029.795999999999, -5004.927, -4978.727, -4951.157999999999, -4922.182, -4891.758, -4859.843, -4826.394, -4791.363, -4754.704000000001, -4716.366, -4676.2970000000005, -4634.443, -4590.748, -4545.152, -4497.593, -4448.009, -4396.331, -4342.491, -4286.416, -4228.029, -4167.253, -4104.005999999999, -4038.203, -3969.755, -3898.571, -3824.5570000000002, -3747.614, -3667.643, -3584.54, -3498.198, -3408.511, -3315.37, -3218.665, -3118.2870000000003, -3014.127, -2906.0820000000003, -2794.05, -2677.938, -2557.663, -2433.153, -2304.35, -2171.221, -2033.751, -1891.9589999999998, -1745.895, -1595.652, -1441.365, -1283.223, -1121.4669999999999, -956.4010000000001, -788.3839999999999, -617.84, -445.24800000000005, -271.14099999999996, -96.09299999999999, 79.28699999999999, 254.37099999999998, 428.527, 601.133, 771.595, 939.3530000000001, 1103.902, 1264.792, 1421.6370000000002, 1574.116, 1721.973, 1865.017, 2003.1129999999998, 2136.18, 2264.1820000000002, 2387.125, 2505.048, 2618.021, 2726.132, 2829.491, 2928.218, 3022.445, 3112.31, 3197.9559999999997, 3279.526, 3357.164, 3431.014, 3501.217, 3567.909, 3631.2259999999997, 3691.297, 3748.248, 3802.2009999999996, 3853.2709999999997, 3901.571, 3947.296, 3990.283, 4030.895, 4069.138, 4105.102, 4138.871, 4170.528, 4200.15, 4227.812, 4253.583, 4277.532999999999, 4299.725, 4320.221, 4339.08, 4356.358, 4372.109, 4386.384, 4399.232, 4410.7, 4420.833, 4429.674, 4437.264, 4443.642, 4448.846, 4452.912, 4455.876, 4457.769, 4458.625, 4458.474, 4457.345, 4455.267, 4452.266, 4448.37, 4443.603, 4437.99, 4431.554, 4424.317, 4416.302, 4407.528, 4398.017, 4387.788, 4376.859, 4365.249, 4352.975, 4340.055, 4326.504, 4312.338, 4297.5740000000005, 4282.224, 4266.305, 4249.83, 4232.812, 4215.265, 4197.2, 4178.630999999999, 4159.569, 4140.026, 4120.013, 4099.541, 4078.62, 4057.261, 4035.474, 4013.268, 3990.653, 3967.638, 3944.232, 3920.4440000000004, 3896.281, 3871.7529999999997, 3846.868, 3821.632, 3796.054, 3770.1420000000003, 3743.902, 3717.341, 3690.467, 3663.285, 3635.804, 3608.028, 3579.9640000000004, 3551.619, 3522.998, 3494.1079999999997, 3464.953, 3435.539, 3405.8720000000003, 3375.958, 3345.8, 3315.405, 3284.778, 3253.922, 3222.844, 3191.547, 3160.0370000000003, 3128.317, 3096.393, 3064.2670000000003, 3031.946, 2999.4320000000002, 2966.7309999999998, 2933.845, 2900.778, 2867.5359999999996, 2834.12, 2800.5359999999996, 2766.7859999999996, 2732.875, 2698.805, 2664.58, 2630.204, 2595.68, 2561.01, 2526.199, 2491.249, 2456.1639999999998, 2420.947, 2385.599, 2350.126, 2314.529, 2278.811, 2242.975, 2207.024, 2170.9610000000002, 2134.7870000000003, 2098.507, 2062.123, 2025.636, 1989.05, 1952.3670000000002, 1915.59, 1878.721, 1841.763, 1804.717, 1767.586, 1730.3729999999998, 1693.08, 1655.7079999999999, 1618.261, 1580.741, 1543.148, 1505.487, 1467.759, 1429.965, 1392.109, 1354.191, 1316.215, 1278.182, 1240.094, 1201.953, 1163.761, 1125.52, 1087.232, 1048.899, 1010.5219999999999, 972.1039999999999, 933.6460000000001, 895.15, 856.618, 818.052, 779.454, 740.824, 702.166, 663.48, 624.769, 586.034, 547.2769999999999, 508.499, 469.70300000000003, 430.889, 392.06, 353.218, 314.363, 275.497, 236.623, 197.74099999999999, 158.85299999999998, 119.961, 81.067, 42.17100000000001, 3.2760000000000002, -35.617, -74.506, -113.39, -152.267, -191.136, -229.99599999999998, -268.844, -307.67900000000003, -346.5, -385.305, -424.093, -462.86199999999997, -501.61, -540.337, -579.04, -617.719, -656.3710000000001, -694.9960000000001, -733.591, -772.155, -810.687, -849.186, -887.6489999999999, -926.076, -964.4639999999999, -1002.813, -1041.12, -1079.385, -1117.606, -1155.781, -1193.9089999999999, -1231.988, -1270.018, -1307.996, -1345.92, -1383.7910000000002, -1421.605, -1459.361, -1497.059, -1534.695, -1572.27, -1609.781, -1647.227, -1684.605, -1721.9160000000002, -1759.1570000000002, -1796.326, -1833.4229999999998, -1870.444, -1907.39, -1944.2579999999998, -1981.047, -2017.754, -2054.38, -2090.9210000000003, -2127.376, -2163.744, -2200.0229999999997, -2236.2110000000002, -2272.3070000000002, -2308.308, -2344.214, -2380.0229999999997, -2415.732, -2451.34, -2486.846, -2522.2470000000003, -2557.542, -2592.729, -2627.8070000000002, -2662.772, -2697.625, -2732.362, -2766.982, -2801.4829999999997, -2835.863, -2870.1209999999996, -2904.2529999999997, -2938.259, -2972.137, -3005.883, -3039.498, -3072.9770000000003, -3106.32, -3139.5240000000003, -3172.587, -3205.508, -3238.283, -3270.9109999999996, -3303.389, -3335.716, -3367.889, -3399.906, -3431.764, -3463.462, -3494.9959999999996, -3526.366, -3557.567, -3588.598, -3619.4559999999997, -3650.138, -3680.643, -3710.968, -3741.11, -3771.066, -3800.833, -3830.41, -3859.7929999999997, -3888.9790000000003, -3917.966, -3946.7509999999997, -3975.3309999999997, -4003.702, -4031.863, -4059.809, -4087.538, -4115.0470000000005, -4142.331, -4169.39, -4196.218, -4222.812, -4249.17, -4275.287, -4301.16, -4326.786, -4352.161, -4377.281, -4402.142, -4426.741, -4451.073, -4475.1359999999995, -4498.924, -4522.433, -4545.66, -4568.599, -4591.248, -4613.6, -4635.653, -4657.4, -4678.838, -4699.962, -4720.766, -4741.246, -4761.396, -4781.212, -4800.688, -4819.818, -4838.598, -4857.021, -4875.082, -4892.774, -4910.093, -4927.031, -4943.582, -4959.74, -4975.498, -4990.85, -5005.788, -5020.306, -5034.396, -5048.0509999999995, -5061.264, -5074.026, -5086.329000000001, -5098.166, -5109.528, -5120.406, -5130.792, -5140.6759999999995, -5150.05, -5158.904, -5167.228, -5175.012, -5182.246, -5188.919, -5195.02, -5200.538, -5205.462, -5209.78, -5213.48, -5216.549, -5218.974, -5220.742, -5221.84, -5222.253, -5221.967000000001, -5220.965999999999, -5219.236, -5216.7609999999995, -5213.524, -5209.5070000000005, -5204.695, -5199.068, -5192.608, -5185.295999999999, -5177.111, -5168.034000000001, -5158.042, -5147.1140000000005, -5135.226, -5122.356, -5108.478, -5093.567, -5077.596, -5060.539000000001, -5042.367, -5023.05, -5002.558, -4980.859, -4957.92, -4933.707, -4908.184, -4881.314, -4853.058, -4823.376, -4792.226, -4759.565, -4725.348, -4689.526, -4652.052, -4612.873, -4571.936, -4529.185, -4484.562, -4438.005999999999, -4389.455, -4338.842000000001, -4286.098, -4231.152, -4173.929, -4114.352, -4052.341, -3987.81, -3920.673, -3850.84, -3778.216, -3702.7070000000003, -3624.211, -3542.6279999999997, -3457.8520000000003, -3369.777, -3278.296, -3183.298, -3084.677, -2982.325, -2876.138, -2766.015, -2651.865, -2533.6020000000003, -2411.155, -2284.467, -2153.5, -2018.24, -1878.701, -1734.932, -1587.02, -1435.096, -1279.343, -1119.995, -957.347, -791.752, -623.624, -453.43199999999996, -281.698, -108.988, 64.09899999999999, 236.94400000000002, 408.925, 579.4259999999999, 747.8580000000001, 913.669, 1076.354, 1235.4669999999999, 1390.6229999999998, 1541.503, 1687.848, 1829.4660000000001, 1966.22, 2098.026, 2224.848, 2346.687, 2463.58, 2575.592, 2682.809, 2785.3379999999997, 2883.296, 2976.812, 3066.0229999999997, 3151.065, 3232.0820000000003, 3309.2140000000004, 3382.603, 3452.388, 3518.703, 3581.6809999999996, 3641.4509999999996, 3698.136, 3751.8559999999998, 3802.7259999999997, 3850.8559999999998, 3896.3509999999997, 3939.313, 3979.8390000000004, 4018.0209999999997, 4053.947, 4087.703, 4119.3679999999995, 4149.021, 4176.732, 4202.573, 4226.611, 4248.909000000001, 4269.529, 4288.528, 4305.960999999999, 4321.883, 4336.344, 4349.392, 4361.0740000000005, 4371.433, 4380.513, 4388.355, 4394.996, 4400.474, 4404.826, 4408.085, 4410.284000000001, 4411.456, 4411.63, 4410.835, 4409.1, 4406.451, 4402.914000000001, 4398.515, 4393.277, 4387.223, 4380.376, 4372.7570000000005, 4364.387, 4355.286, 4345.473, 4334.967000000001, 4323.785, 4311.945, 4299.464, 4286.357, 4272.642, 4258.332, 4243.443, 4227.988, 4211.982, 4195.437, 4178.367, 4160.785, 4142.702, 4124.129, 4105.08, 4085.5640000000003, 4065.592, 4045.176, 4024.324, 4003.048, 3981.355, 3959.257, 3936.762, 3913.8779999999997, 3890.615, 3866.98, 3842.9829999999997, 3818.63, 3793.93, 3768.89, 3743.5170000000003, 3717.8190000000004, 3691.802, 3665.474, 3638.84, 3611.909, 3584.685, 3557.175, 3529.385, 3501.321, 3472.988, 3444.393, 3415.5409999999997, 3386.437, 3357.086, 3327.495, 3297.667, 3267.607, 3237.321, 3206.812, 3176.087, 3145.1490000000003, 3114.002, 3082.652, 3051.1009999999997, 3019.3559999999998, 2987.4179999999997, 2955.2940000000003, 2922.986, 2890.498, 2857.8340000000003, 2824.9990000000003, 2791.995, 2758.8259999999996, 2725.495, 2692.007, 2658.364, 2624.57, 2590.629, 2556.542, 2522.314, 2487.948, 2453.447, 2418.813, 2384.05, 2349.16, 2314.147, 2279.013, 2243.762, 2208.395, 2172.916, 2137.326, 2101.63, 2065.8289999999997, 2029.9260000000002, 1993.924, 1957.8239999999998, 1921.63, 1885.344, 1848.9679999999998, 1812.504, 1775.955, 1739.3239999999998, 1702.612, 1665.8210000000001, 1628.954, 1592.013, 1555.0, 1517.918, 1480.767, 1443.5520000000001, 1406.2720000000002, 1368.932, 1331.531, 1294.0739999999998, 1256.56, 1218.993, 1181.375, 1143.7060000000001, 1105.99, 1068.228, 1030.421, 992.572, 954.683, 916.755, 878.79, 840.79, 802.757, 764.691, 726.596, 688.4730000000001, 650.323, 612.148, 573.951, 535.731, 497.49199999999996, 459.235, 420.961, 382.67199999999997, 344.37, 306.056, 267.731, 229.399, 191.05900000000003, 152.714, 114.365, 76.014, 37.662, -0.69, -39.038000000000004, -77.384, -115.723, -154.056, -192.38099999999997, -230.695, -268.999, -307.289, -345.565, -383.825, -422.06800000000004, -460.292, -498.496, -536.678, -574.837, -612.971, -651.0790000000001, -689.159, -727.21, -765.2310000000001, -803.22, -841.175, -879.095, -916.9789999999999, -954.825, -992.6310000000001, -1030.397, -1068.12, -1105.8, -1143.434, -1181.022, -1218.562, -1256.052, -1293.49, -1330.8770000000002, -1368.2089999999998, -1405.485, -1442.705, -1479.866, -1516.967, -1554.006, -1590.9820000000002, -1627.894, -1664.739, -1701.517, -1738.226, -1774.8629999999998, -1811.4289999999999, -1847.921, -1884.3370000000002, -1920.6760000000002, -1956.9370000000001, -1993.118, -2029.2160000000001, -2065.232, -2101.1620000000003, -2137.006, -2172.762, -2208.428, -2244.002, -2279.4829999999997, -2314.869, -2350.159, -2385.35, -2420.4410000000003, -2455.431, -2490.317, -2525.098, -2559.772, -2594.337, -2628.7909999999997, -2663.133, -2697.361, -2731.473, -2765.467, -2799.341, -2833.093, -2866.722, -2900.225, -2933.6009999999997, -2966.847, -2999.961, -3032.9429999999998, -3065.788, -3098.4959999999996, -3131.0640000000003, -3163.491, -3195.7729999999997, -3227.909, -3259.8979999999997, -3291.735, -3323.42, -3354.95, -3386.323, -3417.5370000000003, -3448.5879999999997, -3479.4759999999997, -3510.196, -3540.7470000000003, -3571.1279999999997, -3601.3340000000003, -3631.363, -3661.2140000000004, -3690.882, -3720.367, -3749.664, -3778.772, -3807.688, -3836.408, -3864.929, -3893.25, -3921.368, -3949.278, -3976.978, -4004.466, -4031.738, -4058.79, -4085.6209999999996, -4112.226, -4138.602, -4164.746, -4190.654, -4216.323, -4241.75, -4266.93, -4291.861, -4316.538, -4340.958, -4365.116, -4389.01, -4412.634, -4435.986, -4459.06, -4481.853, -4504.36, -4526.577, -4548.499, -4570.122, -4591.442, -4612.4529999999995, -4633.15, -4653.53, -4673.585999999999, -4693.314, -4712.708, -4731.764, -4750.475, -4768.835999999999, -4786.840999999999, -4804.485, -4821.762, -4838.665, -4855.189, -4871.327, -4887.072, -4902.418, -4917.358, -4931.885, -4945.9929999999995, -4959.673, -4972.918, -4985.721, -4998.073, -5009.968, -5021.396, -5032.348, -5042.818, -5052.795, -5062.27, -5071.234, -5079.677, -5087.590999999999, -5094.963, -5101.785, -5108.045, -5113.732, -5118.835, -5123.343, -5127.2429999999995, -5130.523, -5133.17, -5135.1720000000005, -5136.515, -5137.184, -5137.167, -5136.447, -5135.0109999999995, -5132.840999999999, -5129.923, -5126.2390000000005, -5121.772, -5116.504, -5110.417, -5103.4929999999995, -5095.71, -5087.049, -5077.49, -5067.009, -5055.585999999999, -5043.195, -5029.814, -5015.417, -4999.977, -4983.469, -4965.8640000000005, -4947.133, -4927.247, -4906.1720000000005, -4883.878, -4860.331, -4835.494000000001, -4809.333, -4781.808, -4752.88, -4722.508, -4690.649, -4657.258, -4622.288, -4585.692, -4547.418, -4507.413, -4465.624, -4421.992, -4376.457, -4328.958, -4279.429, -4227.802, -4174.008, -4117.971, -4059.617, -3998.864, -3935.631, -3869.8309999999997, -3801.3759999999997, -3730.172, -3656.125, -3579.136, -3499.105, -3415.928, -3329.4990000000003, -3239.7140000000004, -3146.462, -3049.637, -2949.133, -2844.847, -2736.678, -2624.535, -2508.3320000000003, -2387.998, -2263.475, -2134.723, -2001.727, -1864.499, -1723.0839999999998, -1577.5639999999999, -1428.067, -1274.767, -1117.895, -957.735, -794.633, -628.993, -461.274, -291.99, -121.695, 49.023, 219.553, 389.28, 557.5980000000001, 723.924, 887.71, 1048.4569999999999, 1205.719, 1359.115, 1508.3239999999998, 1653.089, 1793.215, 1928.5639999999999, 2059.049, 2184.631, 2305.3089999999997, 2421.117, 2532.116, 2638.39, 2740.042, 2837.1859999999997, 2929.948, 3018.462, 3102.862, 3183.2870000000003, 3259.8779999999997, 3332.7729999999997, 3402.107, 3468.015, 3530.627, 3590.0679999999998, 3646.461, 3699.9240000000004, 3750.57, 3798.508, 3843.841, 3886.671, 3927.092, 3965.195, 4001.0679999999998, 4034.795, 4066.454, 4096.123, 4123.871, 4149.77, 4173.8859999999995, 4196.28, 4217.014, 4236.144, 4253.726, 4269.812, 4284.452, 4297.694, 4309.584, 4320.166, 4329.481, 4337.57, 4344.471, 4350.221, 4354.856, 4358.41, 4360.914000000001, 4362.401, 4362.899, 4362.439, 4361.0470000000005, 4358.751, 4355.576, 4351.545999999999, 4346.685, 4341.017, 4334.563, 4327.344, 4319.380999999999, 4310.694, 4301.3009999999995, 4291.222, 4280.473, 4269.072, 4257.036, 4244.38, 4231.12, 4217.272, 4202.848, 4187.865, 4172.335, 4156.271, 4139.686, 4122.593, 4105.004, 4086.929, 4068.382, 4049.3709999999996, 4029.909, 4010.006, 3989.671, 3968.914, 3947.745, 3926.173, 3904.2070000000003, 3881.8559999999998, 3859.1279999999997, 3836.032, 3812.575, 3788.7659999999996, 3764.612, 3740.12, 3715.298, 3690.153, 3664.692, 3638.921, 3612.848, 3586.478, 3559.817, 3532.873, 3505.65, 3478.155, 3450.3940000000002, 3422.3709999999996, 3394.093, 3365.5640000000003, 3336.7909999999997, 3307.777, 3278.528, 3249.05, 3219.345, 3189.421, 3159.28, 3128.927, 3098.367, 3067.6040000000003, 3036.643, 3005.486, 2974.14, 2942.6059999999998, 2910.89, 2878.995, 2846.9240000000004, 2814.683, 2782.2729999999997, 2749.699, 2716.965, 2684.073, 2651.027, 2617.83, 2584.486, 2550.9970000000003, 2517.367, 2483.599, 2449.696, 2415.661, 2381.4970000000003, 2347.2070000000003, 2312.7929999999997, 2278.259, 2243.607, 2208.84, 2173.96, 2138.97, 2103.873, 2068.672, 2033.368, 1997.965, 1962.464, 1926.869, 1891.181, 1855.4029999999998, 1819.5379999999998, 1783.586, 1747.5520000000001, 1711.4370000000001, 1675.243, 1638.9720000000002, 1602.6270000000002, 1566.21, 1529.7220000000002, 1493.1660000000002, 1456.5439999999999, 1419.858, 1383.11, 1346.3020000000001, 1309.4360000000001, 1272.513, 1235.537, 1198.508, 1161.428, 1124.3, 1087.125, 1049.906, 1012.643, 975.3380000000001, 937.995, 900.613, 863.196, 825.7439999999999, 788.2589999999999, 750.7439999999999, 713.199, 675.627, 638.03, 600.408, 562.763, 525.0980000000001, 487.413, 449.71, 411.99199999999996, 374.259, 336.51300000000003, 298.756, 260.98900000000003, 223.21400000000003, 185.433, 147.64600000000002, 109.855, 72.063, 34.27, -3.522, -41.312, -79.097, -116.87700000000001, -154.65, -192.415, -230.17, -267.913, -305.643, -343.36, -381.06, -418.74300000000005, -456.407, -494.051, -531.674, -569.273, -606.8480000000001, -644.3969999999999, -681.918, -719.4110000000001, -756.873, -794.304, -831.701, -869.064, -906.3910000000001, -943.68, -980.93, -1018.14, -1055.307, -1092.432, -1129.512, -1166.545, -1203.531, -1240.468, -1277.354, -1314.1879999999999, -1350.9679999999998, -1387.694, -1424.3629999999998, -1460.974, -1497.526, -1534.016, -1570.445, -1606.809, -1643.108, -1679.34, -1715.503, -1751.5970000000002, -1787.618, -1823.567, -1859.441, -1895.239, -1930.96, -1966.601, -2002.161, -2037.638, -2073.031, -2108.339, -2143.56, -2178.6910000000003, -2213.732, -2248.68, -2283.535, -2318.294, -2352.956, -2387.518, -2421.98, -2456.34, -2490.595, -2524.745, -2558.7870000000003, -2592.719, -2626.54, -2660.248, -2693.84, -2727.316, -2760.6740000000004, -2793.9109999999996, -2827.025, -2860.015, -2892.8779999999997, -2925.614, -2958.219, -2990.691, -3023.03, -3055.232, -3087.295, -3119.218, -3150.9990000000003, -3182.634, -3214.123, -3245.462, -3276.65, -3307.685, -3338.5640000000003, -3369.284, -3399.844, -3430.242, -3460.474, -3490.5370000000003, -3520.4309999999996, -3550.152, -3579.699, -3609.0679999999998, -3638.256, -3667.261, -3696.0809999999997, -3724.712, -3753.153, -3781.4, -3809.45, -3837.3, -3864.948, -3892.3909999999996, -3919.6259999999997, -3946.6490000000003, -3973.4570000000003, -4000.048, -4026.4179999999997, -4052.5640000000003, -4078.4829999999997, -4104.170999999999, -4129.625, -4154.842000000001, -4179.817, -4204.5470000000005, -4229.03, -4253.26, -4277.234, -4300.948, -4324.399, -4347.583, -4370.494000000001, -4393.13, -4415.486, -4437.558, -4459.34, -4480.83, -4502.022, -4522.911, -4543.4929999999995, -4563.764, -4583.717000000001, -4603.348, -4622.653, -4641.625, -4660.259, -4678.55, -4696.4929999999995, -4714.081, -4731.308, -4748.169, -4764.657999999999, -4780.769, -4796.494000000001, -4811.8279999999995, -4826.763, -4841.293, -4855.412, -4869.111, -4882.383, -4895.221, -4907.6179999999995, -4919.564, -4931.053, -4942.076, -4952.624, -4962.689, -4972.2609999999995, -4981.332, -4989.891, -4997.93, -5005.438, -5012.406, -5018.821, -5024.675, -5029.955, -5034.65, -5038.749, -5042.238, -5045.107, -5047.340999999999, -5048.928, -5049.854, -5050.106, -5049.667, -5048.525, -5046.662, -5044.064, -5040.713, -5036.594, -5031.687, -5025.976, -5019.442, -5012.065, -5003.825, -4994.702, -4984.674, -4973.719, -4961.814, -4948.935, -4935.057, -4920.156, -4904.204000000001, -4887.174, -4869.037, -4849.764, -4829.3240000000005, -4807.684, -4784.813, -4760.674, -4735.232, -4708.45, -4680.288, -4650.707, -4619.663, -4587.113, -4553.01, -4517.307, -4479.955, -4440.901, -4400.090999999999, -4357.468, -4312.974, -4266.548, -4218.124, -4167.637, -4115.017, -4060.191, -4003.085, -3943.618, -3881.71, -3817.276, -3750.228, -3680.475, -3607.923, -3532.475, -3454.031, -3372.489, -3287.745, -3199.6929999999998, -3108.2290000000003, -3013.243, -2914.631, -2812.2909999999997, -2706.123, -2596.036, -2481.945, -2363.777, -2241.474, -2114.995, -1984.3220000000001, -1849.4660000000001, -1710.467, -1567.404, -1420.4, -1269.624, -1115.297, -957.697, -797.1619999999999, -634.085, -468.917, -302.159, -134.356, 33.914, 202.05, 369.44699999999995, 535.506, 699.65, 861.337, 1020.072, 1175.413, 1326.979, 1474.451, 1617.57, 1756.142, 1890.025, 2019.132, 2143.419, 2262.883, 2377.555, 2487.492, 2592.777, 2693.507, 2789.795, 2881.764, 2969.5409999999997, 3053.263, 3133.063, 3209.08, 3281.449, 3350.304, 3415.776, 3477.994, 3537.0820000000003, 3593.159, 3646.343, 3696.744, 3744.469, 3789.816, 3832.301, 3872.6, 3910.6090000000004, 3946.414, 3980.098, 4011.738, 4041.4109999999996, 4069.1859999999997, 4095.132, 4119.315, 4141.7970000000005, 4162.6359999999995, 4181.89, 4199.6140000000005, 4215.857, 4230.670999999999, 4244.102, 4256.196, 4266.996, 4276.543, 4284.877, 4292.036, 4298.056, 4302.973, 4306.82, 4309.629, 4311.43, 4312.254, 4312.129, 4311.083, 4309.14, 4306.3279999999995, 4302.67, 4298.19, 4292.91, 4286.852, 4280.037, 4272.485, 4264.215999999999, 4255.249, 4245.601, 4235.291, 4224.334, 4212.749, 4200.549, 4187.752, 4174.371, 4160.420999999999, 4145.916, 4130.869000000001, 4115.293, 4099.202, 4082.6059999999998, 4065.518, 4047.95, 4029.913, 4011.417, 3992.473, 3973.092, 3953.283, 3933.055, 3912.4190000000003, 3891.384, 3869.9570000000003, 3848.1490000000003, 3825.967, 3803.4190000000003, 3780.514, 3757.259, 3733.6620000000003, 3709.73, 3685.47, 3660.89, 3635.995, 3610.7940000000003, 3585.292, 3559.495, 3533.41, 3507.0440000000003, 3480.401, 3453.487, 3426.309, 3398.8709999999996, 3371.179, 3343.239, 3315.055, 3286.633, 3257.9770000000003, 3229.093, 3199.9840000000004, 3170.656, 3141.113, 3111.36, 3081.3990000000003, 3051.238, 3020.88, 2990.327, 2959.5840000000003, 2928.656, 2897.546, 2866.257, 2834.795, 2803.1620000000003, 2771.361, 2739.397, 2707.2729999999997, 2674.991, 2642.5570000000002, 2609.972, 2577.24, 2544.364, 2511.347, 2478.1929999999998, 2444.904, 2411.4829999999997, 2377.933, 2344.257, 2310.458, 2276.5389999999998, 2242.501, 2208.349, 2174.084, 2139.71, 2105.228, 2070.6420000000003, 2035.953, 2001.164, 1966.279, 1931.2979999999998, 1896.224, 1861.0610000000001, 1825.809, 1790.4720000000002, 1755.0510000000002, 1719.5479999999998, 1683.967, 1648.309, 1612.576, 1576.77, 1540.8929999999998, 1504.9479999999999, 1468.9360000000001, 1432.86, 1396.721, 1360.5220000000002, 1324.263, 1287.948, 1251.578, 1215.155, 1178.681, 1142.1580000000001, 1105.587, 1068.97, 1032.31, 995.607, 958.8639999999999, 922.0830000000001, 885.2639999999999, 848.4110000000001, 811.5239999999999, 774.605, 737.6560000000001, 700.678, 663.674, 626.645, 589.592, 552.5169999999999, 515.4209999999999, 478.30699999999996, 441.176, 404.029, 366.869, 329.695, 292.51099999999997, 255.317, 218.11599999999999, 180.908, 143.695, 106.479, 69.26100000000001, 32.043, -5.1739999999999995, -42.388999999999996, -79.59899999999999, -116.804, -154.002, -191.192, -228.37099999999998, -265.539, -302.694, -339.835, -376.961, -414.069, -451.158, -488.228, -525.276, -562.3009999999999, -599.302, -636.2769999999999, -673.225, -710.1439999999999, -747.033, -783.8910000000001, -820.716, -857.507, -894.262, -930.98, -967.66, -1004.299, -1040.897, -1077.453, -1113.964, -1150.4289999999999, -1186.847, -1223.2169999999999, -1259.536, -1295.8039999999999, -1332.02, -1368.18, -1404.285, -1440.3329999999999, -1476.3220000000001, -1512.251, -1548.118, -1583.922, -1619.661, -1655.3339999999998, -1690.9389999999999, -1726.475, -1761.94, -1797.3339999999998, -1832.6529999999998, -1867.8970000000002, -1903.0639999999999, -1938.1529999999998, -1973.162, -2008.089, -2042.933, -2077.692, -2112.365, -2146.95, -2181.445, -2215.85, -2250.161, -2284.3779999999997, -2318.498, -2352.521, -2386.444, -2420.265, -2453.984, -2487.598, -2521.105, -2554.504, -2587.7929999999997, -2620.97, -2654.033, -2686.98, -2719.81, -2752.5209999999997, -2785.111, -2817.577, -2849.9179999999997, -2882.133, -2914.218, -2946.173, -2977.994, -3009.68, -3041.23, -3072.64, -3103.909, -3135.034, -3166.014, -3196.847, -3227.5290000000005, -3258.059, -3288.4359999999997, -3318.655, -3348.715, -3378.612, -3408.347, -3437.9159999999997, -3467.316, -3496.545, -3525.6, -3554.4790000000003, -3583.18, -3611.699, -3640.034, -3668.1820000000002, -3696.1409999999996, -3723.907, -3751.4790000000003, -3778.8520000000003, -3806.025, -3832.994, -3859.756, -3886.309, -3912.6490000000003, -3938.772, -3964.677, -3990.3590000000004, -4015.815, -4041.0429999999997, -4066.0370000000003, -4090.796, -4115.316, -4139.592000000001, -4163.621, -4187.401, -4210.925, -4234.192, -4257.197, -4279.936, -4302.405, -4324.599, -4346.515, -4368.149, -4389.495, -4410.55, -4431.308, -4451.766, -4471.918, -4491.759, -4511.285, -4530.491, -4549.371, -4567.92, -4586.133, -4604.004, -4621.528, -4638.6990000000005, -4655.51, -4671.957, -4688.032, -4703.731, -4719.045, -4733.969, -4748.496, -4762.619000000001, -4776.33, -4789.624, -4802.492, -4814.9259999999995, -4826.92, -4838.464, -4849.552, -4860.174, -4870.322, -4879.987, -4889.159000000001, -4897.831, -4905.992, -4913.6320000000005, -4920.742, -4927.31, -4933.327, -4938.781, -4943.662, -4947.957, -4951.654, -4954.742, -4957.208, -4959.039000000001, -4960.221, -4960.74, -4960.583, -4959.734, -4958.179, -4955.902, -4952.8859999999995, -4949.115, -4944.572, -4939.2390000000005, -4933.098, -4926.129, -4918.313, -4909.63, -4900.058, -4889.576, -4878.161, -4865.79, -4852.438, -4838.08, -4822.691, -4806.2429999999995, -4788.708, -4770.056, -4750.259, -4729.282999999999, -4707.096, -4683.665, -4658.954000000001, -4632.925, -4605.542, -4576.763, -4546.548, -4514.852, -4481.63, -4446.837, -4410.4220000000005, -4372.334, -4332.52, -4290.925, -4247.491, -4202.157, -4154.86, -4105.534000000001, -4054.111, -4000.518, -3944.683, -3886.528, -3825.9709999999995, -3762.93, -3697.3179999999998, -3629.045, -3558.018, -3484.1420000000003, -3407.3190000000004, -3327.447, -3244.423, -3158.143, -3068.5029999999997, -2975.395, -2878.718, -2778.367, -2674.2459999999996, -2566.263, -2454.3320000000003, -2338.38, -2218.349, -2094.197, -1965.904, -1833.4779999999998, -1696.957, -1556.414, -1411.9660000000001, -1263.779, -1112.066, -957.097, -799.201, -638.761, -476.218, -312.062, -146.829, 18.914, 184.578, 349.566, 513.286, 675.17, 834.681, 991.328, 1144.673, 1294.336, 1439.9979999999998, 1581.4029999999998, 1718.3529999999998, 1850.7060000000001, 1978.371, 2101.302, 2219.495, 2332.975, 2441.799, 2546.0429999999997, 2645.802, 2741.187, 2832.317, 2919.317, 3002.3190000000004, 3081.4559999999997, 3156.863, 3228.671, 3297.014, 3362.0190000000002, 3423.813, 3482.5190000000002, 3538.2540000000004, 3591.132, 3641.264, 3688.755, 3733.7059999999997, 3776.2140000000004, 3816.3720000000003, 3854.2690000000002, 3889.989, 3923.613, 3955.219, 3984.881, 4012.6690000000003, 4038.65, 4062.889, 4085.447, 4106.3820000000005, 4125.751, 4143.607, 4160.001, 4174.982, 4188.596, 4200.888, 4211.9, 4221.675, 4230.25, 4237.663, 4243.951, 4249.147, 4253.285, 4256.397, 4258.512, 4259.661, 4259.871, 4259.17, 4257.583, 4255.135, 4251.85, 4247.752, 4242.863, 4237.204000000001, 4230.795, 4223.657999999999, 4215.811, 4207.273, 4198.061, 4188.194, 4177.687, 4166.557, 4154.82, 4142.49, 4129.583, 4116.113, 4102.092000000001, 4087.5359999999996, 4072.4559999999997, 4056.865, 4040.7740000000003, 4024.196, 4007.1420000000003, 3989.6240000000003, 3971.651, 3953.2340000000004, 3934.383, 3915.1090000000004, 3895.42, 3875.327, 3854.837, 3833.96, 3812.704, 3791.077, 3769.0890000000004, 3746.745, 3724.055, 3701.026, 3677.664, 3653.978, 3629.973, 3605.657, 3581.0370000000003, 3556.118, 3530.906, 3505.409, 3479.632, 3453.5809999999997, 3427.261, 3400.678, 3373.8379999999997, 3346.7459999999996, 3319.407, 3291.825, 3264.007, 3235.9570000000003, 3207.68, 3179.18, 3150.462, 3121.531, 3092.39, 3063.0440000000003, 3033.498, 3003.755, 2973.8190000000004, 2943.695, 2913.386, 2882.8959999999997, 2852.2290000000003, 2821.389, 2790.3779999999997, 2759.2009999999996, 2727.861, 2696.362, 2664.7059999999997, 2632.8979999999997, 2600.94, 2568.835, 2536.587, 2504.198, 2471.673, 2439.012, 2406.221, 2373.301, 2340.255, 2307.0860000000002, 2273.7960000000003, 2240.39, 2206.868, 2173.234, 2139.49, 2105.639, 2071.683, 2037.625, 2003.4679999999998, 1969.2120000000002, 1934.862, 1900.4189999999999, 1865.886, 1831.264, 1796.556, 1761.765, 1726.892, 1691.94, 1656.91, 1621.805, 1586.6270000000002, 1551.378, 1516.06, 1480.675, 1445.225, 1409.711, 1374.1370000000002, 1338.503, 1302.812, 1267.065, 1231.265, 1195.413, 1159.511, 1123.5610000000001, 1087.5639999999999, 1051.5230000000001, 1015.438, 979.313, 943.148, 906.946, 870.707, 834.434, 798.1289999999999, 761.7919999999999, 725.426, 689.0319999999999, 652.612, 616.168, 579.7, 543.211, 506.702, 470.175, 433.63199999999995, 397.07300000000004, 360.5, 323.916, 287.32, 250.71599999999998, 214.104, 177.486, 140.863, 104.23700000000001, 67.609, 30.982, -5.645, -42.269, -78.888, -115.50299999999999, -152.11, -188.708, -225.297, -261.874, -298.439, -334.99, -371.525, -408.042, -444.542, -481.022, -517.48, -553.9159999999999, -590.328, -626.714, -663.074, -699.405, -735.707, -771.9780000000001, -808.216, -844.42, -880.5889999999999, -916.722, -952.816, -988.8710000000001, -1024.885, -1060.857, -1096.785, -1132.6680000000001, -1168.504, -1204.2930000000001, -1240.032, -1275.72, -1311.3570000000002, -1346.9389999999999, -1382.4660000000001, -1417.9370000000001, -1453.35, -1488.703, -1523.996, -1559.226, -1594.392, -1629.493, -1664.527, -1699.4920000000002, -1734.388, -1769.213, -1803.964, -1838.642, -1873.243, -1907.767, -1942.2120000000002, -1976.576, -2010.859, -2045.057, -2079.1710000000003, -2113.197, -2147.135, -2180.9829999999997, -2214.739, -2248.402, -2281.969, -2315.44, -2348.813, -2382.085, -2415.255, -2448.322, -2481.284, -2514.138, -2546.884, -2579.519, -2612.042, -2644.45, -2676.742, -2708.917, -2740.9709999999995, -2772.9040000000005, -2804.7129999999997, -2836.3959999999997, -2867.952, -2899.3779999999997, -2930.673, -2961.8340000000003, -2992.86, -3023.748, -3054.4959999999996, -3085.1020000000003, -3115.5640000000003, -3145.88, -3176.048, -3206.065, -3235.929, -3265.638, -3295.19, -3324.5809999999997, -3353.8109999999997, -3382.8759999999997, -3411.7740000000003, -3440.502, -3469.059, -3497.441, -3525.6459999999997, -3553.671, -3581.514, -3609.172, -3636.643, -3663.923, -3691.009, -3717.8990000000003, -3744.591, -3771.08, -3797.364, -3823.44, -3849.3059999999996, -3874.9570000000003, -3900.39, -3925.603, -3950.592, -3975.3540000000003, -3999.885, -4024.1820000000002, -4048.241, -4072.059, -4095.632, -4118.956, -4142.028, -4164.844, -4187.399, -4209.69, -4231.713, -4253.464, -4274.938, -4296.130999999999, -4317.038, -4337.656, -4357.98, -4378.004, -4397.724, -4417.1359999999995, -4436.234, -4455.013, -4473.469, -4491.595, -4509.3859999999995, -4526.838, -4543.943, -4560.698, -4577.094, -4593.128, -4608.791, -4624.079000000001, -4638.985, -4653.502, -4667.622, -4681.34, -4694.649, -4707.54, -4720.0070000000005, -4732.041, -4743.6359999999995, -4754.782999999999, -4765.474, -4775.7, -4785.452, -4794.723, -4803.502, -4811.781, -4819.55, -4826.798, -4833.516, -4839.693, -4845.319, -4850.3820000000005, -4854.871, -4858.774, -4862.08, -4864.776, -4866.848, -4868.285, -4869.072, -4869.195, -4868.641, -4867.393, -4865.437, -4862.7570000000005, -4859.335999999999, -4855.157999999999, -4850.205, -4844.459, -4837.901, -4830.512, -4822.272, -4813.16, -4803.155, -4792.235, -4780.376, -4767.556, -4753.748, -4738.928, -4723.069, -4706.143, -4688.121, -4668.973, -4648.67, -4627.178, -4604.464, -4580.494000000001, -4555.23, -4528.6359999999995, -4500.6720000000005, -4471.2970000000005, -4440.469, -4408.143, -4374.273, -4338.811, -4301.706, -4262.905, -4222.356, -4179.999, -4135.776, -4089.6259999999997, -4041.482, -3991.277, -3938.941, -3884.401, -3827.5820000000003, -3768.402, -3706.781, -3642.633, -3575.869, -3506.3990000000003, -3434.1259999999997, -3358.9570000000003, -3280.788, -3199.52, -3115.05, -3027.272, -2936.0840000000003, -2841.382, -2743.065, -2641.035, -2535.202, -2425.48, -2311.795, -2194.089, -2072.3179999999998, -1946.4620000000002, -1816.524, -1682.54, -1544.58, -1402.756, -1257.224, -1108.194, -955.927, -800.743, -643.014, -483.17199999999997, -321.697, -159.112, 4.026, 167.138, 329.63599999999997, 490.939, 650.4830000000001, 807.74, 962.222, 1113.495, 1261.181, 1404.963, 1544.5829999999999, 1679.844, 1810.6, 1936.76, 2058.276, 2175.138, 2287.37, 2395.026, 2498.177, 2596.917, 2691.3520000000003, 2781.598, 2867.778, 2950.02, 3028.455, 3103.2140000000004, 3174.427, 3242.224, 3306.73, 3368.071, 3426.366, 3481.7309999999998, 3534.278, 3584.117, 3631.35, 3676.077, 3718.3940000000002, 3758.3909999999996, 3796.157, 3831.7740000000003, 3865.323, 3896.88, 3926.5170000000003, 3954.305, 3980.308, 4004.592, 4027.215, 4048.236, 4067.711, 4085.69, 4102.226, 4117.367, 4131.156, 4143.64, 4154.86, 4164.857, 4173.669, 4181.333, 4187.885, 4193.358, 4197.785, 4201.198, 4203.627, 4205.1, 4205.645, 4205.289000000001, 4204.058, 4201.975, 4199.065, 4195.351, 4190.855, 4185.597, 4179.599, 4172.879, 4165.458, 4157.352, 4148.581, 4139.161, 4129.109, 4118.44, 4107.17, 4095.315, 4082.887, 4069.902, 4056.373, 4042.313, 4027.736, 4012.652, 3997.074, 3981.014, 3964.482, 3947.49, 3930.048, 3912.167, 3893.8559999999998, 3875.1259999999997, 3855.985, 3836.4429999999998, 3816.508, 3796.19, 3775.4970000000003, 3754.4359999999997, 3733.0170000000003, 3711.2459999999996, 3689.131, 3666.68, 3643.9, 3620.798, 3597.38, 3573.6540000000005, 3549.625, 3525.301, 3500.687, 3475.789, 3450.614, 3425.1659999999997, 3399.453, 3373.478, 3347.248, 3320.7670000000003, 3294.042, 3267.0759999999996, 3239.875, 3212.4440000000004, 3184.788, 3156.91, 3128.815, 3100.509, 3071.994, 3043.276, 3014.3590000000004, 2985.2459999999996, 2955.941, 2926.45, 2896.7740000000003, 2866.9190000000003, 2836.887, 2806.683, 2776.31, 2745.7709999999997, 2715.07, 2684.21, 2653.195, 2622.027, 2590.7110000000002, 2559.248, 2527.643, 2495.8979999999997, 2464.016, 2432.0, 2399.853, 2367.577, 2335.177, 2302.653, 2270.01, 2237.249, 2204.373, 2171.386, 2138.288, 2105.084, 2071.775, 2038.364, 2004.8529999999998, 1971.244, 1937.54, 1903.744, 1869.856, 1835.881, 1801.819, 1767.674, 1733.4460000000001, 1699.139, 1664.754, 1630.2939999999999, 1595.76, 1561.155, 1526.481, 1491.739, 1456.931, 1422.06, 1387.1270000000002, 1352.134, 1317.0839999999998, 1281.9769999999999, 1246.816, 1211.603, 1176.339, 1141.026, 1105.6660000000002, 1070.26, 1034.8110000000001, 999.32, 963.789, 928.22, 892.613, 856.971, 821.296, 785.5880000000001, 749.8510000000001, 714.084, 678.291, 642.472, 606.628, 570.763, 534.876, 498.971, 463.04699999999997, 427.10699999999997, 391.152, 355.184, 319.204, 283.214, 247.215, 211.209, 175.196, 139.179, 103.16, 67.138, 31.116999999999997, -4.9030000000000005, -40.921, -76.934, -112.94200000000001, -148.94299999999998, -184.935, -220.917, -256.889, -292.847, -328.792, -364.722, -400.634, -436.528, -472.403, -508.25699999999995, -544.089, -579.8969999999999, -615.68, -651.436, -687.164, -722.8639999999999, -758.5319999999999, -794.169, -829.7719999999999, -865.341, -900.8739999999999, -936.3689999999999, -971.825, -1007.24, -1042.615, -1077.9460000000001, -1113.232, -1148.473, -1183.6660000000002, -1218.8110000000001, -1253.906, -1288.9489999999998, -1323.94, -1358.876, -1393.756, -1428.579, -1463.3429999999998, -1498.0479999999998, -1532.691, -1567.271, -1601.786, -1636.236, -1670.618, -1704.932, -1739.175, -1773.346, -1807.444, -1841.467, -1875.414, -1909.283, -1943.0720000000001, -1976.78, -2010.406, -2043.9479999999999, -2077.404, -2110.772, -2144.052, -2177.241, -2210.3379999999997, -2243.341, -2276.248, -2309.0589999999997, -2341.771, -2374.382, -2406.891, -2439.295, -2471.595, -2503.786, -2535.869, -2567.84, -2599.699, -2631.4429999999998, -2663.07, -2694.579, -2725.968, -2757.2340000000004, -2788.377, -2819.393, -2850.282, -2881.04, -2911.667, -2942.159, -2972.515, -3002.7340000000004, -3032.8109999999997, -3062.7470000000003, -3092.538, -3122.1820000000002, -3151.677, -3181.022, -3210.212, -3239.2470000000003, -3268.1240000000003, -3296.84, -3325.3940000000002, -3353.783, -3382.0029999999997, -3410.054, -3437.9320000000002, -3465.634, -3493.159, -3520.5029999999997, -3547.664, -3574.64, -3601.426, -3628.0209999999997, -3654.422, -3680.6259999999997, -3706.63, -3732.43, -3758.025, -3783.41, -3808.583, -3833.5409999999997, -3858.28, -3882.797, -3907.0879999999997, -3931.151, -3954.982, -3978.577, -4001.933, -4025.045, -4047.9120000000003, -4070.527, -4092.889, -4114.992, -4136.833, -4158.407999999999, -4179.712, -4200.742, -4221.4929999999995, -4241.96, -4262.14, -4282.027, -4301.617, -4320.905, -4339.8859999999995, -4358.556, -4376.907999999999, -4394.939, -4412.643, -4430.013, -4447.045999999999, -4463.734, -4480.073, -4496.057, -4511.679, -4526.933, -4541.813, -4556.312, -4570.424, -4584.141, -4597.458, -4610.366, -4622.859, -4634.929, -4646.569, -4657.769, -4668.523, -4678.823, -4688.659000000001, -4698.023, -4706.905, -4715.298, -4723.191, -4730.5740000000005, -4737.438, -4743.772, -4749.566, -4754.809, -4759.49, -4763.597, -4767.119000000001, -4770.043, -4772.357, -4774.0470000000005, -4775.101, -4775.504, -4775.244000000001, -4774.304, -4772.67, -4770.326, -4767.2570000000005, -4763.445, -4758.874, -4753.525, -4747.380999999999, -4740.4220000000005, -4732.628, -4723.981, -4714.457, -4704.036, -4692.695, -4680.411, -4667.159000000001, -4652.914000000001, -4637.651, -4621.340999999999, -4603.956, -4585.468, -4565.846, -4545.058, -4523.072, -4499.853, -4475.365, -4449.572, -4422.436, -4393.915, -4363.968, -4332.552, -4299.62, -4265.127, -4229.021, -4191.252, -4151.765, -4110.505, -4067.414, -4022.43, -3975.49, -3926.526, -3875.47, -3822.2509999999997, -3766.792, -3709.0170000000003, -3648.843, -3586.188, -3520.9640000000004, -3453.08, -3382.445, -3308.961, -3232.533, -3153.0570000000002, -3070.434, -2984.56, -2895.333, -2802.65, -2706.4109999999996, -2606.519, -2502.883, -2395.42, -2284.055, -2168.728, -2049.396, -1926.0339999999999, -1798.645, -1667.261, -1531.9479999999999, -1392.8129999999999, -1250.007, -1103.73, -954.238, -801.8389999999999, -646.898, -489.835, -331.119, -171.261, -10.808, 149.672, 309.601, 468.406, 625.5319999999999, 780.457, 932.698, 1081.8239999999998, 1227.46, 1369.289, 1507.056, 1640.56, 1769.655, 1894.249, 2014.2879999999998, 2129.762, 2240.692, 2347.127, 2449.136, 2546.8089999999997, 2640.248, 2729.566, 2814.885, 2896.327, 2974.022, 3048.097, 3118.68, 3185.8979999999997, 3249.875, 3310.7329999999997, 3368.5890000000004, 3423.558, 3475.75, 3525.2709999999997, 3572.225, 3616.823, 3658.8109999999997, 3698.6290000000004, 3736.2459999999996, 3771.745, 3805.203, 3836.695, 3866.2940000000003, 3894.0679999999998, 3920.0820000000003, 3944.3990000000003, 3967.077, 3988.1740000000004, 4007.745, 4025.84, 4042.51, 4057.803, 4071.763, 4084.433, 4095.8559999999998, 4106.071, 4115.115, 4123.027, 4129.839, 4135.587, 4140.302, 4144.015, 4146.755999999999, 4148.553, 4149.433, 4149.423, 4148.548, 4146.832, 4144.298, 4140.97, 4136.869000000001, 4132.015, 4126.43, 4120.1320000000005, 4113.14, 4105.472, 4097.145, 4088.177, 4078.5840000000003, 4068.382, 4057.585, 4046.2090000000003, 4034.268, 4021.775, 4008.744, 3995.188, 3981.119, 3966.55, 3951.492, 3935.9570000000003, 3919.9559999999997, 3903.4990000000003, 3886.5959999999995, 3869.259, 3851.4970000000003, 3833.32, 3814.736, 3795.755, 3776.385, 3756.636, 3736.515, 3716.031, 3695.191, 3674.0029999999997, 3652.474, 3630.613, 3608.425, 3585.9179999999997, 3563.099, 3539.973, 3516.5490000000004, 3492.8309999999997, 3468.825, 3444.539, 3419.9770000000003, 3395.1459999999997, 3370.051, 3344.696, 3319.0890000000004, 3293.2329999999997, 3267.134, 3240.797, 3214.2270000000003, 3187.427, 3160.4040000000005, 3133.1620000000003, 3105.704, 3078.0359999999996, 3050.1620000000003, 3022.085, 2993.81, 2965.342, 2936.683, 2907.837, 2878.81, 2849.603, 2820.2209999999995, 2790.6679999999997, 2760.946, 2731.06, 2701.013, 2670.8070000000002, 2640.447, 2609.936, 2579.276, 2548.471, 2517.5229999999997, 2486.436, 2455.2129999999997, 2423.857, 2392.37, 2360.755, 2329.015, 2297.152, 2265.17, 2233.071, 2200.857, 2168.532, 2136.097, 2103.555, 2070.908, 2038.1589999999999, 2005.3110000000001, 1972.365, 1939.3239999999998, 1906.19, 1872.965, 1839.652, 1806.253, 1772.769, 1739.203, 1705.558, 1671.835, 1638.035, 1604.1629999999998, 1570.2179999999998, 1536.203, 1502.121, 1467.9720000000002, 1433.76, 1399.485, 1365.151, 1330.757, 1296.307, 1261.802, 1227.245, 1192.635, 1157.9769999999999, 1123.27, 1088.518, 1053.721, 1018.8810000000001, 984.0010000000001, 949.081, 914.123, 879.13, 844.1010000000001, 809.041, 773.948, 738.826, 703.676, 668.5, 633.298, 598.073, 562.826, 527.558, 492.272, 456.968, 421.648, 386.314, 350.967, 315.608, 280.23900000000003, 244.862, 209.477, 174.08599999999998, 138.692, 103.294, 67.895, 32.495, -2.903, -38.298, -73.689, -109.075, -144.453, -179.824, -215.185, -250.53400000000002, -285.872, -321.195, -356.504, -391.796, -427.07, -462.324, -497.559, -532.771, -567.96, -603.124, -638.262, -673.373, -708.455, -743.507, -778.528, -813.5160000000001, -848.4689999999999, -883.387, -918.268, -953.1110000000001, -987.914, -1022.677, -1057.396, -1092.072, -1126.703, -1161.288, -1195.825, -1230.312, -1264.748, -1299.133, -1333.464, -1367.74, -1401.96, -1436.1229999999998, -1470.226, -1504.2679999999998, -1538.249, -1572.1660000000002, -1606.0179999999998, -1639.8039999999999, -1673.5220000000002, -1707.171, -1740.749, -1774.255, -1807.6870000000001, -1841.0439999999999, -1874.3239999999998, -1907.526, -1940.648, -1973.6889999999999, -2006.646, -2039.52, -2072.3070000000002, -2105.007, -2137.617, -2170.136, -2202.563, -2234.896, -2267.133, -2299.2729999999997, -2331.314, -2363.2529999999997, -2395.09, -2426.823, -2458.45, -2489.969, -2521.379, -2552.677, -2583.862, -2614.933, -2645.886, -2676.7209999999995, -2707.435, -2738.026, -2768.494, -2798.835, -2829.047, -2859.1290000000004, -2889.079, -2918.895, -2948.574, -2978.115, -3007.515, -3036.772, -3065.884, -3094.849, -3123.665, -3152.329, -3180.8390000000004, -3209.1929999999998, -3237.389, -3265.4240000000004, -3293.295, -3321.0, -3348.538, -3375.9040000000005, -3403.097, -3430.115, -3456.953, -3483.611, -3510.085, -3536.3720000000003, -3562.47, -3588.375, -3614.086, -3639.598, -3664.909, -3690.0170000000003, -3714.917, -3739.607, -3764.0840000000003, -3788.345, -3812.385, -3836.202, -3859.7929999999997, -3883.1540000000005, -3906.281, -3929.171, -3951.82, -3974.225, -3996.381, -4018.2859999999996, -4039.934, -4061.323, -4082.447, -4103.303, -4123.887, -4144.194, -4164.22, -4183.96, -4203.41, -4222.565, -4241.42, -4259.971, -4278.212, -4296.139, -4313.745, -4331.027, -4347.978, -4364.593, -4380.866, -4396.791, -4412.363, -4427.576, -4442.423, -4456.897, -4470.9929999999995, -4484.7029999999995, -4498.022, -4510.941, -4523.452, -4535.552, -4547.23, -4558.479, -4569.291, -4579.659000000001, -4589.573, -4599.025, -4608.0070000000005, -4616.509, -4624.522, -4632.036, -4639.042, -4645.53, -4651.49, -4656.91, -4661.78, -4666.088, -4669.823, -4672.974, -4675.527, -4677.469, -4678.789000000001, -4679.472, -4679.505, -4678.873, -4677.561, -4675.555, -4672.837, -4669.393, -4665.205, -4660.255999999999, -4654.527, -4648.001, -4640.657, -4632.477, -4623.439, -4613.522, -4602.704000000001, -4590.960999999999, -4578.27, -4564.607, -4549.945, -4534.258, -4517.518, -4499.696, -4480.764, -4460.689, -4439.44, -4416.982, -4393.281, -4368.3009999999995, -4342.004, -4314.349, -4285.298, -4254.805, -4222.827, -4189.317, -4154.226, -4117.504, -4079.098, -4038.953, -3997.012, -3953.2140000000004, -3907.498, -3859.797, -3810.045, -3758.1679999999997, -3704.0959999999995, -3647.75, -3589.051, -3527.9159999999997, -3464.26, -3397.994, -3329.027, -3257.263, -3182.607, -3104.96, -3024.2209999999995, -2940.288, -2853.0609999999997, -2762.4390000000003, -2668.321, -2570.612, -2469.221, -2364.065, -2255.071, -2142.175, -2025.3339999999998, -1904.523, -1779.7420000000002, -1651.019, -1518.4160000000002, -1382.0339999999999, -1242.02, -1098.566, -951.92, -802.3810000000001, -650.303, -496.095, -340.215, -183.16400000000002, -25.476, 132.29, 289.568, 445.79400000000004, 600.4209999999999, 752.933, 902.8539999999999, 1049.755, 1193.265, 1333.067, 1468.9070000000002, 1600.5839999999998, 1727.951, 1850.911, 1969.411, 2083.436, 2193.005, 2298.161, 2398.973, 2495.527, 2587.9210000000003, 2676.2659999999996, 2760.677, 2841.277, 2918.19, 2991.542, 3061.4590000000003, 3128.063, 3191.4770000000003, 3251.82, 3309.208, 3363.7509999999997, 3415.56, 3464.739, 3511.387, 3555.6, 3597.4709999999995, 3637.0890000000004, 3674.538, 3709.8979999999997, 3743.2470000000003, 3774.66, 3804.2059999999997, 3831.952, 3857.962, 3882.2990000000004, 3905.0209999999997, 3926.183, 3945.8390000000004, 3964.0409999999997, 3980.836, 3996.2729999999997, 4010.395, 4023.245, 4034.864, 4045.292, 4054.565, 4062.719, 4069.789, 4075.808, 4080.808, 4084.8190000000004, 4087.87, 4089.989, 4091.204, 4091.539, 4091.0209999999997, 4089.672, 4087.5159999999996, 4084.5759999999996, 4080.8709999999996, 4076.4240000000004, 4071.2540000000004, 4065.38, 4058.82, 4051.593, 4043.716, 4035.204, 4026.075, 4016.344, 4006.026, 3995.135, 3983.685, 3971.69, 3959.164, 3946.118, 3932.565, 3918.518, 3903.987, 3888.985, 3873.5209999999997, 3857.607, 3841.2529999999997, 3824.468, 3807.264, 3789.6479999999997, 3771.63, 3753.219, 3734.4240000000004, 3715.2529999999997, 3695.715, 3675.816, 3655.566, 3634.9709999999995, 3614.04, 3592.778, 3571.1929999999998, 3549.2929999999997, 3527.083, 3504.57, 3481.76, 3458.66, 3435.276, 3411.613, 3387.677, 3363.474, 3339.009, 3314.288, 3289.315, 3264.097, 3238.637, 3212.941, 3187.014, 3160.86, 3134.4840000000004, 3107.89, 3081.083, 3054.067, 3026.847, 2999.425, 2971.8070000000002, 2943.9959999999996, 2915.9959999999996, 2887.812, 2859.446, 2830.902, 2802.185, 2773.297, 2744.242, 2715.0229999999997, 2685.6440000000002, 2656.1079999999997, 2626.4179999999997, 2596.577, 2566.5879999999997, 2536.456, 2506.181, 2475.768, 2445.22, 2414.538, 2383.726, 2352.7870000000003, 2321.724, 2290.538, 2259.2329999999997, 2227.811, 2196.275, 2164.6279999999997, 2132.871, 2101.007, 2069.0389999999998, 2036.969, 2004.8, 1972.5320000000002, 1940.17, 1907.715, 1875.1689999999999, 1842.535, 1809.8139999999999, 1777.009, 1744.121, 1711.154, 1678.109, 1644.987, 1611.7920000000001, 1578.524, 1545.1860000000001, 1511.78, 1478.308, 1444.771, 1411.171, 1377.511, 1343.7920000000001, 1310.016, 1276.184, 1242.299, 1208.361, 1174.374, 1140.338, 1106.255, 1072.128, 1037.9569999999999, 1003.7439999999999, 969.4910000000001, 935.199, 900.8710000000001, 866.507, 832.11, 797.68, 763.22, 728.7310000000001, 694.2139999999999, 659.671, 625.104, 590.514, 555.9019999999999, 521.27, 486.62, 451.952, 417.269, 382.57199999999995, 347.86199999999997, 313.14, 278.409, 243.669, 208.923, 174.17, 139.414, 104.654, 69.893, 35.132, 0.37200000000000005, -34.385, -69.138, -103.88600000000001, -138.627, -173.36, -208.083, -242.796, -277.496, -312.183, -346.855, -381.51099999999997, -416.149, -450.769, -485.36800000000005, -519.946, -554.501, -589.0319999999999, -623.5369999999999, -658.015, -692.465, -726.8860000000001, -761.275, -795.633, -829.957, -864.2460000000001, -898.498, -932.7130000000001, -966.89, -1001.0260000000001, -1035.12, -1069.171, -1103.1789999999999, -1137.14, -1171.0539999999999, -1204.92, -1238.736, -1272.501, -1306.214, -1339.872, -1373.476, -1407.0220000000002, -1440.511, -1473.9389999999999, -1507.307, -1540.6129999999998, -1573.855, -1607.031, -1640.141, -1673.183, -1706.155, -1739.056, -1771.884, -1804.639, -1837.318, -1869.92, -1902.443, -1934.8870000000002, -1967.2479999999998, -1999.527, -2031.721, -2063.8289999999997, -2095.849, -2127.779, -2159.618, -2191.365, -2223.0170000000003, -2254.574, -2286.032, -2317.3920000000003, -2348.65, -2379.806, -2410.857, -2441.803, -2472.64, -2503.367, -2533.984, -2564.486, -2594.874, -2625.145, -2655.296, -2685.328, -2715.236, -2745.02, -2774.677, -2804.2059999999997, -2833.6040000000003, -2862.869, -2892.0, -2920.995, -2949.8509999999997, -2978.565, -3007.137, -3035.5640000000003, -3063.843, -3091.972, -3119.95, -3147.7729999999997, -3175.44, -3202.948, -3230.295, -3257.478, -3284.494, -3311.343, -3338.0190000000002, -3364.5229999999997, -3390.849, -3416.9970000000003, -3442.9629999999997, -3468.745, -3494.3390000000004, -3519.744, -3544.955, -3569.9709999999995, -3594.788, -3619.403, -3643.8140000000003, -3668.0159999999996, -3692.008, -3715.785, -3739.345, -3762.683, -3785.798, -3808.685, -3831.341, -3853.762, -3875.9440000000004, -3897.885, -3919.58, -3941.025, -3962.216, -3983.15, -4003.822, -4024.2290000000003, -4044.365, -4064.2270000000003, -4083.81, -4103.11, -4122.122, -4140.842000000001, -4159.264, -4177.385, -4195.198, -4212.6990000000005, -4229.8820000000005, -4246.7429999999995, -4263.276, -4279.475, -4295.334, -4310.848, -4326.0109999999995, -4340.817, -4355.259, -4369.332, -4383.028, -4396.340999999999, -4409.264, -4421.79, -4433.912, -4445.622, -4456.914000000001, -4467.778, -4478.208, -4488.196, -4497.731, -4506.806, -4515.413, -4523.542, -4531.183, -4538.3279999999995, -4544.965999999999, -4551.087, -4556.681, -4561.737, -4566.244000000001, -4570.191, -4573.565, -4576.356, -4578.55, -4580.134, -4581.096, -4581.420999999999, -4581.097, -4580.107, -4578.438, -4576.073, -4572.998, -4569.194, -4564.646, -4559.335, -4553.244000000001, -4546.353, -4538.643, -4530.094, -4520.684, -4510.394, -4499.197, -4487.073, -4473.996, -4459.943, -4444.885, -4428.7970000000005, -4411.651, -4393.416, -4374.063, -4353.56, -4331.873, -4308.97, -4284.813, -4259.366, -4232.590999999999, -4204.446, -4174.891, -4143.88, -4111.3679999999995, -4077.308, -4041.65, -4004.343, -3965.3309999999997, -3924.559, -3881.967, -3837.495, -3791.078, -3742.65, -3692.1420000000003, -3639.48, -3584.5879999999997, -3527.39, -3467.804, -3405.745, -3341.1259999999997, -3273.857, -3203.847, -3130.998, -3055.2140000000004, -2976.395, -2894.4429999999998, -2809.256, -2720.736, -2628.782, -2533.3, -2434.201, -2331.4, -2224.825, -2114.4139999999998, -2000.119, -1881.9160000000002, -1759.8, -1633.7979999999998, -1503.969, -1370.406, -1233.251, -1092.69, -948.96, -802.3530000000001, -653.214, -501.939, -348.974, -194.81, -39.969, 115.00200000000001, 269.548, 423.11199999999997, 575.159, 725.178, 872.697, 1017.294, 1158.6, 1296.3, 1430.139, 1559.918, 1685.486, 1806.747, 1923.6429999999998, 2036.1570000000002, 2144.305, 2248.127, 2347.688, 2443.07, 2534.369, 2621.691, 2705.15, 2784.863, 2860.954, 2933.5429999999997, 3002.756, 3068.71, 3131.527, 3191.322, 3248.21, 3302.3, 3353.698, 3402.507, 3448.825, 3492.7459999999996, 3534.361, 3573.757, 3611.018, 3646.2209999999995, 3679.4440000000004, 3710.759, 3740.236, 3767.938, 3793.9320000000002, 3818.276, 3841.028, 3862.244, 3881.9759999999997, 3900.2740000000003, 3917.1859999999997, 3932.759, 3947.035, 3960.058, 3971.867, 3982.502, 3991.998, 4000.3909999999996, 4007.7140000000004, 4014.002, 4019.283, 4023.59, 4026.949, 4029.39, 4030.938, 4031.618, 4031.4559999999997, 4030.475, 4028.698, 4026.1459999999997, 4022.84, 4018.802, 4014.0490000000004, 4008.6020000000003, 4002.478, 3995.695, 3988.27, 3980.22, 3971.559, 3962.304, 3952.469, 3942.0679999999998, 3931.116, 3919.625, 3907.6090000000004, 3895.08, 3882.05, 3868.532, 3854.5359999999996, 3840.073, 3825.155, 3809.792, 3793.994, 3777.7709999999997, 3761.132, 3744.087, 3726.6440000000002, 3708.813, 3690.6020000000003, 3672.0190000000002, 3653.072, 3633.77, 3614.119, 3594.1279999999997, 3573.804, 3553.153, 3532.1820000000002, 3510.8990000000003, 3489.309, 3467.42, 3445.237, 3422.7670000000003, 3400.015, 3376.987, 3353.6890000000003, 3330.1259999999997, 3306.304, 3282.228, 3257.903, 3233.335, 3208.527, 3183.486, 3158.215, 3132.72, 3107.0040000000004, 3081.072, 3054.929, 3028.579, 3002.025, 2975.2729999999997, 2948.325, 2921.1859999999997, 2893.86, 2866.35, 2838.66, 2810.7940000000003, 2782.755, 2754.547, 2726.173, 2697.636, 2668.94, 2640.0879999999997, 2611.083, 2581.928, 2552.626, 2523.181, 2493.595, 2463.871, 2434.012, 2404.02, 2373.899, 2343.652, 2313.28, 2282.7870000000003, 2252.175, 2221.447, 2190.604, 2159.651, 2128.5879999999997, 2097.419, 2066.145, 2034.77, 2003.295, 1971.723, 1940.056, 1908.296, 1876.445, 1844.506, 1812.48, 1780.37, 1748.1779999999999, 1715.905, 1683.5539999999999, 1651.1270000000002, 1618.626, 1586.0520000000001, 1553.408, 1520.695, 1487.915, 1455.0710000000001, 1422.164, 1389.195, 1356.1670000000001, 1323.0810000000001, 1289.94, 1256.744, 1223.495, 1190.1960000000001, 1156.848, 1123.453, 1090.012, 1056.526, 1022.998, 989.43, 955.821, 922.176, 888.4939999999999, 854.7769999999999, 821.028, 787.2460000000001, 753.435, 719.596, 685.7289999999999, 651.837, 617.9209999999999, 583.982, 550.0219999999999, 516.043, 482.045, 448.031, 414.001, 379.957, 345.901, 311.83299999999997, 277.756, 243.671, 209.578, 175.48, 141.378, 107.272, 73.166, 39.059, 4.953, -29.15, -63.248999999999995, -97.34299999999999, -131.431, -165.51, -199.58, -233.64, -267.688, -301.723, -335.74300000000005, -369.74800000000005, -403.735, -437.704, -471.653, -505.58099999999996, -539.487, -573.369, -607.226, -641.057, -674.86, -708.6339999999999, -742.378, -776.09, -809.77, -843.415, -877.025, -910.5980000000001, -944.133, -977.628, -1011.0830000000001, -1044.496, -1077.865, -1111.1889999999999, -1144.4669999999999, -1177.698, -1210.88, -1244.011, -1277.0919999999999, -1310.119, -1343.092, -1376.009, -1408.869, -1441.671, -1474.4129999999998, -1507.094, -1539.7120000000002, -1572.266, -1604.755, -1637.1760000000002, -1669.53, -1701.8129999999999, -1734.026, -1766.165, -1798.231, -1830.22, -1862.1329999999998, -1893.967, -1925.721, -1957.3929999999998, -1988.9820000000002, -2020.485, -2051.903, -2083.2329999999997, -2114.473, -2145.6220000000003, -2176.678, -2207.64, -2238.506, -2269.274, -2299.9429999999998, -2330.511, -2360.976, -2391.3360000000002, -2421.591, -2451.736, -2481.774, -2511.698, -2541.511, -2571.2070000000003, -2600.7870000000003, -2630.2470000000003, -2659.587, -2688.804, -2717.897, -2746.863, -2775.7, -2804.407, -2832.9809999999998, -2861.42, -2889.723, -2917.887, -2945.91, -2973.79, -3001.5240000000003, -3029.111, -3056.548, -3083.833, -3110.9640000000004, -3137.938, -3164.752, -3191.406, -3217.895, -3244.218, -3270.3720000000003, -3296.355, -3322.163, -3347.795, -3373.2470000000003, -3398.518, -3423.603, -3448.5009999999997, -3473.208, -3497.722, -3522.04, -3546.158, -3570.074, -3593.784, -3617.2859999999996, -3640.5759999999996, -3663.651, -3686.508, -3709.143, -3731.553, -3753.7340000000004, -3775.684, -3797.397, -3818.8709999999996, -3840.1009999999997, -3861.085, -3881.817, -3902.295, -3922.513, -3942.469, -3962.157, -3981.573, -4000.7129999999997, -4019.573, -4038.147, -4056.4320000000002, -4074.422, -4092.113, -4109.499, -4126.575, -4143.337, -4159.779, -4175.895, -4191.68, -4207.129, -4222.234, -4236.992, -4251.394, -4265.436, -4279.111, -4292.412, -4305.332, -4317.865, -4330.003, -4341.74, -4353.067, -4363.978, -4374.465, -4384.52, -4394.133, -4403.298, -4412.005, -4420.245, -4428.009, -4435.288, -4442.072, -4448.352, -4454.116, -4459.356, -4464.059, -4468.214, -4471.811, -4474.837, -4477.28, -4479.128, -4480.367, -4480.985, -4480.967000000001, -4480.3, -4478.968, -4476.957, -4474.251, -4470.834, -4466.688, -4461.798, -4456.144, -4449.709, -4442.472, -4434.416, -4425.518, -4415.758, -4405.113, -4393.561, -4381.077, -4367.638, -4353.217000000001, -4337.789000000001, -4321.325, -4303.795999999999, -4285.174, -4265.4259999999995, -4244.521, -4222.425, -4199.103, -4174.519, -4148.635, -4121.411, -4092.805, -4062.777, -4031.28, -3998.2659999999996, -3963.6890000000003, -3927.4959999999996, -3889.636, -3850.052, -3808.687, -3765.4809999999998, -3720.37, -3673.29, -3624.172, -3572.945, -3519.535, -3463.865, -3405.855, -3345.423, -3282.482, -3216.9440000000004, -3148.718, -3077.712, -3003.827, -2926.968, -2847.034, -2763.928, -2677.551, -2587.806, -2494.598, -2397.8379999999997, -2297.4429999999998, -2193.339, -2085.465, -1973.773, -1858.234, -1738.845, -1615.626, -1488.6329999999998, -1357.957, -1223.73, -1086.132, -945.3919999999999, -801.7919999999999, -655.6669999999999, -507.402, -357.434, -206.238, -54.325, 97.76899999999999, 249.49900000000002, 400.32, 549.705, 697.148, 842.186, 984.4010000000001, 1123.425, 1258.9489999999998, 1390.715, 1518.524, 1642.225, 1761.719, 1876.9479999999999, 1987.89, 2094.5570000000002, 2196.988, 2295.244, 2389.402, 2479.5570000000002, 2565.8089999999997, 2648.27, 2727.054, 2802.281, 2874.07, 2942.54, 3007.809, 3069.995, 3129.211, 3185.5679999999998, 3239.1740000000004, 3290.135, 3338.548, 3384.511, 3428.1440000000002, 3469.454, 3508.607, 3545.659, 3580.688, 3613.7659999999996, 3644.968, 3674.3590000000004, 3702.0040000000004, 3727.966, 3752.305, 3775.0759999999996, 3796.335, 3816.132, 3834.5159999999996, 3851.5359999999996, 3867.237, 3881.66, 3894.849, 3906.842, 3917.677, 3927.3920000000003, 3936.018, 3943.592, 3950.1440000000002, 3955.705, 3960.304, 3963.9709999999995, 3966.7309999999998, 3968.612, 3969.637, 3969.8320000000003, 3969.219, 3967.821, 3965.659, 3962.7540000000004, 3959.1259999999997, 3954.7940000000003, 3949.776, 3944.091, 3937.756, 3930.788, 3923.202, 3915.014, 3906.239, 3896.893, 3886.988, 3876.539, 3865.558, 3854.059, 3842.053, 3829.553, 3816.57, 3803.116, 3789.202, 3774.837, 3760.033, 3744.7990000000004, 3729.145, 3713.0809999999997, 3696.615, 3679.757, 3662.514, 3644.8959999999997, 3626.9109999999996, 3608.567, 3589.87, 3570.83, 3551.453, 3531.7459999999996, 3511.716, 3491.3709999999996, 3470.716, 3449.758, 3428.5040000000004, 3406.9590000000003, 3385.13, 3363.022, 3340.6409999999996, 3317.993, 3295.083, 3271.9159999999997, 3248.498, 3224.8340000000003, 3200.928, 3176.7859999999996, 3152.4109999999996, 3127.81, 3102.986, 3077.9440000000004, 3052.688, 3027.222, 3001.551, 2975.679, 2949.6090000000004, 2923.3459999999995, 2896.893, 2870.2540000000004, 2843.434, 2816.434, 2789.26, 2761.915, 2734.401, 2706.722, 2678.882, 2650.884, 2622.7309999999998, 2594.426, 2565.972, 2537.373, 2508.63, 2479.7470000000003, 2450.728, 2421.574, 2392.288, 2362.874, 2333.333, 2303.669, 2273.884, 2243.98, 2213.9610000000002, 2183.8289999999997, 2153.585, 2123.2329999999997, 2092.774, 2062.2110000000002, 2031.5479999999998, 2000.7839999999999, 1969.9229999999998, 1938.9679999999998, 1907.9189999999999, 1876.78, 1845.5529999999999, 1814.239, 1782.84, 1751.36, 1719.7979999999998, 1688.1589999999999, 1656.443, 1624.652, 1592.789, 1560.855, 1528.8529999999998, 1496.783, 1464.648, 1432.45, 1400.19, 1367.87, 1335.4920000000002, 1303.058, 1270.569, 1238.027, 1205.433, 1172.79, 1140.099, 1107.362, 1074.579, 1041.754, 1008.887, 975.9789999999999, 943.034, 910.051, 877.033, 843.9810000000001, 810.8960000000001, 777.7810000000001, 744.6360000000001, 711.4630000000001, 678.2639999999999, 645.039, 611.7909999999999, 578.521, 545.23, 511.92, 478.592, 445.24699999999996, 411.88699999999994, 378.514, 345.12800000000004, 311.731, 278.324, 244.90900000000002, 211.487, 178.06, 144.628, 111.194, 77.757, 44.321000000000005, 10.886, -22.546999999999997, -55.977, -89.40100000000001, -122.819, -156.22899999999998, -189.63099999999997, -223.02200000000002, -256.402, -289.769, -323.122, -356.459, -389.78, -423.083, -456.36699999999996, -489.63, -522.871, -556.089, -589.283, -622.451, -655.592, -688.705, -721.789, -754.841, -787.862, -820.8489999999999, -853.801, -886.7180000000001, -919.597, -952.437, -985.238, -1017.997, -1050.714, -1083.387, -1116.015, -1148.597, -1181.13, -1213.615, -1246.049, -1278.431, -1310.76, -1343.035, -1375.253, -1407.415, -1439.517, -1471.56, -1503.5410000000002, -1535.46, -1567.3139999999999, -1599.1029999999998, -1630.825, -1662.479, -1694.0620000000001, -1725.5739999999998, -1757.014, -1788.379, -1819.668, -1850.881, -1882.014, -1913.067, -1944.039, -1974.9279999999999, -2005.731, -2036.4479999999999, -2067.078, -2097.618, -2128.0660000000003, -2158.423, -2188.6839999999997, -2218.85, -2248.9179999999997, -2278.887, -2308.755, -2338.52, -2368.181, -2397.736, -2427.183, -2456.52, -2485.746, -2514.8579999999997, -2543.856, -2572.736, -2601.498, -2630.139, -2658.658, -2687.052, -2715.3190000000004, -2743.458, -2771.466, -2799.342, -2827.083, -2854.688, -2882.1540000000005, -2909.4790000000003, -2936.66, -2963.697, -2990.586, -3017.325, -3043.9120000000003, -3070.345, -3096.62, -3122.737, -3148.692, -3174.4840000000004, -3200.1079999999997, -3225.5640000000003, -3250.848, -3275.958, -3300.89, -3325.6440000000002, -3350.215, -3374.6, -3398.798, -3422.805, -3446.619, -3470.235, -3493.652, -3516.867, -3539.875, -3562.6740000000004, -3585.261, -3607.632, -3629.785, -3651.715, -3673.4190000000003, -3694.8940000000002, -3716.135, -3737.14, -3757.9040000000005, -3778.425, -3798.697, -3818.716, -3838.48, -3857.9840000000004, -3877.223, -3896.1929999999998, -3914.89, -3933.309, -3951.446, -3969.297, -3986.855, -4004.117, -4021.078, -4037.732, -4054.074, -4070.099, -4085.801, -4101.175, -4116.215999999999, -4130.917, -4145.272, -4159.275, -4172.920999999999, -4186.202, -4199.113, -4211.645, -4223.793, -4235.55, -4246.907999999999, -4257.859, -4268.397, -4278.513, -4288.1990000000005, -4297.447, -4306.249, -4314.596, -4322.479, -4329.888, -4336.815, -4343.249, -4349.181, -4354.6, -4359.496, -4363.858, -4367.674, -4370.934, -4373.624, -4375.734, -4377.25, -4378.159000000001, -4378.448, -4378.102, -4377.108, -4375.451, -4373.115, -4370.085, -4366.344, -4361.875, -4356.661, -4350.684, -4343.924, -4336.3640000000005, -4327.982, -4318.7570000000005, -4308.668, -4297.693, -4285.808, -4272.9890000000005, -4259.212, -4244.4490000000005, -4228.675, -4211.861, -4193.977, -4174.995, -4154.880999999999, -4133.603, -4111.127, -4087.417, -4062.4359999999997, -4036.145, -4008.5040000000004, -3979.4709999999995, -3949.002, -3917.051, -3883.571, -3848.511, -3811.82, -3773.4429999999998, -3733.324, -3691.4040000000005, -3647.6209999999996, -3601.9109999999996, -3554.2059999999997, -3504.4390000000003, -3452.535, -3398.42, -3342.014, -3283.236, -3222.0029999999997, -3158.228, -3091.821, -3022.6890000000003, -2950.739, -2875.8740000000003, -2797.998, -2717.013, -2632.821, -2545.327, -2454.437, -2360.062, -2262.121, -2160.5389999999998, -2055.254, -1946.217, -1833.401, -1716.796, -1596.421, -1472.328, -1344.602, -1213.37, -1078.805, -941.127, -800.6089999999999, -657.574, -512.398, -365.50300000000004, -217.355, -68.453, 80.681, 229.512, 377.50699999999995, 524.143, 668.929, 811.404, 951.1560000000001, 1087.82, 1221.087, 1350.704, 1476.469, 1598.2320000000002, 1715.89, 1829.385, 1938.6889999999999, 2043.8139999999999, 2144.794, 2241.687, 2334.567, 2423.5229999999997, 2508.656, 2590.071, 2667.88, 2742.199, 2813.1440000000002, 2880.8320000000003, 2945.3779999999997, 3006.897, 3065.4990000000003, 3121.2929999999997, 3174.386, 3224.8779999999997, 3272.867, 3318.448, 3361.7129999999997, 3402.748, 3441.637, 3478.46, 3513.292, 3546.2070000000003, 3577.276, 3606.5640000000003, 3634.136, 3660.052, 3684.3709999999996, 3707.1479999999997, 3728.437, 3748.2870000000003, 3766.748, 3783.865, 3799.684, 3814.2459999999996, 3827.593, 3839.762, 3850.792, 3860.718, 3869.573, 3877.393, 3884.205, 3890.042, 3894.9320000000002, 3898.902, 3901.9809999999998, 3904.192, 3905.5609999999997, 3906.112, 3905.867, 3904.849, 3903.078, 3900.574, 3897.3579999999997, 3893.448, 3888.863, 3883.619, 3877.735, 3871.2259999999997, 3864.1090000000004, 3856.3990000000003, 3848.11, 3839.256, 3829.8520000000003, 3819.9109999999996, 3809.446, 3798.469, 3786.993, 3775.0290000000005, 3762.5890000000004, 3749.683, 3736.324, 3722.52, 3708.283, 3693.6209999999996, 3678.545, 3663.063, 3647.1859999999997, 3630.92, 3614.276, 3597.26, 3579.882, 3562.1490000000003, 3544.0690000000004, 3525.6490000000003, 3506.8959999999997, 3487.817, 3468.4190000000003, 3448.7090000000003, 3428.6940000000004, 3408.3790000000004, 3387.7709999999997, 3366.8759999999997, 3345.699, 3324.2470000000003, 3302.526, 3280.54, 3258.295, 3235.796, 3213.048, 3190.0570000000002, 3166.8259999999996, 3143.362, 3119.6679999999997, 3095.7490000000003, 3071.6090000000004, 3047.2540000000004, 3022.687, 2997.913, 2972.934, 2947.757, 2922.384, 2896.8190000000004, 2871.066, 2845.13, 2819.012, 2792.718, 2766.25, 2739.612, 2712.808, 2685.8390000000004, 2658.711, 2631.426, 2603.987, 2576.397, 2548.659, 2520.777, 2492.752, 2464.5879999999997, 2436.2889999999998, 2407.855, 2379.291, 2350.599, 2321.781, 2292.84, 2263.779, 2234.601, 2205.306, 2175.899, 2146.381, 2116.756, 2087.024, 2057.188, 2027.251, 1997.2160000000001, 1967.0829999999999, 1936.855, 1906.535, 1876.124, 1845.625, 1815.039, 1784.369, 1753.6170000000002, 1722.7839999999999, 1691.8729999999998, 1660.885, 1629.8220000000001, 1598.6870000000001, 1567.481, 1536.205, 1504.862, 1473.454, 1441.9820000000002, 1410.4479999999999, 1378.854, 1347.201, 1315.491, 1283.726, 1251.9080000000001, 1220.038, 1188.117, 1156.1480000000001, 1124.131, 1092.07, 1059.964, 1027.816, 995.627, 963.3989999999999, 931.133, 898.831, 866.4939999999999, 834.1239999999999, 801.722, 769.29, 736.828, 704.3389999999999, 671.825, 639.285, 606.722, 574.138, 541.533, 508.909, 476.267, 443.60900000000004, 410.936, 378.249, 345.55, 312.84, 280.121, 247.393, 214.65900000000002, 181.918, 149.174, 116.426, 83.677, 50.927, 18.178, -14.569, -47.312, -80.051, -112.78299999999999, -145.50799999999998, -178.225, -210.93200000000002, -243.628, -276.311, -308.981, -341.63599999999997, -374.275, -406.89599999999996, -439.499, -472.082, -504.64300000000003, -537.182, -569.698, -602.188, -634.6519999999999, -667.0889999999999, -699.497, -731.875, -764.222, -796.5360000000001, -828.816, -861.061, -893.27, -925.441, -957.573, -989.665, -1021.716, -1053.723, -1085.687, -1117.605, -1149.4769999999999, -1181.3, -1213.0739999999998, -1244.798, -1276.469, -1308.087, -1339.651, -1371.158, -1402.609, -1434.0, -1465.332, -1496.602, -1527.809, -1558.9520000000002, -1590.029, -1621.04, -1651.9820000000002, -1682.854, -1713.655, -1744.3829999999998, -1775.037, -1805.616, -1836.1170000000002, -1866.54, -1896.8829999999998, -1927.144, -1957.3220000000001, -1987.415, -2017.422, -2047.3410000000001, -2077.1710000000003, -2106.911, -2136.5570000000002, -2166.11, -2195.5660000000003, -2224.926, -2254.186, -2283.346, -2312.403, -2341.355, -2370.202, -2398.942, -2427.572, -2456.091, -2484.496, -2512.7870000000003, -2540.9610000000002, -2569.0170000000003, -2596.952, -2624.765, -2652.454, -2680.0159999999996, -2707.45, -2734.7529999999997, -2761.925, -2788.962, -2815.862, -2842.6240000000003, -2869.2459999999996, -2895.724, -2922.0570000000002, -2948.243, -2974.2790000000005, -3000.164, -3025.8940000000002, -3051.467, -3076.881, -3102.134, -3127.223, -3152.1459999999997, -3176.8990000000003, -3201.4809999999998, -3225.889, -3250.12, -3274.171, -3298.04, -3321.723, -3345.219, -3368.5240000000003, -3391.634, -3414.548, -3437.262, -3459.7729999999997, -3482.078, -3504.173, -3526.0559999999996, -3547.723, -3569.17, -3590.3940000000002, -3611.3920000000003, -3632.159, -3652.6929999999998, -3672.99, -3693.045, -3712.8559999999998, -3732.417, -3751.725, -3770.777, -3789.566, -3808.091, -3826.345, -3844.324, -3862.025, -3879.442, -3896.57, -3913.405, -3929.942, -3946.175, -3962.1, -3977.711, -3993.0029999999997, -4007.969, -4022.605, -4036.905, -4050.863, -4064.472, -4077.7259999999997, -4090.619, -4103.144, -4115.295, -4127.065, -4138.446, -4149.432, -4160.014, -4170.186, -4179.939, -4189.266, -4198.157, -4206.606, -4214.602, -4222.138, -4229.202, -4235.787, -4241.883, -4247.478, -4252.564, -4257.129, -4261.162, -4264.653, -4267.589, -4269.958, -4271.749, -4272.948, -4273.543, -4273.519, -4272.862, -4271.559, -4269.594, -4266.951, -4263.615, -4259.57, -4254.7970000000005, -4249.28, -4243.0, -4235.938, -4228.075, -4219.39, -4209.861, -4199.468, -4188.186, -4175.994000000001, -4162.865, -4148.775, -4133.698, -4117.606, -4100.469, -4082.26, -4062.946, -4042.4959999999996, -4020.8759999999997, -3998.051, -3973.985, -3948.639, -3921.975, -3893.9509999999996, -3864.525, -3833.651, -3801.283, -3767.3720000000003, -3731.867, -3694.715, -3655.861, -3615.2470000000003, -3572.8109999999997, -3528.493, -3482.225, -3433.94, -3383.566, -3331.031, -3276.256, -3219.1609999999996, -3159.665, -3097.6820000000002, -3033.1240000000003, -2965.901, -2895.9190000000003, -2823.085, -2747.303, -2668.4759999999997, -2586.51, -2501.3089999999997, -2412.78, -2320.8360000000002, -2225.395, -2126.385, -2023.74, -1917.4129999999998, -1807.372, -1693.609, -1576.139, -1455.007, -1330.295, -1202.126, -1070.663, -936.118, -798.7539999999999, -658.885, -516.876, -373.135, -228.11700000000002, -82.307, 63.783, 209.63099999999997, 354.713, 498.519, 640.562, 780.3910000000001, 917.595, 1051.818, 1182.75, 1310.141, 1433.786, 1553.537, 1669.2879999999998, 1780.979, 1888.58, 1992.099, 2091.567, 2187.038, 2278.584, 2366.2889999999998, 2450.25, 2530.57, 2607.357, 2680.723, 2750.782, 2817.6479999999997, 2881.4320000000002, 2942.2459999999996, 3000.199, 3055.397, 3107.9440000000004, 3157.938, 3205.474, 3250.6479999999997, 3293.546, 3334.2540000000004, 3372.855, 3409.426, 3444.0409999999997, 3476.7740000000003, 3507.692, 3536.86, 3564.342, 3590.197, 3614.4809999999998, 3637.2509999999997, 3658.5570000000002, 3678.449, 3696.975, 3714.18, 3730.107, 3744.8, 3758.296, 3770.635, 3781.853, 3791.985, 3801.0640000000003, 3809.123, 3816.192, 3822.301, 3827.478, 3831.75, 3835.145, 3837.6859999999997, 3839.3979999999997, 3840.304, 3840.427, 3839.789, 3838.409, 3836.308, 3833.506, 3830.02, 3825.869, 3821.07, 3815.64, 3809.594, 3802.949, 3795.72, 3787.921, 3779.565, 3770.667, 3761.239, 3751.295, 3740.847, 3729.907, 3718.486, 3706.595, 3694.2459999999996, 3681.448, 3668.2129999999997, 3654.55, 3640.469, 3625.978, 3611.0879999999997, 3595.8070000000002, 3580.1440000000002, 3564.1059999999998, 3547.703, 3530.942, 3513.83, 3496.375, 3478.585, 3460.467, 3442.027, 3423.2709999999997, 3404.208, 3384.843, 3365.1820000000002, 3345.232, 3324.9970000000003, 3304.486, 3283.7009999999996, 3262.65, 3241.3379999999997, 3219.77, 3197.9509999999996, 3175.886, 3153.58, 3131.038, 3108.264, 3085.264, 3062.04, 3038.599, 3014.9440000000004, 2991.08, 2967.01, 2942.738, 2918.2690000000002, 2893.607, 2868.755, 2843.716, 2818.495, 2793.0959999999995, 2767.5209999999997, 2741.7740000000003, 2715.8579999999997, 2689.777, 2663.535, 2637.133, 2610.575, 2583.865, 2557.006, 2529.999, 2502.849, 2475.558, 2448.129, 2420.564, 2392.867, 2365.04, 2337.0860000000002, 2309.007, 2280.805, 2252.484, 2224.0460000000003, 2195.493, 2166.828, 2138.052, 2109.169, 2080.18, 2051.0879999999997, 2021.895, 1992.604, 1963.215, 1933.7320000000002, 1904.1570000000002, 1874.491, 1844.737, 1814.896, 1784.9720000000002, 1754.964, 1724.8770000000002, 1694.711, 1664.4679999999998, 1634.15, 1603.76, 1573.2979999999998, 1542.767, 1512.168, 1481.504, 1450.775, 1419.984, 1389.1329999999998, 1358.2220000000002, 1327.255, 1296.231, 1265.154, 1234.024, 1202.843, 1171.613, 1140.336, 1109.012, 1077.644, 1046.233, 1014.78, 983.2869999999999, 951.7560000000001, 920.187, 888.5830000000001, 856.945, 825.2739999999999, 793.572, 761.84, 730.079, 698.2919999999999, 666.4789999999999, 634.641, 602.781, 570.899, 538.997, 507.07599999999996, 475.13699999999994, 443.18300000000005, 411.213, 379.23, 347.235, 315.22900000000004, 283.21299999999997, 251.18900000000002, 219.158, 187.12099999999998, 155.08, 123.036, 90.99, 58.943000000000005, 26.897, -5.148, -37.189, -69.226, -101.257, -133.281, -165.298, -197.304, -229.301, -261.285, -293.256, -325.21299999999997, -357.154, -389.079, -420.985, -452.87199999999996, -484.73900000000003, -516.5840000000001, -548.406, -580.203, -611.976, -643.721, -675.439, -707.128, -738.7860000000001, -770.4119999999999, -802.0060000000001, -833.565, -865.0889999999999, -896.577, -928.0260000000001, -959.436, -990.806, -1022.1339999999999, -1053.42, -1084.661, -1115.856, -1147.005, -1178.105, -1209.157, -1240.157, -1271.105, -1302.001, -1332.8410000000001, -1363.626, -1394.3529999999998, -1425.021, -1455.63, -1486.1770000000001, -1516.662, -1547.082, -1577.4370000000001, -1607.725, -1637.945, -1668.095, -1698.174, -1728.181, -1758.1129999999998, -1787.971, -1817.751, -1847.453, -1877.075, -1906.616, -1936.0739999999998, -1965.4470000000001, -1994.735, -2023.935, -2053.047, -2082.067, -2110.996, -2139.83, -2168.57, -2197.212, -2225.755, -2254.198, -2282.5389999999998, -2310.776, -2338.908, -2366.933, -2394.848, -2422.652, -2450.344, -2477.922, -2505.383, -2532.726, -2559.949, -2587.05, -2614.027, -2640.8779999999997, -2667.6020000000003, -2694.195, -2720.656, -2746.9840000000004, -2773.175, -2799.2290000000003, -2825.1409999999996, -2850.9120000000003, -2876.5370000000003, -2902.0159999999996, -2927.345, -2952.522, -2977.546, -3002.413, -3027.1220000000003, -3051.67, -3076.053, -3100.2709999999997, -3124.32, -3148.197, -3171.9, -3195.427, -3218.7740000000003, -3241.9390000000003, -3264.9179999999997, -3287.71, -3310.3109999999997, -3332.719, -3354.929, -3376.9390000000003, -3398.7459999999996, -3420.347, -3441.738, -3462.917, -3483.8790000000004, -3504.6209999999996, -3525.14, -3545.4320000000002, -3565.494, -3585.322, -3604.9120000000003, -3624.26, -3643.363, -3662.215, -3680.8140000000003, -3699.155, -3717.2340000000004, -3735.046, -3752.587, -3769.853, -3786.8379999999997, -3803.538, -3819.949, -3836.0640000000003, -3851.88, -3867.3909999999996, -3882.591, -3897.4759999999997, -3912.039, -3926.275, -3940.179, -3953.744, -3966.9629999999997, -3979.8320000000003, -3992.343, -4004.49, -4016.2659999999996, -4027.664, -4038.678, -4049.2990000000004, -4059.5209999999997, -4069.336, -4078.735, -4087.712, -4096.2570000000005, -4104.362, -4112.019, -4119.217000000001, -4125.9490000000005, -4132.204000000001, -4137.973, -4143.245, -4148.01, -4152.258, -4155.978, -4159.157, -4161.785, -4163.849, -4165.337, -4166.236, -4166.532999999999, -4166.214, -4165.265, -4163.670999999999, -4161.417, -4158.488, -4154.867, -4150.538, -4145.484, -4139.686, -4133.126, -4125.785, -4117.644, -4108.68, -4098.873, -4088.2009999999996, -4076.64, -4064.167, -4050.757, -4036.384, -4021.0209999999997, -4004.64, -3987.2129999999997, -3968.7090000000003, -3949.0959999999995, -3928.343, -3906.415, -3883.275, -3858.888, -3833.2140000000004, -3806.2140000000004, -3777.845, -3748.0640000000003, -3716.824, -3684.079, -3649.778, -3613.87, -3576.301, -3537.012, -3495.947, -3453.042, -3408.2340000000004, -3361.4559999999997, -3312.639, -3261.7090000000003, -3208.593, -3153.21, -3095.4809999999998, -3035.322, -2972.645, -2907.364, -2839.387, -2768.6209999999996, -2694.9709999999995, -2618.344, -2538.644, -2455.78, -2369.658, -2280.1929999999998, -2187.302, -2090.913, -1990.961, -1887.399, -1780.192, -1669.3310000000001, -1554.825, -1436.719, -1315.089, -1190.05, -1061.76, -930.421, -796.2869999999999, -659.6610000000001, -520.896, -380.39, -238.585, -95.95200000000001, 47.011, 189.791, 331.87699999999995, 472.767, 611.9830000000001, 749.081, 883.658, 1015.3580000000001, 1143.878, 1268.964, 1390.415, 1508.082, 1621.8570000000002, 1731.6760000000002, 1837.509, 1939.359, 2037.255, 2131.2470000000003, 2221.403, 2307.804, 2390.544, 2469.72, 2545.439, 2617.8089999999997, 2686.94, 2752.9429999999998, 2815.927, 2876.0009999999997, 2933.2709999999997, 2987.84, 3039.809, 3089.275, 3136.3320000000003, 3181.0690000000004, 3223.322, 3263.933, 3302.224, 3338.5209999999997, 3372.9, 3405.4309999999996, 3436.18, 3465.212, 3492.5879999999997, 3518.366, 3542.6020000000003, 3565.3509999999997, 3586.6609999999996, 3606.583, 3625.163, 3642.446, 3658.474, 3673.288, 3686.926, 3699.428, 3710.827, 3721.159, 3730.4559999999997, 3738.7509999999997, 3746.073, 3752.45, 3757.9109999999996, 3762.4829999999997, 3766.191, 3769.0609999999997, 3771.115, 3772.3759999999997, 3772.867, 3772.6090000000004, 3771.6209999999996, 3769.925, 3767.538, 3764.478, 3760.764, 3756.4120000000003, 3751.4390000000003, 3745.861, 3739.692, 3732.947, 3725.6420000000003, 3717.79, 3709.403, 3700.494, 3691.078, 3681.164, 3670.7659999999996, 3659.8940000000002, 3648.559, 3636.7729999999997, 3624.545, 3611.886, 3598.805, 3585.312, 3571.4159999999997, 3557.1259999999997, 3542.4509999999996, 3527.3979999999997, 3511.9770000000003, 3496.195, 3480.06, 3463.579, 3446.761, 3429.611, 3412.137, 3394.3459999999995, 3376.244, 3357.8390000000004, 3339.135, 3320.139, 3300.8590000000004, 3281.297, 3261.461, 3241.357, 3220.989, 3200.363, 3179.4840000000004, 3158.357, 3136.987, 3115.3790000000004, 3093.538, 3071.468, 3049.173, 3026.659, 3003.929, 2980.988, 2957.8390000000004, 2934.488, 2910.937, 2887.191, 2863.2529999999997, 2839.127, 2814.817, 2790.327, 2765.659, 2740.8179999999998, 2715.8070000000002, 2690.6279999999997, 2665.2859999999996, 2639.783, 2614.123, 2588.3089999999997, 2562.343, 2536.229, 2509.969, 2483.567, 2457.025, 2430.346, 2403.532, 2376.587, 2349.513, 2322.312, 2294.988, 2267.542, 2239.9770000000003, 2212.295, 2184.5, 2156.592, 2128.575, 2100.451, 2072.222, 2043.89, 2015.4579999999999, 1986.9270000000001, 1958.299, 1929.578, 1900.764, 1871.86, 1842.868, 1813.789, 1784.6270000000002, 1755.382, 1726.056, 1696.652, 1667.172, 1637.616, 1607.987, 1578.2879999999998, 1548.5179999999998, 1518.681, 1488.7779999999998, 1458.81, 1428.78, 1398.6889999999999, 1368.5379999999998, 1338.33, 1308.066, 1277.747, 1247.375, 1216.952, 1186.48, 1155.9589999999998, 1125.391, 1094.778, 1064.121, 1033.422, 1002.683, 971.904, 941.087, 910.2330000000001, 879.345, 848.423, 817.4689999999999, 786.485, 755.47, 724.428, 693.3589999999999, 662.265, 631.1469999999999, 600.006, 568.8430000000001, 537.6619999999999, 506.461, 475.24300000000005, 444.009, 412.76, 381.49800000000005, 350.223, 318.937, 287.642, 256.339, 225.028, 193.71099999999998, 162.39, 131.065, 99.73899999999999, 68.411, 37.084, 5.757999999999999, -25.565, -56.88399999999999, -88.198, -119.505, -150.805, -182.095, -213.37599999999998, -244.645, -275.902, -307.145, -338.374, -369.586, -400.78, -431.957, -463.11300000000006, -494.24800000000005, -525.362, -556.452, -587.5169999999999, -618.556, -649.569, -680.553, -711.508, -742.432, -773.324, -804.183, -835.008, -865.798, -896.55, -927.2639999999999, -957.94, -988.574, -1019.1669999999999, -1049.7169999999999, -1080.223, -1110.683, -1141.096, -1171.461, -1201.777, -1232.0430000000001, -1262.256, -1292.4160000000002, -1322.5220000000002, -1352.5720000000001, -1382.5639999999999, -1412.4979999999998, -1442.3729999999998, -1472.1860000000001, -1501.9370000000001, -1531.6229999999998, -1561.245, -1590.8, -1620.287, -1649.705, -1679.0520000000001, -1708.3270000000002, -1737.5279999999998, -1766.654, -1795.703, -1824.675, -1853.567, -1882.378, -1911.1070000000002, -1939.7520000000002, -1968.3110000000001, -1996.7839999999999, -2025.1670000000001, -2053.4610000000002, -2081.663, -2109.772, -2137.785, -2165.703, -2193.522, -2221.241, -2248.8579999999997, -2276.3720000000003, -2303.782, -2331.084, -2358.278, -2385.362, -2412.333, -2439.1910000000003, -2465.933, -2492.558, -2519.062, -2545.446, -2571.706, -2597.841, -2623.848, -2649.7259999999997, -2675.473, -2701.086, -2726.5640000000003, -2751.9040000000005, -2777.105, -2802.163, -2827.077, -2851.844, -2876.4629999999997, -2900.9309999999996, -2925.245, -2949.403, -2973.4040000000005, -2997.243, -3020.9190000000003, -3044.429, -3067.7709999999997, -3090.9429999999998, -3113.94, -3136.761, -3159.403, -3181.863, -3204.138, -3226.225, -3248.1220000000003, -3269.825, -3291.3320000000003, -3312.639, -3333.742, -3354.64, -3375.328, -3395.803, -3416.062, -3436.1009999999997, -3455.9159999999997, -3475.505, -3494.864, -3513.988, -3532.8740000000003, -3551.518, -3569.915, -3588.063, -3605.9559999999997, -3623.59, -3640.962, -3658.066, -3674.8990000000003, -3691.455, -3707.7290000000003, -3723.718, -3739.4159999999997, -3754.817, -3769.9179999999997, -3784.712, -3799.1940000000004, -3813.3579999999997, -3827.2, -3840.7129999999997, -3853.89, -3866.7270000000003, -3879.216, -3891.3520000000003, -3903.1279999999997, -3914.5370000000003, -3925.572, -3936.2259999999997, -3946.492, -3956.362, -3965.829, -3974.885, -3983.522, -3991.7309999999998, -3999.5040000000004, -4006.8320000000003, -4013.7059999999997, -4020.118, -4026.0559999999996, -4031.511, -4036.474, -4040.934, -4044.88, -4048.3, -4051.185, -4053.5209999999997, -4055.297, -4056.5, -4057.117, -4057.135, -4056.54, -4055.317, -4053.453, -4050.9320000000002, -4047.738, -4043.8540000000003, -4039.265, -4033.952, -4027.897, -4021.083, -4013.488, -4005.093, -3995.8779999999997, -3985.82, -3974.897, -3963.086, -3950.362, -3936.7009999999996, -3922.075, -3906.4590000000003, -3889.823, -3872.138, -3853.3740000000003, -3833.498, -3812.4759999999997, -3790.275, -3766.8590000000004, -3742.188, -3716.225, -3688.929, -3660.255, -3630.1609999999996, -3598.599, -3565.52, -3530.8740000000003, -3494.6079999999997, -3456.6659999999997, -3416.991, -3375.5229999999997, -3332.198, -3286.952, -3239.716, -3190.4190000000003, -3138.987, -3085.3459999999995, -3029.414, -2971.1090000000004, -2910.348, -2847.042, -2781.1040000000003, -2712.442, -2640.9640000000004, -2566.575, -2489.1839999999997, -2408.7, -2325.029, -2238.0879999999997, -2147.7960000000003, -2054.0789999999997, -1956.8729999999998, -1856.13, -1751.815, -1643.912, -1532.433, -1417.418, -1298.935, -1177.094, -1052.045, -923.9860000000001, -793.1569999999999, -659.852, -524.411, -387.221, -248.708, -109.335, 30.415, 170.042, 309.045, 446.93300000000005, 583.238, 717.5210000000001, 849.3860000000001, 978.4830000000001, 1104.508, 1227.211, 1346.3929999999998, 1461.901, 1573.6270000000002, 1681.505, 1785.504, 1885.62, 1981.882, 2074.3360000000002, 2163.045, 2248.087, 2329.552, 2407.536, 2482.138, 2553.466, 2621.627, 2686.7259999999997, 2748.87, 2808.1659999999997, 2864.717, 2918.623, 2969.982, 3018.889, 3065.4359999999997, 3109.711, 3151.8, 3191.782, 3229.737, 3265.739, 3299.86, 3332.1679999999997, 3362.7309999999998, 3391.6079999999997, 3418.861, 3444.546, 3468.719, 3491.4320000000002, 3512.735, 3532.675, 3551.298, 3568.6479999999997, 3584.7659999999996, 3599.692, 3613.465, 3626.1209999999996, 3637.695, 3648.2209999999995, 3657.73, 3666.255, 3673.824, 3680.467, 3686.2090000000003, 3691.078, 3695.098, 3698.2929999999997, 3700.688, 3702.304, 3703.1620000000003, 3703.284, 3702.69, 3701.3979999999997, 3699.428, 3696.797, 3693.522, 3689.62, 3685.107, 3679.998, 3674.309, 3668.055, 3661.248, 3653.903, 3646.032, 3637.6479999999997, 3628.763, 3619.39, 3609.54, 3599.224, 3588.453, 3577.236, 3565.586, 3553.51, 3541.0190000000002, 3528.123, 3514.829, 3501.1479999999997, 3487.086, 3472.6540000000005, 3457.8579999999997, 3442.7070000000003, 3427.2070000000003, 3411.368, 3395.195, 3378.695, 3361.877, 3344.7459999999996, 3327.308, 3309.57, 3291.539, 3273.22, 3254.619, 3235.742, 3216.594, 3197.1809999999996, 3177.508, 3157.58, 3137.403, 3116.9809999999998, 3096.3190000000004, 3075.422, 3054.295, 3032.941, 3011.367, 2989.574, 2967.5690000000004, 2945.355, 2922.937, 2900.317, 2877.5, 2854.491, 2831.292, 2807.907, 2784.34, 2760.594, 2736.673, 2712.5809999999997, 2688.3190000000004, 2663.893, 2639.304, 2614.5570000000002, 2589.653, 2564.597, 2539.39, 2514.0370000000003, 2488.54, 2462.901, 2437.123, 2411.21, 2385.163, 2358.986, 2332.68, 2306.249, 2279.696, 2253.021, 2226.228, 2199.32, 2172.298, 2145.165, 2117.923, 2090.574, 2063.121, 2035.566, 2007.911, 1980.1570000000002, 1952.308, 1924.364, 1896.329, 1868.203, 1839.99, 1811.691, 1783.307, 1754.842, 1726.296, 1697.671, 1668.97, 1640.194, 1611.345, 1582.424, 1553.434, 1524.376, 1495.251, 1466.0620000000001, 1436.81, 1407.497, 1378.124, 1348.693, 1319.205, 1289.662, 1260.067, 1230.4189999999999, 1200.721, 1170.974, 1141.18, 1111.34, 1081.4560000000001, 1051.529, 1021.56, 991.551, 961.5039999999999, 931.42, 901.299, 871.145, 840.957, 810.737, 780.488, 750.209, 719.9019999999999, 689.57, 659.212, 628.83, 598.4259999999999, 568.001, 537.557, 507.093, 476.61300000000006, 446.116, 415.60400000000004, 385.08, 354.542, 323.994, 293.436, 262.87, 232.296, 201.71599999999998, 171.132, 140.543, 109.95299999999999, 79.361, 48.769, 18.178, -12.411, -42.996, -73.57600000000001, -104.15, -134.717, -165.27599999999998, -195.825, -226.364, -256.89099999999996, -287.405, -317.904, -348.38800000000003, -378.856, -409.305, -439.736, -470.147, -500.536, -530.903, -561.246, -591.565, -621.857, -652.122, -682.3589999999999, -712.566, -742.742, -772.8860000000001, -802.997, -833.074, -863.115, -893.1189999999999, -923.086, -953.013, -982.8989999999999, -1012.7439999999999, -1042.546, -1072.303, -1102.016, -1131.681, -1161.299, -1190.867, -1220.386, -1249.8519999999999, -1279.265, -1308.625, -1337.9279999999999, -1367.175, -1396.364, -1425.493, -1454.5610000000001, -1483.567, -1512.51, -1541.388, -1570.2, -1598.944, -1627.619, -1656.224, -1684.757, -1713.2179999999998, -1741.6029999999998, -1769.9129999999998, -1798.145, -1826.2979999999998, -1854.371, -1882.361, -1910.269, -1938.092, -1965.828, -1993.476, -2021.035, -2048.502, -2075.877, -2103.158, -2130.343, -2157.43, -2184.4179999999997, -2211.305, -2238.09, -2264.77, -2291.344, -2317.811, -2344.1679999999997, -2370.413, -2396.545, -2422.563, -2448.4629999999997, -2474.245, -2499.906, -2525.444, -2550.8579999999997, -2576.145, -2601.303, -2626.3309999999997, -2651.2259999999997, -2675.987, -2700.61, -2725.095, -2749.438, -2773.637, -2797.691, -2821.597, -2845.3520000000003, -2868.954, -2892.402, -2915.691, -2938.821, -2961.788, -2984.59, -3007.225, -3029.688, -3051.9790000000003, -3074.094, -3096.031, -3117.7859999999996, -3139.3559999999998, -3160.74, -3181.933, -3202.934, -3223.738, -3244.342, -3264.744, -3284.94, -3304.927, -3324.7009999999996, -3344.259, -3363.597, -3382.7129999999997, -3401.6020000000003, -3420.26, -3438.684, -3456.869, -3474.812, -3492.509, -3509.9559999999997, -3527.1479999999997, -3544.0809999999997, -3560.75, -3577.152, -3593.282, -3609.134, -3624.704, -3639.988, -3654.98, -3669.6740000000004, -3684.066, -3698.151, -3711.922, -3725.375, -3738.5029999999997, -3751.3, -3763.76, -3775.8779999999997, -3787.6459999999997, -3799.059, -3810.1090000000004, -3820.789, -3831.093, -3841.013, -3850.542, -3859.672, -3868.395, -3876.703, -3884.587, -3892.04, -3899.053, -3905.617, -3911.7209999999995, -3917.3559999999998, -3922.513, -3927.1820000000002, -3931.3509999999997, -3935.011, -3938.1490000000003, -3940.756, -3942.8179999999998, -3944.323, -3945.26, -3945.615, -3945.3740000000003, -3944.5229999999997, -3943.0490000000004, -3940.937, -3938.17, -3934.7340000000004, -3930.611, -3925.785, -3920.239, -3913.954, -3906.91, -3899.0890000000004, -3890.469, -3881.031, -3870.7509999999997, -3859.6079999999997, -3847.577, -3834.634, -3820.7540000000004, -3805.909, -3790.073, -3773.216, -3755.309, -3736.321, -3716.218, -3694.968, -3672.534, -3648.88, -3623.968, -3597.758, -3570.2070000000003, -3541.2729999999997, -3510.9109999999996, -3479.071, -3445.7059999999997, -3410.762, -3374.1859999999997, -3335.923, -3295.9120000000003, -3254.094, -3210.403, -3164.772, -3117.134, -3067.415, -3015.542, -2961.4359999999997, -2905.0170000000003, -2846.202, -2784.906, -2721.042, -2654.52, -2585.25, -2513.139, -2438.098, -2360.034, -2278.86, -2194.49, -2106.843, -2015.849, -1921.441, -1823.57, -1722.201, -1617.318, -1508.9260000000002, -1397.0610000000001, -1281.7910000000002, -1163.2160000000001, -1041.481, -916.7710000000001, -789.322, -659.415, -527.377, -393.583, -258.448, -122.41799999999999, 14.034, 150.422, 286.256, 421.056, 554.362, 685.7460000000001, 814.816, 941.2239999999999, 1064.672, 1184.913, 1301.748, 1415.021, 1524.625, 1630.491, 1732.585, 1830.9029999999998, 1925.467, 2016.3220000000001, 2103.525, 2187.153, 2267.29, 2344.029, 2417.467, 2487.706, 2554.851, 2619.0029999999997, 2680.268, 2738.7470000000003, 2794.542, 2847.75, 2898.465, 2946.782, 2992.789, 3036.573, 3078.216, 3117.797, 3155.3920000000003, 3191.0759999999996, 3224.917, 3256.982, 3287.3379999999997, 3316.042, 3343.155, 3368.7309999999998, 3392.8259999999996, 3415.489, 3436.77, 3456.715, 3475.37, 3492.775, 3508.973, 3524.002, 3537.9, 3550.703, 3562.4440000000004, 3573.158, 3582.8740000000003, 3591.6240000000003, 3599.4359999999997, 3606.3390000000004, 3612.3590000000004, 3617.5209999999997, 3621.85, 3625.37, 3628.1040000000003, 3630.073, 3631.298, 3631.801, 3631.6, 3630.7140000000004, 3629.1620000000003, 3626.96, 3624.1259999999997, 3620.676, 3616.6259999999997, 3611.991, 3606.7859999999996, 3601.0240000000003, 3594.72, 3587.887, 3580.5370000000003, 3572.6820000000002, 3564.336, 3555.509, 3546.2140000000004, 3536.4590000000003, 3526.258, 3515.618, 3504.552, 3493.067, 3481.1740000000004, 3468.882, 3456.199, 3443.134, 3429.696, 3415.8920000000003, 3401.7309999999998, 3387.219, 3372.366, 3357.176, 3341.659, 3325.821, 3309.6679999999997, 3293.2059999999997, 3276.4429999999998, 3259.385, 3242.0370000000003, 3224.406, 3206.4959999999996, 3188.315, 3169.867, 3151.157, 3132.191, 3112.974, 3093.511, 3073.8059999999996, 3053.865, 3033.692, 3013.2909999999997, 2992.667, 2971.825, 2950.768, 2929.5009999999997, 2908.028, 2886.353, 2864.4790000000003, 2842.4109999999996, 2820.152, 2797.7059999999997, 2775.0759999999996, 2752.2659999999996, 2729.28, 2706.12, 2682.79, 2659.2940000000003, 2635.634, 2611.814, 2587.837, 2563.705, 2539.422, 2514.991, 2490.413, 2465.694, 2440.834, 2415.8360000000002, 2390.7039999999997, 2365.44, 2340.047, 2314.526, 2288.881, 2263.114, 2237.2270000000003, 2211.223, 2185.103, 2158.8720000000003, 2132.529, 2106.0789999999997, 2079.5229999999997, 2052.862, 2026.1, 1999.2379999999998, 1972.279, 1945.224, 1918.076, 1890.836, 1863.506, 1836.089, 1808.586, 1780.999, 1753.33, 1725.5810000000001, 1697.753, 1669.849, 1641.869, 1613.817, 1585.693, 1557.499, 1529.237, 1500.9089999999999, 1472.516, 1444.06, 1415.5420000000001, 1386.965, 1358.328, 1329.635, 1300.887, 1272.085, 1243.231, 1214.325, 1185.371, 1156.368, 1127.32, 1098.226, 1069.089, 1039.9089999999999, 1010.689, 981.429, 952.132, 922.797, 893.428, 864.025, 834.5889999999999, 805.1210000000001, 775.6239999999999, 746.0980000000001, 716.545, 686.966, 657.362, 627.735, 598.085, 568.414, 538.724, 509.015, 479.289, 449.54699999999997, 419.79, 390.02, 360.23699999999997, 330.444, 300.64, 270.827, 241.007, 211.18099999999998, 181.34900000000002, 151.514, 121.675, 91.836, 61.995, 32.155, 2.318, -27.517, -57.348, -87.17299999999999, -116.991, -146.80200000000002, -176.604, -206.396, -236.17700000000002, -265.94599999999997, -295.70099999999996, -325.441, -355.166, -384.874, -414.564, -444.235, -473.885, -503.514, -533.12, -562.702, -592.259, -621.79, -651.294, -680.7689999999999, -710.215, -739.6289999999999, -769.012, -798.362, -827.677, -856.957, -886.2, -915.405, -944.571, -973.697, -1002.7810000000001, -1031.823, -1060.82, -1089.7730000000001, -1118.6789999999999, -1147.537, -1176.347, -1205.106, -1233.815, -1262.47, -1291.072, -1319.619, -1348.109, -1376.5410000000002, -1404.915, -1433.2279999999998, -1461.479, -1489.668, -1517.7920000000001, -1545.851, -1573.842, -1601.766, -1629.619, -1657.402, -1685.112, -1712.7479999999998, -1740.308, -1767.7920000000001, -1795.1979999999999, -1822.524, -1849.769, -1876.931, -1904.009, -1931.001, -1957.906, -1984.723, -2011.4489999999998, -2038.0829999999999, -2064.624, -2091.07, -2117.419, -2143.669, -2169.82, -2195.869, -2221.814, -2247.654, -2273.388, -2299.012, -2324.526, -2349.928, -2375.216, -2400.388, -2425.4410000000003, -2450.376, -2475.188, -2499.877, -2524.44, -2548.875, -2573.181, -2597.355, -2621.395, -2645.2990000000004, -2669.065, -2692.69, -2716.173, -2739.511, -2762.702, -2785.743, -2808.633, -2831.368, -2853.947, -2876.366, -2898.623, -2920.717, -2942.643, -2964.4, -2985.985, -3007.3940000000002, -3028.6259999999997, -3049.677, -3070.545, -3091.2259999999997, -3111.718, -3132.0170000000003, -3152.1209999999996, -3172.025, -3191.728, -3211.225, -3230.514, -3249.591, -3268.452, -3287.094, -3305.513, -3323.7059999999997, -3341.6690000000003, -3359.397, -3376.887, -3394.135, -3411.137, -3427.889, -3444.386, -3460.6240000000003, -3476.598, -3492.305, -3507.738, -3522.8940000000002, -3537.768, -3552.355, -3566.6490000000003, -3580.645, -3594.3379999999997, -3607.722, -3620.792, -3633.542, -3645.966, -3658.058, -3669.812, -3681.2209999999995, -3692.2790000000005, -3702.9790000000003, -3713.315, -3723.2790000000005, -3732.863, -3742.0609999999997, -3750.865, -3759.2670000000003, -3767.259, -3774.833, -3781.9790000000003, -3788.69, -3794.9559999999997, -3800.768, -3806.116, -3810.991, -3815.381, -3819.277, -3822.6679999999997, -3825.5429999999997, -3827.89, -3829.697, -3830.952, -3831.643, -3831.756, -3831.277, -3830.1940000000004, -3828.491, -3826.153, -3823.1659999999997, -3819.512, -3815.176, -3810.1409999999996, -3804.388, -3797.8990000000003, -3790.655, -3782.636, -3773.822, -3764.191, -3753.7209999999995, -3742.39, -3730.172, -3717.0440000000003, -3702.98, -3687.953, -3671.933, -3654.8940000000002, -3636.803, -3617.6290000000004, -3597.34, -3575.902, -3553.277, -3529.43, -3504.321, -3477.908, -3450.151, -3421.0029999999997, -3390.42, -3358.353, -3324.7509999999997, -3289.563, -3252.732, -3214.2009999999996, -3173.91, -3131.798, -3087.7990000000004, -3041.8459999999995, -2993.867, -2943.79, -2891.539, -2837.0370000000003, -2780.2, -2720.947, -2659.191, -2594.846, -2527.822, -2458.029, -2385.377, -2309.779, -2231.144, -2149.391, -2064.44, -1976.2160000000001, -1884.658, -1789.7160000000001, -1691.349, -1589.5420000000001, -1484.299, -1375.65, -1263.657, -1148.417, -1030.0639999999999, -908.779, -784.784, -658.3510000000001, -529.7959999999999, -399.48, -267.80400000000003, -135.203, -2.134, 130.92700000000002, 263.505, 395.13, 525.352, 653.749, 779.937, 903.574, 1024.364, 1142.062, 1256.47, 1367.432, 1474.84, 1578.624, 1678.745, 1775.1979999999999, 1868.001, 1957.194, 2042.8339999999998, 2124.99, 2203.745, 2279.189, 2351.413, 2420.516, 2486.6, 2549.763, 2610.107, 2667.7309999999998, 2722.7329999999997, 2775.2070000000003, 2825.2459999999996, 2872.941, 2918.3790000000004, 2961.6420000000003, 3003.012, 3041.965, 3079.177, 3114.5190000000002, 3148.058, 3179.86, 3209.988, 3238.5, 3265.455, 3290.907, 3314.908, 3337.507, 3358.7529999999997, 3378.69, 3397.363, 3414.8140000000003, 3431.0809999999997, 3446.204, 3460.219, 3473.16, 3485.062, 3495.955, 3505.8720000000003, 3514.842, 3522.893, 3530.052, 3536.345, 3541.798, 3546.434, 3550.276, 3553.347, 3555.6690000000003, 3557.261, 3558.1440000000002, 3558.336, 3557.857, 3556.724, 3554.953, 3552.563, 3549.567, 3545.9829999999997, 3541.824, 3537.1059999999998, 3531.842, 3526.045, 3519.7270000000003, 3512.903, 3505.5840000000003, 3497.781, 3489.507, 3480.7709999999997, 3471.585, 3461.96, 3451.905, 3441.429, 3430.5429999999997, 3419.256, 3407.5759999999996, 3395.512, 3383.072, 3370.265, 3357.099, 3343.5809999999997, 3329.719, 3315.52, 3300.992, 3286.1409999999996, 3270.973, 3255.4959999999996, 3239.716, 3223.638, 3207.27, 3190.617, 3173.684, 3156.478, 3139.0040000000004, 3121.2670000000003, 3103.272, 3085.025, 3066.531, 3047.7940000000003, 3028.8190000000004, 3009.611, 2990.1740000000004, 2970.513, 2950.632, 2930.5359999999996, 2910.228, 2889.7129999999997, 2868.994, 2848.0759999999996, 2826.962, 2805.656, 2784.1609999999996, 2762.482, 2740.6220000000003, 2718.5840000000003, 2696.3709999999996, 2673.987, 2651.4359999999997, 2628.719, 2605.841, 2582.805, 2559.612, 2536.268, 2512.7729999999997, 2489.132, 2465.347, 2441.42, 2417.355, 2393.153, 2368.819, 2344.353, 2319.759, 2295.04, 2270.196, 2245.232, 2220.149, 2194.95, 2169.637, 2144.212, 2118.677, 2093.034, 2067.2870000000003, 2041.4360000000001, 2015.484, 1989.433, 1963.285, 1937.0420000000001, 1910.705, 1884.2779999999998, 1857.761, 1831.1570000000002, 1804.467, 1777.694, 1750.839, 1723.904, 1696.89, 1669.8, 1642.635, 1615.3970000000002, 1588.0870000000002, 1560.7079999999999, 1533.26, 1505.746, 1478.1670000000001, 1450.524, 1422.82, 1395.055, 1367.2320000000002, 1339.352, 1311.415, 1283.425, 1255.382, 1227.287, 1199.143, 1170.951, 1142.711, 1114.4260000000002, 1086.096, 1057.724, 1029.3110000000001, 1000.857, 972.365, 943.835, 915.2689999999999, 886.668, 858.034, 829.368, 800.671, 771.944, 743.189, 714.4069999999999, 685.5989999999999, 656.7669999999999, 627.911, 599.033, 570.134, 541.216, 512.279, 483.325, 454.35400000000004, 425.369, 396.37, 367.35900000000004, 338.337, 309.30400000000003, 280.262, 251.213, 222.15599999999998, 193.095, 164.02900000000002, 134.959, 105.88799999999999, 76.816, 47.744, 18.673, -10.395, -39.46, -68.52, -97.574, -126.62100000000001, -155.66, -184.68900000000002, -213.708, -242.71599999999998, -271.711, -300.693, -329.659, -358.61, -387.543, -416.459, -445.35400000000004, -474.23, -503.084, -531.915, -560.722, -589.504, -618.26, -646.989, -675.689, -704.36, -733.0, -761.6080000000001, -790.183, -818.7239999999999, -847.23, -875.699, -904.1310000000001, -932.5239999999999, -960.877, -989.188, -1017.4580000000001, -1045.683, -1073.864, -1101.999, -1130.087, -1158.127, -1186.116, -1214.055, -1241.942, -1269.776, -1297.555, -1325.2779999999998, -1352.944, -1380.5520000000001, -1408.1, -1435.586, -1463.011, -1490.372, -1517.668, -1544.898, -1572.06, -1599.154, -1626.1770000000001, -1653.128, -1680.006, -1706.809, -1733.537, -1760.1870000000001, -1786.759, -1813.25, -1839.6589999999999, -1865.985, -1892.227, -1918.382, -1944.4489999999998, -1970.4270000000001, -1996.3139999999999, -2022.109, -2047.809, -2073.4139999999998, -2098.9210000000003, -2124.33, -2149.637, -2174.843, -2199.944, -2224.939, -2249.827, -2274.605, -2299.2729999999997, -2323.827, -2348.266, -2372.589, -2396.792, -2420.876, -2444.8360000000002, -2468.672, -2492.382, -2515.9629999999997, -2539.413, -2562.731, -2585.9139999999998, -2608.959, -2631.866, -2654.631, -2677.252, -2699.7270000000003, -2722.054, -2744.23, -2766.2529999999997, -2788.12, -2809.829, -2831.3779999999997, -2852.763, -2873.9829999999997, -2895.034, -2915.914, -2936.62, -2957.1490000000003, -2977.498, -2997.665, -3017.647, -3037.44, -3057.0409999999997, -3076.448, -3095.656, -3114.664, -3133.467, -3152.062, -3170.446, -3188.615, -3206.565, -3224.2929999999997, -3241.796, -3259.0690000000004, -3276.1079999999997, -3292.909, -3309.469, -3325.784, -3341.848, -3357.658, -3373.2090000000003, -3388.4970000000003, -3403.5170000000003, -3418.264, -3432.7329999999997, -3446.92, -3460.8190000000004, -3474.425, -3487.7329999999997, -3500.737, -3513.4320000000002, -3525.812, -3537.8709999999996, -3549.603, -3561.002, -3572.062, -3582.775, -3593.136, -3603.138, -3612.772, -3622.033, -3630.913, -3639.4040000000005, -3647.498, -3655.187, -3662.4629999999997, -3669.3179999999998, -3675.741, -3681.7259999999997, -3687.262, -3692.3390000000004, -3696.948, -3701.078, -3704.719, -3707.861, -3710.491, -3712.598, -3714.171, -3715.197, -3715.664, -3715.558, -3714.866, -3713.573, -3711.6659999999997, -3709.1290000000004, -3705.946, -3702.1020000000003, -3697.58, -3692.363, -3686.433, -3679.7709999999997, -3672.357, -3664.172, -3655.196, -3645.406, -3634.78, -3623.295, -3610.927, -3597.651, -3583.44, -3568.2690000000002, -3552.1059999999998, -3534.923, -3516.691, -3497.375, -3476.9440000000004, -3455.362, -3432.592, -3408.599, -3383.34, -3356.775, -3328.86, -3299.551, -3268.801, -3236.56, -3202.778, -3167.401, -3130.3720000000003, -3091.633, -3051.1240000000003, -3008.781, -2964.538, -2918.327, -2870.0759999999996, -2819.71, -2767.155, -2712.33, -2655.153, -2595.541, -2533.409, -2468.67, -2401.234, -2331.014, -2257.923, -2181.874, -2102.784, -2020.575, -1935.1760000000002, -1846.521, -1754.559, -1659.253, -1560.582, -1458.549, -1353.18, -1244.53, -1132.692, -1017.795, -900.007, -779.5419999999999, -656.6610000000001, -531.669, -404.913, -276.78, -147.692, -18.093, 111.556, 240.79, 369.153, 496.202, 621.5269999999999, 744.747, 865.528, 983.577, 1098.652, 1210.553, 1319.128, 1424.267, 1525.895, 1623.974, 1718.495, 1809.4720000000002, 1896.942, 1980.9589999999998, 2061.5879999999997, 2138.907, 2213.002, 2283.962, 2351.882, 2416.86, 2478.99, 2538.3720000000003, 2595.101, 2649.2729999999997, 2700.9770000000003, 2750.3059999999996, 2797.347, 2842.184, 2884.897, 2925.566, 2964.2659999999996, 3001.07, 3036.047, 3069.261, 3100.7790000000005, 3130.659, 3158.961, 3185.74, 3211.05, 3234.941, 3257.462, 3278.658, 3298.575, 3317.255, 3334.739, 3351.066, 3366.2729999999997, 3380.395, 3393.466, 3405.52, 3416.5879999999997, 3426.699, 3435.883, 3444.167, 3451.578, 3458.1409999999996, 3463.881, 3468.821, 3472.9829999999997, 3476.39, 3479.063, 3481.0209999999997, 3482.284, 3482.87, 3482.798, 3482.085, 3480.748, 3478.802, 3476.264, 3473.1479999999997, 3469.468, 3465.24, 3460.4759999999997, 3455.191, 3449.395, 3443.1009999999997, 3436.322, 3429.0679999999998, 3421.3509999999997, 3413.1820000000002, 3404.572, 3395.5290000000005, 3386.0640000000003, 3376.187, 3365.907, 3355.2329999999997, 3344.173, 3332.736, 3320.9309999999996, 3308.764, 3296.244, 3283.3790000000004, 3270.176, 3256.6409999999996, 3242.783, 3228.607, 3214.12, 3199.329, 3184.241, 3168.86, 3153.192, 3137.245, 3121.022, 3104.531, 3087.776, 3070.762, 3053.494, 3035.9790000000003, 3018.219, 3000.2209999999995, 2981.988, 2963.526, 2944.8390000000004, 2925.9309999999996, 2906.8059999999996, 2887.469, 2867.923, 2848.173, 2828.222, 2808.075, 2787.735, 2767.205, 2746.489, 2725.592, 2704.515, 2683.263, 2661.8390000000004, 2640.245, 2618.486, 2596.565, 2574.4829999999997, 2552.245, 2529.854, 2507.311, 2484.621, 2461.785, 2438.8070000000002, 2415.689, 2392.4339999999997, 2369.045, 2345.5229999999997, 2321.8720000000003, 2298.094, 2274.1910000000003, 2250.166, 2226.021, 2201.758, 2177.38, 2152.889, 2128.2870000000003, 2103.576, 2078.759, 2053.837, 2028.8129999999999, 2003.6879999999999, 1978.464, 1953.144, 1927.73, 1902.223, 1876.625, 1850.9379999999999, 1825.165, 1799.306, 1773.364, 1747.34, 1721.236, 1695.0539999999999, 1668.796, 1642.463, 1616.057, 1589.579, 1563.0320000000002, 1536.4160000000002, 1509.733, 1482.986, 1456.175, 1429.3020000000001, 1402.369, 1375.376, 1348.326, 1321.22, 1294.06, 1266.846, 1239.5810000000001, 1212.265, 1184.9, 1157.488, 1130.03, 1102.527, 1074.98, 1047.392, 1019.762, 992.0939999999999, 964.387, 936.643, 908.863, 881.049, 853.203, 825.324, 797.415, 769.477, 741.51, 713.5169999999999, 685.498, 657.454, 629.388, 601.299, 573.19, 545.061, 516.913, 488.74800000000005, 460.56699999999995, 432.371, 404.161, 375.93800000000005, 347.704, 319.459, 291.205, 262.943, 234.673, 206.398, 178.118, 149.835, 121.54899999999999, 93.26100000000001, 64.973, 36.686, 8.4, -19.882, -48.161, -76.434, -104.70100000000001, -132.961, -161.21200000000002, -189.454, -217.685, -245.90400000000002, -274.111, -302.30400000000003, -330.48199999999997, -358.64300000000003, -386.788, -414.914, -443.02099999999996, -471.10699999999997, -499.17199999999997, -527.214, -555.232, -583.226, -611.193, -639.134, -667.046, -694.929, -722.7810000000001, -750.602, -778.39, -806.145, -833.8639999999999, -861.547, -889.193, -916.801, -944.3689999999999, -971.8960000000001, -999.382, -1026.8239999999998, -1054.222, -1081.575, -1108.881, -1136.139, -1163.349, -1190.508, -1217.616, -1244.671, -1271.672, -1298.618, -1325.5079999999998, -1352.34, -1379.1129999999998, -1405.826, -1432.4779999999998, -1459.067, -1485.5910000000001, -1512.0510000000002, -1538.443, -1564.7679999999998, -1591.023, -1617.207, -1643.32, -1669.358, -1695.3220000000001, -1721.2089999999998, -1747.019, -1772.749, -1798.399, -1823.9660000000001, -1849.45, -1874.849, -1900.161, -1925.384, -1950.519, -1975.5610000000001, -2000.511, -2025.366, -2050.125, -2074.7870000000003, -2099.349, -2123.8089999999997, -2148.167, -2172.42, -2196.567, -2220.606, -2244.534, -2268.351, -2292.055, -2315.643, -2339.113, -2362.465, -2385.695, -2408.802, -2431.784, -2454.638, -2477.363, -2499.9570000000003, -2522.417, -2544.742, -2566.929, -2588.975, -2610.879, -2632.639, -2654.252, -2675.715, -2697.026, -2718.183, -2739.184, -2760.025, -2780.704, -2801.219, -2821.566, -2841.744, -2861.7490000000003, -2881.578, -2901.2290000000003, -2920.699, -2939.985, -2959.083, -2977.991, -2996.705, -3015.222, -3033.54, -3051.6540000000005, -3069.5609999999997, -3087.258, -3104.741, -3122.007, -3139.051, -3155.8709999999996, -3172.461, -3188.8190000000004, -3204.941, -3220.821, -3236.4559999999997, -3251.842, -3266.974, -3281.848, -3296.4590000000003, -3310.802, -3324.8720000000003, -3338.6659999999997, -3352.176, -3365.4, -3378.33, -3390.962, -3403.29, -3415.308, -3427.011, -3438.393, -3449.447, -3460.167, -3470.547, -3480.579, -3490.258, -3499.5759999999996, -3508.525, -3517.1, -3525.2909999999997, -3533.091, -3540.492, -3547.485, -3554.063, -3560.216, -3565.9359999999997, -3571.2129999999997, -3576.0370000000003, -3580.3990000000003, -3584.288, -3587.6929999999998, -3590.605, -3593.011, -3594.901, -3596.262, -3597.0820000000003, -3597.348, -3597.047, -3596.165, -3594.6890000000003, -3592.6040000000003, -3589.8940000000002, -3586.5440000000003, -3582.539, -3577.86, -3572.492, -3566.415, -3559.611, -3552.06, -3543.743, -3534.639, -3524.725, -3513.9790000000003, -3502.3790000000004, -3489.8979999999997, -3476.513, -3462.196, -3446.92, -3430.656, -3413.375, -3395.0440000000003, -3375.632, -3355.105, -3333.427, -3310.562, -3286.472, -3261.115, -3234.449, -3206.4309999999996, -3177.0159999999996, -3146.155, -3113.7990000000004, -3079.895, -3044.39, -3007.225, -2968.342, -2927.68, -2885.173, -2840.757, -2794.3590000000004, -2745.908, -2695.329, -2642.546, -2587.48, -2530.0460000000003, -2470.1620000000003, -2407.744, -2342.705, -2274.9570000000003, -2204.415, -2130.995, -2054.615, -1975.1970000000001, -1892.668, -1806.9679999999998, -1718.0420000000001, -1625.851, -1530.375, -1431.611, -1329.5829999999999, -1224.344, -1115.976, -1004.602, -890.3839999999999, -773.525, -654.273, -532.922, -409.80699999999996, -285.301, -159.812, -33.77, 92.37899999999999, 218.18200000000002, 343.19300000000004, 466.98199999999997, 589.144, 709.31, 827.148, 942.372, 1054.74, 1164.0539999999999, 1270.164, 1372.954, 1472.3529999999998, 1568.319, 1660.8370000000002, 1749.922, 1835.606, 1917.9370000000001, 1996.979, 2072.806, 2145.498, 2215.143, 2281.831, 2345.655, 2406.708, 2465.084, 2520.8779999999997, 2574.179, 2625.078, 2673.6609999999996, 2720.013, 2764.217, 2806.3509999999997, 2846.491, 2884.71, 2921.079, 2955.665, 2988.532, 3019.742, 3049.355, 3077.427, 3104.012, 3129.1620000000003, 3152.926, 3175.3520000000003, 3196.485, 3216.367, 3235.042, 3252.547, 3268.922, 3284.202, 3298.422, 3311.615, 3323.813, 3335.047, 3345.3459999999995, 3354.738, 3363.25, 3370.908, 3377.736, 3383.759, 3389.0009999999997, 3393.4809999999998, 3397.2209999999995, 3400.243, 3402.566, 3404.208, 3405.1890000000003, 3405.5240000000003, 3405.232, 3404.329, 3402.83, 3400.7509999999997, 3398.1059999999998, 3394.909, 3391.1740000000004, 3386.915, 3382.143, 3376.873, 3371.115, 3364.881, 3358.1809999999996, 3351.028, 3343.4309999999996, 3335.401, 3326.948, 3318.0809999999997, 3308.81, 3299.143, 3289.0890000000004, 3278.657, 3267.8559999999998, 3256.692, 3245.1740000000004, 3233.31, 3221.107, 3208.571, 3195.711, 3182.532, 3169.0409999999997, 3155.2459999999996, 3141.151, 3126.764, 3112.09, 3097.135, 3081.9040000000005, 3066.403, 3050.638, 3034.613, 3018.3340000000003, 3001.8059999999996, 2985.034, 2968.0209999999997, 2950.7740000000003, 2933.297, 2915.594, 2897.6679999999997, 2879.526, 2861.17, 2842.6059999999998, 2823.836, 2804.864, 2785.695, 2766.333, 2746.78, 2727.0409999999997, 2707.118, 2687.0159999999996, 2666.738, 2646.2859999999996, 2625.665, 2604.877, 2583.925, 2562.813, 2541.544, 2520.12, 2498.544, 2476.819, 2454.948, 2432.933, 2410.778, 2388.485, 2366.056, 2343.494, 2320.802, 2297.981, 2275.035, 2251.966, 2228.775, 2205.466, 2182.04, 2158.5, 2134.847, 2111.085, 2087.215, 2063.239, 2039.1589999999999, 2014.9779999999998, 1990.6970000000001, 1966.318, 1941.8429999999998, 1917.275, 1892.614, 1867.8629999999998, 1843.024, 1818.098, 1793.088, 1767.994, 1742.819, 1717.5639999999999, 1692.2320000000002, 1666.8229999999999, 1641.34, 1615.783, 1590.155, 1564.4579999999999, 1538.692, 1512.859, 1486.9620000000002, 1461.0, 1434.977, 1408.892, 1382.749, 1356.5479999999998, 1330.29, 1303.978, 1277.612, 1251.193, 1224.724, 1198.2060000000001, 1171.64, 1145.027, 1118.369, 1091.6660000000002, 1064.921, 1038.134, 1011.308, 984.442, 957.539, 930.5989999999999, 903.6239999999999, 876.6160000000001, 849.574, 822.5010000000001, 795.398, 768.2660000000001, 741.1060000000001, 713.919, 686.707, 659.47, 632.211, 604.929, 577.626, 550.304, 522.9630000000001, 495.60400000000004, 468.23, 440.84, 413.436, 386.019, 358.59, 331.15, 303.70099999999996, 276.243, 248.77700000000002, 221.305, 193.828, 166.347, 138.862, 111.376, 83.88799999999999, 56.401, 28.914, 1.43, -26.05, -53.527, -80.998, -108.463, -135.92, -163.368, -190.80700000000002, -218.235, -245.65099999999998, -273.055, -300.444, -327.81800000000004, -355.17699999999996, -382.51800000000003, -409.841, -437.145, -464.42900000000003, -491.691, -518.931, -546.1469999999999, -573.3380000000001, -600.504, -627.643, -654.755, -681.837, -708.8889999999999, -735.91, -762.8989999999999, -789.8539999999999, -816.775, -843.66, -870.5089999999999, -897.32, -924.092, -950.823, -977.5139999999999, -1004.1619999999999, -1030.766, -1057.326, -1083.84, -1110.307, -1136.726, -1163.095, -1189.414, -1215.681, -1241.895, -1268.0539999999999, -1294.1589999999999, -1320.2060000000001, -1346.195, -1372.126, -1397.996, -1423.8039999999999, -1449.549, -1475.229, -1500.844, -1526.392, -1551.872, -1577.2820000000002, -1602.621, -1627.8870000000002, -1653.08, -1678.1979999999999, -1703.239, -1728.2020000000002, -1753.086, -1777.888, -1802.609, -1827.245, -1851.796, -1876.26, -1900.636, -1924.922, -1949.116, -1973.217, -1997.224, -2021.1329999999998, -2044.945, -2068.657, -2092.268, -2115.776, -2139.178, -2162.474, -2185.6620000000003, -2208.739, -2231.705, -2254.556, -2277.292, -2299.91, -2322.408, -2344.784, -2367.0370000000003, -2389.165, -2411.1639999999998, -2433.034, -2454.772, -2476.375, -2497.843, -2519.172, -2540.36, -2561.406, -2582.305, -2603.0570000000002, -2623.659, -2644.1090000000004, -2664.402, -2684.539, -2704.515, -2724.328, -2743.975, -2763.454, -2782.762, -2801.897, -2820.8540000000003, -2839.631, -2858.2259999999997, -2876.635, -2894.855, -2912.883, -2930.716, -2948.35, -2965.782, -2983.009, -3000.026, -3016.8320000000003, -3033.421, -3049.79, -3065.935, -3081.853, -3097.539, -3112.989, -3128.2, -3143.1659999999997, -3157.884, -3172.349, -3186.5570000000002, -3200.5029999999997, -3214.1809999999996, -3227.5879999999997, -3240.718, -3253.567, -3266.1279999999997, -3278.3959999999997, -3290.367, -3302.033, -3313.39, -3324.4309999999996, -3335.151, -3345.5429999999997, -3355.6, -3365.317, -3374.6859999999997, -3383.7, -3392.3520000000003, -3400.635, -3408.5409999999997, -3416.062, -3423.191, -3429.9179999999997, -3436.237, -3442.136, -3447.6090000000004, -3452.645, -3457.236, -3461.37, -3465.039, -3468.23, -3470.934, -3473.139, -3474.8340000000003, -3476.006, -3476.6440000000002, -3476.735, -3476.265, -3475.2209999999995, -3473.5890000000004, -3471.353, -3468.5, -3465.013, -3460.877, -3456.074, -3450.586, -3444.395, -3437.4840000000004, -3429.8309999999997, -3421.4179999999997, -3412.222, -3402.223, -3391.397, -3379.72, -3367.1690000000003, -3353.717, -3339.336, -3324.0009999999997, -3307.6809999999996, -3290.347, -3271.966, -3252.507, -3231.934, -3210.2129999999997, -3187.304, -3163.17, -3137.77, -3111.0609999999997, -3082.9990000000003, -3053.5370000000003, -3022.627, -2990.218, -2956.257, -2920.6890000000003, -2883.4559999999997, -2844.5, -2803.755, -2761.159, -2716.6420000000003, -2670.135, -2621.565, -2570.856, -2517.931, -2462.7110000000002, -2405.113, -2345.053, -2282.448, -2217.214, -2149.265, -2078.518, -2004.8929999999998, -1928.3129999999999, -1848.7079999999999, -1766.013, -1680.1760000000002, -1591.158, -1498.934, -1403.501, -1304.879, -1203.114, -1098.2839999999999, -990.5060000000001, -879.93, -766.7510000000001, -651.207, -533.578, -414.186, -293.392, -171.58599999999998, -49.187, 73.373, 195.655, 317.226, 437.664, 556.577, 673.6010000000001, 788.4110000000001, 900.7239999999999, 1010.302, 1116.9489999999998, 1220.513, 1320.881, 1417.976, 1511.755, 1602.204, 1689.33, 1773.162, 1853.7479999999998, 1931.145, 2005.4229999999998, 2076.66, 2144.937, 2210.344, 2272.967, 2332.8979999999997, 2390.2270000000003, 2445.044, 2497.437, 2547.492, 2595.295, 2640.926, 2684.465, 2725.988, 2765.4590000000003, 2803.281, 2839.19, 2873.36, 2905.8559999999998, 2936.739, 2966.063, 2993.885, 3020.257, 3045.2290000000003, 3068.85, 3091.1659999999997, 3112.2209999999995, 3132.0559999999996, 3150.712, 3168.2270000000003, 3184.639, 3199.982, 3214.29, 3227.5959999999995, 3239.9309999999996, 3251.324, 3261.804, 3271.3979999999997, 3280.132, 3288.033, 3295.1220000000003, 3301.425, 3306.9640000000004, 3311.759, 3315.833, 3319.203, 3321.889, 3323.9109999999996, 3325.285, 3326.028, 3326.158, 3325.69, 3324.64, 3323.022, 3320.85, 3318.138, 3314.901, 3311.15, 3306.8979999999997, 3302.157, 3296.938, 3291.2540000000004, 3285.114, 3278.53, 3271.512, 3264.0690000000004, 3256.212, 3247.949, 3239.29, 3230.244, 3220.8190000000004, 3211.0229999999997, 3200.864, 3190.3509999999997, 3179.491, 3168.2909999999997, 3156.758, 3144.9, 3132.723, 3120.2340000000004, 3107.44, 3094.345, 3080.958, 3067.283, 3053.3259999999996, 3039.093, 3024.59, 3009.822, 2994.795, 2979.512, 2963.98, 2948.203, 2932.1859999999997, 2915.933, 2899.45, 2882.74, 2865.808, 2848.658, 2831.295, 2813.7209999999995, 2795.942, 2777.961, 2759.782, 2741.409, 2722.845, 2704.094, 2685.159, 2666.0440000000003, 2646.752, 2627.2859999999996, 2607.649, 2587.846, 2567.8779999999997, 2547.749, 2527.462, 2507.019, 2486.424, 2465.679, 2444.788, 2423.752, 2402.574, 2381.258, 2359.805, 2338.218, 2316.5, 2294.652, 2272.678, 2250.58, 2228.36, 2206.02, 2183.562, 2160.99, 2138.304, 2115.507, 2092.601, 2069.5879999999997, 2046.471, 2023.251, 1999.9289999999999, 1976.509, 1952.9920000000002, 1929.38, 1905.675, 1881.878, 1857.991, 1834.017, 1809.9560000000001, 1785.8110000000001, 1761.5839999999998, 1737.275, 1712.8870000000002, 1688.422, 1663.88, 1639.264, 1614.576, 1589.815, 1564.986, 1540.088, 1515.1229999999998, 1490.0929999999998, 1464.999, 1439.8429999999998, 1414.626, 1389.35, 1364.015, 1338.624, 1313.1779999999999, 1287.678, 1262.126, 1236.522, 1210.868, 1185.1660000000002, 1159.417, 1133.622, 1107.782, 1081.899, 1055.974, 1030.008, 1004.002, 977.9580000000001, 951.877, 925.7589999999999, 899.607, 873.422, 847.204, 820.955, 794.676, 768.368, 742.0319999999999, 715.67, 689.2819999999999, 662.87, 636.434, 609.987, 583.508, 557.01, 530.493, 503.958, 477.407, 450.84, 424.259, 397.665, 371.05800000000005, 344.44, 317.812, 291.175, 264.53, 237.878, 211.22099999999998, 184.558, 157.892, 131.222, 104.552, 77.88, 51.208999999999996, 24.539, -2.128, -28.791999999999998, -55.451, -82.105, -108.75200000000001, -135.391, -162.02200000000002, -188.643, -215.25400000000002, -241.852, -268.438, -295.01099999999997, -321.568, -348.10900000000004, -374.634, -401.14, -427.62800000000004, -454.095, -480.542, -506.966, -533.367, -559.744, -586.096, -612.4209999999999, -638.719, -664.9889999999999, -691.2289999999999, -717.438, -743.6160000000001, -769.7610000000001, -795.872, -821.948, -847.988, -873.9910000000001, -899.956, -925.8810000000001, -951.7660000000001, -977.61, -1003.4110000000001, -1029.167, -1054.879, -1080.545, -1106.164, -1131.734, -1157.254, -1182.724, -1208.141, -1233.506, -1258.816, -1284.07, -1309.267, -1334.4070000000002, -1359.487, -1384.506, -1409.464, -1434.359, -1459.1889999999999, -1483.953, -1508.65, -1533.279, -1557.839, -1582.3270000000002, -1606.743, -1631.0839999999998, -1655.351, -1679.5410000000002, -1703.654, -1727.6860000000001, -1751.638, -1775.5079999999998, -1799.293, -1822.993, -1846.6070000000002, -1870.131, -1893.566, -1916.9089999999999, -1940.16, -1963.315, -1986.374, -2009.335, -2032.1960000000001, -2054.955, -2077.612, -2100.163, -2122.6079999999997, -2144.944, -2167.17, -2189.284, -2211.284, -2233.1679999999997, -2254.9339999999997, -2276.58, -2298.104, -2319.505, -2340.779, -2361.926, -2382.9429999999998, -2403.827, -2424.577, -2445.19, -2465.6639999999998, -2485.9970000000003, -2506.187, -2526.231, -2546.126, -2565.87, -2585.462, -2604.897, -2624.1740000000004, -2643.29, -2662.243, -2681.0290000000005, -2699.645, -2718.09, -2736.3590000000004, -2754.4509999999996, -2772.362, -2790.0879999999997, -2807.6279999999997, -2824.9770000000003, -2842.133, -2859.092, -2875.8509999999997, -2892.406, -2908.7529999999997, -2924.89, -2940.812, -2956.5159999999996, -2971.998, -2987.2540000000004, -3002.2790000000005, -3017.071, -3031.623, -3045.934, -3059.9970000000003, -3073.808, -3087.363, -3100.657, -3113.6859999999997, -3126.4440000000004, -3138.926, -3151.127, -3163.0409999999997, -3174.663, -3185.988, -3197.01, -3207.723, -3218.12, -3228.196, -3237.9440000000004, -3247.3579999999997, -3256.4309999999996, -3265.155, -3273.525, -3281.532, -3289.1690000000003, -3296.428, -3303.301, -3309.78, -3315.857, -3321.522, -3326.768, -3331.5840000000003, -3335.961, -3339.89, -3343.3590000000004, -3346.3579999999997, -3348.8779999999997, -3350.905, -3352.43, -3353.44, -3353.922, -3353.865, -3353.2540000000004, -3352.0759999999996, -3350.317, -3347.962, -3344.9959999999996, -3341.4040000000005, -3337.1690000000003, -3332.275, -3326.702, -3320.434, -3313.452, -3305.735, -3297.264, -3288.0170000000003, -3277.972, -3267.107, -3255.397, -3242.8179999999998, -3229.343, -3214.946, -3199.599, -3183.272, -3165.934, -3147.555, -3128.1, -3107.5359999999996, -3085.825, -3062.93, -3038.8109999999997, -3013.427, -2986.736, -2958.691, -2929.2459999999996, -2898.3520000000003, -2865.9570000000003, -2832.008, -2796.449, -2759.2209999999995, -2720.265, -2679.5159999999996, -2636.908, -2592.373, -2545.841, -2497.239, -2446.489, -2393.515, -2338.237, -2280.574, -2220.442, -2157.76, -2092.445, -2024.415, -1953.59, -1879.8970000000002, -1803.2620000000002, -1723.625, -1640.931, -1555.14, -1466.227, -1374.1860000000001, -1279.031, -1180.806, -1079.583, -975.4689999999999, -868.61, -759.187, -647.429, -533.6030000000001, -418.01800000000003, -301.019, -182.984, -64.316, 54.567, 173.239, 291.279, 408.278, 523.852, 637.645, 749.3389999999999, 858.655, 965.36, 1069.258, 1170.197, 1268.065, 1362.7820000000002, 1454.305, 1542.614, 1627.714, 1709.6329999999998, 1788.411, 1864.1029999999998, 1936.777, 2006.503, 2073.362, 2137.438, 2198.814, 2257.577, 2313.817, 2367.616, 2419.062, 2468.237, 2515.224, 2560.1, 2602.9429999999998, 2643.8259999999996, 2682.822, 2719.9970000000003, 2755.4190000000003, 2789.151, 2821.2529999999997, 2851.785, 2880.8, 2908.353, 2934.494, 2959.272, 2982.7340000000004, 3004.925, 3025.888, 3045.6620000000003, 3064.2870000000003, 3081.8, 3098.238, 3113.635, 3128.022, 3141.433, 3153.897, 3165.442, 3176.097, 3185.887, 3194.84, 3202.978, 3210.3259999999996, 3216.905, 3222.739, 3227.847, 3232.2509999999997, 3235.969, 3239.0190000000002, 3241.4190000000003, 3243.188, 3244.34, 3244.8940000000002, 3244.863, 3244.263, 3243.1090000000004, 3241.414, 3239.191, 3236.454, 3233.215, 3229.486, 3225.28, 3220.607, 3215.478, 3209.9040000000005, 3203.895, 3197.462, 3190.613, 3183.3590000000004, 3175.708, 3167.6690000000003, 3159.2509999999997, 3150.4629999999997, 3141.3109999999997, 3131.805, 3121.9509999999996, 3111.757, 3101.2309999999998, 3090.3779999999997, 3079.2070000000003, 3067.724, 3055.934, 3043.8459999999995, 3031.4629999999997, 3018.7940000000003, 3005.842, 2992.615, 2979.117, 2965.353, 2951.33, 2937.051, 2922.5229999999997, 2907.75, 2892.737, 2877.488, 2862.007, 2846.301, 2830.3720000000003, 2814.224, 2797.863, 2781.292, 2764.514, 2747.535, 2730.357, 2712.985, 2695.421, 2677.67, 2659.735, 2641.619, 2623.325, 2604.8579999999997, 2586.22, 2567.413, 2548.4429999999998, 2529.31, 2510.019, 2490.572, 2470.971, 2451.221, 2431.323, 2411.28, 2391.095, 2370.77, 2350.308, 2329.712, 2308.9829999999997, 2288.125, 2267.139, 2246.028, 2224.795, 2203.44, 2181.968, 2160.379, 2138.677, 2116.862, 2094.938, 2072.905, 2050.7670000000003, 2028.525, 2006.182, 1983.7379999999998, 1961.1960000000001, 1938.558, 1915.826, 1893.001, 1870.085, 1847.0810000000001, 1823.989, 1800.8110000000001, 1777.55, 1754.2060000000001, 1730.7820000000002, 1707.279, 1683.6979999999999, 1660.0420000000001, 1636.3120000000001, 1612.509, 1588.634, 1564.69, 1540.6779999999999, 1516.599, 1492.455, 1468.247, 1443.977, 1419.646, 1395.255, 1370.806, 1346.3, 1321.739, 1297.123, 1272.455, 1247.735, 1222.965, 1198.146, 1173.279, 1148.366, 1123.407, 1098.405, 1073.36, 1048.2730000000001, 1023.1460000000001, 997.98, 972.7760000000001, 947.535, 922.2589999999999, 896.948, 871.6039999999999, 846.227, 820.82, 795.383, 769.9169999999999, 744.424, 718.904, 693.3580000000001, 667.788, 642.195, 616.58, 590.944, 565.2869999999999, 539.612, 513.919, 488.209, 462.483, 436.74199999999996, 410.98800000000006, 385.221, 359.44199999999995, 333.653, 307.85400000000004, 282.047, 256.232, 230.41, 204.583, 178.752, 152.917, 127.079, 101.241, 75.40100000000001, 49.562, 23.725, -2.11, -27.941, -53.766999999999996, -79.58800000000001, -105.40299999999999, -131.21, -157.00799999999998, -182.797, -208.575, -234.342, -260.096, -285.837, -311.563, -337.274, -362.968, -388.644, -414.30199999999996, -439.94, -465.55800000000005, -491.154, -516.727, -542.2769999999999, -567.802, -593.3009999999999, -618.774, -644.2180000000001, -669.6339999999999, -695.02, -720.375, -745.698, -770.988, -796.2439999999999, -821.465, -846.6489999999999, -871.797, -896.905, -921.975, -947.003, -971.99, -996.934, -1021.835, -1046.69, -1071.499, -1096.26, -1120.973, -1145.637, -1170.25, -1194.81, -1219.318, -1243.771, -1268.1680000000001, -1292.509, -1316.7920000000001, -1341.016, -1365.1789999999999, -1389.28, -1413.319, -1437.293, -1461.201, -1485.043, -1508.816, -1532.52, -1556.1529999999998, -1579.714, -1603.2020000000002, -1626.614, -1649.95, -1673.2079999999999, -1696.3870000000002, -1719.485, -1742.501, -1765.433, -1788.28, -1811.0410000000002, -1833.713, -1856.296, -1878.787, -1901.185, -1923.489, -1945.6960000000001, -1967.806, -1989.816, -2011.725, -2033.531, -2055.232, -2076.827, -2098.313, -2119.689, -2140.953, -2162.104, -2183.138, -2204.055, -2224.8520000000003, -2245.527, -2266.078, -2286.504, -2306.801, -2326.968, -2347.0029999999997, -2366.904, -2386.667, -2406.292, -2425.775, -2445.115, -2464.308, -2483.353, -2502.2470000000003, -2520.986, -2539.57, -2557.996, -2576.259, -2594.359, -2612.291, -2630.053, -2647.643, -2665.0570000000002, -2682.292, -2699.345, -2716.2129999999997, -2732.893, -2749.382, -2765.675, -2781.7709999999997, -2797.665, -2813.3540000000003, -2828.8340000000003, -2844.1009999999997, -2859.152, -2873.9829999999997, -2888.59, -2902.968, -2917.114, -2931.0240000000003, -2944.692, -2958.115, -2971.288, -2984.2070000000003, -2996.866, -3009.261, -3021.386, -3033.237, -3044.809, -3056.095, -3067.09, -3077.789, -3088.1859999999997, -3098.275, -3108.0490000000004, -3117.502, -3126.6279999999997, -3135.42, -3143.8709999999996, -3151.974, -3159.722, -3167.1079999999997, -3174.123, -3180.76, -3187.01, -3192.866, -3198.3179999999998, -3203.357, -3207.975, -3212.1620000000003, -3215.908, -3219.202, -3222.035, -3224.395, -3226.272, -3227.6540000000005, -3228.5290000000005, -3228.885, -3228.708, -3227.986, -3226.7059999999997, -3224.8520000000003, -3222.4109999999996, -3219.367, -3215.704, -3211.407, -3206.458, -3200.8379999999997, -3194.531, -3187.518, -3179.778, -3171.2909999999997, -3162.0359999999996, -3151.99, -3141.131, -3129.435, -3116.8759999999997, -3103.428, -3089.0640000000003, -3073.757, -3057.475, -3040.1890000000003, -3021.867, -3002.475, -2981.9770000000003, -2960.337, -2937.5159999999996, -2913.4759999999997, -2888.173, -2861.566, -2833.607, -2804.2490000000003, -2773.4429999999998, -2741.136, -2707.276, -2671.803, -2634.66, -2595.786, -2555.116, -2512.585, -2468.1220000000003, -2421.657, -2373.117, -2322.425, -2269.504, -2214.275, -2156.658, -2096.57, -2033.932, -1968.664, -1900.6870000000001, -1829.9270000000001, -1756.315, -1679.787, -1600.2920000000001, -1517.785, -1432.2420000000002, -1343.6529999999998, -1252.029, -1157.411, -1059.862, -959.4839999999999, -856.413, -750.822, -642.927, -532.9830000000001, -421.286, -308.166, -193.987, -79.137, 35.98, 150.953, 265.372, 378.842, 490.986, 601.46, 709.95, 816.183, 919.929, 1020.993, 1119.226, 1214.514, 1306.777, 1395.969, 1482.066, 1565.0710000000001, 1645.009, 1721.9160000000002, 1795.8429999999998, 1866.852, 1935.0120000000002, 2000.4, 2063.092, 2123.172, 2180.723, 2235.827, 2288.5660000000003, 2339.025, 2387.282, 2433.415, 2477.501, 2519.615, 2559.826, 2598.2039999999997, 2634.816, 2669.7259999999997, 2702.993, 2734.677, 2764.8340000000003, 2793.518, 2820.782, 2846.673, 2871.238, 2894.5240000000003, 2916.573, 2937.428, 2957.1259999999997, 2975.708, 2993.2070000000003, 3009.66, 3025.099, 3039.5559999999996, 3053.0609999999997, 3065.645, 3077.335, 3088.158, 3098.139, 3107.303, 3115.6740000000004, 3123.275, 3130.1279999999997, 3136.2529999999997, 3141.672, 3146.4040000000005, 3150.467, 3153.8790000000004, 3156.658, 3158.82, 3160.383, 3161.36, 3161.768, 3161.62, 3160.9309999999996, 3159.715, 3157.9840000000004, 3155.75, 3153.027, 3149.8259999999996, 3146.158, 3142.035, 3137.467, 3132.4629999999997, 3127.0359999999996, 3121.1929999999998, 3114.9440000000004, 3108.3, 3101.2670000000003, 3093.8559999999998, 3086.074, 3077.929, 3069.43, 3060.5840000000003, 3051.3979999999997, 3041.8790000000004, 3032.035, 3021.873, 3011.3979999999997, 3000.618, 2989.538, 2978.165, 2966.505, 2954.5640000000003, 2942.3459999999995, 2929.8579999999997, 2917.105, 2904.093, 2890.825, 2877.308, 2863.546, 2849.5440000000003, 2835.3059999999996, 2820.8379999999997, 2806.1420000000003, 2791.225, 2776.0890000000004, 2760.74, 2745.18, 2729.414, 2713.446, 2697.28, 2680.9190000000003, 2664.367, 2647.627, 2630.702, 2613.597, 2596.315, 2578.8579999999997, 2561.23, 2543.433, 2525.472, 2507.349, 2489.067, 2470.629, 2452.0370000000003, 2433.295, 2414.404, 2395.369, 2376.19, 2356.8720000000003, 2337.416, 2317.824, 2298.1, 2278.246, 2258.264, 2238.156, 2217.924, 2197.571, 2177.1, 2156.511, 2135.808, 2114.992, 2094.0660000000003, 2073.031, 2051.889, 2030.642, 2009.293, 1987.8429999999998, 1966.2939999999999, 1944.648, 1922.9070000000002, 1901.0720000000001, 1879.145, 1857.128, 1835.023, 1812.8310000000001, 1790.555, 1768.195, 1745.753, 1723.231, 1700.63, 1677.953, 1655.2, 1632.3729999999998, 1609.473, 1586.503, 1563.463, 1540.355, 1517.181, 1493.941, 1470.638, 1447.2720000000002, 1423.845, 1400.358, 1376.8129999999999, 1353.211, 1329.5529999999999, 1305.84, 1282.075, 1258.257, 1234.389, 1210.472, 1186.506, 1162.494, 1138.435, 1114.3319999999999, 1090.1860000000001, 1065.998, 1041.768, 1017.4989999999999, 993.191, 968.846, 944.4639999999999, 920.047, 895.596, 871.112, 846.595, 822.048, 797.471, 772.8660000000001, 748.2330000000001, 723.573, 698.888, 674.178, 649.445, 624.69, 599.913, 575.116, 550.3, 525.466, 500.61400000000003, 475.746, 450.86300000000006, 425.966, 401.056, 376.13300000000004, 351.2, 326.256, 301.303, 276.341, 251.373, 226.398, 201.418, 176.43400000000003, 151.446, 126.456, 101.465, 76.473, 51.482, 26.491999999999997, 1.505, -23.479, -48.458, -73.432, -98.399, -123.359, -148.311, -173.25400000000002, -198.18599999999998, -223.107, -248.016, -272.91200000000003, -297.793, -322.66, -347.51, -372.344, -397.159, -421.95599999999996, -446.73199999999997, -471.48699999999997, -496.221, -520.931, -545.618, -570.279, -594.915, -619.523, -644.104, -668.655, -693.177, -717.6669999999999, -742.1260000000001, -766.551, -790.942, -815.298, -839.618, -863.9, -888.1439999999999, -912.3480000000001, -936.512, -960.6339999999999, -984.7139999999999, -1008.7489999999999, -1032.74, -1056.685, -1080.583, -1104.432, -1128.232, -1151.981, -1175.6789999999999, -1199.323, -1222.914, -1246.4489999999998, -1269.928, -1293.349, -1316.711, -1340.013, -1363.254, -1386.432, -1409.546, -1432.595, -1455.5770000000002, -1478.4920000000002, -1501.3370000000002, -1524.112, -1546.816, -1569.4460000000001, -1592.001, -1614.481, -1636.8829999999998, -1659.207, -1681.45, -1703.612, -1725.69, -1747.684, -1769.5910000000001, -1791.411, -1813.142, -1834.781, -1856.328, -1877.7820000000002, -1899.139, -1920.399, -1941.56, -1962.62, -1983.5770000000002, -2004.431, -2025.1779999999999, -2045.817, -2066.347, -2086.765, -2107.069, -2127.258, -2147.3289999999997, -2167.281, -2187.112, -2206.819, -2226.401, -2245.855, -2265.179, -2284.371, -2303.429, -2322.35, -2341.132, -2359.7729999999997, -2378.27, -2396.6220000000003, -2414.824, -2432.876, -2450.774, -2468.515, -2486.098, -2503.518, -2520.774, -2537.863, -2554.782, -2571.527, -2588.096, -2604.485, -2620.6929999999998, -2636.7140000000004, -2652.547, -2668.187, -2683.632, -2698.877, -2713.92, -2728.756, -2743.382, -2757.7940000000003, -2771.988, -2785.961, -2799.7070000000003, -2813.223, -2826.505, -2839.5490000000004, -2852.348, -2864.9, -2877.2, -2889.242, -2901.022, -2912.535, -2923.7740000000003, -2934.736, -2945.415, -2955.804, -2965.8979999999997, -2975.691, -2985.178, -2994.3509999999997, -3003.205, -3011.7329999999997, -3019.927, -3027.782, -3035.289, -3042.442, -3049.232, -3055.652, -3061.6940000000004, -3067.349, -3072.6090000000004, -3077.465, -3081.908, -3085.928, -3089.5159999999996, -3092.6609999999996, -3095.353, -3097.5809999999997, -3099.335, -3100.6020000000003, -3101.3720000000003, -3101.63, -3101.366, -3100.565, -3099.215, -3097.3, -3094.8070000000002, -3091.72, -3088.0229999999997, -3083.7009999999996, -3078.736, -3073.1090000000004, -3066.804, -3059.801, -3052.0809999999997, -3043.6220000000003, -3034.4040000000005, -3024.4040000000005, -3013.599, -3001.965, -2989.4759999999997, -2976.107, -2961.83, -2946.616, -2930.4359999999997, -2913.259, -2895.052, -2875.782, -2855.4120000000003, -2833.906, -2811.2259999999997, -2787.3309999999997, -2762.178, -2735.725, -2707.925, -2678.728, -2648.086, -2615.946, -2582.2529999999997, -2546.95, -2509.9770000000003, -2471.2729999999997, -2430.772, -2388.41, -2344.115, -2297.8160000000003, -2249.44, -2198.913, -2146.155, -2091.089, -2033.6370000000002, -1973.7179999999998, -1911.255, -1846.172, -1778.3929999999998, -1707.852, -1634.486, -1558.241, -1479.076, -1396.9589999999998, -1311.882, -1223.853, -1132.905, -1039.098, -942.5269999999999, -843.316, -741.632, -637.678, -531.696, -423.969, -314.813, -204.576, -93.633, 17.63, 128.813, 239.523, 349.37199999999996, 457.99800000000005, 565.062, 670.2589999999999, 773.323, 874.0219999999999, 972.17, 1067.616, 1160.244, 1249.976, 1336.761, 1420.575, 1501.418, 1579.307, 1654.2779999999998, 1726.379, 1795.6660000000002, 1862.204, 1926.065, 1987.3239999999998, 2046.059, 2102.349, 2156.272, 2207.91, 2257.34, 2304.639, 2349.883, 2393.145, 2434.495, 2474.002, 2511.739, 2547.7529999999997, 2582.1220000000003, 2614.899, 2646.14, 2675.9, 2704.2309999999998, 2731.184, 2756.805, 2781.139, 2804.2309999999998, 2826.123, 2846.8540000000003, 2866.4629999999997, 2884.987, 2902.4590000000003, 2918.915, 2934.385, 2948.901, 2962.493, 2975.188, 2987.014, 2997.998, 3008.1620000000003, 3017.532, 3026.131, 3033.9809999999998, 3041.1020000000003, 3047.5159999999996, 3053.242, 3058.3, 3062.7059999999997, 3066.48, 3069.636, 3072.192, 3074.164, 3075.566, 3076.413, 3076.719, 3076.4970000000003, 3075.762, 3074.525, 3072.7990000000004, 3070.595, 3067.925, 3064.8, 3061.23, 3057.2270000000003, 3052.8, 3047.9590000000003, 3042.7129999999997, 3037.071, 3031.042, 3024.635, 3017.8579999999997, 3010.719, 3003.2259999999997, 2995.387, 2987.208, 2978.698, 2969.864, 2960.711, 2951.2470000000003, 2941.478, 2931.41, 2921.05, 2910.403, 2899.475, 2888.272, 2876.8, 2865.062, 2853.066, 2840.815, 2828.315, 2815.57, 2802.586, 2789.367, 2775.917, 2762.241, 2748.343, 2734.2270000000003, 2719.8979999999997, 2705.3579999999997, 2690.613, 2675.6659999999997, 2660.5209999999997, 2645.1809999999996, 2629.651, 2613.9320000000002, 2598.03, 2581.946, 2565.686, 2549.25, 2532.644, 2515.87, 2498.931, 2481.8289999999997, 2464.5679999999998, 2447.151, 2429.581, 2411.86, 2393.99, 2375.975, 2357.817, 2339.519, 2321.083, 2302.511, 2283.806, 2264.971, 2246.007, 2226.917, 2207.703, 2188.367, 2168.9120000000003, 2149.339, 2129.651, 2109.85, 2089.938, 2069.916, 2049.7870000000003, 2029.5529999999999, 2009.215, 1988.776, 1968.237, 1947.6, 1926.8670000000002, 1906.039, 1885.119, 1864.108, 1843.007, 1821.819, 1800.545, 1779.1870000000001, 1757.746, 1736.223, 1714.621, 1692.941, 1671.185, 1649.3529999999998, 1627.4479999999999, 1605.47, 1583.422, 1561.3039999999999, 1539.119, 1516.8670000000002, 1494.55, 1472.1689999999999, 1449.726, 1427.221, 1404.6570000000002, 1382.0339999999999, 1359.354, 1336.618, 1313.828, 1290.984, 1268.087, 1245.14, 1222.143, 1199.097, 1176.004, 1152.864, 1129.68, 1106.451, 1083.18, 1059.867, 1036.514, 1013.1210000000001, 989.69, 966.222, 942.717, 919.178, 895.605, 871.998, 848.36, 824.692, 800.993, 777.2660000000001, 753.5110000000001, 729.7289999999999, 705.922, 682.091, 658.235, 634.3580000000001, 610.4580000000001, 586.538, 562.599, 538.641, 514.665, 490.67199999999997, 466.664, 442.64099999999996, 418.605, 394.555, 370.494, 346.42199999999997, 322.34, 298.25, 274.151, 250.045, 225.933, 201.815, 177.69400000000002, 153.569, 129.442, 105.314, 81.185, 57.056000000000004, 32.929, 8.804, -15.318, -39.435, -63.548, -87.654, -111.75299999999999, -135.845, -159.92700000000002, -184.0, -208.062, -232.112, -256.15, -280.17400000000004, -304.184, -328.17800000000005, -352.156, -376.11699999999996, -400.059, -423.98199999999997, -447.885, -471.767, -495.62699999999995, -519.4630000000001, -543.276, -567.063, -590.825, -614.559, -638.266, -661.943, -685.591, -709.207, -732.7919999999999, -756.3439999999999, -779.8610000000001, -803.3439999999999, -826.79, -850.2, -873.571, -896.903, -920.195, -943.445, -966.653, -989.818, -1012.938, -1036.012, -1059.04, -1082.02, -1104.95, -1127.8310000000001, -1150.66, -1173.437, -1196.16, -1218.829, -1241.441, -1263.997, -1286.494, -1308.931, -1331.308, -1353.6229999999998, -1375.874, -1398.0610000000001, -1420.182, -1442.236, -1464.221, -1486.1370000000002, -1507.981, -1529.753, -1551.451, -1573.0739999999998, -1594.62, -1616.088, -1637.477, -1658.785, -1680.01, -1701.151, -1722.207, -1743.1760000000002, -1764.056, -1784.846, -1805.545, -1826.15, -1846.66, -1867.0739999999998, -1887.389, -1907.604, -1927.717, -1947.727, -1967.631, -1987.4279999999999, -2007.116, -2026.693, -2046.158, -2065.507, -2084.74, -2103.854, -2122.847, -2141.718, -2160.4629999999997, -2179.081, -2197.57, -2215.928, -2234.151, -2252.239, -2270.188, -2287.996, -2305.661, -2323.18, -2340.551, -2357.771, -2374.837, -2391.748, -2408.499, -2425.089, -2441.514, -2457.772, -2473.86, -2489.774, -2505.512, -2521.07, -2536.446, -2551.635, -2566.635, -2581.4429999999998, -2596.053, -2610.464, -2624.672, -2638.672, -2652.461, -2666.035, -2679.39, -2692.5209999999997, -2705.425, -2718.098, -2730.534, -2742.73, -2754.6809999999996, -2766.381, -2777.827, -2789.013, -2799.934, -2810.5840000000003, -2820.958, -2831.052, -2840.8579999999997, -2850.3720000000003, -2859.587, -2868.4959999999996, -2877.095, -2885.375, -2893.3309999999997, -2900.955, -2908.241, -2915.18, -2921.7659999999996, -2927.991, -2933.8459999999995, -2939.323, -2944.415, -2949.111, -2953.4040000000005, -2957.283, -2960.738, -2963.761, -2966.34, -2968.465, -2970.1240000000003, -2971.308, -2972.002, -2972.196, -2971.877, -2971.031, -2969.6459999999997, -2967.7059999999997, -2965.197, -2962.105, -2958.413, -2954.1059999999998, -2949.165, -2943.574, -2937.3140000000003, -2930.367, -2922.711, -2914.328, -2905.1940000000004, -2895.289, -2884.5890000000004, -2873.07, -2860.705, -2847.469, -2833.335, -2818.2729999999997, -2802.2540000000004, -2785.2459999999996, -2767.218, -2748.135, -2727.96, -2706.656, -2684.1859999999997, -2660.507, -2635.578, -2609.355, -2581.79, -2552.835, -2522.439, -2490.549, -2457.111, -2422.0660000000003, -2385.355, -2346.9139999999998, -2306.68, -2264.587, -2220.563, -2174.5370000000003, -2126.437, -2076.189, -2023.713, -1968.935, -1911.7779999999998, -1852.1629999999998, -1790.017, -1725.2679999999998, -1657.8470000000002, -1587.693, -1514.753, -1438.9820000000002, -1360.352, -1278.847, -1194.474, -1107.262, -1017.265, -924.568, -829.2919999999999, -731.5889999999999, -631.653, -529.7130000000001, -426.039, -320.931, -214.72299999999998, -107.773, -0.45399999999999996, 106.85, 213.757, 319.89599999999996, 424.911, 528.476, 630.2909999999999, 730.095, 827.663, 922.81, 1015.385, 1105.274, 1192.396, 1276.6989999999998, 1358.156, 1436.765, 1512.539, 1585.511, 1655.721, 1723.225, 1788.0839999999998, 1850.364, 1910.136, 1967.476, 2022.4560000000001, 2075.154, 2125.646, 2174.006, 2220.308, 2264.623, 2307.024, 2347.577, 2386.348, 2423.401, 2458.798, 2492.598, 2524.857, 2555.631, 2584.971, 2612.926, 2639.546, 2664.8759999999997, 2688.96, 2711.841, 2733.558, 2754.15, 2773.6540000000005, 2792.105, 2809.5370000000003, 2825.9840000000004, 2841.474, 2856.039, 2869.7059999999997, 2882.5040000000004, 2894.458, 2905.593, 2915.935, 2925.505, 2934.3259999999996, 2942.4190000000003, 2949.805, 2956.5029999999997, 2962.534, 2967.914, 2972.6609999999996, 2976.7929999999997, 2980.3259999999996, 2983.276, 2985.656, 2987.4829999999997, 2988.77, 2989.531, 2989.7790000000005, 2989.527, 2988.7859999999996, 2987.5690000000004, 2985.888, 2983.7529999999997, 2981.175, 2978.164, 2974.7309999999998, 2970.884, 2966.635, 2961.99, 2956.96, 2951.554, 2945.778, 2939.6420000000003, 2933.1540000000005, 2926.32, 2919.1479999999997, 2911.6459999999997, 2903.821, 2895.678, 2887.225, 2878.469, 2869.414, 2860.0690000000004, 2850.438, 2840.527, 2830.341, 2819.887, 2809.1690000000003, 2798.1929999999998, 2786.9640000000004, 2775.486, 2763.764, 2751.804, 2739.6090000000004, 2727.185, 2714.535, 2701.663, 2688.575, 2675.2729999999997, 2661.762, 2648.046, 2634.1290000000004, 2620.014, 2605.7039999999997, 2591.2039999999997, 2576.5170000000003, 2561.647, 2546.595, 2531.367, 2515.964, 2500.391, 2484.65, 2468.744, 2452.676, 2436.449, 2420.0660000000003, 2403.529, 2386.842, 2370.006, 2353.025, 2335.901, 2318.636, 2301.2329999999997, 2283.695, 2266.0229999999997, 2248.22, 2230.2889999999998, 2212.232, 2194.05, 2175.746, 2157.323, 2138.781, 2120.124, 2101.353, 2082.471, 2063.479, 2044.379, 2025.1729999999998, 2005.8629999999998, 1986.451, 1966.9379999999999, 1947.3270000000002, 1927.619, 1907.816, 1887.92, 1867.932, 1847.854, 1827.6870000000001, 1807.434, 1787.095, 1766.6729999999998, 1746.1689999999999, 1725.5839999999998, 1704.92, 1684.1779999999999, 1663.36, 1642.4679999999998, 1621.5020000000002, 1600.465, 1579.3570000000002, 1558.18, 1536.935, 1515.624, 1494.2479999999998, 1472.808, 1451.306, 1429.743, 1408.119, 1386.4370000000001, 1364.6979999999999, 1342.9029999999998, 1321.0529999999999, 1299.149, 1277.192, 1255.184, 1233.126, 1211.019, 1188.864, 1166.662, 1144.415, 1122.123, 1099.788, 1077.411, 1054.992, 1032.5339999999999, 1010.0360000000001, 987.5, 964.928, 942.319, 919.676, 896.9989999999999, 874.289, 851.548, 828.775, 805.9730000000001, 783.1419999999999, 760.284, 737.398, 714.487, 691.551, 668.592, 645.609, 622.605, 599.5790000000001, 576.534, 553.469, 530.387, 507.287, 484.171, 461.04, 437.894, 414.735, 391.56300000000005, 368.38, 345.186, 321.982, 298.77, 275.54900000000004, 252.322, 229.088, 205.84900000000002, 182.606, 159.359, 136.11, 112.859, 89.60799999999999, 66.35600000000001, 43.106, 19.858, -3.388, -26.629, -49.86600000000001, -73.097, -96.322, -119.54, -142.749, -165.949, -189.139, -212.31799999999998, -235.485, -258.64, -281.78, -304.906, -328.017, -351.11, -374.18699999999995, -397.245, -420.284, -443.30300000000005, -466.301, -489.277, -512.229, -535.158, -558.062, -580.94, -603.7919999999999, -626.615, -649.41, -672.175, -694.91, -717.613, -740.283, -762.919, -785.5210000000001, -808.0880000000001, -830.617, -853.1089999999999, -875.563, -897.9760000000001, -920.3489999999999, -942.68, -964.9680000000001, -987.212, -1009.4110000000001, -1031.5639999999999, -1053.67, -1075.7269999999999, -1097.735, -1119.692, -1141.598, -1163.451, -1185.249, -1206.993, -1228.68, -1250.31, -1271.881, -1293.392, -1314.8410000000001, -1336.229, -1357.5520000000001, -1378.8110000000001, -1400.004, -1421.129, -1442.185, -1463.17, -1484.085, -1504.9260000000002, -1525.693, -1546.385, -1566.999, -1587.535, -1607.991, -1628.366, -1648.6570000000002, -1668.865, -1688.986, -1709.02, -1728.964, -1748.818, -1768.58, -1788.247, -1807.819, -1827.2939999999999, -1846.67, -1865.945, -1885.1170000000002, -1904.185, -1923.1470000000002, -1942.001, -1960.745, -1979.3770000000002, -1997.895, -2016.2979999999998, -2034.582, -2052.7470000000003, -2070.79, -2088.709, -2106.501, -2124.165, -2141.699, -2159.099, -2176.364, -2193.492, -2210.479, -2227.324, -2244.024, -2260.576, -2276.978, -2293.2270000000003, -2309.321, -2325.256, -2341.03, -2356.64, -2372.0820000000003, -2387.355, -2402.455, -2417.3779999999997, -2432.1220000000003, -2446.683, -2461.058, -2475.244, -2489.236, -2503.032, -2516.6279999999997, -2530.019, -2543.203, -2556.175, -2568.931, -2581.467, -2593.779, -2605.862, -2617.7129999999997, -2629.3259999999996, -2640.697, -2651.821, -2662.6929999999998, -2673.308, -2683.6609999999996, -2693.7470000000003, -2703.56, -2713.094, -2722.344, -2731.304, -2739.967, -2748.328, -2756.38, -2764.116, -2771.53, -2778.615, -2785.362, -2791.7659999999996, -2797.817, -2803.509, -2808.833, -2813.78, -2818.342, -2822.51, -2826.275, -2829.627, -2832.5559999999996, -2835.051, -2837.103, -2838.7, -2839.8309999999997, -2840.4840000000004, -2840.647, -2840.308, -2839.453, -2838.07, -2836.143, -2833.658, -2830.6009999999997, -2826.9559999999997, -2822.705, -2817.833, -2812.322, -2806.153, -2799.308, -2791.7659999999996, -2783.507, -2774.511, -2764.7529999999997, -2754.212, -2742.862, -2730.679, -2717.635, -2703.703, -2688.855, -2673.0609999999997, -2656.289, -2638.505, -2619.676, -2599.766, -2578.738, -2556.551, -2533.167, -2508.54, -2482.627, -2455.38, -2426.751, -2396.689, -2365.14, -2332.049, -2297.3579999999997, -2261.007, -2222.9320000000002, -2183.069, -2141.3520000000003, -2097.7110000000002, -2052.074, -2004.369, -1954.523, -1902.4589999999998, -1848.1029999999998, -1791.381, -1732.217, -1670.5439999999999, -1606.2920000000001, -1539.401, -1469.818, -1397.497, -1322.4089999999999, -1244.536, -1163.881, -1080.469, -994.3480000000001, -905.597, -814.327, -720.68, -624.84, -527.0219999999999, -427.48199999999997, -326.506, -224.41299999999998, -121.544, -18.259, 85.075, 188.08900000000003, 290.425, 391.73900000000003, 491.713, 590.055, 686.513, 780.863, 872.922, 962.544, 1049.612, 1134.046, 1215.7910000000002, 1294.819, 1371.1229999999998, 1444.713, 1515.619, 1583.8770000000002, 1649.5379999999998, 1712.66, 1773.3029999999999, 1831.536, 1887.4289999999999, 1941.0529999999999, 1992.479, 2041.781, 2089.028, 2134.292, 2177.643, 2219.146, 2258.866, 2296.868, 2333.2129999999997, 2367.958, 2401.161, 2432.876, 2463.157, 2492.051, 2519.6079999999997, 2545.874, 2570.893, 2594.709, 2617.359, 2638.884, 2659.32, 2678.704, 2697.0690000000004, 2714.448, 2730.8720000000003, 2746.3709999999996, 2760.974, 2774.7070000000003, 2787.598, 2799.672, 2810.952, 2821.4629999999997, 2831.2259999999997, 2840.263, 2848.595, 2856.241, 2863.22, 2869.551, 2875.2509999999997, 2880.3379999999997, 2884.827, 2888.735, 2892.077, 2894.867, 2897.119, 2898.8459999999995, 2900.063, 2900.782, 2901.014, 2900.7729999999997, 2900.0679999999998, 2898.9120000000003, 2897.315, 2895.288, 2892.84, 2889.9809999999998, 2886.7209999999995, 2883.0679999999998, 2879.031, 2874.62, 2869.841, 2864.704, 2859.216, 2853.385, 2847.217, 2840.7209999999995, 2833.903, 2826.77, 2819.328, 2811.5840000000003, 2803.5440000000003, 2795.2129999999997, 2786.599, 2777.7059999999997, 2768.5409999999997, 2759.1079999999997, 2749.413, 2739.46, 2729.256, 2718.805, 2708.111, 2697.18, 2686.015, 2674.6209999999996, 2663.0029999999997, 2651.165, 2639.11, 2626.843, 2614.368, 2601.689, 2588.8089999999997, 2575.732, 2562.462, 2549.002, 2535.355, 2521.526, 2507.516, 2493.33, 2478.97, 2464.44, 2449.743, 2434.881, 2419.8579999999997, 2404.676, 2389.3379999999997, 2373.846, 2358.205, 2342.415, 2326.48, 2310.403, 2294.185, 2277.8289999999997, 2261.337, 2244.712, 2227.9570000000003, 2211.072, 2194.062, 2176.926, 2159.669, 2142.292, 2124.797, 2107.186, 2089.46, 2071.623, 2053.676, 2035.621, 2017.4589999999998, 1999.194, 1980.825, 1962.356, 1943.787, 1925.121, 1906.36, 1887.504, 1868.556, 1849.5179999999998, 1830.39, 1811.175, 1791.874, 1772.4879999999998, 1753.02, 1733.47, 1713.84, 1694.132, 1674.3470000000002, 1654.486, 1634.5510000000002, 1614.543, 1594.464, 1574.3139999999999, 1554.096, 1533.81, 1513.4579999999999, 1493.0420000000001, 1472.5610000000001, 1452.019, 1431.415, 1410.751, 1390.029, 1369.249, 1348.412, 1327.521, 1306.576, 1285.578, 1264.528, 1243.428, 1222.279, 1201.0810000000001, 1179.836, 1158.545, 1137.2089999999998, 1115.829, 1094.406, 1072.941, 1051.435, 1029.89, 1008.306, 986.684, 965.0260000000001, 943.332, 921.6030000000001, 899.84, 878.045, 856.2180000000001, 834.36, 812.472, 790.556, 768.612, 746.64, 724.643, 702.6210000000001, 680.574, 658.5039999999999, 636.4119999999999, 614.299, 592.165, 570.011, 547.839, 525.649, 503.44199999999995, 481.219, 458.98199999999997, 436.72900000000004, 414.464, 392.186, 369.897, 347.597, 325.28700000000003, 302.969, 280.642, 258.308, 235.968, 213.623, 191.273, 168.919, 146.562, 124.204, 101.844, 79.484, 57.125, 34.766999999999996, 12.411, -9.941, -32.289, -54.632, -76.97, -99.3, -121.62299999999999, -143.938, -166.24400000000003, -188.53900000000002, -210.82299999999998, -233.09599999999998, -255.355, -277.601, -299.832, -322.048, -344.24800000000005, -366.43, -388.594, -410.74, -432.865, -454.969, -477.05199999999996, -499.11199999999997, -521.149, -543.161, -565.1469999999999, -587.1080000000001, -609.0409999999999, -630.946, -652.821, -674.6669999999999, -696.4810000000001, -718.2639999999999, -740.013, -761.7280000000001, -783.409, -805.053, -826.6610000000001, -848.23, -869.7610000000001, -891.2510000000001, -912.701, -934.1080000000001, -955.4730000000001, -976.793, -998.068, -1019.296, -1040.4769999999999, -1061.61, -1082.693, -1103.725, -1124.7060000000001, -1145.633, -1166.507, -1187.325, -1208.086, -1228.79, -1249.435, -1270.02, -1290.5439999999999, -1311.005, -1331.402, -1351.735, -1372.001, -1392.1989999999998, -1412.328, -1432.3870000000002, -1452.375, -1472.289, -1492.129, -1511.8929999999998, -1531.58, -1551.1889999999999, -1570.717, -1590.164, -1609.527, -1628.806, -1647.999, -1667.104, -1686.119, -1705.0439999999999, -1723.876, -1742.614, -1761.256, -1779.8, -1798.245, -1816.588, -1834.829, -1852.964, -1870.993, -1888.914, -1906.724, -1924.421, -1942.004, -1959.471, -1976.819, -1994.046, -2011.151, -2028.13, -2044.9820000000002, -2061.705, -2078.2960000000003, -2094.7529999999997, -2111.074, -2127.255, -2143.2960000000003, -2159.192, -2174.9410000000003, -2190.541, -2205.99, -2221.283, -2236.419, -2251.395, -2266.208, -2280.854, -2295.331, -2309.635, -2323.763, -2337.7129999999997, -2351.481, -2365.062, -2378.455, -2391.654, -2404.657, -2417.46, -2430.0589999999997, -2442.45, -2454.629, -2466.591, -2478.334, -2489.851, -2501.139, -2512.1929999999998, -2523.009, -2533.5820000000003, -2543.907, -2553.978, -2563.79, -2573.339, -2582.618, -2591.621, -2600.344, -2608.78, -2616.923, -2624.7670000000003, -2632.304, -2639.5290000000005, -2646.435, -2653.013, -2659.258, -2665.16, -2670.7140000000004, -2675.909, -2680.739, -2685.1940000000004, -2689.2659999999996, -2692.946, -2696.224, -2699.0890000000004, -2701.533, -2703.5440000000003, -2705.112, -2706.225, -2706.8720000000003, -2707.0409999999997, -2706.72, -2705.8940000000002, -2704.552, -2702.678, -2700.26, -2697.281, -2693.725, -2689.578, -2684.821, -2679.437, -2673.409, -2666.717, -2659.341, -2651.261, -2642.455, -2632.902, -2622.577, -2611.4570000000003, -2599.515, -2586.7270000000003, -2573.063, -2558.495, -2542.993, -2526.525, -2509.0589999999997, -2490.5589999999997, -2470.99, -2450.315, -2428.492, -2405.484, -2381.244, -2355.728, -2328.889, -2300.678, -2271.045, -2239.9339999999997, -2207.291, -2173.0570000000002, -2137.172, -2099.573, -2060.194, -2018.971, -1975.8339999999998, -1930.711, -1883.531, -1834.223, -1782.711, -1728.9229999999998, -1672.789, -1614.2379999999998, -1553.205, -1489.629, -1423.4560000000001, -1354.642, -1283.155, -1208.974, -1132.1019999999999, -1052.555, -970.378, -885.643, -798.451, -708.937, -617.27, -523.654, -428.33099999999996, -331.574, -233.68200000000002, -134.984, -35.821, 63.452, 162.483, 260.925, 358.44699999999995, 454.74, 549.521, 642.5419999999999, 733.587, 822.475, 909.06, 993.2280000000001, 1074.896, 1154.007, 1230.5330000000001, 1304.461, 1375.8020000000001, 1444.576, 1510.819, 1574.578, 1635.904, 1694.8570000000002, 1751.499, 1805.895, 1858.1129999999998, 1908.223, 1956.29, 2002.384, 2046.5720000000001, 2088.919, 2129.488, 2168.342, 2205.5429999999997, 2241.105, 2275.2110000000002, 2307.7889999999998, 2338.9339999999997, 2368.695, 2397.121, 2424.257, 2450.1479999999997, 2474.8360000000002, 2498.362, 2520.764, 2542.08, 2562.345, 2581.594, 2599.859, 2617.1710000000003, 2633.5609999999997, 2649.0570000000002, 2663.687, 2677.4759999999997, 2690.4509999999996, 2702.636, 2714.053, 2724.7270000000003, 2734.677, 2743.925, 2752.49, 2760.3909999999996, 2767.647, 2774.275, 2780.2929999999997, 2785.717, 2790.562, 2794.843, 2798.5759999999996, 2801.775, 2804.453, 2806.6220000000003, 2808.296, 2809.487, 2810.2059999999997, 2810.466, 2810.277, 2809.65, 2808.595, 2807.1220000000003, 2805.241, 2802.961, 2800.2909999999997, 2797.241, 2793.8179999999998, 2790.03, 2785.886, 2781.3940000000002, 2776.56, 2771.393, 2765.9, 2760.087, 2753.96, 2747.528, 2740.795, 2733.768, 2726.453, 2718.8559999999998, 2710.9829999999997, 2702.8379999999997, 2694.428, 2685.757, 2676.8309999999997, 2667.655, 2658.2329999999997, 2648.571, 2638.672, 2628.542, 2618.1839999999997, 2607.603, 2596.803, 2585.7889999999998, 2574.563, 2563.131, 2551.495, 2539.66, 2527.629, 2515.405, 2502.993, 2490.395, 2477.615, 2464.657, 2451.522, 2438.215, 2424.738, 2411.094, 2397.2870000000003, 2383.319, 2369.1929999999998, 2354.911, 2340.4770000000003, 2325.893, 2311.161, 2296.285, 2281.266, 2266.106, 2250.81, 2235.3779999999997, 2219.813, 2204.118, 2188.294, 2172.343, 2156.269, 2140.073, 2123.756, 2107.322, 2090.771, 2074.107, 2057.33, 2040.443, 2023.4479999999999, 2006.3470000000002, 1989.141, 1971.8310000000001, 1954.421, 1936.911, 1919.3039999999999, 1901.6, 1883.8029999999999, 1865.912, 1847.93, 1829.858, 1811.6989999999998, 1793.453, 1775.122, 1756.707, 1738.21, 1719.6329999999998, 1700.976, 1682.241, 1663.431, 1644.545, 1625.585, 1606.5529999999999, 1587.45, 1568.277, 1549.036, 1529.727, 1510.3529999999998, 1490.914, 1471.412, 1451.8470000000002, 1432.221, 1412.535, 1392.7910000000002, 1372.989, 1353.131, 1333.217, 1313.249, 1293.229, 1273.156, 1253.0330000000001, 1232.859, 1212.638, 1192.368, 1172.052, 1151.691, 1131.285, 1110.835, 1090.343, 1069.81, 1049.236, 1028.623, 1007.971, 987.2819999999999, 966.556, 945.794, 924.998, 904.169, 883.306, 862.4119999999999, 841.487, 820.5319999999999, 799.548, 778.5360000000001, 757.4960000000001, 736.43, 715.3389999999999, 694.2230000000001, 673.084, 651.922, 630.738, 609.533, 588.307, 567.063, 545.8, 524.519, 503.222, 481.909, 460.58099999999996, 439.23900000000003, 417.884, 396.51599999999996, 375.13599999999997, 353.746, 332.345, 310.936, 289.518, 268.093, 246.66099999999997, 225.22400000000002, 203.78099999999998, 182.335, 160.885, 139.433, 117.979, 96.524, 75.069, 53.615, 32.163000000000004, 10.713, -10.732999999999999, -32.175, -53.611999999999995, -75.044, -96.469, -117.88600000000001, -139.295, -160.694, -182.084, -203.463, -224.83, -246.185, -267.526, -288.853, -310.165, -331.461, -352.74, -374.001, -395.244, -416.468, -437.671, -458.853, -480.01300000000003, -501.15, -522.263, -543.351, -564.414, -585.45, -606.4580000000001, -627.439, -648.389, -669.31, -690.199, -711.057, -731.8810000000001, -752.671, -773.426, -794.145, -814.827, -835.471, -856.076, -876.6419999999999, -897.166, -917.648, -938.087, -958.482, -978.832, -999.135, -1019.3919999999999, -1039.6, -1059.758, -1079.866, -1099.922, -1119.9260000000002, -1139.875, -1159.769, -1179.607, -1199.388, -1219.11, -1238.772, -1258.373, -1277.912, -1297.387, -1316.797, -1336.141, -1355.418, -1374.626, -1393.763, -1412.83, -1431.8229999999999, -1450.743, -1469.586, -1488.3529999999998, -1507.0410000000002, -1525.65, -1544.1760000000002, -1562.62, -1580.98, -1599.253, -1617.4379999999999, -1635.535, -1653.54, -1671.453, -1689.2720000000002, -1706.994, -1724.619, -1742.145, -1759.569, -1776.89, -1794.106, -1811.215, -1828.2160000000001, -1845.106, -1861.882, -1878.545, -1895.09, -1911.516, -1927.8210000000001, -1944.003, -1960.059, -1975.987, -1991.785, -2007.451, -2022.9820000000002, -2038.375, -2053.629, -2068.74, -2083.705, -2098.5229999999997, -2113.1910000000003, -2127.705, -2142.063, -2156.261, -2170.298, -2184.17, -2197.873, -2211.405, -2224.762, -2237.942, -2250.939, -2263.752, -2276.377, -2288.8089999999997, -2301.0460000000003, -2313.0820000000003, -2324.915, -2336.541, -2347.9539999999997, -2359.152, -2370.129, -2380.881, -2391.403, -2401.692, -2411.741, -2421.5460000000003, -2431.1020000000003, -2440.404, -2449.446, -2458.223, -2466.729, -2474.958, -2482.903, -2490.56, -2497.9210000000003, -2504.98, -2511.729, -2518.163, -2524.274, -2530.054, -2535.495, -2540.59, -2545.331, -2549.708, -2553.714, -2557.339, -2560.574, -2563.41, -2565.835, -2567.84, -2569.415, -2570.547, -2571.226, -2571.439, -2571.174, -2570.419, -2569.16, -2567.384, -2565.075, -2562.22, -2558.802, -2554.805, -2550.2129999999997, -2545.008, -2539.173, -2532.687, -2525.533, -2517.688, -2509.132, -2499.843, -2489.797, -2478.969, -2467.335, -2454.868, -2441.54, -2427.323, -2412.187, -2396.099, -2379.026, -2360.9339999999997, -2341.788, -2321.548, -2300.177, -2277.631, -2253.868, -2228.843, -2202.509, -2174.8160000000003, -2145.712, -2115.144, -2083.056, -2049.391, -2014.086, -1977.08, -1938.31, -1897.7060000000001, -1855.2020000000002, -1810.73, -1764.215, -1715.59, -1664.783, -1611.7220000000002, -1556.342, -1498.5770000000002, -1438.3670000000002, -1375.6589999999999, -1310.407, -1242.578, -1172.151, -1099.122, -1023.507, -945.342, -864.694, -781.653, -696.346, -608.931, -519.599, -428.575, -336.119, -242.517, -148.077, -53.126999999999995, 41.996, 136.952, 231.408, 325.046, 417.56699999999995, 508.69699999999995, 598.194, 685.847, 771.4780000000001, 854.943, 936.13, 1014.953, 1091.356, 1165.305, 1236.787, 1305.809, 1372.386, 1436.5520000000001, 1498.348, 1557.8220000000001, 1615.0279999999998, 1670.025, 1722.874, 1773.64, 1822.385, 1869.174, 1914.0729999999999, 1957.1429999999998, 1998.4479999999999, 2038.0479999999998, 2076.002, 2112.367, 2147.199, 2180.552, 2212.4770000000003, 2243.024, 2272.241, 2300.173, 2326.866, 2352.36, 2376.696, 2399.913, 2422.049, 2443.139, 2463.217, 2482.315, 2500.465, 2517.697, 2534.04, 2549.521, 2564.167, 2578.0029999999997, 2591.052, 2603.339, 2614.886, 2625.715, 2635.845, 2645.298, 2654.091, 2662.243, 2669.772, 2676.6940000000004, 2683.026, 2688.784, 2693.9829999999997, 2698.637, 2702.761, 2706.368, 2709.4709999999995, 2712.0820000000003, 2714.2140000000004, 2715.8790000000004, 2717.087, 2717.85, 2718.179, 2718.083, 2717.574, 2716.659, 2715.349, 2713.652, 2711.578, 2709.135, 2706.3309999999997, 2703.173, 2699.67, 2695.829, 2691.657, 2687.1609999999996, 2682.349, 2677.2259999999997, 2671.8, 2666.075, 2660.06, 2653.759, 2647.178, 2640.323, 2633.2, 2625.813, 2618.1679999999997, 2610.27, 2602.123, 2593.7329999999997, 2585.105, 2576.242, 2567.15, 2557.831, 2548.292, 2538.535, 2528.565, 2518.386, 2508.002, 2497.416, 2486.632, 2475.653, 2464.4829999999997, 2453.126, 2441.585, 2429.863, 2417.9629999999997, 2405.889, 2393.643, 2381.228, 2368.6479999999997, 2355.905, 2343.002, 2329.942, 2316.7270000000003, 2303.361, 2289.845, 2276.183, 2262.376, 2248.427, 2234.339, 2220.114, 2205.755, 2191.262, 2176.64, 2161.889, 2147.013, 2132.013, 2116.89, 2101.6479999999997, 2086.2889999999998, 2070.813, 2055.224, 2039.5220000000002, 2023.711, 2007.7910000000002, 1991.764, 1975.6329999999998, 1959.399, 1943.0629999999999, 1926.628, 1910.095, 1893.4660000000001, 1876.7420000000002, 1859.925, 1843.017, 1826.0179999999998, 1808.931, 1791.757, 1774.497, 1757.154, 1739.727, 1722.22, 1704.6329999999998, 1686.967, 1669.224, 1651.405, 1633.5120000000002, 1615.546, 1597.5079999999998, 1579.4, 1561.2220000000002, 1542.976, 1524.6629999999998, 1506.2839999999999, 1487.842, 1469.335, 1450.767, 1432.138, 1413.4489999999998, 1394.701, 1375.896, 1357.0339999999999, 1338.1170000000002, 1319.145, 1300.121, 1281.0439999999999, 1261.9160000000002, 1242.738, 1223.511, 1204.236, 1184.914, 1165.546, 1146.133, 1126.6760000000002, 1107.1760000000002, 1087.634, 1068.05, 1048.427, 1028.764, 1009.063, 989.325, 969.55, 949.74, 929.895, 910.0160000000001, 890.105, 870.1610000000001, 850.187, 830.182, 810.148, 790.086, 769.9960000000001, 749.88, 729.737, 709.57, 689.378, 669.164, 648.9259999999999, 628.6669999999999, 608.388, 588.0880000000001, 567.769, 547.432, 527.077, 506.70599999999996, 486.31800000000004, 465.916, 445.499, 425.069, 404.62699999999995, 384.17199999999997, 363.707, 343.231, 322.745, 302.251, 281.749, 261.24, 240.725, 220.204, 199.679, 179.15, 158.61700000000002, 138.082, 117.546, 97.009, 76.472, 55.93600000000001, 35.400999999999996, 14.869000000000002, -5.66, -26.185, -46.705, -67.219, -87.727, -108.228, -128.721, -149.205, -169.68, -190.144, -210.59599999999998, -231.037, -251.465, -271.879, -292.278, -312.663, -333.031, -353.38199999999995, -373.715, -394.029, -414.324, -434.599, -454.852, -475.083, -495.291, -515.475, -535.635, -555.769, -575.876, -595.956, -616.008, -636.031, -656.023, -675.985, -695.914, -715.811, -735.674, -755.502, -775.294, -795.05, -814.768, -834.447, -854.086, -873.685, -893.243, -912.758, -932.2289999999999, -951.655, -971.035, -990.3689999999999, -1009.655, -1028.891, -1048.078, -1067.213, -1086.296, -1105.326, -1124.3010000000002, -1143.22, -1162.083, -1180.887, -1199.632, -1218.316, -1236.938, -1255.498, -1273.993, -1292.423, -1310.785, -1329.08, -1347.305, -1365.4589999999998, -1383.5410000000002, -1401.549, -1419.4820000000002, -1437.339, -1455.1170000000002, -1472.816, -1490.435, -1507.97, -1525.422, -1542.7879999999998, -1560.067, -1577.257, -1594.3570000000002, -1611.364, -1628.2779999999998, -1645.096, -1661.816, -1678.4379999999999, -1694.9579999999999, -1711.376, -1727.6889999999999, -1743.895, -1759.9920000000002, -1775.979, -1791.8529999999998, -1807.612, -1823.255, -1838.7779999999998, -1854.181, -1869.4589999999998, -1884.612, -1899.6370000000002, -1914.5320000000002, -1929.293, -1943.9189999999999, -1958.4070000000002, -1972.754, -1986.9589999999998, -2001.017, -2014.9260000000002, -2028.684, -2042.2879999999998, -2055.735, -2069.021, -2082.143, -2095.099, -2107.885, -2120.498, -2132.935, -2145.1910000000003, -2157.264, -2169.15, -2180.844, -2192.344, -2203.646, -2214.744, -2225.636, -2236.3160000000003, -2246.781, -2257.026, -2267.047, -2276.8379999999997, -2286.395, -2295.7129999999997, -2304.7870000000003, -2313.612, -2322.1820000000002, -2330.491, -2338.533, -2346.304, -2353.7960000000003, -2361.004, -2367.9210000000003, -2374.541, -2380.855, -2386.859, -2392.5429999999997, -2397.901, -2402.924, -2407.606, -2411.936, -2415.908, -2419.511, -2422.738, -2425.577, -2428.02, -2430.056, -2431.674, -2432.864, -2433.614, -2433.913, -2433.748, -2433.106, -2431.976, -2430.341, -2428.19, -2425.507, -2422.276, -2418.482, -2414.107, -2409.135, -2403.548, -2397.327, -2390.452, -2382.903, -2374.659, -2365.697, -2355.995, -2345.528, -2334.27, -2322.196, -2309.278, -2295.487, -2280.7929999999997, -2265.1639999999998, -2248.567, -2230.967, -2212.3289999999997, -2192.614, -2171.785, -2149.797, -2126.6079999999997, -2102.173, -2076.445, -2049.375, -2020.91, -1990.997, -1959.579, -1926.601, -1892.0, -1855.715, -1817.681, -1777.8339999999998, -1736.104, -1692.425, -1646.7279999999998, -1598.943, -1549.0020000000002, -1496.84, -1442.391, -1385.599, -1326.408, -1264.774, -1200.661, -1134.047, -1064.925, -993.305, -919.221, -842.7280000000001, -763.9119999999999, -682.8889999999999, -599.802, -514.8330000000001, -428.19300000000004, -340.12300000000005, -250.895, -160.80200000000002, -70.154, 20.726, 111.516, 201.895, 291.557, 380.215, 467.603, 553.487, 637.66, 719.948, 800.211, 878.3330000000001, 954.2330000000001, 1027.85, 1099.149, 1168.115, 1234.747, 1299.062, 1361.0870000000002, 1420.859, 1478.422, 1533.825, 1587.124, 1638.376, 1687.638, 1734.9720000000002, 1780.44, 1824.1, 1866.0120000000002, 1906.236, 1944.83, 1981.8470000000002, 2017.3429999999998, 2051.3720000000003, 2083.984, 2115.2270000000003, 2145.149, 2173.795, 2201.21, 2227.435, 2252.51, 2276.473, 2299.362, 2321.2129999999997, 2342.0589999999997, 2361.9320000000002, 2380.864, 2398.885, 2416.0229999999997, 2432.306, 2447.761, 2462.411, 2476.282, 2489.397, 2501.778, 2513.446, 2524.422, 2534.726, 2544.377, 2553.3920000000003, 2561.79, 2569.5879999999997, 2576.8, 2583.444, 2589.534, 2595.084, 2600.109, 2604.6220000000003, 2608.637, 2612.165, 2615.218, 2617.81, 2619.949, 2621.6479999999997, 2622.917, 2623.7659999999996, 2624.205, 2624.243, 2623.8909999999996, 2623.156, 2622.047, 2620.573, 2618.742, 2616.561, 2614.0389999999998, 2611.183, 2607.999, 2604.495, 2600.678, 2596.554, 2592.129, 2587.409, 2582.402, 2577.112, 2571.545, 2565.7070000000003, 2559.604, 2553.239, 2546.619, 2539.749, 2532.633, 2525.276, 2517.683, 2509.8579999999997, 2501.805, 2493.529, 2485.034, 2476.325, 2467.404, 2458.276, 2448.944, 2439.413, 2429.685, 2419.765, 2409.655, 2399.36, 2388.882, 2378.225, 2367.3920000000003, 2356.385, 2345.208, 2333.864, 2322.356, 2310.686, 2298.8579999999997, 2286.873, 2274.736, 2262.447, 2250.01, 2237.427, 2224.701, 2211.834, 2198.8289999999997, 2185.687, 2172.411, 2159.0029999999997, 2145.466, 2131.801, 2118.011, 2104.097, 2090.063, 2075.909, 2061.637, 2047.25, 2032.75, 2018.138, 2003.415, 1988.585, 1973.649, 1958.608, 1943.464, 1928.2179999999998, 1912.874, 1897.431, 1881.892, 1866.257, 1850.53, 1834.711, 1818.8020000000001, 1802.8039999999999, 1786.719, 1770.5479999999998, 1754.2920000000001, 1737.954, 1721.5339999999999, 1705.033, 1688.454, 1671.797, 1655.0629999999999, 1638.255, 1621.3729999999998, 1604.418, 1587.392, 1570.296, 1553.131, 1535.899, 1518.6, 1501.236, 1483.807, 1466.316, 1448.7620000000002, 1431.148, 1413.474, 1395.741, 1377.951, 1360.105, 1342.203, 1324.246, 1306.236, 1288.174, 1270.0610000000001, 1251.897, 1233.684, 1215.422, 1197.113, 1178.757, 1160.356, 1141.911, 1123.422, 1104.89, 1086.316, 1067.702, 1049.047, 1030.354, 1011.622, 992.8530000000001, 974.047, 955.206, 936.331, 917.421, 898.4789999999999, 879.505, 860.4989999999999, 841.462, 822.3969999999999, 803.302, 784.179, 765.03, 745.8539999999999, 726.6519999999999, 707.426, 688.176, 668.903, 649.607, 630.29, 610.952, 591.594, 572.217, 552.822, 533.409, 513.979, 494.533, 475.07199999999995, 455.596, 436.10699999999997, 416.60400000000004, 397.09, 377.56300000000005, 358.027, 338.48, 318.923, 299.35900000000004, 279.78700000000003, 260.207, 240.622, 221.03099999999998, 201.435, 181.83599999999998, 162.233, 142.628, 123.021, 103.413, 83.806, 64.19800000000001, 44.592, 24.989, 5.388, -14.21, -33.803000000000004, -53.39, -72.972, -92.54700000000001, -112.115, -131.675, -151.225, -170.766, -190.296, -209.815, -229.322, -248.81599999999997, -268.296, -287.762, -307.212, -326.64599999999996, -346.064, -365.463, -384.844, -404.20599999999996, -423.548, -442.86800000000005, -462.167, -481.44300000000004, -500.69599999999997, -519.924, -539.127, -558.303, -577.453, -596.575, -615.668, -634.732, -653.765, -672.7660000000001, -691.7360000000001, -710.672, -729.573, -748.44, -767.2710000000001, -786.064, -804.82, -823.5360000000001, -842.2130000000001, -860.8489999999999, -879.443, -897.993, -916.5, -934.962, -953.378, -971.7460000000001, -990.067, -1008.3380000000001, -1026.559, -1044.728, -1062.845, -1080.9080000000001, -1098.9160000000002, -1116.868, -1134.763, -1152.599, -1170.376, -1188.0910000000001, -1205.745, -1223.335, -1240.861, -1258.3210000000001, -1275.713, -1293.037, -1310.2910000000002, -1327.473, -1344.5829999999999, -1361.619, -1378.579, -1395.4620000000002, -1412.266, -1428.99, -1445.6329999999998, -1462.193, -1478.668, -1495.056, -1511.3570000000002, -1527.568, -1543.6870000000001, -1559.713, -1575.645, -1591.48, -1607.217, -1622.8529999999998, -1638.3870000000002, -1653.817, -1669.14, -1684.356, -1699.4620000000002, -1714.455, -1729.3339999999998, -1744.0970000000002, -1758.741, -1773.264, -1787.6629999999998, -1801.9370000000001, -1816.0839999999998, -1830.099, -1843.9820000000002, -1857.73, -1871.339, -1884.808, -1898.1329999999998, -1911.3110000000001, -1924.3410000000001, -1937.2179999999998, -1949.941, -1962.505, -1974.908, -1987.1470000000002, -1999.2179999999998, -2011.118, -2022.844, -2034.391, -2045.757, -2056.937, -2067.928, -2078.7270000000003, -2089.327, -2099.7270000000003, -2109.922, -2119.906, -2129.676, -2139.228, -2148.555, -2157.655, -2166.521, -2175.1479999999997, -2183.532, -2191.667, -2199.547, -2207.166, -2214.519, -2221.599, -2228.4, -2234.915, -2241.138, -2247.063, -2252.68, -2257.985, -2262.968, -2267.6220000000003, -2271.938, -2275.909, -2279.525, -2282.779, -2285.659, -2288.157, -2290.262, -2291.964, -2293.2529999999997, -2294.117, -2294.544, -2294.5229999999997, -2294.041, -2293.0860000000002, -2291.643, -2289.698, -2287.239, -2284.248, -2280.71, -2276.609, -2271.927, -2266.647, -2260.75, -2254.217, -2247.028, -2239.1620000000003, -2230.596, -2221.3070000000002, -2211.271, -2200.464, -2188.8579999999997, -2176.427, -2163.1420000000003, -2148.973, -2133.888, -2117.853, -2100.835, -2082.797, -2063.703, -2043.5120000000002, -2022.182, -1999.671, -1975.933, -1950.921, -1924.586, -1896.875, -1867.736, -1837.115, -1804.95, -1771.184, -1735.754, -1698.599, -1659.652, -1618.848, -1576.119, -1531.399, -1484.6229999999998, -1435.724, -1384.641, -1331.317, -1275.6960000000001, -1217.735, -1157.396, -1094.654, -1029.501, -961.941, -892.003, -819.7360000000001, -745.2180000000001, -668.551, -589.871, -509.345, -427.16900000000004, -343.57, -258.80400000000003, -173.146, -86.891, -0.34299999999999997, 86.18799999999999, 172.399, 257.994, 342.69699999999995, 426.25300000000004, 508.43300000000005, 589.039, 667.8989999999999, 744.873, 819.8510000000001, 892.747, 963.5010000000001, 1032.076, 1098.451, 1162.627, 1224.613, 1284.432, 1342.119, 1397.711, 1451.257, 1502.8029999999999, 1552.404, 1600.115, 1645.9920000000002, 1690.0910000000001, 1732.47, 1773.184, 1812.2879999999998, 1849.836, 1885.8829999999998, 1920.477, 1953.7320000000002, 1985.5079999999998, 2016.0410000000002, 2045.31, 2073.36, 2100.231, 2125.964, 2150.598, 2174.1679999999997, 2196.709, 2218.255, 2238.8379999999997, 2258.491, 2277.241, 2295.117, 2312.147, 2328.357, 2343.772, 2358.416, 2372.312, 2385.482, 2397.947, 2409.728, 2420.844, 2431.315, 2441.157, 2450.389, 2459.028, 2467.089, 2474.5879999999997, 2481.54, 2487.959, 2493.8579999999997, 2499.2529999999997, 2504.154, 2508.575, 2512.528, 2516.024, 2519.074, 2521.69, 2523.881, 2525.657, 2527.028, 2528.005, 2528.595, 2528.8070000000002, 2528.651, 2528.134, 2527.265, 2526.051, 2524.5, 2522.618, 2520.4139999999998, 2517.894, 2515.064, 2511.9320000000002, 2508.5029999999997, 2504.783, 2500.779, 2496.495, 2491.939, 2487.115, 2482.028, 2476.6839999999997, 2471.0879999999997, 2465.245, 2459.158, 2452.834, 2446.277, 2439.49, 2432.479, 2425.2470000000003, 2417.799, 2410.139, 2402.269, 2394.195, 2385.92, 2377.448, 2368.781, 2359.924, 2350.88, 2341.652, 2332.243, 2322.657, 2312.897, 2302.965, 2292.865, 2282.599, 2272.1710000000003, 2261.5820000000003, 2250.837, 2239.937, 2228.885, 2217.683, 2206.334, 2194.841, 2183.206, 2171.431, 2159.518, 2147.471, 2135.29, 2122.978, 2110.538, 2097.971, 2085.279, 2072.465, 2059.53, 2046.477, 2033.307, 2020.0220000000002, 2006.6229999999998, 1993.114, 1979.495, 1965.769, 1951.9360000000001, 1938.0, 1923.96, 1909.82, 1895.58, 1881.243, 1866.809, 1852.28, 1837.658, 1822.944, 1808.141, 1793.2479999999998, 1778.2679999999998, 1763.2020000000002, 1748.0510000000002, 1732.817, 1717.501, 1702.105, 1686.629, 1671.075, 1655.445, 1639.7379999999998, 1623.9579999999999, 1608.105, 1592.18, 1576.184, 1560.118, 1543.985, 1527.7839999999999, 1511.517, 1495.185, 1478.789, 1462.3310000000001, 1445.8110000000001, 1429.23, 1412.59, 1395.891, 1379.135, 1362.3220000000001, 1345.453, 1328.53, 1311.5539999999999, 1294.525, 1277.445, 1260.3139999999999, 1243.133, 1225.904, 1208.627, 1191.302, 1173.932, 1156.517, 1139.058, 1121.555, 1104.01, 1086.424, 1068.797, 1051.13, 1033.424, 1015.68, 997.898, 980.081, 962.227, 944.3389999999999, 926.4169999999999, 908.462, 890.4739999999999, 872.455, 854.405, 836.324, 818.215, 800.078, 781.9119999999999, 763.72, 745.502, 727.258, 708.99, 690.698, 672.383, 654.045, 635.686, 617.306, 598.9069999999999, 580.487, 562.049, 543.594, 525.121, 506.631, 488.126, 469.606, 451.07199999999995, 432.524, 413.964, 395.39099999999996, 376.80699999999996, 358.212, 339.608, 320.994, 302.372, 283.742, 265.105, 246.46099999999998, 227.812, 209.158, 190.5, 171.838, 153.174, 134.507, 115.84, 97.171, 78.503, 59.835, 41.169, 22.506, 3.845, -14.812000000000001, -33.465, -52.111999999999995, -70.75399999999999, -89.389, -108.016, -126.635, -145.246, -163.847, -182.437, -201.017, -219.584, -238.139, -256.681, -275.20799999999997, -293.721, -312.218, -330.69800000000004, -349.161, -367.606, -386.032, -404.439, -422.825, -441.19, -459.532, -477.852, -496.149, -514.42, -532.6659999999999, -550.886, -569.0790000000001, -587.244, -605.381, -623.487, -641.563, -659.6080000000001, -677.62, -695.5989999999999, -713.543, -731.453, -749.326, -767.163, -784.962, -802.721, -820.441, -838.12, -855.757, -873.3510000000001, -890.9019999999999, -908.4069999999999, -925.867, -943.279, -960.6439999999999, -977.959, -995.2239999999999, -1012.438, -1029.599, -1046.7060000000001, -1063.759, -1080.756, -1097.695, -1114.576, -1131.3980000000001, -1148.1589999999999, -1164.858, -1181.493, -1198.0639999999999, -1214.569, -1231.007, -1247.376, -1263.675, -1279.902, -1296.057, -1312.138, -1328.142, -1344.07, -1359.9189999999999, -1375.6870000000001, -1391.374, -1406.9779999999998, -1422.496, -1437.9270000000001, -1453.271, -1468.524, -1483.685, -1498.7520000000002, -1513.725, -1528.6, -1543.375, -1558.05, -1572.622, -1587.088, -1601.4479999999999, -1615.6979999999999, -1629.838, -1643.864, -1657.774, -1671.566, -1685.239, -1698.7879999999998, -1712.213, -1725.511, -1738.6779999999999, -1751.714, -1764.614, -1777.376, -1789.9979999999998, -1802.476, -1814.809, -1826.9920000000002, -1839.023, -1850.899, -1862.6170000000002, -1874.1729999999998, -1885.5639999999999, -1896.786, -1907.8370000000002, -1918.7120000000002, -1929.4089999999999, -1939.922, -1950.249, -1960.384, -1970.325, -1980.067, -1989.606, -1998.9370000000001, -2008.055, -2016.957, -2025.636, -2034.089, -2042.31, -2050.2929999999997, -2058.034, -2065.527, -2072.765, -2079.744, -2086.456, -2092.896, -2099.056, -2104.931, -2110.514, -2115.7960000000003, -2120.771, -2125.431, -2129.768, -2133.774, -2137.44, -2140.757, -2143.717, -2146.31, -2148.526, -2150.354, -2151.785, -2152.8070000000002, -2153.409, -2153.58, -2153.306, -2152.576, -2151.375, -2149.6910000000003, -2147.508, -2144.813, -2141.589, -2137.82, -2133.489, -2128.5789999999997, -2123.071, -2116.946, -2110.1839999999997, -2102.765, -2094.666, -2085.865, -2076.337, -2066.0570000000002, -2055.001, -2043.139, -2030.445, -2016.888, -2002.4360000000001, -1987.056, -1970.715, -1953.376, -1935.0020000000002, -1915.5539999999999, -1894.989, -1873.265, -1850.3370000000002, -1826.158, -1800.6779999999999, -1773.8470000000002, -1745.61, -1715.914, -1684.7, -1651.9089999999999, -1617.481, -1581.354, -1543.4620000000002, -1503.743, -1462.132, -1418.5629999999999, -1372.974, -1325.305, -1275.498, -1223.5, -1169.265, -1112.756, -1053.9460000000001, -992.822, -929.387, -863.6619999999999, -795.69, -725.539, -653.304, -579.1080000000001, -503.10400000000004, -425.474, -346.43, -266.211, -185.077, -103.303, -21.179000000000002, 61.001999999999995, 142.951, 224.387, 305.04400000000004, 384.676, 463.064, 540.012, 615.357, 688.959, 760.7080000000001, 830.52, 898.3330000000001, 964.107, 1027.8210000000001, 1089.468, 1149.057, 1206.607, 1262.145, 1315.7079999999999, 1367.336, 1417.0739999999998, 1464.973, 1511.082, 1555.453, 1598.138, 1639.192, 1678.664, 1716.608, 1753.075, 1788.1129999999998, 1821.77, 1854.094, 1885.129, 1914.92, 1943.5079999999998, 1970.934, 1997.237, 2022.455, 2046.6229999999998, 2069.777, 2091.949, 2113.1710000000003, 2133.474, 2152.888, 2171.439, 2189.155, 2206.063, 2222.186, 2237.548, 2252.174, 2266.083, 2279.298, 2291.8379999999997, 2303.722, 2314.97, 2325.599, 2335.627, 2345.07, 2353.9429999999998, 2362.263, 2370.044, 2377.3, 2384.045, 2390.291, 2396.052, 2401.34, 2406.167, 2410.544, 2414.482, 2417.992, 2421.084, 2423.768, 2426.053, 2427.949, 2429.465, 2430.609, 2431.39, 2431.8160000000003, 2431.895, 2431.635, 2431.042, 2430.125, 2428.889, 2427.343, 2425.492, 2423.342, 2420.901, 2418.174, 2415.166, 2411.884, 2408.333, 2404.518, 2400.444, 2396.117, 2391.541, 2386.722, 2381.6639999999998, 2376.371, 2370.849, 2365.1, 2359.13, 2352.9429999999998, 2346.542, 2339.9320000000002, 2333.116, 2326.099, 2318.883, 2311.472, 2303.87, 2296.08, 2288.105, 2279.95, 2271.615, 2263.106, 2254.424, 2245.573, 2236.556, 2227.375, 2218.033, 2208.534, 2198.879, 2189.071, 2179.113, 2169.007, 2158.755, 2148.361, 2137.826, 2127.153, 2116.343, 2105.4, 2094.324, 2083.119, 2071.7870000000003, 2060.3289999999997, 2048.7470000000003, 2037.0439999999999, 2025.221, 2013.28, 2001.224, 1989.0529999999999, 1976.77, 1964.3770000000002, 1951.875, 1939.265, 1926.55, 1913.7320000000002, 1900.8110000000001, 1887.79, 1874.6689999999999, 1861.4520000000002, 1848.138, 1834.73, 1821.2279999999998, 1807.636, 1793.953, 1780.181, 1766.3220000000001, 1752.3770000000002, 1738.348, 1724.235, 1710.04, 1695.764, 1681.4089999999999, 1666.975, 1652.464, 1637.878, 1623.217, 1608.483, 1593.6760000000002, 1578.7979999999998, 1563.85, 1548.8339999999998, 1533.749, 1518.598, 1503.382, 1488.1, 1472.756, 1457.349, 1441.88, 1426.351, 1410.763, 1395.116, 1379.412, 1363.651, 1347.835, 1331.965, 1316.0410000000002, 1300.0639999999999, 1284.035, 1267.9560000000001, 1251.827, 1235.6480000000001, 1219.422, 1203.1480000000001, 1186.828, 1170.462, 1154.052, 1137.597, 1121.1, 1104.5610000000001, 1087.98, 1071.359, 1054.697, 1037.997, 1021.2589999999999, 1004.4839999999999, 987.672, 970.824, 953.942, 937.025, 920.074, 903.091, 886.076, 869.03, 851.953, 834.847, 817.712, 800.548, 783.357, 766.1389999999999, 748.8960000000001, 731.6260000000001, 714.3330000000001, 697.015, 679.674, 662.311, 644.9259999999999, 627.52, 610.0930000000001, 592.6469999999999, 575.181, 557.698, 540.197, 522.679, 505.144, 487.594, 470.029, 452.45, 434.858, 417.25300000000004, 399.635, 382.006, 364.36699999999996, 346.717, 329.05699999999996, 311.389, 293.71299999999997, 276.03, 258.339, 240.643, 222.94099999999997, 205.235, 187.524, 169.81, 152.094, 134.375, 116.655, 98.935, 81.214, 63.494, 45.776, 28.06, 10.345999999999998, -7.364, -25.07, -42.771, -60.466, -78.155, -95.837, -113.512, -131.178, -148.835, -166.482, -184.118, -201.74400000000003, -219.357, -236.958, -254.545, -272.117, -289.675, -307.218, -324.743, -342.25199999999995, -359.74300000000005, -377.214, -394.667, -412.099, -429.51, -446.899, -464.265, -481.608, -498.926, -516.22, -533.487, -550.7280000000001, -567.941, -585.125, -602.28, -619.405, -636.499, -653.561, -670.59, -687.586, -704.546, -721.471, -738.36, -755.211, -772.0239999999999, -788.797, -805.53, -822.221, -838.87, -855.4760000000001, -872.038, -888.554, -905.023, -921.445, -937.818, -954.1419999999999, -970.415, -986.6360000000001, -1002.803, -1018.9169999999999, -1034.975, -1050.976, -1066.92, -1082.805, -1098.629, -1114.392, -1130.0910000000001, -1145.7269999999999, -1161.297, -1176.8010000000002, -1192.236, -1207.6019999999999, -1222.896, -1238.118, -1253.267, -1268.339, -1283.335, -1298.253, -1313.09, -1327.846, -1342.5179999999998, -1357.106, -1371.6070000000002, -1386.02, -1400.342, -1414.5729999999999, -1428.71, -1442.751, -1456.695, -1470.539, -1484.2820000000002, -1497.922, -1511.4560000000001, -1524.882, -1538.1989999999998, -1551.404, -1564.495, -1577.469, -1590.3239999999998, -1603.059, -1615.6689999999999, -1628.154, -1640.509, -1652.733, -1664.8229999999999, -1676.777, -1688.59, -1700.261, -1711.787, -1723.164, -1734.389, -1745.46, -1756.372, -1767.1229999999998, -1777.7089999999998, -1788.126, -1798.372, -1808.441, -1818.3310000000001, -1828.037, -1837.556, -1846.8829999999998, -1856.014, -1864.944, -1873.67, -1882.185, -1890.486, -1898.568, -1906.4260000000002, -1914.0529999999999, -1921.4460000000001, -1928.5970000000002, -1935.5020000000002, -1942.155, -1948.549, -1954.6779999999999, -1960.535, -1966.114, -1971.408, -1976.41, -1981.111, -1985.505, -1989.5829999999999, -1993.3370000000002, -1996.759, -1999.84, -2002.57, -2004.9389999999999, -2006.9389999999999, -2008.557, -2009.785, -2010.61, -2011.0220000000002, -2011.007, -2010.555, -2009.651, -2008.2820000000002, -2006.434, -2004.0929999999998, -2001.244, -1997.87, -1993.954, -1989.479, -1984.4270000000001, -1978.78, -1972.5179999999998, -1965.619, -1958.0639999999999, -1949.828, -1940.888, -1931.219, -1920.796, -1909.592, -1897.579, -1884.727, -1871.003, -1856.3770000000002, -1840.8129999999999, -1824.277, -1806.7320000000002, -1788.136, -1768.4489999999998, -1747.63, -1725.6329999999998, -1702.411, -1677.914, -1652.094, -1624.8970000000002, -1596.267, -1566.148, -1534.4820000000002, -1501.211, -1466.27, -1429.6, -1391.138, -1350.82, -1308.588, -1264.379, -1218.138, -1169.8139999999999, -1119.359, -1066.736, -1011.915, -954.882, -895.633, -834.186, -770.578, -704.865, -637.136, -567.499, -496.095, -423.094, -348.689, -273.103, -196.579, -119.37700000000001, -41.766999999999996, 35.973, 113.569, 190.753, 267.27099999999996, 342.889, 417.39300000000003, 490.597, 562.3380000000001, 632.482, 700.921, 767.568, 832.3610000000001, 895.26, 956.237, 1015.2860000000001, 1072.41, 1127.623, 1180.951, 1232.423, 1282.077, 1329.953, 1376.096, 1420.5520000000001, 1463.369, 1504.594, 1544.277, 1582.4679999999998, 1619.2120000000002, 1654.557, 1688.55, 1721.236, 1752.6570000000002, 1782.856, 1811.876, 1839.754, 1866.529, 1892.2379999999998, 1916.915, 1940.595, 1963.31, 1985.092, 2005.971, 2025.974, 2045.131, 2063.466, 2081.008, 2097.778, 2113.8, 2129.098, 2143.692, 2157.603, 2170.8520000000003, 2183.4570000000003, 2195.436, 2206.8070000000002, 2217.5879999999997, 2227.7929999999997, 2237.44, 2246.5429999999997, 2255.116, 2263.175, 2270.731, 2277.798, 2284.388, 2290.513, 2296.186, 2301.417, 2306.217, 2310.597, 2314.5660000000003, 2318.135, 2321.313, 2324.109, 2326.531, 2328.5879999999997, 2330.2889999999998, 2331.6420000000003, 2332.653, 2333.331, 2333.6839999999997, 2333.717, 2333.438, 2332.854, 2331.971, 2330.794, 2329.331, 2327.587, 2325.5679999999998, 2323.279, 2320.726, 2317.9139999999998, 2314.848, 2311.533, 2307.974, 2304.175, 2300.141, 2295.877, 2291.387, 2286.675, 2281.745, 2276.6020000000003, 2271.248, 2265.689, 2259.927, 2253.967, 2247.811, 2241.464, 2234.929, 2228.209, 2221.3070000000002, 2214.226, 2206.97, 2199.541, 2191.9429999999998, 2184.178, 2176.249, 2168.159, 2159.91, 2151.506, 2142.948, 2134.24, 2125.383, 2116.38, 2107.234, 2097.947, 2088.521, 2078.958, 2069.26, 2059.431, 2049.471, 2039.382, 2029.168, 2018.829, 2008.368, 1997.787, 1987.0870000000002, 1976.271, 1965.34, 1954.296, 1943.14, 1931.875, 1920.5020000000002, 1909.023, 1897.4379999999999, 1885.751, 1873.963, 1862.0739999999998, 1850.0870000000002, 1838.003, 1825.8239999999998, 1813.5510000000002, 1801.185, 1788.7279999999998, 1776.181, 1763.545, 1750.8229999999999, 1738.014, 1725.121, 1712.145, 1699.0870000000002, 1685.9479999999999, 1672.73, 1659.433, 1646.059, 1632.609, 1619.0839999999998, 1605.486, 1591.815, 1578.0729999999999, 1564.26, 1550.378, 1536.4279999999999, 1522.411, 1508.3270000000002, 1494.1789999999999, 1479.9660000000001, 1465.691, 1451.3529999999998, 1436.954, 1422.496, 1407.9779999999998, 1393.401, 1378.7679999999998, 1364.078, 1349.3329999999999, 1334.533, 1319.68, 1304.7730000000001, 1289.815, 1274.806, 1259.747, 1244.638, 1229.481, 1214.276, 1199.025, 1183.7269999999999, 1168.384, 1152.997, 1137.567, 1122.093, 1106.578, 1091.021, 1075.424, 1059.787, 1044.111, 1028.397, 1012.645, 996.857, 981.033, 965.174, 949.28, 933.352, 917.3910000000001, 901.398, 885.373, 869.317, 853.2310000000001, 837.1160000000001, 820.971, 804.799, 788.5980000000001, 772.3710000000001, 756.118, 739.84, 723.5360000000001, 707.209, 690.857, 674.4839999999999, 658.0880000000001, 641.67, 625.232, 608.773, 592.295, 575.798, 559.283, 542.75, 526.2, 509.634, 493.05300000000005, 476.45599999999996, 459.845, 443.22, 426.582, 409.931, 393.269, 376.595, 359.911, 343.217, 326.514, 309.802, 293.082, 276.355, 259.62, 242.88, 226.13400000000001, 209.38400000000001, 192.62900000000002, 175.87099999999998, 159.109, 142.346, 125.58, 108.814, 92.04799999999999, 75.281, 58.516000000000005, 41.751999999999995, 24.991, 8.232000000000001, -8.523, -25.273000000000003, -42.019, -58.76, -75.494, -92.221, -108.94, -125.652, -142.35399999999998, -159.047, -175.729, -192.4, -209.06, -225.707, -242.34099999999998, -258.961, -275.567, -292.157, -308.731, -325.289, -341.829, -358.35, -374.853, -391.336, -407.79900000000004, -424.24, -440.659, -457.055, -473.42800000000005, -489.776, -506.099, -522.396, -538.665, -554.908, -571.121, -587.306, -603.46, -619.582, -635.673, -651.731, -667.755, -683.745, -699.698, -715.6160000000001, -731.495, -747.337, -763.1389999999999, -778.9, -794.62, -810.298, -825.932, -841.5219999999999, -857.066, -872.564, -888.0139999999999, -903.416, -918.768, -934.068, -949.317, -964.513, -979.654, -994.7389999999999, -1009.768, -1024.738, -1039.649, -1054.5, -1069.289, -1084.015, -1098.6760000000002, -1113.271, -1127.799, -1142.258, -1156.647, -1170.965, -1185.2089999999998, -1199.379, -1213.473, -1227.489, -1241.4260000000002, -1255.282, -1269.055, -1282.744, -1296.347, -1309.862, -1323.2879999999998, -1336.622, -1349.8629999999998, -1363.009, -1376.057, -1389.007, -1401.855, -1414.6, -1427.239, -1439.771, -1452.193, -1464.503, -1476.6979999999999, -1488.776, -1500.735, -1512.5720000000001, -1524.285, -1535.871, -1547.3270000000002, -1558.651, -1569.839, -1580.889, -1591.799, -1602.5629999999999, -1613.181, -1623.648, -1633.961, -1644.1170000000002, -1654.112, -1663.943, -1673.6070000000002, -1683.098, -1692.414, -1701.55, -1710.503, -1719.267, -1727.84, -1736.2160000000001, -1744.39, -1752.359, -1760.116, -1767.658, -1774.9779999999998, -1782.0710000000001, -1788.932, -1795.555, -1801.935, -1808.0639999999999, -1813.9370000000001, -1819.5479999999998, -1824.889, -1829.953, -1834.734, -1839.223, -1843.4129999999998, -1847.297, -1850.865, -1854.109, -1857.02, -1859.589, -1861.806, -1863.661, -1865.144, -1866.243, -1866.9479999999999, -1867.247, -1867.128, -1866.578, -1865.5839999999998, -1864.132, -1862.207, -1859.796, -1856.882, -1853.4489999999998, -1849.48, -1844.9560000000001, -1839.861, -1834.1729999999998, -1827.874, -1820.941, -1813.3529999999998, -1805.086, -1796.116, -1786.4170000000001, -1775.963, -1764.726, -1752.6760000000002, -1739.7839999999999, -1726.014, -1711.336, -1695.713, -1679.108, -1661.483, -1642.796, -1623.006, -1602.067, -1579.934, -1556.558, -1531.889, -1505.874, -1478.461, -1449.592, -1419.211, -1387.26, -1353.6779999999999, -1318.405, -1281.382, -1242.548, -1201.846, -1159.221, -1114.62, -1067.998, -1019.314, -968.54, -915.6560000000001, -860.6560000000001, -803.553, -744.3739999999999, -683.17, -620.018, -555.016, -488.291, -419.99800000000005, -350.315, -279.447, -207.62099999999998, -135.078, -62.073, 11.135, 84.285, 157.125, 229.41299999999998, 300.92400000000004, 371.454, 440.82300000000004, 508.875, 575.475, 640.518, 703.919, 765.6139999999999, 825.559, 883.727, 940.1060000000001, 994.695, 1047.507, 1098.56, 1147.881, 1195.502, 1241.4589999999998, 1285.792, 1328.5439999999999, 1369.757, 1409.475, 1447.744, 1484.608, 1520.111, 1554.296, 1587.207, 1618.885, 1649.362, 1678.7020000000002, 1706.918, 1734.058, 1760.154, 1785.241, 1809.3529999999998, 1832.52, 1854.775, 1876.146, 1896.66, 1916.344, 1935.226, 1953.329, 1970.6779999999999, 1987.295, 2003.203, 2018.421, 2032.9720000000002, 2046.8729999999998, 2060.145, 2072.804, 2084.869, 2096.355, 2107.278, 2117.654, 2127.498, 2136.824, 2145.645, 2153.976, 2161.827, 2169.2129999999997, 2176.144, 2182.631, 2188.686, 2194.32, 2199.542, 2204.362, 2208.791, 2212.837, 2216.509, 2219.815, 2222.765, 2225.367, 2227.626, 2229.553, 2231.153, 2232.4339999999997, 2233.403, 2234.0660000000003, 2234.43, 2234.501, 2234.286, 2233.79, 2233.019, 2231.978, 2230.673, 2229.11, 2227.292, 2225.226, 2222.916, 2220.367, 2217.584, 2214.57, 2211.33, 2207.869, 2204.19, 2200.298, 2196.196, 2191.888, 2187.3779999999997, 2182.67, 2177.7670000000003, 2172.672, 2167.39, 2161.922, 2156.2729999999997, 2150.446, 2144.4429999999998, 2138.268, 2131.923, 2125.4120000000003, 2118.736, 2111.9, 2104.905, 2097.755, 2090.451, 2082.996, 2075.393, 2067.644, 2059.752, 2051.718, 2043.546, 2035.236, 2026.7920000000001, 2018.215, 2009.507, 2000.671, 1991.7089999999998, 1982.622, 1973.4129999999998, 1964.0829999999999, 1954.634, 1945.068, 1935.386, 1925.5910000000001, 1915.685, 1905.668, 1895.543, 1885.3110000000001, 1874.974, 1864.533, 1853.99, 1843.346, 1832.604, 1821.763, 1810.8270000000002, 1799.795, 1788.671, 1777.454, 1766.1470000000002, 1754.75, 1743.265, 1731.694, 1720.037, 1708.296, 1696.4720000000002, 1684.566, 1672.58, 1660.514, 1648.37, 1636.149, 1623.852, 1611.48, 1599.0339999999999, 1586.516, 1573.9260000000002, 1561.266, 1548.536, 1535.7379999999998, 1522.872, 1509.94, 1496.942, 1483.88, 1470.754, 1457.565, 1444.315, 1431.005, 1417.634, 1404.204, 1390.717, 1377.172, 1363.5720000000001, 1349.915, 1336.205, 1322.44, 1308.623, 1294.754, 1280.833, 1266.863, 1252.8419999999999, 1238.7730000000001, 1224.656, 1210.492, 1196.281, 1182.025, 1167.724, 1153.379, 1138.99, 1124.559, 1110.085, 1095.5710000000001, 1081.016, 1066.421, 1051.788, 1037.116, 1022.4060000000001, 1007.659, 992.8760000000001, 978.058, 963.205, 948.317, 933.3960000000001, 918.442, 903.456, 888.438, 873.39, 858.311, 843.203, 828.065, 812.9, 797.706, 782.4860000000001, 767.2389999999999, 751.966, 736.669, 721.346, 706.0, 690.6310000000001, 675.238, 659.824, 644.388, 628.932, 613.455, 597.9580000000001, 582.443, 566.909, 551.357, 535.788, 520.203, 504.601, 488.98400000000004, 473.352, 457.70599999999996, 442.046, 426.37300000000005, 410.68800000000005, 394.991, 379.282, 363.56300000000005, 347.834, 332.095, 316.348, 300.592, 284.828, 269.057, 253.28, 237.497, 221.709, 205.915, 190.118, 174.317, 158.514, 142.708, 126.9, 111.09100000000001, 95.28200000000001, 79.473, 63.665, 47.858000000000004, 32.053000000000004, 16.25, 0.451, -15.344000000000001, -31.135, -46.92, -62.7, -78.473, -94.24, -109.99799999999999, -125.74799999999999, -141.49, -157.221, -172.942, -188.65200000000002, -204.351, -220.037, -235.71, -251.36900000000003, -267.013, -282.643, -298.257, -313.85400000000004, -329.43300000000005, -344.995, -360.538, -376.06199999999995, -391.565, -407.04699999999997, -422.50800000000004, -437.94599999999997, -453.36, -468.751, -484.116, -499.45599999999996, -514.77, -530.056, -545.314, -560.543, -575.742, -590.911, -606.048, -621.1519999999999, -636.2230000000001, -651.26, -666.262, -681.2280000000001, -696.1560000000001, -711.047, -725.8989999999999, -740.711, -755.482, -770.211, -784.8969999999999, -799.539, -814.1360000000001, -828.687, -843.191, -857.6469999999999, -872.053, -886.409, -900.7130000000001, -914.9639999999999, -929.1610000000001, -943.303, -957.388, -971.415, -985.3839999999999, -999.2919999999999, -1013.1389999999999, -1026.922, -1040.641, -1054.295, -1067.881, -1081.3980000000001, -1094.846, -1108.222, -1121.524, -1134.752, -1147.903, -1160.9769999999999, -1173.971, -1186.883, -1199.713, -1212.458, -1225.116, -1237.685, -1250.165, -1262.5510000000002, -1274.844, -1287.04, -1299.138, -1311.136, -1323.031, -1334.8210000000001, -1346.504, -1358.078, -1369.54, -1380.888, -1392.119, -1403.231, -1414.221, -1425.0870000000002, -1435.825, -1446.433, -1456.908, -1467.247, -1477.4479999999999, -1487.506, -1497.418, -1507.182, -1516.795, -1526.251, -1535.5479999999998, -1544.683, -1553.651, -1562.4479999999999, -1571.0710000000001, -1579.515, -1587.776, -1595.85, -1603.7320000000002, -1611.4170000000001, -1618.9, -1626.1779999999999, -1633.243, -1640.092, -1646.7179999999998, -1653.1170000000002, -1659.281, -1665.205, -1670.8829999999998, -1676.308, -1681.473, -1686.372, -1690.9979999999998, -1695.342, -1699.3970000000002, -1703.155, -1706.608, -1709.747, -1712.5639999999999, -1715.0479999999998, -1717.19, -1718.98, -1720.408, -1721.4620000000002, -1722.132, -1722.405, -1722.269, -1721.711, -1720.7179999999998, -1719.276, -1717.371, -1714.987, -1712.1070000000002, -1708.7160000000001, -1704.797, -1700.33, -1695.2979999999998, -1689.68, -1683.4560000000001, -1676.6029999999998, -1669.099, -1660.92, -1652.04, -1642.434, -1632.0739999999998, -1620.932, -1608.976, -1596.175, -1582.495, -1567.902, -1552.36, -1535.83, -1518.27, -1499.641, -1479.8970000000002, -1458.994, -1436.882, -1413.514, -1388.8370000000002, -1362.799, -1335.344, -1306.4180000000001, -1275.962, -1243.9180000000001, -1210.23, -1174.839, -1137.688, -1098.725, -1057.897, -1015.158, -970.4689999999999, -923.797, -875.1210000000001, -824.431, -771.7339999999999, -717.051, -660.425, -601.922, -541.628, -479.66, -416.154, -351.275, -285.21, -218.169, -150.374, -82.06299999999999, -13.479000000000001, 55.13399999999999, 123.537, 191.502, 258.815, 325.281, 390.725, 454.99699999999996, 517.967, 579.531, 639.602, 698.1189999999999, 755.034, 810.317, 863.954, 915.939, 966.2810000000001, 1014.9960000000001, 1062.103, 1107.631, 1151.613, 1194.0819999999999, 1235.076, 1274.635, 1312.799, 1349.6070000000002, 1385.1, 1419.3210000000001, 1452.306, 1484.096, 1514.73, 1544.244, 1572.675, 1600.058, 1626.4279999999999, 1651.817, 1676.255, 1699.776, 1722.406, 1744.1760000000002, 1765.1129999999998, 1785.2420000000002, 1804.588, 1823.1760000000002, 1841.0279999999998, 1858.168, 1874.616, 1890.394, 1905.52, 1920.013, 1933.892, 1947.175, 1959.878, 1972.017, 1983.608, 1994.6660000000002, 2005.205, 2015.239, 2024.781, 2033.845, 2042.441, 2050.584, 2058.283, 2065.55, 2072.397, 2078.8320000000003, 2084.866, 2090.508, 2095.769, 2100.656, 2105.178, 2109.345, 2113.163, 2116.641, 2119.7870000000003, 2122.607, 2125.11, 2127.301, 2129.188, 2130.777, 2132.074, 2133.085, 2133.817, 2134.274, 2134.4629999999997, 2134.389, 2134.0570000000002, 2133.473, 2132.641, 2131.5660000000003, 2130.2529999999997, 2128.706, 2126.93, 2124.93, 2122.708, 2120.271, 2117.62, 2114.761, 2111.697, 2108.4320000000002, 2104.969, 2101.312, 2097.465, 2093.43, 2089.212, 2084.812, 2080.235, 2075.4829999999997, 2070.5589999999997, 2065.466, 2060.208, 2054.786, 2049.203, 2043.463, 2037.567, 2031.519, 2025.32, 2018.973, 2012.481, 2005.845, 1999.069, 1992.154, 1985.102, 1977.9160000000002, 1970.5970000000002, 1963.148, 1955.57, 1947.8670000000002, 1940.039, 1932.088, 1924.016, 1915.826, 1907.519, 1899.096, 1890.56, 1881.912, 1873.154, 1864.287, 1855.3120000000001, 1846.233, 1837.049, 1827.763, 1818.376, 1808.89, 1799.306, 1789.624, 1779.848, 1769.9779999999998, 1760.015, 1749.961, 1739.817, 1729.585, 1719.265, 1708.859, 1698.368, 1687.7939999999999, 1677.1370000000002, 1666.398, 1655.58, 1644.682, 1633.7060000000001, 1622.654, 1611.526, 1600.3229999999999, 1589.046, 1577.6970000000001, 1566.276, 1554.7839999999999, 1543.223, 1531.594, 1519.896, 1508.132, 1496.3029999999999, 1484.408, 1472.45, 1460.4289999999999, 1448.345, 1436.201, 1423.996, 1411.731, 1399.408, 1387.0279999999998, 1374.59, 1362.096, 1349.5479999999998, 1336.944, 1324.287, 1311.5770000000002, 1298.815, 1286.002, 1273.139, 1260.225, 1247.263, 1234.252, 1221.193, 1208.088, 1194.937, 1181.741, 1168.499, 1155.214, 1141.886, 1128.515, 1115.1019999999999, 1101.6480000000001, 1088.153, 1074.619, 1061.045, 1047.433, 1033.7830000000001, 1020.095, 1006.3710000000001, 992.6110000000001, 978.816, 964.9860000000001, 951.122, 937.225, 923.295, 909.332, 895.3380000000001, 881.313, 867.258, 853.172, 839.058, 824.915, 810.7439999999999, 796.545, 782.32, 768.069, 753.791, 739.4889999999999, 725.1619999999999, 710.811, 696.437, 682.04, 667.6210000000001, 653.18, 638.7180000000001, 624.235, 609.732, 595.21, 580.669, 566.11, 551.533, 536.939, 522.328, 507.70099999999996, 493.059, 478.401, 463.72900000000004, 449.043, 434.344, 419.63199999999995, 404.908, 390.17199999999997, 375.425, 360.668, 345.9, 331.12300000000005, 316.337, 301.54200000000003, 286.74, 271.931, 257.115, 242.292, 227.465, 212.632, 197.795, 182.953, 168.109, 153.262, 138.412, 123.561, 108.709, 93.85700000000001, 79.00399999999999, 64.153, 49.302, 34.454, 19.608, 4.765, -10.074, -24.909000000000002, -39.739000000000004, -54.56399999999999, -69.382, -84.194, -98.99799999999999, -113.795, -128.582, -143.361, -158.13, -172.888, -187.635, -202.37, -217.093, -231.80200000000002, -246.498, -261.17900000000003, -275.845, -290.495, -305.129, -319.745, -334.344, -348.923, -363.483, -378.023, -392.542, -407.04, -421.514, -435.966, -450.394, -464.79699999999997, -479.17400000000004, -493.525, -507.849, -522.145, -536.4119999999999, -550.649, -564.856, -579.031, -593.175, -607.284, -621.36, -635.401, -649.405, -663.373, -677.303, -691.194, -705.045, -718.8560000000001, -732.6239999999999, -746.35, -760.0310000000001, -773.668, -787.258, -800.801, -814.296, -827.7410000000001, -841.1360000000001, -854.4789999999999, -867.768, -881.003, -894.183, -907.306, -920.37, -933.3760000000001, -946.32, -959.202, -972.02, -984.7739999999999, -997.46, -1010.079, -1022.628, -1035.107, -1047.512, -1059.843, -1072.098, -1084.276, -1096.374, -1108.391, -1120.325, -1132.175, -1143.937, -1155.611, -1167.195, -1178.6860000000001, -1190.0819999999999, -1201.381, -1212.5819999999999, -1223.681, -1234.677, -1245.567, -1256.349, -1267.019, -1277.577, -1288.019, -1298.343, -1308.545, -1318.624, -1328.575, -1338.3970000000002, -1348.086, -1357.639, -1367.0529999999999, -1376.3239999999998, -1385.45, -1394.4260000000002, -1403.249, -1411.9160000000002, -1420.422, -1428.763, -1436.9370000000001, -1444.9370000000001, -1452.761, -1460.4029999999998, -1467.859, -1475.124, -1482.194, -1489.0629999999999, -1495.727, -1502.1789999999999, -1508.4129999999998, -1514.425, -1520.2089999999998, -1525.757, -1531.0639999999999, -1536.1229999999998, -1540.9270000000001, -1545.469, -1549.741, -1553.736, -1557.4460000000001, -1560.8629999999998, -1563.977, -1566.78, -1569.263, -1571.4160000000002, -1573.2279999999998, -1574.69, -1575.79, -1576.516, -1576.858, -1576.8020000000001, -1576.335, -1575.445, -1574.116, -1572.335, -1570.085, -1567.351, -1564.115, -1560.36, -1556.067, -1551.2179999999998, -1545.7910000000002, -1539.766, -1533.12, -1525.83, -1517.87, -1509.2160000000001, -1499.8410000000001, -1489.715, -1478.81, -1467.094, -1454.5339999999999, -1441.096, -1426.743, -1411.4389999999999, -1395.144, -1377.815, -1359.411, -1339.886, -1319.194, -1297.285, -1274.109, -1249.614, -1223.748, -1196.455, -1167.68, -1137.367, -1105.461, -1071.906, -1036.651, -999.643, -960.8389999999999, -920.196, -877.681, -833.2710000000001, -786.95, -738.721, -688.5989999999999, -636.619, -582.835, -527.3240000000001, -470.18699999999995, -411.548, -351.55400000000003, -290.376, -228.205, -165.24599999999998, -101.719, -37.85, 26.134, 90.009, 153.559, 216.582, 278.892, 340.32300000000004, 400.727, 459.98, 517.98, 574.64, 629.8969999999999, 683.704, 736.028, 786.8489999999999, 836.1610000000001, 883.967, 930.2769999999999, 975.1080000000001, 1018.485, 1060.432, 1100.982, 1140.1680000000001, 1178.0230000000001, 1214.583, 1249.884, 1283.965, 1316.859, 1348.604, 1379.236, 1408.789, 1437.297, 1464.7939999999999, 1491.3110000000001, 1516.882, 1541.533, 1565.296, 1588.1989999999998, 1610.2679999999998, 1631.53, 1652.011, 1671.7320000000002, 1690.72, 1708.994, 1726.578, 1743.4920000000002, 1759.756, 1775.3870000000002, 1790.406, 1804.829, 1818.6729999999998, 1831.955, 1844.691, 1856.895, 1868.5810000000001, 1879.765, 1890.4579999999999, 1900.674, 1910.4260000000002, 1919.725, 1928.5829999999999, 1937.011, 1945.02, 1952.62, 1959.8210000000001, 1966.6329999999998, 1973.065, 1979.126, 1984.825, 1990.1689999999999, 1995.168, 1999.829, 2004.16, 2008.1670000000001, 2011.859, 2015.2420000000002, 2018.3220000000001, 2021.106, 2023.601, 2025.8129999999999, 2027.747, 2029.4089999999999, 2030.805, 2031.9389999999999, 2032.818, 2033.4460000000001, 2033.829, 2033.97, 2033.876, 2033.549, 2032.995, 2032.219, 2031.223, 2030.013, 2028.5910000000001, 2026.963, 2025.132, 2023.101, 2020.874, 2018.455, 2015.846, 2013.0510000000002, 2010.0739999999998, 2006.9170000000001, 2003.5839999999998, 2000.0770000000002, 1996.4, 1992.556, 1988.546, 1984.374, 1980.043, 1975.555, 1970.9129999999998, 1966.119, 1961.175, 1956.085, 1950.849, 1945.4720000000002, 1939.954, 1934.2979999999998, 1928.506, 1922.5810000000001, 1916.524, 1910.3370000000002, 1904.0220000000002, 1897.582, 1891.0179999999998, 1884.3310000000001, 1877.525, 1870.599, 1863.558, 1856.401, 1849.13, 1841.7479999999998, 1834.256, 1826.656, 1818.9479999999999, 1811.135, 1803.219, 1795.1989999999998, 1787.079, 1778.86, 1770.5420000000001, 1762.1270000000002, 1753.6170000000002, 1745.013, 1736.317, 1727.5279999999998, 1718.65, 1709.683, 1700.628, 1691.486, 1682.259, 1672.9479999999999, 1663.5539999999999, 1654.078, 1644.521, 1634.885, 1625.17, 1615.3770000000002, 1605.509, 1595.5639999999999, 1585.545, 1575.453, 1565.289, 1555.0529999999999, 1544.746, 1534.37, 1523.9260000000002, 1513.4129999999998, 1502.8339999999998, 1492.19, 1481.48, 1470.7060000000001, 1459.869, 1448.97, 1438.009, 1426.9879999999998, 1415.906, 1404.766, 1393.567, 1382.3110000000001, 1370.999, 1359.63, 1348.207, 1336.729, 1325.1970000000001, 1313.6129999999998, 1301.9769999999999, 1290.289, 1278.55, 1266.762, 1254.924, 1243.038, 1231.104, 1219.123, 1207.095, 1195.022, 1182.903, 1170.74, 1158.5330000000001, 1146.2830000000001, 1133.99, 1121.655, 1109.279, 1096.863, 1084.406, 1071.91, 1059.375, 1046.802, 1034.191, 1021.544, 1008.8589999999999, 996.14, 983.3839999999999, 970.5939999999999, 957.7710000000001, 944.913, 932.023, 919.1, 906.145, 893.159, 880.143, 867.096, 854.02, 840.914, 827.78, 814.618, 801.429, 788.2130000000001, 774.97, 761.702, 748.408, 735.09, 721.747, 708.38, 694.9910000000001, 681.578, 668.1439999999999, 654.688, 641.21, 627.7130000000001, 614.195, 600.6569999999999, 587.1, 573.525, 559.932, 546.321, 532.693, 519.049, 505.389, 491.713, 478.022, 464.31699999999995, 450.597, 436.865, 423.119, 409.361, 395.591, 381.809, 368.017, 354.214, 340.401, 326.579, 312.748, 298.909, 285.062, 271.207, 257.346, 243.47799999999998, 229.605, 215.726, 201.843, 187.956, 174.065, 160.17, 146.274, 132.375, 118.475, 104.573, 90.67200000000001, 76.77, 62.87, 48.97, 35.071999999999996, 21.177, 7.285, -6.604, -20.489, -34.369, -48.244, -62.113, -75.976, -89.831, -103.679, -117.51899999999999, -131.35, -145.171, -158.982, -172.783, -186.572, -200.35, -214.114, -227.86599999999999, -241.60299999999998, -255.326, -269.033, -282.725, -296.4, -310.057, -323.697, -337.31699999999995, -350.91900000000004, -364.5, -378.06, -391.598, -405.11400000000003, -418.606, -432.075, -445.51800000000003, -458.93699999999995, -472.32800000000003, -485.69300000000004, -499.029, -512.336, -525.614, -538.861, -552.077, -565.26, -578.409, -591.525, -604.605, -617.649, -630.656, -643.624, -656.554, -669.443, -682.291, -695.097, -707.86, -720.578, -733.2510000000001, -745.877, -758.455, -770.9839999999999, -783.462, -795.89, -808.2639999999999, -820.585, -832.8510000000001, -845.059, -857.21, -869.302, -881.332, -893.301, -905.206, -917.046, -928.819, -940.5239999999999, -952.159, -963.7230000000001, -975.2130000000001, -986.6289999999999, -997.9680000000001, -1009.2280000000001, -1020.408, -1031.506, -1042.521, -1053.4489999999998, -1064.289, -1075.038, -1085.6960000000001, -1096.259, -1106.726, -1117.093, -1127.359, -1137.522, -1147.578, -1157.526, -1167.362, -1177.0839999999998, -1186.69, -1196.175, -1205.539, -1214.776, -1223.885, -1232.862, -1241.704, -1250.4080000000001, -1258.969, -1267.385, -1275.651, -1283.765, -1291.721, -1299.516, -1307.146, -1314.6070000000002, -1321.8929999999998, -1329.001, -1335.925, -1342.66, -1349.2020000000002, -1355.546, -1361.684, -1367.6129999999998, -1373.326, -1378.816, -1384.079, -1389.106, -1393.892, -1398.4289999999999, -1402.71, -1406.727, -1410.4720000000002, -1413.9379999999999, -1417.115, -1419.994, -1422.567, -1424.8239999999998, -1426.754, -1428.3470000000002, -1429.5929999999998, -1430.4779999999998, -1430.9920000000002, -1431.1229999999998, -1430.8570000000002, -1430.18, -1429.078, -1427.537, -1425.5410000000002, -1423.0729999999999, -1420.116, -1416.652, -1412.6629999999998, -1408.129, -1403.0279999999998, -1397.34, -1391.0420000000001, -1384.11, -1376.517, -1368.239, -1359.247, -1349.5120000000002, -1339.004, -1327.691, -1315.539, -1302.512, -1288.5739999999998, -1273.687, -1257.808, -1240.896, -1222.907, -1203.796, -1183.514, -1162.012, -1139.24, -1115.145, -1089.6760000000002, -1062.777, -1034.396, -1004.48, -972.9760000000001, -939.837, -905.015, -868.4689999999999, -830.164, -790.074, -748.182, -704.4810000000001, -658.9839999999999, -611.715, -562.72, -512.063, -459.832, -406.13599999999997, -351.108, -294.899, -237.683, -179.64700000000002, -120.993, -61.928000000000004, -2.6639999999999997, 56.591, 115.634, 174.275, 232.338, 289.664, 346.11199999999997, 401.561, 455.911, 509.077, 560.995, 611.615, 660.9019999999999, 708.835, 755.403, 800.6039999999999, 844.444, 886.936, 928.1, 967.956, 1006.5310000000001, 1043.853, 1079.953, 1114.86, 1148.608, 1181.23, 1212.756, 1243.22, 1272.653, 1301.088, 1328.54, 1355.0829999999999, 1380.7020000000002, 1405.442, 1429.3270000000002, 1452.386, 1474.644, 1496.126, 1516.856, 1536.8570000000002, 1556.15, 1574.7579999999998, 1592.7, 1609.996, 1626.6660000000002, 1642.727, 1658.1970000000001, 1673.094, 1687.433, 1701.229, 1714.4979999999998, 1727.254, 1739.5120000000002, 1751.2839999999999, 1762.5829999999999, 1773.422, 1783.8129999999999, 1793.766, 1803.2939999999999, 1812.4070000000002, 1821.115, 1829.4279999999999, 1837.3570000000002, 1844.9089999999999, 1852.094, 1858.921, 1865.398, 1871.533, 1877.3339999999998, 1882.808, 1887.963, 1892.805, 1897.342, 1901.5810000000001, 1905.527, 1909.1860000000001, 1912.566, 1915.672, 1918.5079999999998, 1921.082, 1923.398, 1925.4620000000002, 1927.277, 1928.851, 1930.1860000000001, 1931.287, 1932.16, 1932.808, 1933.236, 1933.4479999999999, 1933.4470000000001, 1933.2379999999998, 1932.825, 1932.211, 1931.4, 1930.395, 1929.2, 1927.818, 1926.2520000000002, 1924.506, 1922.582, 1920.484, 1918.215, 1915.777, 1913.1729999999998, 1910.406, 1907.4779999999998, 1904.3929999999998, 1901.1529999999998, 1897.76, 1894.2160000000001, 1890.525, 1886.6879999999999, 1882.7079999999999, 1878.5870000000002, 1874.3270000000002, 1869.93, 1865.399, 1860.735, 1855.94, 1851.017, 1845.967, 1840.7920000000001, 1835.494, 1830.075, 1824.537, 1818.881, 1813.109, 1807.2220000000002, 1801.223, 1795.1129999999998, 1788.894, 1782.566, 1776.132, 1769.594, 1762.951, 1756.207, 1749.362, 1742.418, 1735.376, 1728.2379999999998, 1721.004, 1713.6760000000002, 1706.256, 1698.744, 1691.1429999999998, 1683.4520000000002, 1675.6729999999998, 1667.808, 1659.8570000000002, 1651.8220000000001, 1643.704, 1635.504, 1627.2220000000002, 1618.861, 1610.421, 1601.9029999999998, 1593.308, 1584.6370000000002, 1575.891, 1567.0720000000001, 1558.1789999999999, 1549.214, 1540.1779999999999, 1531.0729999999999, 1521.8970000000002, 1512.654, 1503.3429999999998, 1493.965, 1484.521, 1475.013, 1465.44, 1455.8039999999999, 1446.106, 1436.346, 1426.525, 1416.644, 1406.704, 1396.705, 1386.648, 1376.535, 1366.365, 1356.139, 1345.858, 1335.524, 1325.135, 1314.694, 1304.201, 1293.657, 1283.062, 1272.4160000000002, 1261.722, 1250.978, 1240.1860000000001, 1229.347, 1218.461, 1207.529, 1196.5510000000002, 1185.528, 1174.461, 1163.35, 1152.1960000000001, 1140.999, 1129.761, 1118.48, 1107.1589999999999, 1095.798, 1084.397, 1072.9560000000001, 1061.478, 1049.961, 1038.406, 1026.815, 1015.187, 1003.5239999999999, 991.825, 980.091, 968.323, 956.5210000000001, 944.686, 932.818, 920.918, 908.987, 897.0239999999999, 885.03, 873.007, 860.953, 848.8710000000001, 836.76, 824.62, 812.453, 800.2589999999999, 788.0369999999999, 775.79, 763.5169999999999, 751.2189999999999, 738.895, 726.548, 714.176, 701.7819999999999, 689.3639999999999, 676.924, 664.462, 651.9780000000001, 639.474, 626.9490000000001, 614.403, 601.8380000000001, 589.255, 576.6519999999999, 564.031, 551.3919999999999, 538.736, 526.063, 513.374, 500.66900000000004, 487.949, 475.213, 462.463, 449.699, 436.92199999999997, 424.131, 411.327, 398.51199999999994, 385.685, 372.846, 359.99699999999996, 347.13699999999994, 334.26800000000003, 321.389, 308.501, 295.605, 282.70099999999996, 269.79, 256.872, 243.947, 231.016, 218.08, 205.138, 192.19299999999998, 179.243, 166.28900000000002, 153.333, 140.374, 127.413, 114.45100000000001, 101.488, 88.524, 75.56, 62.597, 49.635, 36.674, 23.715999999999998, 10.761, -2.1919999999999997, -15.14, -28.084, -41.023, -53.957, -66.884, -79.805, -92.719, -105.625, -118.523, -131.411, -144.29, -157.159, -170.017, -182.863, -195.697, -208.519, -221.327, -234.12099999999998, -246.90099999999998, -259.665, -272.413, -285.144, -297.858, -310.55400000000003, -323.231, -335.889, -348.526, -361.142, -373.736, -386.30800000000005, -398.856, -411.38, -423.88, -436.353, -448.8, -461.219, -473.61, -485.972, -498.30400000000003, -510.605, -522.874, -535.111, -547.313, -559.481, -571.613, -583.7090000000001, -595.7669999999999, -607.786, -619.765, -631.7040000000001, -643.6, -655.454, -667.263, -679.0269999999999, -690.7439999999999, -702.414, -714.034, -725.605, -737.123, -748.5889999999999, -760.0010000000001, -771.357, -782.6560000000001, -793.8969999999999, -805.078, -816.197, -827.253, -838.245, -849.171, -860.03, -870.818, -881.5360000000001, -892.18, -902.75, -913.243, -923.658, -933.992, -944.2439999999999, -954.4119999999999, -964.492, -974.4839999999999, -984.385, -994.192, -1003.904, -1013.518, -1023.0310000000001, -1032.441, -1041.745, -1050.941, -1060.025, -1068.995, -1077.849, -1086.5819999999999, -1095.191, -1103.675, -1112.028, -1120.248, -1128.3310000000001, -1136.274, -1144.072, -1151.722, -1159.22, -1166.5610000000001, -1173.742, -1180.757, -1187.6019999999999, -1194.2730000000001, -1200.764, -1207.07, -1213.187, -1219.107, -1224.826, -1230.337, -1235.635, -1240.713, -1245.5639999999999, -1250.181, -1254.558, -1258.6860000000001, -1262.559, -1266.167, -1269.502, -1272.556, -1275.319, -1277.782, -1279.935, -1281.767, -1283.267, -1284.424, -1285.226, -1285.66, -1285.713, -1285.373, -1284.623, -1283.451, -1281.839, -1279.771, -1277.231, -1274.198, -1270.656, -1266.583, -1261.9589999999998, -1256.761, -1250.9669999999999, -1244.552, -1237.491, -1229.755, -1221.318, -1212.149, -1202.2169999999999, -1191.489, -1179.932, -1167.508, -1154.1789999999999, -1139.907, -1124.65, -1108.364, -1091.005, -1072.527, -1052.882, -1032.02, -1009.8910000000001, -986.444, -961.628, -935.3910000000001, -907.683, -878.456, -847.663, -815.2639999999999, -781.22, -745.505, -708.096, -668.9839999999999, -628.173, -585.68, -541.54, -495.80800000000005, -448.556, -399.88, -349.89599999999996, -298.737, -246.56, -193.533, -139.84, -85.669, -31.215999999999998, 23.326999999999998, 77.771, 131.939, 185.66400000000002, 238.794, 291.197, 342.754, 393.36800000000005, 442.95599999999996, 491.452, 538.806, 584.981, 629.951, 673.702, 716.2280000000001, 757.5319999999999, 797.6210000000001, 836.5089999999999, 874.215, 910.7589999999999, 946.163, 980.454, 1013.66, 1045.807, 1076.923, 1107.037, 1136.177, 1164.373, 1191.651, 1218.039, 1243.5639999999999, 1268.252, 1292.129, 1315.217, 1337.543, 1359.129, 1379.997, 1400.17, 1419.6670000000001, 1438.509, 1456.715, 1474.3039999999999, 1491.293, 1507.7, 1523.5420000000001, 1538.835, 1553.594, 1567.8339999999998, 1581.568, 1594.8110000000001, 1607.575, 1619.875, 1631.721, 1643.1270000000002, 1654.102, 1664.658, 1674.806, 1684.555, 1693.9160000000002, 1702.898, 1711.51, 1719.761, 1727.66, 1735.214, 1742.433, 1749.3229999999999, 1755.892, 1762.1470000000002, 1768.095, 1773.7420000000002, 1779.096, 1784.1629999999998, 1788.9479999999999, 1793.4579999999999, 1797.6979999999999, 1801.675, 1805.392, 1808.8570000000002, 1812.0729999999999, 1815.046, 1817.78, 1820.28, 1822.5510000000002, 1824.5970000000002, 1826.4229999999998, 1828.031, 1829.4279999999999, 1830.615, 1831.598, 1832.38, 1832.964, 1833.354, 1833.5539999999999, 1833.567, 1833.396, 1833.0439999999999, 1832.514, 1831.81, 1830.935, 1829.89, 1828.68, 1827.306, 1825.7720000000002, 1824.08, 1822.233, 1820.233, 1818.082, 1815.783, 1813.338, 1810.75, 1808.02, 1805.151, 1802.146, 1799.005, 1795.731, 1792.3270000000002, 1788.793, 1785.1329999999998, 1781.3470000000002, 1777.4379999999999, 1773.408, 1769.257, 1764.989, 1760.604, 1756.104, 1751.491, 1746.767, 1741.932, 1736.99, 1731.94, 1726.7839999999999, 1721.525, 1716.1629999999998, 1710.7, 1705.1370000000002, 1699.475, 1693.7160000000001, 1687.861, 1681.912, 1675.869, 1669.734, 1663.5079999999998, 1657.192, 1650.7879999999998, 1644.296, 1637.717, 1631.0539999999999, 1624.306, 1617.475, 1610.5620000000001, 1603.568, 1596.495, 1589.342, 1582.111, 1574.8029999999999, 1567.4189999999999, 1559.96, 1552.4270000000001, 1544.8210000000001, 1537.142, 1529.392, 1521.5710000000001, 1513.68, 1505.721, 1497.694, 1489.599, 1481.4379999999999, 1473.2120000000002, 1464.92, 1456.565, 1448.1470000000002, 1439.6660000000002, 1431.1229999999998, 1422.52, 1413.856, 1405.1329999999998, 1396.351, 1387.511, 1378.6129999999998, 1369.6589999999999, 1360.649, 1351.5839999999998, 1342.464, 1333.29, 1324.0629999999999, 1314.783, 1305.451, 1296.067, 1286.633, 1277.149, 1267.615, 1258.032, 1248.401, 1238.722, 1228.995, 1219.222, 1209.404, 1199.539, 1189.63, 1179.6760000000002, 1169.6789999999999, 1159.638, 1149.555, 1139.4289999999999, 1129.262, 1119.053, 1108.8039999999999, 1098.515, 1088.1860000000001, 1077.819, 1067.413, 1056.968, 1046.486, 1035.968, 1025.412, 1014.821, 1004.193, 993.5310000000001, 982.834, 972.1030000000001, 961.3380000000001, 950.541, 939.71, 928.847, 917.952, 907.0260000000001, 896.069, 885.081, 874.064, 863.0160000000001, 851.94, 840.835, 829.702, 818.541, 807.352, 796.137, 784.895, 773.627, 762.334, 751.015, 739.672, 728.304, 716.9119999999999, 705.497, 694.059, 682.5980000000001, 671.115, 659.61, 648.0830000000001, 636.536, 624.9680000000001, 613.38, 601.7719999999999, 590.146, 578.5, 566.836, 555.153, 543.453, 531.736, 520.003, 508.25199999999995, 496.486, 484.705, 472.908, 461.097, 449.27099999999996, 437.43199999999996, 425.579, 413.713, 401.834, 389.944, 378.042, 366.12800000000004, 354.204, 342.269, 330.325, 318.371, 306.407, 294.435, 282.455, 270.467, 258.472, 246.47, 234.46200000000002, 222.447, 210.42700000000002, 198.40200000000002, 186.373, 174.33900000000003, 162.30100000000002, 150.261, 138.218, 126.17200000000001, 114.125, 102.07700000000001, 90.027, 77.97800000000001, 65.929, 53.88, 41.833, 29.787, 17.744, 5.702999999999999, -6.334, -18.367, -30.396, -42.42, -54.438, -66.45, -78.456, -90.455, -102.446, -114.428, -126.402, -138.366, -150.319, -162.262, -174.19400000000002, -186.114, -198.021, -209.915, -221.794, -233.66, -245.50900000000001, -257.343, -269.16, -280.96, -292.742, -304.505, -316.248, -327.971, -339.673, -351.353, -363.01, -374.644, -386.254, -397.838, -409.397, -420.92900000000003, -432.43300000000005, -443.908, -455.35400000000004, -466.769, -478.153, -489.505, -500.824, -512.1080000000001, -523.356, -534.569, -545.743, -556.88, -567.976, -579.0319999999999, -590.0459999999999, -601.016, -611.943, -622.823, -633.6569999999999, -644.443, -655.179, -665.865, -676.498, -687.077, -697.602, -708.07, -718.48, -728.83, -739.1189999999999, -749.3439999999999, -759.5060000000001, -769.6010000000001, -779.628, -789.584, -799.47, -809.2810000000001, -819.0169999999999, -828.675, -838.253, -847.7489999999999, -857.1610000000001, -866.4860000000001, -875.7230000000001, -884.868, -893.92, -902.8760000000001, -911.732, -920.488, -929.1389999999999, -937.682, -946.1160000000001, -954.436, -962.6389999999999, -970.7230000000001, -978.684, -986.5189999999999, -994.2230000000001, -1001.793, -1009.225, -1016.515, -1023.66, -1030.654, -1037.494, -1044.175, -1050.69, -1057.037, -1063.211, -1069.204, -1075.012, -1080.63, -1086.0510000000002, -1091.269, -1096.277, -1101.069, -1105.637, -1109.975, -1114.0739999999998, -1117.927, -1121.526, -1124.861, -1127.924, -1130.705, -1133.195, -1135.383, -1137.259, -1138.81, -1140.025, -1140.892, -1141.397, -1141.528, -1141.269, -1140.606, -1139.524, -1138.004, -1136.031, -1133.586, -1130.649, -1127.2, -1123.218, -1118.681, -1113.566, -1107.847, -1101.497, -1094.492, -1086.8, -1078.391, -1069.235, -1059.297, -1048.5430000000001, -1036.935, -1024.435, -1011.003, -996.596, -981.172, -964.685, -947.0880000000001, -928.336, -908.3760000000001, -887.1619999999999, -864.645, -840.773, -815.502, -788.784, -760.578, -730.847, -699.558, -666.688, -632.222, -596.1569999999999, -558.503, -519.285, -478.545, -436.345, -392.76300000000003, -347.899, -301.873, -254.817, -206.885, -158.239, -109.052, -59.498999999999995, -9.759, 39.995, 89.598, 138.894, 187.739, 236.007, 283.586, 330.37800000000004, 376.30400000000003, 421.29699999999997, 465.305, 508.289, 550.222, 591.085, 630.867, 669.567, 707.19, 743.742, 779.2360000000001, 813.691, 847.1239999999999, 879.555, 911.008, 941.505, 971.071, 999.7280000000001, 1027.504, 1054.42, 1080.504, 1105.777, 1130.263, 1153.985, 1176.9669999999999, 1199.229, 1220.7930000000001, 1241.678, 1261.906, 1281.496, 1300.4660000000001, 1318.8329999999999, 1336.616, 1353.8310000000001, 1370.494, 1386.62, 1402.225, 1417.3229999999999, 1431.9270000000001, 1446.0529999999999, 1459.711, 1472.914, 1485.675, 1498.005, 1509.915, 1521.415, 1532.517, 1543.23, 1553.5629999999999, 1563.526, 1573.129, 1582.378, 1591.283, 1599.852, 1608.092, 1616.0120000000002, 1623.618, 1630.918, 1637.918, 1644.624, 1651.0439999999999, 1657.182, 1663.0479999999998, 1668.6429999999998, 1673.975, 1679.049, 1683.871, 1688.445, 1692.776, 1696.87, 1700.731, 1704.3629999999998, 1707.771, 1710.9589999999998, 1713.931, 1716.692, 1719.245, 1721.594, 1723.743, 1725.695, 1727.455, 1729.024, 1730.408, 1731.608, 1732.628, 1733.471, 1734.141, 1734.639, 1734.97, 1735.135, 1735.138, 1734.981, 1734.6660000000002, 1734.1970000000001, 1733.575, 1732.8039999999999, 1731.885, 1730.8210000000001, 1729.614, 1728.266, 1726.779, 1725.156, 1723.398, 1721.5079999999998, 1719.487, 1717.338, 1715.0620000000001, 1712.661, 1710.136, 1707.491, 1704.725, 1701.842, 1698.8429999999998, 1695.729, 1692.5020000000002, 1689.1629999999998, 1685.714, 1682.1570000000002, 1678.493, 1674.723, 1670.85, 1666.8729999999998, 1662.795, 1658.6170000000002, 1654.34, 1649.9660000000001, 1645.496, 1640.931, 1636.271, 1631.52, 1626.6770000000001, 1621.744, 1616.7220000000002, 1611.611, 1606.414, 1601.131, 1595.764, 1590.3129999999999, 1584.779, 1579.164, 1573.467, 1567.691, 1561.838, 1555.906, 1549.8970000000002, 1543.8120000000001, 1537.651, 1531.4170000000001, 1525.11, 1518.73, 1512.2779999999998, 1505.756, 1499.165, 1492.504, 1485.775, 1478.9779999999998, 1472.115, 1465.1860000000001, 1458.191, 1451.1329999999998, 1444.01, 1436.8239999999998, 1429.5770000000002, 1422.267, 1414.8970000000002, 1407.467, 1399.977, 1392.4289999999999, 1384.8220000000001, 1377.158, 1369.4370000000001, 1361.6589999999999, 1353.8270000000002, 1345.9389999999999, 1337.997, 1330.001, 1321.9520000000002, 1313.85, 1305.697, 1297.492, 1289.236, 1280.93, 1272.575, 1264.17, 1255.7169999999999, 1247.215, 1238.6660000000002, 1230.0710000000001, 1221.428, 1212.74, 1204.007, 1195.228, 1186.405, 1177.539, 1168.628, 1159.675, 1150.68, 1141.643, 1132.5639999999999, 1123.444, 1114.2839999999999, 1105.083, 1095.843, 1086.5639999999999, 1077.246, 1067.891, 1058.497, 1049.066, 1039.598, 1030.093, 1020.553, 1010.977, 1001.3660000000001, 991.72, 982.04, 972.326, 962.578, 952.797, 942.9839999999999, 933.138, 923.2610000000001, 913.352, 903.4119999999999, 893.442, 883.441, 873.4110000000001, 863.3510000000001, 853.262, 843.1439999999999, 832.998, 822.824, 812.623, 802.395, 792.1389999999999, 781.8580000000001, 771.551, 761.2180000000001, 750.8589999999999, 740.4760000000001, 730.069, 719.637, 709.182, 698.703, 688.202, 677.678, 667.1310000000001, 656.563, 645.974, 635.363, 624.731, 614.08, 603.408, 592.717, 582.006, 571.2769999999999, 560.529, 549.763, 538.979, 528.178, 517.36, 506.525, 495.67400000000004, 484.80699999999996, 473.925, 463.028, 452.115, 441.189, 430.249, 419.29400000000004, 408.327, 397.347, 386.355, 375.35, 364.334, 353.306, 342.26800000000003, 331.219, 320.16, 309.092, 298.014, 286.927, 275.832, 264.72900000000004, 253.618, 242.5, 231.37599999999998, 220.245, 209.107, 197.965, 186.817, 175.665, 164.50900000000001, 153.34799999999998, 142.185, 131.018, 119.85, 108.679, 97.507, 86.334, 75.16, 63.986000000000004, 52.813, 41.641000000000005, 30.47, 19.301, 8.135, -3.029, -14.189, -25.345, -36.496, -47.641999999999996, -58.783, -69.917, -81.045, -92.165, -103.277, -114.381, -125.476, -136.56, -147.635, -158.69799999999998, -169.75, -180.79, -191.81599999999997, -202.829, -213.828, -224.812, -235.78, -246.731, -257.666, -268.58299999999997, -279.481, -290.35900000000004, -301.218, -312.055, -322.87, -333.663, -344.43300000000005, -355.17800000000005, -365.898, -376.591, -387.25800000000004, -397.897, -408.506, -419.086, -429.635, -440.152, -450.635, -461.085, -471.5, -481.87800000000004, -492.219, -502.52099999999996, -512.783, -523.005, -533.184, -543.319, -553.41, -563.4540000000001, -573.451, -583.398, -593.295, -603.14, -612.931, -622.6669999999999, -632.347, -641.967, -651.528, -661.0260000000001, -670.461, -679.83, -689.132, -698.3639999999999, -707.5239999999999, -716.6110000000001, -725.622, -734.555, -743.4069999999999, -752.177, -760.8610000000001, -769.4580000000001, -777.9639999999999, -786.378, -794.695, -802.914, -811.0310000000001, -819.044, -826.949, -834.742, -842.421, -849.982, -857.421, -864.735, -871.919, -878.97, -885.883, -892.654, -899.279, -905.752, -912.069, -918.2239999999999, -924.212, -930.029, -935.668, -941.123, -946.387, -951.455, -956.319, -960.972, -965.408, -969.618, -973.5939999999999, -977.328, -980.811, -984.034, -986.987, -989.66, -992.0419999999999, -994.122, -995.8889999999999, -997.331, -998.433, -999.184, -999.568, -999.57, -999.176, -998.368, -997.13, -995.443, -993.2869999999999, -990.6419999999999, -987.487, -983.799, -979.554, -974.7280000000001, -969.294, -963.2260000000001, -956.4910000000001, -949.06, -940.9019999999999, -931.9810000000001, -922.263, -911.71, -900.2819999999999, -887.939, -874.6410000000001, -860.341, -844.995, -828.558, -810.982, -792.221, -772.225, -750.95, -728.3510000000001, -704.3839999999999, -679.012, -652.2, -623.9209999999999, -594.156, -562.894, -530.139, -495.907, -460.226, -423.14599999999996, -384.73199999999997, -345.065, -304.246, -262.394, -219.64, -176.127, -132.01, -87.448, -42.6, 2.374, 47.32, 92.096, 136.566, 180.61, 224.12099999999998, 267.005, 309.185, 350.592, 391.175, 430.89099999999996, 469.711, 507.61199999999997, 544.581, 580.61, 615.6990000000001, 649.852, 683.076, 715.3839999999999, 746.788, 777.306, 806.955, 835.753, 863.72, 890.877, 917.2439999999999, 942.842, 967.69, 991.925, 1015.221, 1037.944, 1059.998, 1081.401, 1102.172, 1122.329, 1141.889, 1160.87, 1179.286, 1197.156, 1214.493, 1231.312, 1247.628, 1263.454, 1278.803, 1293.6889999999999, 1308.123, 1322.118, 1335.685, 1348.835, 1361.578, 1373.9260000000002, 1385.8870000000002, 1397.4720000000002, 1408.69, 1419.55, 1430.06, 1440.2279999999998, 1450.0639999999999, 1459.5729999999999, 1468.765, 1477.646, 1486.223, 1494.5020000000002, 1502.4920000000002, 1510.1970000000001, 1517.624, 1524.78, 1531.6689999999999, 1538.2979999999998, 1544.67, 1550.793, 1556.6729999999998, 1562.3110000000001, 1567.713, 1572.885, 1577.832, 1582.556, 1587.0629999999999, 1591.356, 1595.44, 1599.319, 1602.996, 1606.474, 1609.759, 1612.852, 1615.7579999999998, 1618.479, 1621.019, 1623.382, 1625.569, 1627.585, 1629.431, 1631.111, 1632.628, 1633.983, 1635.181, 1636.223, 1637.111, 1637.849, 1638.4379999999999, 1638.881, 1639.18, 1639.338, 1639.356, 1639.237, 1638.9820000000002, 1638.594, 1638.075, 1637.4260000000002, 1636.65, 1635.7479999999998, 1634.7220000000002, 1633.5739999999998, 1632.306, 1630.918, 1629.414, 1627.7939999999999, 1626.0610000000001, 1624.215, 1622.2579999999998, 1620.192, 1618.0179999999998, 1615.737, 1613.352, 1610.862, 1608.271, 1605.578, 1602.786, 1599.895, 1596.9070000000002, 1593.8239999999998, 1590.645, 1587.3729999999998, 1584.0079999999998, 1580.5529999999999, 1577.007, 1573.372, 1569.649, 1565.84, 1561.944, 1557.964, 1553.9, 1549.753, 1545.524, 1541.214, 1536.8239999999998, 1532.356, 1527.809, 1523.185, 1518.485, 1513.7089999999998, 1508.859, 1503.935, 1498.9379999999999, 1493.868, 1488.7279999999998, 1483.517, 1478.236, 1472.8870000000002, 1467.4679999999998, 1461.984, 1456.432, 1450.8129999999999, 1445.13, 1439.381, 1433.57, 1427.695, 1421.756, 1415.7579999999998, 1409.6970000000001, 1403.575, 1397.394, 1391.1529999999998, 1384.854, 1378.496, 1372.082, 1365.61, 1359.082, 1352.4979999999998, 1345.859, 1339.1660000000002, 1332.418, 1325.618, 1318.764, 1311.858, 1304.9, 1297.89, 1290.83, 1283.72, 1276.56, 1269.351, 1262.093, 1254.787, 1247.432, 1240.031, 1232.583, 1225.089, 1217.548, 1209.963, 1202.3319999999999, 1194.657, 1186.938, 1179.175, 1171.369, 1163.52, 1155.629, 1147.697, 1139.723, 1131.7069999999999, 1123.652, 1115.556, 1107.42, 1099.245, 1091.031, 1082.778, 1074.487, 1066.1589999999999, 1057.7930000000001, 1049.39, 1040.95, 1032.474, 1023.962, 1015.415, 1006.8330000000001, 998.216, 989.565, 980.8789999999999, 972.16, 963.408, 954.623, 945.805, 936.955, 928.073, 919.16, 910.215, 901.24, 892.2339999999999, 883.198, 874.132, 865.0369999999999, 855.913, 846.76, 837.578, 828.3689999999999, 819.1310000000001, 809.867, 800.575, 791.257, 781.9119999999999, 772.541, 763.1439999999999, 753.721, 744.2739999999999, 734.801, 725.305, 715.784, 706.2389999999999, 696.67, 687.079, 677.465, 667.828, 658.169, 648.488, 638.785, 629.061, 619.316, 609.5509999999999, 599.765, 589.96, 580.135, 570.29, 560.427, 550.544, 540.644, 530.726, 520.789, 510.836, 500.865, 490.87800000000004, 480.875, 470.855, 460.82, 450.77, 440.704, 430.624, 420.529, 410.421, 400.29900000000004, 390.163, 380.015, 369.85400000000004, 359.681, 349.496, 339.3, 329.092, 318.874, 308.645, 298.406, 288.157, 277.899, 267.632, 257.357, 247.074, 236.782, 226.484, 216.178, 205.86599999999999, 195.547, 185.22299999999998, 174.894, 164.56, 154.221, 143.878, 133.531, 123.181, 112.829, 102.47399999999999, 92.117, 81.759, 71.4, 61.041000000000004, 50.681000000000004, 40.321999999999996, 29.965, 19.608, 9.254, -1.0979999999999999, -11.446, -21.791, -32.132, -42.468999999999994, -52.799, -63.123999999999995, -73.443, -83.755, -94.059, -104.354, -114.641, -124.919, -135.186, -145.442, -155.687, -165.92, -176.14, -186.347, -196.53900000000002, -206.71599999999998, -216.878, -227.02200000000002, -237.15, -247.25900000000001, -257.35, -267.42, -277.47, -287.498, -297.504, -307.487, -317.445, -327.378, -337.284, -347.164, -357.015, -366.836, -376.62800000000004, -386.38699999999994, -396.11400000000003, -405.80699999999996, -415.465, -425.086, -434.67, -444.215, -453.72, -463.18300000000005, -472.603, -481.978, -491.30800000000005, -500.589, -509.82199999999995, -519.004, -528.133, -537.2080000000001, -546.227, -555.189, -564.09, -572.93, -581.706, -590.4159999999999, -599.058, -607.63, -616.13, -624.554, -632.901, -641.168, -649.3530000000001, -657.452, -665.4630000000001, -673.383, -681.209, -688.938, -696.567, -704.091, -711.508, -718.814, -726.005, -733.078, -740.0269999999999, -746.85, -753.541, -760.095, -766.5089999999999, -772.7769999999999, -778.893, -784.8530000000001, -790.6510000000001, -796.28, -801.735, -807.0089999999999, -812.095, -816.9860000000001, -821.675, -826.154, -830.415, -834.449, -838.248, -841.802, -845.1010000000001, -848.1339999999999, -850.8919999999999, -853.363, -855.534, -857.393, -858.927, -860.122, -860.962, -861.432, -861.5169999999999, -861.198, -860.4580000000001, -859.2769999999999, -857.635, -855.5110000000001, -852.8810000000001, -849.722, -846.0089999999999, -841.7139999999999, -836.811, -831.27, -825.059, -818.145, -810.4939999999999, -802.071, -792.8380000000001, -782.755, -771.7810000000001, -759.8739999999999, -746.992, -733.087, -718.117, -702.035, -684.797, -666.357, -646.673, -625.706, -603.418, -579.781, -554.77, -528.368, -500.57099999999997, -471.385, -440.82800000000003, -408.93699999999995, -375.76, -341.36300000000006, -305.832, -269.26099999999997, -231.766, -193.472, -154.513, -115.02799999999999, -75.163, -35.061, 5.14, 45.303999999999995, 85.309, 125.041, 164.39700000000002, 203.28799999999998, 241.635, 279.374, 316.45099999999996, 352.82199999999995, 388.45300000000003, 423.32, 457.403, 490.69300000000004, 523.183, 554.874, 585.766, 615.868, 645.189, 673.7389999999999, 701.533, 728.5830000000001, 754.904, 780.5139999999999, 805.429, 829.665, 853.2389999999999, 876.1669999999999, 898.467, 920.155, 941.247, 961.76, 981.7080000000001, 1001.1060000000001, 1019.971, 1038.316, 1056.155, 1073.502, 1090.37, 1106.772, 1122.719, 1138.224, 1153.299, 1167.954, 1182.201, 1196.049, 1209.509, 1222.5910000000001, 1235.3039999999999, 1247.657, 1259.6580000000001, 1271.315, 1282.639, 1293.635, 1304.312, 1314.6760000000002, 1324.737, 1334.499, 1343.97, 1353.156, 1362.0629999999999, 1370.6979999999999, 1379.066, 1387.1729999999998, 1395.024, 1402.625, 1409.98, 1417.096, 1423.976, 1430.625, 1437.0479999999998, 1443.249, 1449.233, 1455.003, 1460.565, 1465.92, 1471.075, 1476.031, 1480.793, 1485.364, 1489.7479999999998, 1493.9470000000001, 1497.9660000000001, 1501.807, 1505.473, 1508.9679999999998, 1512.293, 1515.453, 1518.4489999999998, 1521.285, 1523.963, 1526.485, 1528.855, 1531.0729999999999, 1533.144, 1535.069, 1536.85, 1538.49, 1539.99, 1541.3529999999998, 1542.5810000000001, 1543.6760000000002, 1544.639, 1545.473, 1546.18, 1546.761, 1547.2179999999998, 1547.5529999999999, 1547.767, 1547.8629999999998, 1547.8410000000001, 1547.705, 1547.454, 1547.09, 1546.616, 1546.033, 1545.3410000000001, 1544.543, 1543.639, 1542.632, 1541.5220000000002, 1540.3110000000001, 1539.0, 1537.59, 1536.0829999999999, 1534.479, 1532.78, 1530.9879999999998, 1529.102, 1527.125, 1525.058, 1522.9, 1520.655, 1518.3210000000001, 1515.902, 1513.3970000000002, 1510.807, 1508.134, 1505.379, 1502.5420000000001, 1499.624, 1496.6270000000002, 1493.5510000000002, 1490.396, 1487.165, 1483.8570000000002, 1480.474, 1477.016, 1473.484, 1469.88, 1466.2020000000002, 1462.454, 1458.634, 1454.745, 1450.786, 1446.759, 1442.664, 1438.5020000000002, 1434.273, 1429.9779999999998, 1425.618, 1421.194, 1416.7060000000001, 1412.155, 1407.5410000000002, 1402.865, 1398.128, 1393.33, 1388.4720000000002, 1383.555, 1378.578, 1373.543, 1368.45, 1363.3, 1358.0929999999998, 1352.83, 1347.5120000000002, 1342.138, 1336.7089999999998, 1331.227, 1325.691, 1320.101, 1314.4589999999998, 1308.765, 1303.02, 1297.223, 1291.375, 1285.4769999999999, 1279.53, 1273.5330000000001, 1267.487, 1261.393, 1255.251, 1249.0610000000001, 1242.8239999999998, 1236.5410000000002, 1230.211, 1223.835, 1217.414, 1210.948, 1204.437, 1197.882, 1191.2830000000001, 1184.64, 1177.955, 1171.226, 1164.4560000000001, 1157.643, 1150.789, 1143.894, 1136.958, 1129.981, 1122.964, 1115.9080000000001, 1108.812, 1101.677, 1094.503, 1087.2910000000002, 1080.04, 1072.752, 1065.427, 1058.065, 1050.6660000000002, 1043.23, 1035.758, 1028.251, 1020.7080000000001, 1013.13, 1005.518, 997.87, 990.189, 982.4739999999999, 974.725, 966.943, 959.128, 951.28, 943.4, 935.488, 927.544, 919.568, 911.562, 903.5239999999999, 895.456, 887.3580000000001, 879.2289999999999, 871.071, 862.883, 854.666, 846.421, 838.1460000000001, 829.8430000000001, 821.513, 813.154, 804.768, 796.355, 787.914, 779.447, 770.954, 762.435, 753.8889999999999, 745.318, 736.722, 728.1010000000001, 719.455, 710.784, 702.0889999999999, 693.3710000000001, 684.628, 675.863, 667.074, 658.262, 649.428, 640.571, 631.692, 622.7919999999999, 613.87, 604.9259999999999, 595.962, 586.977, 577.972, 568.947, 559.901, 550.837, 541.753, 532.65, 523.528, 514.388, 505.22900000000004, 496.05300000000005, 486.85900000000004, 477.648, 468.42, 459.176, 449.915, 440.63699999999994, 431.344, 422.036, 412.712, 403.37300000000005, 394.02, 384.653, 375.27099999999996, 365.876, 356.468, 347.046, 337.61199999999997, 328.166, 318.707, 309.237, 299.756, 290.263, 280.76, 271.246, 261.723, 252.19, 242.648, 233.097, 223.537, 213.96900000000002, 204.394, 194.81099999999998, 185.22099999999998, 175.625, 166.023, 156.414, 146.80100000000002, 137.18200000000002, 127.559, 117.93299999999999, 108.302, 98.66799999999999, 89.03200000000001, 79.393, 69.753, 60.111999999999995, 50.468999999999994, 40.827, 31.184, 21.543000000000003, 11.902999999999999, 2.2640000000000002, -7.372000000000001, -17.005, -26.634, -36.26, -45.88, -55.496, -65.105, -74.708, -84.304, -93.891, -103.471, -113.04, -122.6, -132.15, -141.687, -151.213, -160.725, -170.22400000000002, -179.708, -189.17700000000002, -198.62900000000002, -208.06400000000002, -217.481, -226.87900000000002, -236.257, -245.614, -254.949, -264.26, -273.548, -282.811, -292.047, -301.255, -310.435, -319.585, -328.704, -337.79, -346.843, -355.86, -364.84, -373.783, -382.685, -391.54699999999997, -400.365, -409.139, -417.86699999999996, -426.54699999999997, -435.176, -443.754, -452.278, -460.74699999999996, -469.157, -477.50699999999995, -485.79400000000004, -494.017, -502.17199999999997, -510.25800000000004, -518.271, -526.2090000000001, -534.068, -541.847, -549.5419999999999, -557.149, -564.6659999999999, -572.089, -579.414, -586.637, -593.755, -600.764, -607.659, -614.436, -621.09, -627.617, -634.011, -640.266, -646.378, -652.341, -658.1489999999999, -663.794, -669.2710000000001, -674.573, -679.692, -684.62, -689.3489999999999, -693.8710000000001, -698.176, -702.2560000000001, -706.1, -709.698, -713.039, -716.112, -718.903, -721.4, -723.5889999999999, -725.457, -726.987, -728.163, -728.9680000000001, -729.385, -729.3939999999999, -728.9739999999999, -728.1060000000001, -726.7660000000001, -724.929, -722.572, -719.666, -716.184, -712.096, -707.372, -701.977, -695.877, -689.035, -681.415, -672.9760000000001, -663.678, -653.4780000000001, -642.3330000000001, -630.2, -617.035, -602.793, -587.433, -570.914, -553.197, -534.249, -514.0419999999999, -492.55400000000003, -469.77099999999996, -445.691, -420.32099999999997, -393.68300000000005, -365.81199999999995, -336.75800000000004, -306.586, -275.376, -243.222, -210.22799999999998, -176.51, -142.191, -107.396, -72.25399999999999, -36.89, -1.425, 34.025, 69.355, 104.46799999999999, 139.278, 173.71, 207.69799999999998, 241.188, 274.135, 306.502, 338.26099999999997, 369.38800000000003, 399.87, 429.695, 458.85900000000004, 487.35900000000004, 515.197, 542.377, 568.906, 594.7909999999999, 620.0419999999999, 644.6709999999999, 668.689, 692.107, 714.939, 737.197, 758.8960000000001, 780.047, 800.665, 820.762, 840.35, 859.444, 878.055, 896.196, 913.878, 931.1139999999999, 947.913, 964.288, 980.2489999999999, 995.807, 1010.971, 1025.752, 1040.1580000000001, 1054.2, 1067.885, 1081.223, 1094.221, 1106.888, 1119.232, 1131.26, 1142.979, 1154.396, 1165.518, 1176.3519999999999, 1186.904, 1197.18, 1207.187, 1216.9289999999999, 1226.414, 1235.645, 1244.629, 1253.37, 1261.874, 1270.144, 1278.187, 1286.005, 1293.604, 1300.988, 1308.162, 1315.128, 1321.891, 1328.454, 1334.8220000000001, 1340.9979999999998, 1346.986, 1352.7879999999998, 1358.408, 1363.849, 1369.114, 1374.207, 1379.13, 1383.886, 1388.477, 1392.9070000000002, 1397.1779999999999, 1401.293, 1405.254, 1409.0639999999999, 1412.725, 1416.239, 1419.609, 1422.836, 1425.924, 1428.874, 1431.6870000000001, 1434.3670000000002, 1436.915, 1439.3329999999999, 1441.6229999999998, 1443.787, 1445.826, 1447.7420000000002, 1449.537, 1451.213, 1452.771, 1454.213, 1455.54, 1456.755, 1457.8570000000002, 1458.849, 1459.733, 1460.509, 1461.18, 1461.745, 1462.2079999999999, 1462.568, 1462.828, 1462.9879999999998, 1463.05, 1463.015, 1462.884, 1462.6589999999999, 1462.339, 1461.9279999999999, 1461.424, 1460.8310000000001, 1460.148, 1459.376, 1458.517, 1457.5720000000001, 1456.5420000000001, 1455.4270000000001, 1454.229, 1452.9479999999999, 1451.585, 1450.142, 1448.619, 1447.017, 1445.336, 1443.578, 1441.743, 1439.8329999999999, 1437.848, 1435.7879999999998, 1433.655, 1431.4489999999998, 1429.171, 1426.8220000000001, 1424.402, 1421.912, 1419.3529999999998, 1416.726, 1414.03, 1411.2679999999998, 1408.4389999999999, 1405.5439999999999, 1402.5829999999999, 1399.558, 1396.469, 1393.317, 1390.101, 1386.8239999999998, 1383.484, 1380.0839999999998, 1376.622, 1373.101, 1369.52, 1365.88, 1362.182, 1358.4260000000002, 1354.612, 1350.741, 1346.8139999999999, 1342.8310000000001, 1338.7920000000001, 1334.6989999999998, 1330.5510000000002, 1326.348, 1322.0929999999998, 1317.7839999999999, 1313.422, 1309.008, 1304.542, 1300.025, 1295.4569999999999, 1290.838, 1286.1689999999999, 1281.45, 1276.682, 1271.865, 1266.999, 1262.086, 1257.124, 1252.115, 1247.059, 1241.9569999999999, 1236.808, 1231.613, 1226.372, 1221.087, 1215.756, 1210.381, 1204.962, 1199.498, 1193.992, 1188.442, 1182.849, 1177.214, 1171.536, 1165.817, 1160.056, 1154.254, 1148.411, 1142.527, 1136.6019999999999, 1130.638, 1124.634, 1118.5910000000001, 1112.508, 1106.386, 1100.226, 1094.027, 1087.7910000000002, 1081.516, 1075.205, 1068.856, 1062.469, 1056.047, 1049.588, 1043.0919999999999, 1036.5610000000001, 1029.995, 1023.3919999999999, 1016.755, 1010.0830000000001, 1003.3760000000001, 996.635, 989.86, 983.051, 976.209, 969.3330000000001, 962.424, 955.482, 948.507, 941.5, 934.461, 927.39, 920.2869999999999, 913.153, 905.987, 898.791, 891.564, 884.306, 877.018, 869.7, 862.352, 854.9739999999999, 847.567, 840.1310000000001, 832.665, 825.171, 817.6489999999999, 810.0980000000001, 802.5189999999999, 794.913, 787.278, 779.6160000000001, 771.928, 764.212, 756.4689999999999, 748.7, 740.904, 733.082, 725.235, 717.3610000000001, 709.4630000000001, 701.539, 693.59, 685.6160000000001, 677.618, 669.595, 661.548, 653.477, 645.383, 637.265, 629.124, 620.9590000000001, 612.7719999999999, 604.563, 596.331, 588.077, 579.8, 571.503, 563.183, 554.8430000000001, 546.482, 538.099, 529.697, 521.274, 512.831, 504.36800000000005, 495.88599999999997, 487.384, 478.86300000000006, 470.324, 461.765, 453.189, 444.594, 435.98199999999997, 427.352, 418.705, 410.04, 401.35900000000004, 392.662, 383.94800000000004, 375.218, 366.473, 357.712, 348.93699999999995, 340.14599999999996, 331.341, 322.522, 313.689, 304.842, 295.982, 287.10900000000004, 278.223, 269.32599999999996, 260.416, 251.49400000000003, 242.562, 233.618, 224.66400000000002, 215.7, 206.725, 197.74200000000002, 188.74900000000002, 179.748, 170.738, 161.721, 152.696, 143.664, 134.625, 125.58, 116.53, 107.47399999999999, 98.414, 89.34899999999999, 80.281, 71.209, 62.13399999999999, 53.058, 43.979, 34.9, 25.82, 16.739, 7.66, -1.4180000000000001, -10.495, -19.569000000000003, -28.64, -37.707, -46.769, -55.826, -64.877, -73.922, -82.959, -91.98700000000001, -101.006, -110.016, -119.014, -128.001, -136.975, -145.935, -154.881, -163.81, -172.72299999999998, -181.61900000000003, -190.495, -199.351, -208.18599999999998, -216.998, -225.787, -234.55, -243.287, -251.99599999999998, -260.675, -269.324, -277.94, -286.52099999999996, -295.067, -303.57599999999996, -312.045, -320.472, -328.856, -337.195, -345.48699999999997, -353.728, -361.918, -370.05400000000003, -378.13199999999995, -386.151, -394.108, -402.0, -409.82300000000004, -417.57599999999996, -425.255, -432.856, -440.376, -447.811, -455.157, -462.411, -469.56800000000004, -476.624, -483.575, -490.414, -497.13800000000003, -503.74, -510.216, -516.56, -522.765, -528.8240000000001, -534.732, -540.48, -546.062, -551.4680000000001, -556.691, -561.722, -566.5509999999999, -571.168, -575.563, -579.724, -583.64, -587.299, -590.686, -593.789, -596.592, -599.0790000000001, -601.234, -603.039, -604.475, -605.5219999999999, -606.159, -606.363, -606.111, -605.377, -604.135, -602.356, -600.011, -597.067, -593.491, -589.249, -584.305, -578.62, -572.153, -564.865, -556.7130000000001, -547.6569999999999, -537.65, -526.6519999999999, -514.622, -501.519, -487.306, -471.95099999999996, -455.42699999999996, -437.712, -418.79400000000004, -398.67, -377.348, -354.848, -331.20599999999996, -306.467, -280.692, -253.957, -226.345, -197.953, -168.88299999999998, -139.246, -109.152, -78.71300000000001, -48.038000000000004, -17.230999999999998, 13.609000000000002, 44.391999999999996, 75.036, 105.46799999999999, 135.623, 165.446, 194.89, 223.917, 252.493, 280.593, 308.198, 335.292, 361.866, 387.911, 413.425, 438.407, 462.85900000000004, 486.784, 510.18699999999995, 533.073, 555.451, 577.328, 598.714, 619.616, 639.9730000000001, 660.01, 679.5210000000001, 698.5880000000001, 717.221, 735.428, 753.221, 770.6080000000001, 787.6, 804.205, 820.432, 836.29, 851.788, 866.934, 881.7360000000001, 896.203, 910.341, 924.159, 937.664, 950.863, 963.762, 976.3689999999999, 988.69, 1000.7310000000001, 1012.498, 1023.997, 1035.234, 1046.215, 1056.944, 1067.427, 1077.6689999999999, 1087.675, 1097.45, 1106.999, 1116.325, 1125.433, 1134.328, 1143.013, 1151.492, 1159.77, 1167.849, 1175.734, 1183.4289999999999, 1190.9360000000001, 1198.259, 1205.401, 1212.366, 1219.156, 1225.774, 1232.224, 1238.508, 1244.629, 1250.589, 1256.392, 1262.04, 1267.535, 1272.879, 1278.076, 1283.127, 1288.0339999999999, 1292.8, 1297.427, 1301.917, 1306.272, 1310.494, 1314.5839999999998, 1318.545, 1322.379, 1326.088, 1329.672, 1333.135, 1336.477, 1339.7, 1342.805, 1345.796, 1348.672, 1351.435, 1354.088, 1356.63, 1359.065, 1361.392, 1363.614, 1365.7320000000002, 1367.746, 1369.6589999999999, 1371.4720000000002, 1373.185, 1374.8, 1376.318, 1377.74, 1379.068, 1380.3020000000001, 1381.443, 1382.493, 1383.453, 1384.3229999999999, 1385.105, 1385.799, 1386.4070000000002, 1386.9289999999999, 1387.3670000000002, 1387.721, 1387.9920000000002, 1388.181, 1388.289, 1388.317, 1388.265, 1388.135, 1387.9270000000001, 1387.642, 1387.28, 1386.8429999999998, 1386.332, 1385.746, 1385.0870000000002, 1384.355, 1383.5510000000002, 1382.6760000000002, 1381.73, 1380.715, 1379.63, 1378.477, 1377.255, 1375.9660000000001, 1374.611, 1373.1889999999999, 1371.7020000000002, 1370.149, 1368.5320000000002, 1366.851, 1365.1070000000002, 1363.3, 1361.431, 1359.5, 1357.5079999999998, 1355.455, 1353.342, 1351.1689999999999, 1348.9370000000001, 1346.6470000000002, 1344.2979999999998, 1341.891, 1339.4270000000001, 1336.906, 1334.328, 1331.695, 1329.006, 1326.2620000000002, 1323.463, 1320.61, 1317.703, 1314.7420000000002, 1311.729, 1308.663, 1305.5439999999999, 1302.374, 1299.152, 1295.879, 1292.556, 1289.181, 1285.757, 1282.2830000000001, 1278.76, 1275.188, 1271.567, 1267.8980000000001, 1264.181, 1260.4160000000002, 1256.603, 1252.744, 1248.838, 1244.886, 1240.888, 1236.843, 1232.754, 1228.619, 1224.4389999999999, 1220.215, 1215.9460000000001, 1211.5410000000002, 1207.184, 1202.7839999999999, 1198.3410000000001, 1193.855, 1189.326, 1184.755, 1180.142, 1175.487, 1170.79, 1166.052, 1161.2730000000001, 1156.453, 1151.5919999999999, 1146.691, 1141.75, 1136.769, 1131.748, 1126.688, 1121.589, 1116.451, 1111.2730000000001, 1106.058, 1100.8039999999999, 1095.512, 1090.182, 1084.815, 1079.41, 1073.9669999999999, 1068.488, 1062.972, 1057.4189999999999, 1051.83, 1046.205, 1040.5439999999999, 1034.846, 1029.114, 1023.345, 1017.5419999999999, 1011.704, 1005.83, 999.922, 993.98, 988.003, 981.992, 975.947, 969.8689999999999, 963.7560000000001, 957.6110000000001, 951.432, 945.22, 938.9760000000001, 932.698, 926.388, 920.046, 913.672, 907.265, 900.827, 894.357, 887.8560000000001, 881.323, 874.7589999999999, 868.164, 861.539, 854.882, 848.195, 841.4780000000001, 834.7310000000001, 827.953, 821.1460000000001, 814.309, 807.442, 800.547, 793.6210000000001, 786.6669999999999, 779.684, 772.672, 765.632, 758.563, 751.466, 744.34, 737.187, 730.0060000000001, 722.798, 715.561, 708.298, 701.008, 693.69, 686.346, 678.975, 671.577, 664.153, 656.703, 649.227, 641.725, 634.197, 626.644, 619.066, 611.462, 603.8340000000001, 596.18, 588.502, 580.799, 573.072, 565.321, 557.5459999999999, 549.747, 541.925, 534.0790000000001, 526.2090000000001, 518.317, 510.402, 502.464, 494.504, 486.522, 478.517, 470.491, 462.44199999999995, 454.37300000000005, 446.282, 438.17, 430.037, 421.884, 413.71, 405.51599999999996, 397.30300000000005, 389.069, 380.816, 372.54400000000004, 364.25300000000004, 355.94300000000004, 347.615, 339.26800000000003, 330.904, 322.522, 314.123, 305.70599999999996, 297.27299999999997, 288.823, 280.357, 271.876, 263.378, 254.86599999999999, 246.338, 237.796, 229.24, 220.67, 212.08700000000002, 203.49, 194.88099999999997, 186.25900000000001, 177.62599999999998, 168.981, 160.325, 151.659, 142.982, 134.296, 125.601, 116.897, 108.185, 99.465, 90.738, 82.005, 73.266, 64.521, 55.772, 47.019, 38.262, 29.503, 20.741, 11.979000000000001, 3.216, -5.547000000000001, -14.309000000000001, -23.069000000000003, -31.826, -40.579, -49.328, -58.071000000000005, -66.807, -75.536, -84.256, -92.96600000000001, -101.665, -110.352, -119.02600000000001, -127.684, -136.327, -144.951, -153.55700000000002, -162.142, -170.705, -179.243, -187.757, -196.24200000000002, -204.69799999999998, -213.123, -221.514, -229.87, -238.188, -246.465, -254.699, -262.888, -271.029, -279.119, -287.154, -295.133, -303.051, -310.904, -318.69, -326.405, -334.04400000000004, -341.603, -349.077, -356.463, -363.754, -370.94599999999997, -378.033, -385.009, -391.86699999999996, -398.603, -405.207, -411.673, -417.994, -424.16, -430.164, -435.995, -441.645, -447.101, -452.35400000000004, -457.39099999999996, -462.2, -466.76599999999996, -471.077, -475.116, -478.86699999999996, -482.314, -485.43699999999995, -488.217, -490.63300000000004, -492.663, -494.283, -495.467, -496.19, -496.42199999999997, -496.13300000000004, -495.291, -493.86400000000003, -491.816, -489.10900000000004, -485.705, -481.564, -476.645, -470.906, -464.305, -456.79900000000004, -448.348, -438.912, -428.452, -416.93699999999995, -404.339, -390.635, -375.811, -359.86400000000003, -342.79900000000004, -324.632, -305.395, -285.129, -263.887, -241.735, -218.75, -195.015, -170.62099999999998, -145.662, -120.23700000000001, -94.44, -68.365, -42.103, -15.738, 10.652999999999999, 37.0, 63.238, 89.31299999999999, 115.175, 140.784, 166.10299999999998, 191.10299999999998, 215.76, 240.055, 263.972, 287.499, 310.629, 333.35400000000004, 355.67199999999997, 377.582, 399.082, 420.176, 440.866, 461.156, 481.05, 500.55300000000005, 519.672, 538.41, 556.7769999999999, 574.7769999999999, 592.418, 609.706, 626.648, 643.252, 659.523, 675.4689999999999, 691.096, 706.4110000000001, 721.421, 736.1310000000001, 750.548, 764.678, 778.5269999999999, 792.102, 805.4069999999999, 818.448, 831.2310000000001, 843.7610000000001, 856.043, 868.082, 879.883, 891.451, 902.79, 913.904, 924.799, 935.4780000000001, 945.945, 956.205, 966.2610000000001, 976.118, 985.778, 995.2460000000001, 1004.5239999999999, 1013.617, 1022.5269999999999, 1031.258, 1039.813, 1048.195, 1056.406, 1064.45, 1072.329, 1080.047, 1087.605, 1095.007, 1102.255, 1109.351, 1116.298, 1123.098, 1129.753, 1136.266, 1142.639, 1148.873, 1154.971, 1160.935, 1166.767, 1172.469, 1178.042, 1183.488, 1188.81, 1194.008, 1199.085, 1204.042, 1208.881, 1213.603, 1218.21, 1222.703, 1227.085, 1231.355, 1235.517, 1239.57, 1243.517, 1247.359, 1251.096, 1254.732, 1258.265, 1261.6989999999998, 1265.0330000000001, 1268.269, 1271.4089999999999, 1274.453, 1277.402, 1280.258, 1283.022, 1285.694, 1288.275, 1290.768, 1293.171, 1295.488, 1297.7169999999999, 1299.861, 1301.921, 1303.896, 1305.788, 1307.598, 1309.327, 1310.975, 1312.5439999999999, 1314.033, 1315.444, 1316.7779999999998, 1318.035, 1319.2160000000001, 1320.3220000000001, 1321.3529999999998, 1322.31, 1323.194, 1324.006, 1324.746, 1325.414, 1326.0120000000002, 1326.54, 1326.9979999999998, 1327.388, 1327.71, 1327.964, 1328.151, 1328.271, 1328.326, 1328.315, 1328.24, 1328.1, 1327.896, 1327.63, 1327.3, 1326.908, 1326.454, 1325.94, 1325.364, 1324.7279999999998, 1324.031, 1323.276, 1322.461, 1321.588, 1320.6570000000002, 1319.668, 1318.621, 1317.5179999999998, 1316.358, 1315.1429999999998, 1313.871, 1312.5439999999999, 1311.162, 1309.726, 1308.235, 1306.69, 1305.0919999999999, 1303.441, 1301.737, 1299.981, 1298.172, 1296.312, 1294.4, 1292.438, 1290.424, 1288.36, 1286.245, 1284.0810000000001, 1281.867, 1279.604, 1277.292, 1274.931, 1272.522, 1270.0639999999999, 1267.559, 1265.006, 1262.406, 1259.759, 1257.065, 1254.3239999999998, 1251.537, 1248.705, 1245.826, 1242.902, 1239.932, 1236.9180000000001, 1233.858, 1230.754, 1227.606, 1224.414, 1221.177, 1217.897, 1214.5739999999998, 1211.2069999999999, 1207.797, 1204.344, 1200.849, 1197.3110000000001, 1193.731, 1190.109, 1186.445, 1182.74, 1178.993, 1175.205, 1171.375, 1167.505, 1163.594, 1159.643, 1155.651, 1151.619, 1147.547, 1143.435, 1139.2830000000001, 1135.0919999999999, 1130.862, 1126.5919999999999, 1122.2830000000001, 1117.9360000000001, 1113.55, 1109.125, 1104.661, 1100.16, 1095.62, 1091.0430000000001, 1086.427, 1081.774, 1077.083, 1072.355, 1067.59, 1062.787, 1057.948, 1053.072, 1048.1589999999999, 1043.2089999999998, 1038.223, 1033.2, 1028.142, 1023.047, 1017.916, 1012.75, 1007.547, 1002.309, 997.0360000000001, 991.727, 986.383, 981.0039999999999, 975.59, 970.14, 964.6560000000001, 959.138, 953.584, 947.997, 942.3739999999999, 936.7180000000001, 931.0269999999999, 925.303, 919.544, 913.752, 907.925, 902.065, 896.172, 890.245, 884.285, 878.291, 872.2639999999999, 866.205, 860.112, 853.9860000000001, 847.828, 841.6360000000001, 835.413, 829.1560000000001, 822.868, 816.546, 810.193, 803.808, 797.39, 790.941, 784.46, 777.947, 771.4019999999999, 764.825, 758.2180000000001, 751.578, 744.908, 738.206, 731.4730000000001, 724.709, 717.914, 711.0880000000001, 704.2310000000001, 697.3439999999999, 690.426, 683.4780000000001, 676.4989999999999, 669.49, 662.45, 655.3810000000001, 648.281, 641.1519999999999, 633.993, 626.804, 619.585, 612.337, 605.06, 597.753, 590.4169999999999, 583.052, 575.658, 568.235, 560.783, 553.303, 545.794, 538.257, 530.691, 523.097, 515.476, 507.82599999999996, 500.149, 492.44300000000004, 484.711, 476.95099999999996, 469.164, 461.35, 453.509, 445.64099999999996, 437.746, 429.82599999999996, 421.87800000000004, 413.905, 405.906, 397.881, 389.83099999999996, 381.756, 373.655, 365.529, 357.379, 349.204, 341.005, 332.782, 324.535, 316.265, 307.971, 299.655, 291.316, 282.954, 274.57, 266.165, 257.738, 249.29, 240.821, 232.332, 223.82299999999998, 215.294, 206.74599999999998, 198.179, 189.59400000000002, 180.99099999999999, 172.37, 163.733, 155.079, 146.409, 137.724, 129.024, 120.31, 111.583, 102.84299999999999, 94.09, 85.32700000000001, 76.55199999999999, 67.768, 58.975, 50.173, 41.365, 32.55, 23.73, 14.905, 6.077999999999999, -2.752, -11.583, -20.413, -29.241, -38.067, -46.887, -55.702, -64.509, -73.306, -82.09299999999999, -90.866, -99.624, -108.366, -117.088, -125.788, -134.465, -143.114, -151.735, -160.32299999999998, -168.877, -177.391, -185.864, -194.292, -202.671, -210.99599999999998, -219.264, -227.46900000000002, -235.608, -243.675, -251.66400000000002, -259.57, -267.387, -275.108, -282.725, -290.232, -297.621, -304.882, -312.007, -318.986, -325.809, -332.465, -338.941, -345.226, -351.30400000000003, -357.163, -362.785, -368.155, -373.254, -378.06300000000005, -382.561, -386.727, -390.535, -393.963, -396.981, -399.56199999999995, -401.676, -403.289, -404.36800000000005, -404.875, -404.774, -404.024, -402.586, -400.417, -397.473, -393.712, -389.093, -383.574, -377.116, -369.684, -361.246, -351.779, -341.26599999999996, -329.69699999999995, -317.073, -303.406, -288.719, -273.046, -256.432, -238.933, -220.614, -201.547, -181.80900000000003, -161.482, -140.65, -119.39399999999999, -97.79700000000001, -75.935, -53.881, -31.703000000000003, -9.463, 12.784, 34.986999999999995, 57.102, 79.09100000000001, 100.921, 122.56299999999999, 143.99200000000002, 165.18900000000002, 186.137, 206.82299999999998, 227.235, 247.365, 267.207, 286.756, 306.01, 324.966, 343.624, 361.98400000000004, 380.048, 397.816, 415.292, 432.478, 449.37699999999995, 465.994, 482.33099999999996, 498.39300000000003, 514.183, 529.707, 544.9680000000001, 559.97, 574.7180000000001, 589.216, 603.469, 617.48, 631.254, 644.795, 658.1080000000001, 671.196, 684.063, 696.7139999999999, 709.1519999999999, 721.3810000000001, 733.405, 745.227, 756.8510000000001, 768.2810000000001, 779.5189999999999, 790.569, 801.435, 812.1189999999999, 822.6239999999999, 832.954, 843.1110000000001, 853.0989999999999, 862.92, 872.577, 882.072, 891.408, 900.5880000000001, 909.6139999999999, 918.4889999999999, 927.2139999999999, 935.7919999999999, 944.2260000000001, 952.518, 960.669, 968.682, 976.558, 984.301, 991.9110000000001, 999.39, 1006.7410000000001, 1013.965, 1021.064, 1028.039, 1034.893, 1041.627, 1048.242, 1054.74, 1061.123, 1067.392, 1073.549, 1079.595, 1085.531, 1091.358, 1097.079, 1102.695, 1108.205, 1113.613, 1118.9189999999999, 1124.124, 1129.23, 1134.237, 1139.147, 1143.961, 1148.68, 1153.3039999999999, 1157.836, 1162.276, 1166.625, 1170.883, 1175.053, 1179.134, 1183.128, 1187.036, 1190.859, 1194.597, 1198.251, 1201.822, 1205.3110000000001, 1208.718, 1212.046, 1215.2930000000001, 1218.461, 1221.552, 1224.5639999999999, 1227.5, 1230.36, 1233.144, 1235.853, 1238.488, 1241.05, 1243.539, 1245.9560000000001, 1248.3010000000002, 1250.576, 1252.78, 1254.914, 1256.979, 1258.975, 1260.903, 1262.763, 1264.557, 1266.2839999999999, 1267.945, 1269.5410000000002, 1271.0710000000001, 1272.537, 1273.9389999999999, 1275.278, 1276.553, 1277.766, 1278.917, 1280.006, 1281.0330000000001, 1282.0, 1282.907, 1283.753, 1284.54, 1285.268, 1285.9360000000001, 1286.547, 1287.099, 1287.594, 1288.032, 1288.412, 1288.736, 1289.004, 1289.2160000000001, 1289.372, 1289.474, 1289.52, 1289.512, 1289.45, 1289.3339999999998, 1289.164, 1288.941, 1288.6660000000002, 1288.337, 1287.9560000000001, 1287.5230000000001, 1287.039, 1286.502, 1285.915, 1285.276, 1284.587, 1283.848, 1283.058, 1282.218, 1281.329, 1280.39, 1279.402, 1278.365, 1277.28, 1276.146, 1274.964, 1273.733, 1272.455, 1271.129, 1269.756, 1268.336, 1266.869, 1265.355, 1263.795, 1262.188, 1260.535, 1258.836, 1257.0910000000001, 1255.3010000000002, 1253.465, 1251.5839999999998, 1249.6580000000001, 1247.687, 1245.672, 1243.612, 1241.507, 1239.359, 1237.1660000000002, 1234.9289999999999, 1232.649, 1230.325, 1227.958, 1225.547, 1223.093, 1220.596, 1218.057, 1215.474, 1212.849, 1210.182, 1207.472, 1204.72, 1201.9260000000002, 1199.09, 1196.213, 1193.2930000000001, 1190.3319999999999, 1187.33, 1184.286, 1181.201, 1178.075, 1174.9080000000001, 1171.7, 1168.451, 1165.161, 1161.8310000000001, 1158.46, 1155.049, 1151.598, 1148.106, 1144.575, 1141.003, 1137.391, 1133.739, 1130.048, 1126.317, 1122.546, 1118.736, 1114.886, 1110.997, 1107.068, 1103.1, 1099.093, 1095.047, 1090.962, 1086.838, 1082.675, 1078.473, 1074.232, 1069.953, 1065.635, 1061.278, 1056.883, 1052.4489999999998, 1047.976, 1043.4660000000001, 1038.9160000000002, 1034.329, 1029.703, 1025.039, 1020.337, 1015.597, 1010.818, 1006.002, 1001.1469999999999, 996.255, 991.324, 986.3560000000001, 981.3489999999999, 976.305, 971.2230000000001, 966.1030000000001, 960.946, 955.75, 950.5169999999999, 945.2460000000001, 939.938, 934.592, 929.2080000000001, 923.7860000000001, 918.327, 912.831, 907.297, 901.725, 896.1160000000001, 890.4689999999999, 884.785, 879.063, 873.303, 867.507, 861.672, 855.801, 849.8919999999999, 843.945, 837.961, 831.94, 825.8810000000001, 819.784, 813.65, 807.4789999999999, 801.2710000000001, 795.025, 788.7410000000001, 782.42, 776.062, 769.6669999999999, 763.2330000000001, 756.763, 750.255, 743.71, 737.127, 730.507, 723.8489999999999, 717.154, 710.422, 703.6519999999999, 696.845, 690.0, 683.118, 676.199, 669.242, 662.248, 655.216, 648.1469999999999, 641.04, 633.896, 626.715, 619.496, 612.24, 604.947, 597.616, 590.248, 582.842, 575.399, 567.919, 560.4019999999999, 552.847, 545.255, 537.626, 529.9590000000001, 522.256, 514.515, 506.73699999999997, 498.923, 491.07099999999997, 483.18199999999996, 475.25699999999995, 467.29400000000004, 459.295, 451.259, 443.18699999999995, 435.07800000000003, 426.93300000000005, 418.751, 410.533, 402.279, 393.98900000000003, 385.663, 377.30199999999996, 368.904, 360.472, 352.004, 343.501, 334.963, 326.39, 317.783, 309.142, 300.466, 291.757, 283.015, 274.23900000000003, 265.431, 256.59, 247.717, 238.812, 229.87599999999998, 220.90900000000002, 211.912, 202.88400000000001, 193.828, 184.74200000000002, 175.62900000000002, 166.487, 157.319, 148.125, 138.905, 129.661, 120.39299999999999, 111.102, 101.789, 92.456, 83.103, 73.73100000000001, 64.343, 54.938, 45.519, 36.088, 26.645, 17.192999999999998, 7.733, -1.733, -11.202, -20.671999999999997, -30.141, -39.606, -49.06399999999999, -58.513000000000005, -67.94800000000001, -77.368, -86.76700000000001, -96.14299999999999, -105.491, -114.806, -124.083, -133.31799999999998, -142.504, -151.636, -160.707, -169.71, -178.638, -187.482, -196.234, -204.88400000000001, -213.422, -221.83599999999998, -230.11599999999999, -238.248, -246.21900000000002, -254.013, -261.613, -269.003, -276.164, -283.075, -289.714, -296.057, -302.079, -307.753, -313.048, -317.934, -322.377, -326.341, -329.787, -332.67699999999996, -334.969, -336.62, -337.585, -337.82, -337.279, -335.91900000000004, -333.69699999999995, -330.574, -326.515, -321.48900000000003, -315.473, -308.452, -300.42, -291.379, -281.345, -270.344, -258.408, -245.584, -231.926, -217.49200000000002, -202.34900000000002, -186.567, -170.21599999999998, -153.369, -136.095, -118.463, -100.536, -82.376, -64.03699999999999, -45.571999999999996, -27.026, -8.44, 10.147, 28.703000000000003, 47.2, 65.613, 83.919, 102.101, 120.14200000000001, 138.029, 155.75, 173.297, 190.66, 207.835, 224.815, 241.59799999999998, 258.17900000000003, 274.607, 290.73, 306.699, 322.462, 338.019, 353.37199999999996, 368.522, 383.469, 398.216, 412.764, 427.11400000000003, 441.269, 455.231, 469.00300000000004, 482.586, 495.98199999999997, 509.195, 522.226, 535.0790000000001, 547.754, 560.256, 572.586, 584.746, 596.74, 608.569, 620.236, 631.743, 643.092, 654.2869999999999, 665.328, 676.2180000000001, 686.959, 697.553, 708.003, 718.31, 728.477, 738.5039999999999, 748.3960000000001, 758.1519999999999, 767.775, 777.2669999999999, 786.63, 795.865, 804.9739999999999, 813.9580000000001, 822.82, 831.561, 840.182, 848.685, 857.072, 865.3430000000001, 873.5010000000001, 881.547, 889.482, 897.307, 905.0239999999999, 912.6339999999999, 920.138, 927.538, 934.835, 942.03, 949.1239999999999, 956.118, 963.013, 969.811, 976.512, 983.118, 989.63, 996.048, 1002.3739999999999, 1008.6089999999999, 1014.753, 1020.807, 1026.7730000000001, 1032.651, 1038.442, 1044.147, 1049.767, 1055.302, 1060.754, 1066.124, 1071.411, 1076.617, 1081.743, 1086.788, 1091.755, 1096.644, 1101.455, 1106.1889999999999, 1110.847, 1115.4289999999999, 1119.9360000000001, 1124.369, 1128.728, 1133.015, 1137.228, 1141.37, 1145.44, 1149.44, 1153.37, 1157.229, 1161.02, 1164.742, 1168.396, 1171.983, 1175.502, 1178.955, 1182.3410000000001, 1185.662, 1188.9180000000001, 1192.109, 1195.236, 1198.3, 1201.299, 1204.236, 1207.111, 1209.923, 1212.674, 1215.363, 1217.991, 1220.559, 1223.067, 1225.515, 1227.903, 1230.233, 1232.504, 1234.7160000000001, 1236.871, 1238.968, 1241.007, 1242.99, 1244.9160000000002, 1246.785, 1248.599, 1250.357, 1252.059, 1253.7060000000001, 1255.298, 1256.836, 1258.319, 1259.749, 1261.124, 1262.4460000000001, 1263.715, 1264.931, 1266.094, 1267.205, 1268.263, 1269.27, 1270.225, 1271.128, 1271.98, 1272.78, 1273.53, 1274.23, 1274.879, 1275.4769999999999, 1276.026, 1276.525, 1276.974, 1277.374, 1277.725, 1278.026, 1278.279, 1278.483, 1278.639, 1278.746, 1278.805, 1278.816, 1278.78, 1278.695, 1278.5639999999999, 1278.384, 1278.1580000000001, 1277.885, 1277.565, 1277.198, 1276.7839999999999, 1276.3239999999998, 1275.818, 1275.265, 1274.667, 1274.022, 1273.3319999999999, 1272.596, 1271.8139999999999, 1270.987, 1270.115, 1269.197, 1268.235, 1267.2269999999999, 1266.174, 1265.077, 1263.935, 1262.748, 1261.517, 1260.242, 1258.922, 1257.558, 1256.149, 1254.697, 1253.201, 1251.66, 1250.076, 1248.448, 1246.777, 1245.062, 1243.303, 1241.501, 1239.656, 1237.767, 1235.8339999999998, 1233.859, 1231.84, 1229.779, 1227.674, 1225.526, 1223.335, 1221.101, 1218.825, 1216.505, 1214.143, 1211.738, 1209.29, 1206.799, 1204.266, 1201.69, 1199.0710000000001, 1196.41, 1193.7060000000001, 1190.96, 1188.171, 1185.34, 1182.4660000000001, 1179.55, 1176.5910000000001, 1173.589, 1170.546, 1167.4589999999998, 1164.3310000000001, 1161.16, 1157.9460000000001, 1154.69, 1151.391, 1148.05, 1144.667, 1141.241, 1137.7730000000001, 1134.262, 1130.708, 1127.112, 1123.474, 1119.7930000000001, 1116.069, 1112.303, 1108.494, 1104.642, 1100.748, 1096.8110000000001, 1092.8310000000001, 1088.809, 1084.743, 1080.635, 1076.484, 1072.289, 1068.052, 1063.772, 1059.448, 1055.0819999999999, 1050.672, 1046.219, 1041.723, 1037.183, 1032.6, 1027.973, 1023.303, 1018.5889999999999, 1013.831, 1009.03, 1004.185, 999.295, 994.362, 989.385, 984.3639999999999, 979.298, 974.188, 969.034, 963.835, 958.592, 953.304, 947.971, 942.5939999999999, 937.171, 931.704, 926.191, 920.633, 915.03, 909.3810000000001, 903.687, 897.947, 892.1610000000001, 886.33, 880.452, 874.528, 868.558, 862.5419999999999, 856.4789999999999, 850.37, 844.2139999999999, 838.0110000000001, 831.7610000000001, 825.4639999999999, 819.1189999999999, 812.7280000000001, 806.288, 799.801, 793.2669999999999, 786.684, 780.053, 773.3739999999999, 766.6469999999999, 759.8710000000001, 753.046, 746.173, 739.25, 732.279, 725.258, 718.188, 711.068, 703.898, 696.679, 689.409, 682.0889999999999, 674.7189999999999, 667.298, 659.827, 652.304, 644.731, 637.106, 629.43, 621.703, 613.923, 606.092, 598.2090000000001, 590.274, 582.286, 574.246, 566.154, 558.008, 549.81, 541.558, 533.254, 524.895, 516.484, 508.019, 499.5, 490.92699999999996, 482.3, 473.619, 464.88300000000004, 456.094, 447.25, 438.351, 429.399, 420.39099999999996, 411.329, 402.212, 393.041, 383.814, 374.534, 365.19800000000004, 355.80800000000005, 346.36300000000006, 336.86400000000003, 327.311, 317.704, 308.04200000000003, 298.327, 288.559, 278.737, 268.862, 258.935, 248.955, 238.924, 228.842, 218.709, 208.52599999999998, 198.294, 188.014, 177.68599999999998, 167.31099999999998, 156.891, 146.42600000000002, 135.918, 125.369, 114.779, 104.15, 93.485, 82.786, 72.053, 61.291000000000004, 50.501000000000005, 39.687, 28.851, 17.997, 7.127999999999999, -3.75, -14.634, -25.519000000000002, -36.399, -47.269, -58.123000000000005, -68.952, -79.75, -90.508, -101.21700000000001, -111.867, -122.447, -132.945, -143.34799999999998, -153.641, -163.809, -173.835, -183.7, -193.38299999999998, -202.861, -212.112, -221.108, -229.82, -238.21900000000002, -246.269, -253.935, -261.17900000000003, -267.959, -274.233, -279.954, -285.075, -289.54900000000004, -293.32599999999996, -296.355, -298.591, -299.986, -300.498, -300.089, -298.728, -296.39099999999996, -293.063, -288.737, -283.418, -277.12, -269.869, -261.698, -252.649, -242.773, -232.125, -220.764, -208.752, -196.15, -183.023, -169.43, -155.431, -141.08, -126.43, -111.52799999999999, -96.421, -81.14699999999999, -65.745, -50.248000000000005, -34.684, -19.082, -3.464, 12.147, 27.734, 43.281000000000006, 58.772, 74.195, 89.54, 104.796, 119.956, 135.013, 149.96, 164.792, 179.50400000000002, 194.09400000000002, 208.558, 222.894, 237.1, 251.173, 265.113, 278.91900000000004, 292.59, 306.127, 319.528, 332.79400000000004, 345.925, 358.92199999999997, 371.784, 384.514, 397.111, 409.57599999999996, 421.91, 434.115, 446.191, 458.139, 469.96, 481.656, 493.227, 504.675, 516.001, 527.205, 538.29, 549.257, 560.106, 570.839, 581.456, 591.96, 602.352, 612.631, 622.8009999999999, 632.861, 642.813, 652.658, 662.398, 672.033, 681.564, 690.992, 700.319, 709.545, 718.672, 727.701, 736.632, 745.466, 754.205, 762.8489999999999, 771.4, 779.8580000000001, 788.2239999999999, 796.4989999999999, 804.684, 812.78, 820.7869999999999, 828.707, 836.54, 844.2869999999999, 851.949, 859.5260000000001, 867.02, 874.431, 881.76, 889.007, 896.174, 903.26, 910.2669999999999, 917.196, 924.046, 930.819, 937.515, 944.135, 950.679, 957.1489999999999, 963.544, 969.8660000000001, 976.1139999999999, 982.29, 988.393, 994.426, 1000.387, 1006.278, 1012.0980000000001, 1017.85, 1023.5319999999999, 1029.146, 1034.692, 1040.171, 1045.5819999999999, 1050.927, 1056.2060000000001, 1061.4189999999999, 1066.567, 1071.65, 1076.6680000000001, 1081.623, 1086.514, 1091.3419999999999, 1096.107, 1100.81, 1105.45, 1110.029, 1114.547, 1119.003, 1123.399, 1127.735, 1132.011, 1136.2269999999999, 1140.384, 1144.482, 1148.522, 1152.503, 1156.4260000000002, 1160.2910000000002, 1164.099, 1167.85, 1171.5439999999999, 1175.182, 1178.763, 1182.288, 1185.758, 1189.172, 1192.53, 1195.8339999999998, 1199.083, 1202.278, 1205.4180000000001, 1208.504, 1211.537, 1214.516, 1217.442, 1220.3139999999999, 1223.134, 1225.901, 1228.615, 1231.277, 1233.887, 1236.4460000000001, 1238.952, 1241.407, 1243.8110000000001, 1246.164, 1248.465, 1250.7160000000001, 1252.9160000000002, 1255.066, 1257.1660000000002, 1259.215, 1261.214, 1263.164, 1265.0639999999999, 1266.914, 1268.715, 1270.4669999999999, 1272.1689999999999, 1273.823, 1275.428, 1276.984, 1278.492, 1279.951, 1281.362, 1282.724, 1284.039, 1285.305, 1286.524, 1287.694, 1288.817, 1289.893, 1290.921, 1291.902, 1292.835, 1293.721, 1294.56, 1295.3519999999999, 1296.097, 1296.796, 1297.447, 1298.052, 1298.61, 1299.122, 1299.587, 1300.005, 1300.378, 1300.704, 1300.983, 1301.2169999999999, 1301.404, 1301.545, 1301.641, 1301.69, 1301.693, 1301.651, 1301.562, 1301.428, 1301.248, 1301.022, 1300.751, 1300.433, 1300.0710000000001, 1299.662, 1299.208, 1298.708, 1298.163, 1297.572, 1296.935, 1296.253, 1295.525, 1294.752, 1293.933, 1293.069, 1292.1589999999999, 1291.204, 1290.203, 1289.156, 1288.0639999999999, 1286.927, 1285.744, 1284.515, 1283.24, 1281.92, 1280.555, 1279.143, 1277.6860000000001, 1276.183, 1274.635, 1273.04, 1271.4, 1269.714, 1267.982, 1266.204, 1264.379, 1262.509, 1260.593, 1258.631, 1256.622, 1254.567, 1252.4660000000001, 1250.318, 1248.124, 1245.883, 1243.596, 1241.262, 1238.882, 1236.454, 1233.98, 1231.4589999999998, 1228.89, 1226.275, 1223.612, 1220.902, 1218.145, 1215.34, 1212.488, 1209.588, 1206.64, 1203.644, 1200.6, 1197.508, 1194.368, 1191.18, 1187.943, 1184.657, 1181.323, 1177.94, 1174.508, 1171.027, 1167.497, 1163.917, 1160.288, 1156.61, 1152.881, 1149.103, 1145.275, 1141.396, 1137.4669999999999, 1133.488, 1129.4569999999999, 1125.376, 1121.244, 1117.0610000000001, 1112.826, 1108.54, 1104.202, 1099.812, 1095.37, 1090.875, 1086.328, 1081.729, 1077.076, 1072.371, 1067.612, 1062.799, 1057.933, 1053.013, 1048.039, 1043.01, 1037.927, 1032.788, 1027.595, 1022.346, 1017.0419999999999, 1011.682, 1006.2660000000001, 1000.793, 995.2639999999999, 989.678, 984.035, 978.334, 972.576, 966.76, 960.885, 954.952, 948.96, 942.909, 936.798, 930.628, 924.3969999999999, 918.107, 911.755, 905.342, 898.8689999999999, 892.3330000000001, 885.735, 879.075, 872.352, 865.566, 858.717, 851.803, 844.826, 837.784, 830.677, 823.5039999999999, 816.2660000000001, 808.962, 801.591, 794.154, 786.648, 779.076, 771.435, 763.725, 755.946, 748.0980000000001, 740.18, 732.191, 724.132, 716.0010000000001, 707.798, 699.5239999999999, 691.176, 682.7560000000001, 674.2610000000001, 665.693, 657.05, 648.332, 639.538, 630.668, 621.721, 612.698, 603.597, 594.418, 585.16, 575.823, 566.406, 556.909, 547.332, 537.674, 527.934, 518.112, 508.207, 498.22, 488.148, 477.99300000000005, 467.754, 457.42900000000003, 447.02, 436.524, 425.94300000000004, 415.275, 404.52099999999996, 393.67900000000003, 382.75, 371.73400000000004, 360.63, 349.43800000000005, 338.158, 326.79, 315.335, 303.791, 292.16, 280.441, 268.635, 256.743, 244.765, 232.701, 220.553, 208.321, 196.00799999999998, 183.613, 171.14, 158.589, 145.963, 133.264, 120.495, 107.66, 94.76100000000001, 81.803, 68.79, 55.728, 42.621, 29.478, 16.303, 3.1069999999999998, -10.103, -23.316, -36.522, -49.707, -62.857, -75.959, -88.993, -101.94200000000001, -114.78299999999999, -127.495, -140.05, -152.421, -164.576, -176.482, -188.101, -199.392, -210.31400000000002, -220.81900000000002, -230.857, -240.37599999999998, -249.32299999999998, -257.642, -265.276, -272.168, -278.264, -283.512, -287.865, -291.281, -293.726, -295.172, -295.60400000000004, -295.015, -293.411, -290.80400000000003, -287.22, -282.692, -277.259, -270.969, -263.874, -256.029, -247.488, -238.31099999999998, -228.55200000000002, -218.268, -207.51, -196.328, -184.771, -172.88299999999998, -160.704, -148.27200000000002, -135.623, -122.787, -109.794, -96.669, -83.43799999999999, -70.12, -56.736000000000004, -43.303000000000004, -29.836, -16.35, -2.8560000000000003, 10.633, 24.107, 37.558, 50.977, 64.358, 77.693, 90.978, 104.206, 117.374, 130.47799999999998, 143.513, 156.47799999999998, 169.368, 182.183, 194.919, 207.575, 220.149, 232.64, 245.047, 257.369, 269.60400000000004, 281.753, 293.815, 305.789, 317.675, 329.473, 341.18300000000005, 352.80400000000003, 364.337, 375.782, 387.13800000000003, 398.407, 409.587, 420.68, 431.686, 442.605, 453.43699999999995, 464.184, 474.844, 485.41900000000004, 495.909, 506.315, 516.637, 526.875, 537.03, 547.1030000000001, 557.0930000000001, 567.002, 576.83, 586.577, 596.245, 605.832, 615.341, 624.771, 634.123, 643.398, 652.595, 661.717, 670.762, 679.7310000000001, 688.6260000000001, 697.446, 706.192, 714.865, 723.465, 731.992, 740.446, 748.83, 757.1419999999999, 765.383, 773.554, 781.655, 789.687, 797.65, 805.544, 813.37, 821.1289999999999, 828.82, 836.444, 844.002, 851.4939999999999, 858.92, 866.28, 873.576, 880.807, 887.9739999999999, 895.077, 902.1160000000001, 909.0930000000001, 916.0060000000001, 922.857, 929.6460000000001, 936.373, 943.039, 949.6439999999999, 956.188, 962.671, 969.0939999999999, 975.457, 981.76, 988.005, 994.19, 1000.316, 1006.3839999999999, 1012.3939999999999, 1018.346, 1024.24, 1030.077, 1035.856, 1041.579, 1047.245, 1052.854, 1058.4080000000001, 1063.905, 1069.347, 1074.733, 1080.065, 1085.3410000000001, 1090.562, 1095.728, 1100.84, 1105.8980000000001, 1110.902, 1115.853, 1120.749, 1125.5919999999999, 1130.382, 1135.119, 1139.803, 1144.434, 1149.013, 1153.539, 1158.013, 1162.435, 1166.806, 1171.124, 1175.391, 1179.607, 1183.771, 1187.884, 1191.9460000000001, 1195.9569999999999, 1199.9180000000001, 1203.827, 1207.687, 1211.496, 1215.255, 1218.963, 1222.622, 1226.231, 1229.79, 1233.299, 1236.759, 1240.1689999999999, 1243.53, 1246.8419999999999, 1250.105, 1253.318, 1256.483, 1259.598, 1262.665, 1265.683, 1268.653, 1271.573, 1274.4460000000001, 1277.269, 1280.045, 1282.772, 1285.451, 1288.0819999999999, 1290.664, 1293.1989999999998, 1295.685, 1298.124, 1300.515, 1302.857, 1305.152, 1307.4, 1309.599, 1311.751, 1313.855, 1315.911, 1317.92, 1319.881, 1321.795, 1323.661, 1325.479, 1327.25, 1328.974, 1330.65, 1332.2779999999998, 1333.86, 1335.3929999999998, 1336.879, 1338.318, 1339.71, 1341.0539999999999, 1342.35, 1343.599, 1344.8, 1345.954, 1347.0610000000001, 1348.12, 1349.131, 1350.095, 1351.0120000000002, 1351.88, 1352.701, 1353.475, 1354.201, 1354.879, 1355.509, 1356.0910000000001, 1356.626, 1357.1129999999998, 1357.5520000000001, 1357.942, 1358.285, 1358.58, 1358.8270000000002, 1359.025, 1359.175, 1359.277, 1359.33, 1359.335, 1359.2920000000001, 1359.2, 1359.059, 1358.869, 1358.631, 1358.3429999999998, 1358.007, 1357.622, 1357.1870000000001, 1356.704, 1356.17, 1355.588, 1354.9560000000001, 1354.274, 1353.5420000000001, 1352.761, 1351.9289999999999, 1351.0479999999998, 1350.116, 1349.134, 1348.102, 1347.019, 1345.885, 1344.701, 1343.465, 1342.1789999999999, 1340.8410000000001, 1339.4520000000002, 1338.011, 1336.519, 1334.974, 1333.378, 1331.73, 1330.03, 1328.277, 1326.471, 1324.6129999999998, 1322.7020000000002, 1320.737, 1318.72, 1316.649, 1314.524, 1312.345, 1310.113, 1307.826, 1305.484, 1303.088, 1300.637, 1298.131, 1295.57, 1292.953, 1290.281, 1287.553, 1284.768, 1281.927, 1279.03, 1276.076, 1273.0639999999999, 1269.995, 1266.869, 1263.685, 1260.442, 1257.141, 1253.782, 1250.363, 1246.886, 1243.349, 1239.752, 1236.095, 1232.377, 1228.599, 1224.76, 1220.86, 1216.8980000000001, 1212.874, 1208.788, 1204.639, 1200.427, 1196.152, 1191.813, 1187.41, 1182.943, 1178.412, 1173.815, 1169.152, 1164.424, 1159.629, 1154.768, 1149.839, 1144.844, 1139.78, 1134.6480000000001, 1129.447, 1124.1760000000002, 1118.837, 1113.427, 1107.9460000000001, 1102.395, 1096.772, 1091.077, 1085.309, 1079.468, 1073.5539999999999, 1067.566, 1061.503, 1055.365, 1049.152, 1042.862, 1036.496, 1030.052, 1023.53, 1016.93, 1010.2510000000001, 1003.4910000000001, 996.6519999999999, 989.7310000000001, 982.7289999999999, 975.645, 968.4780000000001, 961.227, 953.8919999999999, 946.471, 938.965, 931.373, 923.693, 915.926, 908.07, 900.1239999999999, 892.0880000000001, 883.961, 875.742, 867.43, 859.025, 850.5260000000001, 841.931, 833.24, 824.452, 815.566, 806.582, 797.497, 788.312, 779.025, 769.6360000000001, 760.1419999999999, 750.544, 740.841, 731.0310000000001, 721.113, 711.086, 700.949, 690.701, 680.341, 669.868, 659.2810000000001, 648.578, 637.758, 626.82, 615.764, 604.587, 593.289, 581.869, 570.325, 558.656, 546.861, 534.939, 522.889, 510.709, 498.398, 485.95599999999996, 473.381, 460.67199999999997, 447.829, 434.849, 421.733, 408.47900000000004, 395.087, 381.556, 367.88599999999997, 354.075, 340.12300000000005, 326.032, 311.79900000000004, 297.426, 282.913, 268.26, 253.468, 238.54, 223.475, 208.27700000000002, 192.94799999999998, 177.49099999999999, 161.909, 146.207, 130.389, 114.463, 98.434, 82.31, 66.101, 49.818000000000005, 33.472, 17.077, 0.649, -15.795, -32.233000000000004, -48.644, -65.001, -81.277, -97.439, -113.45100000000001, -129.274, -144.864, -160.175, -175.155, -189.748, -203.896, -217.53599999999997, -230.60299999999998, -243.032, -254.75400000000002, -265.70599999999996, -275.823, -285.045, -293.319, -300.599, -306.847, -312.035, -316.149, -319.18, -321.137, -322.033, -321.89599999999996, -320.759, -318.663, -315.653, -311.781, -307.099, -301.66, -295.519, -288.72900000000004, -281.342, -273.409, -264.976, -256.089, -246.79, -237.118, -227.112, -216.803, -206.22400000000002, -195.40400000000002, -184.37, -173.144, -161.751, -150.21, -138.54, -126.759, -114.88, -102.906, -90.89, -78.803, -66.668, -54.497, -42.299, -30.08, -17.849, -5.612, 6.624, 18.852999999999998, 31.070999999999998, 43.273, 55.45399999999999, 67.611, 79.74, 91.837, 103.9, 115.926, 127.913, 139.858, 151.759, 163.614, 175.421, 187.18, 198.889, 210.545, 222.149, 233.699, 245.19400000000002, 256.634, 268.017, 279.343, 290.611, 301.82099999999997, 312.972, 324.064, 335.097, 346.069, 356.981, 367.833, 378.624, 389.35400000000004, 400.024, 410.63199999999995, 421.17900000000003, 431.665, 442.09, 452.45300000000003, 462.755, 472.996, 483.176, 493.29400000000004, 503.352, 513.3480000000001, 523.283, 533.158, 542.972, 552.725, 562.418, 572.0509999999999, 581.623, 591.135, 600.587, 609.98, 619.313, 628.587, 637.8009999999999, 646.956, 656.053, 665.09, 674.069, 682.99, 691.8530000000001, 700.6569999999999, 709.404, 718.0930000000001, 726.7239999999999, 735.299, 743.816, 752.2760000000001, 760.68, 769.0269999999999, 777.318, 785.552, 793.7310000000001, 801.8530000000001, 809.92, 817.932, 825.888, 833.789, 841.635, 849.426, 857.163, 864.845, 872.472, 880.046, 887.566, 895.0310000000001, 902.444, 909.802, 917.107, 924.3589999999999, 931.558, 938.704, 945.797, 952.8380000000001, 959.826, 966.7610000000001, 973.645, 980.4760000000001, 987.255, 993.9830000000001, 1000.658, 1007.2819999999999, 1013.855, 1020.3760000000001, 1026.846, 1033.265, 1039.633, 1045.95, 1052.2160000000001, 1058.432, 1064.597, 1070.711, 1076.775, 1082.789, 1088.752, 1094.6660000000002, 1100.529, 1106.343, 1112.106, 1117.82, 1123.484, 1129.099, 1134.664, 1140.18, 1145.646, 1151.063, 1156.43, 1161.749, 1167.018, 1172.239, 1177.41, 1182.532, 1187.606, 1192.631, 1197.607, 1202.5339999999999, 1207.412, 1212.242, 1217.0230000000001, 1221.756, 1226.44, 1231.076, 1235.663, 1240.202, 1244.693, 1249.135, 1253.529, 1257.874, 1262.171, 1266.42, 1270.62, 1274.7730000000001, 1278.877, 1282.933, 1286.94, 1290.9, 1294.8110000000001, 1298.674, 1302.489, 1306.255, 1309.973, 1313.644, 1317.265, 1320.839, 1324.364, 1327.8410000000001, 1331.27, 1334.65, 1337.9820000000002, 1341.266, 1344.501, 1347.6879999999999, 1350.8270000000002, 1353.9170000000001, 1356.9579999999999, 1359.951, 1362.895, 1365.7910000000002, 1368.638, 1371.4360000000001, 1374.1860000000001, 1376.886, 1379.5379999999998, 1382.141, 1384.695, 1387.2, 1389.655, 1392.0620000000001, 1394.4189999999999, 1396.727, 1398.986, 1401.195, 1403.355, 1405.465, 1407.526, 1409.536, 1411.497, 1413.408, 1415.269, 1417.08, 1418.84, 1420.55, 1422.21, 1423.82, 1425.378, 1426.886, 1428.344, 1429.75, 1431.105, 1432.4089999999999, 1433.662, 1434.8629999999998, 1436.013, 1437.111, 1438.158, 1439.152, 1440.095, 1440.985, 1441.8229999999999, 1442.608, 1443.3410000000001, 1444.021, 1444.648, 1445.2220000000002, 1445.743, 1446.21, 1446.624, 1446.984, 1447.29, 1447.5420000000001, 1447.74, 1447.884, 1447.973, 1448.007, 1447.986, 1447.91, 1447.7779999999998, 1447.5910000000001, 1447.348, 1447.05, 1446.695, 1446.283, 1445.815, 1445.29, 1444.7089999999998, 1444.069, 1443.3729999999998, 1442.618, 1441.806, 1440.935, 1440.006, 1439.0179999999998, 1437.971, 1436.865, 1435.6989999999998, 1434.474, 1433.1879999999999, 1431.842, 1430.4360000000001, 1428.9679999999998, 1427.44, 1425.85, 1424.1979999999999, 1422.484, 1420.7079999999999, 1418.869, 1416.9660000000001, 1415.001, 1412.9720000000002, 1410.879, 1408.721, 1406.499, 1404.2120000000002, 1401.859, 1399.44, 1396.955, 1394.404, 1391.786, 1389.1, 1386.3470000000002, 1383.526, 1380.636, 1377.6779999999999, 1374.65, 1371.5520000000001, 1368.384, 1365.145, 1361.836, 1358.455, 1355.001, 1351.476, 1347.8770000000002, 1344.205, 1340.4589999999998, 1336.639, 1332.744, 1328.773, 1324.727, 1320.604, 1316.404, 1312.126, 1307.77, 1303.336, 1298.822, 1294.228, 1289.553, 1284.798, 1279.961, 1275.0410000000002, 1270.038, 1264.952, 1259.781, 1254.526, 1249.184, 1243.756, 1238.241, 1232.638, 1226.947, 1221.1660000000002, 1215.295, 1209.333, 1203.28, 1197.134, 1190.894, 1184.5610000000001, 1178.132, 1171.608, 1164.986, 1158.267, 1151.45, 1144.5330000000001, 1137.515, 1130.396, 1123.174, 1115.849, 1108.42, 1100.885, 1093.243, 1085.494, 1077.635, 1069.667, 1061.588, 1053.396, 1045.0910000000001, 1036.671, 1028.136, 1019.4830000000001, 1010.711, 1001.82, 992.807, 983.672, 974.413, 965.028, 955.5169999999999, 945.877, 936.107, 926.206, 916.172, 906.0039999999999, 895.699, 885.257, 874.674, 863.951, 853.084, 842.073, 830.914, 819.607, 808.15, 796.54, 784.7760000000001, 772.8560000000001, 760.7769999999999, 748.538, 736.1360000000001, 723.569, 710.836, 697.934, 684.86, 671.613, 658.191, 644.59, 630.809, 616.845, 602.697, 588.362, 573.837, 559.12, 544.21, 529.104, 513.799, 498.29400000000004, 482.586, 466.675, 450.55699999999996, 434.231, 417.69599999999997, 400.95, 383.99300000000005, 366.82300000000004, 349.44, 331.844, 314.035, 296.014, 277.782, 259.342, 240.697, 221.84900000000002, 202.804, 183.56799999999998, 164.14700000000002, 144.55100000000002, 124.789, 104.875, 84.822, 64.648, 44.373000000000005, 24.018, 3.61, -16.82, -37.239000000000004, -57.608999999999995, -77.88600000000001, -98.023, -117.965, -137.655, -157.029, -176.019, -194.55200000000002, -212.55200000000002, -229.94, -246.637, -262.562, -277.64, -291.797, -304.967, -317.091, -328.121, -338.02, -346.76099999999997, -354.33099999999996, -360.72900000000004, -365.964, -370.05800000000005, -373.039, -374.94599999999997, -375.82099999999997, -375.712, -374.671, -372.751, -370.005, -366.486, -362.24800000000005, -357.34, -351.81300000000005, -345.712, -339.083, -331.967, -324.403, -316.428, -308.075, -299.377, -290.363, -281.06, -271.494, -261.687, -251.662, -241.438, -231.033, -220.46400000000003, -209.747, -198.89700000000002, -187.926, -176.847, -165.671, -154.409, -143.07, -131.664, -120.198, -108.68, -97.117, -85.516, -73.883, -62.224, -50.543, -38.846, -27.136, -15.419, -3.698, 8.023, 19.741, 31.453000000000003, 43.156000000000006, 54.847, 66.524, 78.184, 89.82600000000001, 101.446, 113.044, 124.617, 136.164, 147.683, 159.173, 170.63299999999998, 182.06099999999998, 193.455, 204.81599999999997, 216.142, 227.43200000000002, 238.685, 249.9, 261.077, 272.214, 283.312, 294.369, 305.385, 316.35900000000004, 327.291, 338.181, 349.027, 359.83, 370.589, 381.30400000000003, 391.974, 402.6, 413.18, 423.715, 434.204, 444.648, 455.045, 465.39599999999996, 475.7, 485.958, 496.16900000000004, 506.333, 516.45, 526.52, 536.5419999999999, 546.5169999999999, 556.445, 566.325, 576.1569999999999, 585.942, 595.679, 605.368, 615.01, 624.6030000000001, 634.149, 643.646, 653.096, 662.498, 671.8510000000001, 681.1569999999999, 690.415, 699.6239999999999, 708.7860000000001, 717.8989999999999, 726.965, 735.982, 744.951, 753.873, 762.7460000000001, 771.572, 780.3489999999999, 789.079, 797.76, 806.3939999999999, 814.9789999999999, 823.5169999999999, 832.007, 840.449, 848.8439999999999, 857.19, 865.4889999999999, 873.74, 881.943, 890.0980000000001, 898.206, 906.2660000000001, 914.278, 922.243, 930.16, 938.029, 945.8510000000001, 953.6260000000001, 961.352, 969.0310000000001, 976.663, 984.247, 991.784, 999.273, 1006.715, 1014.1089999999999, 1021.456, 1028.755, 1036.007, 1043.211, 1050.368, 1057.478, 1064.54, 1071.555, 1078.5230000000001, 1085.443, 1092.315, 1099.14, 1105.9180000000001, 1112.649, 1119.3319999999999, 1125.9669999999999, 1132.556, 1139.096, 1145.59, 1152.035, 1158.434, 1164.785, 1171.088, 1177.344, 1183.552, 1189.713, 1195.826, 1201.892, 1207.91, 1213.88, 1219.803, 1225.678, 1231.505, 1237.2839999999999, 1243.016, 1248.7, 1254.336, 1259.924, 1265.464, 1270.955, 1276.399, 1281.795, 1287.143, 1292.442, 1297.693, 1302.896, 1308.0510000000002, 1313.1570000000002, 1318.214, 1323.223, 1328.184, 1333.096, 1337.9589999999998, 1342.773, 1347.5379999999998, 1352.255, 1356.922, 1361.5410000000002, 1366.11, 1370.63, 1375.1, 1379.5220000000002, 1383.8929999999998, 1388.215, 1392.4879999999998, 1396.71, 1400.8829999999998, 1405.006, 1409.079, 1413.101, 1417.0729999999999, 1420.995, 1424.8670000000002, 1428.6879999999999, 1432.4579999999999, 1436.1770000000001, 1439.845, 1443.463, 1447.029, 1450.5439999999999, 1454.007, 1457.4189999999999, 1460.779, 1464.088, 1467.344, 1470.549, 1473.701, 1476.8010000000002, 1479.848, 1482.8429999999998, 1485.785, 1488.674, 1491.51, 1494.2920000000001, 1497.021, 1499.6970000000001, 1502.319, 1504.8870000000002, 1507.4, 1509.86, 1512.265, 1514.616, 1516.911, 1519.152, 1521.338, 1523.4679999999998, 1525.5420000000001, 1527.5610000000001, 1529.524, 1531.431, 1533.281, 1535.075, 1536.8120000000001, 1538.4920000000002, 1540.114, 1541.6789999999999, 1543.1870000000001, 1544.6370000000002, 1546.0279999999998, 1547.361, 1548.635, 1549.851, 1551.007, 1552.104, 1553.141, 1554.119, 1555.036, 1555.8929999999998, 1556.6889999999999, 1557.424, 1558.098, 1558.71, 1559.26, 1559.749, 1560.174, 1560.537, 1560.8370000000002, 1561.0739999999998, 1561.247, 1561.356, 1561.401, 1561.381, 1561.296, 1561.145, 1560.9289999999999, 1560.6470000000002, 1560.299, 1559.884, 1559.401, 1558.852, 1558.234, 1557.5479999999998, 1556.793, 1555.969, 1555.076, 1554.1129999999998, 1553.08, 1551.976, 1550.8010000000002, 1549.5539999999999, 1548.236, 1546.844, 1545.38, 1543.8429999999998, 1542.2320000000002, 1540.546, 1538.786, 1536.95, 1535.0379999999998, 1533.0510000000002, 1530.986, 1528.844, 1526.624, 1524.325, 1521.9479999999999, 1519.491, 1516.954, 1514.336, 1511.6370000000002, 1508.856, 1505.9920000000002, 1503.046, 1500.016, 1496.901, 1493.701, 1490.4160000000002, 1487.0439999999999, 1483.585, 1480.039, 1476.404, 1472.68, 1468.866, 1464.961, 1460.965, 1456.8770000000002, 1452.6960000000001, 1448.421, 1444.0520000000001, 1439.5870000000002, 1435.026, 1430.368, 1425.612, 1420.757, 1415.8020000000001, 1410.747, 1405.59, 1400.3310000000001, 1394.9679999999998, 1389.5, 1383.9270000000001, 1378.2479999999998, 1372.46, 1366.565, 1360.559, 1354.443, 1348.214, 1341.8729999999998, 1335.4170000000001, 1328.846, 1322.1570000000002, 1315.351, 1308.4260000000002, 1301.38, 1294.212, 1286.921, 1279.505, 1271.964, 1264.295, 1256.497, 1248.568, 1240.508, 1232.3139999999999, 1223.985, 1215.519, 1206.914, 1198.17, 1189.2839999999999, 1180.254, 1171.078, 1161.755, 1152.2839999999999, 1142.661, 1132.885, 1122.953, 1112.865, 1102.617, 1092.208, 1081.635, 1070.897, 1059.989, 1048.912, 1037.661, 1026.234, 1014.63, 1002.845, 990.8760000000001, 978.722, 966.3789999999999, 953.845, 941.1160000000001, 928.189, 915.062, 901.732, 888.195, 874.448, 860.488, 846.311, 831.915, 817.296, 802.449, 787.373, 772.062, 756.513, 740.7239999999999, 724.689, 708.405, 691.8689999999999, 675.075, 658.0219999999999, 640.703, 623.117, 605.258, 587.124, 568.71, 550.014, 531.031, 511.75800000000004, 492.19199999999995, 472.332, 452.173, 431.715, 410.955, 389.89300000000003, 368.528, 346.86199999999997, 324.895, 302.631, 280.072, 257.223, 234.093, 210.69, 187.024, 163.11, 138.964, 114.60600000000001, 90.059, 65.352, 40.515, 15.587, -9.389, -34.366, -59.287, -84.09299999999999, -108.715, -133.078, -157.10299999999998, -180.704, -203.791, -226.268, -248.043, -269.022, -289.11, -308.223, -326.281, -343.213, -358.961, -373.478, -386.73199999999997, -398.704, -409.385, -418.786, -426.921, -433.82099999999997, -439.52099999999996, -444.06300000000005, -447.496, -449.87199999999996, -451.24300000000005, -451.665, -451.19199999999995, -449.88, -447.78, -444.94300000000004, -441.42, -437.256, -432.496, -427.181, -421.351, -415.04400000000004, -408.293, -401.131, -393.587, -385.689, -377.465, -368.93800000000005, -360.13, -351.06300000000005, -341.756, -332.226, -322.491, -312.567, -302.468, -292.207, -281.797, -271.249, -260.575, -249.785, -238.889, -227.894, -216.81, -205.643, -194.40200000000002, -183.093, -171.722, -160.295, -148.81799999999998, -137.295, -125.73200000000001, -114.134, -102.50399999999999, -90.84700000000001, -79.165, -67.464, -55.746, -44.015, -32.272, -20.522, -8.766, 2.992, 14.751, 26.506999999999998, 38.260999999999996, 50.008, 61.747, 73.477, 85.196, 96.90299999999999, 108.595, 120.271, 131.931, 143.572, 155.19299999999998, 166.795, 178.37400000000002, 189.93099999999998, 201.46400000000003, 212.972, 224.455, 235.912, 247.34099999999998, 258.743, 270.116, 281.459, 292.77299999999997, 304.056, 315.307, 326.527, 337.715, 348.87, 359.991, 371.079, 382.13300000000004, 393.152, 404.135, 415.084, 425.996, 436.87199999999996, 447.712, 458.515, 469.281, 480.009, 490.7, 501.352, 511.966, 522.5419999999999, 533.0790000000001, 543.576, 554.035, 564.4540000000001, 574.8330000000001, 585.173, 595.472, 605.732, 615.95, 626.129, 636.266, 646.362, 656.418, 666.432, 676.405, 686.336, 696.2260000000001, 706.074, 715.88, 725.6439999999999, 735.3660000000001, 745.046, 754.683, 764.278, 773.831, 783.34, 792.807, 802.2310000000001, 811.612, 820.95, 830.245, 839.4960000000001, 848.705, 857.8689999999999, 866.9910000000001, 876.068, 885.102, 894.092, 903.039, 911.941, 920.799, 929.613, 938.383, 947.1089999999999, 955.791, 964.428, 973.02, 981.568, 990.071, 998.53, 1006.944, 1015.312, 1023.6360000000001, 1031.915, 1040.149, 1048.337, 1056.481, 1064.579, 1072.631, 1080.638, 1088.6, 1096.515, 1104.385, 1112.21, 1119.988, 1127.72, 1135.406, 1143.046, 1150.64, 1158.188, 1165.6889999999999, 1173.143, 1180.5510000000002, 1187.913, 1195.2269999999999, 1202.495, 1209.7160000000001, 1216.89, 1224.016, 1231.096, 1238.128, 1245.113, 1252.05, 1258.9389999999999, 1265.781, 1272.575, 1279.3210000000001, 1286.019, 1292.6689999999999, 1299.271, 1305.8239999999998, 1312.329, 1318.786, 1325.193, 1331.5520000000001, 1337.862, 1344.1229999999998, 1350.3339999999998, 1356.497, 1362.61, 1368.6729999999998, 1374.6870000000001, 1380.651, 1386.565, 1392.4289999999999, 1398.243, 1404.006, 1409.72, 1415.382, 1420.994, 1426.555, 1432.065, 1437.523, 1442.931, 1448.286, 1453.5910000000001, 1458.8429999999998, 1464.0439999999999, 1469.192, 1474.2879999999998, 1479.332, 1484.3229999999999, 1489.2620000000002, 1494.1470000000002, 1498.98, 1503.759, 1508.485, 1513.1570000000002, 1517.775, 1522.339, 1526.849, 1531.305, 1535.7060000000001, 1540.0520000000001, 1544.344, 1548.58, 1552.761, 1556.886, 1560.9560000000001, 1564.969, 1568.9260000000002, 1572.8270000000002, 1576.671, 1580.4589999999998, 1584.1889999999999, 1587.862, 1591.477, 1595.0339999999999, 1598.5339999999999, 1601.975, 1605.3570000000002, 1608.681, 1611.9460000000001, 1615.151, 1618.297, 1621.3829999999998, 1624.4089999999999, 1627.375, 1630.28, 1633.124, 1635.9070000000002, 1638.628, 1641.2879999999998, 1643.886, 1646.421, 1648.894, 1651.3029999999999, 1653.65, 1655.933, 1658.151, 1660.306, 1662.396, 1664.422, 1666.382, 1668.276, 1670.105, 1671.8670000000002, 1673.5629999999999, 1675.191, 1676.753, 1678.246, 1679.672, 1681.029, 1682.317, 1683.536, 1684.6860000000001, 1685.765, 1686.774, 1687.711, 1688.578, 1689.3729999999998, 1690.095, 1690.745, 1691.3220000000001, 1691.826, 1692.255, 1692.611, 1692.891, 1693.095, 1693.224, 1693.277, 1693.253, 1693.151, 1692.971, 1692.713, 1692.376, 1691.96, 1691.463, 1690.886, 1690.2279999999998, 1689.4879999999998, 1688.665, 1687.76, 1686.771, 1685.6979999999999, 1684.54, 1683.297, 1681.9679999999998, 1680.5520000000001, 1679.0479999999998, 1677.457, 1675.777, 1674.0079999999998, 1672.148, 1670.1979999999999, 1668.156, 1666.021, 1663.7939999999999, 1661.473, 1659.057, 1656.546, 1653.9379999999999, 1651.233, 1648.431, 1645.53, 1642.529, 1639.4279999999999, 1636.225, 1632.92, 1629.5120000000002, 1625.999, 1622.382, 1618.658, 1614.828, 1610.889, 1606.8410000000001, 1602.683, 1598.414, 1594.0320000000002, 1589.537, 1584.9270000000001, 1580.2020000000002, 1575.359, 1570.398, 1565.318, 1560.1170000000002, 1554.795, 1549.349, 1543.779, 1538.0829999999999, 1532.259, 1526.307, 1520.225, 1514.0120000000002, 1507.665, 1501.184, 1494.567, 1487.8120000000001, 1480.9170000000001, 1473.882, 1466.704, 1459.382, 1451.9129999999998, 1444.297, 1436.531, 1428.6129999999998, 1420.5410000000002, 1412.3139999999999, 1403.9289999999999, 1395.385, 1386.6789999999999, 1377.809, 1368.773, 1359.568, 1350.193, 1340.645, 1330.921, 1321.019, 1310.9370000000001, 1300.672, 1290.22, 1279.5810000000001, 1268.75, 1257.725, 1246.503, 1235.0810000000001, 1223.4560000000001, 1211.625, 1199.5839999999998, 1187.3310000000001, 1174.861, 1162.172, 1149.26, 1136.12, 1122.75, 1109.145, 1095.302, 1081.2169999999999, 1066.885, 1052.303, 1037.465, 1022.368, 1007.007, 991.377, 975.4730000000001, 959.291, 942.826, 926.072, 909.025, 891.679, 874.029, 856.069, 837.794, 819.198, 800.275, 781.0210000000001, 761.428, 741.4910000000001, 721.204, 700.562, 679.559, 658.189, 636.446, 614.325, 591.822, 568.93, 545.6469999999999, 521.967, 497.88699999999994, 473.405, 448.519, 423.228, 397.532, 371.43300000000005, 344.935, 318.04200000000003, 290.763, 263.108, 235.09, 206.727, 178.03799999999998, 149.048, 119.789, 90.29700000000001, 60.613, 30.785999999999998, 0.8740000000000001, -29.061, -58.946999999999996, -88.70299999999999, -118.242, -147.468, -176.28, -204.572, -232.232, -259.149, -285.214, -310.318, -334.361, -357.251, -378.908, -399.265, -418.269, -435.88300000000004, -452.083, -466.86199999999997, -480.227, -492.194, -502.793, -512.061, -520.0419999999999, -526.7869999999999, -532.3480000000001, -536.7819999999999, -540.145, -542.495, -543.889, -544.381, -544.025, -542.874, -540.976, -538.38, -535.128, -531.264, -526.828, -521.855, -516.381, -510.44, -504.06199999999995, -497.275, -490.105, -482.58, -474.721, -466.55, -458.087, -449.353, -440.36300000000006, -431.13599999999997, -421.686, -412.028, -402.176, -392.142, -381.939, -371.57599999999996, -361.066, -350.417, -339.639, -328.741, -317.73, -306.61400000000003, -295.401, -284.098, -272.709, -261.243, -249.704, -238.097, -226.428, -214.702, -202.923, -191.095, -179.222, -167.30900000000003, -155.358, -143.373, -131.358, -119.316, -107.249, -95.16, -83.052, -70.928, -58.788999999999994, -46.638999999999996, -34.479, -22.311999999999998, -10.138, 2.039, 14.218, 26.397, 38.575, 50.75, 62.92, 75.085, 87.242, 99.391, 111.53, 123.65799999999999, 135.774, 147.877, 159.966, 172.03900000000002, 184.09599999999998, 196.136, 208.157, 220.16, 232.143, 244.106, 256.047, 267.966, 279.862, 291.735, 303.584, 315.408, 327.207, 338.98, 350.727, 362.44599999999997, 374.13800000000003, 385.80199999999996, 397.43699999999995, 409.04400000000004, 420.621, 432.168, 443.684, 455.17, 466.625, 478.048, 489.439, 500.798, 512.124, 523.418, 534.677, 545.904, 557.096, 568.254, 579.377, 590.466, 601.519, 612.5369999999999, 623.519, 634.465, 645.375, 656.2489999999999, 667.085, 677.885, 688.6469999999999, 699.373, 710.06, 720.709, 731.321, 741.8939999999999, 752.428, 762.924, 773.3810000000001, 783.798, 794.177, 804.5160000000001, 814.815, 825.074, 835.293, 845.472, 855.61, 865.7080000000001, 875.765, 885.7810000000001, 895.7560000000001, 905.69, 915.582, 925.432, 935.2410000000001, 945.008, 954.7330000000001, 964.415, 974.055, 983.6519999999999, 993.207, 1002.7189999999999, 1012.187, 1021.613, 1030.995, 1040.333, 1049.628, 1058.879, 1068.087, 1077.249, 1086.368, 1095.442, 1104.472, 1113.4569999999999, 1122.397, 1131.292, 1140.142, 1148.9460000000001, 1157.705, 1166.4180000000001, 1175.086, 1183.7069999999999, 1192.2830000000001, 1200.812, 1209.2939999999999, 1217.731, 1226.12, 1234.462, 1242.758, 1251.006, 1259.2069999999999, 1267.36, 1275.4660000000001, 1283.5230000000001, 1291.5330000000001, 1299.495, 1307.4080000000001, 1315.273, 1323.089, 1330.856, 1338.5739999999998, 1346.243, 1353.862, 1361.432, 1368.953, 1376.4229999999998, 1383.844, 1391.214, 1398.533, 1405.8029999999999, 1413.021, 1420.1879999999999, 1427.3039999999999, 1434.369, 1441.3829999999998, 1448.344, 1455.254, 1462.111, 1468.9160000000002, 1475.6689999999999, 1482.369, 1489.016, 1495.609, 1502.15, 1508.6370000000002, 1515.07, 1521.4489999999998, 1527.774, 1534.0439999999999, 1540.26, 1546.421, 1552.527, 1558.5770000000002, 1564.5720000000001, 1570.511, 1576.394, 1582.221, 1587.991, 1593.704, 1599.361, 1604.96, 1610.5020000000002, 1615.986, 1621.412, 1626.779, 1632.088, 1637.339, 1642.53, 1647.662, 1652.734, 1657.746, 1662.6979999999999, 1667.59, 1672.42, 1677.19, 1681.899, 1686.545, 1691.13, 1695.6529999999998, 1700.112, 1704.509, 1708.8429999999998, 1713.1129999999998, 1717.32, 1721.4620000000002, 1725.539, 1729.5520000000001, 1733.499, 1737.381, 1741.1970000000001, 1744.9460000000001, 1748.629, 1752.245, 1755.7939999999999, 1759.275, 1762.6870000000001, 1766.031, 1769.306, 1772.5120000000002, 1775.648, 1778.714, 1781.71, 1784.634, 1787.487, 1790.2679999999998, 1792.977, 1795.614, 1798.1770000000001, 1800.6670000000001, 1803.082, 1805.424, 1807.69, 1809.881, 1811.996, 1814.0339999999999, 1815.996, 1817.88, 1819.6860000000001, 1821.414, 1823.0629999999999, 1824.632, 1826.121, 1827.53, 1828.8570000000002, 1830.1029999999998, 1831.267, 1832.3470000000002, 1833.344, 1834.257, 1835.086, 1835.829, 1836.486, 1837.057, 1837.54, 1837.9360000000001, 1838.243, 1838.461, 1838.589, 1838.6270000000002, 1838.5729999999999, 1838.4279999999999, 1838.1889999999999, 1837.8570000000002, 1837.431, 1836.91, 1836.2939999999999, 1835.5810000000001, 1834.77, 1833.861, 1832.854, 1831.746, 1830.5379999999998, 1829.229, 1827.817, 1826.3010000000002, 1824.682, 1822.957, 1821.1270000000002, 1819.1889999999999, 1817.1429999999998, 1814.9879999999998, 1812.723, 1810.3470000000002, 1807.859, 1805.257, 1802.5410000000002, 1799.71, 1796.763, 1793.6970000000001, 1790.513, 1787.2089999999998, 1783.7839999999999, 1780.236, 1776.5639999999999, 1772.7679999999998, 1768.845, 1764.795, 1760.615, 1756.305, 1751.864, 1747.289, 1742.579, 1737.733, 1732.75, 1727.6270000000002, 1722.3629999999998, 1716.957, 1711.406, 1705.71, 1699.866, 1693.8729999999998, 1687.729, 1681.432, 1674.98, 1668.371, 1661.604, 1654.675, 1647.5839999999998, 1640.328, 1632.905, 1625.3129999999999, 1617.549, 1609.612, 1601.4979999999998, 1593.2060000000001, 1584.733, 1576.0770000000002, 1567.235, 1558.204, 1548.9820000000002, 1539.565, 1529.9520000000002, 1520.138, 1510.122, 1499.9, 1489.469, 1478.826, 1467.967, 1456.89, 1445.59, 1434.0639999999999, 1422.309, 1410.3210000000001, 1398.095, 1385.629, 1372.918, 1359.957, 1346.743, 1333.271, 1319.537, 1305.536, 1291.264, 1276.715, 1261.885, 1246.768, 1231.36, 1215.654, 1199.646, 1183.329, 1166.698, 1149.746, 1132.469, 1114.858, 1096.9089999999999, 1078.613, 1059.965, 1040.9569999999999, 1021.5830000000001, 1001.835, 981.706, 961.188, 940.273, 918.954, 897.2230000000001, 875.072, 852.493, 829.477, 806.0160000000001, 782.1039999999999, 757.73, 732.888, 707.571, 681.77, 655.4780000000001, 628.689, 601.398, 573.5980000000001, 545.2869999999999, 516.4590000000001, 487.115, 457.25300000000004, 426.876, 395.98699999999997, 364.594, 332.707, 300.339, 267.508, 234.238, 200.55599999999998, 166.49599999999998, 132.101, 97.42, 62.50899999999999, 27.436, -7.724, -42.886, -77.955, -112.82600000000001, -147.387, -181.518, -215.09400000000002, -247.986, -280.064, -311.20099999999996, -341.277, -370.176, -397.798, -424.05400000000003, -448.87, -472.191, -493.977, -514.205, -532.869, -549.976, -565.547, -579.613, -592.215, -603.401, -613.222, -621.737, -629.005, -635.0840000000001, -640.036, -643.92, -646.794, -648.716, -649.739, -649.9169999999999, -649.297, -647.93, -645.859, -643.125, -639.77, -635.832, -631.344, -626.34, -620.851, -614.9069999999999, -608.535, -601.76, -594.606, -587.095, -579.25, -571.0880000000001, -562.63, -553.893, -544.8919999999999, -535.6419999999999, -526.16, -516.456, -506.546, -496.439, -486.149, -475.684, -465.056, -454.274, -443.346, -432.282, -421.088, -409.773, -398.343, -386.805, -375.166, -363.431, -351.606, -339.69800000000004, -327.71, -315.647, -303.515, -291.318, -279.06, -266.744, -254.375, -241.957, -229.49200000000002, -216.985, -204.437, -191.85299999999998, -179.235, -166.585, -153.907, -141.203, -128.475, -115.726, -102.95700000000001, -90.171, -77.37, -64.556, -51.731, -38.896, -26.053, -13.204, -0.35, 12.507, 25.365, 38.224000000000004, 51.082, 63.938, 76.79, 89.637, 102.478, 115.31200000000001, 128.138, 140.955, 153.761, 166.55599999999998, 179.34, 192.11, 204.86599999999999, 217.608, 230.334, 243.043, 255.736, 268.41, 281.066, 293.703, 306.32, 318.916, 331.491, 344.04400000000004, 356.574, 369.082, 381.565, 394.025, 406.46, 418.869, 431.25300000000004, 443.61, 455.941, 468.245, 480.52, 492.76800000000003, 504.98699999999997, 517.177, 529.3380000000001, 541.4680000000001, 553.569, 565.639, 577.678, 589.685, 601.661, 613.605, 625.516, 637.395, 649.24, 661.052, 672.83, 684.574, 696.283, 707.9580000000001, 719.5980000000001, 731.202, 742.7710000000001, 754.304, 765.801, 777.2610000000001, 788.684, 800.071, 811.42, 822.7310000000001, 834.005, 845.2410000000001, 856.438, 867.596, 878.716, 889.797, 900.8380000000001, 911.84, 922.802, 933.7239999999999, 944.605, 955.446, 966.247, 977.0060000000001, 987.7239999999999, 998.4, 1009.035, 1019.628, 1030.1789999999999, 1040.687, 1051.153, 1061.576, 1071.955, 1082.292, 1092.585, 1102.835, 1113.04, 1123.202, 1133.319, 1143.391, 1153.4189999999999, 1163.402, 1173.339, 1183.231, 1193.078, 1202.878, 1212.632, 1222.3410000000001, 1232.002, 1241.617, 1251.185, 1260.7060000000001, 1270.1789999999999, 1279.605, 1288.983, 1298.312, 1307.594, 1316.8270000000002, 1326.011, 1335.146, 1344.233, 1353.269, 1362.256, 1371.194, 1380.0810000000001, 1388.918, 1397.704, 1406.4389999999999, 1415.124, 1423.757, 1432.339, 1440.869, 1449.346, 1457.7720000000002, 1466.145, 1474.4660000000001, 1482.734, 1490.9479999999999, 1499.109, 1507.2160000000001, 1515.269, 1523.2679999999998, 1531.213, 1539.1029999999998, 1546.9370000000001, 1554.717, 1562.441, 1570.109, 1577.721, 1585.277, 1592.776, 1600.219, 1607.604, 1614.932, 1622.201, 1629.4129999999998, 1636.567, 1643.662, 1650.6979999999999, 1657.675, 1664.592, 1671.45, 1678.247, 1684.985, 1691.661, 1698.276, 1704.83, 1711.3220000000001, 1717.7520000000002, 1724.12, 1730.425, 1736.6670000000001, 1742.845, 1748.96, 1755.011, 1760.997, 1766.9189999999999, 1772.775, 1778.566, 1784.2910000000002, 1789.95, 1795.5420000000001, 1801.067, 1806.525, 1811.915, 1817.237, 1822.49, 1827.674, 1832.789, 1837.8339999999998, 1842.809, 1847.714, 1852.547, 1857.309, 1861.999, 1866.616, 1871.161, 1875.6329999999998, 1880.03, 1884.354, 1888.6029999999998, 1892.777, 1896.875, 1900.8970000000002, 1904.842, 1908.711, 1912.501, 1916.214, 1919.848, 1923.402, 1926.8770000000002, 1930.2720000000002, 1933.586, 1936.818, 1939.969, 1943.037, 1946.0220000000002, 1948.9229999999998, 1951.74, 1954.473, 1957.119, 1959.68, 1962.154, 1964.54, 1966.839, 1969.049, 1971.1689999999999, 1973.2, 1975.139, 1976.9879999999998, 1978.744, 1980.4070000000002, 1981.977, 1983.453, 1984.8329999999999, 1986.118, 1987.306, 1988.3970000000002, 1989.389, 1990.283, 1991.0770000000002, 1991.77, 1992.361, 1992.851, 1993.237, 1993.519, 1993.6960000000001, 1993.767, 1993.731, 1993.5870000000002, 1993.335, 1992.973, 1992.5, 1991.9160000000002, 1991.2179999999998, 1990.4070000000002, 1989.481, 1988.4389999999999, 1987.28, 1986.003, 1984.606, 1983.089, 1981.45, 1979.6889999999999, 1977.8029999999999, 1975.7920000000001, 1973.654, 1971.389, 1968.994, 1966.4679999999998, 1963.8110000000001, 1961.02, 1958.095, 1955.033, 1951.8339999999998, 1948.496, 1945.017, 1941.395, 1937.63, 1933.72, 1929.662, 1925.4560000000001, 1921.099, 1916.59, 1911.9260000000002, 1907.1070000000002, 1902.13, 1896.993, 1891.695, 1886.233, 1880.605, 1874.81, 1868.845, 1862.7079999999999, 1856.396, 1849.908, 1843.2420000000002, 1836.394, 1829.3629999999998, 1822.145, 1814.739, 1807.141, 1799.35, 1791.362, 1783.174, 1774.785, 1766.19, 1757.388, 1748.374, 1739.145, 1729.7, 1720.033, 1710.142, 1700.023, 1689.6729999999998, 1679.0870000000002, 1668.264, 1657.1979999999999, 1645.885, 1634.3220000000001, 1622.504, 1610.4270000000001, 1598.0870000000002, 1585.479, 1572.598, 1559.44, 1546.0, 1532.273, 1518.253, 1503.9360000000001, 1489.316, 1474.388, 1459.144, 1443.5810000000001, 1427.69, 1411.467, 1394.904, 1377.996, 1360.735, 1343.114, 1325.126, 1306.763, 1288.018, 1268.883, 1249.35, 1229.411, 1209.057, 1188.279, 1167.068, 1145.4160000000002, 1123.313, 1100.75, 1077.715, 1054.2, 1030.194, 1005.687, 980.669, 955.1289999999999, 929.057, 902.441, 875.2710000000001, 847.5369999999999, 819.2289999999999, 790.335, 760.847, 730.7560000000001, 700.052, 668.7289999999999, 636.779, 604.197, 570.981, 537.127, 502.63599999999997, 467.51300000000003, 431.76300000000003, 395.398, 358.431, 320.884, 282.782, 244.15900000000002, 205.055, 165.519, 125.61, 85.395, 44.955, 4.379, -36.23, -76.759, -117.086, -157.077, -196.593, -235.488, -273.613, -310.82099999999997, -346.97, -381.926, -415.56199999999995, -447.77099999999996, -478.458, -507.54699999999997, -534.982, -560.725, -584.756, -607.072, -627.684, -646.618, -663.9110000000001, -679.607, -693.758, -706.421, -717.659, -727.533, -736.107, -743.445, -749.6110000000001, -754.664, -758.666, -761.672, -763.74, -764.921, -765.265, -764.82, -763.63, -761.7389999999999, -759.186, -756.008, -752.2410000000001, -747.919, -743.072, -737.73, -731.92, -725.67, -719.002, -711.94, -704.505, -696.7180000000001, -688.597, -680.1610000000001, -671.427, -662.41, -653.125, -643.587, -633.808, -623.8009999999999, -613.5790000000001, -603.1519999999999, -592.531, -581.726, -570.747, -559.602, -548.3, -536.849, -525.257, -513.5319999999999, -501.67900000000003, -489.705, -477.61699999999996, -465.421, -453.12300000000005, -440.727, -428.23900000000003, -415.664, -403.006, -390.27099999999996, -377.461, -364.582, -351.63699999999994, -338.629, -325.563, -312.442, -299.269, -286.048, -272.78, -259.47, -246.11900000000003, -232.731, -219.30700000000002, -205.852, -192.36599999999999, -178.852, -165.312, -151.748, -138.16299999999998, -124.55799999999999, -110.935, -97.296, -83.64299999999999, -69.976, -56.299, -42.611999999999995, -28.916999999999998, -15.216, -1.5090000000000001, 12.200999999999999, 25.914, 39.629, 53.343, 67.056, 80.767, 94.475, 108.178, 121.875, 135.566, 149.25, 162.925, 176.59099999999998, 190.24599999999998, 203.89, 217.52200000000002, 231.141, 244.747, 258.33799999999997, 271.913, 285.473, 299.01599999999996, 312.54200000000003, 326.05, 339.539, 353.00800000000004, 366.458, 379.88699999999994, 393.29400000000004, 406.68, 420.043, 433.384, 446.7, 459.99300000000005, 473.26099999999997, 486.504, 499.721, 512.9119999999999, 526.076, 539.214, 552.323, 565.405, 578.4580000000001, 591.482, 604.477, 617.442, 630.377, 643.281, 656.154, 668.995, 681.805, 694.5830000000001, 707.328, 720.04, 732.7180000000001, 745.363, 757.9739999999999, 770.55, 783.092, 795.5980000000001, 808.069, 820.5039999999999, 832.903, 845.265, 857.591, 869.8789999999999, 882.13, 894.3430000000001, 906.518, 918.655, 930.753, 942.812, 954.831, 966.811, 978.7510000000001, 990.6510000000001, 1002.51, 1014.329, 1026.106, 1037.8419999999999, 1049.536, 1061.188, 1072.798, 1084.365, 1095.89, 1107.371, 1118.809, 1130.203, 1141.553, 1152.859, 1164.121, 1175.337, 1186.509, 1197.635, 1208.715, 1219.75, 1230.738, 1241.68, 1252.575, 1263.422, 1274.223, 1284.976, 1295.681, 1306.338, 1316.9460000000001, 1327.506, 1338.017, 1348.4779999999998, 1358.89, 1369.2520000000002, 1379.5639999999999, 1389.825, 1400.036, 1410.195, 1420.3039999999999, 1430.36, 1440.365, 1450.318, 1460.2179999999998, 1470.066, 1479.861, 1489.602, 1499.29, 1508.9229999999998, 1518.503, 1528.0279999999998, 1537.4979999999998, 1546.9129999999998, 1556.2720000000002, 1565.576, 1574.8239999999998, 1584.015, 1593.15, 1602.227, 1611.2479999999998, 1620.21, 1629.115, 1637.961, 1646.749, 1655.4779999999998, 1664.1470000000002, 1672.757, 1681.307, 1689.796, 1698.225, 1706.592, 1714.899, 1723.1429999999998, 1731.326, 1739.4460000000001, 1747.503, 1755.497, 1763.4279999999999, 1771.2939999999999, 1779.0970000000002, 1786.8339999999998, 1794.507, 1802.114, 1809.655, 1817.13, 1824.539, 1831.88, 1839.154, 1846.36, 1853.4979999999998, 1860.567, 1867.567, 1874.4979999999998, 1881.358, 1888.148, 1894.868, 1901.515, 1908.092, 1914.596, 1921.027, 1927.385, 1933.67, 1939.88, 1946.016, 1952.0770000000002, 1958.0629999999999, 1963.9720000000002, 1969.805, 1975.56, 1981.2379999999998, 1986.838, 1992.359, 1997.8010000000002, 2003.164, 2008.4460000000001, 2013.6470000000002, 2018.767, 2023.805, 2028.761, 2033.6329999999998, 2038.422, 2043.126, 2047.746, 2052.28, 2056.7270000000003, 2061.0879999999997, 2065.362, 2069.547, 2073.644, 2077.652, 2081.569, 2085.396, 2089.131, 2092.774, 2096.324, 2099.78, 2103.143, 2106.41, 2109.581, 2112.656, 2115.633, 2118.512, 2121.2929999999997, 2123.973, 2126.553, 2129.032, 2131.408, 2133.6820000000002, 2135.851, 2137.916, 2139.874, 2141.7270000000003, 2143.471, 2145.107, 2146.634, 2148.05, 2149.354, 2150.5460000000003, 2151.625, 2152.589, 2153.438, 2154.17, 2154.784, 2155.28, 2155.655, 2155.91, 2156.042, 2156.051, 2155.935, 2155.6929999999998, 2155.325, 2154.828, 2154.201, 2153.444, 2152.554, 2151.53, 2150.3720000000003, 2149.077, 2147.645, 2146.073, 2144.361, 2142.506, 2140.507, 2138.363, 2136.072, 2133.632, 2131.042, 2128.3, 2125.404, 2122.353, 2119.145, 2115.777, 2112.249, 2108.5570000000002, 2104.701, 2100.678, 2096.487, 2092.124, 2087.5879999999997, 2082.877, 2077.989, 2072.9210000000003, 2067.6710000000003, 2062.237, 2056.616, 2050.805, 2044.8039999999999, 2038.608, 2032.215, 2025.622, 2018.8270000000002, 2011.828, 2004.62, 1997.2, 1989.567, 1981.717, 1973.6470000000002, 1965.3529999999998, 1956.832, 1948.0810000000001, 1939.096, 1929.874, 1920.411, 1910.703, 1900.747, 1890.537, 1880.0710000000001, 1869.345, 1858.3529999999998, 1847.092, 1835.556, 1823.7420000000002, 1811.644, 1799.2579999999998, 1786.578, 1773.599, 1760.317, 1746.725, 1732.819, 1718.5910000000001, 1704.036, 1689.148, 1673.921, 1658.348, 1642.4229999999998, 1626.138, 1609.486, 1592.461, 1575.0539999999999, 1557.2579999999998, 1539.065, 1520.4660000000001, 1501.454, 1482.019, 1462.152, 1441.845, 1421.0870000000002, 1399.869, 1378.181, 1356.0120000000002, 1333.352, 1310.19, 1286.514, 1262.3139999999999, 1237.577, 1212.2910000000002, 1186.443, 1160.022, 1133.015, 1105.4089999999999, 1077.1889999999999, 1048.343, 1018.8589999999999, 988.722, 957.918, 926.436, 894.262, 861.383, 827.788, 793.466, 758.4060000000001, 722.6, 686.041, 648.722, 610.6419999999999, 571.8, 532.2, 491.847, 450.755, 408.941, 366.43, 323.251, 279.445, 235.06, 190.15599999999998, 144.803, 99.083, 53.092, 6.939, -39.257, -85.36, -131.226, -176.7, -221.62, -265.819, -309.13, -351.39, -392.441, -432.13800000000003, -470.348, -506.958, -541.872, -575.016, -606.335, -635.797, -663.387, -689.107, -712.9760000000001, -735.0260000000001, -755.299, -773.846, -790.725, -805.997, -819.7289999999999, -831.988, -842.841, -852.355, -860.5980000000001, -867.6339999999999, -873.525, -878.332, -882.112, -884.922, -886.814, -887.836, -888.038, -887.462, -886.153, -884.148, -881.488, -878.205, -874.3330000000001, -869.905, -864.948, -859.492, -853.561, -847.182, -840.3760000000001, -833.166, -825.573, -817.6139999999999, -809.31, -800.678, -791.7330000000001, -782.4910000000001, -772.966, -763.173, -753.1239999999999, -742.832, -732.308, -721.564, -710.6089999999999, -699.455, -688.1110000000001, -676.584, -664.885, -653.021, -641.0, -628.8290000000001, -616.515, -604.065, -591.486, -578.783, -565.9630000000001, -553.03, -539.99, -526.849, -513.611, -500.28, -486.86199999999997, -473.36, -459.778, -446.121, -432.39300000000003, -418.595, -404.73400000000004, -390.81, -376.829, -362.792, -348.704, -334.565, -320.38, -306.152, -291.881, -277.572, -263.226, -248.84599999999998, -234.433, -219.99099999999999, -205.52, -191.024, -176.503, -161.96, -147.39600000000002, -132.814, -118.214, -103.6, -88.971, -74.329, -59.677, -45.016000000000005, -30.346, -15.669, -0.987, 13.699000000000002, 28.388, 43.07899999999999, 57.771, 72.462, 87.15100000000001, 101.838, 116.521, 131.2, 145.873, 160.539, 175.19799999999998, 189.84799999999998, 204.488, 219.11900000000003, 233.738, 248.34599999999998, 262.941, 277.522, 292.089, 306.64099999999996, 321.177, 335.69699999999995, 350.2, 364.685, 379.151, 393.598, 408.025, 422.43199999999996, 436.81800000000004, 451.18199999999996, 465.524, 479.843, 494.13800000000003, 508.41, 522.6569999999999, 536.879, 551.075, 565.245, 579.389, 593.505, 607.594, 621.654, 635.686, 649.689, 663.6619999999999, 677.605, 691.518, 705.3989999999999, 719.2489999999999, 733.068, 746.8539999999999, 760.607, 774.327, 788.0139999999999, 801.666, 815.285, 828.868, 842.416, 855.929, 869.4060000000001, 882.846, 896.25, 909.6160000000001, 922.945, 936.2360000000001, 949.4889999999999, 962.703, 975.878, 989.0139999999999, 1002.11, 1015.166, 1028.182, 1041.156, 1054.09, 1066.982, 1079.8319999999999, 1092.64, 1105.406, 1118.128, 1130.808, 1143.443, 1156.035, 1168.583, 1181.085, 1193.5430000000001, 1205.9560000000001, 1218.323, 1230.644, 1242.9189999999999, 1255.147, 1267.328, 1279.462, 1291.548, 1303.586, 1315.575, 1327.517, 1339.4089999999999, 1351.251, 1363.0439999999999, 1374.787, 1386.48, 1398.122, 1409.713, 1421.253, 1432.74, 1444.1760000000002, 1455.559, 1466.89, 1478.168, 1489.392, 1500.5620000000001, 1511.6779999999999, 1522.739, 1533.746, 1544.6979999999999, 1555.594, 1566.434, 1577.217, 1587.945, 1598.615, 1609.227, 1619.7820000000002, 1630.279, 1640.7179999999998, 1651.0970000000002, 1661.418, 1671.6789999999999, 1681.879, 1692.02, 1702.1, 1712.118, 1722.076, 1731.971, 1741.8039999999999, 1751.5739999999998, 1761.281, 1770.925, 1780.505, 1790.02, 1799.471, 1808.8570000000002, 1818.1770000000001, 1827.431, 1836.618, 1845.739, 1854.793, 1863.779, 1872.6960000000001, 1881.545, 1890.325, 1899.036, 1907.6760000000002, 1916.247, 1924.746, 1933.174, 1941.53, 1949.8129999999999, 1958.024, 1966.162, 1974.226, 1982.215, 1990.13, 1997.969, 2005.733, 2013.42, 2021.031, 2028.5639999999999, 2036.019, 2043.395, 2050.6929999999998, 2057.911, 2065.049, 2072.106, 2079.0820000000003, 2085.976, 2092.7870000000003, 2099.516, 2106.161, 2112.722, 2119.197, 2125.5879999999997, 2131.8920000000003, 2138.109, 2144.239, 2150.281, 2156.234, 2162.098, 2167.8720000000003, 2173.554, 2179.146, 2184.645, 2190.051, 2195.364, 2200.583, 2205.706, 2210.7329999999997, 2215.6639999999998, 2220.498, 2225.2329999999997, 2229.87, 2234.407, 2238.842, 2243.177, 2247.41, 2251.5389999999998, 2255.564, 2259.485, 2263.301, 2267.008, 2270.61, 2274.101, 2277.485, 2280.757, 2283.9179999999997, 2286.967, 2289.903, 2292.724, 2295.43, 2298.02, 2300.492, 2302.845, 2305.0789999999997, 2307.192, 2309.183, 2311.051, 2312.795, 2314.4139999999998, 2315.905, 2317.269, 2318.505, 2319.61, 2320.5820000000003, 2321.422, 2322.1279999999997, 2322.698, 2323.131, 2323.426, 2323.581, 2323.594, 2323.465, 2323.1910000000003, 2322.771, 2322.2039999999997, 2321.488, 2320.6220000000003, 2319.604, 2318.43, 2317.101, 2315.615, 2313.97, 2312.1639999999998, 2310.195, 2308.061, 2305.761, 2303.291, 2300.651, 2297.839, 2294.851, 2291.687, 2288.343, 2284.819, 2281.11, 2277.216, 2273.133, 2268.86, 2264.394, 2259.732, 2254.8720000000003, 2249.811, 2244.5460000000003, 2239.075, 2233.396, 2227.5029999999997, 2221.396, 2215.072, 2208.525, 2201.756, 2194.758, 2187.53, 2180.0679999999998, 2172.368, 2164.426, 2156.241, 2147.806, 2139.12, 2130.177, 2120.974, 2111.506, 2101.77, 2091.761, 2081.474, 2070.905, 2060.05, 2048.903, 2037.4589999999998, 2025.714, 2013.661, 2001.297, 1988.614, 1975.609, 1962.273, 1948.602, 1934.589, 1920.229, 1905.514, 1890.4370000000001, 1874.9920000000002, 1859.171, 1842.9679999999998, 1826.374, 1809.381, 1791.983, 1774.168, 1755.932, 1737.2620000000002, 1718.151, 1698.589, 1678.566, 1658.0729999999999, 1637.099, 1615.6329999999998, 1593.6660000000002, 1571.184, 1548.175, 1524.631, 1500.536, 1475.878, 1450.646, 1424.8229999999999, 1398.398, 1371.356, 1343.682, 1315.3629999999998, 1286.382, 1256.724, 1226.373, 1195.3139999999999, 1163.53, 1131.005, 1097.723, 1063.6680000000001, 1028.823, 993.174, 956.704, 919.3989999999999, 881.247, 842.2330000000001, 802.3480000000001, 761.581, 719.928, 677.383, 633.947, 589.625, 544.422, 498.35699999999997, 451.449, 403.728, 355.23199999999997, 306.01099999999997, 256.122, 205.639, 154.64700000000002, 103.245, 51.547, -0.316, -52.2, -103.948, -155.392, -206.35299999999998, -256.647, -306.087, -354.486, -401.668, -447.464, -491.72, -534.3009999999999, -575.091, -613.998, -650.951, -685.904, -718.828, -749.7180000000001, -778.587, -805.4580000000001, -830.372, -853.378, -874.534, -893.905, -911.556, -927.559, -941.9860000000001, -954.9069999999999, -966.395, -976.52, -985.3489999999999, -992.946, -999.377, -1004.701, -1008.9760000000001, -1012.257, -1014.596, -1016.043, -1016.643, -1016.442, -1015.482, -1013.802, -1011.438, -1008.426, -1004.798, -1000.587, -995.821, -990.528, -984.735, -978.466, -971.743, -964.59, -957.0260000000001, -949.072, -940.7460000000001, -932.066, -923.048, -913.707, -904.06, -894.1189999999999, -883.8989999999999, -873.41, -862.668, -851.682, -840.462, -829.0210000000001, -817.367, -805.51, -793.4580000000001, -781.221, -768.807, -756.222, -743.4760000000001, -730.572, -717.5219999999999, -704.328, -691.0, -677.541, -663.957, -650.254, -636.437, -622.511, -608.481, -594.352, -580.128, -565.812, -551.41, -536.925, -522.361, -507.721, -493.009, -478.228, -463.381, -448.472, -433.504, -418.48, -403.4, -388.27099999999996, -373.093, -357.869, -342.601, -327.293, -311.945, -296.56, -281.142, -265.69, -250.207, -234.697, -219.15900000000002, -203.59599999999998, -188.012, -172.40400000000002, -156.77700000000002, -141.132, -125.471, -109.79299999999999, -94.102, -78.4, -62.68600000000001, -46.963, -31.233, -15.494000000000002, 0.249, 15.998, 31.749000000000002, 47.503, 63.258, 79.01100000000001, 94.764, 110.516, 126.26299999999999, 142.007, 157.745, 173.476, 189.202, 204.918, 220.625, 236.324, 252.01, 267.687, 283.35, 299.0, 314.63599999999997, 330.259, 345.865, 361.45599999999996, 377.029, 392.586, 408.12300000000005, 423.642, 439.14, 454.62, 470.077, 485.514, 500.92800000000005, 516.32, 531.688, 547.0319999999999, 562.351, 577.646, 592.915, 608.1569999999999, 623.372, 638.56, 653.72, 668.8510000000001, 683.954, 699.0269999999999, 714.07, 729.082, 744.064, 759.0139999999999, 773.931, 788.817, 803.669, 818.488, 833.273, 848.0239999999999, 862.7389999999999, 877.42, 892.065, 906.673, 921.245, 935.78, 950.2769999999999, 964.7360000000001, 979.1569999999999, 993.539, 1007.882, 1022.185, 1036.448, 1050.67, 1064.8519999999999, 1078.992, 1093.0910000000001, 1107.147, 1121.161, 1135.131, 1149.059, 1162.943, 1176.782, 1190.577, 1204.327, 1218.031, 1231.6889999999999, 1245.302, 1258.868, 1272.387, 1285.859, 1299.2830000000001, 1312.658, 1325.985, 1339.263, 1352.4920000000002, 1365.67, 1378.8, 1391.878, 1404.906, 1417.881, 1430.805, 1443.6779999999999, 1456.497, 1469.264, 1481.9779999999998, 1494.638, 1507.244, 1519.795, 1532.2910000000002, 1544.7320000000002, 1557.118, 1569.4470000000001, 1581.719, 1593.935, 1606.0929999999998, 1618.194, 1630.236, 1642.22, 1654.144, 1666.01, 1677.815, 1689.56, 1701.245, 1712.868, 1724.43, 1735.9289999999999, 1747.3670000000002, 1758.741, 1770.0529999999999, 1781.3, 1792.483, 1803.601, 1814.655, 1825.642, 1836.5629999999999, 1847.418, 1858.207, 1868.9279999999999, 1879.5810000000001, 1890.1660000000002, 1900.681, 1911.128, 1921.504, 1931.81, 1942.045, 1952.2089999999998, 1962.3020000000001, 1972.3220000000001, 1982.2679999999998, 1992.142, 2001.942, 2011.6670000000001, 2021.318, 2030.8929999999998, 2040.391, 2049.814, 2059.159, 2068.426, 2077.616, 2086.726, 2095.757, 2104.708, 2113.5789999999997, 2122.368, 2131.077, 2139.702, 2148.244, 2156.703, 2165.078, 2173.368, 2181.572, 2189.69, 2197.721, 2205.666, 2213.522, 2221.2889999999998, 2228.967, 2236.555, 2244.051, 2251.4570000000003, 2258.77, 2265.99, 2273.116, 2280.1479999999997, 2287.085, 2293.925, 2300.669, 2307.3160000000003, 2313.864, 2320.314, 2326.6620000000003, 2332.91, 2339.0570000000002, 2345.1020000000003, 2351.0429999999997, 2356.881, 2362.613, 2368.239, 2373.758, 2379.17, 2384.473, 2389.667, 2394.749, 2399.721, 2404.58, 2409.326, 2413.9570000000003, 2418.472, 2422.8720000000003, 2427.153, 2431.3160000000003, 2435.36, 2439.282, 2443.0820000000003, 2446.76, 2450.312, 2453.739, 2457.041, 2460.214, 2463.258, 2466.172, 2468.9539999999997, 2471.604, 2474.119, 2476.499, 2478.742, 2480.847, 2482.812, 2484.637, 2486.3179999999998, 2487.856, 2489.248, 2490.494, 2491.591, 2492.5370000000003, 2493.3320000000003, 2493.975, 2494.4610000000002, 2494.791, 2494.9629999999997, 2494.975, 2494.824, 2494.51, 2494.03, 2493.383, 2492.5660000000003, 2491.5789999999997, 2490.4179999999997, 2489.081, 2487.565, 2485.8720000000003, 2483.996, 2481.936, 2479.69, 2477.255, 2474.629, 2471.81, 2468.7960000000003, 2465.5820000000003, 2462.1679999999997, 2458.551, 2454.7270000000003, 2450.695, 2446.451, 2441.993, 2437.317, 2432.4210000000003, 2427.302, 2421.956, 2416.38, 2410.572, 2404.526, 2398.242, 2391.715, 2384.9410000000003, 2377.916, 2370.637, 2363.101, 2355.301, 2347.237, 2338.903, 2330.2929999999997, 2321.405, 2312.234, 2302.775, 2293.024, 2282.976, 2272.624, 2261.966, 2250.995, 2239.7070000000003, 2228.095, 2216.153, 2203.877, 2191.26, 2178.294, 2164.976, 2151.298, 2137.2529999999997, 2122.834, 2108.034, 2092.847, 2077.262, 2061.275, 2044.876, 2028.057, 2010.809, 1993.124, 1974.994, 1956.4070000000002, 1937.354, 1917.8270000000002, 1897.8129999999999, 1877.3029999999999, 1856.287, 1834.7520000000002, 1812.6860000000001, 1790.079, 1766.9170000000001, 1743.1870000000001, 1718.8770000000002, 1693.9720000000002, 1668.46, 1642.325, 1615.5520000000001, 1588.126, 1560.03, 1531.251, 1501.769, 1471.569, 1440.632, 1408.942, 1376.479, 1343.225, 1309.161, 1274.268, 1238.528, 1201.92, 1164.4260000000002, 1126.026, 1086.702, 1046.4360000000001, 1005.211, 963.0110000000001, 919.821, 875.628, 830.423, 784.197, 736.948, 688.675, 639.385, 589.0880000000001, 537.804, 485.56199999999995, 432.395, 378.35400000000004, 323.498, 267.899, 211.64700000000002, 154.845, 97.61399999999999, 40.09, -17.573, -75.205, -132.625, -189.637, -246.03799999999998, -301.625, -356.18800000000005, -409.53, -461.458, -511.798, -560.391, -607.104, -651.8240000000001, -694.465, -734.9630000000001, -773.2810000000001, -809.4, -843.327, -875.081, -904.697, -932.2239999999999, -957.7189999999999, -981.2460000000001, -1002.877, -1022.683, -1040.74, -1057.126, -1071.914, -1085.18, -1096.998, -1107.438, -1116.568, -1124.455, -1131.1589999999999, -1136.744, -1141.264, -1144.775, -1147.328, -1148.97, -1149.75, -1149.7089999999998, -1148.889, -1147.329, -1145.066, -1142.134, -1138.566, -1134.392, -1129.641, -1124.3419999999999, -1118.521, -1112.2, -1105.405, -1098.157, -1090.476, -1082.383, -1073.897, -1065.0339999999999, -1055.81, -1046.244, -1036.349, -1026.139, -1015.6289999999999, -1004.832, -993.758, -982.421, -970.832, -959.0, -946.937, -934.6519999999999, -922.154, -909.452, -896.553, -883.467, -870.202, -856.7639999999999, -843.16, -829.398, -815.4830000000001, -801.422, -787.22, -772.885, -758.42, -743.831, -729.123, -714.302, -699.372, -684.336, -669.201, -653.969, -638.644, -623.231, -607.734, -592.155, -576.499, -560.768, -544.966, -529.096, -513.1619999999999, -497.165, -481.10900000000004, -464.996, -448.83, -432.61199999999997, -416.345, -400.032, -383.67400000000004, -367.275, -350.836, -334.35900000000004, -317.847, -301.301, -284.723, -268.116, -251.48, -234.81799999999998, -218.132, -201.423, -184.69299999999998, -167.94299999999998, -151.175, -134.391, -117.59100000000001, -100.77799999999999, -83.95299999999999, -67.116, -50.27, -33.416, -16.554000000000002, 0.313, 17.185, 34.06, 50.938, 67.817, 84.696, 101.574, 118.45, 135.32299999999998, 152.192, 169.05599999999998, 185.91400000000002, 202.766, 219.609, 236.44400000000002, 253.269, 270.084, 286.887, 303.678, 320.45599999999996, 337.22, 353.97, 370.705, 387.423, 404.124, 420.80800000000005, 437.474, 454.12, 470.74699999999996, 487.353, 503.93800000000005, 520.502, 537.043, 553.56, 570.055, 586.524, 602.969, 619.388, 635.781, 652.146, 668.485, 684.795, 701.077, 717.33, 733.553, 749.745, 765.9069999999999, 782.038, 798.1360000000001, 814.202, 830.235, 846.2339999999999, 862.199, 878.13, 894.025, 909.885, 925.709, 941.4960000000001, 957.2460000000001, 972.9580000000001, 988.633, 1004.268, 1019.865, 1035.422, 1050.9389999999999, 1066.415, 1081.85, 1097.244, 1112.596, 1127.906, 1143.172, 1158.396, 1173.575, 1188.71, 1203.8010000000002, 1218.846, 1233.846, 1248.799, 1263.7060000000001, 1278.566, 1293.378, 1308.143, 1322.859, 1337.526, 1352.144, 1366.7120000000002, 1381.23, 1395.6979999999999, 1410.114, 1424.479, 1438.7910000000002, 1453.0520000000001, 1467.259, 1481.4129999999998, 1495.513, 1509.559, 1523.5510000000002, 1537.487, 1551.3670000000002, 1565.192, 1578.96, 1592.67, 1606.3239999999998, 1619.9189999999999, 1633.4560000000001, 1646.935, 1660.354, 1673.713, 1687.0120000000002, 1700.25, 1713.4270000000001, 1726.5420000000001, 1739.595, 1752.586, 1765.513, 1778.3770000000002, 1791.1770000000001, 1803.912, 1816.582, 1829.1860000000001, 1841.725, 1854.1960000000001, 1866.601, 1878.9379999999999, 1891.207, 1903.408, 1915.539, 1927.6, 1939.5910000000001, 1951.5120000000002, 1963.361, 1975.139, 1986.844, 1998.476, 2010.035, 2021.52, 2032.93, 2044.265, 2055.525, 2066.708, 2077.814, 2088.843, 2099.794, 2110.667, 2121.46, 2132.173, 2142.806, 2153.3579999999997, 2163.8289999999997, 2174.217, 2184.522, 2194.744, 2204.881, 2214.9339999999997, 2224.901, 2234.782, 2244.576, 2254.283, 2263.901, 2273.43, 2282.87, 2292.22, 2301.478, 2310.645, 2319.72, 2328.701, 2337.5879999999997, 2346.38, 2355.077, 2363.678, 2372.181, 2380.587, 2388.894, 2397.1020000000003, 2405.21, 2413.216, 2421.12, 2428.922, 2436.62, 2444.2129999999997, 2451.701, 2459.083, 2466.357, 2473.5229999999997, 2480.58, 2487.527, 2494.363, 2501.087, 2507.698, 2514.195, 2520.577, 2526.843, 2532.992, 2539.0229999999997, 2544.935, 2550.7270000000003, 2556.397, 2561.945, 2567.369, 2572.669, 2577.842, 2582.889, 2587.8070000000002, 2592.595, 2597.2529999999997, 2601.779, 2606.1710000000003, 2610.429, 2614.551, 2618.535, 2622.381, 2626.087, 2629.652, 2633.074, 2636.3509999999997, 2639.4829999999997, 2642.468, 2645.303, 2647.989, 2650.522, 2652.902, 2655.1259999999997, 2657.1940000000004, 2659.103, 2660.8520000000003, 2662.4390000000003, 2663.863, 2665.12, 2666.211, 2667.132, 2667.882, 2668.458, 2668.86, 2669.0840000000003, 2669.1290000000004, 2668.992, 2668.672, 2668.167, 2667.473, 2666.5890000000004, 2665.513, 2664.241, 2662.7729999999997, 2661.1040000000003, 2659.2329999999997, 2657.157, 2654.8740000000003, 2652.381, 2649.675, 2646.7529999999997, 2643.612, 2640.2509999999997, 2636.664, 2632.85, 2628.8059999999996, 2624.527, 2620.012, 2615.256, 2610.257, 2605.01, 2599.513, 2593.761, 2587.75, 2581.478, 2574.94, 2568.131, 2561.049, 2553.688, 2546.045, 2538.115, 2529.893, 2521.374, 2512.555, 2503.429, 2493.993, 2484.241, 2474.167, 2463.766, 2453.032, 2441.96, 2430.544, 2418.777, 2406.654, 2394.169, 2381.313, 2368.081, 2354.465, 2340.459, 2326.055, 2311.245, 2296.021, 2280.376, 2264.3, 2247.786, 2230.824, 2213.406, 2195.521, 2177.161, 2158.314, 2138.97, 2119.12, 2098.752, 2077.853, 2056.413, 2034.42, 2011.861, 1988.7220000000002, 1964.99, 1940.6529999999998, 1915.695, 1890.1, 1863.855, 1836.944, 1809.35, 1781.057, 1752.047, 1722.3020000000001, 1691.805, 1660.536, 1628.476, 1595.605, 1561.904, 1527.351, 1491.924, 1455.6029999999998, 1418.366, 1380.19, 1341.0529999999999, 1300.932, 1259.806, 1217.652, 1174.45, 1130.178, 1084.816, 1038.347, 990.753, 942.0219999999999, 892.1419999999999, 841.1060000000001, 788.909, 735.557, 681.055, 625.422, 568.681, 510.87, 452.033, 392.231, 331.54, 270.048, 207.865, 145.114, 81.94200000000001, 18.51, -45.0, -108.39200000000001, -171.456, -233.97400000000002, -295.718, -356.463, -415.98400000000004, -474.07099999999997, -530.526, -585.168, -637.8430000000001, -688.42, -736.795, -782.8889999999999, -826.6519999999999, -868.056, -907.097, -943.79, -978.166, -1010.2710000000001, -1040.162, -1067.904, -1093.569, -1117.233, -1138.976, -1158.879, -1177.02, -1193.48, -1208.337, -1221.667, -1233.5439999999999, -1244.04, -1253.22, -1261.152, -1267.896, -1273.513, -1278.057, -1281.639, -1284.141, -1285.777, -1286.538, -1286.4660000000001, -1285.601, -1283.98, -1281.641, -1278.618, -1274.942, -1270.643, -1265.751, -1260.2930000000001, -1254.2939999999999, -1247.778, -1240.769, -1233.289, -1225.359, -1216.997, -1208.223, -1199.053, -1189.506, -1179.598, -1169.3419999999999, -1158.754, -1147.848, -1136.635, -1125.13, -1113.344, -1101.288, -1088.973, -1076.41, -1063.607, -1050.576, -1037.3239999999998, -1023.86, -1010.194, -996.331, -982.2810000000001, -968.05, -953.6460000000001, -939.075, -924.3439999999999, -909.4580000000001, -894.424, -879.247, -863.933, -848.487, -832.914, -817.2189999999999, -801.4069999999999, -785.482, -769.449, -753.312, -737.075, -720.7410000000001, -704.316, -687.802, -671.202, -654.521, -637.762, -620.927, -604.02, -587.045, -570.003, -552.8969999999999, -535.732, -518.508, -501.228, -483.89599999999996, -466.51300000000003, -449.082, -431.605, -414.085, -396.522, -378.921, -361.282, -343.60699999999997, -325.899, -308.159, -290.389, -272.591, -254.767, -236.918, -219.046, -201.153, -183.239, -165.30700000000002, -147.359, -129.394, -111.416, -93.425, -75.423, -57.41, -39.389, -21.36, -3.326, 14.714, 32.758, 50.805, 68.85300000000001, 86.90100000000001, 104.949, 122.99600000000001, 141.039, 159.079, 177.115, 195.144, 213.167, 231.18200000000002, 249.18900000000002, 267.186, 285.173, 303.149, 321.113, 339.064, 357.001, 374.923, 392.83, 410.721, 428.595, 446.45099999999996, 464.288, 482.106, 499.904, 517.682, 535.438, 553.172, 570.883, 588.57, 606.2330000000001, 623.871, 641.484, 659.07, 676.6289999999999, 694.1610000000001, 711.665, 729.14, 746.585, 764.0010000000001, 781.385, 798.7389999999999, 816.06, 833.3489999999999, 850.605, 867.827, 885.0160000000001, 902.169, 919.2869999999999, 936.3689999999999, 953.414, 970.423, 987.3939999999999, 1004.326, 1021.22, 1038.075, 1054.89, 1071.664, 1088.3980000000001, 1105.09, 1121.741, 1138.348, 1154.913, 1171.435, 1187.912, 1204.345, 1220.733, 1237.075, 1253.371, 1269.62, 1285.823, 1301.9769999999999, 1318.0839999999998, 1334.142, 1350.151, 1366.11, 1382.019, 1397.8770000000002, 1413.684, 1429.4389999999999, 1445.142, 1460.793, 1476.39, 1491.933, 1507.4229999999998, 1522.8570000000002, 1538.236, 1553.56, 1568.8270000000002, 1584.0379999999998, 1599.191, 1614.286, 1629.3229999999999, 1644.3010000000002, 1659.22, 1674.079, 1688.8770000000002, 1703.615, 1718.2910000000002, 1732.905, 1747.457, 1761.9460000000001, 1776.371, 1790.7320000000002, 1805.0279999999998, 1819.26, 1833.425, 1847.524, 1861.557, 1875.5220000000002, 1889.4189999999999, 1903.2479999999998, 1917.0079999999998, 1930.6979999999999, 1944.318, 1957.8670000000002, 1971.345, 1984.751, 1998.085, 2011.346, 2024.533, 2037.646, 2050.6839999999997, 2063.647, 2076.534, 2089.344, 2102.077, 2114.732, 2127.3089999999997, 2139.806, 2152.224, 2164.562, 2176.8179999999998, 2188.993, 2201.085, 2213.095, 2225.021, 2236.862, 2248.619, 2260.29, 2271.874, 2283.3720000000003, 2294.781, 2306.1020000000003, 2317.334, 2328.476, 2339.528, 2350.488, 2361.355, 2372.13, 2382.812, 2393.399, 2403.89, 2414.286, 2424.585, 2434.786, 2444.888, 2454.8920000000003, 2464.795, 2474.598, 2484.298, 2493.896, 2503.391, 2512.781, 2522.0660000000003, 2531.244, 2540.315, 2549.279, 2558.133, 2566.877, 2575.511, 2584.032, 2592.4410000000003, 2600.736, 2608.916, 2616.98, 2624.927, 2632.757, 2640.467, 2648.0570000000002, 2655.525, 2662.8720000000003, 2670.094, 2677.1929999999998, 2684.165, 2691.01, 2697.7270000000003, 2704.315, 2710.772, 2717.097, 2723.289, 2729.347, 2735.2690000000002, 2741.054, 2746.7009999999996, 2752.208, 2757.574, 2762.797, 2767.8759999999997, 2772.81, 2777.597, 2782.235, 2786.723, 2791.06, 2795.244, 2799.2740000000003, 2803.147, 2806.862, 2810.417, 2813.812, 2817.0429999999997, 2820.1090000000004, 2823.009, 2825.74, 2828.301, 2830.69, 2832.9040000000005, 2834.9429999999998, 2836.803, 2838.4829999999997, 2839.9809999999998, 2841.2940000000003, 2842.421, 2843.3590000000004, 2844.107, 2844.6609999999996, 2845.0190000000002, 2845.18, 2845.14, 2844.897, 2844.449, 2843.7940000000003, 2842.927, 2841.847, 2840.552, 2839.0370000000003, 2837.301, 2835.34, 2833.152, 2830.7340000000004, 2828.0820000000003, 2825.1940000000004, 2822.065, 2818.6929999999998, 2815.074, 2811.205, 2807.083, 2802.703, 2798.062, 2793.157, 2787.9829999999997, 2782.5359999999996, 2776.813, 2770.809, 2764.5190000000002, 2757.94, 2751.067, 2743.8959999999997, 2736.422, 2728.639, 2720.5440000000003, 2712.13, 2703.393, 2694.327, 2684.927, 2675.187, 2665.1020000000003, 2654.6659999999997, 2643.8709999999996, 2632.7129999999997, 2621.1839999999997, 2609.278, 2596.989, 2584.3089999999997, 2571.231, 2557.7470000000003, 2543.849, 2529.531, 2514.784, 2499.599, 2483.968, 2467.882, 2451.3320000000003, 2434.308, 2416.801, 2398.8, 2380.2960000000003, 2361.276, 2341.732, 2321.651, 2301.021, 2279.83, 2258.065, 2235.714, 2212.764, 2189.2, 2165.007, 2140.172, 2114.679, 2088.512, 2061.655, 2034.0910000000001, 2005.8029999999999, 1976.7720000000002, 1946.98, 1916.4089999999999, 1885.037, 1852.845, 1819.8129999999999, 1785.9170000000001, 1751.1370000000002, 1715.4489999999998, 1678.83, 1641.257, 1602.704, 1563.148, 1522.5629999999999, 1480.924, 1438.205, 1394.381, 1349.4260000000002, 1303.316, 1256.025, 1207.532, 1157.8139999999999, 1106.851, 1054.624, 1001.1210000000001, 946.328, 890.2410000000001, 832.857, 774.183, 714.2310000000001, 653.026, 590.599, 526.998, 462.28, 396.523, 329.819, 262.278, 194.03099999999998, 125.23100000000001, 56.048, -13.325999999999999, -82.681, -151.793, -220.425, -288.33099999999996, -355.264, -420.981, -485.246, -547.839, -608.561, -667.232, -723.704, -777.8530000000001, -829.5880000000001, -878.8430000000001, -925.58, -969.7869999999999, -1011.471, -1050.66, -1087.396, -1121.737, -1153.747, -1183.5, -1211.076, -1236.557, -1260.027, -1281.5710000000001, -1301.275, -1319.219, -1335.487, -1350.1570000000002, -1363.306, -1375.005, -1385.3270000000002, -1394.3370000000002, -1402.1, -1408.6760000000002, -1414.1229999999998, -1418.496, -1421.846, -1424.223, -1425.672, -1426.239, -1425.964, -1424.888, -1423.045, -1420.474, -1417.2060000000001, -1413.2720000000002, -1408.703, -1403.5279999999998, -1397.773, -1391.4620000000002, -1384.621, -1377.2720000000002, -1369.4370000000001, -1361.135, -1352.388, -1343.2120000000002, -1333.626, -1323.6470000000002, -1313.2910000000002, -1302.573, -1291.506, -1280.106, -1268.385, -1256.356, -1244.03, -1231.42, -1218.537, -1205.39, -1191.99, -1178.346, -1164.4669999999999, -1150.364, -1136.0430000000001, -1121.513, -1106.781, -1091.856, -1076.744, -1061.453, -1045.988, -1030.356, -1014.564, -998.6160000000001, -982.52, -966.28, -949.9010000000001, -933.3889999999999, -916.7489999999999, -899.985, -883.102, -866.1039999999999, -848.9960000000001, -831.7810000000001, -814.4639999999999, -797.048, -779.538, -761.936, -744.2460000000001, -726.472, -708.617, -690.683, -672.675, -654.595, -636.445, -618.23, -599.95, -581.61, -563.211, -544.757, -526.249, -507.69, -489.082, -470.42800000000005, -451.72900000000004, -432.98800000000006, -414.20599999999996, -395.38599999999997, -376.53, -357.639, -338.716, -319.762, -300.779, -281.769, -262.733, -243.673, -224.59, -205.487, -186.364, -167.22400000000002, -148.067, -128.895, -109.71, -90.512, -71.304, -52.086000000000006, -32.86, -13.626, 5.6129999999999995, 24.857, 44.104, 63.353, 82.604, 101.855, 121.104, 140.352, 159.596, 178.83599999999998, 198.071, 217.3, 236.521, 255.734, 274.939, 294.133, 313.316, 332.48699999999997, 351.645, 370.79, 389.92, 409.035, 428.134, 447.216, 466.28, 485.325, 504.351, 523.356, 542.341, 561.304, 580.244, 599.161, 618.054, 636.922, 655.765, 674.582, 693.372, 712.1339999999999, 730.868, 749.573, 768.2489999999999, 786.8939999999999, 805.508, 824.091, 842.6419999999999, 861.159, 879.643, 898.0930000000001, 916.508, 934.888, 953.232, 971.538, 989.808, 1008.04, 1026.233, 1044.387, 1062.501, 1080.576, 1098.609, 1116.6, 1134.55, 1152.4569999999999, 1170.3210000000001, 1188.141, 1205.9160000000002, 1223.647, 1241.3319999999999, 1258.97, 1276.562, 1294.107, 1311.604, 1329.0529999999999, 1346.4520000000002, 1363.8029999999999, 1381.102, 1398.352, 1415.55, 1432.6960000000001, 1449.79, 1466.8310000000001, 1483.818, 1500.7520000000002, 1517.631, 1534.454, 1551.2220000000002, 1567.934, 1584.588, 1601.1860000000001, 1617.725, 1634.2060000000001, 1650.6270000000002, 1666.989, 1683.2910000000002, 1699.531, 1715.711, 1731.828, 1747.8829999999998, 1763.875, 1779.8020000000001, 1795.6660000000002, 1811.465, 1827.1979999999999, 1842.865, 1858.4660000000001, 1873.999, 1889.465, 1904.862, 1920.19, 1935.4479999999999, 1950.636, 1965.753, 1980.799, 1995.773, 2010.674, 2025.501, 2040.255, 2054.9339999999997, 2069.5370000000003, 2084.065, 2098.516, 2112.89, 2127.186, 2141.404, 2155.5429999999997, 2169.601, 2183.5789999999997, 2197.476, 2211.291, 2225.024, 2238.673, 2252.238, 2265.719, 2279.114, 2292.424, 2305.646, 2318.781, 2331.827, 2344.785, 2357.653, 2370.43, 2383.116, 2395.71, 2408.2110000000002, 2420.618, 2432.931, 2445.149, 2457.271, 2469.2960000000003, 2481.223, 2493.051, 2504.781, 2516.409, 2527.937, 2539.363, 2550.686, 2561.906, 2573.02, 2584.029, 2594.9320000000002, 2605.7270000000003, 2616.4139999999998, 2626.992, 2637.46, 2647.816, 2658.06, 2668.191, 2678.2070000000003, 2688.1079999999997, 2697.893, 2707.5609999999997, 2717.11, 2726.539, 2735.848, 2745.035, 2754.1, 2763.04, 2771.855, 2780.5440000000003, 2789.1059999999998, 2797.539, 2805.842, 2814.014, 2822.053, 2829.9590000000003, 2837.73, 2845.365, 2852.862, 2860.22, 2867.438, 2874.514, 2881.447, 2888.236, 2894.8790000000004, 2901.3740000000003, 2907.7209999999995, 2913.917, 2919.961, 2925.8509999999997, 2931.587, 2937.1659999999997, 2942.586, 2947.847, 2952.945, 2957.88, 2962.65, 2967.2529999999997, 2971.688, 2975.9509999999996, 2980.042, 2983.9590000000003, 2987.699, 2991.261, 2994.643, 2997.842, 3000.857, 3003.685, 3006.325, 3008.7729999999997, 3011.0290000000005, 3013.0890000000004, 3014.9509999999996, 3016.613, 3018.072, 3019.3259999999996, 3020.373, 3021.21, 3021.8340000000003, 3022.243, 3022.434, 3022.4040000000005, 3022.15, 3021.67, 3020.96, 3020.018, 3018.84, 3017.4240000000004, 3015.765, 3013.861, 3011.7090000000003, 3009.305, 3006.6459999999997, 3003.728, 3000.547, 2997.1, 2993.382, 2989.39, 2985.1209999999996, 2980.5690000000004, 2975.7309999999998, 2970.6020000000003, 2965.179, 2959.4559999999997, 2953.428, 2947.092, 2940.442, 2933.474, 2926.1809999999996, 2918.5609999999997, 2910.605, 2902.31, 2893.67, 2884.678, 2875.329, 2865.617, 2855.5359999999996, 2845.079, 2834.239, 2823.009, 2811.384, 2799.355, 2786.915, 2774.0570000000002, 2760.772, 2747.053, 2732.89, 2718.277, 2703.204, 2687.6620000000003, 2671.6409999999996, 2655.132, 2638.125, 2620.61, 2602.576, 2584.011, 2564.906, 2545.248, 2525.026, 2504.226, 2482.8360000000002, 2460.843, 2438.2329999999997, 2414.992, 2391.105, 2366.5570000000002, 2341.333, 2315.417, 2288.791, 2261.438, 2233.342, 2204.482, 2174.841, 2144.3979999999997, 2113.133, 2081.024, 2048.052, 2014.192, 1979.422, 1943.7179999999998, 1907.055, 1869.4089999999999, 1830.754, 1791.0620000000001, 1750.308, 1708.464, 1665.501, 1621.391, 1576.105, 1529.615, 1481.892, 1432.908, 1382.634, 1331.0439999999999, 1278.113, 1223.815, 1168.131, 1111.0410000000002, 1052.531, 992.5889999999999, 931.2139999999999, 868.404, 804.174, 738.54, 671.5369999999999, 603.2080000000001, 533.612, 462.825, 390.94199999999995, 318.077, 244.36599999999999, 169.965, 95.056, 19.84, -55.461000000000006, -130.606, -205.342, -279.407, -352.53, -424.449, -494.904, -563.654, -630.475, -695.17, -757.567, -817.528, -874.942, -929.732, -981.8480000000001, -1031.266, -1077.99, -1122.04, -1163.4589999999998, -1202.299, -1238.628, -1272.52, -1304.057, -1333.325, -1360.412, -1385.4070000000002, -1408.4, -1429.479, -1448.731, -1466.2379999999998, -1482.0829999999999, -1496.345, -1509.098, -1520.414, -1530.3629999999998, -1539.0079999999998, -1546.414, -1552.639, -1557.739, -1561.766, -1564.7720000000002, -1566.8029999999999, -1567.906, -1568.1229999999998, -1567.494, -1566.057, -1563.849, -1560.904, -1557.253, -1552.9289999999999, -1547.961, -1542.376, -1536.2, -1529.457, -1522.1729999999998, -1514.369, -1506.067, -1497.287, -1488.047, -1478.368, -1468.265, -1457.757, -1446.858, -1435.5839999999998, -1423.9489999999998, -1411.967, -1399.651, -1387.014, -1374.068, -1360.825, -1347.295, -1333.49, -1319.418, -1305.0910000000001, -1290.516, -1275.704, -1260.662, -1245.4, -1229.924, -1214.243, -1198.363, -1182.2930000000001, -1166.037, -1149.604, -1133.0, -1116.229, -1099.299, -1082.214, -1064.981, -1047.604, -1030.089, -1012.44, -994.6619999999999, -976.76, -958.738, -940.6010000000001, -922.352, -903.995, -885.535, -866.9739999999999, -848.317, -829.568, -810.7289999999999, -791.804, -772.796, -753.7080000000001, -734.544, -715.306, -695.9960000000001, -676.6189999999999, -657.176, -637.67, -618.104, -598.48, -578.8, -559.067, -539.284, -519.452, -499.57300000000004, -479.65, -459.685, -439.68, -419.63699999999994, -399.55699999999996, -379.44199999999995, -359.295, -339.11699999999996, -318.91, -298.676, -278.416, -258.131, -237.824, -217.49599999999998, -197.149, -176.78400000000002, -156.40200000000002, -136.005, -115.594, -95.171, -74.737, -54.293, -33.841, -13.382, 7.082999999999999, 27.552, 48.025, 68.5, 88.977, 109.45299999999999, 129.928, 150.401, 170.87099999999998, 191.33599999999998, 211.796, 232.24900000000002, 252.695, 273.133, 293.56, 313.978, 334.384, 354.778, 375.159, 395.525, 415.87699999999995, 436.213, 456.531, 476.833, 497.115, 517.379, 537.622, 557.844, 578.044, 598.222, 618.376, 638.506, 658.6110000000001, 678.691, 698.7439999999999, 718.7689999999999, 738.7669999999999, 758.7360000000001, 778.675, 798.585, 818.4630000000001, 838.31, 858.1239999999999, 877.905, 897.653, 917.3660000000001, 937.044, 956.686, 976.2919999999999, 995.8610000000001, 1015.3910000000001, 1034.884, 1054.337, 1073.75, 1093.123, 1112.455, 1131.745, 1150.992, 1170.197, 1189.358, 1208.474, 1227.546, 1246.572, 1265.5510000000002, 1284.484, 1303.37, 1322.207, 1340.996, 1359.735, 1378.424, 1397.0629999999999, 1415.65, 1434.1860000000001, 1452.6689999999999, 1471.1, 1489.476, 1507.7979999999998, 1526.065, 1544.277, 1562.433, 1580.531, 1598.5729999999999, 1616.556, 1634.481, 1652.346, 1670.152, 1687.8970000000002, 1705.5810000000001, 1723.203, 1740.763, 1758.26, 1775.693, 1793.0620000000001, 1810.366, 1827.604, 1844.777, 1861.882, 1878.92, 1895.89, 1912.7920000000001, 1929.6229999999998, 1946.385, 1963.0770000000002, 1979.6970000000001, 1996.244, 2012.72, 2029.122, 2045.4489999999998, 2061.703, 2077.88, 2093.982, 2110.007, 2125.955, 2141.824, 2157.615, 2173.326, 2188.9570000000003, 2204.507, 2219.975, 2235.361, 2250.6639999999998, 2265.883, 2281.0170000000003, 2296.0660000000003, 2311.029, 2325.905, 2340.694, 2355.394, 2370.005, 2384.526, 2398.956, 2413.295, 2427.542, 2441.695, 2455.755, 2469.72, 2483.589, 2497.361, 2511.0370000000003, 2524.614, 2538.093, 2551.471, 2564.749, 2577.925, 2590.998, 2603.968, 2616.834, 2629.594, 2642.248, 2654.795, 2667.2340000000004, 2679.5640000000003, 2691.783, 2703.8920000000003, 2715.888, 2727.772, 2739.5409999999997, 2751.195, 2762.7329999999997, 2774.1540000000005, 2785.4559999999997, 2796.639, 2807.702, 2818.6420000000003, 2829.46, 2840.1540000000005, 2850.723, 2861.1659999999997, 2871.4809999999998, 2881.6679999999997, 2891.725, 2901.651, 2911.4440000000004, 2921.1040000000003, 2930.6279999999997, 2940.0170000000003, 2949.268, 2958.38, 2967.3520000000003, 2976.1820000000002, 2984.869, 2993.4120000000003, 3001.809, 3010.059, 3018.16, 3026.11, 3033.909, 3041.555, 3049.045, 3056.3790000000004, 3063.554, 3070.57, 3077.4240000000004, 3084.115, 3090.6409999999996, 3097.0, 3103.191, 3109.212, 3115.06, 3120.7340000000004, 3126.2329999999997, 3131.553, 3136.6940000000004, 3141.653, 3146.428, 3151.0170000000003, 3155.4179999999997, 3159.6279999999997, 3163.6459999999997, 3167.47, 3171.0959999999995, 3174.5240000000003, 3177.7490000000003, 3180.7709999999997, 3183.587, 3186.1929999999998, 3188.5879999999997, 3190.7690000000002, 3192.7329999999997, 3194.4770000000003, 3196.0, 3197.298, 3198.368, 3199.2070000000003, 3199.813, 3200.1820000000002, 3200.312, 3200.198, 3199.8390000000004, 3199.23, 3198.368, 3197.25, 3195.8720000000003, 3194.2309999999998, 3192.323, 3190.1440000000002, 3187.691, 3184.96, 3181.946, 3178.645, 3175.054, 3171.1679999999997, 3166.982, 3162.492, 3157.6940000000004, 3152.583, 3147.155, 3141.403, 3135.322, 3128.909, 3122.157, 3115.0609999999997, 3107.616, 3099.815, 3091.653, 3083.1240000000003, 3074.2209999999995, 3064.938, 3055.2690000000002, 3045.2070000000003, 3034.745, 3023.875, 3012.591, 3000.885, 2988.7490000000003, 2976.175, 2963.155, 2949.6809999999996, 2935.744, 2921.335, 2906.4440000000004, 2891.063, 2875.1820000000002, 2858.79, 2841.877, 2824.4320000000002, 2806.4440000000004, 2787.903, 2768.796, 2749.11, 2728.8340000000003, 2707.953, 2686.4559999999997, 2664.328, 2641.555, 2618.121, 2594.013, 2569.2129999999997, 2543.705, 2517.473, 2490.5, 2462.766, 2434.252, 2404.942, 2374.813, 2343.845, 2312.016, 2279.305, 2245.689, 2211.143, 2175.644, 2139.166, 2101.683, 2063.169, 2023.596, 1982.9360000000001, 1941.1589999999999, 1898.236, 1854.1370000000002, 1808.83, 1762.285, 1714.4679999999998, 1665.35, 1614.896, 1563.076, 1509.8570000000002, 1455.211, 1399.106, 1341.516, 1282.415, 1221.782, 1159.596, 1095.844, 1030.52, 963.62, 895.154, 825.1389999999999, 753.6039999999999, 680.592, 606.161, 530.389, 453.369, 375.22, 296.08299999999997, 216.11900000000003, 135.517, 54.489, -26.730999999999998, -107.88799999999999, -188.71200000000002, -268.921, -348.228, -426.346, -502.995, -577.91, -650.846, -721.585, -789.933, -855.7330000000001, -918.8589999999999, -979.22, -1036.752, -1091.423, -1143.229, -1192.1860000000001, -1238.3310000000001, -1281.7169999999999, -1322.412, -1360.489, -1396.0339999999999, -1429.135, -1459.884, -1488.376, -1514.703, -1538.9589999999998, -1561.236, -1581.6229999999998, -1600.207, -1617.07, -1632.2939999999999, -1645.955, -1658.1270000000002, -1668.881, -1678.2579999999998, -1686.394, -1693.277, -1698.99, -1703.585, -1707.114, -1709.6270000000002, -1711.168, -1711.7820000000002, -1711.51, -1710.391, -1708.4620000000002, -1705.759, -1702.3139999999999, -1698.16, -1693.326, -1687.8410000000001, -1681.731, -1675.023, -1667.7420000000002, -1659.9089999999999, -1651.5479999999998, -1642.6779999999999, -1633.3210000000001, -1623.495, -1613.219, -1602.509, -1591.3829999999998, -1579.855, -1567.942, -1555.656, -1543.013, -1530.025, -1516.705, -1503.065, -1489.1170000000002, -1474.871, -1460.339, -1445.529, -1430.453, -1415.119, -1399.537, -1383.715, -1367.661, -1351.384, -1334.891, -1318.19, -1301.287, -1284.19, -1266.905, -1249.4389999999999, -1231.797, -1213.987, -1196.012, -1177.88, -1159.596, -1141.163, -1122.589, -1103.876, -1085.031, -1066.058, -1046.96, -1027.743, -1008.41, -988.965, -969.413, -949.757, -930.0, -910.1460000000001, -890.199, -870.1619999999999, -850.038, -829.83, -809.5419999999999, -789.176, -768.735, -748.222, -727.64, -706.992, -686.279, -665.505, -644.672, -623.7819999999999, -602.8380000000001, -581.842, -560.7959999999999, -539.703, -518.564, -497.381, -476.158, -454.895, -433.594, -412.25800000000004, -390.88699999999994, -369.485, -348.05300000000005, -326.592, -305.105, -283.592, -262.055, -240.497, -218.918, -197.32, -175.705, -154.07399999999998, -132.428, -110.77, -89.09899999999999, -67.418, -45.728, -24.03, -2.326, 19.384, 41.098, 62.81399999999999, 84.53200000000001, 106.251, 127.96799999999999, 149.684, 171.39700000000002, 193.106, 214.81, 236.507, 258.197, 279.879, 301.552, 323.214, 344.865, 366.504, 388.129, 409.74, 431.336, 452.915, 474.478, 496.023, 517.549, 539.055, 560.5409999999999, 582.005, 603.447, 624.866, 646.26, 667.63, 688.9739999999999, 710.2919999999999, 731.5830000000001, 752.845, 774.079, 795.2819999999999, 816.456, 837.5980000000001, 858.7080000000001, 879.7860000000001, 900.83, 921.84, 942.814, 963.753, 984.6560000000001, 1005.5210000000001, 1026.349, 1047.138, 1067.887, 1088.597, 1109.265, 1129.892, 1150.4769999999999, 1171.019, 1191.518, 1211.972, 1232.381, 1252.745, 1273.062, 1293.3319999999999, 1313.5539999999999, 1333.7279999999998, 1353.8529999999998, 1373.9289999999999, 1393.953, 1413.9270000000001, 1433.849, 1453.7179999999998, 1473.5339999999999, 1493.296, 1513.004, 1532.6570000000002, 1552.254, 1571.7939999999999, 1591.277, 1610.703, 1630.069, 1649.3770000000002, 1668.625, 1687.8120000000001, 1706.9379999999999, 1726.0020000000002, 1745.003, 1763.942, 1782.816, 1801.625, 1820.37, 1839.0479999999998, 1857.66, 1876.204, 1894.68, 1913.088, 1931.4260000000002, 1949.694, 1967.891, 1986.016, 2004.069, 2022.049, 2039.9560000000001, 2057.788, 2075.545, 2093.226, 2110.831, 2128.3579999999997, 2145.8070000000002, 2163.177, 2180.468, 2197.679, 2214.808, 2231.856, 2248.821, 2265.703, 2282.501, 2299.214, 2315.842, 2332.383, 2348.8360000000002, 2365.202, 2381.479, 2397.666, 2413.763, 2429.768, 2445.681, 2461.502, 2477.228, 2492.86, 2508.396, 2523.8360000000002, 2539.179, 2554.423, 2569.569, 2584.614, 2599.5589999999997, 2614.402, 2629.1420000000003, 2643.7790000000005, 2658.3109999999997, 2672.737, 2687.0570000000002, 2701.27, 2715.3740000000003, 2729.369, 2743.2529999999997, 2757.026, 2770.6859999999997, 2784.2329999999997, 2797.6659999999997, 2810.9829999999997, 2824.183, 2837.265, 2850.228, 2863.072, 2875.7940000000003, 2888.3940000000002, 2900.8709999999996, 2913.223, 2925.449, 2937.5490000000004, 2949.5209999999997, 2961.363, 2973.075, 2984.655, 2996.1009999999997, 3007.414, 3018.591, 3029.631, 3040.532, 3051.2940000000003, 3061.915, 3072.393, 3082.7270000000003, 3092.9159999999997, 3102.9590000000003, 3112.853, 3122.597, 3132.191, 3141.631, 3150.9179999999997, 3160.048, 3169.0209999999997, 3177.835, 3186.489, 3194.9790000000003, 3203.3059999999996, 3211.467, 3219.46, 3227.283, 3234.9359999999997, 3242.415, 3249.719, 3256.847, 3263.795, 3270.563, 3277.1479999999997, 3283.5490000000004, 3289.762, 3295.7859999999996, 3301.62, 3307.26, 3312.705, 3317.952, 3322.9990000000003, 3327.844, 3332.4829999999997, 3336.9159999999997, 3341.139, 3345.1490000000003, 3348.946, 3352.5240000000003, 3355.883, 3359.02, 3361.9309999999996, 3364.613, 3367.065, 3369.282, 3371.263, 3373.0029999999997, 3374.5009999999997, 3375.752, 3376.7529999999997, 3377.502, 3377.995, 3378.228, 3378.198, 3377.901, 3377.3340000000003, 3376.493, 3375.3740000000003, 3373.973, 3372.2859999999996, 3370.309, 3368.038, 3365.469, 3362.598, 3359.4190000000003, 3355.928, 3352.1209999999996, 3347.993, 3343.538, 3338.752, 3333.63, 3328.167, 3322.3559999999998, 3316.1929999999998, 3309.671, 3302.7859999999996, 3295.53, 3287.8990000000003, 3279.884, 3271.4809999999998, 3262.683, 3253.4809999999998, 3243.87, 3233.843, 3223.3909999999996, 3212.508, 3201.185, 3189.415, 3177.1890000000003, 3164.498, 3151.335, 3137.6890000000003, 3123.552, 3108.914, 3093.765, 3078.095, 3061.8940000000002, 3045.15, 3027.853, 3009.991, 2991.551, 2972.5229999999997, 2952.893, 2932.6490000000003, 2911.775, 2890.26, 2868.0890000000004, 2845.245, 2821.715, 2797.482, 2772.53, 2746.842, 2720.4, 2693.1859999999997, 2665.1809999999996, 2636.365, 2606.719, 2576.221, 2544.85, 2512.584, 2479.399, 2445.272, 2410.177, 2374.09, 2336.9829999999997, 2298.83, 2259.6020000000003, 2219.269, 2177.804, 2135.173, 2091.347, 2046.2920000000001, 1999.975, 1952.3629999999998, 1903.421, 1853.114, 1801.406, 1748.264, 1693.65, 1637.53, 1579.871, 1520.638, 1459.8010000000002, 1397.33, 1333.2, 1267.387, 1199.875, 1130.652, 1059.713, 987.063, 912.716, 836.7, 759.057, 679.842, 599.134, 517.0269999999999, 433.644, 349.125, 263.64099999999996, 177.389, 90.588, 3.485, -83.65299999999999, -170.53799999999998, -256.872, -342.346, -426.652, -509.49, -590.571, -669.6289999999999, -746.42, -820.735, -892.3960000000001, -961.2589999999999, -1027.218, -1090.198, -1150.1580000000001, -1207.0819999999999, -1260.984, -1311.895, -1359.868, -1404.9679999999998, -1447.2720000000002, -1486.866, -1523.842, -1558.295, -1590.3239999999998, -1620.026, -1647.5, -1672.844, -1696.149, -1717.509, -1737.0120000000002, -1754.744, -1770.787, -1785.2179999999998, -1798.1129999999998, -1809.5439999999999, -1819.5770000000002, -1828.279, -1835.7089999999998, -1841.925, -1846.983, -1850.9360000000001, -1853.832, -1855.7179999999998, -1856.64, -1856.639, -1855.755, -1854.026, -1851.487, -1848.174, -1844.118, -1839.35, -1833.899, -1827.793, -1821.057, -1813.719, -1805.8, -1797.325, -1788.3139999999999, -1778.787, -1768.766, -1758.267, -1747.31, -1735.912, -1724.088, -1711.854, -1699.226, -1686.2160000000001, -1672.84, -1659.111, -1645.04, -1630.639, -1615.921, -1600.896, -1585.575, -1569.9679999999998, -1554.085, -1537.935, -1521.527, -1504.871, -1487.974, -1470.844, -1453.489, -1435.918, -1418.136, -1400.151, -1381.969, -1363.5970000000002, -1345.0420000000001, -1326.309, -1307.404, -1288.3339999999998, -1269.1019999999999, -1249.715, -1230.178, -1210.496, -1190.673, -1170.714, -1150.623, -1130.406, -1110.065, -1089.606, -1069.032, -1048.347, -1027.555, -1006.66, -985.664, -964.572, -943.3860000000001, -922.1110000000001, -900.7489999999999, -879.303, -857.7760000000001, -836.172, -814.493, -792.7410000000001, -770.92, -749.0319999999999, -727.079, -705.065, -682.9910000000001, -660.86, -638.675, -616.437, -594.149, -571.812, -549.43, -527.004, -504.536, -482.027, -459.481, -436.899, -414.283, -391.634, -368.954, -346.245, -323.509, -300.748, -277.962, -255.15400000000002, -232.326, -209.47799999999998, -186.612, -163.73, -140.833, -117.92299999999999, -95.001, -72.068, -49.126000000000005, -26.176, -3.219, 19.743, 42.708999999999996, 65.678, 88.648, 111.619, 134.589, 157.55700000000002, 180.52200000000002, 203.483, 226.438, 249.387, 272.329, 295.26099999999997, 318.184, 341.096, 363.99699999999996, 386.885, 409.75800000000004, 432.61699999999996, 455.461, 478.287, 501.096, 523.886, 546.6569999999999, 569.4069999999999, 592.136, 614.842, 637.525, 660.184, 682.818, 705.426, 728.008, 750.561, 773.087, 795.5830000000001, 818.048, 840.4830000000001, 862.8860000000001, 885.257, 907.5939999999999, 929.8969999999999, 952.164, 974.3960000000001, 996.591, 1018.7489999999999, 1040.869, 1062.95, 1084.991, 1106.991, 1128.95, 1150.868, 1172.742, 1194.573, 1216.359, 1238.101, 1259.797, 1281.4460000000001, 1303.048, 1324.601, 1346.106, 1367.5620000000001, 1388.967, 1410.3220000000001, 1431.624, 1452.875, 1474.0720000000001, 1495.215, 1516.3029999999999, 1537.3370000000002, 1558.3139999999999, 1579.234, 1600.0970000000002, 1620.902, 1641.6470000000002, 1662.3329999999999, 1682.9589999999998, 1703.523, 1724.025, 1744.465, 1764.842, 1785.154, 1805.402, 1825.5839999999998, 1845.7, 1865.749, 1885.73, 1905.642, 1925.486, 1945.259, 1964.961, 1984.592, 2004.151, 2023.6370000000002, 2043.049, 2062.387, 2081.649, 2100.835, 2119.944, 2138.976, 2157.929, 2176.803, 2195.597, 2214.31, 2232.942, 2251.492, 2269.958, 2288.34, 2306.638, 2324.849, 2342.975, 2361.013, 2378.9629999999997, 2396.824, 2414.596, 2432.276, 2449.865, 2467.362, 2484.766, 2502.075, 2519.29, 2536.408, 2553.43, 2570.353, 2587.179, 2603.904, 2620.529, 2637.053, 2653.474, 2669.792, 2686.006, 2702.114, 2718.116, 2734.011, 2749.797, 2765.474, 2781.0409999999997, 2796.4959999999996, 2811.8390000000004, 2827.0679999999998, 2842.183, 2857.1820000000002, 2872.0640000000003, 2886.829, 2901.475, 2916.0, 2930.405, 2944.687, 2958.8459999999995, 2972.88, 2986.788, 3000.5690000000004, 3014.222, 3027.745, 3041.137, 3054.3979999999997, 3067.525, 3080.5170000000003, 3093.373, 3106.092, 3118.673, 3131.113, 3143.4120000000003, 3155.5690000000004, 3167.5809999999997, 3179.448, 3191.167, 3202.738, 3214.159, 3225.428, 3236.5440000000003, 3247.506, 3258.3109999999997, 3268.958, 3279.446, 3289.7729999999997, 3299.9359999999997, 3309.9359999999997, 3319.7690000000002, 3329.434, 3338.929, 3348.252, 3357.403, 3366.3779999999997, 3375.175, 3383.7940000000003, 3392.2309999999998, 3400.486, 3408.555, 3416.437, 3424.13, 3431.631, 3438.9390000000003, 3446.052, 3452.966, 3459.68, 3466.191, 3472.498, 3478.597, 3484.487, 3490.164, 3495.627, 3500.873, 3505.8990000000003, 3510.702, 3515.28, 3519.6290000000004, 3523.748, 3527.634, 3531.282, 3534.692, 3537.8579999999997, 3540.7790000000005, 3543.4509999999996, 3545.87, 3548.035, 3549.94, 3551.583, 3552.96, 3554.0690000000004, 3554.9040000000005, 3555.4629999999997, 3555.741, 3555.735, 3555.441, 3554.8540000000003, 3553.9709999999995, 3552.7870000000003, 3551.298, 3549.4990000000003, 3547.386, 3544.955, 3542.2, 3539.117, 3535.7, 3531.945, 3527.847, 3523.3990000000003, 3518.597, 3513.4359999999997, 3507.908, 3502.009, 3495.732, 3489.07, 3482.0190000000002, 3474.571, 3466.719, 3458.4570000000003, 3449.778, 3440.6740000000004, 3431.137, 3421.1609999999996, 3410.736, 3399.8559999999998, 3388.512, 3376.696, 3364.397, 3351.6079999999997, 3338.3190000000004, 3324.52, 3310.202, 3295.3540000000003, 3279.966, 3264.027, 3247.526, 3230.452, 3212.7909999999997, 3194.533, 3175.664, 3156.171, 3136.042, 3115.261, 3093.815, 3071.6890000000003, 3048.867, 3025.333, 3001.072, 2976.065, 2950.296, 2923.7459999999996, 2896.3959999999997, 2868.228, 2839.22, 2809.3520000000003, 2778.6020000000003, 2746.947, 2714.366, 2680.833, 2646.324, 2610.813, 2574.275, 2536.679, 2498.0, 2458.206, 2417.269, 2375.156, 2331.8360000000002, 2287.275, 2241.44, 2194.294, 2145.801, 2095.927, 2044.631, 1991.878, 1937.628, 1881.8429999999998, 1824.483, 1765.511, 1704.889, 1642.579, 1578.547, 1512.76, 1445.1879999999999, 1375.8029999999999, 1304.586, 1231.521, 1156.601, 1079.825, 1001.206, 920.7689999999999, 838.553, 754.615, 669.029, 581.895, 493.333, 403.48900000000003, 312.54, 220.687, 128.161, 35.218, -57.858999999999995, -150.77, -243.197, -334.81199999999995, -425.288, -514.3009999999999, -601.5409999999999, -686.717, -769.566, -849.8560000000001, -927.3910000000001, -1002.01, -1073.59, -1142.045, -1207.32, -1269.395, -1328.274, -1383.987, -1436.582, -1486.125, -1532.695, -1576.376, -1617.266, -1655.4620000000002, -1691.067, -1724.183, -1754.9129999999998, -1783.359, -1809.621, -1833.793, -1855.9720000000002, -1876.2479999999998, -1894.707, -1911.432, -1926.503, -1939.997, -1951.984, -1962.5339999999999, -1971.713, -1979.5810000000001, -1986.2, -1991.6229999999998, -1995.9029999999998, -1999.092, -2001.236, -2002.381, -2002.569, -2001.842, -2000.236, -1997.79, -1994.539, -1990.513, -1985.746, -1980.266, -1974.1029999999998, -1967.2839999999999, -1959.832, -1951.773, -1943.132, -1933.9289999999999, -1924.185, -1913.921, -1903.156, -1891.9089999999999, -1880.1970000000001, -1868.037, -1855.444, -1842.435, -1829.025, -1815.226, -1801.0529999999999, -1786.519, -1771.636, -1756.4160000000002, -1740.87, -1725.009, -1708.845, -1692.386, -1675.644, -1658.6270000000002, -1641.345, -1623.805, -1606.0179999999998, -1587.989, -1569.7279999999998, -1551.2420000000002, -1532.539, -1513.624, -1494.506, -1475.19, -1455.683, -1435.9920000000002, -1416.121, -1396.0770000000002, -1375.865, -1355.49, -1334.9579999999999, -1314.274, -1293.443, -1272.469, -1251.357, -1230.111, -1208.736, -1187.236, -1165.615, -1143.877, -1122.025, -1100.0639999999999, -1077.997, -1055.828, -1033.56, -1011.196, -988.74, -966.195, -943.563, -920.8489999999999, -898.054, -875.182, -852.2360000000001, -829.2180000000001, -806.13, -782.9760000000001, -759.758, -736.4789999999999, -713.14, -689.7439999999999, -666.294, -642.7909999999999, -619.239, -595.638, -571.991, -548.3009999999999, -524.569, -500.79699999999997, -476.98699999999997, -453.14099999999996, -429.26099999999997, -405.348, -381.405, -357.43300000000005, -333.434, -309.41, -285.361, -261.29, -237.199, -213.08900000000003, -188.96099999999998, -164.817, -140.658, -116.48700000000001, -92.303, -68.109, -43.907, -19.695999999999998, 4.52, 28.741999999999997, 52.967, 77.194, 101.42299999999999, 125.65100000000001, 149.878, 174.10299999999998, 198.32299999999998, 222.53900000000002, 246.74900000000002, 270.952, 295.14599999999996, 319.33099999999996, 343.506, 367.66900000000004, 391.819, 415.95599999999996, 440.07800000000003, 464.184, 488.273, 512.345, 536.3969999999999, 560.43, 584.442, 608.433, 632.401, 656.345, 680.265, 704.159, 728.0260000000001, 751.867, 775.679, 799.462, 823.215, 846.937, 870.627, 894.285, 917.909, 941.4989999999999, 965.053, 988.571, 1012.053, 1035.496, 1058.901, 1082.267, 1105.5919999999999, 1128.876, 1152.118, 1175.318, 1198.474, 1221.585, 1244.652, 1267.672, 1290.646, 1313.5720000000001, 1336.4489999999998, 1359.2779999999998, 1382.057, 1404.7839999999999, 1427.461, 1450.085, 1472.656, 1495.1729999999998, 1517.635, 1540.0420000000001, 1562.3929999999998, 1584.6860000000001, 1606.922, 1629.099, 1651.217, 1673.275, 1695.2720000000002, 1717.207, 1739.08, 1760.89, 1782.635, 1804.316, 1825.931, 1847.479, 1868.961, 1890.374, 1911.719, 1932.994, 1954.1989999999998, 1975.3329999999999, 1996.394, 2017.3829999999998, 2038.299, 2059.14, 2079.905, 2100.595, 2121.208, 2141.743, 2162.2, 2182.578, 2202.875, 2223.091, 2243.226, 2263.278, 2283.246, 2303.13, 2322.929, 2342.6420000000003, 2362.268, 2381.805, 2401.255, 2420.614, 2439.883, 2459.061, 2478.147, 2497.139, 2516.0370000000003, 2534.84, 2553.547, 2572.157, 2590.669, 2609.083, 2627.3959999999997, 2645.6090000000004, 2663.7209999999995, 2681.7290000000003, 2699.634, 2717.435, 2735.1290000000004, 2752.717, 2770.197, 2787.5690000000004, 2804.83, 2821.9809999999998, 2839.02, 2855.945, 2872.757, 2889.453, 2906.033, 2922.4959999999996, 2938.84, 2955.0640000000003, 2971.1679999999997, 2987.1490000000003, 3003.007, 3018.741, 3034.349, 3049.8309999999997, 3065.184, 3080.408, 3095.502, 3110.4640000000004, 3125.292, 3139.986, 3154.5440000000003, 3168.966, 3183.248, 3197.3909999999996, 3211.393, 3225.252, 3238.967, 3252.5359999999996, 3265.9590000000003, 3279.2329999999997, 3292.357, 3305.329, 3318.1479999999997, 3330.813, 3343.322, 3355.673, 3367.864, 3379.895, 3391.763, 3403.466, 3415.0029999999997, 3426.373, 3437.572, 3448.6009999999997, 3459.4559999999997, 3470.135, 3480.638, 3490.961, 3501.1040000000003, 3511.0640000000003, 3520.8390000000004, 3530.427, 3539.8259999999996, 3549.035, 3558.05, 3566.869, 3575.491, 3583.913, 3592.133, 3600.1490000000003, 3607.9570000000003, 3615.5570000000002, 3622.945, 3630.118, 3637.0759999999996, 3643.8140000000003, 3650.33, 3656.6220000000003, 3662.6859999999997, 3668.5209999999997, 3674.123, 3679.489, 3684.616, 3689.502, 3694.1440000000002, 3698.5370000000003, 3702.68, 3706.5690000000004, 3710.2, 3713.571, 3716.678, 3719.5170000000003, 3722.085, 3724.3779999999997, 3726.393, 3728.1259999999997, 3729.572, 3730.7290000000003, 3731.591, 3732.156, 3732.4179999999997, 3732.3740000000003, 3732.0190000000002, 3731.348, 3730.357, 3729.0409999999997, 3727.3959999999997, 3725.4159999999997, 3723.0959999999995, 3720.4320000000002, 3717.4190000000003, 3714.0490000000004, 3710.3190000000004, 3706.223, 3701.7540000000004, 3696.907, 3691.676, 3686.054, 3680.035, 3673.613, 3666.781, 3659.531, 3651.857, 3643.7509999999997, 3635.2059999999997, 3626.215, 3616.7690000000002, 3606.86, 3596.48, 3585.62, 3574.272, 3562.426, 3550.074, 3537.204, 3523.808, 3509.8759999999997, 3495.397, 3480.36, 3464.7529999999997, 3448.565, 3431.785, 3414.401, 3396.3990000000003, 3377.7670000000003, 3358.491, 3338.558, 3317.952, 3296.66, 3274.6659999999997, 3251.953, 3228.507, 3204.309, 3179.342, 3153.59, 3127.032, 3099.6479999999997, 3071.42, 3042.327, 3012.3459999999995, 2981.4559999999997, 2949.634, 2916.855, 2883.0959999999995, 2848.3309999999997, 2812.532, 2775.672, 2737.725, 2698.658, 2658.4440000000004, 2617.05, 2574.442, 2530.589, 2485.455, 2439.006, 2391.203, 2342.01, 2291.387, 2239.295, 2185.694, 2130.544, 2073.8, 2015.4229999999998, 1955.37, 1893.599, 1830.068, 1764.736, 1697.567, 1628.521, 1557.566, 1484.671, 1409.8110000000001, 1332.967, 1254.128, 1173.292, 1090.4660000000001, 1005.674, 918.952, 830.3560000000001, 739.961, 647.863, 554.188, 459.084, 362.73199999999997, 265.339, 167.145, 68.417, -30.551, -129.442, -227.921, -325.643, -422.25800000000004, -517.423, -610.802, -702.085, -790.9860000000001, -877.2510000000001, -960.665, -1041.048, -1118.263, -1192.208, -1262.82, -1330.069, -1393.951, -1454.494, -1511.7420000000002, -1565.76, -1616.626, -1664.4279999999999, -1709.264, -1751.236, -1790.45, -1827.013, -1861.033, -1892.615, -1921.865, -1948.884, -1973.7720000000002, -1996.6229999999998, -2017.53, -2036.58, -2053.859, -2069.474, -2083.4179999999997, -2095.847, -2106.804, -2116.355, -2124.561, -2131.482, -2137.176, -2141.694, -2145.0879999999997, -2147.406, -2148.694, -2148.994, -2148.349, -2146.7960000000003, -2144.374, -2141.117, -2137.058, -2132.23, -2126.6639999999998, -2120.387, -2113.427, -2105.8089999999997, -2097.561, -2088.7039999999997, -2079.262, -2069.255, -2058.705, -2047.6329999999998, -2036.055, -2023.991, -2011.457, -1998.47, -1985.046, -1971.2, -1956.9470000000001, -1942.3, -1927.273, -1911.878, -1896.128, -1880.035, -1863.61, -1846.8629999999998, -1829.807, -1812.45, -1794.8020000000001, -1776.8729999999998, -1758.672, -1740.207, -1721.487, -1702.519, -1683.3129999999999, -1663.875, -1644.213, -1624.3329999999999, -1604.243, -1583.9489999999998, -1563.4579999999999, -1542.775, -1521.906, -1500.858, -1479.636, -1458.245, -1436.691, -1414.9779999999998, -1393.112, -1371.0970000000002, -1348.9389999999999, -1326.641, -1304.208, -1281.645, -1258.954, -1236.142, -1213.211, -1190.164, -1167.007, -1143.743, -1120.374, -1096.904, -1073.338, -1049.677, -1025.925, -1002.086, -978.1619999999999, -954.1560000000001, -930.071, -905.91, -881.675, -857.37, -832.9960000000001, -808.556, -784.054, -759.49, -734.8689999999999, -710.191, -685.459, -660.676, -635.8430000000001, -610.9630000000001, -586.038, -561.07, -536.06, -511.01099999999997, -485.925, -460.80400000000003, -435.649, -410.462, -385.245, -360.001, -334.72900000000004, -309.433, -284.113, -258.772, -233.41099999999997, -208.03099999999998, -182.635, -157.22299999999998, -131.798, -106.36, -80.911, -55.452, -29.986, -4.513, 20.965999999999998, 46.449, 71.934, 97.421, 122.90899999999999, 148.395, 173.87900000000002, 199.36, 224.835, 250.305, 275.768, 301.222, 326.66700000000003, 352.101, 377.524, 402.93300000000005, 428.329, 453.71, 479.075, 504.42199999999997, 529.752, 555.062, 580.352, 605.621, 630.867, 656.09, 681.289, 706.462, 731.6089999999999, 756.7289999999999, 781.821, 806.883, 831.916, 856.9169999999999, 881.887, 906.823, 931.7260000000001, 956.5939999999999, 981.427, 1006.2230000000001, 1030.981, 1055.701, 1080.382, 1105.0230000000001, 1129.623, 1154.18, 1178.6960000000001, 1203.167, 1227.594, 1251.976, 1276.312, 1300.6, 1324.8410000000001, 1349.033, 1373.175, 1397.267, 1420.816, 1444.8039999999999, 1468.7379999999998, 1492.618, 1516.444, 1540.214, 1563.9279999999999, 1587.585, 1611.184, 1634.724, 1658.205, 1681.625, 1704.984, 1728.28, 1751.514, 1774.684, 1797.789, 1820.828, 1843.8020000000001, 1866.7079999999999, 1889.546, 1912.316, 1935.016, 1957.645, 1980.203, 2002.6879999999999, 2025.101, 2047.4389999999999, 2069.703, 2091.891, 2114.0029999999997, 2136.0370000000003, 2157.993, 2179.87, 2201.667, 2223.383, 2245.0170000000003, 2266.5679999999998, 2288.036, 2309.42, 2330.718, 2351.93, 2373.054, 2394.091, 2415.038, 2435.896, 2456.6620000000003, 2477.337, 2497.919, 2518.408, 2538.802, 2559.1, 2579.301, 2599.405, 2619.41, 2639.316, 2659.1209999999996, 2678.825, 2698.426, 2717.9240000000004, 2737.316, 2756.603, 2775.784, 2794.8559999999998, 2813.82, 2832.6740000000004, 2851.417, 2870.047, 2888.565, 2906.968, 2925.256, 2943.427, 2961.48, 2979.414, 2997.228, 3014.921, 3032.492, 3049.938, 3067.26, 3084.4559999999997, 3101.525, 3118.4640000000004, 3135.2740000000003, 3151.953, 3168.4990000000003, 3184.9120000000003, 3201.1890000000003, 3217.33, 3233.333, 3249.197, 3264.92, 3280.5009999999997, 3295.9390000000003, 3311.2309999999998, 3326.3779999999997, 3341.3759999999997, 3356.225, 3370.923, 3385.469, 3399.861, 3414.097, 3428.176, 3442.0959999999995, 3455.8559999999998, 3469.453, 3482.887, 3496.155, 3509.256, 3522.188, 3534.949, 3547.538, 3559.952, 3572.1890000000003, 3584.2490000000003, 3596.1279999999997, 3607.825, 3619.3379999999997, 3630.664, 3641.803, 3652.7509999999997, 3663.507, 3674.0690000000004, 3684.434, 3694.599, 3704.5640000000003, 3714.3259999999996, 3723.881, 3733.2290000000003, 3742.366, 3751.29, 3759.998, 3768.489, 3776.759, 3784.805, 3792.6259999999997, 3800.219, 3807.58, 3814.7070000000003, 3821.597, 3828.2470000000003, 3834.655, 3840.816, 3846.7290000000003, 3852.39, 3857.795, 3862.942, 3867.827, 3872.446, 3876.797, 3880.8759999999997, 3884.679, 3888.203, 3891.4429999999998, 3894.397, 3897.059, 3899.427, 3901.495, 3903.261, 3904.719, 3905.865, 3906.696, 3907.2059999999997, 3907.3909999999996, 3907.245, 3906.765, 3905.946, 3904.781, 3903.2659999999996, 3901.3959999999997, 3899.1659999999997, 3896.5690000000004, 3893.6, 3890.2540000000004, 3886.5240000000003, 3882.403, 3877.887, 3872.969, 3867.6409999999996, 3861.8979999999997, 3855.732, 3849.136, 3842.1020000000003, 3834.6240000000003, 3826.6929999999998, 3818.303, 3809.4440000000004, 3800.1079999999997, 3790.2870000000003, 3779.972, 3769.1540000000005, 3757.823, 3745.97, 3733.586, 3720.659, 3707.18, 3693.137, 3678.52, 3663.3179999999998, 3647.5170000000003, 3631.1079999999997, 3614.075, 3596.407, 3578.091, 3559.113, 3539.4590000000003, 3519.113, 3498.06, 3476.2859999999996, 3453.7729999999997, 3430.506, 3406.466, 3381.637, 3355.9990000000003, 3329.533, 3302.219, 3274.038, 3244.968, 3214.985, 3184.0690000000004, 3152.196, 3119.34, 3085.4770000000003, 3050.5809999999997, 3014.623, 2977.577, 2939.4120000000003, 2900.099, 2859.6079999999997, 2817.9040000000005, 2774.955, 2730.7270000000003, 2685.1820000000002, 2638.2859999999996, 2589.998, 2540.282, 2489.095, 2436.397, 2382.146, 2326.297, 2268.8070000000002, 2209.631, 2148.724, 2086.04, 2021.5339999999999, 1955.161, 1886.876, 1816.638, 1744.404, 1670.138, 1593.805, 1515.3770000000002, 1434.83, 1352.15, 1267.3319999999999, 1180.379, 1091.312, 1000.166, 906.993, 811.8689999999999, 714.89, 616.181, 515.8969999999999, 414.218, 311.36, 207.57, 103.125, -1.6680000000000001, -106.479, -210.956, -314.736, -417.44800000000004, -518.727, -618.216, -715.581, -810.5160000000001, -902.7439999999999, -992.029, -1078.1760000000002, -1161.028, -1240.473, -1316.434, -1388.871, -1457.776, -1523.17, -1585.094, -1643.611, -1698.8, -1750.751, -1799.5629999999999, -1845.3410000000001, -1888.1960000000001, -1928.237, -1965.578, -2000.33, -2032.601, -2062.498, -2090.126, -2115.5860000000002, -2138.973, -2160.381, -2179.899, -2197.611, -2213.599, -2227.94, -2240.7070000000003, -2251.97, -2261.7960000000003, -2270.2470000000003, -2277.384, -2283.263, -2287.937, -2291.458, -2293.875, -2295.2329999999997, -2295.577, -2294.948, -2293.384, -2290.924, -2287.603, -2283.455, -2278.513, -2272.808, -2266.367, -2259.22, -2251.3920000000003, -2242.909, -2233.7960000000003, -2224.075, -2213.768, -2202.896, -2191.48, -2179.538, -2167.09, -2154.152, -2140.741, -2126.874, -2112.5660000000003, -2097.833, -2082.688, -2067.145, -2051.217, -2034.9170000000001, -2018.257, -2001.2479999999998, -1983.902, -1966.23, -1948.2420000000002, -1929.9479999999999, -1911.359, -1892.4820000000002, -1873.3270000000002, -1853.904, -1834.219, -1814.2820000000002, -1794.1, -1773.68, -1753.031, -1732.158, -1711.069, -1689.771, -1668.269, -1646.5710000000001, -1624.682, -1602.6070000000002, -1580.3529999999998, -1557.925, -1535.329, -1512.568, -1489.649, -1466.576, -1443.355, -1419.9879999999998, -1396.4820000000002, -1372.84, -1349.066, -1325.165, -1301.141, -1276.997, -1252.737, -1228.366, -1203.885, -1179.3, -1154.613, -1129.828, -1104.947, -1079.975, -1054.913, -1029.766, -1004.5360000000001, -979.225, -953.837, -928.375, -902.841, -877.237, -851.567, -825.832, -800.0360000000001, -774.18, -748.2669999999999, -722.299, -696.278, -670.2080000000001, -644.0880000000001, -617.923, -591.714, -565.462, -539.1709999999999, -512.841, -486.475, -460.075, -433.64300000000003, -407.17900000000003, -380.68699999999995, -354.167, -327.622, -301.05400000000003, -274.46299999999997, -247.852, -221.22099999999998, -194.574, -167.91099999999997, -141.233, -114.54299999999999, -87.84100000000001, -61.13, -34.41, -7.683, 19.049, 45.785, 72.525, 99.265, 126.006, 152.746, 179.483, 206.217, 232.946, 259.66900000000004, 286.384, 313.091, 339.788, 366.473, 393.147, 419.80800000000005, 446.454, 473.084, 499.69800000000004, 526.294, 552.872, 579.429, 605.965, 632.479, 658.97, 685.437, 711.878, 738.294, 764.682, 791.041, 817.372, 843.672, 869.941, 896.177, 922.38, 948.549, 974.683, 1000.78, 1026.8410000000001, 1052.863, 1078.847, 1104.79, 1130.693, 1156.553, 1182.371, 1208.146, 1233.875, 1259.559, 1285.197, 1310.7879999999998, 1336.33, 1361.8229999999999, 1387.266, 1412.658, 1437.9979999999998, 1463.286, 1488.52, 1513.6989999999998, 1538.8229999999999, 1563.891, 1588.901, 1613.8529999999998, 1638.747, 1663.58, 1688.3529999999998, 1713.0639999999999, 1737.713, 1762.2979999999998, 1786.819, 1811.275, 1835.664, 1859.987, 1884.2420000000002, 1908.4279999999999, 1932.545, 1956.59, 1980.565, 2004.467, 2028.296, 2052.05, 2075.73, 2099.334, 2122.861, 2146.31, 2169.68, 2192.971, 2216.181, 2239.3089999999997, 2262.356, 2285.3179999999998, 2308.197, 2330.99, 2353.698, 2376.3179999999998, 2398.85, 2421.2929999999997, 2443.645, 2465.907, 2488.077, 2510.154, 2532.137, 2554.025, 2575.817, 2597.512, 2619.109, 2640.607, 2662.0040000000004, 2683.301, 2704.4959999999996, 2725.587, 2746.574, 2767.4559999999997, 2788.2309999999998, 2808.8990000000003, 2829.458, 2849.907, 2870.2459999999996, 2890.473, 2910.586, 2930.586, 2950.47, 2970.238, 2989.887, 3009.4179999999997, 3028.829, 3048.118, 3067.285, 3086.329, 3105.2470000000003, 3124.039, 3142.703, 3161.238, 3179.6440000000002, 3197.9179999999997, 3216.059, 3234.066, 3251.937, 3269.672, 3287.268, 3304.725, 3322.0409999999997, 3339.2140000000004, 3356.244, 3373.1279999999997, 3389.865, 3406.454, 3422.893, 3439.18, 3455.315, 3471.295, 3487.119, 3502.785, 3518.2909999999997, 3533.637, 3548.82, 3563.8379999999997, 3578.69, 3593.3740000000003, 3607.888, 3622.2309999999998, 3636.4, 3650.3940000000002, 3664.211, 3677.849, 3691.305, 3704.579, 3717.6690000000003, 3730.571, 3743.284, 3755.8059999999996, 3768.135, 3780.2690000000002, 3792.205, 3803.941, 3815.475, 3826.805, 3837.929, 3848.843, 3859.547, 3870.0359999999996, 3880.309, 3890.364, 3900.197, 3909.8059999999996, 3919.188, 3928.341, 3937.262, 3945.949, 3954.397, 3962.605, 3970.5690000000004, 3978.2859999999996, 3985.7540000000004, 3992.97, 3999.929, 4006.63, 4013.0679999999998, 4019.24, 4025.143, 4030.7740000000003, 4036.1279999999997, 4041.202, 4045.993, 4050.4959999999996, 4054.7090000000003, 4058.6259999999997, 4062.244, 4065.559, 4068.567, 4071.263, 4073.643, 4075.702, 4077.4359999999997, 4078.841, 4079.9120000000003, 4080.643, 4081.03, 4081.0679999999998, 4080.752, 4080.075, 4079.034, 4077.6209999999996, 4075.8320000000003, 4073.66, 4071.1009999999997, 4068.147, 4064.792, 4061.031, 4056.855, 4052.26, 4047.236, 4041.778, 4035.8790000000004, 4029.53, 4022.725, 4015.455, 4007.712, 3999.487, 3990.7740000000003, 3981.5609999999997, 3971.842, 3961.6059999999998, 3950.843, 3939.5440000000003, 3927.699, 3915.298, 3902.33, 3888.783, 3874.647, 3859.909, 3844.559, 3828.5820000000003, 3811.968, 3794.7009999999996, 3776.77, 3758.159, 3738.855, 3718.842, 3698.105, 3676.627, 3654.393, 3631.386, 3607.587, 3582.978, 3557.5409999999997, 3531.257, 3504.103, 3476.062, 3447.1090000000004, 3417.224, 3386.382, 3354.56, 3321.7329999999997, 3287.8740000000003, 3252.958, 3216.9559999999997, 3179.84, 3141.5809999999997, 3102.1459999999997, 3061.505, 3019.6240000000003, 2976.469, 2932.005, 2886.1940000000004, 2839.0, 2790.383, 2740.301, 2688.716, 2635.5809999999997, 2580.855, 2524.491, 2466.445, 2406.667, 2345.112, 2281.729, 2216.47, 2149.286, 2080.129, 2008.951, 1935.705, 1860.346, 1782.8339999999998, 1703.131, 1621.2020000000002, 1537.023, 1450.5729999999999, 1361.844, 1270.838, 1177.5710000000001, 1082.075, 984.403, 884.627, 782.8430000000001, 679.18, 573.789, 466.85900000000004, 358.61, 249.295, 139.203, 28.649, -82.02, -192.43900000000002, -302.224, -410.986, -518.3380000000001, -623.9019999999999, -727.322, -828.2660000000001, -926.44, -1021.587, -1113.49, -1201.98, -1286.928, -1368.245, -1445.881, -1519.8220000000001, -1590.0810000000001, -1656.6979999999999, -1719.734, -1779.267, -1835.388, -1888.1979999999999, -1937.806, -1984.3229999999999, -2027.8670000000002, -2068.552, -2106.496, -2141.811, -2174.612, -2205.004, -2233.095, -2258.986, -2282.774, -2304.554, -2324.415, -2342.4410000000003, -2358.715, -2373.314, -2386.313, -2397.78, -2407.783, -2416.384, -2423.644, -2429.619, -2434.365, -2437.9320000000002, -2440.369, -2441.721, -2442.035, -2441.351, -2439.708, -2437.145, -2433.698, -2429.401, -2424.286, -2418.384, -2411.725, -2404.3379999999997, -2396.248, -2387.4829999999997, -2378.0660000000003, -2368.021, -2357.37, -2346.133, -2334.333, -2321.988, -2309.118, -2295.739, -2281.87, -2267.527, -2252.725, -2237.48, -2221.8070000000002, -2205.719, -2189.23, -2172.353, -2155.099, -2137.482, -2119.513, -2101.203, -2082.563, -2063.6020000000003, -2044.332, -2024.76, -2004.8970000000002, -1984.7520000000002, -1964.3329999999999, -1943.649, -1922.707, -1901.515, -1880.082, -1858.4129999999998, -1836.5179999999998, -1814.401, -1792.069, -1769.53, -1746.79, -1723.8529999999998, -1700.727, -1677.4170000000001, -1653.9270000000001, -1630.265, -1606.434, -1582.441, -1558.2879999999998, -1533.983, -1509.5279999999998, -1484.9289999999999, -1460.19, -1435.316, -1410.309, -1385.1760000000002, -1359.918, -1334.5410000000002, -1309.047, -1283.441, -1257.726, -1231.906, -1205.983, -1179.962, -1153.845, -1127.635, -1101.336, -1074.951, -1048.482, -1021.932, -995.304, -968.602, -941.826, -914.9810000000001, -888.068, -861.091, -834.051, -806.951, -779.793, -752.58, -725.314, -697.998, -670.632, -643.22, -615.763, -588.263, -560.724, -533.145, -505.531, -477.881, -450.199, -422.485, -394.74300000000005, -366.973, -339.17699999999996, -311.358, -283.51599999999996, -255.65400000000002, -227.77200000000002, -199.87400000000002, -171.959, -144.03, -116.089, -88.13600000000001, -60.174, -32.203, -4.226, 23.756999999999998, 51.744, 79.733, 107.723, 135.713, 163.702, 191.688, 219.67, 247.646, 275.616, 303.577, 331.53, 359.472, 387.402, 415.319, 443.223, 471.111, 498.983, 526.837, 554.672, 582.488, 610.283, 638.055, 665.804, 693.529, 721.2289999999999, 748.9019999999999, 776.548, 804.165, 831.752, 859.309, 886.834, 914.326, 941.784, 969.207, 996.595, 1023.946, 1051.259, 1078.532, 1105.766, 1132.96, 1160.111, 1187.22, 1214.2839999999999, 1241.3039999999999, 1268.278, 1295.2060000000001, 1322.086, 1348.9170000000001, 1375.6979999999999, 1402.4289999999999, 1429.109, 1455.736, 1482.309, 1508.829, 1535.293, 1561.7, 1588.0510000000002, 1614.344, 1640.5770000000002, 1666.75, 1692.8629999999998, 1718.9129999999998, 1744.901, 1770.825, 1796.684, 1822.4779999999998, 1848.205, 1873.865, 1899.4560000000001, 1924.977, 1950.4289999999999, 1975.809, 2001.116, 2026.351, 2051.511, 2076.596, 2101.605, 2126.5370000000003, 2151.391, 2176.166, 2200.861, 2225.476, 2250.008, 2274.4570000000003, 2298.823, 2323.104, 2347.298, 2371.406, 2395.427, 2419.3579999999997, 2443.2, 2466.951, 2490.609, 2514.175, 2537.647, 2561.024, 2584.305, 2607.489, 2630.575, 2653.562, 2676.448, 2699.2329999999997, 2721.915, 2744.494, 2766.969, 2789.337, 2811.599, 2833.7529999999997, 2855.797, 2877.732, 2899.555, 2921.265, 2942.861, 2964.343, 2985.708, 3006.9559999999997, 3028.086, 3049.0959999999995, 3069.985, 3090.7509999999997, 3111.3940000000002, 3131.9120000000003, 3152.305, 3172.57, 3192.7059999999997, 3212.712, 3232.587, 3252.33, 3271.938, 3291.4109999999996, 3310.7470000000003, 3329.945, 3349.0029999999997, 3367.921, 3386.696, 3405.327, 3423.812, 3442.15, 3460.34, 3478.38, 3496.2690000000002, 3514.0040000000004, 3531.5840000000003, 3549.008, 3566.2740000000003, 3583.381, 3600.3259999999996, 3617.1079999999997, 3633.7259999999997, 3650.177, 3666.4590000000003, 3682.572, 3698.513, 3714.28, 3729.8720000000003, 3745.2859999999996, 3760.5209999999997, 3775.574, 3790.445, 3805.13, 3819.627, 3833.9359999999997, 3848.053, 3861.9770000000003, 3875.705, 3889.235, 3902.565, 3915.692, 3928.615, 3941.3309999999997, 3953.8379999999997, 3966.133, 3978.2140000000004, 3990.079, 4001.724, 4013.147, 4024.347, 4035.3190000000004, 4046.062, 4056.573, 4066.848, 4076.886, 4086.683, 4096.236, 4105.543, 4114.6, 4123.404, 4131.952, 4140.241, 4148.267, 4156.028, 4163.519, 4170.7390000000005, 4177.682, 4184.346, 4190.726, 4196.819, 4202.622, 4208.129, 4213.338, 4218.245, 4222.845, 4227.134, 4231.108, 4234.762, 4238.092000000001, 4241.094, 4243.762, 4246.092000000001, 4248.079000000001, 4249.718, 4251.004, 4251.933, 4252.498, 4252.693, 4252.515, 4251.956, 4251.0109999999995, 4249.674, 4247.939, 4245.8, 4243.25, 4240.282999999999, 4236.892, 4233.069, 4228.809, 4224.104, 4218.946, 4213.327, 4207.24, 4200.678, 4193.63, 4186.09, 4178.048, 4169.496, 4160.424, 4150.823, 4140.683, 4129.994000000001, 4118.745, 4106.927, 4094.5290000000005, 4081.539, 4067.945, 4053.736, 4038.8990000000003, 4023.423, 4007.2929999999997, 3990.4970000000003, 3973.02, 3954.849, 3935.968, 3916.363, 3896.018, 3874.915, 3853.04, 3830.3740000000003, 3806.9, 3782.598, 3757.45, 3731.437, 3704.5359999999996, 3676.728, 3647.991, 3618.301, 3587.634, 3555.968, 3523.276, 3489.532, 3454.7090000000003, 3418.778, 3381.711, 3343.478, 3304.047, 3263.385, 3221.4590000000003, 3178.2340000000004, 3133.6740000000004, 3087.741, 3040.3979999999997, 2991.6040000000003, 2941.316, 2889.494, 2836.092, 2781.065, 2724.367, 2665.95, 2605.765, 2543.761, 2479.888, 2414.094, 2346.326, 2276.532, 2204.661, 2130.661, 2054.48, 1976.0720000000001, 1895.391, 1812.395, 1727.046, 1639.316, 1549.181, 1456.6270000000002, 1361.654, 1264.275, 1164.521, 1062.4389999999999, 958.1010000000001, 851.605, 743.076, 632.672, 520.581, 407.029, 292.276, 176.61900000000003, 60.386, -56.065, -172.35299999999998, -288.07599999999996, -402.82599999999996, -516.196, -627.786, -737.217, -844.135, -948.2239999999999, -1049.2060000000001, -1146.848, -1240.962, -1331.4029999999998, -1418.07, -1500.906, -1579.885, -1655.016, -1726.335, -1793.9, -1857.79, -1918.095, -1974.9189999999999, -2028.3729999999998, -2078.572, -2125.636, -2169.686, -2210.843, -2249.225, -2284.947, -2318.126, -2348.871, -2377.288, -2403.479, -2427.544, -2449.635, -2469.6639999999998, -2487.894, -2504.349, -2519.104, -2532.236, -2543.813, -2553.902, -2562.567, -2569.868, -2575.861, -2580.601, -2584.14, -2586.526, -2587.806, -2588.024, -2587.222, -2585.44, -2582.716, -2579.087, -2574.587, -2569.2470000000003, -2563.101, -2556.178, -2548.505, -2540.111, -2531.021, -2521.261, -2510.853, -2499.82, -2488.1839999999997, -2475.967, -2463.187, -2449.864, -2436.016, -2421.66, -2406.814, -2391.492, -2375.712, -2359.487, -2342.8320000000003, -2325.761, -2308.2870000000003, -2290.423, -2272.179, -2253.57, -2234.605, -2215.297, -2195.655, -2175.69, -2155.411, -2134.828, -2113.951, -2092.7870000000003, -2071.346, -2049.635, -2027.6629999999998, -2005.4379999999999, -1982.967, -1960.257, -1937.316, -1914.149, -1890.765, -1867.1689999999999, -1843.3670000000002, -1819.365, -1795.1689999999999, -1770.786, -1746.22, -1721.476, -1696.5610000000001, -1671.4779999999998, -1646.234, -1620.832, -1595.277, -1569.5739999999998, -1543.7279999999998, -1517.7420000000002, -1491.62, -1465.368, -1438.9879999999998, -1412.485, -1385.8629999999998, -1359.124, -1332.273, -1305.3139999999999, -1278.249, -1251.0810000000001, -1223.815, -1196.454, -1169.0, -1141.4560000000001, -1113.826, -1086.112, -1058.317, -1030.444, -1002.4960000000001, -974.4760000000001, -946.385, -918.227, -890.0039999999999, -861.7180000000001, -833.373, -804.9689999999999, -776.51, -747.998, -719.435, -690.823, -662.164, -633.461, -604.715, -575.929, -547.104, -518.243, -489.347, -460.418, -431.459, -402.47, -373.454, -344.413, -315.347, -286.26, -257.152, -228.02599999999998, -198.88299999999998, -169.72400000000002, -140.55100000000002, -111.366, -82.17, -52.965, -23.752, 5.4670000000000005, 34.691, 63.919, 93.148, 122.37799999999999, 151.607, 180.834, 210.05700000000002, 239.27599999999998, 268.488, 297.693, 326.888, 356.074, 385.24800000000005, 414.41, 443.55800000000005, 472.69, 501.80699999999996, 530.905, 559.986, 589.0459999999999, 618.085, 647.101, 676.095, 705.063, 734.007, 762.923, 791.811, 820.67, 849.4989999999999, 878.297, 907.062, 935.794, 964.492, 993.153, 1021.779, 1050.366, 1078.915, 1107.423, 1135.891, 1164.317, 1192.7, 1221.04, 1249.3339999999998, 1277.5819999999999, 1305.7830000000001, 1333.9360000000001, 1362.04, 1390.0929999999998, 1418.096, 1446.047, 1473.944, 1501.7879999999998, 1529.576, 1557.308, 1584.983, 1612.6, 1640.158, 1667.656, 1695.0929999999998, 1722.4679999999998, 1749.78, 1777.027, 1804.21, 1831.3270000000002, 1858.376, 1885.358, 1912.27, 1939.1129999999998, 1965.884, 1992.5839999999998, 2019.211, 2045.763, 2072.241, 2098.6420000000003, 2124.967, 2151.2129999999997, 2177.381, 2203.468, 2229.474, 2255.3979999999997, 2281.239, 2306.996, 2332.6679999999997, 2358.2529999999997, 2383.752, 2409.161, 2434.482, 2459.712, 2484.85, 2509.897, 2534.849, 2559.7070000000003, 2584.468, 2609.133, 2633.7, 2658.1679999999997, 2682.5359999999996, 2706.803, 2730.966, 2755.027, 2778.982, 2802.8320000000003, 2826.575, 2850.21, 2873.735, 2897.15, 2920.453, 2943.643, 2966.719, 2989.679, 3012.5229999999997, 3035.25, 3057.857, 3080.343, 3102.7090000000003, 3124.9509999999996, 3147.0690000000004, 3169.062, 3190.928, 3212.6659999999997, 3234.2740000000003, 3255.752, 3277.097, 3298.309, 3319.386, 3340.327, 3361.13, 3381.7929999999997, 3402.316, 3422.697, 3442.935, 3463.027, 3482.972, 3502.7690000000002, 3522.417, 3541.913, 3561.257, 3580.445, 3599.478, 3618.353, 3637.0679999999998, 3655.6220000000003, 3674.014, 3692.241, 3710.301, 3728.1940000000004, 3745.917, 3763.468, 3780.845, 3798.047, 3815.072, 3831.917, 3848.5820000000003, 3865.063, 3881.3590000000004, 3897.468, 3913.388, 3929.116, 3944.651, 3959.99, 3975.131, 3990.073, 4004.812, 4019.347, 4033.675, 4047.7940000000003, 4061.702, 4075.395, 4088.873, 4102.130999999999, 4115.168, 4127.98, 4140.567, 4152.923, 4165.048, 4176.938, 4188.59, 4200.002, 4211.170999999999, 4222.093, 4232.766, 4243.187, 4253.353, 4263.259, 4272.904, 4282.284000000001, 4291.395, 4300.235, 4308.799, 4317.085, 4325.088, 4332.805, 4340.232, 4347.366, 4354.202, 4360.736, 4366.965, 4372.885, 4378.49, 4383.777, 4388.742, 4393.38, 4397.686, 4401.657, 4405.286, 4408.569, 4411.502, 4414.079000000001, 4416.294, 4418.143, 4419.62, 4420.72, 4421.437, 4421.766, 4421.6990000000005, 4421.232, 4420.357, 4419.069, 4417.36, 4415.225, 4412.657, 4409.648, 4406.191, 4402.279, 4397.904, 4393.059, 4387.735, 4381.924, 4375.619000000001, 4368.809, 4361.488, 4353.644, 4345.27, 4336.354, 4326.888, 4316.862, 4306.265, 4295.085999999999, 4283.313, 4270.937, 4257.945, 4244.325, 4230.065, 4215.151, 4199.57, 4183.31, 4166.356, 4148.693, 4130.307, 4111.181, 4091.301, 4070.65, 4049.211, 4026.965, 4003.8959999999997, 3979.9840000000004, 3955.21, 3929.554, 3902.995, 3875.512, 3847.083, 3817.683, 3787.29, 3755.8790000000004, 3723.425, 3689.901, 3655.278, 3619.53, 3582.6259999999997, 3544.5359999999996, 3505.2270000000003, 3464.6679999999997, 3422.824, 3379.66, 3335.139, 3289.222, 3241.8720000000003, 3193.046, 3142.703, 3090.8, 3037.292, 2982.131, 2925.2709999999997, 2866.6609999999996, 2806.252, 2743.991, 2679.8259999999996, 2613.702, 2545.565, 2475.3579999999997, 2403.026, 2328.516, 2251.768, 2172.732, 2091.355, 2007.5870000000002, 1921.382, 1832.7, 1741.507, 1647.775, 1551.489, 1452.6429999999998, 1351.2479999999998, 1247.33, 1140.937, 1032.137, 921.028, 807.7339999999999, 692.416, 575.263, 456.506, 336.412, 215.28400000000002, 93.463, -28.683000000000003, -150.756, -272.339, -393.004, -512.325, -629.878, -745.265, -858.1080000000001, -968.07, -1074.8519999999999, -1178.202, -1277.913, -1373.828, -1465.8310000000001, -1553.855, -1637.865, -1717.865, -1793.886, -1865.983, -1934.234, -1998.731, -2059.577, -2116.887, -2170.78, -2221.3779999999997, -2268.8070000000002, -2313.1910000000003, -2354.654, -2393.317, -2429.298, -2462.715, -2493.675, -2522.288, -2548.656, -2572.879, -2595.048, -2615.255, -2633.585, -2650.12, -2664.9359999999997, -2678.1090000000004, -2689.7070000000003, -2699.798, -2708.4440000000004, -2715.7070000000003, -2721.6420000000003, -2726.304, -2729.7459999999996, -2732.014, -2733.157, -2733.218, -2732.24, -2730.262, -2727.324, -2723.461, -2718.7070000000003, -2713.095, -2706.659, -2699.427, -2691.427, -2682.688, -2673.235, -2663.095, -2652.289, -2640.842, -2628.775, -2616.109, -2602.865, -2589.062, -2574.717, -2559.849, -2544.475, -2528.612, -2512.274, -2495.478, -2478.237, -2460.565, -2442.476, -2423.9829999999997, -2405.099, -2385.834, -2366.202, -2346.214, -2325.8779999999997, -2305.208, -2284.2110000000002, -2262.899, -2241.28, -2219.363, -2197.158, -2174.672, -2151.9139999999998, -2128.8920000000003, -2105.614, -2082.0860000000002, -2058.317, -2034.3129999999999, -2010.0810000000001, -1985.6270000000002, -1960.9579999999999, -1936.0810000000001, -1911.0, -1885.7220000000002, -1860.253, -1834.598, -1808.7620000000002, -1782.751, -1756.57, -1730.224, -1703.717, -1677.0539999999999, -1650.24, -1623.279, -1596.1760000000002, -1568.934, -1541.558, -1514.0510000000002, -1486.4189999999999, -1458.6629999999998, -1430.789, -1402.8, -1374.6989999999998, -1346.489, -1318.175, -1289.759, -1261.245, -1232.636, -1203.934, -1175.143, -1146.267, -1117.307, -1088.266, -1059.1480000000001, -1029.955, -1000.689, -971.3539999999999, -941.952, -912.4839999999999, -882.955, -853.3660000000001, -823.7189999999999, -794.018, -764.263, -734.457, -704.6039999999999, -674.703, -644.759, -614.7719999999999, -584.746, -554.681, -524.58, -494.444, -464.277, -434.079, -403.852, -373.599, -343.32, -313.019, -282.695, -252.352, -221.99099999999999, -191.613, -161.221, -130.815, -100.398, -69.971, -39.535, -9.092, 21.357, 51.809, 82.264, 112.72, 143.17600000000002, 173.62900000000002, 204.08, 234.52599999999998, 264.966, 295.399, 325.822, 356.23699999999997, 386.639, 417.03, 447.406, 477.767, 508.11199999999997, 538.439, 568.747, 599.035, 629.302, 659.546, 689.7660000000001, 719.962, 750.1310000000001, 780.2719999999999, 810.385, 840.4689999999999, 870.5219999999999, 900.5419999999999, 930.53, 960.4830000000001, 990.4010000000001, 1020.2819999999999, 1050.126, 1079.931, 1109.6960000000001, 1139.42, 1169.103, 1198.742, 1228.337, 1257.887, 1287.39, 1316.846, 1346.253, 1375.611, 1404.9189999999999, 1434.174, 1463.3770000000002, 1492.527, 1521.621, 1550.66, 1579.641, 1608.565, 1637.4289999999999, 1666.234, 1694.977, 1723.6589999999999, 1752.277, 1780.83, 1809.319, 1837.741, 1866.096, 1894.382, 1922.599, 1950.746, 1978.8210000000001, 2006.8229999999999, 2034.7520000000002, 2062.606, 2090.384, 2118.0860000000002, 2145.709, 2173.254, 2200.719, 2228.103, 2255.404, 2282.6220000000003, 2309.757, 2336.805, 2363.768, 2390.6420000000003, 2417.428, 2444.125, 2470.73, 2497.244, 2523.665, 2549.991, 2576.222, 2602.357, 2628.3940000000002, 2654.333, 2680.172, 2705.909, 2731.545, 2757.077, 2782.505, 2807.827, 2833.042, 2858.1490000000003, 2883.147, 2908.034, 2932.809, 2957.472, 2982.02, 3006.453, 3030.7690000000002, 3054.967, 3079.046, 3103.005, 3126.841, 3150.555, 3174.1440000000002, 3197.607, 3220.9429999999998, 3244.15, 3267.2270000000003, 3290.173, 3312.987, 3335.6659999999997, 3358.21, 3380.617, 3402.885, 3425.013, 3447.0, 3468.844, 3490.5440000000003, 3512.097, 3533.5029999999997, 3554.76, 3575.867, 3596.821, 3617.6209999999996, 3638.2659999999996, 3658.7529999999997, 3679.0820000000003, 3699.25, 3719.256, 3739.099, 3758.775, 3778.284, 3797.623, 3816.7909999999997, 3835.7870000000003, 3854.607, 3873.2509999999997, 3891.716, 3910.0, 3928.1020000000003, 3946.0190000000002, 3963.7490000000003, 3981.2909999999997, 3998.6420000000003, 4015.8, 4032.763, 4049.5290000000005, 4066.095, 4082.46, 4098.621, 4114.576, 4130.322, 4145.858, 4161.18, 4176.286, 4191.174, 4205.842000000001, 4220.286, 4234.504, 4248.4929999999995, 4262.252, 4275.776, 4289.063, 4302.111, 4314.916, 4327.476, 4339.788, 4351.848, 4363.654, 4375.2029999999995, 4386.49, 4397.514, 4408.271, 4418.7570000000005, 4428.969, 4438.903, 4448.557, 4457.925, 4467.005999999999, 4475.794, 4484.286, 4492.479, 4500.3679999999995, 4507.9490000000005, 4515.219, 4522.1720000000005, 4528.805, 4535.1140000000005, 4541.092000000001, 4546.737, 4552.044, 4557.0070000000005, 4561.623, 4565.885, 4569.79, 4573.331, 4576.503, 4579.302, 4581.721, 4583.755, 4585.398, 4586.644, 4587.488, 4587.9220000000005, 4587.941, 4587.538, 4586.707, 4585.44, 4583.731, 4581.572, 4578.957, 4575.877, 4572.326, 4568.294, 4563.775, 4558.759, 4553.238, 4547.204000000001, 4540.648, 4533.56, 4525.931, 4517.751, 4509.009, 4499.696, 4489.802, 4479.315, 4468.224, 4456.518, 4444.184, 4431.21, 4417.585, 4403.295, 4388.326, 4372.666, 4356.299, 4339.21, 4321.3859999999995, 4302.81, 4283.467000000001, 4263.339, 4242.409000000001, 4220.661, 4198.075, 4174.633, 4150.314, 4125.099, 4098.968, 4071.897, 4043.865, 4014.848, 3984.824, 3953.7659999999996, 3921.6479999999997, 3888.445, 3854.1279999999997, 3818.6679999999997, 3782.0370000000003, 3744.203, 3705.133, 3664.795, 3623.155, 3580.177, 3535.823, 3490.0559999999996, 3442.835, 3394.12, 3343.867, 3292.033, 3238.572, 3183.437, 3126.579, 3067.946, 3007.49, 2945.1540000000005, 2880.886, 2814.6290000000004, 2746.3259999999996, 2675.92, 2603.35, 2528.56, 2451.488, 2372.077, 2290.269, 2206.008, 2119.242, 2029.92, 1937.997, 1843.4360000000001, 1746.207, 1646.287, 1543.67, 1438.3629999999998, 1330.3870000000002, 1219.789, 1106.636, 991.0219999999999, 873.074, 752.951, 630.845, 506.99300000000005, 381.663, 255.171, 127.86200000000001, 0.121, -127.64299999999999, -254.99599999999998, -381.49300000000005, -506.685, -630.131, -751.4069999999999, -870.1160000000001, -985.898, -1098.433, -1207.451, -1312.727, -1414.086, -1511.4029999999998, -1604.595, -1693.622, -1778.479, -1859.194, -1935.819, -2008.43, -2077.118, -2141.99, -2203.1620000000003, -2260.754, -2314.894, -2365.71, -2413.3320000000003, -2457.888, -2499.5029999999997, -2538.301, -2574.402, -2607.922, -2638.972, -2667.659, -2694.0879999999997, -2718.3559999999998, -2740.5559999999996, -2760.78, -2779.111, -2795.631, -2810.4190000000003, -2823.545, -2835.0820000000003, -2845.095, -2853.6459999999997, -2860.798, -2866.6040000000003, -2871.1209999999996, -2874.4, -2876.489, -2877.435, -2877.282, -2876.073, -2873.847, -2870.643, -2866.4970000000003, -2861.4440000000004, -2855.5170000000003, -2848.748, -2841.1659999999997, -2832.801, -2823.68, -2813.829, -2803.275, -2792.04, -2780.1479999999997, -2767.62, -2754.4790000000003, -2740.744, -2726.435, -2711.571, -2696.1690000000003, -2680.2470000000003, -2663.821, -2646.907, -2629.5209999999997, -2611.676, -2593.389, -2574.6710000000003, -2555.5370000000003, -2535.998, -2516.0679999999998, -2495.757, -2475.077, -2454.0389999999998, -2432.654, -2410.933, -2388.884, -2366.5170000000003, -2343.843, -2320.868, -2297.604, -2274.056, -2250.235, -2226.147, -2201.8, -2177.202, -2152.359, -2127.28, -2101.969, -2076.435, -2050.683, -2024.72, -1998.5510000000002, -1972.183, -1945.62, -1918.869, -1891.934, -1864.8220000000001, -1837.537, -1810.0839999999998, -1782.467, -1754.692, -1726.763, -1698.684, -1670.461, -1642.096, -1613.595, -1584.961, -1556.1970000000001, -1527.309, -1498.3, -1469.1729999999998, -1439.932, -1410.58, -1381.121, -1351.558, -1321.895, -1292.134, -1262.278, -1232.3319999999999, -1202.297, -1172.177, -1141.974, -1111.692, -1081.3319999999999, -1050.899, -1020.3939999999999, -989.819, -959.179, -928.4739999999999, -897.707, -866.882, -836.0, -805.063, -774.074, -743.035, -711.948, -680.815, -649.639, -618.4209999999999, -587.164, -555.87, -524.54, -493.176, -461.781, -430.35699999999997, -398.904, -367.426, -335.923, -304.39799999999997, -272.85200000000003, -241.287, -209.705, -178.108, -146.496, -114.87200000000001, -83.238, -51.595, -19.944000000000003, 11.713, 43.373999999999995, 75.038, 106.704, 138.369, 170.033, 201.69400000000002, 233.35, 265.001, 296.644, 328.279, 359.903, 391.517, 423.11699999999996, 454.704, 486.275, 517.8290000000001, 549.365, 580.882, 612.379, 643.8530000000001, 675.305, 706.732, 738.1339999999999, 769.508, 800.855, 832.173, 863.46, 894.715, 925.938, 957.1260000000001, 988.279, 1019.3960000000001, 1050.476, 1081.516, 1112.517, 1143.4769999999999, 1174.395, 1205.269, 1236.099, 1266.883, 1297.621, 1328.3110000000001, 1358.9520000000002, 1389.543, 1420.0829999999999, 1450.5710000000001, 1481.005, 1511.384, 1541.7089999999998, 1571.976, 1602.1860000000001, 1632.3370000000002, 1662.4279999999999, 1692.4579999999999, 1722.425, 1752.33, 1782.17, 1811.945, 1841.6529999999998, 1871.293, 1900.865, 1930.3670000000002, 1959.7979999999998, 1989.1570000000002, 2018.444, 2047.655, 2076.792, 2105.8520000000003, 2134.835, 2163.739, 2192.563, 2221.306, 2249.968, 2278.5460000000003, 2307.04, 2335.449, 2363.772, 2392.006, 2420.152, 2448.209, 2476.174, 2504.047, 2531.827, 2559.512, 2587.1020000000003, 2614.594, 2641.989, 2669.285, 2696.48, 2723.574, 2750.565, 2777.452, 2804.2329999999997, 2830.909, 2857.4759999999997, 2883.935, 2910.283, 2936.52, 2962.645, 2988.655, 3014.55, 3040.329, 3065.99, 3091.531, 3116.952, 3142.2509999999997, 3167.427, 3192.4790000000003, 3217.4040000000005, 3242.203, 3266.8720000000003, 3291.4109999999996, 3315.8190000000004, 3340.094, 3364.235, 3388.24, 3412.107, 3435.836, 3459.4240000000004, 3482.8709999999996, 3506.1740000000004, 3529.333, 3552.345, 3575.2090000000003, 3597.923, 3620.486, 3642.897, 3665.152, 3687.252, 3709.1940000000004, 3730.9759999999997, 3752.597, 3774.055, 3795.347, 3816.474, 3837.4320000000002, 3858.22, 3878.835, 3899.277, 3919.5440000000003, 3939.632, 3959.5409999999997, 3979.268, 3998.8109999999997, 4018.1690000000003, 4037.3390000000004, 4056.3190000000004, 4075.1079999999997, 4093.702, 4112.1, 4130.3, 4148.299, 4166.095, 4183.685, 4201.069, 4218.242, 4235.204000000001, 4251.95, 4268.48, 4284.79, 4300.878, 4316.741, 4332.377, 4347.782, 4362.955, 4377.893, 4392.592000000001, 4407.05, 4421.264, 4435.231, 4448.948, 4462.413, 4475.621, 4488.57, 4501.2570000000005, 4513.679, 4525.831, 4537.712, 4549.316, 4560.642, 4571.685, 4582.441, 4592.907999999999, 4603.081, 4612.956, 4622.53, 4631.799, 4640.758, 4649.403, 4657.731, 4665.737, 4673.417, 4680.766, 4687.779, 4694.4529999999995, 4700.782, 4706.76, 4712.385, 4717.65, 4722.55, 4727.08, 4731.235, 4735.009, 4738.397, 4741.392, 4743.99, 4746.183, 4747.965, 4749.332, 4750.275, 4750.79, 4750.867, 4750.502, 4749.687, 4748.413, 4746.675, 4744.464, 4741.774, 4738.595, 4734.919, 4730.7390000000005, 4726.045, 4720.8279999999995, 4715.08, 4708.791, 4701.9529999999995, 4694.553, 4686.584, 4678.032999999999, 4668.89, 4659.146, 4648.788, 4637.804, 4626.183, 4613.913, 4600.979, 4587.37, 4573.072, 4558.072, 4542.354, 4525.904, 4508.707, 4490.747, 4472.008, 4452.474, 4432.126, 4410.947, 4388.919, 4366.023, 4342.238, 4317.544, 4291.9220000000005, 4265.348, 4237.8, 4209.255, 4179.689, 4149.076, 4117.391, 4084.6059999999998, 4050.6940000000004, 4015.627, 3979.373, 3941.902, 3903.183, 3863.18, 3821.862, 3779.19, 3735.127, 3689.636, 3642.675, 3594.205, 3544.1809999999996, 3492.559, 3439.2929999999997, 3384.3340000000003, 3327.635, 3269.143, 3208.8059999999996, 3146.5690000000004, 3082.3779999999997, 3016.1740000000004, 2947.9, 2877.493, 2804.8959999999997, 2730.0440000000003, 2652.8759999999997, 2573.328, 2491.34, 2406.85, 2319.798, 2230.127, 2137.784, 2042.72, 1944.8929999999998, 1844.269, 1740.8229999999999, 1634.5439999999999, 1525.434, 1413.514, 1298.826, 1181.434, 1061.434, 938.95, 814.1389999999999, 687.201, 558.37, 427.92400000000004, 296.18, 163.498, 30.27, -103.079, -236.101, -368.333, -499.306, -628.56, -755.6469999999999, -880.15, -1001.687, -1119.9189999999999, -1234.552, -1345.346, -1452.11, -1554.705, -1653.036, -1747.055, -1836.75, -1922.141, -2003.281, -2080.24, -2153.114, -2222.006, -2287.035, -2348.327, -2406.009, -2460.216, -2511.08, -2558.734, -2603.308, -2644.9309999999996, -2683.7259999999997, -2719.815, -2753.312, -2784.3320000000003, -2813.0209999999997, -2839.3590000000004, -2863.567, -2885.698, -2905.841, -2924.0809999999997, -2940.4990000000003, -2955.171, -2968.17, -2979.567, -2989.427, -2997.812, -3004.782, -3010.3940000000002, -3014.703, -3017.758, -3019.6090000000004, -3020.303, -3019.883, -3018.3909999999996, -3015.868, -3012.3520000000003, -3007.8790000000004, -3002.4829999999997, -2996.2, -2989.059, -2981.091, -2972.324, -2962.788, -2952.507, -2941.509, -2929.815, -2917.45, -2904.437, -2890.795, -2876.546, -2861.71, -2846.305, -2830.349, -2813.86, -2796.8540000000003, -2779.348, -2761.357, -2742.8959999999997, -2723.9790000000003, -2704.6209999999996, -2684.8340000000003, -2664.631, -2644.0240000000003, -2623.026, -2601.6479999999997, -2579.901, -2557.797, -2535.345, -2512.555, -2489.438, -2466.002, -2442.257, -2418.2110000000002, -2393.873, -2369.252, -2344.355, -2319.19, -2293.765, -2268.0860000000002, -2242.1620000000003, -2215.999, -2189.603, -2162.982, -2136.14, -2109.085, -2081.823, -2054.359, -2026.6989999999998, -1998.848, -1970.8120000000001, -1942.596, -1914.204, -1885.6429999999998, -1856.9160000000002, -1828.029, -1798.985, -1769.79, -1740.4479999999999, -1710.963, -1681.339, -1651.58, -1621.69, -1591.6729999999998, -1561.533, -1531.2720000000002, -1500.896, -1470.408, -1439.81, -1409.106, -1378.3, -1347.395, -1316.3929999999998, -1285.299, -1254.114, -1222.8419999999999, -1191.486, -1160.049, -1128.5330000000001, -1096.941, -1065.276, -1033.5410000000002, -1001.737, -969.8689999999999, -937.937, -905.944, -873.8939999999999, -841.7869999999999, -809.627, -777.416, -745.1560000000001, -712.8489999999999, -680.497, -648.1030000000001, -615.668, -583.195, -550.686, -518.1419999999999, -485.565, -452.958, -420.32300000000004, -387.661, -354.973, -322.263, -289.532, -256.781, -224.012, -191.227, -158.428, -125.616, -92.79299999999999, -59.96, -27.12, 5.726, 38.577, 71.431, 104.286, 137.142, 169.99599999999998, 202.847, 235.69299999999998, 268.534, 301.367, 334.191, 367.005, 399.80800000000005, 432.597, 465.37199999999996, 498.131, 530.873, 563.597, 596.3009999999999, 628.9830000000001, 661.643, 694.28, 726.8910000000001, 759.4760000000001, 792.034, 824.563, 857.061, 889.528, 921.9630000000001, 954.363, 986.7289999999999, 1019.058, 1051.35, 1083.603, 1115.817, 1147.989, 1180.118, 1212.205, 1244.246, 1276.242, 1308.191, 1340.0910000000001, 1371.942, 1403.743, 1435.491, 1467.1870000000001, 1498.829, 1530.4160000000002, 1561.9460000000001, 1593.4189999999999, 1624.8329999999999, 1656.1879999999999, 1687.481, 1718.713, 1749.881, 1780.985, 1812.024, 1842.995, 1873.9, 1904.735, 1935.5, 1966.193, 1996.815, 2027.3629999999998, 2057.8360000000002, 2088.234, 2118.554, 2148.797, 2178.96, 2209.0429999999997, 2239.044, 2268.962, 2298.797, 2328.5460000000003, 2358.209, 2387.785, 2417.272, 2446.669, 2475.976, 2505.19, 2534.31, 2563.3360000000002, 2592.2670000000003, 2621.1, 2649.835, 2678.47, 2707.005, 2735.438, 2763.7670000000003, 2791.992, 2820.112, 2848.1240000000003, 2876.028, 2903.823, 2931.507, 2959.078, 2986.5370000000003, 3013.88, 3041.1079999999997, 3068.218, 3095.2090000000003, 3122.08, 3148.829, 3175.4559999999997, 3201.958, 3228.335, 3254.585, 3280.7059999999997, 3306.697, 3332.5570000000002, 3358.284, 3383.8759999999997, 3409.333, 3434.653, 3459.833, 3484.8740000000003, 3509.772, 3534.527, 3559.137, 3583.6, 3607.915, 3632.08, 3656.094, 3679.955, 3703.6609999999996, 3727.21, 3750.6020000000003, 3773.833, 3796.903, 3819.809, 3842.55, 3865.1240000000003, 3887.5290000000005, 3909.763, 3931.825, 3953.7129999999997, 3975.423, 3996.9559999999997, 4018.308, 4039.478, 4060.4629999999997, 4081.263, 4101.873, 4122.294, 4142.521, 4162.554, 4182.39, 4202.027, 4221.462, 4240.694, 4259.719, 4278.536, 4297.143, 4315.536, 4333.714, 4351.673, 4369.412, 4386.928, 4404.218, 4421.28, 4438.11, 4454.707, 4471.068, 4487.189, 4503.068, 4518.7029999999995, 4534.089, 4549.224, 4564.105, 4578.729, 4593.093, 4607.193, 4621.027, 4634.59, 4647.880999999999, 4660.895, 4673.628, 4686.0779999999995, 4698.24, 4710.112, 4721.688, 4732.965999999999, 4743.942, 4754.611, 4764.97, 4775.014, 4784.7390000000005, 4794.141, 4803.215999999999, 4811.959, 4820.365, 4828.431, 4836.151, 4843.521, 4850.536, 4857.19, 4863.478, 4869.396, 4874.937, 4880.097, 4884.87, 4889.25, 4893.232, 4896.809, 4899.976, 4902.726, 4905.052, 4906.948, 4908.407999999999, 4909.4259999999995, 4909.9929999999995, 4910.102, 4909.747, 4908.92, 4907.612, 4905.817, 4903.526, 4900.731, 4897.424, 4893.595, 4889.235, 4884.335999999999, 4878.888, 4872.8820000000005, 4866.307, 4859.154, 4851.411, 4843.068, 4834.1140000000005, 4824.537, 4814.326, 4803.469, 4791.954000000001, 4779.766, 4766.894, 4753.323, 4739.041, 4724.031, 4708.281, 4691.773, 4674.492, 4656.423, 4637.548, 4617.85, 4597.311, 4575.912, 4553.635, 4530.46, 4506.365, 4481.33, 4455.333, 4428.352, 4400.363, 4371.340999999999, 4341.263, 4310.101, 4277.829000000001, 4244.418, 4209.840999999999, 4174.066, 4137.063, 4098.8, 4059.242, 4018.3559999999998, 3976.105, 3932.452, 3887.3590000000004, 3840.784, 3792.687, 3743.0240000000003, 3691.75, 3638.8190000000004, 3584.183, 3527.792, 3469.594, 3409.5370000000003, 3347.5640000000003, 3283.6209999999996, 3217.647, 3149.5840000000003, 3079.369, 3006.941, 2932.2329999999997, 2855.184, 2775.7259999999997, 2693.7929999999997, 2609.32, 2522.242, 2432.498, 2340.0229999999997, 2244.762, 2146.663, 2045.6779999999999, 1941.77, 1834.912, 1725.086, 1612.2920000000001, 1496.5479999999998, 1377.8929999999998, 1256.389, 1132.128, 1005.235, 875.867, 744.2230000000001, 610.543, 475.10699999999997, 338.24, 200.308, 61.715, -77.102, -215.68, -353.539, -490.191, -625.156, -757.965, -888.18, -1015.3960000000001, -1139.252, -1259.438, -1375.693, -1487.8120000000001, -1595.64, -1699.0710000000001, -1798.047, -1892.5479999999998, -1982.5910000000001, -2068.223, -2149.513, -2226.556, -2299.456, -2368.334, -2433.317, -2494.5370000000003, -2552.132, -2606.236, -2656.989, -2704.5229999999997, -2748.974, -2790.468, -2829.13, -2865.083, -2898.442, -2929.317, -2957.8179999999998, -2984.045, -3008.0959999999995, -3030.062, -3050.035, -3068.097, -3084.329, -3098.8059999999996, -3111.6020000000003, -3122.7859999999996, -3132.422, -3140.573, -3147.298, -3152.6540000000005, -3156.695, -3159.4709999999995, -3161.0290000000005, -3161.4190000000003, -3160.6820000000002, -3158.86, -3155.995, -3152.1240000000003, -3147.283, -3141.507, -3134.829, -3127.28, -3118.8920000000003, -3109.6929999999998, -3099.711, -3088.9709999999995, -3077.5, -3065.323, -3052.461, -3038.937, -3024.7729999999997, -3009.991, -2994.6079999999997, -2978.6440000000002, -2962.118, -2945.047, -2927.448, -2909.336, -2890.728, -2871.638, -2852.0820000000003, -2832.074, -2811.625, -2790.7509999999997, -2769.462, -2747.7709999999997, -2725.69, -2703.23, -2680.403, -2657.218, -2633.6859999999997, -2609.817, -2585.62, -2561.104, -2536.279, -2511.153, -2485.734, -2460.031, -2434.052, -2407.804, -2381.294, -2354.53, -2327.519, -2300.268, -2272.784, -2245.072, -2217.139, -2188.991, -2160.635, -2132.075, -2103.3179999999998, -2074.368, -2045.231, -2015.9129999999998, -1986.4189999999999, -1956.7520000000002, -1926.9189999999999, -1896.9229999999998, -1866.769, -1836.463, -1806.007, -1775.4070000000002, -1744.6660000000002, -1713.7879999999998, -1682.7779999999998, -1651.64, -1620.376, -1588.9920000000002, -1557.489, -1525.8729999999998, -1494.146, -1462.3110000000001, -1430.3729999999998, -1398.3339999999998, -1366.1970000000001, -1333.965, -1301.643, -1269.232, -1236.735, -1204.155, -1171.496, -1138.76, -1105.9489999999998, -1073.066, -1040.114, -1007.096, -974.0139999999999, -940.87, -907.666, -874.4060000000001, -841.091, -807.725, -774.308, -740.8430000000001, -707.334, -673.78, -640.186, -606.552, -572.881, -539.175, -505.436, -471.666, -437.86699999999996, -404.04, -370.18800000000005, -336.31300000000005, -302.416, -268.499, -234.56400000000002, -200.612, -166.646, -132.667, -98.677, -64.67699999999999, -30.669, 3.344, 37.363, 71.384, 105.40700000000001, 139.43, 173.451, 207.46900000000002, 241.483, 275.49, 309.48900000000003, 343.47900000000004, 377.459, 411.42699999999996, 445.381, 479.32, 513.243, 547.148, 581.034, 614.899, 648.743, 682.563, 716.3589999999999, 750.1289999999999, 783.872, 817.587, 851.2710000000001, 884.925, 918.546, 952.133, 985.685, 1019.201, 1052.68, 1086.12, 1119.52, 1152.878, 1186.194, 1219.4669999999999, 1252.694, 1285.875, 1319.009, 1352.094, 1385.129, 1418.1129999999998, 1451.045, 1483.9229999999998, 1516.746, 1549.514, 1582.225, 1614.8770000000002, 1647.469, 1680.0020000000002, 1712.4720000000002, 1744.879, 1777.221, 1809.499, 1841.7089999999998, 1873.852, 1905.9260000000002, 1937.9289999999999, 1969.862, 2001.721, 2033.507, 2065.217, 2096.8520000000003, 2128.409, 2159.887, 2191.286, 2222.603, 2253.839, 2284.99, 2316.058, 2347.0389999999998, 2377.933, 2408.739, 2439.455, 2470.081, 2500.614, 2531.055, 2561.401, 2591.651, 2621.803, 2651.8579999999997, 2681.813, 2711.6679999999997, 2741.42, 2771.0690000000004, 2800.613, 2830.051, 2859.382, 2888.6040000000003, 2917.716, 2946.717, 2975.6059999999998, 3004.38, 3033.039, 3061.5809999999997, 3090.005, 3118.31, 3146.494, 3174.5559999999996, 3202.494, 3230.3059999999996, 3257.992, 3285.551, 3312.9790000000003, 3340.277, 3367.442, 3394.473, 3421.369, 3448.1279999999997, 3474.748, 3501.228, 3527.567, 3553.762, 3579.813, 3605.717, 3631.473, 3657.079, 3682.534, 3707.836, 3732.9829999999997, 3757.974, 3782.8059999999996, 3807.4790000000003, 3831.99, 3856.337, 3880.5190000000002, 3904.534, 3928.38, 3952.055, 3975.5570000000002, 3998.885, 4022.0359999999996, 4045.008, 4067.8, 4090.409, 4112.834, 4135.071, 4157.121, 4178.979, 4200.644, 4222.1140000000005, 4243.387, 4264.46, 4285.332, 4305.999, 4326.459, 4346.710999999999, 4366.752, 4386.579000000001, 4406.19, 4425.582, 4444.754, 4463.701, 4482.4220000000005, 4500.915, 4519.175, 4537.202, 4554.991, 4572.541, 4589.848, 4606.909000000001, 4623.722, 4640.282999999999, 4656.59, 4672.639, 4688.427, 4703.951, 4719.208, 4734.194, 4748.907, 4763.342000000001, 4777.496, 4791.365, 4804.947, 4818.237, 4831.232, 4843.928, 4856.321, 4868.407, 4880.183, 4891.643, 4902.782999999999, 4913.601, 4924.09, 4934.247, 4944.068, 4953.548, 4962.681, 4971.464, 4979.891, 4987.958, 4995.659000000001, 5002.99, 5009.943, 5016.516, 5022.701, 5028.494000000001, 5033.889, 5038.879, 5043.459, 5047.623, 5051.3640000000005, 5054.675, 5057.5509999999995, 5059.984, 5061.968, 5063.495, 5064.558, 5065.151, 5065.265, 5064.893, 5064.026, 5062.656, 5060.775, 5058.375, 5055.447, 5051.982, 5047.97, 5043.402, 5038.269, 5032.559, 5026.263, 5019.371, 5011.871, 5003.753, 4995.004, 4985.6140000000005, 4975.569, 4964.858, 4953.467000000001, 4941.384, 4928.595, 4915.084, 4900.839, 4885.845, 4870.085999999999, 4853.545999999999, 4836.208, 4818.056, 4799.073, 4779.24, 4758.539000000001, 4736.951, 4714.455, 4691.032999999999, 4666.661, 4641.319, 4614.984, 4587.630999999999, 4559.238, 4529.779, 4499.227, 4467.557, 4434.7390000000005, 4400.745, 4365.545999999999, 4329.11, 4291.405, 4252.396, 4212.05, 4170.331, 4127.2, 4082.6209999999996, 4036.552, 3988.95, 3939.775, 3888.9790000000003, 3836.518, 3782.341, 3726.401, 3668.645, 3609.018, 3547.466, 3483.9309999999996, 3418.3559999999998, 3350.677, 3280.835, 3208.762, 3134.395, 3057.6679999999997, 2978.509, 2896.8540000000003, 2812.63, 2725.77, 2636.205, 2543.869, 2448.696, 2350.627, 2249.603, 2145.575, 2038.5020000000002, 1928.351, 1815.101, 1698.75, 1579.3110000000001, 1456.819, 1331.336, 1202.9489999999998, 1071.7830000000001, 937.9960000000001, 801.7860000000001, 663.395, 523.107, 381.25300000000004, 238.206, 94.38, -49.776, -193.785, -337.15, -479.36800000000005, -619.934, -758.363, -894.193, -1026.998, -1156.3980000000001, -1282.0610000000001, -1403.7089999999998, -1521.12, -1634.125, -1742.606, -1846.494, -1945.7620000000002, -2040.421, -2130.513, -2216.1079999999997, -2297.295, -2374.1839999999997, -2446.8920000000003, -2515.551, -2580.297, -2641.268, -2698.607, -2752.452, -2802.9429999999998, -2850.218, -2894.41, -2935.6490000000003, -2974.058, -3009.759, -3042.868, -3073.495, -3101.7470000000003, -3127.725, -3151.526, -3173.241, -3192.958, -3210.761, -3226.7290000000003, -3240.937, -3253.4590000000003, -3264.36, -3273.7070000000003, -3281.562, -3287.982, -3293.025, -3296.743, -3299.1859999999997, -3300.403, -3300.44, -3299.341, -3297.1459999999997, -3293.8979999999997, -3289.632, -3284.385, -3278.192, -3271.086, -3263.098, -3254.26, -3244.598, -3234.1420000000003, -3222.9179999999997, -3210.952, -3198.2670000000003, -3184.886, -3170.833, -3156.1290000000004, -3140.7940000000003, -3124.849, -3108.312, -3091.202, -3073.5359999999996, -3055.33, -3036.603, -3017.368, -2997.6420000000003, -2977.44, -2956.7740000000003, -2935.659, -2914.1079999999997, -2892.133, -2869.7459999999996, -2846.96, -2823.7859999999996, -2800.235, -2776.3179999999998, -2752.045, -2727.425, -2702.469, -2677.1859999999997, -2651.585, -2625.675, -2599.464, -2572.96, -2546.172, -2519.1079999999997, -2491.774, -2464.179, -2436.33, -2408.2329999999997, -2379.895, -2351.323, -2322.522, -2293.5, -2264.262, -2234.815, -2205.163, -2175.313, -2145.269, -2115.0370000000003, -2084.623, -2054.031, -2023.266, -1992.3329999999999, -1961.237, -1929.9820000000002, -1898.5720000000001, -1867.0120000000002, -1835.306, -1803.4589999999998, -1771.474, -1739.355, -1707.106, -1674.731, -1642.234, -1609.618, -1576.886, -1544.043, -1511.0910000000001, -1478.0339999999999, -1444.875, -1411.618, -1378.265, -1344.819, -1311.2839999999999, -1277.662, -1243.9569999999999, -1210.171, -1176.307, -1142.367, -1108.355, -1074.272, -1040.122, -1005.908, -971.6310000000001, -937.293, -902.8989999999999, -868.449, -833.946, -799.393, -764.791, -730.143, -695.451, -660.7180000000001, -625.945, -591.134, -556.288, -521.408, -486.49699999999996, -451.55699999999996, -416.588, -381.595, -346.577, -311.538, -276.478, -241.4, -206.30599999999998, -171.197, -136.075, -100.94200000000001, -65.8, -30.649, 4.507, 39.668, 74.831, 109.99600000000001, 145.161, 180.32299999999998, 215.482, 250.636, 285.784, 320.923, 356.05199999999996, 391.171, 426.276, 461.36800000000005, 496.444, 531.503, 566.543, 601.564, 636.564, 671.54, 706.493, 741.42, 776.32, 811.193, 846.035, 880.847, 915.6260000000001, 950.372, 985.0830000000001, 1019.757, 1054.395, 1088.993, 1123.5510000000002, 1158.068, 1192.542, 1226.971, 1261.356, 1295.694, 1329.984, 1364.225, 1398.4160000000002, 1432.555, 1466.641, 1500.6729999999998, 1534.65, 1568.57, 1602.432, 1636.235, 1669.9779999999998, 1703.658, 1737.277, 1770.8310000000001, 1804.319, 1837.741, 1871.095, 1904.381, 1937.596, 1970.739, 2003.809, 2036.806, 2069.7270000000003, 2102.572, 2135.339, 2168.027, 2200.635, 2233.161, 2265.604, 2297.964, 2330.238, 2362.425, 2394.525, 2426.536, 2458.456, 2490.285, 2522.021, 2553.6620000000003, 2585.208, 2616.657, 2648.009, 2679.26, 2710.4109999999996, 2741.46, 2772.405, 2803.2459999999996, 2833.9809999999998, 2864.6079999999997, 2895.1259999999997, 2925.534, 2955.8309999999997, 2986.015, 3016.0840000000003, 3046.039, 3075.8759999999997, 3105.593, 3135.192, 3164.6690000000003, 3194.0229999999997, 3223.2529999999997, 3252.357, 3281.3340000000003, 3310.1820000000002, 3338.9, 3367.486, 3395.9390000000003, 3424.258, 3452.44, 3480.4829999999997, 3508.388, 3536.151, 3563.772, 3591.248, 3618.579, 3645.762, 3672.795, 3699.678, 3726.408, 3752.9829999999997, 3779.402, 3805.664, 3831.7659999999996, 3857.7059999999997, 3883.4829999999997, 3909.095, 3934.5409999999997, 3959.817, 3984.923, 4009.8559999999998, 4034.615, 4059.197, 4083.6009999999997, 4107.825, 4131.866, 4155.722, 4179.392, 4202.873, 4226.164000000001, 4249.2609999999995, 4272.163, 4294.8679999999995, 4317.373, 4339.6759999999995, 4361.776, 4383.668, 4405.352, 4426.8240000000005, 4448.083, 4469.125, 4489.9490000000005, 4510.552, 4530.93, 4551.083, 4571.0070000000005, 4590.6990000000005, 4610.156, 4629.376, 4648.357, 4667.094, 4685.585999999999, 4703.829000000001, 4721.82, 4739.557, 4757.035, 4774.253, 4791.207, 4807.893, 4824.309, 4840.45, 4856.314, 4871.898, 4887.197, 4902.208, 4916.927, 4931.351, 4945.476, 4959.298, 4972.813, 4986.018, 4998.907, 5011.477, 5023.724, 5035.644, 5047.231, 5058.481, 5069.391, 5079.956, 5090.17, 5100.028, 5109.527, 5118.661, 5127.424, 5135.812, 5143.819, 5151.44, 5158.668, 5165.499, 5171.927, 5177.945, 5183.548, 5188.73, 5193.483, 5197.802, 5201.68, 5205.111, 5208.085999999999, 5210.599, 5212.643, 5214.21, 5215.293, 5215.884, 5215.975, 5215.557, 5214.623, 5213.163, 5211.169, 5208.630999999999, 5205.541, 5201.889, 5197.665, 5192.859, 5187.460999999999, 5181.459, 5174.843, 5167.602, 5159.725, 5151.2, 5142.013, 5132.154, 5121.608, 5110.363, 5098.404, 5085.719, 5072.293, 5058.109, 5043.154, 5027.411, 5010.863, 4993.495, 4975.288, 4956.225, 4936.287, 4915.454000000001, 4893.707, 4871.026, 4847.389, 4822.775, 4797.16, 4770.522, 4742.837, 4714.0779999999995, 4684.22, 4653.236, 4621.1, 4587.78, 4553.248, 4517.473, 4480.4220000000005, 4442.062, 4402.359, 4361.276, 4318.777, 4274.822, 4229.371, 4182.384, 4133.816, 4083.623, 4031.759, 3978.1740000000004, 3922.82, 3865.6440000000002, 3806.592, 3745.6090000000004, 3682.638, 3617.619, 3550.491, 3481.19, 3409.651, 3335.809, 3259.593, 3180.935, 3099.764, 3016.008, 2929.593, 2840.449, 2748.5040000000004, 2653.685, 2555.927, 2455.1639999999998, 2351.334, 2244.386, 2134.272, 2020.955, 1904.414, 1784.64, 1661.642, 1535.453, 1406.132, 1273.765, 1138.472, 1000.413, 859.785, 716.832, 571.841, 425.148, 277.133, 128.219, -21.136, -170.43900000000002, -319.17900000000003, -466.834, -612.881, -756.815, -898.153, -1036.448, -1171.297, -1302.351, -1429.3120000000001, -1551.942, -1670.057, -1783.527, -1892.273, -1996.259, -2095.489, -2190.0029999999997, -2279.865, -2365.167, -2446.014, -2522.529, -2594.844, -2663.0959999999995, -2727.429, -2787.986, -2844.9120000000003, -2898.3509999999997, -2948.4440000000004, -2995.328, -3039.138, -3080.002, -3118.046, -3153.4240000000004, -3186.145, -3216.426, -3244.336, -3269.975, -3293.44, -3314.82, -3334.204, -3351.673, -3367.305, -3381.176, -3393.3559999999998, -3403.913, -3412.9109999999996, -3420.4109999999996, -3426.4709999999995, -3431.1479999999997, -3434.493, -3436.555, -3437.385, -3437.026, -3435.522, -3432.915, -3429.245, -3424.5490000000004, -3418.863, -3412.22, -3404.656, -3396.2009999999996, -3386.885, -3376.736, -3365.783, -3354.052, -3341.5679999999998, -3328.357, -3314.44, -3299.841, -3284.5809999999997, -3268.68, -3252.158, -3235.0359999999996, -3217.33, -3199.06, -3180.24, -3160.89, -3141.022, -3120.6540000000005, -3099.8, -3078.473, -3056.6890000000003, -3034.4590000000003, -3011.798, -2988.716, -2965.225, -2941.3390000000004, -2917.067, -2892.42, -2867.408, -2842.0429999999997, -2816.333, -2790.288, -2763.917, -2737.23, -2710.2340000000004, -2682.9390000000003, -2655.3520000000003, -2627.4809999999998, -2599.334, -2570.9179999999997, -2542.241, -2513.3089999999997, -2484.13, -2454.709, -2425.055, -2395.173, -2365.0679999999998, -2334.746, -2304.215, -2273.479, -2242.544, -2211.415, -2180.098, -2148.597, -2116.9179999999997, -2085.0660000000003, -2053.045, -2020.859, -1988.514, -1956.014, -1923.3629999999998, -1890.565, -1857.624, -1824.546, -1791.332, -1757.9879999999998, -1724.517, -1690.922, -1657.2079999999999, -1623.378, -1589.435, -1555.3829999999998, -1521.225, -1486.964, -1452.604, -1418.1470000000002, -1383.598, -1348.9579999999999, -1314.231, -1279.4189999999999, -1244.526, -1209.5539999999999, -1174.506, -1139.385, -1104.194, -1068.934, -1033.609, -998.221, -962.7719999999999, -927.265, -891.703, -856.087, -820.42, -784.705, -748.943, -713.137, -677.289, -641.401, -605.475, -569.514, -533.518, -497.49199999999996, -461.435, -425.351, -389.241, -353.10699999999997, -316.952, -280.776, -244.583, -208.373, -172.148, -135.911, -99.662, -63.405, -27.14, 9.131, 45.406000000000006, 81.684, 117.962, 154.24, 190.515, 226.78599999999997, 263.051, 299.309, 335.559, 371.798, 408.025, 444.23900000000003, 480.43800000000005, 516.621, 552.786, 588.931, 625.056, 661.159, 697.238, 733.291, 769.319, 805.318, 841.288, 877.227, 913.1339999999999, 949.008, 984.846, 1020.6489999999999, 1056.414, 1092.14, 1127.825, 1163.469, 1199.07, 1234.627, 1270.138, 1305.6019999999999, 1341.0179999999998, 1376.385, 1411.7, 1446.963, 1482.1729999999998, 1517.328, 1552.4260000000002, 1587.4679999999998, 1622.451, 1657.3729999999998, 1692.235, 1727.0339999999999, 1761.769, 1796.4379999999999, 1831.0420000000001, 1865.578, 1900.0439999999999, 1934.441, 1968.766, 2003.0179999999998, 2037.1960000000001, 2071.298, 2105.324, 2139.272, 2173.141, 2206.929, 2240.635, 2274.257, 2307.7960000000003, 2341.249, 2374.614, 2407.891, 2441.078, 2474.175, 2507.179, 2540.089, 2572.904, 2605.623, 2638.244, 2670.7659999999996, 2703.187, 2735.507, 2767.724, 2799.836, 2831.842, 2863.741, 2895.531, 2927.211, 2958.7790000000005, 2990.2340000000004, 3021.5759999999996, 3052.801, 3083.909, 3114.8979999999997, 3145.7670000000003, 3176.514, 3207.139, 3237.638, 3268.012, 3298.258, 3328.3740000000003, 3358.361, 3388.2140000000004, 3417.934, 3447.5190000000002, 3476.967, 3506.276, 3535.4440000000004, 3564.4709999999995, 3593.355, 3622.093, 3650.685, 3679.1279999999997, 3707.421, 3735.562, 3763.5490000000004, 3791.381, 3819.055, 3846.571, 3873.926, 3901.118, 3928.1459999999997, 3955.008, 3981.7009999999996, 4008.224, 4034.575, 4060.752, 4086.7529999999997, 4112.576, 4138.219, 4163.68, 4188.957, 4214.048, 4238.951, 4263.663, 4288.183, 4312.508, 4336.6359999999995, 4360.565, 4384.292, 4407.815, 4431.1320000000005, 4454.241, 4477.139, 4499.823, 4522.292, 4544.542, 4566.571, 4588.377, 4609.957, 4631.308, 4652.427, 4673.313, 4693.960999999999, 4714.37, 4734.536, 4754.458, 4774.13, 4793.552, 4812.718, 4831.628, 4850.277, 4868.662, 4886.78, 4904.628, 4922.202, 4939.5, 4956.516, 4973.249, 4989.694, 5005.848, 5021.707, 5037.268, 5052.527, 5067.479, 5082.12, 5096.448, 5110.457, 5124.144, 5137.503, 5150.532, 5163.224, 5175.577, 5187.585, 5199.2429999999995, 5210.5470000000005, 5221.492, 5232.073, 5242.286, 5252.1230000000005, 5261.581999999999, 5270.655, 5279.338000000001, 5287.624, 5295.509, 5302.986999999999, 5310.05, 5316.693, 5322.911, 5328.696, 5334.0419999999995, 5338.943, 5343.391, 5347.38, 5350.901999999999, 5353.95, 5356.517, 5358.594, 5360.174, 5361.249, 5361.811, 5361.851, 5361.361, 5360.331, 5358.753000000001, 5356.616999999999, 5353.914000000001, 5350.633000000001, 5346.766, 5342.3009999999995, 5337.227, 5331.534000000001, 5325.21, 5318.244000000001, 5310.625, 5302.339, 5293.375, 5283.72, 5273.359, 5262.279, 5250.467, 5237.907999999999, 5224.588, 5210.4890000000005, 5195.598, 5179.896, 5163.367, 5145.995, 5127.762, 5108.648, 5088.634, 5067.7, 5045.827, 5022.9929999999995, 4999.1759999999995, 4974.355, 4948.503, 4921.6, 4893.62, 4864.535, 4834.32, 4802.947, 4770.387, 4736.611, 4701.587, 4665.282999999999, 4627.667, 4588.704000000001, 4548.357, 4506.592000000001, 4463.367, 4418.644, 4372.3820000000005, 4324.537, 4275.064, 4223.918, 4171.05, 4116.41, 4059.948, 4001.6079999999997, 3941.336, 3879.073, 3814.761, 3748.3390000000004, 3679.741, 3608.903, 3535.757, 3460.235, 3382.264, 3301.7740000000003, 3218.688, 3132.934, 3044.435, 2953.115, 2858.901, 2761.716, 2661.49, 2558.155, 2451.645, 2341.903, 2228.88, 2112.534, 1992.839, 1869.783, 1743.3729999999998, 1613.635, 1480.6270000000002, 1344.433, 1205.1689999999999, 1062.995, 918.1080000000001, 770.752, 621.2180000000001, 469.846, 317.019, 163.171, 8.771, -145.67700000000002, -299.647, -452.6, -603.996, -753.308, -900.034, -1043.704, -1183.8980000000001, -1320.245, -1452.4289999999999, -1580.194, -1703.342, -1821.73, -1935.269, -2043.9129999999998, -2147.661, -2246.547, -2340.634, -2430.009, -2514.781, -2595.07, -2671.011, -2742.744, -2810.414, -2874.171, -2934.1609999999996, -2990.533, -3043.4309999999996, -3092.998, -3139.37, -3182.683, -3223.063, -3260.637, -3295.5209999999997, -3327.8320000000003, -3357.675, -3385.157, -3410.3740000000003, -3433.4240000000004, -3454.3940000000002, -3473.3709999999996, -3490.4359999999997, -3505.6659999999997, -3519.135, -3530.913, -3541.067, -3549.6609999999996, -3556.7529999999997, -3562.403, -3566.665, -3569.591, -3571.2290000000003, -3571.6290000000004, -3570.835, -3568.89, -3565.835, -3561.71, -3556.551, -3550.395, -3543.276, -3535.2270000000003, -3526.278, -3516.461, -3505.803, -3494.3320000000003, -3482.075, -3469.058, -3455.303, -3440.835, -3425.676, -3409.8459999999995, -3393.368, -3376.261, -3358.5440000000003, -3340.236, -3321.3540000000003, -3301.915, -3281.9359999999997, -3261.4320000000002, -3240.4190000000003, -3218.9120000000003, -3196.9240000000004, -3174.4709999999995, -3151.5640000000003, -3128.217, -3104.442, -3080.2509999999997, -3055.655, -3030.667, -3005.296, -2979.553, -2953.449, -2926.993, -2900.195, -2873.0640000000003, -2845.61, -2817.84, -2789.764, -2761.389, -2732.723, -2703.775, -2674.552, -2645.0609999999997, -2615.3089999999997, -2585.304, -2555.051, -2524.558, -2493.83, -2462.875, -2431.698, -2400.305, -2368.701, -2336.894, -2304.887, -2272.686, -2240.2960000000003, -2207.723, -2174.972, -2142.0460000000003, -2108.952, -2075.6929999999998, -2042.274, -2008.6989999999998, -1974.974, -1941.101, -1907.085, -1872.93, -1838.64, -1804.219, -1769.671, -1734.9979999999998, -1700.2060000000001, -1665.297, -1630.275, -1595.1429999999998, -1559.905, -1524.5639999999999, -1489.1229999999998, -1453.585, -1417.954, -1382.231, -1346.421, -1310.527, -1274.55, -1238.494, -1202.362, -1166.157, -1129.88, -1093.535, -1057.125, -1020.6510000000001, -984.1160000000001, -947.523, -910.8739999999999, -874.172, -837.418, -800.6160000000001, -763.7669999999999, -726.8739999999999, -689.938, -652.9630000000001, -615.95, -578.901, -541.818, -504.704, -467.56, -430.389, -393.19199999999995, -355.972, -318.73, -281.468, -244.188, -206.892, -169.582, -132.26, -94.926, -57.583999999999996, -20.235, 17.119, 54.477, 91.837, 129.19799999999998, 166.55700000000002, 203.912, 241.263, 278.608, 315.945, 353.272, 390.589, 427.892, 465.18199999999996, 502.455, 539.711, 576.9490000000001, 614.1659999999999, 651.361, 688.534, 725.681, 762.802, 799.895, 836.959, 873.993, 910.995, 947.9630000000001, 984.895, 1021.793, 1058.652, 1095.472, 1132.252, 1168.99, 1205.685, 1242.335, 1278.9389999999999, 1315.496, 1352.004, 1388.4620000000002, 1424.868, 1461.2220000000002, 1497.5220000000002, 1533.766, 1569.953, 1606.082, 1642.152, 1678.161, 1714.108, 1749.991, 1785.81, 1821.5620000000001, 1857.247, 1892.8629999999998, 1928.4089999999999, 1963.8829999999998, 1999.285, 2034.612, 2069.864, 2105.0389999999998, 2140.136, 2175.154, 2210.091, 2244.945, 2279.716, 2314.403, 2349.0029999999997, 2383.516, 2417.939, 2452.2729999999997, 2486.514, 2520.663, 2554.718, 2588.676, 2622.538, 2656.301, 2689.9640000000004, 2723.526, 2756.985, 2790.3390000000004, 2823.5890000000004, 2856.7309999999998, 2889.765, 2922.6890000000003, 2955.502, 2988.202, 3020.788, 3053.258, 3085.611, 3117.845, 3149.9590000000003, 3181.9509999999996, 3213.82, 3245.565, 3277.183, 3308.673, 3340.034, 3371.264, 3402.361, 3433.325, 3464.152, 3494.842, 3525.393, 3555.803, 3586.071, 3616.195, 3646.1740000000004, 3676.005, 3705.687, 3735.218, 3764.5959999999995, 3793.82, 3822.888, 3851.798, 3880.548, 3909.136, 3937.5609999999997, 3965.82, 3993.9120000000003, 4021.835, 4049.587, 4077.165, 4104.569, 4131.795, 4158.842000000001, 4185.708, 4212.391, 4238.889, 4265.198, 4291.319, 4317.247, 4342.981, 4368.519, 4393.859, 4418.998, 4443.934, 4468.664000000001, 4493.187, 4517.499, 4541.599, 4565.484, 4589.151, 4612.598, 4635.822, 4658.821, 4681.592000000001, 4704.1320000000005, 4726.439, 4748.509, 4770.340999999999, 4791.931, 4813.276, 4834.373, 4855.22, 4875.813, 4896.15, 4916.227, 4936.041, 4955.589, 4974.8679999999995, 4993.873, 5012.603, 5031.053, 5049.22, 5067.101, 5084.691, 5101.988, 5118.987, 5135.684, 5152.076, 5168.159000000001, 5183.929, 5199.3820000000005, 5214.513, 5229.319, 5243.795, 5257.937, 5271.74, 5285.2, 5298.311, 5311.07, 5323.472, 5335.5109999999995, 5347.183000000001, 5358.482, 5369.404, 5379.943, 5390.093000000001, 5399.849, 5409.206, 5418.156999999999, 5426.696999999999, 5434.819, 5442.518, 5449.786999999999, 5456.621, 5463.0109999999995, 5468.951999999999, 5474.437, 5479.4580000000005, 5484.008000000001, 5488.081, 5491.668000000001, 5494.7609999999995, 5497.354, 5499.438, 5501.004, 5502.045, 5502.55, 5502.513000000001, 5501.923000000001, 5500.77, 5499.045999999999, 5496.741, 5493.843000000001, 5490.344, 5486.232, 5481.496999999999, 5476.1269999999995, 5470.111, 5463.436, 5456.090999999999, 5448.062, 5439.339, 5429.905, 5419.75, 5408.857, 5397.213000000001, 5384.802, 5371.609, 5357.62, 5342.816, 5327.182, 5310.7, 5293.352, 5275.119000000001, 5255.984, 5235.925, 5214.923, 5192.956, 5170.003, 5146.041, 5121.048, 5094.999, 5067.87, 5039.633, 5010.264, 4979.734, 4948.016, 4915.0779999999995, 4880.891, 4845.423, 4808.641, 4770.51, 4730.996, 4690.062, 4647.669, 4603.776, 4558.345, 4511.332, 4462.692, 4412.38, 4360.348, 4306.545, 4250.9220000000005, 4193.423, 4133.995, 4072.58, 4009.118, 3943.548, 3875.8059999999996, 3805.827, 3733.5429999999997, 3658.883, 3581.777, 3502.15, 3419.928, 3335.033, 3247.389, 3156.9159999999997, 3063.535, 2967.1690000000003, 2867.739, 2765.171, 2659.3920000000003, 2550.334, 2437.936, 2322.1420000000003, 2202.91, 2080.21, 1954.0220000000002, 1824.351, 1691.223, 1554.6889999999999, 1414.829, 1271.761, 1125.639, 976.663, 825.074, 671.168, 515.285, 357.81699999999995, 199.203, 39.923, -119.51, -278.55400000000003, -436.654, -593.253, -747.805, -899.7860000000001, -1048.7089999999998, -1194.13, -1335.6589999999999, -1472.963, -1605.769, -1733.862, -1857.089, -1975.345, -2088.58, -2196.784, -2299.985, -2398.243, -2491.645, -2580.297, -2664.321, -2743.853, -2819.035, -2890.015, -2956.946, -3019.9770000000003, -3079.262, -3134.948, -3187.1809999999996, -3236.103, -3281.853, -3324.562, -3364.36, -3401.367, -3435.702, -3467.4770000000003, -3496.8, -3523.7729999999997, -3548.493, -3571.054, -3591.545, -3610.048, -3626.645, -3641.4120000000003, -3654.421, -3665.742, -3675.44, -3683.578, -3690.215, -3695.408, -3699.212, -3701.676, -3702.8520000000003, -3702.785, -3701.52, -3699.1, -3695.565, -3690.955, -3685.3059999999996, -3678.6540000000005, -3671.033, -3662.475, -3653.012, -3642.6740000000004, -3631.488, -3619.4829999999997, -3606.684, -3593.117, -3578.8059999999996, -3563.775, -3548.045, -3531.638, -3514.575, -3496.875, -3478.558, -3459.6420000000003, -3440.145, -3420.083, -3399.474, -3378.3340000000003, -3356.676, -3334.518, -3311.8709999999996, -3288.7509999999997, -3265.17, -3241.1420000000003, -3216.679, -3191.7940000000003, -3166.4970000000003, -3140.8, -3114.7129999999997, -3088.2490000000003, -3061.4159999999997, -3034.225, -3006.685, -2978.8059999999996, -2950.5959999999995, -2922.065, -2893.2209999999995, -2864.073, -2834.6279999999997, -2804.8940000000002, -2774.88, -2744.591, -2714.0359999999996, -2683.222, -2652.155, -2620.841, -2589.2889999999998, -2557.502, -2525.489, -2493.255, -2460.805, -2428.145, -2395.281, -2362.218, -2328.962, -2295.5170000000003, -2261.89, -2228.083, -2194.103, -2159.955, -2125.641, -2091.1679999999997, -2056.5389999999998, -2021.759, -1986.832, -1951.7620000000002, -1916.5529999999999, -1881.2079999999999, -1845.733, -1810.129, -1774.402, -1738.555, -1702.5910000000001, -1666.514, -1630.3270000000002, -1594.033, -1557.636, -1521.139, -1484.545, -1447.8570000000002, -1411.079, -1374.213, -1337.261, -1300.228, -1263.116, -1225.927, -1188.664, -1151.33, -1113.928, -1076.46, -1038.9289999999999, -1001.337, -963.686, -925.98, -888.221, -850.41, -812.55, -774.6439999999999, -736.694, -698.702, -660.67, -622.6, -584.495, -546.357, -508.18699999999995, -469.98800000000006, -431.76099999999997, -393.51, -355.235, -316.939, -278.623, -240.29, -201.94099999999997, -163.579, -125.204, -86.82, -48.427, -10.027999999999999, 28.375999999999998, 66.783, 105.19200000000001, 143.599, 182.005, 220.407, 258.803, 297.192, 335.57300000000004, 373.94300000000004, 412.3, 450.645, 488.974, 527.286, 565.58, 603.854, 642.107, 680.336, 718.5419999999999, 756.721, 794.872, 832.995, 871.087, 909.1469999999999, 947.174, 985.166, 1023.122, 1061.04, 1098.9180000000001, 1136.756, 1174.552, 1212.3039999999999, 1250.012, 1287.673, 1325.286, 1362.85, 1400.364, 1437.825, 1475.234, 1512.5870000000002, 1549.885, 1587.125, 1624.306, 1661.4270000000001, 1698.486, 1735.4820000000002, 1772.414, 1809.28, 1846.078, 1882.809, 1919.469, 1956.058, 1992.575, 2029.017, 2065.384, 2101.674, 2137.886, 2174.019, 2210.071, 2246.04, 2281.925, 2317.726, 2353.44, 2389.0660000000003, 2424.603, 2460.049, 2495.404, 2530.6639999999998, 2565.83, 2600.899, 2635.8709999999996, 2670.744, 2705.515, 2740.185, 2774.7509999999997, 2809.2129999999997, 2843.5679999999998, 2877.815, 2911.952, 2945.9790000000003, 2979.893, 3013.6940000000004, 3047.3790000000004, 3080.947, 3114.397, 3147.7259999999997, 3180.935, 3214.02, 3246.9809999999998, 3279.815, 3312.522, 3345.099, 3377.546, 3409.86, 3442.039, 3474.083, 3505.99, 3537.757, 3569.383, 3600.867, 3632.2059999999997, 3663.4, 3694.445, 3725.341, 3756.086, 3786.678, 3817.115, 3847.3959999999997, 3877.5170000000003, 3907.4790000000003, 3937.278, 3966.913, 3996.382, 4025.683, 4054.8140000000003, 4083.7729999999997, 4112.558, 4141.167, 4169.598, 4197.849, 4225.918, 4253.803, 4281.502, 4309.012, 4336.331, 4363.458, 4390.389, 4417.124, 4443.657999999999, 4469.991, 4496.119000000001, 4522.04, 4547.753, 4573.253, 4598.54, 4623.611, 4648.462, 4673.092000000001, 4697.497, 4721.6759999999995, 4745.625, 4769.340999999999, 4792.823, 4816.067, 4839.07, 4861.83, 4884.344, 4906.608, 4928.619000000001, 4950.376, 4971.874, 4993.11, 5014.081, 5034.784000000001, 5055.215999999999, 5075.373, 5095.252, 5114.849, 5134.161, 5153.184, 5171.915, 5190.35, 5208.485, 5226.316, 5243.84, 5261.052, 5277.9490000000005, 5294.526, 5310.779, 5326.705, 5342.298000000001, 5357.554, 5372.469, 5387.0380000000005, 5401.255999999999, 5415.12, 5428.6230000000005, 5441.76, 5454.528, 5466.92, 5478.932, 5490.559, 5501.794, 5512.632, 5523.066999999999, 5533.095, 5542.7080000000005, 5551.9, 5560.6669999999995, 5569.0, 5576.893, 5584.340999999999, 5591.3369999999995, 5597.8730000000005, 5603.943, 5609.5380000000005, 5614.653, 5619.279, 5623.409000000001, 5627.034000000001, 5630.146, 5632.738, 5634.8009999999995, 5636.326999999999, 5637.305, 5637.727, 5637.584, 5636.866999999999, 5635.564, 5633.6669999999995, 5631.1630000000005, 5628.044, 5624.299, 5619.915, 5614.882, 5609.187, 5602.819, 5595.764, 5588.009, 5579.543000000001, 5570.351, 5560.42, 5549.733, 5538.278, 5526.036999999999, 5512.996, 5499.139, 5484.4490000000005, 5468.908, 5452.499, 5435.201999999999, 5417.0, 5397.8730000000005, 5377.8009999999995, 5356.762, 5334.735, 5311.696999999999, 5287.626, 5262.4980000000005, 5236.289000000001, 5208.971, 5180.52, 5150.907999999999, 5120.107, 5088.087, 5054.818, 5020.268, 4984.406, 4947.195, 4908.603, 4868.592000000001, 4827.125, 4784.161, 4739.661, 4693.583, 4645.880999999999, 4596.5109999999995, 4545.4259999999995, 4492.576, 4437.911, 4381.377, 4322.918, 4262.48, 4200.002, 4135.423, 4068.68, 3999.7070000000003, 3928.437, 3854.7990000000004, 3778.722, 3700.13, 3618.95, 3535.1009999999997, 3448.507, 3359.0840000000003, 3266.752, 3171.429, 3073.034, 2971.486, 2866.704, 2758.615, 2647.147, 2532.232, 2413.815, 2291.847, 2166.291, 2037.129, 1904.361, 1768.006, 1628.112, 1484.759, 1338.059, 1188.167, 1035.279, 879.638, 721.54, 561.327, 399.399, 236.197, 72.212, -92.027, -255.975, -419.059, -580.703, -740.341, -897.433, -1051.47, -1201.988, -1348.578, -1490.8870000000002, -1628.626, -1761.565, -1889.536, -2012.425, -2130.17, -2242.755, -2350.2039999999997, -2452.573, -2549.9429999999998, -2642.423, -2730.134, -2813.2129999999997, -2891.804, -2966.058, -3036.1290000000004, -3102.172, -3164.342, -3222.7909999999997, -3277.67, -3329.1240000000003, -3377.295, -3422.3179999999998, -3464.312, -3503.446, -3539.7990000000004, -3573.4990000000003, -3604.66, -3633.385, -3659.775, -3683.927, -3705.933, -3725.8779999999997, -3743.847, -3759.9179999999997, -3774.165, -3786.6609999999996, -3797.474, -3806.6659999999997, -3814.303, -3820.441, -3825.136, -3828.44, -3830.407, -3831.0840000000003, -3830.5159999999996, -3828.7490000000003, -3825.823, -3821.781, -3816.659, -3810.4959999999996, -3803.325, -3795.1809999999996, -3786.094, -3776.099, -3765.222, -3753.494, -3740.94, -3727.587, -3713.46, -3698.583, -3682.9790000000003, -3666.671, -3649.68, -3632.027, -3613.73, -3594.81, -3575.285, -3555.172, -3534.488, -3513.25, -3491.474, -3469.175, -3446.369, -3423.0679999999998, -3399.2870000000003, -3375.04, -3350.3390000000004, -3325.197, -3299.625, -3273.636, -3247.241, -3220.4509999999996, -3193.276, -3165.7259999999997, -3137.813, -3109.545, -3080.9320000000002, -3051.9829999999997, -3022.7070000000003, -2993.113, -2963.208, -2933.0009999999997, -2902.4990000000003, -2871.712, -2840.645, -2809.3070000000002, -2777.703, -2745.842, -2713.73, -2681.373, -2648.778, -2615.951, -2582.897, -2549.624, -2516.136, -2482.439, -2448.54, -2414.442, -2380.151, -2345.673, -2311.012, -2276.173, -2241.161, -2205.98, -2170.636, -2135.132, -2099.472, -2063.6620000000003, -2027.705, -1991.605, -1955.3670000000002, -1918.993, -1882.489, -1845.8570000000002, -1809.101, -1772.226, -1735.233, -1698.128, -1660.9129999999998, -1623.592, -1586.1670000000001, -1548.6429999999998, -1511.021, -1473.306, -1435.501, -1397.608, -1359.629, -1321.569, -1283.43, -1245.215, -1206.9260000000002, -1168.566, -1130.138, -1091.645, -1053.088, -1014.471, -975.795, -937.064, -898.28, -859.445, -820.562, -781.632, -742.658, -703.643, -664.5880000000001, -625.496, -586.369, -547.2090000000001, -508.01800000000003, -468.79900000000004, -429.55199999999996, -390.281, -350.98699999999997, -311.672, -272.33799999999997, -232.987, -193.622, -154.243, -114.853, -75.454, -36.047, 3.366, 42.782, 82.20100000000001, 121.62, 161.03799999999998, 200.453, 239.863, 279.267, 318.663, 358.04900000000004, 397.423, 436.785, 476.131, 515.461, 554.774, 594.067, 633.339, 672.5880000000001, 711.813, 751.012, 790.183, 829.326, 868.439, 907.5189999999999, 946.567, 985.579, 1024.555, 1063.493, 1102.391, 1141.249, 1180.0639999999999, 1218.836, 1257.562, 1296.242, 1334.8729999999998, 1373.455, 1411.986, 1450.464, 1488.889, 1527.2579999999998, 1565.57, 1603.8239999999998, 1642.019, 1680.152, 1718.223, 1756.23, 1794.172, 1832.047, 1869.854, 1907.5910000000001, 1945.257, 1982.851, 2020.372, 2057.817, 2095.185, 2132.475, 2169.686, 2206.8160000000003, 2243.863, 2280.827, 2317.705, 2354.4970000000003, 2391.201, 2427.815, 2464.3379999999997, 2500.769, 2537.106, 2573.348, 2609.493, 2645.54, 2681.487, 2717.3320000000003, 2753.075, 2788.7140000000004, 2824.248, 2859.6740000000004, 2894.991, 2930.198, 2965.2940000000003, 3000.276, 3035.143, 3069.8940000000002, 3104.528, 3139.0409999999997, 3173.434, 3207.704, 3241.85, 3275.87, 3309.762, 3343.525, 3377.158, 3410.658, 3444.0240000000003, 3477.255, 3510.348, 3543.302, 3576.115, 3608.785, 3641.3109999999997, 3673.692, 3705.9240000000004, 3738.007, 3769.9390000000003, 3801.717, 3833.34, 3864.8070000000002, 3896.114, 3927.261, 3958.245, 3989.065, 4019.719, 4050.204, 4080.518, 4110.66, 4140.628, 4170.42, 4200.032999999999, 4229.465, 4258.715, 4287.78, 4316.657, 4345.346, 4373.843, 4402.147, 4430.255, 4458.164000000001, 4485.873, 4513.379, 4540.68, 4567.773, 4594.656, 4621.327, 4647.782999999999, 4674.021, 4700.039000000001, 4725.835, 4751.405, 4776.747, 4801.859, 4826.737, 4851.379, 4875.781, 4899.942, 4923.858, 4947.526, 4970.944, 4994.108, 5017.015, 5039.662, 5062.045999999999, 5084.163, 5106.0109999999995, 5127.585, 5148.884, 5169.902, 5190.637, 5211.085999999999, 5231.244000000001, 5251.108, 5270.674, 5289.939, 5308.898, 5327.548000000001, 5345.885, 5363.904, 5381.602, 5398.974, 5416.016, 5432.723000000001, 5449.092, 5465.118, 5480.795, 5496.12, 5511.0869999999995, 5525.691999999999, 5539.931, 5553.797, 5567.285, 5580.391, 5593.109, 5605.433000000001, 5617.358, 5628.879, 5639.988, 5650.681, 5660.951999999999, 5670.794, 5680.2, 5689.164000000001, 5697.681, 5705.741999999999, 5713.342, 5720.473000000001, 5727.128000000001, 5733.299, 5738.979, 5744.16, 5748.835, 5752.994000000001, 5756.630999999999, 5759.735, 5762.299, 5764.315, 5765.772, 5766.661, 5766.973000000001, 5766.698, 5765.826, 5764.346, 5762.246999999999, 5759.52, 5756.151, 5752.132, 5747.4490000000005, 5742.089, 5736.0419999999995, 5729.294, 5721.831, 5713.64, 5704.706999999999, 5695.018, 5684.558000000001, 5673.313, 5661.265, 5648.399, 5634.6990000000005, 5620.146, 5604.724, 5588.414000000001, 5571.198, 5553.056, 5533.967, 5513.911999999999, 5492.868, 5470.814, 5447.727, 5423.5830000000005, 5398.359, 5372.026999999999, 5344.562, 5315.938, 5286.1269999999995, 5255.099, 5222.823, 5189.27, 5154.406, 5118.1990000000005, 5080.613, 5041.612, 5001.16, 4959.217000000001, 4915.7429999999995, 4870.695, 4824.032999999999, 4775.708, 4725.6759999999995, 4673.887, 4620.291, 4564.835999999999, 4507.465999999999, 4448.127, 4386.759, 4323.3009999999995, 4257.691, 4189.8640000000005, 4119.751, 4047.284, 3972.389, 3894.994, 3815.0209999999997, 3732.393, 3647.0290000000005, 3558.8459999999995, 3467.762, 3373.691, 3276.551, 3176.2540000000004, 3072.718, 2965.86, 2855.6, 2741.865, 2624.5820000000003, 2503.6929999999998, 2379.143, 2250.895, 2118.924, 1983.225, 1843.815, 1700.739, 1554.0720000000001, 1403.924, 1250.447, 1093.835, 934.332, 772.2330000000001, 607.883, 441.684, 274.085, 105.583, -63.287, -231.959, -399.849, -566.367, -730.929, -892.9739999999999, -1051.974, -1207.447, -1358.961, -1506.149, -1648.701, -1786.375, -1918.986, -2046.411, -2168.577, -2285.4610000000002, -2397.0789999999997, -2503.485, -2604.759, -2701.006, -2792.347, -2878.921, -2960.873, -3038.357, -3111.5290000000005, -3180.546, -3245.5690000000004, -3306.752, -3364.2490000000003, -3418.211, -3468.78, -3516.099, -3560.302, -3601.5209999999997, -3639.8779999999997, -3675.495, -3708.4829999999997, -3738.954, -3767.01, -3792.7509999999997, -3816.27, -3837.658, -3857.0009999999997, -3874.3790000000004, -3889.869, -3903.546, -3915.4809999999998, -3925.738, -3934.383, -3941.4759999999997, -3947.074, -3951.2329999999997, -3954.005, -3955.44, -3955.586, -3954.489, -3952.191, -3948.735, -3944.16, -3938.505, -3931.805, -3924.0959999999995, -3915.41, -3905.781, -3895.237, -3883.81, -3871.526, -3858.413, -3844.4959999999996, -3829.801, -3814.3509999999997, -3798.17, -3781.28, -3763.7009999999996, -3745.455, -3726.5609999999997, -3707.038, -3686.9040000000005, -3666.177, -3644.8740000000003, -3623.012, -3600.6059999999998, -3577.672, -3554.224, -3530.277, -3505.844, -3480.94, -3455.575, -3429.765, -3403.5190000000002, -3376.8509999999997, -3349.77, -3322.29, -3294.4190000000003, -3266.17, -3237.55, -3208.571, -3179.241, -3149.571, -3119.5679999999998, -3089.241, -3058.599, -3027.65, -2996.402, -2964.863, -2933.04, -2900.94, -2868.57, -2835.9390000000003, -2803.051, -2769.915, -2736.535, -2702.9190000000003, -2669.073, -2635.002, -2600.712, -2566.21, -2531.499, -2496.587, -2461.479, -2426.178, -2390.6910000000003, -2355.022, -2319.176, -2283.158, -2246.972, -2210.623, -2174.115, -2137.452, -2100.639, -2063.68, -2026.579, -1989.34, -1951.9660000000001, -1914.4620000000002, -1876.8310000000001, -1839.0770000000002, -1801.203, -1763.213, -1725.111, -1686.899, -1648.5810000000001, -1610.16, -1571.64, -1533.024, -1494.3139999999999, -1455.514, -1416.626, -1377.655, -1338.601, -1299.469, -1260.261, -1220.98, -1181.629, -1142.2089999999998, -1102.725, -1063.177, -1023.57, -983.905, -944.185, -904.4119999999999, -864.5880000000001, -824.717, -784.8, -744.84, -704.8380000000001, -664.798, -624.721, -584.609, -544.465, -504.29, -464.088, -423.85900000000004, -383.606, -343.33099999999996, -303.036, -262.723, -222.394, -182.05, -141.695, -101.32799999999999, -60.95399999999999, -20.572, 19.814, 60.20399999999999, 100.595, 140.985, 181.373, 221.757, 262.135, 302.505, 342.86699999999996, 383.217, 423.555, 463.879, 504.18699999999995, 544.477, 584.748, 624.999, 665.227, 705.43, 745.6089999999999, 785.76, 825.882, 865.9739999999999, 906.034, 946.061, 986.053, 1026.008, 1065.925, 1105.803, 1145.639, 1185.433, 1225.183, 1264.888, 1304.545, 1344.154, 1383.7120000000002, 1423.219, 1462.674, 1502.0729999999999, 1541.4170000000001, 1580.703, 1619.93, 1659.0970000000002, 1698.203, 1737.245, 1776.2220000000002, 1815.1329999999998, 1853.976, 1892.75, 1931.454, 1970.085, 2008.6429999999998, 2047.1270000000002, 2085.533, 2123.862, 2162.112, 2200.281, 2238.367, 2276.37, 2314.288, 2352.118, 2389.861, 2427.514, 2465.076, 2502.5460000000003, 2539.9210000000003, 2577.201, 2614.383, 2651.468, 2688.4509999999996, 2725.3340000000003, 2762.113, 2798.7870000000003, 2835.3559999999998, 2871.816, 2908.167, 2944.408, 2980.535, 3016.5490000000004, 3052.448, 3088.2290000000003, 3123.8909999999996, 3159.433, 3194.853, 3230.1490000000003, 3265.32, 3300.364, 3335.28, 3370.065, 3404.719, 3439.238, 3473.623, 3507.87, 3541.978, 3575.946, 3609.772, 3643.454, 3676.99, 3710.3779999999997, 3743.617, 3776.705, 3809.64, 3842.4190000000003, 3875.042, 3907.506, 3939.809, 3971.95, 4003.926, 4035.736, 4067.377, 4098.848, 4130.146, 4161.27, 4192.217000000001, 4222.985, 4253.572, 4283.977, 4314.196, 4344.228, 4374.07, 4403.721, 4433.177, 4462.437, 4491.499, 4520.359, 4549.016, 4577.468, 4605.710999999999, 4633.7429999999995, 4661.563, 4689.166, 4716.552, 4743.715999999999, 4770.657, 4797.372, 4823.859, 4850.113, 4876.134, 4901.918, 4927.460999999999, 4952.762, 4977.818, 5002.624, 5027.179, 5051.479, 5075.521, 5099.302, 5122.819, 5146.069, 5169.0470000000005, 5191.752, 5214.179, 5236.326, 5258.187, 5279.7609999999995, 5301.043000000001, 5322.029, 5342.717, 5363.102, 5383.18, 5402.946999999999, 5422.4, 5441.534000000001, 5460.345, 5478.829000000001, 5496.982, 5514.799, 5532.275, 5549.406999999999, 5566.189, 5582.618, 5598.687, 5614.393, 5629.729, 5644.691999999999, 5659.276, 5673.476, 5687.286, 5700.701, 5713.715, 5726.323, 5738.519, 5750.295999999999, 5761.649, 5772.571999999999, 5783.058000000001, 5793.1, 5802.693, 5811.828, 5820.5, 5828.701999999999, 5836.4259999999995, 5843.665, 5850.411, 5856.656999999999, 5862.394, 5867.615, 5872.311, 5876.473000000001, 5880.094, 5883.164000000001, 5885.674, 5887.615, 5888.977, 5889.751, 5889.9259999999995, 5889.491999999999, 5888.438, 5886.754, 5884.429, 5881.4490000000005, 5877.806, 5873.485, 5868.476, 5862.764, 5856.3369999999995, 5849.182, 5841.284000000001, 5832.628000000001, 5823.201, 5812.988, 5801.973000000001, 5790.14, 5777.471, 5763.951, 5749.562, 5734.285, 5718.102, 5700.994000000001, 5682.94, 5663.920999999999, 5643.916, 5622.9, 5600.854, 5577.753000000001, 5553.573, 5528.289000000001, 5501.875, 5474.305, 5445.55, 5415.5830000000005, 5384.3730000000005, 5351.89, 5318.1, 5282.973000000001, 5246.473000000001, 5208.565, 5169.212, 5128.375, 5086.016, 5042.092000000001, 4996.561, 4949.378, 4900.498, 4849.873, 4797.451, 4743.183, 4687.014, 4628.888, 4568.748, 4506.534000000001, 4442.183, 4375.630999999999, 4306.811, 4235.653, 4162.087, 4086.0359999999996, 4007.428, 3926.18, 3842.215, 3755.449, 3665.796, 3573.172, 3477.488, 3378.659, 3276.594, 3171.2070000000003, 3062.413, 2950.1290000000004, 2834.276, 2714.781, 2591.578, 2464.611, 2333.837, 2199.229, 2060.776, 1918.4920000000002, 1772.4189999999999, 1622.626, 1469.223, 1312.356, 1152.219, 989.053, 823.155, 654.87, 484.603, 312.809, 139.989, -33.31, -206.513, -379.022, -550.231, -719.539, -886.368, -1050.1689999999999, -1210.442, -1366.737, -1518.665, -1665.902, -1808.1870000000001, -1945.325, -2077.178, -2203.665, -2324.754, -2440.4570000000003, -2550.821, -2655.9240000000004, -2755.868, -2850.777, -2940.7870000000003, -3026.047, -3106.7090000000003, -3182.9359999999997, -3254.886, -3322.723, -3386.605, -3446.688, -3503.127, -3556.07, -3605.6609999999996, -3652.038, -3695.337, -3735.683, -3773.202, -3808.007, -3840.215, -3869.929, -3897.252, -3922.282, -3945.111, -3965.8259999999996, -3984.512, -4001.2490000000003, -4016.111, -4029.173, -4040.502, -4050.163, -4058.2209999999995, -4064.7329999999997, -4069.758, -4073.348, -4075.555, -4076.43, -4076.0190000000002, -4074.366, -4071.513, -4067.505, -4062.3779999999997, -4056.17, -4048.917, -4040.6540000000005, -4031.413, -4021.2259999999997, -4010.1240000000003, -3998.135, -3985.288, -3971.6079999999997, -3957.1220000000003, -3941.853, -3925.828, -3909.067, -3891.593, -3873.427, -3854.5890000000004, -3835.099, -3814.9759999999997, -3794.238, -3772.902, -3750.987, -3728.507, -3705.4790000000003, -3681.9179999999997, -3657.8390000000004, -3633.256, -3608.1820000000002, -3582.632, -3556.618, -3530.152, -3503.2470000000003, -3475.914, -3448.165, -3420.011, -3391.4629999999997, -3362.53, -3333.223, -3303.552, -3273.526, -3243.1540000000005, -3212.445, -3181.408, -3150.052, -3118.384, -3086.4120000000003, -3054.145, -3021.5890000000004, -2988.7529999999997, -2955.643, -2922.2670000000003, -2888.63, -2854.74, -2820.603, -2786.2259999999997, -2751.615, -2716.775, -2681.712, -2646.433, -2610.9429999999998, -2575.2470000000003, -2539.35, -2503.258, -2466.976, -2430.508, -2393.86, -2357.036, -2320.042, -2282.88, -2245.5570000000002, -2208.076, -2170.4410000000003, -2132.657, -2094.7270000000003, -2056.657, -2018.4489999999998, -1980.108, -1941.636, -1903.039, -1864.32, -1825.481, -1786.527, -1747.461, -1708.287, -1669.007, -1629.625, -1590.145, -1550.568, -1510.899, -1471.14, -1431.295, -1391.365, -1351.355, -1311.267, -1271.103, -1230.867, -1190.5610000000001, -1150.188, -1109.75, -1069.25, -1028.691, -988.075, -947.404, -906.681, -865.908, -825.0880000000001, -784.2230000000001, -743.316, -702.368, -661.382, -620.359, -579.303, -538.215, -497.098, -455.954, -414.784, -373.59, -332.376, -291.142, -249.891, -208.625, -167.345, -126.054, -84.75399999999999, -43.446000000000005, -2.1319999999999997, 39.186, 80.505, 121.825, 163.144, 204.458, 245.768, 287.07099999999997, 328.365, 369.649, 410.921, 452.17900000000003, 493.421, 534.646, 575.8530000000001, 617.038, 658.202, 699.342, 740.456, 781.543, 822.602, 863.63, 904.627, 945.59, 986.518, 1027.4089999999999, 1068.262, 1109.076, 1149.848, 1190.577, 1231.262, 1271.901, 1312.4920000000002, 1353.0339999999999, 1393.526, 1433.9660000000001, 1474.3529999999998, 1514.684, 1554.9589999999998, 1595.1760000000002, 1635.3339999999998, 1675.43, 1715.464, 1755.433, 1795.3370000000002, 1835.174, 1874.943, 1914.641, 1954.2679999999998, 1993.8220000000001, 2033.3010000000002, 2072.7039999999997, 2112.03, 2151.276, 2190.442, 2229.526, 2268.527, 2307.442, 2346.271, 2385.011, 2423.6620000000003, 2462.222, 2500.689, 2539.062, 2577.34, 2615.52, 2653.6009999999997, 2691.5809999999997, 2729.46, 2767.236, 2804.906, 2842.47, 2879.925, 2917.2709999999997, 2954.505, 2991.627, 3028.633, 3065.5240000000003, 3102.297, 3138.95, 3175.482, 3211.8909999999996, 3248.176, 3284.335, 3320.366, 3356.2670000000003, 3392.038, 3427.675, 3463.177, 3498.5440000000003, 3533.772, 3568.86, 3603.8059999999996, 3638.6090000000004, 3673.2659999999996, 3707.776, 3742.138, 3776.348, 3810.406, 3844.309, 3878.0559999999996, 3911.6440000000002, 3945.071, 3978.337, 4011.438, 4044.373, 4077.139, 4109.735, 4142.159000000001, 4174.407999999999, 4206.481, 4238.375, 4270.088, 4301.6179999999995, 4332.963, 4364.12, 4395.088, 4425.8640000000005, 4456.446, 4486.831, 4517.018, 4547.004, 4576.786, 4606.362, 4635.729, 4664.8859999999995, 4693.829000000001, 4722.557, 4751.066, 4779.353, 4807.417, 4835.255, 4862.863, 4890.2390000000005, 4917.380999999999, 4944.285, 4970.9490000000005, 4997.369000000001, 5023.543, 5049.468, 5075.141, 5100.558, 5125.717000000001, 5150.615, 5175.247, 5199.612, 5223.704000000001, 5247.522, 5271.062, 5294.32, 5317.293000000001, 5339.978, 5362.37, 5384.465999999999, 5406.262, 5427.754, 5448.939, 5469.812, 5490.37, 5510.608, 5530.522, 5550.109, 5569.363, 5588.28, 5606.856, 5625.0869999999995, 5642.967, 5660.491999999999, 5677.656, 5694.456999999999, 5710.888000000001, 5726.944, 5742.62, 5757.911, 5772.811, 5787.315, 5801.4169999999995, 5815.111999999999, 5828.394, 5841.255999999999, 5853.693, 5865.6990000000005, 5877.267, 5888.391, 5899.063, 5909.278, 5919.029, 5928.308000000001, 5937.108, 5945.423000000001, 5953.243, 5960.563, 5967.3730000000005, 5973.666, 5979.433000000001, 5984.6669999999995, 5989.358, 5993.496999999999, 5997.075, 6000.084, 6002.513000000001, 6004.354, 6005.595, 6006.227, 6006.2390000000005, 6005.62, 6004.359, 6002.445, 5999.866, 5996.609, 5992.664000000001, 5988.017, 5982.655, 5976.565, 5969.732, 5962.143, 5953.784000000001, 5944.638000000001, 5934.691, 5923.927, 5912.329000000001, 5899.882, 5886.566, 5872.365, 5857.259, 5841.231, 5824.259, 5806.3240000000005, 5787.405, 5767.48, 5746.528, 5724.524, 5701.444, 5677.265, 5651.960999999999, 5625.505999999999, 5597.871, 5569.029, 5538.95, 5507.605, 5474.960999999999, 5440.986, 5405.647, 5368.908, 5330.732, 5291.0830000000005, 5249.920999999999, 5207.206, 5162.894, 5116.944, 5069.309, 5019.943, 4968.794, 4915.814, 4860.95, 4804.146, 4745.344, 4684.488, 4621.514, 4556.358, 4488.956, 4419.238, 4347.133, 4272.568, 4195.468, 4115.752, 4033.343, 3948.1540000000005, 3860.1040000000003, 3769.103, 3675.065, 3577.8990000000003, 3477.513, 3373.8179999999998, 3266.725, 3156.1420000000003, 3041.985, 2924.17, 2802.623, 2677.2709999999997, 2548.058, 2414.933, 2277.867, 2136.845, 1991.876, 1842.999, 1690.2779999999998, 1533.82, 1373.7679999999998, 1210.313, 1043.695, 874.209, 702.203, 528.081, 352.30300000000005, 175.378, -2.1430000000000002, -179.672, -356.599, -532.304, -706.17, -877.6010000000001, -1046.031, -1210.937, -1371.8529999999998, -1528.372, -1680.152, -1826.9160000000002, -1968.455, -2104.6220000000003, -2235.321, -2360.514, -2480.205, -2594.437, -2703.2870000000003, -2806.8520000000003, -2905.256, -2998.636, -3087.1420000000003, -3170.928, -3250.156, -3324.992, -3395.598, -3462.137, -3524.77, -3583.652, -3638.938, -3690.772, -3739.383, -3784.655, -3826.9709999999995, -3866.3740000000003, -3902.982, -3936.913, -3968.2740000000003, -3997.172, -4023.7059999999997, -4047.969, -4070.055, -4090.048, -4108.03, -4124.08, -4138.273, -4150.678, -4161.362, -4170.392, -4177.8279999999995, -4183.729, -4188.149, -4191.141, -4192.758, -4193.0470000000005, -4192.055, -4189.825, -4186.399, -4181.819, -4176.123, -4169.348, -4161.529, -4152.7, -4142.893, -4132.14, -4120.471, -4107.915, -4094.498, -4080.248, -4065.1890000000003, -4049.347, -4032.745, -4015.4040000000005, -3997.348, -3978.598, -3959.172, -3939.092, -3918.375, -3897.04, -3875.105, -3852.585, -3829.4970000000003, -3805.857, -3781.6809999999996, -3756.9829999999997, -3731.778, -3706.078, -3679.897, -3653.2490000000003, -3626.145, -3598.598, -3570.619, -3542.22, -3513.4120000000003, -3484.205, -3454.61, -3424.637, -3394.296, -3363.595, -3332.545, -3301.1540000000005, -3269.4309999999996, -3237.385, -3205.0229999999997, -3172.3540000000003, -3139.385, -3106.1240000000003, -3072.579, -3038.757, -3004.664, -2970.3070000000002, -2935.6940000000004, -2900.83, -2865.722, -2830.3759999999997, -2794.798, -2758.995, -2722.9709999999995, -2686.732, -2650.284, -2613.633, -2576.782, -2539.739, -2502.506, -2465.091, -2427.496, -2389.7270000000003, -2351.7889999999998, -2313.685, -2275.4210000000003, -2237.0, -2198.428, -2159.7070000000003, -2120.842, -2081.837, -2042.6960000000001, -2003.4229999999998, -1964.021, -1924.494, -1884.845, -1845.079, -1805.1979999999999, -1765.2060000000001, -1725.1070000000002, -1684.9029999999998, -1644.598, -1604.195, -1563.6970000000001, -1523.1070000000002, -1482.4289999999999, -1441.665, -1400.817, -1359.89, -1318.885, -1277.806, -1236.655, -1195.4360000000001, -1154.149, -1112.799, -1071.388, -1029.9180000000001, -988.3919999999999, -946.812, -905.181, -863.5010000000001, -821.775, -780.0039999999999, -738.192, -696.34, -654.451, -612.526, -570.569, -528.581, -486.564, -444.52099999999996, -402.454, -360.36400000000003, -318.254, -276.125, -233.981, -191.822, -149.651, -107.469, -65.279, -23.083000000000002, 19.118, 61.321999999999996, 103.52600000000001, 145.73, 187.93099999999998, 230.127, 272.317, 314.499, 356.67, 398.83, 440.977, 483.10900000000004, 525.2230000000001, 567.319, 609.395, 651.4490000000001, 693.4789999999999, 735.4839999999999, 777.462, 819.4110000000001, 861.33, 903.217, 945.071, 986.8889999999999, 1028.671, 1070.414, 1112.118, 1153.78, 1195.399, 1236.973, 1278.501, 1319.981, 1361.412, 1402.7920000000001, 1444.119, 1485.392, 1526.61, 1567.771, 1608.8729999999998, 1649.915, 1690.894, 1731.8110000000001, 1772.6629999999998, 1813.4479999999999, 1854.1660000000002, 1894.8139999999999, 1935.391, 1975.896, 2016.3270000000002, 2056.6820000000002, 2096.959, 2137.159, 2177.278, 2217.315, 2257.269, 2297.139, 2336.9210000000003, 2376.616, 2416.222, 2455.736, 2495.158, 2534.486, 2573.718, 2612.8520000000003, 2651.888, 2690.824, 2729.657, 2768.386, 2807.011, 2845.528, 2883.937, 2922.236, 2960.423, 2998.4959999999996, 3036.455, 3074.297, 3112.02, 3149.623, 3187.105, 3224.4629999999997, 3261.697, 3298.803, 3335.781, 3372.6290000000004, 3409.344, 3445.926, 3482.373, 3518.6809999999996, 3554.8509999999997, 3590.88, 3626.7659999999996, 3662.508, 3698.103, 3733.55, 3768.8459999999995, 3803.991, 3838.9809999999998, 3873.816, 3908.493, 3943.01, 3977.365, 4011.5559999999996, 4045.5809999999997, 4079.4390000000003, 4113.127, 4146.642, 4179.984, 4213.15, 4246.137, 4278.943, 4311.567, 4344.0070000000005, 4376.259, 4408.321, 4440.192, 4471.87, 4503.35, 4534.633, 4565.714, 4596.590999999999, 4627.263, 4657.727, 4687.979, 4718.019, 4747.842000000001, 4777.448, 4806.832, 4835.991, 4864.925, 4893.629, 4922.102, 4950.34, 4978.34, 5006.1, 5033.616, 5060.8859999999995, 5087.906, 5114.674, 5141.187, 5167.441, 5193.433, 5219.16, 5244.619000000001, 5269.806, 5294.718000000001, 5319.352, 5343.704000000001, 5367.77, 5391.548000000001, 5415.031999999999, 5438.22, 5461.108, 5483.691999999999, 5505.968000000001, 5527.932, 5549.58, 5570.908, 5591.911999999999, 5612.588000000001, 5632.931, 5652.937, 5672.601, 5691.92, 5710.887, 5729.499, 5747.751, 5765.638000000001, 5783.155, 5800.295999999999, 5817.057, 5833.433000000001, 5849.4169999999995, 5865.005, 5880.191, 5894.969, 5909.334, 5923.279, 5936.798000000001, 5949.8859999999995, 5962.535, 5974.7390000000005, 5986.493, 5997.789000000001, 6008.62, 6018.98, 6028.86, 6038.254, 6047.155, 6055.554, 6063.444, 6070.816, 6077.6630000000005, 6083.976, 6089.746999999999, 6094.965999999999, 6099.624, 6103.713000000001, 6107.223000000001, 6110.144, 6112.465999999999, 6114.18, 6115.274, 6115.738, 6115.561, 6114.731, 6113.238, 6111.068, 6108.21, 6104.651, 6100.378000000001, 6095.379, 6089.639, 6083.145, 6075.880999999999, 6067.834, 6058.986999999999, 6049.326, 6038.8330000000005, 6027.493, 6015.286999999999, 6002.1990000000005, 5988.21, 5973.3009999999995, 5957.453, 5940.646, 5922.859, 5904.071, 5884.26, 5863.401, 5841.474, 5818.451999999999, 5794.312, 5769.026999999999, 5742.569, 5714.911999999999, 5686.025, 5655.88, 5624.445, 5591.689, 5557.578, 5522.078, 5485.151999999999, 5446.764, 5406.876, 5365.448, 5322.438, 5277.803000000001, 5231.498, 5183.477, 5133.693, 5082.095, 5028.630999999999, 4973.245, 4915.885, 4856.491, 4795.002, 4731.354, 4665.485, 4597.326, 4526.806, 4453.852, 4378.392, 4300.346, 4219.633, 4136.1720000000005, 4049.8790000000004, 3960.664, 3868.4390000000003, 3773.115, 3674.5959999999995, 3572.792, 3467.6079999999997, 3358.95, 3246.7290000000003, 3130.8520000000003, 3011.235, 2887.798, 2760.468, 2629.179, 2493.883, 2354.542, 2211.139, 2063.68, 1912.195, 1756.749, 1597.442, 1434.4160000000002, 1267.857, 1098.004, 925.1510000000001, 749.643, 571.889, 392.35, 211.54, 30.018, -151.621, -332.754, -512.747, -690.97, -866.806, -1039.675, -1209.035, -1374.4, -1535.345, -1691.5120000000002, -1842.608, -1988.411, -2128.756, -2263.544, -2392.725, -2516.2960000000003, -2634.296, -2746.796, -2853.8940000000002, -2955.711, -3052.384, -3144.062, -3230.9040000000005, -3313.073, -3390.735, -3464.0570000000002, -3533.205, -3598.34, -3659.6259999999997, -3717.215, -3771.258, -3821.903, -3869.2859999999996, -3913.546, -3954.81, -3993.199, -4028.835, -4061.829, -4092.2859999999996, -4120.312, -4146.003, -4169.452, -4190.746, -4209.971, -4227.207, -4242.531, -4256.013, -4267.725, -4277.732, -4286.098, -4292.8820000000005, -4298.141, -4301.929, -4304.3, -4305.303, -4304.985, -4303.393, -4300.568, -4296.552, -4291.3859999999995, -4285.107, -4277.753, -4269.357, -4259.9529999999995, -4249.573, -4238.248, -4226.0070000000005, -4212.878, -4198.89, -4184.069, -4168.438, -4152.023, -4134.846, -4116.931, -4098.298, -4078.968, -4058.9629999999997, -4038.2990000000004, -4016.9970000000003, -3995.074, -3972.5490000000004, -3949.437, -3925.7540000000004, -3901.5170000000003, -3876.741, -3851.4390000000003, -3825.6259999999997, -3799.317, -3772.5240000000003, -3745.259, -3717.5359999999996, -3689.367, -3660.762, -3631.7340000000004, -3602.2940000000003, -3572.4509999999996, -3542.217, -3511.6020000000003, -3480.614, -3449.265, -3417.562, -3385.5159999999996, -3353.134, -3320.425, -3287.397, -3254.059, -3220.4179999999997, -3186.4809999999998, -3152.257, -3117.752, -3082.974, -3047.929, -3012.623, -2977.0640000000003, -2941.258, -2905.211, -2868.929, -2832.4179999999997, -2795.683, -2758.7309999999998, -2721.567, -2684.196, -2646.623, -2608.854, -2570.894, -2532.7470000000003, -2494.419, -2455.9139999999998, -2417.236, -2378.391, -2339.382, -2300.214, -2260.8920000000003, -2221.419, -2181.799, -2142.0370000000003, -2102.136, -2062.101, -2021.935, -1981.641, -1941.223, -1900.6860000000001, -1860.0320000000002, -1819.264, -1778.3870000000002, -1737.4029999999998, -1696.316, -1655.129, -1613.845, -1572.4679999999998, -1530.999, -1489.443, -1447.8020000000001, -1406.079, -1364.277, -1322.399, -1280.448, -1238.425, -1196.335, -1154.1789999999999, -1111.961, -1069.682, -1027.346, -984.954, -942.51, -900.015, -857.4730000000001, -814.885, -772.2539999999999, -729.582, -686.872, -644.125, -601.345, -558.5319999999999, -515.69, -472.82, -429.92400000000004, -387.006, -344.066, -301.107, -258.131, -215.14, -172.136, -129.12, -86.096, -43.06399999999999, -0.027000000000000003, 43.013000000000005, 86.055, 129.097, 172.136, 215.171, 258.20099999999996, 301.222, 344.235, 387.235, 430.223, 473.19599999999997, 516.1519999999999, 559.09, 602.008, 644.904, 687.7769999999999, 730.6239999999999, 773.444, 816.2360000000001, 858.998, 901.7280000000001, 944.424, 987.085, 1029.7089999999998, 1072.295, 1114.8410000000001, 1157.344, 1199.805, 1242.22, 1284.589, 1326.91, 1369.181, 1411.401, 1453.568, 1495.68, 1537.736, 1579.735, 1621.674, 1663.5520000000001, 1705.368, 1747.12, 1788.806, 1830.425, 1871.976, 1913.4560000000001, 1954.864, 1996.1989999999998, 2037.4589999999998, 2078.643, 2119.748, 2160.7729999999997, 2201.717, 2242.5789999999997, 2283.356, 2324.047, 2364.65, 2405.1639999999998, 2445.587, 2485.9179999999997, 2526.155, 2566.2960000000003, 2606.341, 2646.2859999999996, 2686.131, 2725.873, 2765.513, 2805.046, 2844.473, 2883.7909999999997, 2922.9990000000003, 2962.094, 3001.077, 3039.9429999999998, 3078.6929999999998, 3117.324, 3155.835, 3194.224, 3232.488, 3270.6279999999997, 3308.64, 3346.522, 3384.2740000000003, 3421.8940000000002, 3459.3779999999997, 3496.7270000000003, 3533.937, 3571.008, 3607.937, 3644.722, 3681.362, 3717.855, 3754.198, 3790.39, 3826.429, 3862.313, 3898.04, 3933.607, 3969.014, 4004.258, 4039.337, 4074.2490000000003, 4108.991, 4143.563, 4177.960999999999, 4212.183, 4246.228, 4280.093, 4313.775, 4347.274, 4380.585999999999, 4413.71, 4446.642, 4479.380999999999, 4511.924, 4544.269, 4576.413, 4608.355, 4640.090999999999, 4671.619000000001, 4702.937, 4734.042, 4764.931, 4795.603, 4826.053, 4856.28, 4886.282, 4916.053, 4945.594, 4974.9, 5003.969, 5032.7970000000005, 5061.383, 5089.722, 5117.813, 5145.651, 5173.233, 5200.558, 5227.621, 5254.418000000001, 5280.948, 5307.206999999999, 5333.19, 5358.895, 5384.319, 5409.456999999999, 5434.306, 5458.863, 5483.1230000000005, 5507.084, 5530.74, 5554.089, 5577.126, 5599.847, 5622.249, 5644.326, 5666.075, 5687.491999999999, 5708.571, 5729.309, 5749.701, 5769.743, 5789.429, 5808.755999999999, 5827.717, 5846.308000000001, 5864.525, 5882.361, 5899.812, 5916.871999999999, 5933.535, 5949.797, 5965.651999999999, 5981.093000000001, 5996.1140000000005, 6010.710999999999, 6024.876, 6038.603, 6051.8859999999995, 6064.718000000001, 6077.092, 6089.003000000001, 6100.441999999999, 6111.403, 6121.879, 6131.861, 6141.342, 6150.315, 6158.771, 6166.703, 6174.101, 6180.9580000000005, 6187.264, 6193.0109999999995, 6198.19, 6202.79, 6206.803000000001, 6210.218000000001, 6213.026, 6215.215999999999, 6216.776999999999, 6217.6990000000005, 6217.97, 6217.579000000001, 6216.514, 6214.763000000001, 6212.314, 6209.151999999999, 6205.266, 6200.642, 6195.267, 6189.125, 6182.203, 6174.485, 6165.955, 6156.598000000001, 6146.397, 6135.335, 6123.394, 6110.557, 6096.805, 6082.119000000001, 6066.479, 6049.865, 6032.255, 6013.629, 5993.9619999999995, 5973.234, 5951.4169999999995, 5928.49, 5904.4259999999995, 5879.1990000000005, 5852.78, 5825.143, 5796.255999999999, 5766.09, 5734.6140000000005, 5701.795, 5667.599, 5631.991, 5594.935, 5556.391, 5516.323, 5474.689, 5431.448, 5386.554, 5339.963000000001, 5291.626, 5241.497, 5189.523, 5135.651, 5079.827, 5021.9929999999995, 4962.09, 4900.056, 4835.8279999999995, 4769.337, 4700.518, 4629.295999999999, 4555.598, 4479.348, 4400.467000000001, 4318.872, 4234.478, 4147.1990000000005, 4056.946, 3963.627, 3867.15, 3767.4179999999997, 3664.3379999999997, 3557.812, 3447.743, 3334.038, 3216.6040000000003, 3095.3520000000003, 2970.197, 2841.065, 2707.885, 2570.604, 2429.1820000000002, 2283.596, 2133.848, 1979.965, 1822.007, 1660.069, 1494.29, 1324.8529999999998, 1151.994, 976.003, 797.227, 616.075, 433.009, 248.546, 63.253, -122.26700000000001, -307.382, -491.44599999999997, -673.813, -853.8510000000001, -1030.961, -1204.585, -1374.217, -1539.4170000000001, -1699.807, -1855.0810000000001, -2004.999, -2149.388, -2288.136, -2421.183, -2548.52, -2670.1809999999996, -2786.2309999999998, -2896.768, -3001.9109999999996, -3101.7940000000003, -3196.571, -3286.3979999999997, -3371.441, -3451.869, -3527.85, -3599.553, -3667.145, -3730.7870000000003, -3790.639, -3846.8540000000003, -3899.5809999999997, -3948.962, -3995.137, -4038.236, -4078.385, -4115.705, -4150.313, -4182.316, -4211.821, -4238.928, -4263.73, -4286.319, -4306.782999999999, -4325.202, -4341.655, -4356.217000000001, -4368.957, -4379.946, -4389.246, -4396.920999999999, -4403.027, -4407.621, -4410.7570000000005, -4412.486, -4412.857, -4411.916, -4409.707, -4406.273, -4401.655, -4395.893, -4389.023, -4381.081, -4372.102, -4362.1179999999995, -4351.161, -4339.2609999999995, -4326.447, -4312.748, -4298.19, -4282.799, -4266.599, -4249.616, -4231.871, -4213.387, -4194.185, -4174.286, -4153.709, -4132.474, -4110.599, -4088.1020000000003, -4065.0, -4041.31, -4017.048, -3992.23, -3966.869, -3940.982, -3914.5820000000003, -3887.6820000000002, -3860.297, -3832.437, -3804.117, -3775.347, -3746.1409999999996, -3716.508, -3686.4590000000003, -3656.006, -3625.159, -3593.927, -3562.322, -3530.3509999999997, -3498.0240000000003, -3465.3509999999997, -3432.3390000000004, -3398.9970000000003, -3365.3340000000003, -3331.3579999999997, -3297.0759999999996, -3262.4959999999996, -3227.625, -3192.4709999999995, -3157.04, -3121.34, -3085.377, -3049.157, -3012.688, -2975.975, -2939.0240000000003, -2901.842, -2864.434, -2826.805, -2788.962, -2750.909, -2712.652, -2674.196, -2635.547, -2596.708, -2557.686, -2518.484, -2479.107, -2439.56, -2399.848, -2359.974, -2319.944, -2279.76, -2239.428, -2198.951, -2158.333, -2117.578, -2076.69, -2035.6729999999998, -1994.53, -1953.264, -1911.88, -1870.381, -1828.771, -1787.0510000000002, -1745.227, -1703.3010000000002, -1661.276, -1619.156, -1576.943, -1534.64, -1492.251, -1449.779, -1407.226, -1364.595, -1321.889, -1279.111, -1236.263, -1193.349, -1150.37, -1107.329, -1064.23, -1021.074, -977.8639999999999, -934.6030000000001, -891.2919999999999, -847.935, -804.533, -761.09, -717.6060000000001, -674.086, -630.53, -586.941, -543.322, -499.67400000000004, -456.0, -412.301, -368.58099999999996, -324.84, -281.082, -237.308, -193.52, -149.72, -105.91, -62.092, -18.268, 25.559, 69.389, 113.219, 157.047, 200.87099999999998, 244.69, 288.502, 332.305, 376.096, 419.875, 463.639, 507.38699999999994, 551.117, 594.827, 638.515, 682.18, 725.82, 769.433, 813.0169999999999, 856.572, 900.0939999999999, 943.5830000000001, 987.0360000000001, 1030.453, 1073.83, 1117.1680000000001, 1160.463, 1203.715, 1246.922, 1290.0819999999999, 1333.193, 1376.255, 1419.264, 1462.22, 1505.121, 1547.9660000000001, 1590.7520000000002, 1633.4779999999998, 1676.1429999999998, 1718.745, 1761.2820000000002, 1803.753, 1846.156, 1888.49, 1930.7520000000002, 1972.942, 2015.058, 2057.097, 2099.06, 2140.9429999999998, 2182.745, 2224.465, 2266.101, 2307.651, 2349.115, 2390.489, 2431.7729999999997, 2472.965, 2514.064, 2555.067, 2595.973, 2636.78, 2677.487, 2718.093, 2758.594, 2798.991, 2839.28, 2879.461, 2919.531, 2959.49, 2999.335, 3039.0640000000003, 3078.676, 3118.17, 3157.542, 3196.792, 3235.9190000000003, 3274.9190000000003, 3313.7909999999997, 3352.534, 3391.1459999999997, 3429.625, 3467.969, 3506.176, 3544.244, 3582.173, 3619.958, 3657.6, 3695.095, 3732.442, 3769.64, 3806.685, 3843.577, 3880.312, 3916.89, 3953.3070000000002, 3989.563, 4025.655, 4061.5809999999997, 4097.338, 4132.9259999999995, 4168.340999999999, 4203.581, 4238.645, 4273.53, 4308.233, 4342.753, 4377.088, 4411.235, 4445.192, 4478.956, 4512.525, 4545.897, 4579.069, 4612.039000000001, 4644.804, 4677.363, 4709.712, 4741.848, 4773.77, 4805.474, 4836.959, 4868.22, 4899.2570000000005, 4930.065, 4960.642, 4990.985, 5021.090999999999, 5050.958, 5080.583, 5109.962, 5139.093, 5167.972, 5196.597, 5224.964, 5253.07, 5280.911, 5308.485, 5335.789000000001, 5362.818, 5389.569, 5416.039000000001, 5442.225, 5468.121999999999, 5493.727, 5519.036999999999, 5544.047, 5568.753000000001, 5593.153, 5617.241999999999, 5641.015, 5664.469, 5687.6, 5710.403, 5732.874, 5755.009, 5776.803000000001, 5798.251, 5819.35, 5840.095, 5860.48, 5880.5, 5900.151999999999, 5919.429, 5938.326999999999, 5956.84, 5974.963000000001, 5992.691, 6010.017, 6026.937, 6043.445, 6059.534000000001, 6075.1990000000005, 6090.433000000001, 6105.231, 6119.585, 6133.49, 6146.939, 6159.924, 6172.439, 6184.477, 6196.031, 6207.093000000001, 6217.655, 6227.710999999999, 6237.251, 6246.268, 6254.754, 6262.7, 6270.097, 6276.936, 6283.209, 6288.906, 6294.018, 6298.533, 6302.444, 6305.7390000000005, 6308.408, 6310.44, 6311.825, 6312.549, 6312.603, 6311.974, 6310.649, 6308.616, 6305.861999999999, 6302.374, 6298.137, 6293.139, 6287.3640000000005, 6280.797, 6273.424, 6265.228, 6256.193, 6246.302, 6235.5380000000005, 6223.884, 6211.32, 6197.829000000001, 6183.39, 6167.984, 6151.59, 6134.187, 6115.7519999999995, 6096.263000000001, 6075.695, 6054.025, 6031.228, 6007.278, 5982.147, 5955.808000000001, 5928.232, 5899.389, 5869.2480000000005, 5837.778, 5804.945, 5770.715, 5735.0509999999995, 5697.918000000001, 5659.276, 5619.085999999999, 5577.308000000001, 5533.897, 5488.809, 5441.9980000000005, 5393.416, 5343.013000000001, 5290.738, 5236.536, 5180.351, 5122.125, 5061.799, 4999.309, 4934.588, 4867.572, 4798.189, 4726.366, 4652.026, 4575.094, 4495.488, 4413.123, 4327.915, 4239.773, 4148.607, 4054.324, 3956.828, 3856.022, 3751.808, 3644.087, 3532.76, 3417.7309999999998, 3298.901, 3176.1809999999996, 3049.482, 2918.725, 2783.837, 2644.761, 2501.451, 2353.883, 2202.051, 2045.981, 1885.725, 1721.378, 1553.0720000000001, 1380.985, 1205.354, 1026.462, 844.658, 660.3480000000001, 473.996, 286.122, 97.29700000000001, -91.866, -280.72900000000004, -468.631, -654.9159999999999, -838.937, -1020.077, -1197.759, -1371.464, -1540.729, -1705.164, -1864.444, -2018.317, -2166.596, -2309.157, -2445.9339999999997, -2576.909, -2702.1090000000004, -2821.5959999999995, -2935.4640000000004, -3043.83, -3146.8320000000003, -3244.617, -3337.348, -3425.188, -3508.31, -3586.883, -3661.08, -3731.0690000000004, -3797.014, -3859.079, -3917.42, -3972.2540000000004, -4023.527, -4071.5809999999997, -4116.483, -4158.362, -4197.342000000001, -4233.539000000001, -4267.067, -4298.032999999999, -4326.539000000001, -4352.682, -4376.556, -4398.248, -4417.843, -4435.42, -4451.057, -4464.825, -4476.795999999999, -4487.034000000001, -4495.602, -4502.562, -4507.968, -4511.878, -4514.343, -4515.413, -4515.1359999999995, -4513.558, -4510.721, -4506.669, -4501.439, -4495.072, -4487.604, -4479.071, -4469.504, -4458.938, -4447.403, -4434.929, -4421.544, -4407.276, -4392.151, -4376.196, -4359.434, -4341.89, -4323.585, -4304.542, -4284.781, -4264.3240000000005, -4243.189, -4221.395, -4198.962, -4175.906, -4152.244000000001, -4127.994000000001, -4103.17, -4077.789, -4051.864, -4025.4120000000003, -3998.445, -3970.9770000000003, -3943.022, -3914.591, -3885.697, -3856.353, -3826.5690000000004, -3796.357, -3765.728, -3734.6929999999998, -3703.261, -3671.442, -3639.2470000000003, -3606.685, -3573.765, -3540.4959999999996, -3506.886, -3472.9440000000004, -3438.678, -3404.097, -3369.2070000000003, -3334.0170000000003, -3298.534, -3262.7659999999996, -3226.719, -3190.4, -3153.815, -3116.973, -3079.8779999999997, -3042.5370000000003, -3004.9559999999997, -2967.1409999999996, -2929.097, -2890.8320000000003, -2852.349, -2813.655, -2774.7540000000004, -2735.653, -2696.355, -2656.866, -2617.192, -2577.335, -2537.302, -2497.097, -2456.724, -2416.188, -2375.492, -2334.6420000000003, -2293.641, -2252.493, -2211.202, -2169.7729999999997, -2128.209, -2086.513, -2044.69, -2002.743, -1960.675, -1918.491, -1876.193, -1833.785, -1791.27, -1748.652, -1705.933, -1663.118, -1620.2079999999999, -1577.207, -1534.118, -1490.945, -1447.6889999999999, -1404.354, -1360.942, -1317.457, -1273.901, -1230.276, -1186.587, -1142.8339999999998, -1099.021, -1055.15, -1011.225, -967.2460000000001, -923.217, -879.1410000000001, -835.0189999999999, -790.8539999999999, -746.648, -702.404, -658.1239999999999, -613.81, -569.464, -525.089, -480.68699999999995, -436.26, -391.81, -347.339, -302.85, -258.344, -213.82299999999998, -169.29, -124.74700000000001, -80.195, -35.635999999999996, 8.927, 53.492, 98.059, 142.624, 187.185, 231.74200000000002, 276.29200000000003, 320.83299999999997, 365.36300000000006, 409.881, 454.384, 498.87199999999996, 543.341, 587.7909999999999, 632.219, 676.6239999999999, 721.0039999999999, 765.357, 809.682, 853.977, 898.2389999999999, 942.4680000000001, 986.6619999999999, 1030.818, 1074.9360000000001, 1119.013, 1163.048, 1207.039, 1250.985, 1294.883, 1338.733, 1382.5320000000002, 1426.279, 1469.9720000000002, 1513.61, 1557.191, 1600.713, 1644.174, 1687.5739999999998, 1730.91, 1774.18, 1817.384, 1860.519, 1903.5839999999998, 1946.5770000000002, 1989.497, 2032.3410000000001, 2075.109, 2117.798, 2160.407, 2202.935, 2245.379, 2287.739, 2330.011, 2372.196, 2414.29, 2456.2929999999997, 2498.203, 2540.018, 2581.736, 2623.3559999999998, 2664.8759999999997, 2706.295, 2747.61, 2788.82, 2829.923, 2870.9179999999997, 2911.803, 2952.575, 2993.235, 3033.778, 3074.205, 3114.513, 3154.7, 3194.765, 3234.705, 3274.5190000000002, 3314.2059999999997, 3353.763, 3393.188, 3432.48, 3471.637, 3510.657, 3549.538, 3588.278, 3626.875, 3665.328, 3703.634, 3741.7909999999997, 3779.798, 3817.652, 3855.3520000000003, 3892.895, 3930.28, 3967.5040000000004, 4004.566, 4041.4629999999997, 4078.192, 4114.753, 4151.143, 4187.36, 4223.401, 4259.264, 4294.947, 4330.448, 4365.765, 4400.895, 4435.835999999999, 4470.585999999999, 4505.142, 4539.502, 4573.663, 4607.624, 4641.38, 4674.931, 4708.274, 4741.405, 4774.323, 4807.024, 4839.505999999999, 4871.767, 4903.803, 4935.613, 4967.192, 4998.538, 5029.649, 5060.522, 5091.153, 5121.54, 5151.679, 5181.567, 5211.202, 5240.581, 5269.6990000000005, 5298.554, 5327.142, 5355.460999999999, 5383.507, 5411.276, 5438.764, 5465.969, 5492.887, 5519.514, 5545.846, 5571.88, 5597.611, 5623.036999999999, 5648.151999999999, 5672.954000000001, 5697.437, 5721.598000000001, 5745.433000000001, 5768.937, 5792.105, 5814.934, 5837.419, 5859.555, 5881.338000000001, 5902.763000000001, 5923.8240000000005, 5944.518, 5964.839, 5984.781, 6004.340999999999, 6023.5109999999995, 6042.2880000000005, 6060.665, 6078.6359999999995, 6096.196999999999, 6113.340999999999, 6130.063, 6146.355, 6162.2119999999995, 6177.628000000001, 6192.595, 6207.108, 6221.16, 6234.744000000001, 6247.853, 6260.479, 6272.615, 6284.254, 6295.388000000001, 6306.01, 6316.11, 6325.681, 6334.715, 6343.203, 6351.1359999999995, 6358.505, 6365.3, 6371.513000000001, 6377.134, 6382.151999999999, 6386.558000000001, 6390.342, 6393.491999999999, 6395.996999999999, 6397.847, 6399.029, 6399.533, 6399.345, 6398.454000000001, 6396.846, 6394.508000000001, 6391.427, 6387.589, 6382.979, 6377.5830000000005, 6371.3859999999995, 6364.3730000000005, 6356.526, 6347.831, 6338.269, 6327.823, 6316.476, 6304.2080000000005, 6291.001, 6276.834, 6261.687, 6245.54, 6228.371999999999, 6210.158, 6190.8769999999995, 6170.504, 6149.014, 6126.383000000001, 6102.5830000000005, 6077.588000000001, 6051.368, 6023.896, 5995.141, 5965.071, 5933.653, 5900.855, 5866.642, 5830.975, 5793.82, 5755.137, 5714.885, 5673.022, 5629.505999999999, 5584.289000000001, 5537.326, 5488.569, 5437.965999999999, 5385.464, 5331.01, 5274.544, 5216.0109999999995, 5155.347, 5092.4890000000005, 5027.371, 4959.923, 4890.075, 4817.752, 4742.877, 4665.371, 4585.153, 4502.1359999999995, 4416.232, 4327.351, 4235.402, 4140.286, 4041.909, 3940.17, 3834.969, 3726.204, 3613.776, 3497.5809999999997, 3377.5240000000003, 3253.507, 3125.441, 2993.242, 2856.835, 2716.157, 2571.161, 2421.814, 2268.111, 2110.069, 1947.74, 1781.21, 1610.609, 1436.112, 1257.947, 1076.401, 891.816, 704.5980000000001, 515.211, 324.178, 132.07399999999998, -60.485, -252.84900000000002, -444.35, -634.317, -822.0889999999999, -1007.035, -1188.5610000000001, -1366.129, -1539.2620000000002, -1707.55, -1870.656, -2028.3110000000001, -2180.317, -2326.5370000000003, -2466.897, -2601.3720000000003, -2729.98, -2852.783, -2969.869, -3081.353, -3187.369, -3288.0690000000004, -3383.612, -3474.167, -3559.903, -3640.9959999999996, -3717.618, -3789.94, -3858.131, -3922.3540000000003, -3982.7690000000002, -4039.53, -4092.7859999999996, -4142.68, -4189.348, -4232.924, -4273.532, -4311.294, -4346.321, -4378.727, -4408.6140000000005, -4436.082, -4461.224, -4484.134, -4504.895, -4523.59, -4540.2970000000005, -4555.09, -4568.04, -4579.215999999999, -4588.681, -4596.497, -4602.722, -4607.412, -4610.622, -4612.402, -4612.8, -4611.865, -4609.639, -4606.167, -4601.488, -4595.642, -4588.667, -4580.599, -4571.472, -4561.318, -4550.170999999999, -4538.061, -4525.016, -4511.065, -4496.234, -4480.55, -4464.04, -4446.725, -4428.63, -4409.776, -4390.186, -4369.880999999999, -4348.879, -4327.202, -4304.866, -4281.892, -4258.295, -4234.092000000001, -4209.3009999999995, -4183.936, -4158.014, -4131.548, -4104.553, -4077.0440000000003, -4049.033, -4020.533, -3991.5570000000002, -3962.117, -3932.225, -3901.893, -3871.131, -3839.95, -3808.362, -3776.3759999999997, -3744.0029999999997, -3711.25, -3678.1290000000004, -3644.6479999999997, -3610.817, -3576.643, -3542.135, -3507.302, -3472.152, -3436.691, -3400.929, -3364.8709999999996, -3328.526, -3291.901, -3255.0009999999997, -3217.835, -3180.408, -3142.7259999999997, -3104.797, -3066.6259999999997, -3028.22, -2989.583, -2950.722, -2911.6420000000003, -2872.349, -2832.847, -2793.143, -2753.24, -2713.145, -2672.862, -2632.395, -2591.75, -2550.931, -2509.9429999999998, -2468.7889999999998, -2427.475, -2386.004, -2344.38, -2302.6079999999997, -2260.692, -2218.635, -2176.442, -2134.116, -2091.66, -2049.0789999999997, -2006.3770000000002, -1963.555, -1920.619, -1877.5710000000001, -1834.415, -1791.154, -1747.7910000000002, -1704.33, -1660.773, -1617.124, -1573.385, -1529.56, -1485.652, -1441.6629999999998, -1397.5970000000002, -1353.455, -1309.242, -1264.9589999999998, -1220.61, -1176.197, -1131.722, -1087.188, -1042.598, -997.955, -953.26, -908.5160000000001, -863.7260000000001, -818.8919999999999, -774.0169999999999, -729.102, -684.15, -639.164, -594.145, -549.096, -504.019, -458.916, -413.79, -368.642, -323.475, -278.291, -233.09099999999998, -187.87900000000002, -142.655, -97.42299999999999, -52.183, -6.939, 38.309, 83.55799999999999, 128.806, 174.051, 219.291, 264.525, 309.75, 354.965, 400.168, 445.356, 490.529, 535.684, 580.819, 625.933, 671.0239999999999, 716.09, 761.1289999999999, 806.14, 851.1210000000001, 896.069, 940.9839999999999, 985.863, 1030.705, 1075.509, 1120.271, 1164.992, 1209.6680000000001, 1254.298, 1298.881, 1343.415, 1387.898, 1432.329, 1476.705, 1521.025, 1565.2879999999998, 1609.4920000000002, 1653.635, 1697.715, 1741.731, 1785.681, 1829.5639999999999, 1873.3770000000002, 1917.12, 1960.79, 2004.385, 2047.905, 2091.348, 2134.7110000000002, 2177.993, 2221.192, 2264.308, 2307.337, 2350.279, 2393.132, 2435.894, 2478.563, 2521.137, 2563.616, 2605.9970000000003, 2648.278, 2690.458, 2732.535, 2774.508, 2816.3740000000003, 2858.132, 2899.78, 2941.317, 2982.74, 3024.048, 3065.239, 3106.312, 3147.264, 3188.093, 3228.7990000000004, 3269.3779999999997, 3309.83, 3350.151, 3390.342, 3430.3990000000003, 3470.32, 3510.105, 3549.75, 3589.255, 3628.616, 3667.8320000000003, 3706.902, 3745.823, 3784.593, 3823.21, 3861.672, 3899.9770000000003, 3938.123, 3976.1079999999997, 4013.93, 4051.586, 4089.075, 4126.395, 4163.543, 4200.517, 4237.315, 4273.934, 4310.373, 4346.629, 4382.7, 4418.583, 4454.276, 4489.777, 4525.083, 4560.192, 4595.102, 4629.81, 4664.313, 4698.609, 4732.695, 4766.569, 4800.228, 4833.67, 4866.891, 4899.889, 4932.662, 4965.206, 4997.519, 5029.598, 5061.439, 5093.041, 5124.399, 5155.512, 5186.375, 5216.986, 5247.342, 5277.439, 5307.275, 5336.845, 5366.147, 5395.177, 5423.932, 5452.408, 5480.602, 5508.5109999999995, 5536.13, 5563.455, 5590.484, 5617.2119999999995, 5643.6359999999995, 5669.751, 5695.554, 5721.04, 5746.205, 5771.045, 5795.557, 5819.734, 5843.5740000000005, 5867.071999999999, 5890.222, 5913.02, 5935.4619999999995, 5957.543000000001, 5979.258000000001, 6000.601, 6021.569, 6042.155, 6062.355, 6082.161999999999, 6101.571999999999, 6120.578, 6139.1759999999995, 6157.359, 6175.121, 6192.456999999999, 6209.36, 6225.8240000000005, 6241.842, 6257.408, 6272.515, 6287.156999999999, 6301.326, 6315.015, 6328.217, 6340.925, 6353.130999999999, 6364.826999999999, 6376.005, 6386.656, 6396.774, 6406.349, 6415.371999999999, 6423.835, 6431.728, 6439.0419999999995, 6445.768, 6451.896, 6457.415, 6462.316, 6466.588000000001, 6470.219, 6473.2, 6475.518, 6477.161999999999, 6478.119000000001, 6478.379, 6477.927, 6476.751, 6474.838000000001, 6472.174, 6468.744000000001, 6464.535, 6459.531, 6453.718000000001, 6447.079000000001, 6439.597, 6431.258000000001, 6422.043000000001, 6411.934, 6400.914000000001, 6388.964, 6376.063, 6362.193, 6347.3330000000005, 6331.460999999999, 6314.555, 6296.593000000001, 6277.5509999999995, 6257.405, 6236.13, 6213.6990000000005, 6190.088000000001, 6165.267, 6139.209, 6111.884, 6083.26, 6053.306, 6021.99, 5989.276999999999, 5955.132, 5919.518, 5882.396, 5843.729, 5803.474, 5761.59, 5718.031999999999, 5672.755, 5625.710999999999, 5576.849, 5526.12, 5473.469, 5418.842, 5362.18, 5303.424, 5242.5109999999995, 5179.377, 5113.955, 5046.173, 4975.960999999999, 4903.244000000001, 4827.942, 4749.975, 4669.259, 4585.709, 4499.234, 4409.7429999999995, 4317.141, 4221.331, 4122.213, 4019.687, 3913.65, 3803.998, 3690.627, 3573.435, 3452.321, 3327.1859999999997, 3197.935, 3064.4829999999997, 2926.752, 2784.673, 2638.195, 2487.284, 2331.928, 2172.14, 2007.9660000000001, 1839.49, 1666.8339999999998, 1490.171, 1309.726, 1125.778, 938.668, 748.8, 556.639, 362.708, 167.584, -28.112, -223.72299999999998, -418.57099999999997, -611.975, -803.26, -991.778, -1176.923, -1358.139, -1534.932, -1706.875, -1873.6170000000002, -2034.875, -2190.435, -2340.154, -2483.944, -2621.7740000000003, -2753.656, -2879.6440000000002, -2999.8259999999996, -3114.312, -3223.238, -3326.752, -3425.014, -3518.1929999999998, -3606.4629999999997, -3689.9970000000003, -3768.973, -3843.5609999999997, -3913.934, -3980.256, -4042.692, -4101.397, -4156.522, -4208.212, -4256.609, -4301.846, -4344.05, -4383.345, -4419.847, -4453.668, -4484.914000000001, -4513.688, -4540.085, -4564.198, -4586.113, -4605.916, -4623.686, -4639.499, -4653.427, -4665.539000000001, -4675.901, -4684.576, -4691.623, -4697.1, -4701.062, -4703.56, -4704.645, -4704.365, -4702.764, -4699.8859999999995, -4695.774, -4690.467000000001, -4684.003, -4676.419, -4667.751, -4658.032999999999, -4647.2970000000005, -4635.5740000000005, -4622.893, -4609.285, -4594.776, -4579.392, -4563.161, -4546.106, -4528.251, -4509.6179999999995, -4490.231, -4470.11, -4449.276, -4427.748, -4405.545, -4382.687, -4359.191, -4335.0740000000005, -4310.353, -4285.044, -4259.162, -4232.723, -4205.741, -4178.23, -4150.204000000001, -4121.677, -4092.6609999999996, -4063.1679999999997, -4033.211, -4002.802, -3971.9509999999996, -3940.671, -3908.9709999999995, -3876.862, -3844.355, -3811.4590000000003, -3778.183, -3744.538, -3710.532, -3676.1740000000004, -3641.473, -3606.4359999999997, -3571.073, -3535.3909999999996, -3499.3979999999997, -3463.1020000000003, -3426.509, -3389.627, -3352.4629999999997, -3315.0240000000003, -3277.316, -3239.3459999999995, -3201.1209999999996, -3162.6459999999997, -3123.929, -3084.973, -3045.7870000000003, -3006.3740000000003, -2966.741, -2926.893, -2886.835, -2846.573, -2806.112, -2765.4559999999997, -2724.61, -2683.58, -2642.37, -2600.984, -2559.427, -2517.7039999999997, -2475.819, -2433.775, -2391.578, -2349.23, -2306.737, -2264.1020000000003, -2221.3289999999997, -2178.422, -2135.384, -2092.219, -2048.931, -2005.524, -1962.0, -1918.3629999999998, -1874.616, -1830.764, -1786.808, -1742.753, -1698.601, -1654.355, -1610.019, -1565.595, -1521.0870000000002, -1476.4979999999998, -1431.829, -1387.085, -1342.267, -1297.379, -1252.423, -1207.403, -1162.32, -1117.177, -1071.9769999999999, -1026.722, -981.415, -936.059, -890.655, -845.207, -799.716, -754.185, -708.6160000000001, -663.012, -617.375, -571.707, -526.01, -480.287, -434.54, -388.77, -342.981, -297.17400000000004, -251.351, -205.514, -159.666, -113.80799999999999, -67.943, -22.073, 23.801, 69.676, 115.551, 161.424, 207.292, 253.15400000000002, 299.007, 344.851, 390.68199999999996, 436.5, 482.30199999999996, 528.086, 573.851, 619.595, 665.316, 711.0110000000001, 756.68, 802.321, 847.932, 893.51, 939.055, 984.564, 1030.035, 1075.468, 1120.86, 1166.2089999999998, 1211.515, 1256.774, 1301.985, 1347.1470000000002, 1392.2579999999998, 1437.316, 1482.32, 1527.267, 1572.156, 1616.986, 1661.755, 1706.46, 1751.1, 1795.675, 1840.181, 1884.6170000000002, 1928.981, 1973.273, 2017.49, 2061.63, 2105.6910000000003, 2149.673, 2193.573, 2237.39, 2281.121, 2324.766, 2368.322, 2411.788, 2455.163, 2498.4429999999998, 2541.6279999999997, 2584.716, 2627.705, 2670.594, 2713.38, 2756.062, 2798.638, 2841.1059999999998, 2883.466, 2925.7140000000004, 2967.848, 3009.869, 3051.772, 3093.5570000000002, 3135.222, 3176.765, 3218.184, 3259.478, 3300.643, 3341.679, 3382.5840000000003, 3423.3559999999998, 3463.992, 3504.491, 3544.8509999999997, 3585.07, 3625.1459999999997, 3665.078, 3704.862, 3744.4970000000003, 3783.982, 3823.313, 3862.489, 3901.509, 3940.369, 3979.067, 4017.6020000000003, 4055.972, 4094.1740000000004, 4132.206, 4170.065, 4207.751, 4245.259, 4282.589, 4319.738, 4356.704000000001, 4393.484, 4430.075, 4466.476, 4502.684, 4538.697, 4574.512, 4610.127, 4645.539000000001, 4680.746, 4715.744000000001, 4750.532, 4785.107, 4819.467000000001, 4853.608, 4887.527, 4921.223, 4954.692, 4987.931, 5020.938, 5053.709, 5086.242, 5118.534000000001, 5150.582, 5182.383, 5213.932, 5245.229, 5276.269, 5307.048000000001, 5337.565, 5367.815, 5397.795, 5427.501, 5456.931, 5486.08, 5514.946, 5543.524, 5571.811, 5599.803000000001, 5627.496, 5654.8859999999995, 5681.971, 5708.744000000001, 5735.203, 5761.344, 5787.161, 5812.651999999999, 5837.811, 5862.634, 5887.116999999999, 5911.255, 5935.044, 5958.478, 5981.554, 6004.265, 6026.609, 6048.578, 6070.168000000001, 6091.375, 6112.191, 6132.613, 6152.634, 6172.249, 6191.451999999999, 6210.236999999999, 6228.598000000001, 6246.529, 6264.025, 6281.076999999999, 6297.681, 6313.828, 6329.514, 6344.73, 6359.469, 6373.725, 6387.49, 6400.757, 6413.517, 6425.763000000001, 6437.486999999999, 6448.68, 6459.335, 6469.443, 6478.994000000001, 6487.981, 6496.392, 6504.22, 6511.454000000001, 6518.085, 6524.102, 6529.495, 6534.254, 6538.366999999999, 6541.823, 6544.611, 6546.719, 6548.134, 6548.845, 6548.839, 6548.101, 6546.62, 6544.380999999999, 6541.369000000001, 6537.571, 6532.971, 6527.553000000001, 6521.303000000001, 6514.201999999999, 6506.235, 6497.384, 6487.632, 6476.959, 6465.347, 6452.776, 6439.227, 6424.677, 6409.106, 6392.491, 6374.81, 6356.0380000000005, 6336.151999999999, 6315.126, 6292.933000000001, 6269.547, 6244.94, 6219.0830000000005, 6191.946, 6163.499, 6133.7080000000005, 6102.54, 6069.9619999999995, 6035.937, 6000.429, 5963.398, 5924.804, 5884.608, 5842.765, 5799.232, 5753.96, 5706.904, 5658.0109999999995, 5607.231, 5554.509, 5499.789000000001, 5443.014, 5384.121999999999, 5323.05, 5259.732, 5194.101, 5126.085, 5055.612, 4982.605, 4906.986, 4828.670999999999, 4747.576, 4663.6140000000005, 4576.693, 4486.721, 4393.602, 4297.235, 4197.52, 4094.355, 3987.635, 3877.2540000000004, 3763.1059999999998, 3645.085, 3523.0890000000004, 3397.015, 3266.7659999999996, 3132.2540000000004, 2993.3959999999997, 2850.1209999999996, 2702.373, 2550.115, 2393.328, 2232.022, 2066.24, 1896.058, 1721.594, 1543.0179999999998, 1360.547, 1174.458, 985.0880000000001, 792.837, 598.17, 401.61, 203.733, 5.167999999999999, -193.425, -391.36, -587.944, -782.492, -974.341, -1162.87, -1347.507, -1527.7420000000002, -1703.132, -1873.3110000000001, -2037.981, -2196.917, -2349.9629999999997, -2497.021, -2638.052, -2773.063, -2902.1, -3025.248, -3142.616, -3254.335, -3360.555, -3461.435, -3557.145, -3647.8590000000004, -3733.7509999999997, -3815.0009999999997, -3891.783, -3964.2690000000002, -4032.6279999999997, -4097.024, -4157.959, -4214.561, -4268.001, -4318.082, -4364.94, -4408.704000000001, -4449.499, -4487.443, -4522.653, -4555.235, -4585.292, -4612.924, -4638.223, -4661.279, -4682.179, -4701.002, -4717.827, -4732.727, -4745.772, -4757.03, -4766.565, -4774.436, -4780.704000000001, -4785.423, -4788.647, -4790.427, -4790.812, -4789.847, -4787.577, -4784.045999999999, -4779.293, -4773.358, -4766.278, -4758.09, -4748.827, -4738.524, -4727.210999999999, -4714.92, -4701.679, -4687.517, -4672.460999999999, -4656.537, -4639.77, -4622.185, -4603.805, -4584.652, -4564.748, -4544.1140000000005, -4522.77, -4500.736, -4478.03, -4454.670999999999, -4430.6759999999995, -4406.062, -4380.846, -4355.044, -4328.670999999999, -4301.741, -4274.27, -4246.271, -4217.758, -4188.744000000001, -4159.241, -4129.263, -4098.821, -4067.926, -4036.59, -4004.824, -3972.639, -3940.045, -3907.051, -3873.6690000000003, -3839.907, -3805.7740000000003, -3771.281, -3736.434, -3701.244, -3665.718, -3629.864, -3593.691, -3557.205, -3520.415, -3483.328, -3445.9509999999996, -3408.2909999999997, -3370.355, -3332.1490000000003, -3293.68, -3254.955, -3215.9790000000003, -3176.759, -3137.3, -3097.6079999999997, -3057.69, -3017.55, -2977.1929999999998, -2936.6259999999997, -2895.8540000000003, -2854.88, -2813.711, -2772.3520000000003, -2730.8059999999996, -2689.079, -2647.176, -2605.1, -2562.857, -2520.45, -2477.883, -2435.1620000000003, -2392.29, -2349.271, -2306.1079999999997, -2262.8070000000002, -2219.37, -2175.801, -2132.105, -2088.284, -2044.342, -2000.283, -1956.109, -1911.826, -1867.435, -1822.9389999999999, -1778.3429999999998, -1733.65, -1688.862, -1643.9820000000002, -1599.014, -1553.96, -1508.8239999999998, -1463.608, -1418.315, -1372.9479999999999, -1327.509, -1282.003, -1236.43, -1190.7939999999999, -1145.097, -1099.343, -1053.5330000000001, -1007.67, -961.757, -915.795, -869.789, -823.7389999999999, -777.648, -731.5189999999999, -685.3530000000001, -639.154, -592.924, -546.664, -500.37699999999995, -454.066, -407.73199999999997, -361.37699999999995, -315.004, -268.615, -222.21099999999998, -175.796, -129.371, -82.93799999999999, -36.499, 9.943999999999999, 56.388999999999996, 102.833, 149.276, 195.71400000000003, 242.146, 288.57, 334.985, 381.38699999999994, 427.776, 474.15, 520.506, 566.8430000000001, 613.158, 659.451, 705.7189999999999, 751.96, 798.299, 844.482, 890.632, 936.7489999999999, 982.83, 1028.874, 1074.878, 1120.8419999999999, 1166.763, 1212.64, 1258.47, 1304.252, 1349.985, 1395.6660000000002, 1441.295, 1486.868, 1532.385, 1577.8429999999998, 1623.241, 1668.578, 1713.851, 1759.059, 1804.2, 1849.2720000000002, 1894.274, 1939.204, 1984.06, 2028.8410000000001, 2073.544, 2118.1679999999997, 2162.712, 2207.173, 2251.55, 2295.841, 2340.045, 2384.159, 2428.1820000000002, 2472.113, 2515.948, 2559.688, 2603.3289999999997, 2646.8709999999996, 2690.31, 2733.647, 2776.8779999999997, 2820.002, 2863.0170000000003, 2905.922, 2948.7140000000004, 2991.393, 3033.955, 3076.3990000000003, 3118.723, 3160.926, 3203.005, 3244.958, 3286.785, 3328.4829999999997, 3370.0490000000004, 3411.4829999999997, 3452.781, 3493.9429999999998, 3534.966, 3575.848, 3616.5879999999997, 3657.1820000000002, 3697.63, 3737.929, 3778.078, 3818.073, 3857.913, 3897.5959999999995, 3937.12, 3976.4829999999997, 4015.6820000000002, 4054.715, 4093.5809999999997, 4132.277, 4170.8, 4209.149, 4247.321, 4285.314, 4323.125, 4360.753, 4398.195, 4435.448, 4472.5109999999995, 4509.38, 4546.053, 4582.528, 4618.803, 4654.874, 4690.7390000000005, 4726.396, 4761.842000000001, 4797.0740000000005, 4832.09, 4866.8859999999995, 4901.460999999999, 4935.811, 4969.933, 5003.826, 5037.485, 5070.907, 5104.090999999999, 5137.032, 5169.729, 5202.177, 5234.374, 5266.316, 5298.0, 5329.423000000001, 5360.581999999999, 5391.473000000001, 5422.093000000001, 5452.438, 5482.505999999999, 5512.2919999999995, 5541.7919999999995, 5571.004, 5599.924, 5628.547, 5656.869000000001, 5684.888000000001, 5712.598000000001, 5739.996999999999, 5767.079000000001, 5793.842, 5820.279, 5846.388000000001, 5872.164000000001, 5897.602, 5922.696999999999, 5947.446999999999, 5971.844, 5995.8859999999995, 6019.566999999999, 6042.882, 6065.826, 6088.394, 6110.58, 6132.380999999999, 6153.789000000001, 6174.8, 6195.408, 6215.608, 6235.392, 6254.757, 6273.695, 6292.2, 6310.266, 6327.887, 6345.056, 6361.766, 6378.0109999999995, 6393.783, 6409.076, 6423.882, 6438.194, 6452.003000000001, 6465.304, 6478.085999999999, 6490.343000000001, 6502.066, 6513.246, 6523.875, 6533.943, 6543.443, 6552.3640000000005, 6560.698, 6568.433000000001, 6575.561, 6582.071, 6587.951999999999, 6593.194, 6597.785, 6601.715, 6604.972, 6607.543000000001, 6609.4169999999995, 6610.581, 6611.021, 6610.726, 6609.681, 6607.871999999999, 6605.285, 6601.906, 6597.718000000001, 6592.706, 6586.855, 6580.147, 6572.566, 6564.095, 6554.714, 6544.404, 6533.149, 6520.927, 6507.718000000001, 6493.501, 6478.255, 6461.956, 6444.581999999999, 6426.109, 6406.5109999999995, 6385.764, 6363.842, 6340.715999999999, 6316.359, 6290.741, 6263.831999999999, 6235.601, 6206.015, 6175.041, 6142.644, 6108.7880000000005, 6073.435, 6036.547, 5998.0830000000005, 5958.0019999999995, 5916.259, 5872.811, 5827.61, 5780.607, 5731.7519999999995, 5680.991, 5628.272, 5573.536999999999, 5516.727, 5457.781, 5396.634, 5333.221, 5267.473000000001, 5199.318, 5128.681, 5055.487, 4979.655, 4901.101, 4819.74, 4735.482, 4648.237, 4557.907999999999, 4464.399, 4367.61, 4267.438, 4163.777, 4056.522, 3945.5640000000003, 3830.797, 3712.112, 3589.402, 3462.565, 3331.4990000000003, 3196.113, 3056.322, 2912.05, 2763.238, 2609.843, 2451.845, 2289.248, 2122.0879999999997, 1950.4370000000001, 1774.41, 1594.1689999999999, 1409.9279999999999, 1221.958, 1030.593, 836.2280000000001, 639.327, 440.411, 240.058, 38.898, -162.403, -363.153, -562.649, -760.196, -955.118, -1146.78, -1334.594, -1518.0339999999999, -1696.645, -1870.0420000000001, -2037.915, -2200.026, -2356.2070000000003, -2506.3520000000003, -2650.4109999999996, -2788.385, -2920.315, -3046.282, -3166.3920000000003, -3280.772, -3389.573, -3492.954, -3591.083, -3684.134, -3772.2870000000003, -3855.719, -3934.607, -4009.125, -4079.442, -4145.729, -4208.143, -4266.842000000001, -4321.975, -4373.685, -4422.113, -4467.39, -4509.642, -4548.992, -4585.553, -4619.437, -4650.748, -4679.587, -4706.049, -4730.225, -4752.2029999999995, -4772.063, -4789.8859999999995, -4805.746, -4819.715, -4831.862, -4842.249, -4850.943, -4858.0, -4863.478, -4867.43, -4869.91, -4870.965, -4870.644, -4868.992, -4866.052, -4861.865, -4856.472, -4849.911, -4842.219, -4833.43, -4823.577, -4812.695, -4800.813, -4787.962, -4774.170999999999, -4759.465999999999, -4743.875, -4727.424, -4710.1359999999995, -4692.036, -4673.147, -4653.491, -4633.088, -4611.960999999999, -4590.127, -4567.608, -4544.42, -4520.583, -4496.113, -4471.028, -4445.342000000001, -4419.073, -4392.235, -4364.843, -4336.911, -4308.4529999999995, -4279.482, -4250.012, -4220.054, -4189.621, -4158.725, -4127.378, -4095.591, -4063.3740000000003, -4030.739, -3997.695, -3964.252, -3930.42, -3896.208, -3861.6259999999997, -3826.683, -3791.387, -3755.7470000000003, -3719.772, -3683.468, -3646.844, -3609.908, -3572.667, -3535.1279999999997, -3497.2990000000004, -3459.1859999999997, -3420.797, -3382.138, -3343.2140000000004, -3304.034, -3264.6020000000003, -3224.925, -3185.009, -3144.8590000000004, -3104.4809999999998, -3063.881, -3023.0640000000003, -2982.0359999999996, -2940.801, -2899.364, -2857.7309999999998, -2815.906, -2773.895, -2731.7009999999996, -2689.33, -2646.7859999999996, -2604.073, -2561.195, -2518.158, -2474.964, -2431.619, -2388.125, -2344.488, -2300.71, -2256.797, -2212.75, -2168.575, -2124.274, -2079.8520000000003, -2035.3110000000001, -1990.656, -1945.889, -1901.014, -1856.0339999999999, -1810.9520000000002, -1765.771, -1720.496, -1675.128, -1629.67, -1584.1270000000002, -1538.5, -1492.7920000000001, -1447.007, -1401.1470000000002, -1355.214, -1309.213, -1263.145, -1217.013, -1170.82, -1124.568, -1078.259, -1031.8980000000001, -985.485, -939.023, -892.5160000000001, -845.9639999999999, -799.372, -752.74, -706.071, -659.3689999999999, -612.634, -565.869, -519.077, -472.26, -425.41900000000004, -378.55800000000005, -331.67800000000005, -284.781, -237.87, -190.946, -144.012, -97.069, -50.121, -3.168, 43.787, 90.742, 137.695, 184.644, 231.588, 278.52299999999997, 325.45, 372.36400000000003, 419.265, 466.151, 513.019, 559.869, 606.697, 653.502, 700.283, 747.0369999999999, 793.762, 840.457, 887.1210000000001, 933.75, 980.3439999999999, 1026.9, 1073.417, 1119.893, 1166.326, 1212.715, 1259.057, 1305.351, 1351.595, 1397.7879999999998, 1443.9270000000001, 1490.011, 1536.0379999999998, 1582.006, 1627.915, 1673.76, 1719.5420000000001, 1765.259, 1810.908, 1856.4879999999998, 1901.997, 1947.433, 1992.796, 2038.082, 2083.29, 2128.419, 2173.466, 2218.43, 2263.31, 2308.103, 2352.8070000000002, 2397.422, 2441.944, 2486.373, 2530.7070000000003, 2574.9429999999998, 2619.081, 2663.117, 2707.051, 2750.881, 2794.6040000000003, 2838.22, 2881.725, 2925.119, 2968.4, 3011.565, 3054.612, 3097.5409999999997, 3140.349, 3183.034, 3225.594, 3268.027, 3310.3320000000003, 3352.506, 3394.548, 3436.455, 3478.2259999999997, 3519.8590000000004, 3561.3509999999997, 3602.7009999999996, 3643.907, 3684.966, 3725.8759999999997, 3766.636, 3807.244, 3847.696, 3887.992, 3928.1290000000004, 3968.105, 4007.917, 4047.5640000000003, 4087.0429999999997, 4126.353, 4165.49, 4204.4529999999995, 4243.2390000000005, 4281.846, 4320.271, 4358.513, 4396.569, 4434.436, 4472.112, 4509.595, 4546.8820000000005, 4583.971, 4620.859, 4657.543, 4694.022, 4730.291, 4766.349, 4802.194, 4837.821, 4873.229, 4908.415, 4943.376, 4978.109, 5012.611, 5046.879, 5080.911, 5114.7029999999995, 5148.253, 5181.556, 5214.611, 5247.414000000001, 5279.9619999999995, 5312.251, 5344.278, 5376.041, 5407.534000000001, 5438.755999999999, 5469.703, 5500.37, 5530.755, 5560.854, 5590.664000000001, 5620.18, 5649.398, 5678.315, 5706.927, 5735.23, 5763.22, 5790.892, 5818.243, 5845.269, 5871.964, 5898.3240000000005, 5924.346, 5950.024, 5975.355, 6000.331999999999, 6024.951, 6049.2080000000005, 6073.098000000001, 6096.615, 6119.754, 6142.5109999999995, 6164.88, 6186.854, 6208.43, 6229.601, 6250.361, 6270.705, 6290.626, 6310.119000000001, 6329.177, 6347.793000000001, 6365.963000000001, 6383.678000000001, 6400.932, 6417.718000000001, 6434.029, 6449.859, 6465.198, 6480.041, 6494.38, 6508.206, 6521.512, 6534.289000000001, 6546.529, 6558.224, 6569.3640000000005, 6579.941999999999, 6589.946999999999, 6599.37, 6608.201999999999, 6616.433000000001, 6624.052, 6631.05, 6637.415, 6643.138000000001, 6648.206, 6652.608, 6656.334, 6659.37, 6661.704000000001, 6663.3240000000005, 6664.217, 6664.369000000001, 6663.766, 6662.395, 6660.241, 6657.29, 6653.525, 6648.931, 6643.491999999999, 6637.191, 6630.0109999999995, 6621.935, 6612.944, 6603.019, 6592.141, 6580.29, 6567.445, 6553.585999999999, 6538.69, 6522.735, 6505.698, 6487.553000000001, 6468.276999999999, 6447.844, 6426.227, 6403.398, 6379.329000000001, 6353.991, 6327.353, 6299.384, 6270.05, 6239.316999999999, 6207.153, 6173.518, 6138.376, 6101.688, 6063.411999999999, 6023.507, 5981.929, 5938.632, 5893.569, 5846.691, 5797.948, 5747.285, 5694.648, 5639.98, 5583.221, 5524.309, 5463.18, 5399.767, 5334.0, 5265.807, 5195.113, 5121.840999999999, 5045.907999999999, 4967.232, 4885.725, 4801.2970000000005, 4713.856, 4623.305, 4529.545999999999, 4432.477, 4331.994000000001, 4227.991, 4120.359, 4008.99, 3893.772, 3774.597, 3651.3559999999998, 3523.942, 3392.2529999999997, 3256.1929999999998, 3115.673, 2970.617, 2820.958, 2666.653, 2507.675, 2344.025, 2175.7329999999997, 2002.866, 1825.533, 1643.89, 1458.1470000000002, 1268.569, 1075.485, 879.2869999999999, 680.434, 479.445, 276.899, 73.42699999999999, -130.30200000000002, -333.59, -535.727, -736.0060000000001, -933.742, -1128.2839999999999, -1319.031, -1505.443, -1687.049, -1863.4479999999999, -2034.319, -2199.409, -2358.5389999999998, -2511.593, -2658.512, -2799.2909999999997, -2933.965, -3062.6090000000004, -3185.3259999999996, -3302.244, -3413.507, -3519.275, -3619.718, -3715.01, -3805.329, -3890.8559999999998, -3971.768, -4048.241, -4120.448, -4188.557, -4252.731, -4313.127, -4369.898, -4423.19, -4473.143, -4519.891, -4563.562, -4604.28, -4642.162, -4677.319, -4709.859, -4739.880999999999, -4767.486, -4792.764, -4815.803, -4836.688, -4855.499, -4872.311, -4887.198, -4900.228, -4911.47, -4920.984, -4928.833, -4935.073, -4939.759, -4942.945, -4944.68, -4945.013, -4943.99, -4941.654, -4938.049, -4933.215, -4927.19, -4920.012, -4911.715999999999, -4902.337, -4891.907999999999, -4880.46, -4868.024, -4854.629, -4840.304, -4825.0740000000005, -4808.967000000001, -4792.0070000000005, -4774.218, -4755.624, -4736.248, -4716.111, -4695.234, -4673.637, -4651.339, -4628.36, -4604.718, -4580.43, -4555.514, -4529.985, -4503.86, -4477.154, -4449.883, -4422.06, -4393.7, -4364.816, -4335.4220000000005, -4305.529, -4275.153, -4244.302, -4212.99, -4181.228, -4149.027, -4116.398, -4083.3509999999997, -4049.8959999999997, -4016.0440000000003, -3981.803, -3947.183, -3912.1940000000004, -3876.843, -3841.1409999999996, -3805.094, -3768.712, -3732.002, -3694.972, -3657.63, -3619.9829999999997, -3582.039, -3543.804, -3505.285, -3466.489, -3427.423, -3388.093, -3348.505, -3308.6659999999997, -3268.5809999999997, -3228.256, -3187.698, -3146.9109999999996, -3105.901, -3064.6740000000004, -3023.235, -2981.5879999999997, -2939.74, -2897.695, -2855.4570000000003, -2813.032, -2770.4240000000004, -2727.638, -2684.678, -2641.5490000000004, -2598.254, -2554.799, -2511.187, -2467.423, -2423.51, -2379.452, -2335.254, -2290.9179999999997, -2246.449, -2201.851, -2157.127, -2112.28, -2067.314, -2022.2320000000002, -1977.0379999999998, -1931.736, -1886.328, -1840.817, -1795.207, -1749.5020000000002, -1703.703, -1657.8139999999999, -1611.838, -1565.7779999999998, -1519.6370000000002, -1473.4170000000001, -1427.1229999999998, -1380.755, -1334.318, -1287.813, -1241.244, -1194.612, -1147.922, -1101.175, -1054.373, -1007.52, -960.618, -913.669, -866.676, -819.6410000000001, -772.566, -725.454, -678.308, -631.129, -583.919, -536.682, -489.41900000000004, -442.13199999999995, -394.824, -347.49699999999996, -300.153, -252.794, -205.422, -158.04, -110.649, -63.251000000000005, -15.849, 31.555, 78.96, 126.363, 173.763, 221.157, 268.54400000000004, 315.921, 363.286, 410.639, 457.976, 505.296, 552.597, 599.877, 647.134, 694.367, 741.573, 788.7510000000001, 835.898, 883.013, 930.095, 977.1410000000001, 1024.149, 1071.118, 1118.046, 1164.931, 1211.771, 1258.565, 1305.31, 1352.005, 1398.649, 1445.239, 1491.773, 1538.25, 1584.6689999999999, 1631.026, 1677.3220000000001, 1723.5529999999999, 1769.7179999999998, 1815.815, 1861.8429999999998, 1907.799, 1953.683, 1999.491, 2045.224, 2090.877, 2136.451, 2181.9429999999998, 2227.351, 2272.674, 2317.91, 2363.056, 2408.112, 2453.075, 2497.944, 2542.717, 2587.3920000000003, 2631.967, 2676.441, 2720.8109999999997, 2765.0759999999996, 2809.2329999999997, 2853.282, 2897.22, 2941.046, 2984.756, 3028.3509999999997, 3071.827, 3115.183, 3158.417, 3201.527, 3244.511, 3287.367, 3330.094, 3372.688, 3415.1490000000003, 3457.474, 3499.6609999999996, 3541.7090000000003, 3583.615, 3625.377, 3666.993, 3708.461, 3749.78, 3790.946, 3831.958, 3872.813, 3913.51, 3954.046, 3994.42, 4034.6279999999997, 4074.6690000000003, 4114.541, 4154.24, 4193.766, 4233.115, 4272.285, 4311.274, 4350.08, 4388.7, 4427.1320000000005, 4465.373, 4503.42, 4541.272, 4578.9259999999995, 4616.379, 4653.628, 4690.6720000000005, 4727.5070000000005, 4764.13, 4800.54, 4836.733, 4872.706, 4908.458, 4943.984, 4979.282, 5014.349, 5049.182, 5083.778, 5118.135, 5152.249, 5186.117, 5219.735, 5253.102, 5286.213000000001, 5319.065, 5351.655, 5383.98, 5416.036, 5447.819, 5479.326999999999, 5510.555, 5541.501, 5572.159000000001, 5602.528, 5632.601, 5662.378000000001, 5691.852, 5721.021, 5749.88, 5778.425, 5806.651999999999, 5834.557, 5862.135, 5889.383000000001, 5916.295, 5942.866999999999, 5969.095, 5994.974, 6020.499, 6045.666, 6070.469, 6094.903, 6118.964, 6142.646, 6165.944, 6188.852, 6211.366, 6233.479, 6255.186, 6276.482, 6297.359, 6317.812, 6337.835999999999, 6357.423000000001, 6376.566999999999, 6395.262, 6413.5019999999995, 6431.278, 6448.585999999999, 6465.416, 6481.763000000001, 6497.618, 6512.975, 6527.825, 6542.161, 6555.974, 6569.257, 6582.0, 6594.196, 6605.835999999999, 6616.909000000001, 6627.408, 6637.323, 6646.644, 6655.361, 6663.464, 6670.943, 6677.786999999999, 6683.985, 6689.526, 6694.398, 6698.59, 6702.089, 6704.883000000001, 6706.96, 6708.306, 6708.906999999999, 6708.751, 6707.823, 6706.107, 6703.590999999999, 6700.257, 6696.09, 6691.073, 6685.191, 6678.425, 6670.758000000001, 6662.170999999999, 6652.647, 6642.164000000001, 6630.703, 6618.243, 6604.764, 6590.241999999999, 6574.656, 6557.981, 6540.193, 6521.268, 6501.179, 6479.9, 6457.403, 6433.659000000001, 6408.638000000001, 6382.311, 6354.644, 6325.605, 6295.161, 6263.275, 6229.911, 6195.031, 6158.597, 6120.566, 6080.895, 6039.541, 5996.459, 5951.6, 5904.915, 5856.353, 5805.861, 5753.382, 5698.859, 5642.233, 5583.44, 5522.416, 5459.093000000001, 5393.401999999999, 5325.269, 5254.618, 5181.372, 5105.448, 5026.7609999999995, 4945.225, 4860.748, 4773.236, 4682.592000000001, 4588.715999999999, 4491.505999999999, 4390.856, 4286.657999999999, 4178.804, 4067.1809999999996, 3951.677, 3832.1820000000002, 3708.585, 3580.776, 3448.651, 3312.11, 3171.0640000000003, 3025.43, 2875.1409999999996, 2720.1459999999997, 2560.416, 2395.945, 2226.762, 2052.926, 1874.5410000000002, 1691.757, 1504.7779999999998, 1313.864, 1119.338, 921.5880000000001, 721.067, 518.2919999999999, 313.842, 108.346, -97.523, -303.063, -507.55800000000005, -710.2919999999999, -910.568, -1107.725, -1301.147, -1490.28, -1674.638, -1853.808, -2027.4520000000002, -2195.308, -2357.1839999999997, -2512.952, -2662.548, -2805.9559999999997, -2943.2070000000003, -3074.37, -3199.545, -3318.8559999999998, -3432.448, -3540.478, -3643.115, -3740.534, -3832.915, -3920.437, -4003.2790000000005, -4081.619, -4155.6320000000005, -4225.486, -4291.36, -4353.373, -4411.718, -4466.531, -4517.954000000001, -4566.122, -4611.165, -4653.208, -4692.37, -4728.764, -4762.498, -4793.6759999999995, -4822.395, -4848.751, -4872.831, -4894.721, -4914.502, -4932.253, -4948.045999999999, -4961.952, -4974.038, -4984.369000000001, -4993.005999999999, -5000.0070000000005, -5005.428, -5009.323, -5011.7429999999995, -5012.736, -5012.35, -5010.629, -5007.616, -5003.353, -4997.878, -4991.23, -4983.445, -4974.557, -4964.601, -4953.607, -4941.608, -4928.633, -4914.71, -4899.867, -4884.13, -4867.525, -4850.077, -4831.809, -4812.7429999999995, -4792.903, -4772.308, -4750.981, -4728.939, -4706.204000000001, -4682.793, -4658.723, -4634.013, -4608.68, -4582.738, -4556.204000000001, -4529.094, -4501.420999999999, -4473.201, -4444.446, -4415.170999999999, -4385.389, -4355.111, -4324.35, -4293.119000000001, -4261.428, -4229.29, -4196.714, -4163.710999999999, -4130.293, -4096.468, -4062.2470000000003, -4027.638, -3992.652, -3957.297, -3921.583, -3885.5170000000003, -3849.1079999999997, -3812.364, -3775.292, -3737.902, -3700.2, -3662.1929999999998, -3623.889, -3585.295, -3546.4179999999997, -3507.263, -3467.8390000000004, -3428.15, -3388.205, -3348.007, -3307.5640000000003, -3266.881, -3225.9640000000004, -3184.8190000000004, -3143.4509999999996, -3101.865, -3060.066, -3018.0609999999997, -2975.853, -2933.448, -2890.85, -2848.0640000000003, -2805.0959999999995, -2761.949, -2718.627, -2675.136, -2631.4790000000003, -2587.661, -2543.686, -2499.558, -2455.281, -2410.859, -2366.295, -2321.594, -2276.759, -2231.794, -2186.703, -2141.488, -2096.154, -2050.7039999999997, -2005.141, -1959.469, -1913.691, -1867.81, -1821.829, -1775.751, -1729.58, -1683.318, -1636.969, -1590.535, -1544.02, -1497.425, -1450.755, -1404.0120000000002, -1357.1979999999999, -1310.316, -1263.369, -1216.36, -1169.2910000000002, -1122.165, -1074.985, -1027.752, -980.4689999999999, -933.14, -885.765, -838.3489999999999, -790.8919999999999, -743.398, -695.8689999999999, -648.306, -600.7130000000001, -553.092, -505.445, -457.773, -410.08, -362.36800000000005, -314.638, -266.893, -219.135, -171.365, -123.587, -75.803, -28.013, 19.779, 67.572, 115.36399999999999, 163.15200000000002, 210.935, 258.71, 306.476, 354.231, 401.973, 449.7, 497.41, 545.101, 592.771, 640.418, 688.04, 735.637, 783.204, 830.742, 878.248, 925.7189999999999, 973.155, 1020.554, 1067.913, 1115.231, 1162.506, 1209.736, 1256.9189999999999, 1304.055, 1351.139, 1398.172, 1445.151, 1492.075, 1538.941, 1585.7479999999998, 1632.494, 1679.1770000000001, 1725.796, 1772.349, 1818.8329999999999, 1865.2479999999998, 1911.5910000000001, 1957.861, 2004.055, 2050.173, 2096.2110000000002, 2142.17, 2188.045, 2233.837, 2279.5429999999997, 2325.161, 2370.69, 2416.127, 2461.471, 2506.72, 2551.8720000000003, 2596.926, 2641.8790000000004, 2686.73, 2731.4770000000003, 2776.118, 2820.651, 2865.074, 2909.386, 2953.5840000000003, 2997.667, 3041.632, 3085.478, 3129.203, 3172.8059999999996, 3216.283, 3259.633, 3302.8540000000003, 3345.9440000000004, 3388.902, 3431.724, 3474.41, 3516.9570000000003, 3559.363, 3601.625, 3643.743, 3685.7140000000004, 3727.535, 3769.205, 3810.7209999999995, 3852.0820000000003, 3893.284, 3934.327, 3975.208, 4015.9240000000004, 4056.473, 4096.854, 4137.063, 4177.098, 4216.958, 4256.64, 4296.141, 4335.459, 4374.590999999999, 4413.536, 4452.291, 4490.853, 4529.219, 4567.388, 4605.356, 4643.121, 4680.681, 4718.032, 4755.173, 4792.099, 4828.81, 4865.3009999999995, 4901.57, 4937.6140000000005, 4973.43, 5009.016, 5044.3679999999995, 5079.483, 5114.359, 5148.992, 5183.379, 5217.518, 5251.404, 5285.034000000001, 5318.406, 5351.516, 5384.36, 5416.936, 5449.2390000000005, 5481.266, 5513.014, 5544.479, 5575.656999999999, 5606.545, 5637.138000000001, 5667.434, 5697.427, 5727.1140000000005, 5756.491, 5785.554, 5814.299, 5842.721, 5870.816999999999, 5898.581, 5926.009, 5953.097, 5979.840999999999, 6006.235, 6032.274, 6057.955, 6083.271, 6108.219, 6132.7919999999995, 6156.986, 6180.795, 6204.214, 6227.238, 6249.86, 6272.075, 6293.878000000001, 6315.262, 6336.221, 6356.75, 6376.840999999999, 6396.4890000000005, 6415.686, 6434.427, 6452.704000000001, 6470.51, 6487.839, 6504.682, 6521.033, 6536.885, 6552.228, 6567.056, 6581.359, 6595.130999999999, 6608.363, 6621.045, 6633.169, 6644.726, 6655.706, 6666.101, 6675.9, 6685.094, 6693.672, 6701.6230000000005, 6708.938, 6715.605, 6721.613, 6726.9490000000005, 6731.604, 6735.563, 6738.816, 6741.348000000001, 6743.148, 6744.2, 6744.491999999999, 6744.01, 6742.738, 6740.661, 6737.765, 6734.031999999999, 6729.446999999999, 6723.993, 6717.653, 6710.408, 6702.24, 6693.13, 6683.058000000001, 6672.005999999999, 6659.95, 6646.871, 6632.745, 6617.5509999999995, 6601.264, 6583.859, 6565.313, 6545.599, 6524.689, 6502.556, 6479.170999999999, 6454.505, 6428.526, 6401.203, 6372.501, 6342.388000000001, 6310.828, 6277.783, 6243.215999999999, 6207.085999999999, 6169.352, 6129.973000000001, 6088.903, 6046.096, 6001.505, 5955.08, 5906.769, 5856.518, 5804.271, 5749.972, 5693.558000000001, 5634.967, 5574.134, 5510.991, 5445.468000000001, 5377.491, 5306.983, 5233.866, 5158.057, 5079.472, 4998.021, 4913.612, 4826.152, 4735.542, 4641.682, 4544.467000000001, 4443.791, 4339.545999999999, 4231.619000000001, 4119.9, 4004.2729999999997, 3884.6259999999997, 3760.8459999999995, 3632.822, 3500.447, 3363.619, 3222.244, 3076.237, 2925.5290000000005, 2770.063, 2609.8070000000002, 2444.75, 2274.915, 2100.357, 1921.174, 1737.509, 1549.5610000000001, 1357.5829999999999, 1161.893, 962.873, 760.971, 556.702, 350.639, 143.41299999999998, -64.30199999999999, -271.803, -478.366, -683.268, -885.804, -1085.3, -1281.129, -1472.7220000000002, -1659.58, -1841.277, -2017.461, -2187.8579999999997, -2352.263, -2510.541, -2662.615, -2808.466, -2948.115, -3081.6290000000004, -3209.1009999999997, -3330.655, -3446.4309999999996, -3556.586, -3661.2870000000003, -3760.7129999999997, -3855.039, -3944.449, -4029.12, -4109.231, -4184.959, -4256.473, -4323.941, -4387.522, -4447.373, -4503.643, -4556.474, -4606.005999999999, -4652.3679999999995, -4695.688, -4736.085, -4773.675, -4808.566, -4840.863, -4870.667, -4898.071, -4923.166, -4946.039000000001, -4966.772, -4985.443, -5002.127, -5016.896, -5029.818, -5040.957, -5050.377, -5058.135, -5064.29, -5068.894, -5072.0, -5073.657999999999, -5073.915, -5072.816, -5070.405, -5066.723, -5061.811, -5055.707, -5048.447, -5040.068, -5030.602, -5020.083, -5008.541, -4996.0070000000005, -4982.51, -4968.0779999999995, -4952.738, -4936.515, -4919.434, -4901.519, -4882.794, -4863.281, -4843.001, -4821.976, -4800.224, -4777.767, -4754.621, -4730.807, -4706.34, -4681.2390000000005, -4655.519, -4629.197, -4602.287, -4574.805, -4546.766, -4518.183, -4489.07, -4459.44, -4429.306, -4398.68, -4367.5740000000005, -4336.0, -4303.97, -4271.494000000001, -4238.584, -4205.249, -4171.5, -4137.347, -4102.8, -4067.867, -4032.558, -3996.883, -3960.848, -3924.4640000000004, -3887.738, -3850.678, -3813.292, -3775.5879999999997, -3737.573, -3699.2540000000004, -3660.639, -3621.735, -3582.547, -3543.0840000000003, -3503.3509999999997, -3463.3540000000003, -3423.1, -3382.5959999999995, -3341.8459999999995, -3300.8559999999998, -3259.633, -3218.1809999999996, -3176.507, -3134.615, -3092.511, -3050.2, -3007.6859999999997, -2964.975, -2922.071, -2878.98, -2835.7059999999997, -2792.252, -2748.625, -2704.827, -2660.864, -2616.74, -2572.458, -2528.0229999999997, -2483.438, -2438.709, -2393.837, -2348.828, -2303.685, -2258.411, -2213.011, -2167.487, -2121.843, -2076.083, -2030.21, -1984.227, -1938.138, -1891.945, -1845.6529999999998, -1799.263, -1752.779, -1706.205, -1659.543, -1612.795, -1565.9660000000001, -1519.057, -1472.0720000000001, -1425.014, -1377.884, -1330.6870000000001, -1283.424, -1236.098, -1188.712, -1141.269, -1093.77, -1046.219, -998.618, -950.97, -903.2760000000001, -855.54, -807.763, -759.949, -712.0989999999999, -664.216, -616.3009999999999, -568.359, -520.389, -472.39599999999996, -424.38, -376.345, -328.292, -280.223, -232.141, -184.048, -135.946, -87.837, -39.723, 8.394, 56.512, 104.62899999999999, 152.743, 200.852, 248.953, 297.045, 345.12699999999995, 393.195, 441.24800000000005, 489.285, 537.302, 585.299, 633.273, 681.2230000000001, 729.1460000000001, 777.041, 824.9060000000001, 872.7389999999999, 920.538, 968.302, 1016.0269999999999, 1063.714, 1111.359, 1158.961, 1206.519, 1254.029, 1301.491, 1348.9029999999998, 1396.263, 1443.569, 1490.819, 1538.011, 1585.145, 1632.217, 1679.226, 1726.171, 1773.049, 1819.858, 1866.598, 1913.266, 1959.86, 2006.378, 2052.819, 2099.1820000000002, 2145.4629999999997, 2191.661, 2237.775, 2283.803, 2329.742, 2375.592, 2421.35, 2467.014, 2512.5820000000003, 2558.053, 2603.426, 2648.697, 2693.865, 2738.928, 2783.885, 2828.7329999999997, 2873.4709999999995, 2918.097, 2962.6079999999997, 3007.0029999999997, 3051.28, 3095.438, 3139.473, 3183.384, 3227.17, 3270.828, 3314.355, 3357.752, 3401.014, 3444.14, 3487.1290000000004, 3529.9770000000003, 3572.683, 3615.2459999999996, 3657.6620000000003, 3699.93, 3742.047, 3784.012, 3825.822, 3867.475, 3908.969, 3950.301, 3991.47, 4032.474, 4073.309, 4113.973, 4154.465, 4194.782, 4234.920999999999, 4274.880999999999, 4314.657999999999, 4354.251, 4393.657, 4432.873, 4471.897, 4510.727, 4549.359, 4587.792, 4626.022, 4664.048, 4701.865, 4739.473, 4776.867, 4814.045999999999, 4851.005, 4887.744000000001, 4924.258, 4960.545, 4996.602, 5032.425, 5068.013, 5103.361, 5138.467000000001, 5173.3279999999995, 5207.94, 5242.3, 5276.406, 5310.253000000001, 5343.838000000001, 5377.159000000001, 5410.21, 5442.99, 5475.495, 5507.72, 5539.6630000000005, 5571.319, 5602.685, 5633.755999999999, 5664.531, 5695.003000000001, 5725.169, 5755.026, 5784.569, 5813.794, 5842.696, 5871.271, 5899.516, 5927.424, 5954.993, 5982.217, 6009.090999999999, 6035.611, 6061.772, 6087.569, 6112.996999999999, 6138.0509999999995, 6162.725, 6187.014, 6210.9130000000005, 6234.4169999999995, 6257.519, 6280.214, 6302.496, 6324.359, 6345.798000000001, 6366.805, 6387.374, 6407.5, 6427.175, 6446.393, 6465.147, 6483.43, 6501.235, 6518.554, 6535.380999999999, 6551.706999999999, 6567.524, 6582.825, 6597.602, 6611.846, 6625.549, 6638.701999999999, 6651.297, 6663.323, 6674.772, 6685.635, 6695.901, 6705.561, 6714.604, 6723.02, 6730.797, 6737.9259999999995, 6744.395, 6750.191999999999, 6755.304, 6759.722, 6763.43, 6766.4169999999995, 6768.67, 6770.175, 6770.9169999999995, 6770.884, 6770.059, 6768.428000000001, 6765.976, 6762.686, 6758.5419999999995, 6753.526, 6747.6230000000005, 6740.812, 6733.076999999999, 6724.398, 6714.755, 6704.128000000001, 6692.496, 6679.838000000001, 6666.130999999999, 6651.353, 6635.479, 6618.486, 6600.347, 6581.036999999999, 6560.529, 6538.795, 6515.805, 6491.53, 6465.94, 6439.001, 6410.68, 6380.945, 6349.757, 6317.08, 6282.8769999999995, 6247.106, 6209.728, 6170.698, 6129.972, 6087.505, 6043.2480000000005, 5997.151, 5949.161, 5899.227, 5847.29, 5793.2919999999995, 5737.174, 5678.871999999999, 5618.32, 5555.45, 5490.191, 5422.469, 5352.2080000000005, 5279.326999999999, 5203.745, 5125.375, 5044.129, 4959.913, 4872.633, 4782.191, 4688.484, 4591.407, 4490.853, 4386.712, 4278.872, 4167.219, 4051.639, 3932.015, 3808.2340000000004, 3680.183, 3547.752, 3410.8379999999997, 3269.342, 3123.178, 2972.2729999999997, 2816.565, 2656.0190000000002, 2490.619, 2320.383, 2145.36, 1965.642, 1781.368, 1592.727, 1399.969, 1203.402, 1003.404, 800.4169999999999, 594.95, 387.575, 178.919, -30.344, -239.50799999999998, -447.846, -654.629, -859.1410000000001, -1060.701, -1258.6680000000001, -1452.4620000000002, -1641.57, -1825.5529999999999, -2004.046, -2176.762, -2343.486, -2504.072, -2658.434, -2806.545, -2948.421, -3084.1209999999996, -3213.735, -3337.384, -3455.205, -3567.355, -3673.9990000000003, -3775.313, -3871.475, -3962.667, -4049.0679999999998, -4130.858, -4208.214, -4281.307, -4350.305, -4415.37, -4476.659000000001, -4534.323, -4588.505, -4639.346, -4686.977, -4731.527, -4773.116, -4811.862, -4847.873, -4881.2570000000005, -4912.1140000000005, -4940.541, -4966.627, -4990.460999999999, -5012.126, -5031.701, -5049.263, -5064.883, -5078.630999999999, -5090.571, -5100.768, -5109.281, -5116.168, -5121.483, -5125.279, -5127.606, -5128.512, -5128.043, -5126.2429999999995, -5123.154, -5118.818, -5113.271, -5106.553, -5098.698, -5089.742, -5079.715999999999, -5068.653, -5056.583, -5043.535, -5029.539000000001, -5014.62, -4998.805, -4982.12, -4964.588, -4946.233, -4927.0779999999995, -4907.145, -4886.454000000001, -4865.026, -4842.88, -4820.037, -4796.513, -4772.327, -4747.496, -4722.036, -4695.964, -4669.295999999999, -4642.045999999999, -4614.228, -4585.859, -4556.95, -4527.516, -4497.569, -4467.122, -4436.187, -4404.776, -4372.901, -4340.572, -4307.802, -4274.599, -4240.975, -4206.939, -4172.502, -4137.673, -4102.460999999999, -4066.875, -4030.9240000000004, -3994.616, -3957.96, -3920.9640000000004, -3883.636, -3845.9829999999997, -3808.014, -3769.735, -3731.153, -3692.277, -3653.112, -3613.665, -3573.9429999999998, -3533.952, -3493.699, -3453.1890000000003, -3412.429, -3371.425, -3330.1809999999996, -3288.705, -3247.0, -3205.074, -3162.93, -3120.574, -3078.012, -3035.2470000000003, -2992.2859999999996, -2949.132, -2905.7909999999997, -2862.2659999999996, -2818.563, -2774.6859999999997, -2730.639, -2686.426, -2642.052, -2597.521, -2552.8360000000002, -2508.0029999999997, -2463.0229999999997, -2417.902, -2372.644, -2327.251, -2281.7270000000003, -2236.077, -2190.303, -2144.41, -2098.399, -2052.276, -2006.0420000000001, -1959.7020000000002, -1913.259, -1866.715, -1820.0729999999999, -1773.338, -1726.5120000000002, -1679.5970000000002, -1632.5970000000002, -1585.515, -1538.3529999999998, -1491.115, -1443.8029999999999, -1396.42, -1348.9679999999998, -1301.451, -1253.87, -1206.23, -1158.531, -1110.777, -1062.97, -1015.113, -967.2080000000001, -919.258, -871.265, -823.2310000000001, -775.16, -727.052, -678.9110000000001, -630.738, -582.5369999999999, -534.309, -486.056, -437.781, -389.486, -341.17400000000004, -292.845, -244.503, -196.15, -147.787, -99.417, -51.041000000000004, -2.6630000000000003, 45.717, 94.095, 142.471, 190.842, 239.205, 287.56, 335.904, 384.235, 432.551, 480.851, 529.131, 577.3919999999999, 625.629, 673.842, 722.029, 770.188, 818.317, 866.413, 914.4760000000001, 962.503, 1010.493, 1058.444, 1106.353, 1154.219, 1202.04, 1249.815, 1297.5410000000002, 1345.2160000000001, 1392.84, 1440.4089999999999, 1487.9229999999998, 1535.379, 1582.776, 1630.111, 1677.384, 1724.5910000000001, 1771.7320000000002, 1818.805, 1865.807, 1912.737, 1959.5929999999998, 2006.3729999999998, 2053.076, 2099.7, 2146.242, 2192.701, 2239.076, 2285.364, 2331.563, 2377.672, 2423.689, 2469.612, 2515.439, 2561.1679999999997, 2606.797, 2652.325, 2697.75, 2743.07, 2788.282, 2833.385, 2878.377, 2923.257, 2968.0209999999997, 3012.6690000000003, 3057.198, 3101.607, 3145.893, 3190.054, 3234.0890000000004, 3277.995, 3321.7709999999997, 3365.414, 3408.922, 3452.2940000000003, 3495.527, 3538.619, 3581.5679999999998, 3624.373, 3667.03, 3709.5370000000003, 3751.8940000000002, 3794.0959999999995, 3836.143, 3878.032, 3919.76, 3961.327, 4002.728, 4043.962, 4085.027, 4125.92, 4166.64, 4207.183, 4247.5470000000005, 4287.73, 4327.729, 4367.542, 4407.167, 4446.601, 4485.840999999999, 4524.884, 4563.73, 4602.373, 4640.813, 4679.045999999999, 4717.069, 4754.880999999999, 4792.477, 4829.856, 4867.014, 4903.9490000000005, 4940.657, 4977.1359999999995, 5013.383, 5049.395, 5085.168, 5120.7, 5155.987, 5191.026, 5225.815, 5260.349, 5294.625, 5328.641, 5362.393, 5395.876, 5429.089, 5462.026999999999, 5494.686, 5527.063, 5559.155, 5590.956999999999, 5622.465999999999, 5653.677, 5684.5869999999995, 5715.193, 5745.4890000000005, 5775.471, 5805.1359999999995, 5834.48, 5863.496999999999, 5892.183000000001, 5920.535, 5948.547, 5976.215, 6003.533, 6030.499, 6057.105, 6083.348000000001, 6109.223000000001, 6134.723000000001, 6159.845, 6184.581999999999, 6208.93, 6232.882, 6256.433000000001, 6279.578, 6302.31, 6324.6230000000005, 6346.512, 6367.97, 6388.991, 6409.568, 6429.695, 6449.366, 6468.571999999999, 6487.308000000001, 6505.565, 6523.3369999999995, 6540.616999999999, 6557.396, 6573.6669999999995, 6589.422, 6604.654, 6619.352, 6633.509, 6647.116, 6660.165, 6672.646, 6684.549, 6695.866, 6706.585999999999, 6716.7, 6726.196999999999, 6735.066, 6743.298000000001, 6750.88, 6757.802, 6764.052, 6769.618, 6774.488, 6778.649, 6782.088000000001, 6784.7919999999995, 6786.7480000000005, 6787.941999999999, 6788.359, 6787.984, 6786.803000000001, 6784.8, 6781.9580000000005, 6778.2609999999995, 6773.693, 6768.236, 6761.871, 6754.581, 6746.345, 6737.146, 6726.960999999999, 6715.771, 6703.553000000001, 6690.285, 6675.945, 6660.509, 6643.951, 6626.246999999999, 6607.37, 6587.293000000001, 6565.9890000000005, 6543.428000000001, 6519.58, 6494.414000000001, 6467.899, 6440.0, 6410.683000000001, 6379.911999999999, 6347.651, 6313.86, 6278.5, 6241.53, 6202.906, 6162.5830000000005, 6120.516, 6076.655, 6030.953, 5983.354, 5933.806, 5882.253000000001, 5828.635, 5772.892, 5714.960999999999, 5654.776, 5592.268, 5527.366, 5459.995, 5390.08, 5317.54, 5242.293, 5164.25, 5083.323, 4999.42, 4912.444, 4822.295999999999, 4728.874, 4632.073, 4531.782999999999, 4427.895, 4320.295999999999, 4208.869000000001, 4093.4990000000003, 3974.0690000000004, 3850.4629999999997, 3722.567, 3590.27, 3453.4640000000004, 3312.05, 3165.938, 3015.05, 2859.324, 2698.717, 2533.212, 2362.82, 2187.585, 2007.592, 1822.974, 1633.914, 1440.654, 1243.497, 1042.8110000000001, 839.034, 632.668, 424.282, 214.498, 3.99, -206.535, -416.348, -624.715, -830.913, -1034.25, -1234.078, -1429.8020000000001, -1620.898, -1806.912, -1987.47, -2162.271, -2331.09, -2493.768, -2650.2129999999997, -2800.388, -2944.303, -3082.013, -3213.6009999999997, -3339.185, -3458.9, -3572.901, -3681.3520000000003, -3784.425, -3882.301, -3975.16, -4063.183, -4146.55, -4225.437, -4300.02, -4370.82, -4436.932, -4499.584, -4558.571, -4614.039000000001, -4666.127, -4714.971, -4760.6990000000005, -4803.431, -4843.287, -4880.377, -4914.809, -4946.684, -4976.099, -5003.147, -5027.916, -5050.49, -5070.9490000000005, -5089.37, -5105.826, -5120.387, -5133.1179999999995, -5144.084, -5153.345, -5160.96, -5166.983, -5171.468, -5174.465999999999, -5176.024, -5176.19, -5175.009, -5172.522, -5168.77, -5163.794, -5157.63, -5150.315, -5141.883, -5132.369000000001, -5121.803, -5110.217000000001, -5097.64, -5084.102, -5069.629, -5054.248, -5037.984, -5020.862, -5002.906, -4984.139, -4964.582, -4944.2570000000005, -4923.185, -4901.385, -4878.877, -4855.679, -4831.809, -4807.285, -4782.123, -4756.34, -4729.951, -4702.972, -4675.418, -4647.303, -4618.641, -4589.445, -4559.728, -4529.504, -4498.785, -4467.582, -4435.907, -4403.772, -4371.187, -4338.164000000001, -4304.713, -4270.844, -4236.566, -4201.89, -4166.8240000000005, -4131.378, -4095.5609999999997, -4059.382, -4022.848, -3985.968, -3948.75, -3911.203, -3873.3320000000003, -3835.147, -3796.6540000000005, -3757.86, -3718.772, -3679.3979999999997, -3639.743, -3599.815, -3559.618, -3519.1609999999996, -3478.448, -3437.486, -3396.28, -3354.837, -3313.1609999999996, -3271.258, -3229.134, -3186.7929999999997, -3144.241, -3101.4829999999997, -3058.5240000000003, -3015.368, -2972.02, -2928.485, -2884.7670000000003, -2840.8720000000003, -2796.802, -2752.563, -2708.159, -2663.593, -2618.871, -2573.996, -2528.971, -2483.801, -2438.49, -2393.041, -2347.458, -2301.744, -2255.904, -2209.94, -2163.857, -2117.656, -2071.343, -2024.9189999999999, -1978.389, -1931.756, -1885.021, -1838.19, -1791.264, -1744.247, -1697.142, -1649.9520000000002, -1602.6789999999999, -1555.326, -1507.8970000000002, -1460.394, -1412.819, -1365.1760000000002, -1317.467, -1269.695, -1221.862, -1173.971, -1126.025, -1078.025, -1029.976, -981.878, -933.7339999999999, -885.548, -837.321, -789.055, -740.753, -692.418, -644.0509999999999, -595.655, -547.232, -498.784, -450.314, -401.824, -353.315, -304.791, -256.253, -207.703, -159.144, -110.57700000000001, -62.005, -13.429, 35.148, 83.72399999999999, 132.297, 180.86599999999999, 229.42700000000002, 277.98, 326.522, 375.05199999999996, 423.566, 472.064, 520.544, 569.003, 617.44, 665.852, 714.238, 762.597, 810.925, 859.221, 907.4839999999999, 955.711, 1003.9, 1052.0510000000002, 1100.16, 1148.226, 1196.247, 1244.222, 1292.1480000000001, 1340.023, 1387.8470000000002, 1435.6170000000002, 1483.33, 1530.986, 1578.5829999999999, 1626.118, 1673.59, 1720.9979999999998, 1768.338, 1815.61, 1862.8120000000001, 1909.941, 1956.996, 2003.976, 2050.877, 2097.7, 2144.44, 2191.098, 2237.6710000000003, 2284.156, 2330.553, 2376.86, 2423.073, 2469.1929999999998, 2515.216, 2561.1420000000003, 2606.967, 2652.691, 2698.3109999999997, 2743.825, 2789.232, 2834.5290000000005, 2879.715, 2924.788, 2969.745, 3014.585, 3059.3059999999996, 3103.906, 3148.383, 3192.7340000000004, 3236.9590000000003, 3281.054, 3325.018, 3368.849, 3412.545, 3456.103, 3499.522, 3542.7990000000004, 3585.933, 3628.92, 3671.76, 3714.45, 3756.988, 3799.3709999999996, 3841.597, 3883.665, 3925.571, 3967.3140000000003, 4008.8909999999996, 4050.3, 4091.539, 4132.605, 4173.496, 4214.209, 4254.742, 4295.094, 4335.26, 4375.2390000000005, 4415.028, 4454.625, 4494.027, 4533.232, 4572.236, 4611.037, 4649.633, 4688.021, 4726.198, 4764.161, 4801.907999999999, 4839.435, 4876.74, 4913.819, 4950.670999999999, 4987.292, 5023.678, 5059.827, 5095.736, 5131.402, 5166.821, 5201.99, 5236.906, 5271.565, 5305.965, 5340.102, 5373.972, 5407.571, 5440.898, 5473.946, 5506.714, 5539.198, 5571.392, 5603.295, 5634.901, 5666.2080000000005, 5697.21, 5727.904, 5758.286, 5788.351, 5818.096, 5847.516, 5876.606, 5905.361999999999, 5933.779, 5961.854, 5989.58, 6016.953, 6043.969, 6070.6230000000005, 6096.909000000001, 6122.821999999999, 6148.356, 6173.508000000001, 6198.271, 6222.639, 6246.608, 6270.170999999999, 6293.321999999999, 6316.055, 6338.365, 6360.245, 6381.689, 6402.69, 6423.241999999999, 6443.3369999999995, 6462.97, 6482.133000000001, 6500.819, 6519.021, 6536.73, 6553.94, 6570.643, 6586.831, 6602.495, 6617.6269999999995, 6632.219, 6646.262, 6659.746999999999, 6672.665, 6685.007, 6696.763000000001, 6707.923000000001, 6718.478, 6728.4169999999995, 6737.729, 6746.403, 6754.429, 6761.795, 6768.49, 6774.5019999999995, 6779.818, 6784.4259999999995, 6788.314, 6791.467, 6793.871999999999, 6795.515, 6796.382, 6796.459, 6795.729, 6794.178000000001, 6791.789000000001, 6788.545999999999, 6784.432, 6779.429, 6773.519, 6766.684, 6758.904, 6750.161, 6740.434, 6729.701, 6717.94, 6705.130999999999, 6691.249, 6676.271, 6660.172, 6642.927, 6624.509, 6604.892, 6584.048000000001, 6561.946999999999, 6538.559, 6513.854, 6487.798000000001, 6460.359, 6431.504, 6401.194, 6369.392, 6336.062, 6301.161999999999, 6264.651, 6226.486, 6186.621999999999, 6145.013000000001, 6101.61, 6056.3640000000005, 6009.222, 5960.13, 5909.031999999999, 5855.868, 5800.578, 5743.098000000001, 5683.363, 5621.304, 5556.848000000001, 5489.923000000001, 5420.451999999999, 5348.353, 5273.5419999999995, 5195.935, 5115.44, 5031.965, 4945.414000000001, 4855.687, 4762.68, 4666.289000000001, 4566.403, 4462.912, 4355.701, 4244.656, 4129.657, 4010.587, 3887.329, 3759.7659999999996, 3627.7870000000003, 3491.281, 3350.1459999999997, 3204.29, 3053.633, 2898.107, 2737.667, 2572.29, 2401.9829999999997, 2226.783, 2046.771, 1862.0729999999999, 1672.865, 1479.38, 1281.914, 1080.829, 876.556, 669.59, 460.49300000000005, 249.887, 38.439, -173.142, -384.12699999999995, -593.776, -801.362, -1006.184, -1207.5839999999998, -1404.9589999999998, -1597.771, -1785.555, -1967.924, -2144.565, -2315.243, -2479.7889999999998, -2638.1009999999997, -2790.135, -2935.8940000000002, -3075.425, -3208.81, -3336.16, -3457.6090000000004, -3573.3070000000002, -3683.42, -3788.117, -3887.577, -3981.9809999999998, -4071.511, -4156.346, -4236.662, -4312.635, -4384.434, -4452.221, -4516.155, -4576.389, -4633.071, -4686.340999999999, -4736.335, -4783.181, -4827.002, -4867.918, -4906.041, -4941.478, -4974.332, -5004.701, -5032.678, -5058.352, -5081.808, -5103.126, -5122.385, -5139.657999999999, -5155.015, -5168.523, -5180.246, -5190.248, -5198.583, -5205.31, -5210.481, -5214.148, -5216.361, -5217.165, -5216.606, -5214.727, -5211.569, -5207.1720000000005, -5201.5740000000005, -5194.812, -5186.92, -5177.932, -5167.8820000000005, -5156.798, -5144.712, -5131.653, -5117.648, -5102.723, -5086.906, -5070.22, -5052.689, -5034.337, -5015.186, -4995.258, -4974.572, -4953.15, -4931.01, -4908.1720000000005, -4884.653, -4860.472, -4835.644, -4810.187, -4784.117, -4757.448, -4730.197, -4702.377, -4674.002, -4645.087, -4615.644, -4585.687, -4555.226, -4524.276, -4492.847, -4460.951, -4428.6, -4395.803, -4362.572, -4328.917, -4294.847, -4260.373, -4225.504, -4190.249, -4154.617, -4118.616, -4082.256, -4045.545, -4008.49, -3971.1, -3933.382, -3895.344, -3856.993, -3818.337, -3779.382, -3740.135, -3700.603, -3660.7929999999997, -3620.71, -3580.361, -3539.7529999999997, -3498.8909999999996, -3457.781, -3416.428, -3374.8390000000004, -3333.0190000000002, -3290.973, -3248.7070000000003, -3206.225, -3163.533, -3120.635, -3077.538, -3034.244, -2990.759, -2947.0879999999997, -2903.235, -2859.205, -2815.0009999999997, -2770.6290000000004, -2726.092, -2681.3940000000002, -2636.539, -2591.532, -2546.376, -2501.076, -2455.634, -2410.055, -2364.342, -2318.498, -2272.528, -2226.435, -2180.223, -2133.893, -2087.451, -2040.899, -1994.24, -1947.4779999999998, -1900.616, -1853.656, -1806.602, -1759.457, -1712.224, -1664.905, -1617.504, -1570.024, -1522.4660000000001, -1474.835, -1427.132, -1379.36, -1331.523, -1283.622, -1235.661, -1187.642, -1139.566, -1091.438, -1043.259, -995.033, -946.76, -898.444, -850.087, -801.692, -753.2610000000001, -704.795, -656.298, -607.7719999999999, -559.219, -510.64, -462.039, -413.418, -364.779, -316.123, -267.453, -218.77200000000002, -170.081, -121.382, -72.678, -23.97, 24.739, 73.44800000000001, 122.154, 170.855, 219.55, 268.236, 316.91200000000003, 365.575, 414.223, 462.855, 511.469, 560.062, 608.633, 657.18, 705.701, 754.194, 802.6569999999999, 851.0880000000001, 899.4860000000001, 947.8480000000001, 996.173, 1044.4589999999998, 1092.703, 1140.905, 1189.062, 1237.172, 1285.234, 1333.246, 1381.205, 1429.111, 1476.961, 1524.753, 1572.485, 1620.1570000000002, 1667.765, 1715.309, 1762.785, 1810.193, 1857.531, 1904.796, 1951.987, 1999.1029999999998, 2046.14, 2093.098, 2139.975, 2186.768, 2233.476, 2280.097, 2326.629, 2373.07, 2419.419, 2465.672, 2511.83, 2557.89, 2603.85, 2649.7070000000003, 2695.461, 2741.1090000000004, 2786.6490000000003, 2832.079, 2877.3979999999997, 2922.603, 2967.692, 3012.664, 3057.5159999999996, 3102.2470000000003, 3146.8540000000003, 3191.336, 3235.691, 3279.915, 3324.008, 3367.968, 3411.7909999999997, 3455.4770000000003, 3499.0229999999997, 3542.427, 3585.6859999999997, 3628.7990000000004, 3671.764, 3714.578, 3757.239, 3799.745, 3842.093, 3884.282, 3926.309, 3968.172, 4009.869, 4051.3959999999997, 4092.752, 4133.935, 4174.942, 4215.77, 4256.418, 4296.8820000000005, 4337.161, 4377.251, 4417.151, 4456.857, 4496.367, 4535.678, 4574.788, 4613.694, 4652.393, 4690.883, 4729.161, 4767.224, 4805.069, 4842.693, 4880.093, 4917.267, 4954.210999999999, 4990.923, 5027.398, 5063.635, 5099.63, 5135.38, 5170.8820000000005, 5206.1320000000005, 5241.127, 5275.863, 5310.338000000001, 5344.548000000001, 5378.4890000000005, 5412.158, 5445.552, 5478.665, 5511.496, 5544.039000000001, 5576.2919999999995, 5608.25, 5639.91, 5671.267, 5702.316999999999, 5733.057, 5763.481, 5793.585999999999, 5823.368, 5852.821, 5881.941999999999, 5910.726, 5939.169, 5967.265, 5995.009, 6022.398, 6049.425, 6076.0869999999995, 6102.3769999999995, 6128.29, 6153.821999999999, 6178.965999999999, 6203.718000000001, 6228.071, 6252.02, 6275.559, 6298.682, 6321.382, 6343.655, 6365.493, 6386.889, 6407.838000000001, 6428.331999999999, 6448.365, 6467.929, 6487.018, 6505.624, 6523.74, 6541.358, 6558.47, 6575.068, 6591.144, 6606.691, 6621.698, 6636.158, 6650.062, 6663.401, 6676.164000000001, 6688.344, 6699.929, 6710.91, 6721.276999999999, 6731.019, 6740.125, 6748.584, 6756.3859999999995, 6763.518, 6769.968000000001, 6775.724, 6780.773, 6785.104, 6788.701999999999, 6791.553000000001, 6793.645, 6794.9619999999995, 6795.491, 6795.214, 6794.118, 6792.186, 6789.401999999999, 6785.7480000000005, 6781.206999999999, 6775.7609999999995, 6769.392, 6762.081, 6753.807, 6744.55, 6734.29, 6723.004, 6710.670999999999, 6697.268, 6682.77, 6667.153, 6650.392, 6632.460999999999, 6613.331999999999, 6592.977, 6571.369000000001, 6548.475, 6524.265, 6498.706999999999, 6471.768, 6443.4130000000005, 6413.606, 6382.311, 6349.486999999999, 6315.097, 6279.097, 6241.446999999999, 6202.098000000001, 6161.007, 6118.124, 6073.399, 6026.78, 5978.213000000001, 5927.642, 5875.008000000001, 5820.25, 5763.303000000001, 5704.103, 5642.58, 5578.6630000000005, 5512.279, 5443.349, 5371.7919999999995, 5297.526, 5220.464, 5140.515, 5057.589, 4971.585, 4882.405, 4789.946, 4694.102, 4594.763, 4491.816, 4385.147, 4274.64, 4160.177, 4041.637, 3918.903, 3791.857, 3660.384, 3524.373, 3383.722, 3238.3320000000003, 3088.12, 2933.0190000000002, 2772.9770000000003, 2607.967, 2437.991, 2263.081, 2083.312, 1898.8010000000002, 1709.72, 1516.2920000000001, 1318.807, 1117.618, 913.1469999999999, 705.883, 496.38199999999995, 285.259, 73.18, -139.15, -351.0, -561.629, -770.305, -976.32, -1179.009, -1377.756, -1572.014, -1761.307, -1945.235, -2123.475, -2295.78, -2461.972, -2621.94, -2775.63, -2923.039, -3064.2090000000003, -3199.216, -3328.167, -3451.192, -3568.4390000000003, -3680.072, -3786.258, -3887.176, -3983.007, -4073.929, -4160.124, -4241.77, -4319.039000000001, -4392.101, -4461.122, -4526.259, -4587.667, -4645.4929999999995, -4699.88, -4750.962, -4798.87, -4843.728, -4885.655, -4924.765, -4961.165, -4994.96, -5026.246, -5055.12, -5081.669, -5105.981, -5128.1359999999995, -5148.212, -5166.282999999999, -5182.42, -5196.692, -5209.162, -5219.892, -5228.942, -5236.3679999999995, -5242.223, -5246.559, -5249.4259999999995, -5250.871, -5250.94, -5249.675, -5247.119000000001, -5243.311, -5238.291, -5232.093, -5224.755999999999, -5216.311, -5206.791, -5196.229, -5184.653, -5172.094, -5158.579000000001, -5144.135, -5128.788, -5112.564, -5095.485, -5077.577, -5058.86, -5039.358, -5019.09, -4998.077, -4976.339, -4953.895, -4930.762, -4906.959, -4882.502, -4857.407999999999, -4831.694, -4805.375, -4778.465, -4750.98, -4722.934, -4694.340999999999, -4665.213, -4635.565, -4605.407, -4574.754, -4543.616, -4512.005, -4479.932, -4447.409000000001, -4414.445, -4381.052, -4347.2390000000005, -4313.016, -4278.392, -4243.378, -4207.981, -4172.210999999999, -4136.076, -4099.584, -4062.745, -4025.565, -3988.054, -3950.217, -3912.063, -3873.598, -3834.83, -3795.7659999999996, -3756.413, -3716.776, -3676.863, -3636.68, -3596.2329999999997, -3555.528, -3514.571, -3473.368, -3431.9240000000004, -3390.244, -3348.336, -3306.203, -3263.85, -3221.284, -3178.508, -3135.5290000000005, -3092.35, -3048.9759999999997, -3005.413, -2961.664, -2917.7340000000004, -2873.627, -2829.348, -2784.901, -2740.29, -2695.5190000000002, -2650.592, -2605.513, -2560.285, -2514.9139999999998, -2469.402, -2423.7529999999997, -2377.971, -2332.0589999999997, -2286.02, -2239.859, -2193.5789999999997, -2147.1820000000002, -2100.673, -2054.054, -2007.329, -1960.5, -1913.5720000000001, -1866.546, -1819.4270000000001, -1772.2160000000001, -1724.918, -1677.5339999999999, -1630.068, -1582.5220000000002, -1534.9, -1487.203, -1439.435, -1391.599, -1343.6970000000001, -1295.732, -1247.705, -1199.621, -1151.481, -1103.288, -1055.0439999999999, -1006.753, -958.415, -910.034, -861.612, -813.1510000000001, -764.655, -716.1239999999999, -667.561, -618.969, -570.35, -521.706, -473.039, -424.352, -375.64599999999996, -326.92400000000004, -278.187, -229.43900000000002, -180.68099999999998, -131.915, -83.14399999999999, -34.368, 14.408, 63.185, 111.959, 160.72799999999998, 209.49099999999999, 258.246, 306.99, 355.721, 404.439, 453.14, 501.82300000000004, 550.485, 599.126, 647.743, 696.3330000000001, 744.8960000000001, 793.43, 841.931, 890.3989999999999, 938.832, 987.2280000000001, 1035.5839999999998, 1083.9, 1132.173, 1180.401, 1228.583, 1276.7169999999999, 1324.8, 1372.8310000000001, 1420.809, 1468.731, 1516.595, 1564.4, 1612.144, 1659.8239999999998, 1707.44, 1754.989, 1802.47, 1849.88, 1897.2179999999998, 1944.4820000000002, 1991.67, 2038.781, 2085.812, 2132.761, 2179.627, 2226.408, 2273.1020000000003, 2319.7070000000003, 2366.221, 2412.643, 2458.97, 2505.2, 2551.333, 2597.365, 2643.295, 2689.1209999999996, 2734.841, 2780.453, 2825.955, 2871.345, 2916.6220000000003, 2961.783, 3006.8259999999996, 3051.75, 3096.551, 3141.23, 3185.782, 3230.2059999999997, 3274.5009999999997, 3318.664, 3362.692, 3406.585, 3450.34, 3493.954, 3537.426, 3580.7529999999997, 3623.933, 3666.965, 3709.845, 3752.572, 3795.143, 3837.5570000000002, 3879.81, 3921.901, 3963.828, 4005.587, 4047.177, 4088.595, 4129.839, 4170.906, 4211.794, 4252.501, 4293.024, 4333.36, 4373.5070000000005, 4413.463, 4453.224, 4492.788, 4532.153, 4571.316, 4610.274, 4649.024, 4687.563, 4725.89, 4764.0, 4801.892, 4839.562, 4877.0070000000005, 4914.224, 4951.21, 4987.962, 5024.477, 5060.752, 5096.784000000001, 5132.569, 5168.105, 5203.387, 5238.413, 5273.179, 5307.682, 5341.918000000001, 5375.884, 5409.575, 5442.99, 5476.121999999999, 5508.969, 5541.528, 5573.794, 5605.764, 5637.432, 5668.795999999999, 5699.852, 5730.594, 5761.019, 5791.121999999999, 5820.899, 5850.345, 5879.456, 5908.228, 5936.655, 5964.732, 5992.456, 6019.821, 6046.821, 6073.453, 6099.709, 6125.585999999999, 6151.078, 6176.179, 6200.883000000001, 6225.186, 6249.08, 6272.56, 6295.621, 6318.255, 6340.456, 6362.219, 6383.536, 6404.4, 6424.806, 6444.745, 6464.210999999999, 6483.196999999999, 6501.694, 6519.696, 6537.194, 6554.181, 6570.648, 6586.5869999999995, 6601.99, 6616.848000000001, 6631.151999999999, 6644.892, 6658.061, 6670.647, 6682.642, 6694.035, 6704.816, 6714.975, 6724.501, 6733.382, 6741.608, 6749.1669999999995, 6756.047, 6762.236, 6767.721, 6772.4890000000005, 6776.526999999999, 6779.821999999999, 6782.36, 6784.126, 6785.106, 6785.284000000001, 6784.645, 6783.174, 6780.852, 6777.665, 6773.593000000001, 6768.619000000001, 6762.726, 6755.893, 6748.1, 6739.328, 6729.556, 6718.7609999999995, 6706.923000000001, 6694.017, 6680.02, 6664.908, 6648.656, 6631.236, 6612.6230000000005, 6592.786999999999, 6571.701, 6549.3330000000005, 6525.653, 6500.629, 6474.228, 6446.415, 6417.154, 6386.409000000001, 6354.14, 6320.308000000001, 6284.871, 6247.786, 6209.009, 6168.493, 6126.191, 6082.0509999999995, 6036.022, 5988.05, 5938.076999999999, 5886.047, 5831.898, 5775.565, 5716.984, 5656.085, 5592.797, 5527.047, 5458.755999999999, 5387.844, 5314.228, 5237.821, 5158.532999999999, 5076.271, 4990.937, 4902.432, 4810.653, 4715.492, 4616.84, 4514.585, 4408.611, 4298.8009999999995, 4185.036, 4067.196, 3945.1620000000003, 3818.8140000000003, 3688.0370000000003, 3552.718, 3412.75, 3268.0359999999996, 3118.488, 2964.0359999999996, 2804.623, 2640.2209999999995, 2470.822, 2296.456, 2117.192, 1933.139, 1744.46, 1551.372, 1354.156, 1153.1580000000001, 948.789, 741.5310000000001, 531.933, 320.60200000000003, 108.20100000000001, -104.568, -316.976, -528.2819999999999, -737.748, -944.6619999999999, -1148.351, -1348.191, -1543.6229999999998, -1734.1629999999998, -1919.3970000000002, -2098.994, -2272.692, -2440.3070000000002, -2601.716, -2756.8590000000004, -2905.724, -3048.348, -3184.801, -3315.1859999999997, -3439.6279999999997, -3558.2740000000003, -3671.283, -3778.823, -3881.072, -3978.2059999999997, -4070.408, -4157.856, -4240.726, -4319.196, -4393.2390000000005, -4463.6, -4529.86, -4592.366, -4651.266, -4706.702, -4758.811, -4807.723, -4853.563, -4896.451, -4936.501, -4973.821, -5008.515, -5040.684, -5070.420999999999, -5097.815, -5122.955, -5145.92, -5166.791, -5185.642, -5202.542, -5217.562, -5230.766, -5242.215999999999, -5251.972, -5260.09, -5266.625, -5271.629, -5275.15, -5277.238, -5277.938, -5277.293000000001, -5275.346, -5272.1359999999995, -5267.703, -5262.0830000000005, -5255.312, -5247.424, -5238.452, -5228.428, -5217.380999999999, -5205.342000000001, -5192.339, -5178.397, -5163.545, -5147.807, -5131.207, -5113.769, -5095.516, -5076.469, -5056.648, -5036.076, -5014.771, -4992.753, -4970.039000000001, -4946.648, -4922.598, -4897.904, -4872.583, -4846.65, -4820.122, -4793.0109999999995, -4765.334, -4737.104, -4708.333, -4679.036, -4649.225, -4618.912, -4588.109, -4556.8279999999995, -4525.08, -4492.876, -4460.226, -4427.142, -4393.633, -4359.709, -4325.38, -4290.655, -4255.543, -4220.054, -4184.195, -4147.975, -4111.402, -4074.485, -4037.2309999999998, -3999.6479999999997, -3961.743, -3923.5240000000003, -3884.998, -3846.171, -3807.051, -3767.6440000000002, -3727.9559999999997, -3687.995, -3647.765, -3607.2740000000003, -3566.527, -3525.53, -3484.289, -3442.809, -3401.095, -3359.1540000000005, -3316.99, -3274.6090000000004, -3232.015, -3189.2140000000004, -3146.21, -3103.008, -3059.612, -3016.027, -2972.259, -2928.31, -2884.1859999999997, -2839.8909999999996, -2795.428, -2750.802, -2706.018, -2661.078, -2615.987, -2570.749, -2525.367, -2479.845, -2434.187, -2388.397, -2342.4770000000003, -2296.431, -2250.263, -2203.9770000000003, -2157.575, -2111.06, -2064.436, -2017.707, -1970.874, -1923.942, -1876.9129999999998, -1829.79, -1782.5770000000002, -1735.276, -1687.89, -1640.421, -1592.874, -1545.25, -1497.5520000000001, -1449.783, -1401.945, -1354.0420000000001, -1306.075, -1258.048, -1209.963, -1161.822, -1113.628, -1065.383, -1017.091, -968.752, -920.37, -871.947, -823.4860000000001, -774.988, -726.456, -677.893, -629.3, -580.679, -532.034, -483.365, -434.676, -385.969, -337.245, -288.507, -239.757, -190.997, -142.22899999999998, -93.455, -44.677, 4.103, 52.882, 101.65899999999999, 150.43200000000002, 199.19799999999998, 247.956, 296.704, 345.44, 394.161, 442.866, 491.55400000000003, 540.221, 588.867, 637.488, 686.084, 734.6519999999999, 783.191, 831.699, 880.173, 928.612, 977.0139999999999, 1025.377, 1073.7, 1121.98, 1170.215, 1218.404, 1266.545, 1314.636, 1362.675, 1410.661, 1458.5910000000001, 1506.463, 1554.277, 1602.029, 1649.719, 1697.344, 1744.902, 1792.392, 1839.8120000000001, 1887.16, 1934.433, 1981.631, 2028.7520000000002, 2075.7929999999997, 2122.752, 2169.629, 2216.42, 2263.125, 2309.74, 2356.265, 2402.698, 2449.036, 2495.277, 2541.4210000000003, 2587.464, 2633.405, 2679.242, 2724.973, 2770.5959999999995, 2816.11, 2861.511, 2906.7990000000004, 2951.9709999999995, 2997.026, 3041.96, 3086.7729999999997, 3131.462, 3176.025, 3220.46, 3264.7659999999996, 3308.9390000000003, 3352.978, 3396.881, 3440.6459999999997, 3484.27, 3527.7509999999997, 3571.0879999999997, 3614.278, 3657.3190000000004, 3700.208, 3742.9440000000004, 3785.5240000000003, 3827.946, 3870.2070000000003, 3912.3059999999996, 3954.24, 3996.006, 4037.6020000000003, 4079.026, 4120.276, 4161.348, 4202.241, 4242.9529999999995, 4283.479, 4323.819, 4363.969, 4403.927, 4443.689, 4483.255, 4522.62, 4561.782999999999, 4600.74, 4639.488, 4678.026, 4716.349, 4754.456, 4792.343, 4830.0070000000005, 4867.445, 4904.655, 4941.633, 4978.376, 5014.880999999999, 5051.145, 5087.165, 5122.937, 5158.458, 5193.725, 5228.735, 5263.483, 5297.965999999999, 5332.182, 5366.126, 5399.794, 5433.184, 5466.29, 5499.11, 5531.64, 5563.875, 5595.812, 5627.446, 5658.774, 5689.791, 5720.493, 5750.876, 5780.935, 5810.666, 5840.065, 5869.125, 5897.844, 5926.215999999999, 5954.236999999999, 5981.901, 6009.203, 6036.139, 6062.701999999999, 6088.888000000001, 6114.691999999999, 6140.108, 6165.129, 6189.751, 6213.968000000001, 6237.774, 6261.161999999999, 6284.126, 6306.661, 6328.759, 6350.415, 6371.621, 6392.371, 6412.656999999999, 6432.473000000001, 6451.811, 6470.664000000001, 6489.025, 6506.885, 6524.236, 6541.071, 6557.380999999999, 6573.156999999999, 6588.392, 6603.075, 6617.1990000000005, 6630.754, 6643.73, 6656.116999999999, 6667.906, 6679.0869999999995, 6689.648, 6699.58, 6708.87, 6717.509, 6725.484, 6732.784000000001, 6739.396, 6745.308000000001, 6750.507, 6754.98, 6758.713000000001, 6761.693, 6763.905, 6765.334, 6765.965999999999, 6765.785, 6764.774, 6762.919, 6760.201, 6756.603, 6752.108, 6746.696, 6740.351, 6733.05, 6724.774, 6715.5019999999995, 6705.213000000001, 6693.884, 6681.493, 6668.016, 6653.43, 6637.706999999999, 6620.821999999999, 6602.7480000000005, 6583.4580000000005, 6562.922, 6541.11, 6517.991999999999, 6493.536999999999, 6467.709, 6440.475, 6411.799, 6381.644, 6349.972, 6316.744000000001, 6281.918000000001, 6245.45, 6207.297, 6167.411, 6125.746, 6082.25, 6036.874, 5989.561, 5940.255, 5888.899, 5835.431, 5779.789000000001, 5721.906, 5661.714, 5599.141, 5534.115, 5466.556, 5396.385, 5323.518, 5247.871, 5169.351, 5087.865, 5003.318, 4915.609, 4824.634, 4730.287, 4632.458, 4531.032999999999, 4425.899, 4316.936, 4204.027, 4087.0490000000004, 3965.882, 3840.407, 3710.506, 3576.065, 3436.975, 3293.138, 3144.462, 2990.873, 2832.313, 2668.7459999999996, 2500.163, 2326.5879999999997, 2148.08, 1964.746, 1776.737, 1584.266, 1387.602, 1187.0819999999999, 983.11, 776.158, 566.765, 355.534, 143.12, -69.78, -282.437, -494.11199999999997, -704.064, -911.578, -1115.973, -1316.6170000000002, -1512.945, -1704.4579999999999, -1890.737, -2071.433, -2246.282, -2415.083, -2577.71, -2734.09, -2884.2059999999997, -3028.087, -3165.798, -3297.438, -3423.1290000000004, -3543.012, -3657.2459999999996, -3765.995, -3869.4359999999997, -3967.744, -4061.1009999999997, -4149.683, -4233.67, -4313.234, -4388.545, -4459.768, -4527.063, -4590.584, -4650.479, -4706.892, -4759.959, -4809.811, -4856.573, -4900.366, -4941.303, -4979.495, -5015.045999999999, -5048.053, -5078.615, -5106.819, -5132.754, -5156.502, -5178.141, -5197.746, -5215.389, -5231.14, -5245.062, -5257.218000000001, -5267.668000000001, -5276.469, -5283.6759999999995, -5289.343000000001, -5293.516, -5296.246, -5297.576999999999, -5297.555, -5296.22, -5293.6140000000005, -5289.776, -5284.743, -5278.549, -5271.231, -5262.82, -5253.349, -5242.848, -5231.346, -5218.873, -5205.455, -5191.119000000001, -5175.891, -5159.793, -5142.85, -5125.085, -5106.52, -5087.1759999999995, -5067.073, -5046.231, -5024.67, -5002.407999999999, -4979.463, -4955.852, -4931.593, -4906.702, -4881.192, -4855.082, -4828.384, -4801.115, -4773.286, -4744.913, -4716.008, -4686.585, -4656.654, -4626.229, -4595.321, -4563.941, -4532.101, -4499.811, -4467.082, -4433.924, -4400.346, -4366.36, -4331.972, -4297.194, -4262.035, -4226.501, -4190.603, -4154.348, -4117.745, -4080.801, -4043.5240000000003, -4005.921, -3968.0, -3929.7690000000002, -3891.2329999999997, -3852.4, -3813.277, -3773.87, -3734.185, -3694.2290000000003, -3654.007, -3613.527, -3572.7929999999997, -3531.8109999999997, -3490.587, -3449.127, -3407.4359999999997, -3365.518, -3323.38, -3281.026, -3238.462, -3195.691, -3152.72, -3109.552, -3066.192, -3022.645, -2978.915, -2935.007, -2890.9240000000004, -2846.671, -2802.2529999999997, -2757.672, -2712.934, -2668.0409999999997, -2622.9990000000003, -2577.81, -2532.478, -2487.007, -2441.401, -2395.663, -2349.7960000000003, -2303.805, -2257.692, -2211.4610000000002, -2165.114, -2118.656, -2072.09, -2025.418, -1978.6429999999998, -1931.77, -1884.8, -1837.737, -1790.5829999999999, -1743.342, -1696.017, -1648.609, -1601.1229999999998, -1553.56, -1505.924, -1458.217, -1410.441, -1362.6, -1314.6960000000001, -1266.732, -1218.7089999999998, -1170.631, -1122.501, -1074.319, -1026.09, -977.814, -929.4960000000001, -881.1360000000001, -832.738, -784.304, -735.835, -687.335, -638.805, -590.248, -541.6659999999999, -493.061, -444.435, -395.79, -347.129, -298.454, -249.766, -201.06900000000002, -152.363, -103.65100000000001, -54.93600000000001, -6.218, 42.498999999999995, 91.215, 139.92600000000002, 188.63099999999997, 237.328, 286.015, 334.69, 383.351, 431.996, 480.62300000000005, 529.231, 577.816, 626.379, 674.915, 723.425, 771.905, 820.3539999999999, 868.7689999999999, 917.15, 965.495, 1013.8, 1062.065, 1110.288, 1158.4669999999999, 1206.599, 1254.684, 1302.719, 1350.7020000000002, 1398.632, 1446.506, 1494.3239999999998, 1542.0829999999999, 1589.78, 1637.4160000000002, 1684.986, 1732.491, 1779.9270000000001, 1827.293, 1874.588, 1921.809, 1968.954, 2016.0220000000002, 2063.01, 2109.9179999999997, 2156.742, 2203.482, 2250.135, 2296.7, 2343.174, 2389.555, 2435.843, 2482.034, 2528.127, 2574.12, 2620.011, 2665.798, 2711.48, 2757.054, 2802.518, 2847.87, 2893.1090000000004, 2938.2329999999997, 2983.238, 3028.1240000000003, 3072.888, 3117.5290000000005, 3162.0440000000003, 3206.4309999999996, 3250.688, 3294.813, 3338.804, 3382.659, 3426.3759999999997, 3469.952, 3513.385, 3556.6740000000004, 3599.816, 3642.808, 3685.6490000000003, 3728.337, 3770.869, 3813.242, 3855.455, 3897.505, 3939.39, 3981.107, 4022.655, 4064.03, 4105.23, 4146.253, 4187.097, 4227.758, 4268.234, 4308.523, 4348.623, 4388.529, 4428.241, 4467.755, 4507.068, 4546.178, 4585.082, 4623.778, 4662.2609999999995, 4700.531, 4738.583, 4776.414000000001, 4814.022, 4851.405, 4888.557, 4925.478, 4962.163, 4998.609, 5034.813, 5070.773, 5106.484, 5141.943, 5177.148, 5212.093, 5246.776999999999, 5281.195, 5315.344, 5349.22, 5382.82, 5416.14, 5449.175, 5481.923000000001, 5514.38, 5546.54, 5578.401, 5609.9580000000005, 5641.206999999999, 5672.144, 5702.765, 5733.064, 5763.0380000000005, 5792.683000000001, 5821.993, 5850.964, 5879.590999999999, 5907.869000000001, 5935.794, 5963.36, 5990.562, 6017.396, 6043.855, 6069.935, 6095.629, 6120.933000000001, 6145.840999999999, 6170.347, 6194.445, 6218.128000000001, 6241.391, 6264.227, 6286.630999999999, 6308.595, 6330.113, 6351.177, 6371.781999999999, 6391.92, 6411.584, 6430.766, 6449.459, 6467.656, 6485.347, 6502.525, 6519.183000000001, 6535.311, 6550.901, 6565.944, 6580.431, 6594.352, 6607.6990000000005, 6620.4619999999995, 6632.63, 6644.193, 6655.142, 6665.465, 6675.151, 6684.19, 6692.57, 6700.279, 6707.304, 6713.634, 6719.255999999999, 6724.156999999999, 6728.321999999999, 6731.738, 6734.392, 6736.268, 6737.352, 6737.6269999999995, 6737.079000000001, 6735.691, 6733.445, 6730.326, 6726.314, 6721.392, 6715.541, 6708.74, 6700.97, 6692.210999999999, 6682.44, 6671.6359999999995, 6659.776, 6646.835999999999, 6632.7919999999995, 6617.62, 6601.2919999999995, 6583.781999999999, 6565.062, 6545.103, 6523.8769999999995, 6501.351, 6477.495, 6452.275, 6425.656, 6397.603, 6368.08, 6337.048000000001, 6304.467, 6270.297, 6234.496, 6197.017, 6157.815, 6116.843000000001, 6074.05, 6029.3859999999995, 5982.795999999999, 5934.223000000001, 5883.61, 5830.897, 5776.02, 5718.914000000001, 5659.509, 5597.736, 5533.52, 5466.785, 5397.45, 5325.432, 5250.646, 5173.001, 5092.403, 5008.7570000000005, 4921.963, 4831.916, 4738.5109999999995, 4641.638, 4541.183, 4437.032999999999, 4329.067, 4217.166, 4101.210999999999, 3981.078, 3856.6490000000003, 3727.803, 3594.426, 3456.407, 3313.645, 3166.047, 3013.535, 2856.0490000000004, 2693.548, 2526.018, 2353.4770000000003, 2175.978, 1993.62, 1806.5510000000002, 1614.969, 1419.139, 1219.384, 1016.102, 809.7539999999999, 600.871, 390.045, 177.925, -34.796, -247.395, -459.12699999999995, -669.263, -877.077, -1081.883, -1283.046, -1479.9879999999998, -1672.204, -1859.2620000000002, -2040.807, -2216.56, -2386.3160000000003, -2549.9320000000002, -2707.3340000000003, -2858.495, -3003.4359999999997, -3142.219, -3274.9359999999997, -3401.7059999999997, -3522.665, -3637.969, -3747.782, -3852.276, -3951.6279999999997, -4046.015, -4135.616, -4220.606, -4301.16, -4377.446, -4449.630999999999, -4517.871, -4582.325, -4643.137, -4700.4529999999995, -4754.407999999999, -4805.134, -4852.758, -4897.398, -4939.17, -4978.184, -5014.544, -5048.349, -5079.695, -5108.675, -5135.372, -5159.871, -5182.25, -5202.587, -5220.95, -5237.41, -5252.031999999999, -5264.88, -5276.013000000001, -5285.486999999999, -5293.359, -5299.68, -5304.501, -5307.871, -5309.8330000000005, -5310.434, -5309.715999999999, -5307.719, -5304.481, -5300.0419999999995, -5294.436, -5287.698, -5279.861, -5270.956999999999, -5261.017, -5250.07, -5238.145, -5225.271, -5211.471, -5196.772, -5181.1990000000005, -5164.775, -5147.524, -5129.467000000001, -5110.626, -5091.02, -5070.6720000000005, -5049.599, -5027.819, -5005.352, -4982.214, -4958.4220000000005, -4933.9929999999995, -4908.943, -4883.286, -4857.039000000001, -4830.214, -4802.827, -4774.89, -4746.417, -4717.420999999999, -4687.916, -4657.91, -4627.418, -4596.45, -4565.018, -4533.1320000000005, -4500.803, -4468.041, -4434.856, -4401.258, -4367.255999999999, -4332.859, -4298.077, -4262.918, -4227.39, -4191.502, -4155.263, -4118.679, -4081.759, -4044.51, -4006.94, -3969.055, -3930.863, -3892.3709999999996, -3853.585, -3814.513, -3775.159, -3735.531, -3695.634, -3655.475, -3615.06, -3574.3940000000002, -3533.4829999999997, -3492.333, -3450.948, -3409.3340000000003, -3367.4970000000003, -3325.441, -3283.172, -3240.6940000000004, -3198.012, -3155.131, -3112.055, -3068.789, -3025.3379999999997, -2981.705, -2937.895, -2893.913, -2849.761, -2805.446, -2760.969, -2716.337, -2671.551, -2626.616, -2581.536, -2536.314, -2490.955, -2445.4610000000002, -2399.8360000000002, -2354.084, -2308.2070000000003, -2262.21, -2216.095, -2169.866, -2123.526, -2077.078, -2030.526, -1983.871, -1937.119, -1890.27, -1843.329, -1796.297, -1749.1789999999999, -1701.977, -1654.693, -1607.33, -1559.892, -1512.381, -1464.7979999999998, -1417.148, -1369.433, -1321.655, -1273.816, -1225.92, -1177.968, -1129.964, -1081.9089999999999, -1033.807, -985.658, -937.467, -889.235, -840.9639999999999, -792.6560000000001, -744.315, -695.942, -647.54, -599.11, -550.655, -502.17699999999996, -453.67800000000005, -405.16, -356.626, -308.078, -259.517, -210.946, -162.36700000000002, -113.78200000000001, -65.193, -16.601, 31.99, 80.58, 129.165, 177.745, 226.317, 274.879, 323.42900000000003, 371.965, 420.486, 468.98900000000003, 517.4730000000001, 565.935, 614.373, 662.7869999999999, 711.173, 759.5310000000001, 807.857, 856.1510000000001, 904.41, 952.633, 1000.818, 1048.962, 1097.0639999999999, 1145.122, 1193.135, 1241.1, 1289.015, 1336.88, 1384.691, 1432.4470000000001, 1480.1470000000002, 1527.787, 1575.368, 1622.886, 1670.34, 1717.7279999999998, 1765.0479999999998, 1812.299, 1859.4779999999998, 1906.5829999999999, 1953.614, 2000.567, 2047.442, 2094.236, 2140.947, 2187.573, 2234.114, 2280.565, 2326.927, 2373.197, 2419.373, 2465.453, 2511.435, 2557.317, 2603.098, 2648.775, 2694.347, 2739.8109999999997, 2785.1659999999997, 2830.41, 2875.54, 2920.555, 2965.453, 3010.2309999999998, 3054.887, 3099.421, 3143.828, 3188.1090000000004, 3232.259, 3276.278, 3320.163, 3363.9120000000003, 3407.5229999999997, 3450.994, 3494.322, 3537.506, 3580.5429999999997, 3623.43, 3666.167, 3708.75, 3751.178, 3793.447, 3835.5559999999996, 3877.502, 3919.283, 3960.897, 4002.34, 4043.612, 4084.7090000000003, 4125.628, 4166.3679999999995, 4206.9259999999995, 4247.299, 4287.484, 4327.48, 4367.282999999999, 4406.891, 4446.302, 4485.5109999999995, 4524.518, 4563.318, 4601.909000000001, 4640.288, 4678.4529999999995, 4716.4, 4754.126, 4791.629, 4828.905, 4865.952, 4902.766, 4939.345, 4975.684, 5011.781, 5047.6320000000005, 5083.235, 5118.585, 5153.68, 5188.515, 5223.088, 5257.395, 5291.432, 5325.196, 5358.683000000001, 5391.889, 5424.81, 5457.441999999999, 5489.781999999999, 5521.825, 5553.568, 5585.005999999999, 5616.135, 5646.95, 5677.4490000000005, 5707.624, 5737.475, 5766.993, 5796.1759999999995, 5825.018, 5853.515, 5881.661999999999, 5909.453, 5936.885, 5963.951, 5990.646, 6016.965, 6042.903, 6068.454000000001, 6093.611999999999, 6118.371999999999, 6142.728, 6166.673000000001, 6190.201, 6213.307, 6235.984, 6258.226, 6280.025, 6301.376, 6322.271, 6342.703, 6362.665, 6382.149, 6401.148, 6419.655, 6437.661, 6455.159000000001, 6472.14, 6488.596, 6504.519, 6519.899, 6534.728, 6548.996, 6562.694, 6575.813, 6588.343000000001, 6600.273, 6611.593000000001, 6622.2919999999995, 6632.36, 6641.786, 6650.557, 6658.6630000000005, 6666.090999999999, 6672.829000000001, 6678.8640000000005, 6684.184, 6688.774, 6692.621999999999, 6695.713000000001, 6698.031999999999, 6699.564, 6700.295, 6700.2080000000005, 6699.286999999999, 6697.516, 6694.8769999999995, 6691.353, 6686.9259999999995, 6681.575, 6675.283, 6668.028, 6659.791, 6650.5509999999995, 6640.284000000001, 6628.969, 6616.5830000000005, 6603.1, 6588.496, 6572.745, 6555.821, 6537.696, 6518.34, 6497.726, 6475.821999999999, 6452.596, 6428.015, 6402.045999999999, 6374.653, 6345.8, 6315.448, 6283.558000000001, 6250.09, 6215.0, 6178.244000000001, 6139.779, 6099.554, 6057.52, 6013.6269999999995, 5967.821, 5920.045999999999, 5870.244000000001, 5818.355, 5764.315, 5708.062, 5649.524, 5588.632, 5525.314, 5459.491999999999, 5391.085, 5320.013000000001, 5246.188, 5169.521, 5089.919, 5007.287, 4921.524, 4832.528, 4740.191, 4644.404, 4545.056, 4442.029, 4335.206, 4224.467000000001, 4109.692, 3990.757, 3867.5429999999997, 3739.928, 3607.798, 3471.039, 3329.5490000000004, 3183.232, 3032.01, 2875.8140000000003, 2714.6040000000003, 2548.361, 2377.094, 2200.855, 2019.731, 1833.864, 1643.444, 1448.724, 1250.021, 1047.72, 842.2719999999999, 634.198, 424.082, 212.563, 0.32799999999999996, -211.905, -423.398, -633.413, -841.2280000000001, -1046.153, -1247.547, -1444.8229999999999, -1637.47, -1825.043, -2007.182, -2183.595, -2354.067, -2518.449, -2676.657, -2828.655, -2974.46, -3114.1259999999997, -3247.74, -3375.4159999999997, -3497.289, -3613.51, -3724.239, -3829.6479999999997, -3929.91, -4025.202, -4115.702, -4201.584, -4283.021, -4360.219, -4433.232, -4502.329000000001, -4567.629, -4629.279, -4687.420999999999, -4742.195, -4793.73, -4842.152, -4887.582, -4930.134, -4969.919, -5007.04, -5041.599, -5073.69, -5103.405, -5130.83, -5156.049, -5179.141, -5200.181, -5219.241, -5236.391, -5251.695, -5265.217, -5277.018, -5287.154, -5295.68, -5302.65, -5308.113, -5312.118, -5314.71, -5315.935, -5315.834, -5314.4490000000005, -5311.818, -5307.98, -5302.969, -5296.821, -5289.569, -5281.245, -5271.879, -5261.5019999999995, -5250.143, -5237.8279999999995, -5224.584, -5210.436, -5195.409000000001, -5179.528, -5162.814, -5145.29, -5126.977, -5107.896, -5088.069, -5067.512, -5046.244000000001, -5024.285, -5001.651, -4978.36, -4954.428, -4929.87, -4904.702, -4878.94, -4852.597, -4825.688, -4798.226, -4770.225, -4741.696, -4712.653, -4683.108, -4653.073, -4622.559, -4591.577, -4560.138, -4528.253, -4495.932, -4463.184, -4430.021, -4396.45, -4362.482, -4328.125, -4293.387, -4258.279, -4222.807, -4186.98, -4150.806, -4114.293, -4077.448, -4040.2790000000005, -4002.7929999999997, -3964.9970000000003, -3926.897, -3888.5009999999997, -3849.815, -3810.845, -3771.599, -3732.0809999999997, -3692.298, -3652.256, -3611.961, -3571.4179999999997, -3530.633, -3489.611, -3448.357, -3406.8779999999997, -3365.177, -3323.26, -3281.132, -3238.797, -3196.261, -3153.527, -3110.6009999999997, -3067.487, -3024.1890000000003, -2980.711, -2937.059, -2893.235, -2849.244, -2805.09, -2760.777, -2716.309, -2671.6890000000003, -2626.922, -2582.011, -2536.96, -2491.771, -2446.45, -2400.998, -2355.42, -2309.719, -2263.8979999999997, -2217.9610000000002, -2171.91, -2125.75, -2079.482, -2033.11, -1986.6370000000002, -1940.066, -1893.4, -1846.642, -1799.795, -1752.861, -1705.844, -1658.746, -1611.569, -1564.318, -1516.993, -1469.598, -1422.136, -1374.608, -1327.019, -1279.369, -1231.661, -1183.899, -1136.0839999999998, -1088.219, -1040.306, -992.3480000000001, -944.347, -896.305, -848.2239999999999, -800.1080000000001, -751.957, -703.7739999999999, -655.562, -607.323, -559.059, -510.77099999999996, -462.463, -414.13599999999997, -365.793, -317.435, -269.064, -220.68400000000003, -172.295, -123.899, -75.5, -27.098000000000003, 21.304000000000002, 69.704, 118.101, 166.49099999999999, 214.875, 263.248, 311.61, 359.958, 408.291, 456.60699999999997, 504.903, 553.178, 601.43, 649.6569999999999, 697.8580000000001, 746.03, 794.171, 842.279, 890.3539999999999, 938.3919999999999, 986.3919999999999, 1034.353, 1082.272, 1130.147, 1177.9769999999999, 1225.76, 1273.493, 1321.1760000000002, 1368.806, 1416.381, 1463.901, 1511.362, 1558.7620000000002, 1606.101, 1653.3770000000002, 1700.586, 1747.729, 1794.8020000000001, 1841.8039999999999, 1888.733, 1935.5870000000002, 1982.365, 2029.0639999999999, 2075.683, 2122.22, 2168.672, 2215.0389999999998, 2261.3179999999998, 2307.507, 2353.604, 2399.6079999999997, 2445.5170000000003, 2491.328, 2537.04, 2582.651, 2628.159, 2673.562, 2718.857, 2764.0440000000003, 2809.12, 2854.083, 2898.9309999999996, 2943.6620000000003, 2988.2740000000003, 3032.765, 3077.133, 3121.3759999999997, 3165.491, 3209.478, 3253.333, 3297.055, 3340.6409999999996, 3384.09, 3427.3990000000003, 3470.565, 3513.5879999999997, 3556.4640000000004, 3599.192, 3641.768, 3684.192, 3726.46, 3768.57, 3810.52, 3852.308, 3893.9309999999996, 3935.387, 3976.673, 4017.7870000000003, 4058.7270000000003, 4099.49, 4140.073, 4180.475, 4220.692, 4260.721, 4300.562, 4340.209, 4379.662, 4418.917, 4457.972, 4496.823, 4535.468, 4573.905, 4612.13, 4650.14, 4687.933, 4725.505, 4762.854, 4799.976, 4836.8679999999995, 4873.528, 4909.952, 4946.137, 4982.08, 5017.776, 5053.224, 5088.42, 5123.359, 5158.04, 5192.458, 5226.609, 5260.49, 5294.098000000001, 5327.428000000001, 5360.476, 5393.24, 5425.714, 5457.895, 5489.78, 5521.363, 5552.64, 5583.608, 5614.262, 5644.598000000001, 5674.611, 5704.297, 5733.65, 5762.668000000001, 5791.343000000001, 5819.673000000001, 5847.651, 5875.273, 5902.534000000001, 5929.428000000001, 5955.95, 5982.095, 6007.857, 6033.23, 6058.21, 6082.789000000001, 6106.9619999999995, 6130.723000000001, 6154.066, 6176.985, 6199.472, 6221.522, 6243.1269999999995, 6264.281999999999, 6284.978, 6305.209, 6324.967, 6344.246, 6363.036999999999, 6381.331999999999, 6399.124, 6416.404, 6433.165, 6449.397, 6465.092, 6480.241, 6494.835, 6508.8640000000005, 6522.319, 6535.191, 6547.469, 6559.143, 6570.203, 6580.6359999999995, 6590.434, 6599.5830000000005, 6608.073, 6615.891, 6623.026, 6629.465, 6635.194, 6640.201, 6644.473000000001, 6647.994000000001, 6650.75, 6652.727, 6653.909000000001, 6654.281, 6653.826999999999, 6652.53, 6650.3730000000005, 6647.338000000001, 6643.408, 6638.564, 6632.785, 6626.053000000001, 6618.347, 6609.646, 6599.928000000001, 6589.170999999999, 6577.352, 6564.445, 6550.427, 6535.271, 6518.953, 6501.443, 6482.715, 6462.736999999999, 6441.479, 6418.911999999999, 6395.001, 6369.713000000001, 6343.014, 6314.865, 6285.231, 6254.071, 6221.345, 6187.012, 6151.026, 6113.343000000001, 6073.915, 6032.694, 5989.629, 5944.664000000001, 5897.746, 5848.818, 5797.818, 5744.686, 5689.355, 5631.759, 5571.826999999999, 5509.486, 5444.661, 5377.271, 5307.234, 5234.465999999999, 5158.876, 5080.373, 4998.861, 4914.2390000000005, 4826.407999999999, 4735.259, 4640.684, 4542.57, 4440.8009999999995, 4335.2609999999995, 4225.829000000001, 4112.383, 3994.802, 3872.9640000000004, 3746.7490000000003, 3616.038, 3480.7209999999995, 3340.69, 3195.85, 3046.117, 2891.423, 2731.72, 2566.987, 2397.2270000000003, 2222.486, 2042.845, 1858.434, 1669.4379999999999, 1476.101, 1278.726, 1077.6889999999999, 873.431, 666.461, 457.352, 246.737, 35.292, -176.269, -387.215, -596.807, -804.323, -1009.071, -1210.404, -1407.7320000000002, -1600.531, -1788.354, -1970.8239999999998, -2147.646, -2318.593, -2483.509, -2642.2990000000004, -2794.921, -2941.385, -3081.738, -3216.0640000000003, -3344.47, -3467.086, -3584.062, -3695.555, -3801.732, -3902.7670000000003, -3998.833, -4090.107, -4176.762, -4258.971, -4336.901, -4410.717000000001, -4480.575, -4546.6320000000005, -4609.034000000001, -4667.925, -4723.441, -4775.713, -4824.8679999999995, -4871.024, -4914.299, -4954.799, -4992.630999999999, -5027.896, -5060.688, -5091.098, -5119.213, -5145.1179999999995, -5168.889, -5190.603, -5210.334, -5228.149, -5244.1140000000005, -5258.2919999999995, -5270.744000000001, -5281.526999999999, -5290.696, -5298.303000000001, -5304.4, -5309.034000000001, -5312.2519999999995, -5314.098000000001, -5314.6140000000005, -5313.842, -5311.82, -5308.5869999999995, -5304.178000000001, -5298.628000000001, -5291.969, -5284.235, -5275.456999999999, -5265.6630000000005, -5254.883000000001, -5243.144, -5230.472, -5216.894, -5202.433, -5187.113, -5170.959, -5153.991, -5136.231, -5117.7, -5098.418, -5078.404, -5057.677, -5036.255, -5014.155, -4991.395, -4967.991, -4943.958, -4919.313, -4894.07, -4868.2429999999995, -4841.847, -4814.896, -4787.403, -4759.379, -4730.839, -4701.794, -4672.255, -4642.235, -4611.745, -4580.795, -4549.396, -4517.558, -4485.292, -4452.606, -4419.5109999999995, -4386.015, -4352.129, -4317.86], \"z\": [-1599.129, -1737.642, -1875.378, -2012.057, -2147.652, -2282.145, -2415.515, -2547.751, -2678.841, -2808.777, -2937.551, -3065.16, -3191.6, -3316.87, -3440.97, -3563.902, -3685.6690000000003, -3806.272, -3925.717, -4044.009, -4161.152, -4277.151, -4392.016, -4505.751, -4618.3640000000005, -4729.863, -4840.254, -4949.5470000000005, -5057.748, -5164.866, -5270.911, -5375.889, -5479.809, -5582.681, -5684.5109999999995, -5785.31, -5885.084, -5983.843000000001, -6081.595, -6178.35, -6274.1140000000005, -6368.896, -6462.704000000001, -6555.548000000001, -6647.433000000001, -6738.369000000001, -6828.3640000000005, -6917.424, -7005.559, -7092.775, -7179.081, -7264.482, -7348.988, -7432.605, -7515.34, -7597.2, -7678.191, -7758.321999999999, -7837.599, -7916.028, -7993.616, -8070.369000000001, -8146.294, -8221.396999999999, -8295.683, -8369.16, -8441.832, -8513.706, -8584.788, -8655.083, -8724.597, -8793.336, -8861.304, -8928.507, -8994.951, -9060.64, -9125.58, -9189.775, -9253.23, -9315.952, -9377.943000000001, -9439.209, -9499.755, -9559.584, -9618.702, -9677.113000000001, -9734.821, -9791.83, -9848.144, -9903.768, -9958.706, -10012.962, -10066.539, -10119.442, -10171.675, -10223.24, -10274.142, -10324.384, -10373.971, -10422.904, -10471.189, -10518.827, -10565.823, -10612.18, -10657.902, -10702.99, -10747.448999999999, -10791.282, -10834.491000000002, -10877.08, -10919.051000000001, -10960.408000000001, -11001.153, -11041.288999999999, -11080.818000000001, -11119.743999999999, -11158.069, -11195.796, -11232.928, -11269.466, -11305.413999999999, -11340.774, -11375.548, -11409.739, -11443.348999999998, -11476.38, -11508.835, -11540.715, -11572.024, -11602.763, -11632.935, -11662.54, -11691.582, -11720.063, -11747.983999999999, -11775.348999999998, -11802.157, -11828.412, -11854.115, -11879.268, -11903.872, -11927.931, -11951.445, -11974.415, -11996.845, -12018.735, -12040.086000000001, -12060.902, -12081.181999999999, -12100.93, -12120.146, -12138.831, -12156.988000000001, -12174.617, -12191.721000000001, -12208.3, -12224.356000000002, -12239.889, -12254.903, -12269.396999999999, -12283.373, -12296.832, -12309.776000000002, -12322.205, -12334.121000000001, -12345.525, -12356.419, -12366.802, -12376.677, -12386.044, -12394.905, -12403.26, -12411.11, -12418.457, -12425.301000000001, -12431.643, -12437.485, -12442.826000000001, -12447.668, -12452.002, -12455.848, -12459.198, -12462.052, -12464.411, -12466.275, -12467.646999999999, -12468.525, -12468.911, -12468.805, -12468.208999999999, -12467.122, -12465.545, -12463.48, -12460.926000000001, -12457.883999999998, -12454.355, -12450.339, -12445.836000000001, -12440.847, -12435.374, -12429.415, -12422.972, -12416.045, -12408.633999999998, -12400.74, -12392.363000000001, -12383.503, -12374.161, -12364.338, -12354.032, -12343.245, -12331.976999999999, -12320.228000000001, -12307.998, -12295.288, -12282.097, -12268.427, -12254.277, -12239.646999999999, -12224.537, -12208.948, -12192.88, -12176.332, -12159.303999999998, -12141.798, -12123.812, -12105.347, -12086.403, -12066.98, -12047.077, -12026.695, -12005.833, -11984.492, -11962.671999999999, -11940.372, -11917.591999999999, -11894.332, -11870.591, -11846.371000000001, -11821.67, -11796.488000000001, -11770.825, -11744.68, -11718.055, -11690.947, -11663.357, -11635.285, -11606.73, -11577.691, -11548.169, -11518.163, -11487.673, -11456.698999999999, -11425.239, -11393.293, -11360.861, -11327.943000000001, -11294.538, -11260.645, -11226.263, -11191.393, -11156.034, -11120.185, -11083.845, -11047.014, -11009.691, -10971.876, -10933.568000000001, -10894.765, -10855.468, -10815.675, -10775.386999999999, -10734.601999999999, -10693.319, -10651.538, -10609.257, -10566.476999999999, -10523.195, -10479.411, -10435.125, -10390.334, -10345.039, -10299.239, -10252.931, -10206.116, -10158.792, -10110.959, -10062.614, -10013.758, -9964.39, -9914.507, -9864.108, -9813.194, -9761.761, -9709.81, -9657.34, -9604.347, -9550.833, -9496.794, -9442.23, -9387.14, -9331.521999999999, -9275.375, -9218.697, -9161.488000000001, -9103.745, -9045.466999999999, -8986.653, -8927.302, -8867.411, -8806.979, -8746.005, -8684.485999999999, -8622.423, -8559.812, -8496.652, -8432.942, -8368.679, -8303.863000000001, -8238.491, -8172.562, -8106.0740000000005, -8039.025, -7971.414000000001, -7903.238, -7834.496, -7765.185, -7695.305, -7624.853, -7553.828, -7482.226, -7410.047, -7337.2880000000005, -7263.948, -7190.024, -7115.515, -7040.419, -6964.734, -6888.456999999999, -6811.585999999999, -6734.12, -6656.057, -6577.394, -6498.13, -6418.262, -6337.789000000001, -6256.7080000000005, -6175.017, -6092.715, -6009.8, -5926.269, -5842.121, -5757.354, -5671.965, -5585.954000000001, -5499.316999999999, -5412.054, -5324.1630000000005, -5235.642, -5146.488, -5056.702, -4966.281, -4875.224, -4783.53, -4691.197, -4598.225, -4504.612, -4410.358, -4315.462, -4219.923, -4123.741, -4026.915, -3929.447, -3831.335, -3732.5809999999997, -3633.185, -3533.1490000000003, -3432.474, -3331.1609999999996, -3229.2129999999997, -3126.632, -3023.421, -2919.583, -2815.123, -2710.045, -2604.354, -2498.0570000000002, -2391.158, -2283.667, -2175.592, -2066.9410000000003, -1957.726, -1847.9579999999999, -1737.649, -1626.8129999999999, -1515.4679999999998, -1403.629, -1291.316, -1178.55, -1065.355, -951.7560000000001, -837.7819999999999, -723.4639999999999, -608.835, -493.935, -378.80400000000003, -263.48900000000003, -148.039, -32.510999999999996, 83.035, 198.53099999999998, 313.904, 429.07300000000004, 543.948, 658.43, 772.4119999999999, 885.775, 998.387, 1110.104, 1220.769, 1330.2060000000001, 1438.226, 1544.618, 1649.154, 1751.582, 1851.628, 1948.995, 2043.358, 2134.364, 2221.639, 2304.774, 2383.3379999999997, 2456.8720000000003, 2524.8979999999997, 2586.915, 2642.4120000000003, 2690.8720000000003, 2731.782, 2764.643, 2788.985, 2804.3759999999997, 2810.4440000000004, 2806.884, 2793.4770000000003, 2770.095, 2736.715, 2693.415, 2640.382, 2577.8979999999997, 2506.337, 2426.15, 2337.85, 2241.998, 2139.186, 2030.016, 1915.1, 1795.036, 1670.401, 1541.751, 1409.605, 1274.453, 1136.744, 996.8919999999999, 855.2760000000001, 712.24, 568.092, 423.111, 277.548, 131.624, -14.462, -160.532, -306.432, -452.022, -597.181, -741.802, -885.79, -1029.062, -1171.547, -1313.183, -1453.914, -1593.694, -1732.481, -1870.2420000000002, -2006.9460000000001, -2142.5679999999998, -2277.087, -2410.487, -2542.7529999999997, -2673.873, -2803.84, -2932.6459999999997, -3060.2859999999996, -3186.758, -3312.0609999999997, -3436.195, -3559.1609999999996, -3680.961, -3801.599, -3921.079, -4039.403, -4156.581, -4272.616, -4387.515, -4501.285, -4613.933, -4725.465999999999, -4835.892, -4945.219, -5053.455, -5160.608, -5266.687, -5371.7, -5475.655, -5578.56, -5680.425, -5781.257, -5881.066, -5979.859, -6077.645, -6174.433000000001, -6270.231, -6365.047, -6458.889, -6551.765, -6643.683000000001, -6734.653, -6824.68, -6913.774, -7001.941999999999, -7089.191, -7175.528, -7260.963000000001, -7345.501, -7429.149, -7511.916, -7593.808000000001, -7674.831999999999, -7754.995, -7834.303000000001, -7912.764, -7990.383000000001, -8067.1669999999995, -8143.1230000000005, -8218.257, -8292.574, -8366.081, -8438.784, -8510.689, -8581.801, -8652.127, -8721.671, -8790.44, -8858.438, -8925.671, -8992.145, -9057.863000000001, -9122.832, -9187.056999999999, -9250.543, -9313.293, -9375.314, -9436.609, -9497.184000000001, -9557.042, -9616.189, -9674.629, -9732.365, -9789.402, -9845.745, -9901.398000000001, -9956.364, -10010.648000000001, -10064.254, -10117.185, -10169.445, -10221.038, -10271.968, -10322.238000000001, -10371.851999999999, -10420.813, -10469.125, -10516.791000000001, -10563.815, -10610.198999999999, -10655.948, -10701.063999999998, -10745.55, -10789.409, -10832.645, -10875.261, -10917.258999999998, -10958.642, -10999.413999999999, -11039.576000000001, -11079.132, -11118.083999999999, -11156.436000000002, -11194.188999999998, -11231.347, -11267.912, -11303.886, -11339.271999999999, -11374.072, -11408.288999999999, -11441.923999999999, -11474.981000000002, -11507.462, -11539.368, -11570.703000000001, -11601.466999999999, -11631.663, -11661.295, -11690.363000000001, -11718.868999999999, -11746.816, -11774.205, -11801.038999999999, -11827.319, -11853.046999999999, -11878.225, -11902.854, -11926.938, -11950.476, -11973.472, -11995.926000000001, -12017.84, -12039.216999999999, -12060.056999999999, -12080.362, -12100.133999999998, -12119.375, -12138.085, -12156.266000000001, -12173.919, -12191.046999999999, -12207.65, -12223.73, -12239.288, -12254.326000000001, -12268.844, -12282.844, -12296.328000000001, -12309.295, -12321.748, -12333.688, -12345.116000000002, -12356.033000000001, -12366.441, -12376.339, -12385.73, -12394.614, -12402.993, -12410.867, -12418.237, -12425.105, -12431.47, -12437.335, -12442.7, -12447.565, -12451.931999999999, -12455.801000000001, -12459.173999999999, -12462.051000000001, -12464.434, -12466.321000000002, -12467.715, -12468.616000000002, -12469.025, -12468.943000000001, -12468.368999999999, -12467.305, -12465.751, -12463.708999999999, -12461.177, -12458.158000000001, -12454.652, -12450.658000000001, -12446.178, -12441.212, -12435.761, -12429.825, -12423.403999999999, -12416.499, -12409.111, -12401.239, -12392.883999999998, -12384.046999999999, -12374.726999999999, -12364.926000000001, -12354.642, -12343.878, -12332.632, -12320.905, -12308.697, -12296.008999999998, -12282.84, -12269.192, -12255.063999999998, -12240.456, -12225.368, -12209.801000000001, -12193.753999999999, -12177.228000000001, -12160.223, -12142.738000000001, -12124.774, -12106.331, -12087.409, -12068.007, -12048.126, -12027.766000000001, -12006.926000000001, -11985.607, -11963.808, -11941.528999999999, -11918.77, -11895.531, -11871.813, -11847.614, -11822.934, -11797.773000000001, -11772.132, -11746.008999999998, -11719.403999999999, -11692.318000000001, -11664.75, -11636.698999999999, -11608.165, -11579.148000000001, -11549.646999999999, -11519.662, -11489.193000000001, -11458.239, -11426.8, -11394.876, -11362.465, -11329.568000000001, -11296.184, -11262.311000000002, -11227.951000000001, -11193.101999999999, -11157.764, -11121.935, -11085.617, -11048.806999999999, -11011.505, -10973.71, -10935.423, -10896.641000000001, -10857.364, -10817.593, -10777.325, -10736.561000000002, -10695.298, -10653.538, -10611.278, -10568.518, -10525.257, -10481.493, -10437.228000000001, -10392.458, -10347.183, -10301.403, -10255.116, -10208.322, -10161.019, -10113.206, -10064.882, -10016.046, -9966.697, -9916.835, -9866.457, -9815.562, -9764.15, -9712.22, -9659.769, -9606.796999999999, -9553.303, -9499.284, -9444.741, -9389.671, -9334.073, -9277.946, -9221.289, -9164.099, -9106.376, -9048.118, -8989.325, -8929.993, -8870.122, -8809.71, -8748.756, -8687.258, -8625.214, -8562.623, -8499.483, -8435.793, -8371.55, -8306.754, -8241.401, -8175.491999999999, -8109.023, -8041.994000000001, -7974.403, -7906.246, -7837.524, -7768.233, -7698.3730000000005, -7627.94, -7556.934, -7485.352, -7413.193, -7340.453, -7267.133000000001, -7193.228, -7118.738, -7043.661999999999, -6967.995, -6891.736999999999, -6814.8859999999995, -6737.44, -6659.395, -6580.7519999999995, -6501.507, -6421.658, -6341.204000000001, -6260.142, -6178.47, -6096.188, -6013.291, -5929.778, -5845.649, -5760.9, -5675.53, -5589.536999999999, -5502.919, -5415.674, -5327.8009999999995, -5239.2970000000005, -5150.163, -5060.394, -4969.992, -4878.952, -4787.275, -4694.96, -4602.005, -4508.41, -4414.173, -4319.293, -4223.771, -4127.606, -4030.797, -3933.345, -3835.25, -3736.512, -3637.133, -3537.112, -3436.452, -3335.1540000000005, -3233.2209999999995, -3130.6540000000005, -3027.4570000000003, -2923.634, -2819.188, -2714.123, -2608.445, -2502.16, -2395.274, -2287.795, -2179.731, -2071.091, -1961.885, -1852.126, -1741.826, -1630.9979999999998, -1519.66, -1407.828, -1295.52, -1182.759, -1069.567, -955.971, -841.998, -727.679, -613.049, -498.14599999999996, -383.01099999999997, -267.689, -152.231, -36.692, 78.866, 194.378, 309.77, 424.96, 539.859, 654.37, 768.3839999999999, 881.7819999999999, 994.435, 1106.198, 1216.914, 1326.408, 1434.4920000000002, 1540.9560000000001, 1645.5710000000001, 1748.0870000000002, 1848.229, 1945.703, 2040.183, 2131.319, 2218.736, 2302.026, 2380.759, 2454.478, 2522.7039999999997, 2584.938, 2640.6679999999997, 2689.377, 2730.553, 2763.695, 2788.333, 2804.033, 2810.422, 2807.191, 2794.119, 2771.0759999999996, 2738.034, 2695.07, 2642.363, 2580.197, 2508.942, 2429.0460000000003, 2341.02, 2245.425, 2142.849, 2033.898, 1919.181, 1799.296, 1674.8229999999999, 1546.317, 1414.3, 1279.26, 1141.649, 1001.883, 860.341, 717.3660000000001, 573.27, 428.33099999999996, 282.802, 136.905, -9.161, -155.217, -301.108, -446.694, -591.854, -736.4780000000001, -880.4739999999999, -1023.757, -1166.257, -1307.9089999999999, -1448.6589999999999, -1588.4589999999998, -1727.269, -1865.0529999999999, -2001.783, -2137.431, -2271.978, -2405.407, -2537.702, -2668.853, -2798.8509999999997, -2927.688, -3055.361, -3181.866, -3307.202, -3431.369, -3554.369, -3676.203, -3796.875, -3916.389, -4034.748, -4151.96, -4268.03, -4382.964, -4496.769, -4609.451, -4721.02, -4831.48, -4940.842000000001, -5049.113, -5156.302, -5262.415, -5367.463000000001, -5471.451999999999, -5574.393, -5676.2919999999995, -5777.159000000001, -5877.001, -5975.829000000001, -6073.65, -6170.472, -6266.303000000001, -6361.153, -6455.029, -6547.939, -6639.891, -6730.894, -6820.955, -6910.081999999999, -6998.281999999999, -7085.564, -7171.935, -7257.401999999999, -7341.973000000001, -7425.654, -7508.453, -7590.3769999999995, -7671.434, -7751.628000000001, -7830.969, -7909.460999999999, -7987.111999999999, -8063.929, -8139.916, -8215.081, -8289.429, -8362.966999999999, -8435.702, -8507.638, -8578.780999999999, -8649.138, -8718.713, -8787.511999999999, -8855.541, -8922.804, -8989.308, -9055.056999999999, -9120.056, -9184.311, -9247.826, -9310.607, -9372.657, -9433.982, -9494.586, -9554.474, -9613.65, -9672.119, -9729.884, -9786.951, -9843.323, -9899.004, -9954.0, -10008.312, -10061.947, -10114.905999999999, -10167.195, -10218.817, -10269.775, -10320.073, -10369.715, -10418.704, -10467.044, -10514.738000000001, -10561.788999999999, -10608.202, -10653.978000000001, -10699.122, -10743.635, -10787.523000000001, -10830.786, -10873.428999999998, -10915.454, -10956.865, -10997.663999999999, -11037.853000000001, -11077.436000000002, -11116.415, -11154.794, -11192.573999999999, -11229.758999999998, -11266.35, -11302.351, -11337.763, -11372.59, -11406.833, -11440.495, -11473.579, -11506.085, -11538.018, -11569.378999999999, -11600.169, -11630.392, -11660.048999999999, -11689.143, -11717.675, -11745.648000000001, -11773.063, -11799.921999999999, -11826.228000000001, -11851.981000000002, -11877.185, -11901.84, -11925.948999999999, -11949.513, -11972.534, -11995.013, -12016.953000000001, -12038.355, -12059.22, -12079.551000000001, -12099.348, -12118.613000000001, -12137.348, -12155.553999999998, -12173.233, -12190.386, -12207.014, -12223.118999999999, -12238.701000000001, -12253.764, -12268.306, -12282.331, -12295.839, -12308.831, -12321.309, -12333.273000000001, -12344.726, -12355.667, -12366.098999999998, -12376.021999999999, -12385.437, -12394.345, -12402.748, -12410.646, -12418.04, -12424.931999999999, -12431.322, -12437.21, -12442.598999999998, -12447.488000000001, -12451.878999999999, -12455.771999999999, -12459.169, -12462.07, -12464.476, -12466.386999999999, -12467.805, -12468.73, -12469.162, -12469.103000000001, -12468.553, -12467.511999999999, -12465.982, -12463.963, -12461.455, -12458.46, -12454.976, -12451.006000000001, -12446.548999999999, -12441.606000000002, -12436.178, -12430.265, -12423.868, -12416.986, -12409.621000000001, -12401.771999999999, -12393.441, -12384.626, -12375.33, -12365.551000000001, -12355.29, -12344.548999999999, -12333.326000000001, -12321.622, -12309.437, -12296.771, -12283.625, -12270.0, -12255.893999999998, -12241.309, -12226.243999999999, -12210.698999999999, -12194.675, -12178.171999999999, -12161.188999999998, -12143.726999999999, -12125.785, -12107.365, -12088.465, -12069.085, -12049.226999999999, -12028.889, -12008.071000000002, -11986.775, -11964.998, -11942.741000000002, -11920.003999999999, -11896.788, -11873.091, -11848.913999999999, -11824.257, -11799.118, -11773.499, -11747.398000000001, -11720.816, -11693.751, -11666.205, -11638.176000000001, -11609.663999999999, -11580.669, -11551.19, -11521.226999999999, -11490.78, -11459.848, -11428.431, -11396.528, -11364.139, -11331.264, -11297.901000000002, -11264.051000000001, -11229.712, -11194.885, -11159.568000000001, -11123.761, -11087.464, -11050.676000000001, -11013.395, -10975.623, -10937.356000000002, -10898.596000000001, -10859.341, -10819.591, -10779.345, -10738.601999999999, -10697.361, -10655.622, -10613.383, -10570.645, -10527.405, -10483.663, -10439.418, -10394.67, -10349.417, -10303.658000000001, -10257.392, -10210.619, -10163.337, -10115.545, -10067.242, -10018.428, -9969.1, -9919.259, -9868.902, -9818.028, -9766.638, -9714.728000000001, -9662.298, -9609.347, -9555.874, -9501.876, -9447.354, -9392.305, -9336.728000000001, -9280.622, -9223.985, -9166.815999999999, -9109.114, -9050.878, -8992.104, -8932.794, -8872.943000000001, -8812.552, -8751.619, -8690.141, -8628.118, -8565.548, -8502.428, -8438.759, -8374.537, -8309.761, -8244.429, -8178.54, -8112.092, -8045.084, -7977.512, -7909.3769999999995, -7840.674, -7771.404, -7701.564, -7631.151999999999, -7560.166, -7488.604, -7416.465, -7343.746, -7270.445, -7196.561, -7122.090999999999, -7047.035, -6971.388000000001, -6895.151, -6818.319, -6740.893, -6662.868, -6584.245, -6505.019, -6425.19, -6344.755999999999, -6263.714, -6182.062, -6099.799, -6016.920999999999, -5933.428000000001, -5849.318, -5764.588000000001, -5679.238, -5593.264, -5506.665, -5419.439, -5331.585, -5243.101, -5153.985, -5064.235, -4973.851, -4882.83, -4791.1720000000005, -4698.875, -4605.938, -4512.361, -4418.142, -4323.28, -4227.776, -4131.628, -4034.837, -3937.402, -3839.324, -3740.603, -3641.239, -3541.235, -3440.591, -3339.309, -3237.3909999999996, -3134.84, -3031.658, -2927.849, -2823.417, -2718.367, -2612.702, -2506.43, -2399.5570000000002, -2292.09, -2184.038, -2075.409, -1966.214, -1856.465, -1746.1729999999998, -1635.355, -1524.024, -1412.1979999999999, -1299.897, -1187.141, -1073.953, -960.3589999999999, -846.387, -732.069, -617.437, -502.531, -387.39099999999996, -272.063, -156.596, -41.04600000000001, 74.52600000000001, 190.053, 305.464, 420.675, 535.6, 650.14, 764.187, 877.623, 990.318, 1102.128, 1212.897, 1322.451, 1430.601, 1537.138, 1641.835, 1744.442, 1844.685, 1942.27, 2036.872, 2128.143, 2215.706, 2299.158, 2378.0679999999998, 2451.979, 2520.413, 2582.871, 2638.844, 2687.813, 2729.265, 2762.7, 2787.6459999999997, 2803.6690000000003, 2810.3909999999996, 2807.5040000000004, 2794.782, 2772.092, 2739.402, 2696.7870000000003, 2644.4240000000004, 2582.59, 2511.654, 2432.061, 2344.323, 2248.995, 2146.667, 2037.944, 1923.4360000000001, 1803.739, 1679.4360000000001, 1551.0810000000001, 1419.1979999999999, 1284.275, 1146.768, 1007.091, 865.625, 722.715, 578.673, 433.779, 288.286, 142.417, -3.627, -149.66899999999998, -295.551, -441.13300000000004, -586.293, -730.922, -874.926, -1018.221, -1160.735, -1302.404, -1443.1729999999998, -1583.391, -1721.828, -1859.638, -1996.394, -2132.07, -2266.646, -2400.105, -2532.431, -2663.614, -2793.6440000000002, -2922.515, -3050.2209999999995, -3176.76, -3302.131, -3426.333, -3549.368, -3671.238, -3791.945, -3911.495, -4029.8909999999996, -4147.139, -4263.245, -4378.215, -4492.057, -4604.776, -4716.380999999999, -4826.878, -4936.276, -5044.584, -5151.809, -5257.959, -5363.043000000001, -5467.069, -5570.045, -5671.981, -5772.883000000001, -5872.762, -5971.626, -6069.482, -6166.34, -6262.206999999999, -6357.092, -6451.003000000001, -6543.9490000000005, -6635.936, -6726.973000000001, -6817.069, -6906.231, -6994.465999999999, -7081.783, -7168.188, -7253.689, -7338.294, -7422.009, -7504.842, -7586.8, -7667.89, -7748.119000000001, -7827.493, -7906.018, -7983.703, -8060.552, -8136.571999999999, -8211.77, -8286.151, -8359.722, -8432.489, -8504.457, -8575.633, -8646.021, -8715.628, -8784.459, -8852.52, -8919.815, -8986.351, -9052.131, -9117.162, -9181.448, -9244.994, -9307.806, -9369.886999999999, -9431.243, -9491.878, -9551.796, -9611.003, -9669.502, -9727.298, -9784.395, -9840.796999999999, -9896.509, -9951.534, -10005.877, -10059.541, -10112.530999999999, -10164.849, -10216.5, -10267.488000000001, -10317.815999999999, -10367.487, -10416.505, -10464.874, -10512.597, -10559.678, -10606.118999999999, -10651.923999999999, -10697.097, -10741.639, -10785.555, -10828.847, -10871.518999999998, -10913.572, -10955.011, -10995.838, -11036.056, -11075.667, -11114.673999999999, -11153.081, -11190.889, -11228.101, -11264.72, -11300.749, -11336.188999999998, -11371.043, -11405.313999999998, -11439.003999999999, -11472.114, -11504.649, -11536.608999999999, -11567.996000000001, -11598.813999999998, -11629.063999999998, -11658.748, -11687.868999999999, -11716.428, -11744.427, -11771.868999999999, -11798.755, -11825.088, -11850.868, -11876.098, -11900.78, -11924.915, -11948.506000000001, -11971.553, -11994.059, -12016.024, -12037.452, -12058.344, -12078.701000000001, -12098.524, -12117.815, -12136.576000000001, -12154.808, -12172.513, -12189.691, -12206.345, -12222.475, -12238.083999999999, -12253.171999999999, -12267.74, -12281.79, -12295.323999999999, -12308.341, -12320.844, -12332.833999999999, -12344.312, -12355.278, -12365.735, -12375.683, -12385.124, -12394.056999999999, -12402.485, -12410.408000000001, -12417.827, -12424.743999999999, -12431.158000000001, -12437.072, -12442.485, -12447.399, -12451.815, -12455.732, -12459.153999999999, -12462.079, -12464.51, -12466.446000000002, -12467.888, -12468.837, -12469.294, -12469.258999999998, -12468.733, -12467.716999999999, -12466.211000000001, -12464.216, -12461.733, -12458.761, -12455.302, -12451.355, -12446.921999999999, -12442.003999999999, -12436.6, -12430.711000000001, -12424.337, -12417.48, -12410.138, -12402.313, -12394.005, -12385.215, -12375.942, -12366.186000000002, -12355.95, -12345.231000000002, -12334.032, -12322.351, -12310.19, -12297.548, -12284.426000000001, -12270.823, -12256.741000000002, -12242.178999999998, -12227.138, -12211.616000000002, -12195.615, -12179.135, -12162.175, -12144.736, -12126.818000000001, -12108.42, -12089.544, -12070.187, -12050.351999999999, -12030.037, -12009.242, -11987.968, -11966.214, -11943.98, -11921.267, -11898.073, -11874.399, -11850.245, -11825.61, -11800.495, -11774.898000000001, -11748.82, -11722.26, -11695.218, -11667.694, -11639.688, -11611.198, -11582.226, -11552.77, -11522.829, -11492.403999999999, -11461.493999999999, -11430.1, -11398.219, -11365.853000000001, -11333.0, -11299.659, -11265.831, -11231.515, -11196.71, -11161.415, -11125.631000000001, -11089.355, -11052.589, -11015.331, -10977.58, -10939.336000000001, -10900.597, -10861.364, -10821.636, -10781.412, -10740.691, -10699.472, -10657.755, -10615.538, -10572.821000000002, -10529.603000000001, -10485.883, -10441.66, -10396.933, -10351.702, -10305.965, -10259.721, -10212.969000000001, -10165.709, -10117.939, -10069.657, -10020.864, -9971.558, -9921.738000000001, -9871.402, -9820.551, -9769.181, -9717.293, -9664.884, -9611.955, -9558.503, -9504.527, -9450.025, -9394.998, -9339.442, -9283.357, -9226.742, -9169.594000000001, -9111.913, -9053.697, -8994.945, -8935.655, -8875.826, -8815.456, -8754.543, -8693.087, -8631.085, -8568.535, -8505.437, -8441.788, -8377.587, -8312.832, -8247.521, -8181.651999999999, -8115.225, -8048.236999999999, -7980.687, -7912.571999999999, -7843.89, -7774.64, -7704.821, -7634.429, -7563.464, -7491.922, -7419.803000000001, -7347.105, -7273.825, -7199.96, -7125.5109999999995, -7050.475, -6974.848000000001, -6898.630999999999, -6821.82, -6744.4130000000005, -6666.409000000001, -6587.805, -6508.599, -6428.79, -6348.376, -6267.353, -6185.721, -6103.477, -6020.62, -5937.146, -5853.055, -5768.345, -5683.014, -5597.059, -5510.479, -5423.272, -5335.437, -5246.972, -5157.874, -5068.144, -4977.778, -4886.776, -4795.1359999999995, -4702.857, -4609.938, -4516.379, -4422.177, -4327.334, -4231.847, -4135.715999999999, -4038.942, -3941.5240000000003, -3843.4629999999997, -3744.758, -3645.4120000000003, -3545.423, -3444.795, -3343.5290000000005, -3241.6259999999997, -3139.09, -3035.923, -2932.1279999999997, -2827.71, -2722.673, -2617.022, -2510.763, -2403.902, -2296.447, -2188.406, -2079.788, -1970.6029999999998, -1860.8629999999998, -1750.58, -1639.769, -1528.4460000000001, -1416.626, -1304.33, -1191.578, -1078.394, -964.802, -850.831, -736.512, -621.879, -506.969, -391.82300000000004, -276.487, -161.011, -45.45, 70.13600000000001, 185.68, 301.11, 416.345, 531.295, 645.865, 759.946, 873.42, 986.158, 1098.017, 1208.84, 1318.454, 1426.672, 1533.2839999999999, 1638.0639999999999, 1740.7620000000002, 1841.1070000000002, 1938.8029999999999, 2033.529, 2124.935, 2212.647, 2296.261, 2375.348, 2449.452, 2518.095, 2580.78, 2636.9959999999996, 2686.225, 2727.955, 2761.685, 2786.9390000000003, 2803.2859999999996, 2810.343, 2807.8, 2795.429, 2773.094, 2740.759, 2698.495, 2646.475, 2584.975, 2514.36, 2435.074, 2347.623, 2252.565, 2150.487, 2041.994, 1927.6960000000001, 1808.1889999999999, 1684.058, 1555.855, 1424.108, 1289.305, 1151.902, 1012.315, 870.927, 728.0830000000001, 584.096, 439.24800000000005, 293.79200000000003, 147.952, 1.93, -144.096, -289.968, -435.545, -580.705, -725.3380000000001, -869.3489999999999, -1012.6560000000001, -1155.184, -1296.869, -1437.6570000000002, -1577.5, -1716.356, -1854.191, -1990.973, -2126.677, -2261.281, -2394.77, -2527.127, -2658.341, -2788.403, -2917.3070000000002, -3045.047, -3171.619, -3297.025, -3421.262, -3544.3320000000003, -3666.237, -3786.98, -3906.566, -4024.998, -4142.282, -4258.424, -4373.431, -4487.309, -4600.065, -4711.706, -4822.24, -4931.675, -5040.019, -5147.28, -5253.467, -5358.5869999999995, -5462.649, -5565.661999999999, -5667.634, -5768.573, -5868.486999999999, -5967.387, -6065.279, -6162.172, -6258.075, -6352.996, -6446.943, -6539.924, -6631.946, -6723.018, -6813.149, -6902.346, -6990.616, -7077.967, -7164.406999999999, -7249.943, -7334.581999999999, -7418.331, -7501.198, -7583.19, -7664.314, -7744.576, -7823.984, -7902.543000000001, -7980.2609999999995, -8057.143, -8133.196999999999, -8208.427, -8282.841999999999, -8356.445, -8429.245, -8501.245, -8572.454, -8642.875, -8712.514000000001, -8781.377, -8849.47, -8916.796999999999, -8983.365, -9049.177, -9114.239, -9178.556, -9242.134, -9304.976999999999, -9367.09, -9428.476999999999, -9489.143, -9549.091999999999, -9608.33, -9666.86, -9724.686, -9781.814, -9838.246, -9893.988000000001, -9949.044, -10003.417, -10057.110999999999, -10110.131, -10162.479, -10214.16, -10265.178, -10315.535, -10365.237, -10414.284, -10462.683, -10510.435, -10557.545, -10604.016000000001, -10649.85, -10695.051000000001, -10739.623, -10783.568000000001, -10826.889, -10869.589, -10911.671, -10953.139, -10993.993999999999, -11034.241000000002, -11073.88, -11112.916000000001, -11151.35, -11189.187, -11226.427, -11263.075, -11299.131000000001, -11334.598999999998, -11369.481000000002, -11403.78, -11437.497, -11470.636, -11503.198, -11535.185, -11566.601, -11597.446000000002, -11627.723, -11657.435, -11686.583, -11715.169, -11743.196000000002, -11770.665, -11797.578000000001, -11823.937, -11849.743999999999, -11875.001, -11899.71, -11923.872, -11947.489, -11970.563999999998, -11993.096000000001, -12015.088, -12036.543, -12057.461000000001, -12077.844, -12097.693000000001, -12117.011, -12135.798, -12154.056, -12171.787, -12188.992, -12205.671999999999, -12221.828000000001, -12237.463, -12252.576000000001, -12267.171, -12281.247, -12294.806, -12307.848999999998, -12320.378, -12332.393, -12343.896999999999, -12354.889, -12365.371000000001, -12375.345, -12384.811000000002, -12393.77, -12402.223, -12410.171, -12417.616000000002, -12424.556999999999, -12430.997, -12436.936000000002, -12442.374, -12447.313, -12451.753999999999, -12455.697, -12459.143, -12462.093, -12464.548999999999, -12466.508999999998, -12467.976, -12468.95, -12469.431999999999, -12469.421999999999, -12468.921, -12467.928999999998, -12466.448, -12464.476999999999, -12462.018, -12459.071000000002, -12455.636, -12451.714, -12447.306, -12442.411, -12437.032, -12431.167, -12424.818000000001, -12417.983999999999, -12410.667, -12402.866000000002, -12394.582, -12385.815, -12376.566, -12366.835, -12356.622, -12345.928, -12334.753, -12323.096000000001, -12310.958, -12298.34, -12285.241000000002, -12271.663, -12257.604, -12243.066, -12228.048, -12212.55, -12196.573, -12180.116000000002, -12163.18, -12145.765, -12127.87, -12109.495, -12090.642, -12071.309, -12051.497, -12031.205, -12010.434, -11989.183, -11967.452, -11945.242, -11922.551000000001, -11899.381000000001, -11875.73, -11851.598999999998, -11826.987, -11801.893999999998, -11776.32, -11750.265, -11723.728000000001, -11696.708999999999, -11669.208, -11641.225, -11612.758, -11583.808, -11554.375, -11524.457, -11494.055, -11463.168, -11431.796, -11399.938, -11367.594, -11334.764, -11301.446000000002, -11267.64, -11233.346000000001, -11198.563999999998, -11163.291000000001, -11127.528999999999, -11091.277, -11054.533000000001, -11017.296999999999, -10979.568000000001, -10941.346000000001, -10902.63, -10863.419, -10823.713, -10783.511, -10742.812, -10701.616000000002, -10659.92, -10617.726, -10575.031, -10531.835, -10488.136999999999, -10443.936, -10399.231, -10354.021999999999, -10308.306, -10262.084, -10215.354, -10168.116, -10120.368, -10072.108, -10023.336, -9974.052, -9924.254, -9873.94, -9823.11, -9771.761999999999, -9719.895, -9667.509, -9614.601, -9561.17, -9507.215, -9452.735999999999, -9397.729, -9342.195, -9286.132, -9229.537, -9172.411, -9114.751, -9056.556999999999, -8997.826, -8938.558, -8878.75, -8818.401, -8757.509, -8696.074, -8634.093, -8571.564, -8508.487, -8444.859, -8380.679, -8315.945, -8250.655, -8184.807, -8118.401, -8051.434, -7983.904, -7915.81, -7847.149, -7777.92, -7708.121, -7637.75, -7566.805, -7495.284000000001, -7423.186, -7350.508000000001, -7277.2480000000005, -7203.404, -7128.975, -7053.959, -6978.353, -6902.156, -6825.365, -6747.978, -6669.994000000001, -6591.41, -6512.225, -6432.435, -6352.041, -6271.039000000001, -6189.4259999999995, -6107.201999999999, -6024.3640000000005, -5940.911, -5856.84, -5772.149, -5686.8369999999995, -5600.901, -5514.34, -5427.151999999999, -5339.335999999999, -5250.889, -5161.81, -5072.098, -4981.751, -4890.768, -4799.146, -4706.8859999999995, -4613.985, -4520.444, -4426.26, -4331.434, -4235.964, -4139.851, -4043.093, -3945.692, -3847.647, -3748.9590000000003, -3649.6290000000004, -3549.657, -3449.045, -3347.7940000000003, -3245.907, -3143.385, -3040.2329999999997, -2936.452, -2832.048, -2727.025, -2621.386, -2515.14, -2408.291, -2300.847, -2192.8160000000003, -2084.209, -1975.0339999999999, -1865.3029999999999, -1755.03, -1644.227, -1532.91, -1421.096, -1308.805, -1196.057, -1082.876, -969.2860000000001, -855.315, -740.995, -626.359, -511.445, -396.29400000000004, -280.95, -165.465, -49.891000000000005, 65.709, 181.271, 296.721, 411.97900000000004, 526.956, 641.556, 755.671, 869.184, 981.966, 1093.874, 1204.752, 1314.4279999999999, 1422.713, 1529.4, 1634.263, 1737.0539999999999, 1837.5020000000002, 1935.3110000000001, 2030.16, 2121.703, 2209.564, 2293.342, 2372.607, 2446.905, 2515.758, 2578.67, 2635.13, 2684.6220000000003, 2726.631, 2760.656, 2786.222, 2802.893, 2810.2870000000003, 2808.091, 2796.073, 2774.095, 2742.116, 2700.2059999999997, 2648.534, 2587.3720000000003, 2517.081, 2438.1020000000003, 2350.9429999999998, 2256.157, 2154.333, 2046.0729999999999, 1931.987, 1812.674, 1688.7160000000001, 1560.6689999999999, 1429.059, 1294.378, 1157.08, 1017.586, 876.2769999999999, 733.5010000000001, 589.571, 444.77099999999996, 299.35200000000003, 153.543, 7.544, -138.465, -284.32599999999996, -429.898, -575.057, -719.694, -863.7130000000001, -1007.03, -1149.5710000000001, -1291.2730000000001, -1432.08, -1571.943, -1710.8220000000001, -1848.68, -1985.4879999999998, -2121.219, -2255.853, -2389.371, -2521.759, -2653.005, -2783.099, -2912.035, -3039.808, -3166.415, -3291.855, -3416.127, -3539.2329999999997, -3661.173, -3781.952, -3901.574, -4020.0429999999997, -4137.363, -4253.541, -4368.585, -4482.499, -4595.292, -4706.97, -4817.541, -4927.013, -5035.394, -5142.691, -5248.914000000001, -5354.071, -5458.17, -5561.219, -5663.228, -5764.203, -5864.155, -5963.090999999999, -6061.019, -6157.948, -6253.887, -6348.843000000001, -6442.826, -6535.842, -6627.901, -6719.009, -6809.175, -6898.406999999999, -6986.713000000001, -7074.098000000001, -7160.573, -7246.143, -7330.816999999999, -7414.602, -7497.503000000001, -7579.53, -7660.688, -7740.984, -7820.4259999999995, -7899.019, -7976.771, -8053.686, -8129.773, -8205.037, -8279.485, -8353.122, -8425.955, -8497.989, -8569.23, -8639.684000000001, -8709.356, -8778.252, -8846.377, -8913.737, -8980.336, -9046.18, -9111.275, -9175.625, -9239.235, -9302.109, -9364.254, -9425.671999999999, -9486.37, -9546.351, -9605.62, -9664.181, -9722.039, -9779.198, -9835.661, -9891.434000000001, -9946.52, -10000.924, -10054.649, -10107.699, -10160.078000000001, -10211.789, -10262.837, -10313.225, -10362.956, -10412.034, -10460.463, -10508.246000000001, -10555.386, -10601.885, -10647.749, -10692.98, -10737.581, -10781.555, -10824.905, -10867.635, -10909.747, -10951.243999999999, -10992.128, -11032.403999999999, -11072.072, -11111.136999999999, -11149.601, -11187.466, -11224.735, -11261.411, -11297.496000000001, -11332.992, -11367.903, -11402.23, -11435.975, -11469.142, -11501.732, -11533.748, -11565.191, -11596.065, -11626.37, -11656.11, -11685.286, -11713.9, -11741.955, -11769.451000000001, -11796.392, -11822.778999999999, -11848.613000000001, -11873.896999999999, -11898.633, -11922.823, -11946.466999999999, -11969.569, -11992.128, -12014.148000000001, -12035.63, -12056.575, -12076.985, -12096.862, -12116.206, -12135.02, -12153.306, -12171.063, -12188.294, -12205.001, -12221.184, -12236.845, -12251.985, -12266.605, -12280.708, -12294.293, -12307.363000000001, -12319.918, -12331.96, -12343.49, -12354.508, -12365.017, -12375.016000000001, -12384.508, -12393.493, -12401.972, -12409.946000000002, -12417.417, -12424.383999999998, -12430.85, -12436.813999999998, -12442.278, -12447.242, -12451.708999999999, -12455.678, -12459.15, -12462.126, -12464.606000000002, -12466.591999999999, -12468.085, -12469.083999999999, -12469.591, -12469.606000000002, -12469.13, -12468.163999999999, -12466.708, -12464.761999999999, -12462.328000000001, -12459.406, -12455.997, -12452.1, -12447.716999999999, -12442.847, -12437.492, -12431.652, -12425.327, -12418.518999999998, -12411.226, -12403.45, -12395.191, -12386.448999999999, -12377.223999999998, -12367.518, -12357.33, -12346.66, -12335.508999999998, -12323.876, -12311.763, -12299.17, -12286.096000000001, -12272.542, -12258.508, -12243.993, -12228.999, -12213.525, -12197.572, -12181.14, -12164.226999999999, -12146.836000000001, -12128.965, -12110.615, -12091.786, -12072.476999999999, -12052.688, -12032.421, -12011.673, -11990.446000000002, -11968.74, -11946.553, -11923.886999999999, -11900.74, -11877.113000000001, -11853.006000000001, -11828.417, -11803.348, -11777.798, -11751.765, -11725.252, -11698.257, -11670.778999999999, -11642.819, -11614.376, -11585.448999999999, -11556.038999999999, -11526.145, -11495.767, -11464.903, -11433.555, -11401.72, -11369.399, -11336.591999999999, -11303.296999999999, -11269.515, -11235.243999999999, -11200.483999999999, -11165.235, -11129.495, -11093.266000000001, -11056.545, -11019.332, -10981.626, -10943.427, -10904.735, -10865.546999999999, -10825.864, -10785.685, -10745.008999999998, -10703.835, -10662.162, -10619.99, -10577.318000000001, -10534.145, -10490.47, -10446.291, -10401.609, -10356.421999999999, -10310.729, -10264.529, -10217.822, -10170.606, -10122.88, -10074.643, -10025.894, -9976.632, -9926.857, -9876.565, -9825.757, -9774.431999999999, -9722.587, -9670.223, -9617.337, -9563.929, -9509.996, -9455.539, -9400.554, -9345.042, -9289.0, -9232.428, -9175.324, -9117.687, -9059.514000000001, -9000.806, -8941.559000000001, -8881.773000000001, -8821.446, -8760.576, -8699.163, -8637.203000000001, -8574.697, -8511.641, -8448.035, -8383.877, -8319.164, -8253.896, -8188.071, -8121.686, -8054.74, -7987.231, -7919.158, -7850.519, -7781.311, -7711.534000000001, -7641.184, -7570.26, -7498.7609999999995, -7426.684, -7354.026999999999, -7280.7880000000005, -7206.965999999999, -7132.559, -7057.563, -6981.978, -6905.8009999999995, -6829.031, -6751.665, -6673.701999999999, -6595.139, -6515.974, -6436.205, -6355.831, -6274.849, -6193.257, -6111.053000000001, -6028.236, -5944.802, -5860.751, -5776.081, -5690.789000000001, -5604.8730000000005, -5518.331999999999, -5431.164000000001, -5343.366999999999, -5254.94, -5165.880999999999, -5076.188, -4985.86, -4894.896, -4803.294, -4711.052, -4618.17, -4524.647, -4430.482, -4335.674, -4240.223, -4144.127, -4047.388, -3950.0040000000004, -3851.9770000000003, -3753.3059999999996, -3653.993, -3554.0370000000003, -3453.442, -3352.2070000000003, -3250.336, -3147.83, -3044.6929999999998, -2940.927, -2836.5370000000003, -2731.528, -2625.903, -2519.67, -2412.834, -2305.402, -2197.383, -2088.7870000000003, -1979.622, -1869.902, -1759.6370000000002, -1648.842, -1537.533, -1425.726, -1313.44, -1200.697, -1087.518, -973.93, -859.961, -745.64, -631.002, -516.0840000000001, -400.92699999999996, -285.57599999999996, -170.08, -54.495, 61.121, 176.7, 292.17, 407.45099999999996, 522.456, 637.086, 751.237, 864.79, 977.617, 1089.575, 1200.509, 1310.248, 1418.6029999999998, 1525.368, 1630.318, 1733.204, 1833.7579999999998, 1931.682, 2026.66, 2118.344, 2206.359, 2290.306, 2369.756, 2444.254, 2513.325, 2576.473, 2633.1859999999997, 2682.949, 2725.248, 2759.579, 2785.468, 2802.4759999999997, 2810.2209999999995, 2808.385, 2796.735, 2775.127, 2743.52, 2701.978, 2650.667, 2589.855, 2519.902, 2441.245, 2354.389, 2259.888, 2158.327, 2050.31, 1936.4460000000001, 1817.3339999999998, 1693.557, 1565.671, 1434.205, 1299.651, 1162.464, 1023.066, 881.8389999999999, 739.133, 595.263, 450.51099999999997, 305.133, 159.355, 13.38, -132.613, -278.46299999999997, -424.029, -569.187, -713.828, -857.8539999999999, -1001.182, -1143.738, -1285.4569999999999, -1426.283, -1566.06, -1705.0710000000001, -1842.955, -1979.789, -2115.55, -2250.2129999999997, -2383.762, -2516.1820000000002, -2647.461, -2777.5890000000004, -2906.56, -3034.368, -3161.011, -3286.487, -3410.795, -3533.937, -3655.915, -3776.732, -3896.3909999999996, -4014.897, -4132.255, -4248.472, -4363.554, -4477.505999999999, -4590.337, -4702.054, -4812.663, -4922.173, -5030.593, -5137.928, -5244.19, -5349.385, -5453.522, -5556.609, -5658.656, -5759.669, -5859.659000000001, -5958.632, -6056.599, -6153.565, -6249.541, -6344.535, -6438.555, -6531.609, -6623.704000000001, -6714.85, -6805.053000000001, -6894.321, -6982.6630000000005, -7070.085999999999, -7156.596, -7242.203, -7326.9130000000005, -7410.733, -7493.670999999999, -7575.733, -7656.927, -7737.259, -7816.736, -7895.3640000000005, -7973.151, -8050.102, -8126.223000000001, -8201.521999999999, -8276.005, -8349.676, -8422.544, -8494.612, -8565.886999999999, -8636.375, -8706.081, -8775.011, -8843.17, -8910.563, -8977.195, -9043.073, -9108.201, -9172.584, -9236.226999999999, -9299.135, -9361.312, -9422.763, -9483.494, -9543.507, -9602.809000000001, -9661.402, -9719.292, -9776.483, -9832.979, -9888.784, -9943.902, -9998.338, -10052.094000000001, -10105.176, -10157.586, -10209.329, -10260.408000000001, -10310.827, -10360.59, -10409.699, -10458.159, -10505.972, -10553.143, -10599.673999999999, -10645.568000000001, -10690.829, -10735.461000000001, -10779.466, -10822.846000000001, -10865.606000000002, -10907.748, -10949.275, -10990.19, -11030.495, -11070.194, -11109.288999999999, -11147.782, -11185.677, -11222.976, -11259.681, -11295.796, -11331.321000000002, -11366.261, -11400.617, -11434.392, -11467.588, -11500.207, -11532.252, -11563.723999999998, -11594.627, -11624.961000000001, -11654.729, -11683.934, -11712.577, -11740.66, -11768.185, -11795.153999999999, -11821.569, -11847.431999999999, -11872.743999999999, -11897.508, -11921.726, -11945.399, -11968.528, -11991.116000000002, -12013.163999999999, -12034.673, -12055.646, -12076.083999999999, -12095.988000000001, -12115.36, -12134.202, -12152.515, -12170.3, -12187.558, -12204.292, -12220.503, -12236.191, -12251.358, -12266.005, -12280.135, -12293.748, -12306.845, -12319.427, -12331.496000000001, -12343.052, -12354.098, -12364.633, -12374.659, -12384.178, -12393.188999999998, -12401.695, -12409.696000000002, -12417.193000000001, -12424.187, -12430.678999999998, -12436.669, -12442.159, -12447.15, -12451.643, -12455.638, -12459.136, -12462.138, -12464.645, -12466.657, -12468.175, -12469.201000000001, -12469.733, -12469.774, -12469.323999999999, -12468.383999999998, -12466.953000000001, -12465.034, -12462.625, -12459.729, -12456.345, -12452.473999999998, -12448.116000000002, -12443.271999999999, -12437.942, -12432.127, -12425.828000000001, -12419.045, -12411.777, -12404.026000000002, -12395.792, -12387.076000000001, -12377.876, -12368.195, -12358.032, -12347.386999999999, -12336.261, -12324.653999999999, -12312.566, -12299.997, -12286.948, -12273.419, -12259.409, -12244.919, -12229.95, -12214.501, -12198.572, -12182.163999999999, -12165.277, -12147.91, -12130.063, -12111.738000000001, -12092.933, -12073.648000000001, -12053.883999999998, -12033.641000000001, -12012.918, -11991.715, -11970.033000000001, -11947.87, -11925.228000000001, -11902.105, -11878.503, -11854.419, -11829.855, -11804.81, -11779.283000000001, -11753.275, -11726.785, -11699.813999999998, -11672.36, -11644.423999999999, -11616.005, -11587.101999999999, -11557.716, -11527.845, -11497.49, -11466.651000000002, -11435.325, -11403.515, -11371.216999999999, -11338.433, -11305.162, -11271.403, -11237.156, -11202.42, -11167.194, -11131.476999999999, -11095.271, -11058.573, -11021.383, -10983.701000000001, -10945.525, -10906.856000000002, -10867.691, -10828.032, -10787.875, -10747.222, -10706.071000000002, -10664.421999999999, -10622.273000000001, -10579.624, -10536.473, -10492.821000000002, -10448.665, -10404.006, -10358.841999999999, -10313.171999999999, -10266.994, -10220.31, -10173.116, -10125.413, -10077.199, -10028.473, -9979.234, -9929.48, -9879.211, -9828.426, -9777.123, -9725.301, -9672.959, -9620.095, -9566.709, -9512.799, -9458.364, -9403.402, -9347.911, -9291.892, -9235.341999999999, -9178.26, -9120.645, -9062.495, -9003.808, -8944.583, -8884.819, -8824.514000000001, -8763.666, -8702.274, -8640.337, -8577.851999999999, -8514.818000000001, -8451.234, -8387.097, -8322.407, -8257.16, -8191.356, -8124.993, -8058.068, -7990.581, -7922.53, -7853.911999999999, -7784.726, -7714.969, -7644.641, -7573.738, -7502.26, -7430.204000000001, -7357.568, -7284.351, -7210.55, -7136.1630000000005, -7061.189, -6985.624, -6909.468000000001, -6832.719, -6755.374, -6677.431, -6598.888000000001, -6519.744000000001, -6439.996, -6359.642, -6278.68, -6197.109, -6114.925, -6032.128000000001, -5948.714, -5864.683000000001, -5780.033, -5694.76, -5608.865, -5522.343000000001, -5435.194, -5347.4169999999995, -5259.009, -5169.969, -5080.295999999999, -4989.987, -4899.041, -4807.458, -4715.235, -4622.372, -4528.867, -4434.72, -4339.93, -4244.496, -4148.418, -4051.696, -3954.33, -3856.3190000000004, -3757.665, -3658.368, -3558.429, -3457.85, -3356.631, -3254.775, -3152.284, -3049.1620000000003, -2945.4109999999996, -2841.035, -2736.039, -2630.428, -2524.2070000000003, -2417.383, -2309.9629999999997, -2201.955, -2093.369, -1984.215, -1874.503, -1764.247, -1653.4589999999998, -1542.1570000000002, -1430.356, -1318.075, -1205.335, -1092.16, -978.573, -864.6030000000001, -750.2810000000001, -635.64, -520.7180000000001, -405.55400000000003, -290.195, -174.68900000000002, -59.091, 56.54, 172.137, 287.628, 402.934, 517.966, 632.628, 746.814, 860.408, 973.28, 1085.289, 1196.28, 1306.0819999999999, 1414.507, 1521.349, 1626.385, 1729.3670000000002, 1830.026, 1928.067, 2023.172, 2114.996, 2203.1639999999998, 2287.279, 2366.913, 2441.61, 2510.897, 2574.278, 2631.243, 2681.275, 2723.861, 2758.4959999999996, 2784.704, 2802.047, 2810.139, 2808.66, 2797.3740000000003, 2776.134, 2744.8959999999997, 2703.719, 2652.7659999999996, 2592.303, 2522.685, 2444.348, 2357.794, 2263.575, 2162.277, 2054.502, 1940.859, 1821.9470000000001, 1698.351, 1570.6270000000002, 1439.305, 1304.878, 1167.8010000000002, 1028.5, 887.357, 744.721, 600.911, 456.209, 310.871, 165.125, 19.174, -126.8, -272.638, -418.19800000000004, -563.354, -707.998, -852.0310000000001, -995.3689999999999, -1137.938, -1279.673, -1420.519, -1560.425, -1699.351, -1837.259, -1974.12, -2109.909, -2244.601, -2378.181, -2510.632, -2641.9429999999998, -2772.1040000000003, -2901.1090000000004, -3028.9509999999996, -3155.6290000000004, -3281.14, -3405.4840000000004, -3528.663, -3650.677, -3771.531, -3891.2270000000003, -4009.77, -4127.166, -4243.42, -4358.54, -4472.53, -4585.399, -4697.153, -4807.8, -4917.349, -5025.806, -5133.179, -5239.479, -5344.7119999999995, -5448.887, -5552.012, -5654.096, -5755.147, -5855.174, -5954.185, -6052.189, -6149.193, -6245.206, -6340.236999999999, -6434.294, -6527.385, -6619.517, -6710.6990000000005, -6800.939, -6890.244000000001, -6978.621999999999, -7066.08, -7152.6269999999995, -7238.27, -7323.016, -7406.871999999999, -7489.845, -7571.943, -7653.172, -7733.539000000001, -7813.052, -7891.715, -7969.536999999999, -8046.522, -8122.679, -8198.011999999999, -8272.529, -8346.235, -8419.136999999999, -8491.239, -8562.549, -8633.071, -8702.81, -8771.774, -8839.966999999999, -8907.393, -8974.059000000001, -9039.971, -9105.132, -9169.548, -9233.224, -9296.164, -9358.374, -9419.859, -9480.621, -9540.668, -9600.001, -9658.627, -9716.55, -9773.773000000001, -9830.301, -9886.138, -9941.288, -9995.755, -10049.543, -10102.657, -10155.098, -10206.873, -10257.983, -10308.434000000001, -10358.226999999999, -10407.368, -10455.859, -10503.703000000001, -10550.905, -10597.466, -10643.391000000001, -10688.683, -10733.345, -10777.38, -10820.792, -10863.582, -10905.753999999999, -10947.311000000002, -10988.256000000001, -11028.591, -11068.32, -11107.445, -11145.968, -11183.893, -11221.221000000001, -11257.956, -11294.1, -11329.655, -11364.624, -11399.01, -11432.813999999998, -11466.038999999999, -11498.688, -11530.761, -11562.263, -11593.194, -11623.556999999999, -11653.355, -11682.588, -11711.26, -11739.371000000001, -11766.925, -11793.923, -11820.366000000002, -11846.257, -11871.598, -11896.391000000001, -11920.636999999999, -11944.338, -11967.495, -11990.111, -12012.187, -12033.723999999998, -12054.725, -12075.191, -12095.123, -12114.523000000001, -12133.392, -12151.733, -12169.545, -12186.832, -12203.593, -12219.831, -12235.546, -12250.741000000002, -12265.416000000001, -12279.573, -12293.213, -12306.337, -12318.946000000002, -12331.042, -12342.625, -12353.698, -12364.26, -12374.313, -12383.858999999999, -12392.896999999999, -12401.428999999998, -12409.457, -12416.98, -12424.001, -12430.52, -12436.537, -12442.053, -12447.071000000002, -12451.59, -12455.611, -12459.136, -12462.163999999999, -12464.697, -12466.735, -12468.28, -12469.331, -12469.89, -12469.957, -12469.533000000001, -12468.618, -12467.214, -12465.32, -12462.938, -12460.067, -12456.708999999999, -12452.863000000001, -12448.531, -12443.713, -12438.409, -12432.618999999999, -12426.346000000001, -12419.588, -12412.346000000001, -12404.62, -12396.412, -12387.72, -12378.546, -12368.89, -12358.752, -12348.133, -12337.032, -12325.45, -12313.386999999999, -12300.843, -12287.819, -12274.315, -12260.33, -12245.865, -12230.921, -12215.496000000001, -12199.593, -12183.208999999999, -12166.347, -12149.003999999999, -12131.183, -12112.882, -12094.101, -12074.841, -12055.101999999999, -12034.883, -12014.184, -11993.006000000001, -11971.348, -11949.21, -11926.591999999999, -11903.493999999999, -11879.915, -11855.856000000002, -11831.316, -11806.295, -11780.793, -11754.809, -11728.343, -11701.396, -11673.966, -11646.053999999998, -11617.658000000001, -11588.78, -11559.417, -11529.571000000002, -11499.24, -11468.423999999999, -11437.122, -11405.335, -11373.062, -11340.302, -11307.053999999998, -11273.319, -11239.095, -11204.382, -11169.18, -11133.487, -11097.303999999998, -11060.63, -11023.464, -10985.805, -10947.652, -10909.006000000001, -10869.865, -10830.228000000001, -10790.095, -10749.466, -10708.338, -10666.711000000001, -10624.586000000001, -10581.958999999999, -10538.832, -10495.203000000001, -10451.07, -10406.434000000001, -10361.293, -10315.645, -10269.491, -10222.829, -10175.659, -10127.978000000001, -10079.787, -10031.083, -9981.867, -9932.136, -9881.89, -9831.127, -9779.847, -9728.046999999999, -9675.728000000001, -9622.886999999999, -9569.523000000001, -9515.635, -9461.222, -9406.283000000001, -9350.815, -9294.818000000001, -9238.29, -9181.231, -9123.636999999999, -9065.509, -9006.845, -8947.642, -8887.9, -8827.617, -8766.791, -8705.421, -8643.506, -8581.043, -8518.030999999999, -8454.469000000001, -8390.354, -8325.685, -8260.46, -8194.678, -8128.335999999999, -8061.433000000001, -7993.968000000001, -7925.938, -7857.340999999999, -7788.1759999999995, -7718.441999999999, -7648.134, -7577.253000000001, -7505.795999999999, -7433.762, -7361.147, -7287.951, -7214.170999999999, -7139.805, -7064.852, -6989.308000000001, -6913.173000000001, -6836.444, -6759.12, -6681.198, -6602.6759999999995, -6523.552, -6443.825, -6363.491, -6282.55, -6200.999, -6118.835, -6036.058000000001, -5952.665, -5868.654, -5784.023, -5698.771, -5612.894, -5526.393, -5439.263000000001, -5351.505999999999, -5263.116999999999, -5174.097, -5084.442, -4994.152, -4903.225, -4811.66, -4719.456, -4626.611, -4533.125, -4438.996, -4344.224, -4248.808, -4152.748, -4056.0429999999997, -3958.6940000000004, -3860.7, -3762.063, -3662.782, -3562.86, -3462.296, -3361.093, -3259.252, -3156.776, -3053.6679999999997, -2949.9320000000002, -2845.57, -2740.587, -2634.989, -2528.781, -2421.969, -2314.56, -2206.564, -2097.988, -1988.8429999999998, -1879.14, -1768.892, -1658.1129999999998, -1546.817, -1435.021, -1322.745, -1210.009, -1096.836, -983.2510000000001, -869.2810000000001, -754.957, -640.313, -525.386, -410.216, -294.847, -179.331, -63.718999999999994, 51.927, 167.542, 283.055, 398.385, 513.445, 628.139, 742.3610000000001, 855.995, 968.913, 1080.973, 1192.021, 1301.886, 1410.382, 1517.3029999999999, 1622.4260000000002, 1725.504, 1826.2679999999998, 1924.4260000000002, 2019.6589999999999, 2111.624, 2199.946, 2284.23, 2364.047, 2438.945, 2508.449, 2572.065, 2629.282, 2679.585, 2722.458, 2757.3990000000003, 2783.929, 2801.6090000000004, 2810.0490000000004, 2808.93, 2798.01, 2777.1420000000003, 2746.2740000000003, 2705.465, 2654.8740000000003, 2594.762, 2525.4829999999997, 2447.469, 2361.22, 2267.2870000000003, 2166.255, 2058.725, 1945.306, 1826.5970000000002, 1703.185, 1575.625, 1444.4489999999998, 1310.15, 1173.187, 1033.984, 892.925, 750.362, 606.613, 461.961, 316.665, 170.952, 25.026999999999997, -120.928, -266.753, -412.306, -557.461, -702.1060000000001, -846.1460000000001, -989.4939999999999, -1132.076, -1273.827, -1414.691, -1554.618, -1693.567, -1831.5, -1968.3870000000002, -2104.203, -2238.925, -2372.535, -2505.018, -2636.361, -2766.555, -2895.594, -3023.47, -3150.183, -3275.73, -3400.111, -3523.325, -3645.3759999999997, -3766.2670000000003, -3886.0, -4004.5820000000003, -4122.015, -4238.307, -4353.464, -4467.4929999999995, -4580.4, -4692.192, -4802.878, -4912.464, -5020.96, -5128.371, -5234.709, -5339.98, -5444.193, -5547.357, -5649.479, -5750.568, -5850.633000000001, -5949.682, -6047.723000000001, -6144.765, -6240.816, -6335.884, -6429.978, -6523.106, -6615.276, -6706.495, -6796.772, -6886.1140000000005, -6974.529, -7062.024, -7148.607, -7234.286, -7319.069, -7402.960999999999, -7485.97, -7568.104, -7649.369000000001, -7729.772, -7809.32, -7888.019, -7965.876, -8042.897, -8119.088000000001, -8194.457, -8269.009, -8342.75, -8415.686, -8487.823, -8559.167, -8629.724, -8699.498, -8768.496, -8836.722, -8904.183, -8970.883, -9036.828000000001, -9102.023000000001, -9166.473, -9230.181999999999, -9293.155999999999, -9355.399, -9416.917, -9477.713, -9537.792, -9597.159, -9655.818000000001, -9713.773000000001, -9771.029, -9827.589, -9883.458, -9938.64, -9993.14, -10046.961, -10100.106, -10152.58, -10204.386, -10255.529, -10306.011, -10355.836, -10405.008, -10453.530999999999, -10501.407, -10548.639, -10595.232, -10641.188, -10686.511999999999, -10731.205, -10775.271, -10818.713, -10861.534, -10903.737, -10945.325, -10986.3, -11026.666000000001, -11066.425, -11105.58, -11144.133999999998, -11182.089, -11219.448, -11256.213, -11292.386999999999, -11327.972, -11362.971000000001, -11397.386, -11431.22, -11464.475, -11497.153, -11529.257, -11560.788, -11591.749, -11622.141000000001, -11651.968, -11681.231000000002, -11709.931, -11738.072, -11765.655, -11792.681999999999, -11819.155, -11845.075, -11870.444, -11895.266000000001, -11919.54, -11943.27, -11966.456, -11989.101, -12011.205, -12032.771, -12053.8, -12074.295, -12094.255, -12113.683, -12132.581, -12150.948999999999, -12168.79, -12186.105, -12202.893999999998, -12219.16, -12234.903, -12250.126, -12264.828000000001, -12279.013, -12292.681, -12305.833, -12318.47, -12330.593, -12342.204, -12353.303999999998, -12363.893999999998, -12373.975, -12383.546999999999, -12392.613000000001, -12401.173, -12409.226999999999, -12416.777, -12423.825, -12430.371000000001, -12436.415, -12441.958999999999, -12447.003999999999, -12451.55, -12455.598, -12459.149, -12462.205, -12464.764, -12466.829, -12468.401000000002, -12469.479, -12470.063999999998, -12470.158000000001, -12469.76, -12468.872, -12467.493999999999, -12465.627, -12463.271, -12460.426000000001, -12457.094, -12453.275, -12448.969, -12444.177, -12438.9, -12433.136999999999, -12426.889, -12420.157, -12412.941, -12405.241000000002, -12397.058, -12388.393, -12379.245, -12369.614, -12359.502, -12348.908000000001, -12337.833, -12326.277, -12314.239, -12301.721000000001, -12288.723, -12275.243999999999, -12261.285, -12246.846000000001, -12231.927, -12216.528999999999, -12200.65, -12184.292, -12167.455, -12150.138, -12132.341999999999, -12114.066, -12095.31, -12076.076000000001, -12056.361, -12036.167, -12015.493999999999, -11994.341, -11972.707, -11950.594, -11928.001, -11904.927, -11881.373, -11857.339, -11832.823999999999, -11807.828000000001, -11782.35, -11756.392, -11729.951000000001, -11703.028, -11675.623, -11647.735, -11619.364, -11590.51, -11561.171999999999, -11531.35, -11501.044, -11470.252, -11438.975, -11407.212, -11374.963, -11342.226999999999, -11309.003999999999, -11275.293, -11241.093, -11206.405, -11171.226999999999, -11135.559, -11099.4, -11062.75, -11025.607, -10987.972, -10949.843, -10911.221000000001, -10872.104, -10832.491000000002, -10792.382, -10751.776000000002, -10710.671999999999, -10669.069, -10626.966999999999, -10584.365, -10541.261, -10497.655, -10453.546, -10408.934000000001, -10363.815999999999, -10318.192, -10272.062, -10225.424, -10178.277, -10130.62, -10082.452, -10033.771999999999, -9984.579, -9934.871, -9884.648000000001, -9833.909, -9782.652, -9730.875, -9678.578000000001, -9625.76, -9572.42, -9518.555, -9464.165, -9409.249, -9353.804, -9297.83, -9241.326, -9184.289, -9126.719000000001, -9068.614, -9009.972, -8950.792, -8891.073, -8830.812, -8770.009, -8708.662, -8646.769, -8584.329, -8521.34, -8457.8, -8393.707, -8329.061, -8263.858, -8198.099, -8131.78, -8064.899, -7997.456, -7929.448, -7860.8730000000005, -7791.731, -7722.018, -7651.733, -7580.874, -7509.439, -7437.4259999999995, -7364.834, -7291.659000000001, -7217.901, -7143.557, -7068.625, -6993.104, -6916.991, -6840.284000000001, -6762.981, -6685.08, -6606.58, -6527.477, -6447.771, -6367.459, -6286.539000000001, -6205.008000000001, -6122.865, -6040.109, -5956.736, -5872.746, -5788.1359999999995, -5702.904, -5617.048000000001, -5530.566999999999, -5443.459, -5355.721, -5267.353, -5178.353, -5088.718, -4998.448, -4907.541, -4815.995, -4723.81, -4630.985, -4537.517, -4443.407, -4348.654, -4253.2570000000005, -4157.215, -4060.5290000000005, -3963.197, -3865.2209999999995, -3766.6009999999997, -3667.3379999999997, -3567.4320000000002, -3466.885, -3365.698, -3263.8740000000003, -3161.414, -3058.322, -2954.6, -2850.2529999999997, -2745.284, -2639.7, -2533.505, -2426.706, -2319.31, -2211.326, -2102.761, -1993.6270000000002, -1883.934, -1773.694, -1662.9229999999998, -1551.634, -1439.845, -1327.5729999999999, -1214.8410000000001, -1101.671, -988.087, -874.118, -759.793, -645.146, -530.214, -415.038, -299.66200000000003, -184.13400000000001, -68.51, 47.152, 162.785, 278.319, 393.67400000000004, 508.76300000000003, 623.49, 737.7489999999999, 851.424, 964.388, 1076.5, 1187.606, 1297.537, 1406.105, 1513.1070000000002, 1618.319, 1721.495, 1822.369, 1920.646, 2016.0120000000002, 2108.1220000000003, 2196.605, 2281.062, 2361.069, 2436.174, 2505.903, 2569.761, 2627.24, 2677.823, 2720.9959999999996, 2756.2529999999997, 2783.117, 2801.1459999999997, 2809.948, 2809.203, 2798.664, 2778.18, 2747.699, 2707.272, 2657.0570000000002, 2597.312, 2528.384, 2450.7070000000003, 2364.777, 2271.143, 2170.386, 2063.112, 1949.925, 1831.4289999999999, 1708.2079999999999, 1580.819, 1449.7939999999999, 1315.63, 1178.785, 1039.684, 898.7139999999999, 756.225, 612.539, 467.94, 322.687, 177.00799999999998, 31.11, -114.82600000000001, -260.639, -406.184, -551.337, -695.985, -840.0319999999999, -983.39, -1125.986, -1267.754, -1408.6370000000002, -1548.7079999999999, -1687.559, -1825.519, -1962.434, -2098.279, -2233.032, -2366.674, -2499.189, -2630.566, -2760.795, -2889.869, -3017.782, -3144.532, -3270.116, -3394.534, -3517.7870000000003, -3639.8759999999997, -3760.805, -3880.578, -3999.198, -4116.6720000000005, -4233.003, -4348.2, -4462.269, -4575.215, -4687.045999999999, -4797.772, -4907.398, -5015.934, -5123.3859999999995, -5229.764, -5335.075, -5439.328, -5542.531, -5644.691999999999, -5745.821, -5845.9259999999995, -5945.014, -6043.094, -6140.175, -6236.265, -6331.3730000000005, -6425.505999999999, -6518.673000000001, -6610.880999999999, -6702.138000000001, -6792.453, -6881.834, -6970.286999999999, -7057.821, -7144.441999999999, -7230.16, -7314.979, -7398.909000000001, -7481.956, -7564.1269999999995, -7645.429, -7725.869000000001, -7805.453, -7884.189, -7962.0830000000005, -8039.141, -8115.369000000001, -8190.775, -8265.363000000001, -8339.14, -8412.112, -8484.285, -8555.665, -8626.257, -8696.065999999999, -8765.1, -8833.360999999999, -8900.857, -8967.591999999999, -9033.573, -9098.802, -9163.287, -9227.030999999999, -9290.04, -9352.317, -9413.869, -9474.699, -9534.812, -9594.213, -9652.905999999999, -9710.895, -9768.185, -9824.779, -9880.681999999999, -9935.898000000001, -9990.431, -10044.285, -10097.463, -10149.97, -10201.809000000001, -10252.984, -10303.499, -10353.357, -10402.561, -10451.116, -10499.025, -10546.29, -10592.915, -10638.903999999999, -10684.258999999998, -10728.985, -10773.083, -10816.556999999999, -10859.409, -10901.643999999998, -10943.263, -10984.27, -11024.668, -11064.458, -11103.645, -11142.229, -11180.215, -11217.604, -11254.401000000002, -11290.606000000002, -11326.222, -11361.252, -11395.698, -11429.563, -11462.848, -11495.556999999999, -11527.691, -11559.252, -11590.243, -11620.666000000001, -11650.523000000001, -11679.816, -11708.546, -11736.716999999999, -11764.33, -11791.386999999999, -11817.889, -11843.839, -11869.239, -11894.09, -11918.393999999998, -11942.153, -11965.368999999999, -11988.042, -12010.176000000001, -12031.771, -12052.829, -12073.351999999999, -12093.341999999999, -12112.798999999999, -12131.726, -12150.123, -12167.993, -12185.336000000001, -12202.153999999999, -12218.448999999999, -12234.221000000001, -12249.472, -12264.204, -12278.417, -12292.113000000001, -12305.293, -12317.958, -12330.11, -12341.749, -12352.877, -12363.495, -12373.604, -12383.205, -12392.298, -12400.886, -12408.968, -12416.546, -12423.621000000001, -12430.195, -12436.267, -12441.838, -12446.911, -12451.483999999999, -12455.56, -12459.139, -12462.221000000001, -12464.808, -12466.901000000002, -12468.499, -12469.604, -12470.216999999999, -12470.338, -12469.966999999999, -12469.106000000002, -12467.755, -12465.915, -12463.585, -12460.768, -12457.463, -12453.67, -12449.391000000001, -12444.626, -12439.375, -12433.639, -12427.418, -12420.712, -12413.521999999999, -12405.848999999998, -12397.692, -12389.053, -12379.931, -12370.327, -12360.241000000002, -12349.673, -12338.624, -12327.094, -12315.083, -12302.591, -12289.618, -12276.165, -12262.232, -12247.819, -12232.926000000001, -12217.553, -12201.701000000001, -12185.368999999999, -12168.556999999999, -12151.266000000001, -12133.495, -12115.243999999999, -12096.515, -12077.305, -12057.617, -12037.448, -12016.8, -11995.671999999999, -11974.063999999998, -11951.976, -11929.408000000001, -11906.36, -11882.831, -11858.822, -11834.332, -11809.361, -11783.908000000001, -11757.973999999998, -11731.559, -11704.661, -11677.281, -11649.418, -11621.072, -11592.242, -11562.928999999998, -11533.132, -11502.85, -11472.083, -11440.831, -11409.093, -11376.868, -11344.156, -11310.958, -11277.271, -11243.096000000001, -11208.431999999999, -11173.278, -11137.633999999998, -11101.5, -11064.874, -11027.756000000001, -10990.143999999998, -10952.04, -10913.442, -10874.348, -10834.76, -10794.675, -10754.093, -10713.013, -10671.434, -10629.356000000002, -10586.777, -10543.697, -10500.115, -10456.03, -10411.440999999999, -10366.347, -10320.748, -10274.641, -10228.026, -10180.903, -10133.269, -10085.125, -10036.468, -9987.298, -9937.614, -9887.415, -9836.699, -9785.465, -9733.711, -9681.438, -9628.643, -9575.326, -9521.484, -9467.117, -9412.224, -9356.802, -9300.851999999999, -9244.37, -9187.356, -9129.809000000001, -9071.726, -9013.107, -8953.95, -8894.254, -8834.016, -8773.235999999999, -8711.911, -8650.041, -8587.623, -8524.657, -8461.139000000001, -8397.069, -8332.445, -8267.265, -8201.528, -8135.231, -8068.3730000000005, -8000.951, -7932.965, -7864.4130000000005, -7795.293000000001, -7725.602, -7655.339, -7584.5019999999995, -7513.089, -7441.097, -7368.526999999999, -7295.374, -7221.637, -7147.315, -7072.405, -6996.905, -6920.813, -6844.128000000001, -6766.846, -6688.967, -6610.486999999999, -6531.406, -6451.721, -6371.43, -6290.53, -6209.021, -6126.898, -6044.161999999999, -5960.811, -5876.840999999999, -5792.251, -5707.04, -5621.204000000001, -5534.743, -5447.655, -5359.937, -5271.589, -5182.608, -5092.9929999999995, -5002.742, -4911.854, -4820.3279999999995, -4728.162, -4635.355, -4541.906, -4447.815, -4353.08, -4257.701, -4161.677, -4065.008, -3967.6940000000004, -3869.736, -3771.133, -3671.886, -3571.9970000000003, -3471.466, -3370.295, -3268.486, -3166.042, -3062.9640000000004, -2959.257, -2854.9240000000004, -2749.969, -2644.3979999999997, -2538.216, -2431.429, -2324.045, -2216.071, -2107.5170000000003, -1998.3929999999998, -1888.7089999999998, -1778.4779999999998, -1667.714, -1556.432, -1444.648, -1332.381, -1219.653, -1106.485, -992.9019999999999, -878.932, -764.6060000000001, -649.956, -535.019, -419.835, -304.45, -188.912, -73.274, 42.403999999999996, 158.05700000000002, 273.612, 388.99300000000005, 504.11, 618.869, 733.166, 846.883, 959.8939999999999, 1072.058, 1183.222, 1293.218, 1401.859, 1508.941, 1614.2420000000002, 1717.516, 1818.4979999999998, 1916.894, 2012.391, 2104.645, 2193.286, 2277.916, 2358.111, 2433.4210000000003, 2503.371, 2567.47, 2625.2070000000003, 2676.066, 2719.534, 2755.1040000000003, 2782.298, 2800.671, 2809.8309999999997, 2809.455, 2799.292, 2779.1890000000003, 2749.09, 2709.042, 2659.199, 2599.815, 2531.237, 2453.893, 2368.278, 2274.939, 2174.4570000000003, 2067.436, 1954.481, 1836.1960000000001, 1713.165, 1585.9460000000001, 1455.0729999999999, 1321.043, 1184.316, 1045.317, 904.435, 762.0219999999999, 618.399, 473.85400000000004, 328.644, 183.0, 37.129, -108.787, -254.58599999999998, -400.124, -545.274, -689.924, -833.9760000000001, -977.345, -1119.953, -1261.737, -1402.639, -1542.609, -1681.605, -1819.59, -1956.533, -2092.406, -2227.189, -2360.861, -2493.409, -2624.8190000000004, -2755.0820000000003, -2884.191, -3012.139, -3138.9240000000004, -3264.545, -3389.0, -3512.29, -3634.417, -3755.384, -3875.195, -3993.8540000000003, -4111.366, -4227.737, -4342.973, -4457.08, -4570.065, -4681.936, -4792.701, -4902.367, -5010.942, -5118.433, -5224.85, -5330.2, -5434.491999999999, -5537.735, -5639.936, -5741.103, -5841.246999999999, -5940.374, -6038.493, -6135.613, -6231.741999999999, -6326.888000000001, -6421.059, -6514.264, -6606.5109999999995, -6697.807, -6788.16, -6877.578, -6966.069, -7053.641, -7140.3, -7226.055, -7310.911999999999, -7394.879, -7477.963000000001, -7560.17, -7641.509, -7721.986, -7801.608, -7880.38, -7958.31, -8035.404, -8111.669, -8187.11, -8261.735, -8335.548, -8408.556, -8480.764000000001, -8552.18, -8622.806999999999, -8692.652, -8761.72, -8830.017, -8897.548, -8964.318000000001, -9030.333, -9095.598, -9160.117, -9223.895, -9286.938, -9349.25, -9410.836, -9471.7, -9531.848, -9591.282, -9650.009, -9708.030999999999, -9765.355, -9821.982, -9877.919, -9933.168, -9987.734, -10041.621, -10094.833, -10147.372, -10199.244, -10250.452, -10301.0, -10350.89, -10400.128, -10448.715, -10496.655, -10543.953000000001, -10590.61, -10636.631000000001, -10682.018999999998, -10726.776000000002, -10770.906, -10814.412, -10857.296, -10899.562, -10941.213, -10982.252, -11022.68, -11062.502, -11101.72, -11140.336000000001, -11178.351999999999, -11215.773000000001, -11252.6, -11288.836000000001, -11324.483, -11359.544, -11394.021, -11427.916000000001, -11461.232, -11493.971000000001, -11526.135, -11557.726999999999, -11588.748, -11619.202, -11649.088, -11678.411, -11707.171999999999, -11735.373, -11763.016000000001, -11790.101999999999, -11816.633999999998, -11842.614, -11868.044, -11892.923999999999, -11917.258, -11941.046999999999, -11964.292, -11986.993999999999, -12009.157, -12030.781, -12051.868999999999, -12072.421, -12092.44, -12111.926000000001, -12130.882, -12149.308, -12167.206, -12184.578000000001, -12201.425, -12217.749, -12233.548999999999, -12248.829, -12263.59, -12277.831, -12291.556, -12304.764, -12317.458, -12329.638, -12341.305, -12352.462, -12363.108, -12373.243999999999, -12382.873, -12391.995, -12400.61, -12408.72, -12416.326000000001, -12423.428999999998, -12430.03, -12436.13, -12441.729, -12446.829, -12451.43, -12455.534, -12459.14, -12462.25, -12464.864, -12466.983999999999, -12468.61, -12469.742, -12470.382, -12470.53, -12470.187, -12469.353000000001, -12468.028999999999, -12466.215, -12463.913, -12461.122, -12457.844, -12454.078000000001, -12449.826000000001, -12445.087, -12439.863000000001, -12434.153, -12427.958999999999, -12421.28, -12414.117, -12406.47, -12398.34, -12389.726999999999, -12380.632, -12371.053999999998, -12360.993999999999, -12350.453000000001, -12339.43, -12327.926000000001, -12315.94, -12303.475, -12290.528, -12277.101, -12263.194, -12248.806999999999, -12233.94, -12218.593, -12202.766000000001, -12186.46, -12169.673999999999, -12152.408000000001, -12134.663, -12116.438999999998, -12097.733999999999, -12078.551000000001, -12058.886999999999, -12038.743999999999, -12018.122, -11997.018999999998, -11975.437, -11953.374, -11930.831, -11907.808, -11884.305, -11860.321000000002, -11835.856000000002, -11810.91, -11785.483, -11759.573999999999, -11733.183, -11706.311000000002, -11678.955, -11651.117, -11622.796, -11593.992, -11564.703000000001, -11534.931, -11504.673999999999, -11473.931999999999, -11442.704, -11410.99, -11378.79, -11346.104, -11312.928999999998, -11279.267, -11245.117, -11210.476999999999, -11175.348, -11139.728000000001, -11103.618, -11067.016000000001, -11029.923, -10992.336000000001, -10954.255, -10915.681, -10876.612, -10837.048, -10796.987, -10756.428999999998, -10715.373, -10673.818000000001, -10631.764, -10589.208999999999, -10546.153, -10502.595, -10458.534, -10413.969000000001, -10368.899, -10323.322, -10277.239, -10230.648000000001, -10183.549, -10135.939, -10087.818000000001, -10039.185, -9990.039, -9940.378, -9890.202, -9839.509, -9788.298, -9736.568000000001, -9684.318000000001, -9631.546, -9578.252, -9524.434000000001, -9470.09, -9415.22, -9359.822, -9303.894, -9247.435, -9190.444, -9132.92, -9074.86, -9016.264000000001, -8957.13, -8897.456, -8837.241, -8776.484, -8715.181999999999, -8653.334, -8590.939, -8527.995, -8464.5, -8400.452, -8335.85, -8270.693000000001, -8204.978000000001, -8138.703, -8071.866999999999, -8004.468000000001, -7936.504, -7867.974, -7798.876, -7729.206999999999, -7658.965999999999, -7588.151, -7516.759, -7444.79, -7372.241, -7299.11, -7225.395, -7151.094, -7076.206, -7000.727, -6924.656999999999, -6847.993, -6770.732, -6692.874, -6614.416, -6535.356, -6455.691999999999, -6375.420999999999, -6294.543000000001, -6213.054, -6130.951999999999, -6048.236999999999, -5964.906, -5880.956999999999, -5796.387, -5711.196, -5625.38, -5538.94, -5451.871, -5364.173000000001, -5275.844, -5186.883, -5097.287, -5007.056, -4916.187, -4824.68, -4732.532999999999, -4639.745, -4546.315, -4452.242, -4357.525, -4262.164000000001, -4166.157999999999, -4069.507, -3972.21, -3874.2690000000002, -3775.683, -3676.453, -3576.58, -3476.065, -3374.91, -3273.117, -3170.687, -3067.6240000000003, -2963.9309999999996, -2859.612, -2754.671, -2649.113, -2542.944, -2436.169, -2328.7960000000003, -2220.834, -2112.29, -2003.175, -1893.5, -1783.277, -1672.52, -1561.245, -1449.4660000000001, -1337.204, -1224.479, -1111.313, -997.7310000000001, -883.7610000000001, -769.433, -654.779, -539.837, -424.64599999999996, -309.252, -193.702, -78.05, 37.644, 153.315, 268.893, 384.29900000000004, 499.44599999999997, 614.238, 728.571, 842.33, 955.388, 1067.605, 1178.828, 1288.889, 1397.602, 1504.765, 1610.155, 1713.527, 1814.6170000000002, 1913.1329999999998, 2008.761, 2101.159, 2189.9570000000003, 2274.76, 2355.143, 2430.658, 2500.83, 2565.169, 2623.165, 2674.301, 2718.0640000000003, 2753.947, 2781.4709999999995, 2800.1890000000003, 2809.708, 2809.7009999999996, 2799.9159999999997, 2780.195, 2750.4790000000003, 2710.8109999999997, 2661.342, 2602.323, 2534.095, 2457.087, 2371.7889999999998, 2278.748, 2178.5429999999997, 2071.778, 1959.057, 1840.985, 1718.146, 1591.099, 1460.38, 1326.485, 1189.877, 1050.982, 910.19, 767.8539999999999, 624.2959999999999, 479.806, 334.64, 189.033, 43.18899999999999, -102.706, -248.49, -394.02, -539.1659999999999, -683.817, -827.875, -971.253, -1113.874, -1255.673, -1396.594, -1536.585, -1675.604, -1813.6129999999998, -1950.5829999999999, -2086.485, -2221.297, -2355.0, -2487.58, -2619.0229999999997, -2749.32, -2878.4629999999997, -3006.446, -3133.268, -3258.925, -3383.417, -3506.744, -3628.909, -3749.915, -3869.764, -3988.461, -4106.012, -4222.4220000000005, -4337.697, -4451.843, -4564.8679999999995, -4676.779, -4787.583, -4897.288, -5005.902, -5113.434, -5219.89, -5325.28, -5429.611, -5532.893, -5635.133000000001, -5736.34, -5836.523, -5935.69, -6033.848000000001, -6131.005999999999, -6227.174, -6322.359, -6416.57, -6509.813, -6602.098000000001, -6693.433000000001, -6783.8240000000005, -6873.281, -6961.81, -7049.419, -7136.116999999999, -7221.909000000001, -7306.804, -7390.809, -7473.93, -7556.175, -7637.5509999999995, -7718.065, -7797.724, -7876.533, -7954.5, -8031.630999999999, -8107.932, -8183.41, -8258.071, -8331.92, -8404.964, -8477.209, -8548.66, -8619.323, -8689.204, -8758.308, -8826.64, -8894.206, -8961.011999999999, -9027.062, -9092.360999999999, -9156.915, -9220.729, -9283.806999999999, -9346.153, -9407.774, -9468.671999999999, -9528.854, -9588.323, -9647.084, -9705.14, -9762.498, -9819.159, -9875.13, -9930.413, -9985.011999999999, -10038.933, -10092.178, -10144.751, -10196.655999999999, -10247.896999999999, -10298.476999999999, -10348.401, -10397.671, -10446.291, -10494.265, -10541.595, -10588.285, -10634.339, -10679.758, -10724.548, -10768.71, -10812.248, -10855.165, -10897.463, -10939.146, -10980.216, -11020.677, -11060.53, -11099.778999999999, -11138.427, -11176.475, -11213.927, -11250.786, -11287.053, -11322.731000000002, -11357.823, -11392.331, -11426.258, -11459.605, -11492.375, -11524.57, -11556.192, -11587.243999999999, -11617.728000000001, -11647.646, -11676.999, -11705.79, -11734.021, -11761.694, -11788.811000000002, -11815.374, -11841.383999999998, -11866.843, -11891.753999999999, -11916.118, -11939.936000000002, -11963.211000000001, -11985.944, -12008.136, -12029.79, -12050.907, -12071.489, -12091.537, -12111.053, -12130.038, -12148.493999999999, -12166.421, -12183.823, -12200.698999999999, -12217.051000000001, -12232.881000000001, -12248.19, -12262.979, -12277.25, -12291.003, -12304.241000000002, -12316.963, -12329.171999999999, -12340.868, -12352.053, -12362.728000000001, -12372.893, -12382.55, -12391.7, -12400.344, -12408.483, -12416.117, -12423.248, -12429.877, -12436.005, -12441.633, -12446.761, -12451.39, -12455.521, -12459.155, -12462.293, -12464.936000000002, -12467.083, -12468.737, -12469.896999999999, -12470.563999999998, -12470.74, -12470.423999999999, -12469.618, -12468.321000000002, -12466.535, -12464.26, -12461.497, -12458.246000000001, -12454.508, -12450.283000000001, -12445.571000000002, -12440.374, -12434.692, -12428.524, -12421.873, -12414.737, -12407.117, -12399.013, -12390.427, -12381.358999999999, -12371.808, -12361.775, -12351.26, -12340.264, -12328.787, -12316.828000000001, -12304.389, -12291.469, -12278.069, -12264.188, -12249.827, -12234.987, -12219.666000000001, -12203.866000000002, -12187.586000000001, -12170.826000000001, -12153.586000000001, -12135.868, -12117.669, -12098.991000000002, -12079.833, -12060.196000000002, -12040.079, -12019.483, -11998.406, -11976.848999999998, -11954.813, -11932.296, -11909.298, -11885.821000000002, -11861.863000000001, -11837.423999999999, -11812.503, -11787.101999999999, -11761.218, -11734.853000000001, -11708.006000000001, -11680.676000000001, -11652.864, -11624.568000000001, -11595.788999999999, -11566.526000000002, -11536.778999999999, -11506.546999999999, -11475.83, -11444.628, -11412.938999999998, -11380.764, -11348.103000000001, -11314.954, -11281.317, -11247.191, -11212.576000000001, -11177.472, -11141.878, -11105.792, -11069.216, -11032.146999999999, -10994.583999999999, -10956.528999999999, -10917.979, -10878.935, -10839.395, -10799.358999999999, -10758.826000000001, -10717.794, -10676.264, -10634.235, -10591.704, -10548.673, -10505.139, -10461.101999999999, -10416.561, -10371.516, -10325.964, -10279.905, -10233.338, -10186.263, -10138.677, -10090.58, -10041.971, -9992.849, -9943.212, -9893.06, -9842.391, -9791.205, -9739.499, -9687.271999999999, -9634.524, -9581.254, -9527.46, -9473.14, -9418.293, -9362.918, -9307.014000000001, -9250.579, -9193.612, -9136.110999999999, -9078.075, -9019.502, -8960.391, -8900.741, -8840.549, -8779.815, -8718.537, -8656.712, -8594.34, -8531.419, -8467.947, -8403.923, -8339.344000000001, -8274.209, -8208.517, -8142.266, -8075.453, -8008.076999999999, -7940.135, -7871.628000000001, -7802.552, -7732.906, -7662.687, -7591.895, -7520.526, -7448.579000000001, -7376.053000000001, -7302.944, -7229.251, -7154.973000000001, -7080.106, -7004.65, -6928.602, -6851.96, -6774.721, -6696.885, -6618.4490000000005, -6539.41, -6459.768, -6379.519, -6298.661999999999, -6217.195, -6135.115, -6052.420999999999, -5969.111, -5885.182, -5800.634, -5715.464, -5629.669, -5543.249, -5456.201, -5368.524, -5280.215999999999, -5191.275, -5101.6990000000005, -5011.488, -4920.639, -4829.152, -4737.024, -4644.255999999999, -4550.845, -4456.791, -4362.093, -4266.751, -4170.763, -4074.131, -3976.8520000000003, -3878.929, -3780.36, -3681.1479999999997, -3581.292, -3480.7940000000003, -3379.656, -3277.8779999999997, -3175.465, -3072.4179999999997, -2968.74, -2864.4359999999997, -2759.509, -2653.9640000000004, -2547.808, -2441.0460000000003, -2333.686, -2225.735, -2117.202, -2008.0970000000002, -1898.432, -1788.2179999999998, -1677.469, -1566.2, -1454.4279999999999, -1342.171, -1229.45, -1116.287, -1002.706, -888.7360000000001, -774.4060000000001, -659.75, -544.802, -429.605, -314.202, -198.641, -82.976, 32.735, 148.42600000000002, 264.026, 379.457, 494.63300000000004, 609.4580000000001, 723.829, 837.6310000000001, 950.7360000000001, 1063.007, 1174.2910000000002, 1284.4180000000001, 1393.2060000000001, 1500.45, 1605.931, 1709.404, 1810.605, 1909.243, 2005.006, 2097.552, 2186.513, 2271.493, 2352.07, 2427.7960000000003, 2498.197, 2562.783, 2621.0460000000003, 2672.468, 2716.5359999999996, 2752.742, 2780.607, 2799.683, 2809.573, 2809.948, 2800.554, 2781.228, 2751.909, 2712.636, 2663.554, 2604.913, 2537.05, 2460.389, 2375.4210000000003, 2282.689, 2182.772, 2076.272, 1963.795, 1845.944, 1723.3039999999999, 1596.4370000000001, 1465.8770000000002, 1332.1229999999998, 1195.638, 1056.851, 916.1519999999999, 773.8969999999999, 630.4069999999999, 485.972, 340.853, 195.282, 49.468, -96.406, -242.176, -387.69599999999997, -532.839, -677.492, -821.556, -964.944, -1107.579, -1249.395, -1390.3339999999998, -1530.0710000000001, -1669.39, -1807.4260000000002, -1944.424, -2080.355, -2215.198, -2348.9339999999997, -2481.547, -2613.024, -2743.3559999999998, -2872.535, -3000.5559999999996, -3127.415, -3253.111, -3377.6409999999996, -3501.008, -3623.212, -3744.257, -3864.1459999999997, -3982.884, -4100.475, -4216.9259999999995, -4332.241, -4446.428, -4559.494000000001, -4671.446, -4782.291, -4892.038, -5000.693, -5108.265, -5214.763, -5320.193, -5424.566, -5527.889, -5630.17, -5731.418000000001, -5831.641, -5930.847, -6029.045999999999, -6126.246, -6222.454000000001, -6317.68, -6411.93, -6505.214, -6597.539000000001, -6688.9130000000005, -6779.344, -6868.840999999999, -6957.409000000001, -7045.058000000001, -7131.795, -7217.626, -7302.56, -7386.603, -7469.763000000001, -7552.048000000001, -7633.4619999999995, -7714.015, -7793.7119999999995, -7872.559, -7950.564, -8027.733, -8104.071999999999, -8179.588000000001, -8254.286, -8328.173, -8401.254, -8473.536, -8545.024, -8615.724, -8685.642, -8754.782, -8823.151, -8890.754, -8957.596, -9023.683, -9089.018, -9153.608, -9217.458, -9280.571, -9342.954, -9404.61, -9465.544, -9525.761, -9585.265, -9644.061, -9702.153, -9759.545, -9816.242, -9872.247, -9927.565, -9982.199, -10036.154, -10089.433, -10142.04, -10193.98, -10245.255, -10295.87, -10345.828000000001, -10395.132, -10443.786, -10491.793, -10539.157, -10585.88, -10631.966999999999, -10677.42, -10722.243, -10766.438, -10810.008999999998, -10852.958999999999, -10895.29, -10937.006000000001, -10978.108999999999, -11018.601999999999, -11058.488000000001, -11097.77, -11136.45, -11174.531, -11212.015, -11248.906, -11285.205, -11320.916000000001, -11356.04, -11390.58, -11424.538, -11457.916000000001, -11490.718, -11522.945, -11554.598999999998, -11585.681999999999, -11616.198, -11646.146999999999, -11675.531, -11704.354, -11732.616000000002, -11760.32, -11787.468, -11814.061000000002, -11840.101999999999, -11865.593, -11890.534, -11914.928999999998, -11938.777, -11962.082, -11984.845, -12007.069, -12028.753, -12049.901000000002, -12070.513, -12090.591, -12110.136999999999, -12129.152, -12147.638, -12165.596000000001, -12183.027, -12199.933, -12216.315, -12232.175, -12247.513, -12262.332, -12276.632, -12290.415, -12303.681999999999, -12316.434, -12328.671999999999, -12340.398000000001, -12351.612, -12362.315, -12372.51, -12382.196000000002, -12391.375, -12400.048, -12408.216, -12415.878999999999, -12423.038999999999, -12429.697, -12435.854, -12441.51, -12446.666000000001, -12451.323999999999, -12455.483999999999, -12459.146999999999, -12462.313, -12464.983999999999, -12467.159, -12468.841, -12470.03, -12470.725, -12470.928999999998, -12470.641000000001, -12469.863000000001, -12468.594, -12466.836000000001, -12464.589, -12461.854, -12458.631000000001, -12454.92, -12450.723, -12446.038999999999, -12440.87, -12435.215, -12429.075, -12422.451000000001, -12415.341999999999, -12407.75, -12399.673999999999, -12391.115, -12382.073999999999, -12372.55, -12362.544, -12352.056999999999, -12341.088, -12329.636999999999, -12317.706, -12305.294, -12292.401000000002, -12279.027, -12265.173999999999, -12250.84, -12236.026000000002, -12220.732, -12204.958, -12188.705, -12171.972, -12154.758999999998, -12137.067, -12118.895, -12100.243, -12081.112, -12061.501, -12041.41, -12020.84, -11999.79, -11978.26, -11956.249, -11933.758999999998, -11910.788, -11887.336000000001, -11863.403, -11838.99, -11814.096000000001, -11788.72, -11762.863000000001, -11736.523000000001, -11709.702, -11682.398000000001, -11654.611, -11626.341, -11597.588, -11568.35, -11538.628999999999, -11508.421999999999, -11477.731000000002, -11446.553999999998, -11414.891000000001, -11382.742, -11350.105, -11316.982, -11283.37, -11249.268999999998, -11214.68, -11179.601, -11144.032, -11107.971000000001, -11071.42, -11034.376, -10996.839, -10958.808, -10920.284, -10881.264, -10841.749, -10801.738000000001, -10761.229, -10720.222, -10678.716999999999, -10636.712, -10594.206, -10551.2, -10507.69, -10463.678, -10419.162, -10374.14, -10328.613000000001, -10282.578000000001, -10236.036, -10188.985, -10141.423, -10093.351, -10044.766, -9995.668, -9946.055, -9895.927, -9845.283000000001, -9794.12, -9742.438, -9690.235999999999, -9637.511999999999, -9584.265, -9530.494, -9476.198, -9421.375, -9366.024, -9310.143, -9253.732, -9196.788, -9139.311, -9081.298, -9022.749, -8963.662, -8904.035, -8843.867, -8783.155999999999, -8721.9, -8660.099, -8597.75, -8534.851999999999, -8471.403, -8407.402, -8342.846, -8277.735, -8212.065, -8145.8369999999995, -8079.045999999999, -8011.693, -7943.775, -7875.29, -7806.236999999999, -7736.613, -7666.4169999999995, -7595.647, -7524.3, -7452.376, -7379.871999999999, -7306.785, -7233.115, -7158.858, -7084.014, -7008.579000000001, -6932.553000000001, -6855.933000000001, -6778.715999999999, -6700.901999999999, -6622.486999999999, -6543.47, -6463.849, -6383.621999999999, -6302.786, -6221.34, -6139.281999999999, -6056.609, -5973.32, -5889.4130000000005, -5804.884, -5719.734, -5633.960999999999, -5547.561, -5460.533, -5372.876, -5284.588000000001, -5195.667, -5106.112, -5015.92, -4925.090999999999, -4833.623, -4741.515, -4648.765, -4555.373, -4461.338, -4366.659000000001, -4271.335, -4175.366, -4078.7509999999997, -3981.491, -3883.585, -3785.034, -3685.837, -3585.998, -3485.5170000000003, -3384.3940000000002, -3282.633, -3180.235, -3077.202, -2973.539, -2869.2490000000003, -2764.336, -2658.805, -2552.6620000000003, -2445.9120000000003, -2338.563, -2230.623, -2122.101, -2013.006, -1903.35, -1793.144, -1682.402, -1571.14, -1459.374, -1347.121, -1234.404, -1121.243, -1007.663, -893.692, -779.36, -664.699, -549.746, -434.542, -319.129, -203.55599999999998, -87.87700000000001, 27.85, 143.561, 259.183, 374.64099999999996, 489.846, 604.705, 719.1139999999999, 832.959, 946.112, 1058.437, 1169.78, 1279.974, 1388.835, 1496.162, 1601.733, 1705.307, 1806.618, 1905.378, 2001.275, 2093.968, 2183.09, 2268.245, 2349.014, 2424.949, 2495.577, 2560.408, 2618.9339999999997, 2670.638, 2715.008, 2751.534, 2779.736, 2799.165, 2809.422, 2810.175, 2801.167, 2782.2329999999997, 2753.3070000000002, 2714.4240000000004, 2665.7270000000003, 2607.459, 2539.9570000000003, 2463.643, 2379.001, 2286.576, 2186.945, 2080.709, 1968.474, 1850.8429999999998, 1728.402, 1601.714, 1471.3120000000001, 1337.6989999999998, 1201.338, 1062.6589999999999, 922.053, 779.878, 636.456, 492.07800000000003, 347.006, 201.47299999999998, 55.688, -90.164, -235.918, -381.42900000000003, -526.568, -671.222, -815.29, -958.687, -1101.335, -1243.1660000000002, -1384.124, -1524.158, -1663.225, -1801.286, -1938.31, -2074.27, -2209.144, -2342.911, -2475.556, -2607.0679999999998, -2737.434, -2866.6479999999997, -2994.7059999999997, -3121.6020000000003, -3247.3340000000003, -3371.903, -3495.3070000000002, -3617.55, -3738.634, -3858.563, -3977.34, -4094.9709999999995, -4211.462, -4326.817, -4441.044, -4554.151, -4666.143, -4777.029, -4886.816, -4995.512, -5103.124, -5209.662, -5315.134, -5419.547, -5522.91, -5625.231, -5726.52, -5826.784000000001, -5926.03, -6024.269, -6121.509, -6217.757, -6313.023, -6407.313, -6500.6359999999995, -6593.001, -6684.414000000001, -6774.885, -6864.420999999999, -6953.028, -7040.715999999999, -7127.491999999999, -7213.361999999999, -7298.335, -7382.416, -7465.615, -7547.938, -7629.391, -7709.982, -7789.715999999999, -7868.602, -7946.645, -8023.851, -8100.228, -8175.781, -8250.516, -8324.44, -8397.559000000001, -8469.878, -8541.403, -8612.14, -8682.094000000001, -8751.271, -8819.676, -8887.315999999999, -8954.194, -9020.315999999999, -9085.688, -9150.314, -9214.199, -9277.349, -9339.767, -9401.458, -9462.428, -9522.68, -9582.22, -9641.051, -9699.178, -9756.605, -9813.336, -9869.376, -9924.728000000001, -9979.396999999999, -10033.386, -10086.7, -10139.341, -10191.315, -10242.625, -10293.273000000001, -10343.265, -10392.603000000001, -10441.29, -10489.331, -10536.728000000001, -10583.485, -10629.606000000002, -10675.091999999999, -10719.948, -10764.176000000001, -10807.78, -10850.763, -10893.127, -10934.876, -10976.011, -11016.537, -11056.456, -11095.77, -11134.483, -11172.596000000001, -11210.112, -11247.035, -11283.367, -11319.108999999999, -11354.265, -11388.837, -11422.827, -11456.238000000001, -11489.071000000002, -11521.329, -11553.015, -11584.13, -11614.677, -11644.657, -11674.073, -11702.926000000001, -11731.22, -11758.955, -11786.133999999998, -11812.758, -11838.83, -11864.351, -11889.323999999999, -11913.749, -11937.628, -11960.964, -11983.758, -12006.011, -12027.726, -12048.903999999999, -12069.546999999999, -12089.655, -12109.231000000002, -12128.277, -12146.792, -12164.78, -12182.241000000002, -12199.177, -12215.589, -12231.478000000001, -12246.847, -12261.695, -12276.025, -12289.837, -12303.133999999998, -12315.915, -12328.183, -12339.938, -12351.181, -12361.913999999999, -12372.138, -12381.853000000001, -12391.061000000002, -12399.763, -12407.958999999999, -12415.652, -12422.841, -12429.528, -12435.713, -12441.398000000001, -12446.583, -12451.268999999998, -12455.458, -12459.149, -12462.344, -12465.043, -12467.247, -12468.957, -12470.173999999999, -12470.898000000001, -12471.13, -12470.87, -12470.12, -12468.88, -12467.15, -12464.931, -12462.223, -12459.028, -12455.345, -12451.176000000001, -12446.52, -12441.378, -12435.751, -12429.639, -12423.042, -12415.961000000001, -12408.396, -12400.347, -12391.816, -12382.802, -12373.306, -12363.328000000001, -12352.867, -12341.925, -12330.502, -12318.598, -12306.213, -12293.347, -12280.0, -12266.173999999999, -12251.867, -12237.08, -12221.812, -12206.066, -12189.839, -12173.132, -12155.946000000002, -12138.281, -12120.135, -12101.51, -12082.406, -12062.821000000002, -12042.757, -12022.213, -12001.188999999998, -11979.685, -11957.701000000001, -11935.237, -11912.292, -11888.866000000002, -11864.96, -11840.573, -11815.704, -11790.355, -11764.523000000001, -11738.21, -11711.413999999999, -11684.136, -11656.375, -11628.131000000001, -11599.403, -11570.192, -11540.496000000001, -11510.315, -11479.649, -11448.498, -11416.86, -11384.737, -11352.126, -11319.027, -11285.441, -11251.366000000002, -11216.802, -11181.748, -11146.204, -11110.169, -11073.642, -11036.623, -10999.111, -10961.106000000002, -10922.606000000002, -10883.612, -10844.122, -10804.135, -10763.651000000002, -10722.669, -10681.188999999998, -10639.208, -10596.728000000001, -10553.745, -10510.261, -10466.273000000001, -10421.780999999999, -10376.784, -10331.280999999999, -10285.271, -10238.753, -10191.726, -10144.189, -10096.141, -10047.58, -9998.507, -9948.918, -9898.814, -9848.194, -9797.055, -9745.396999999999, -9693.219000000001, -9640.519, -9587.296, -9533.549, -9479.277, -9424.476999999999, -9369.15, -9313.293, -9256.905999999999, -9199.985999999999, -9142.532, -9084.543, -9026.017, -8966.953000000001, -8907.349, -8847.205, -8786.517, -8725.285, -8663.507, -8601.181, -8538.306, -8474.88, -8410.902, -8346.369, -8281.280999999999, -8215.634, -8149.428000000001, -8082.661, -8015.331, -7947.436, -7878.973000000001, -7809.941999999999, -7740.340999999999, -7670.1669999999995, -7599.42, -7528.096, -7456.194, -7383.710999999999, -7310.647, -7236.999, -7162.764, -7087.941999999999, -7012.53, -6936.525, -6859.927, -6782.732, -6704.939, -6626.545999999999, -6547.5509999999995, -6467.951, -6387.745, -6306.931, -6225.505999999999, -6143.469, -6060.816999999999, -5977.549, -5893.661999999999, -5809.155, -5724.025, -5638.272, -5551.893, -5464.8859999999995, -5377.249, -5288.981, -5200.079000000001, -5110.544, -5020.372, -4929.562, -4838.113, -4746.024, -4653.294, -4559.920999999999, -4465.904, -4371.244000000001, -4275.938, -4179.987, -4083.39, -3986.147, -3888.259, -3789.725, -3690.545, -3590.723, -3490.257, -3389.151, -3287.405, -3185.022, -3082.005, -2978.3559999999998, -2874.08, -2769.1809999999996, -2663.663, -2557.532, -2450.795, -2343.4570000000003, -2235.528, -2127.016, -2017.931, -1908.283, -1798.085, -1687.351, -1576.095, -1464.3339999999998, -1352.086, -1239.371, -1126.212, -1012.6339999999999, -898.6619999999999, -784.327, -669.663, -554.7040000000001, -439.49199999999996, -324.069, -208.485, -92.791, 22.953000000000003, 138.683, 254.329, 369.81199999999995, 485.048, 599.941, 714.388, 828.275, 941.477, 1053.855, 1165.258, 1275.519, 1384.454, 1491.8629999999998, 1597.525, 1701.1989999999998, 1802.621, 1901.5020000000002, 1997.533, 2090.373, 2179.656, 2264.987, 2345.948, 2422.092, 2492.946, 2558.022, 2616.812, 2668.8, 2713.4709999999995, 2750.3179999999998, 2778.8579999999997, 2798.64, 2809.265, 2810.397, 2801.777, 2783.237, 2754.705, 2716.2140000000004, 2667.903, 2610.012, 2542.873, 2466.906, 2382.594, 2290.479, 2191.136, 2085.167, 1973.1760000000002, 1855.767, 1733.527, 1607.02, 1476.779, 1343.309, 1207.0739999999998, 1068.504, 927.9939999999999, 785.9, 642.547, 498.228, 353.204, 207.709, 61.955, -83.874, -229.612, -375.11199999999997, -520.246, -664.9, -808.9739999999999, -952.3789999999999, -1095.038, -1236.885, -1377.862, -1517.9160000000002, -1657.006, -1795.092, -1932.1429999999998, -2068.132, -2203.035, -2336.833, -2469.512, -2601.056, -2731.4570000000003, -2860.7070000000003, -2988.8, -3115.7329999999997, -3241.5029999999997, -3366.1090000000004, -3489.553, -3611.835, -3732.958, -3852.926, -3971.743, -4089.414, -4205.944, -4321.34, -4435.607, -4548.754, -4660.787, -4771.714, -4881.542, -4990.278, -5097.932, -5204.5109999999995, -5310.023, -5414.477, -5517.88, -5620.243, -5721.571999999999, -5821.876, -5921.1630000000005, -6019.443, -6116.723000000001, -6213.0109999999995, -6308.316999999999, -6402.647, -6496.0109999999995, -6588.415, -6679.869000000001, -6770.379, -6859.954000000001, -6948.602, -7036.329000000001, -7123.144, -7209.053000000001, -7294.065, -7378.185, -7461.423000000001, -7543.784000000001, -7625.276, -7705.905, -7785.678000000001, -7864.602, -7942.683000000001, -8019.928000000001, -8096.343000000001, -8171.933000000001, -8246.707, -8320.668, -8393.824, -8466.181, -8537.743, -8608.517, -8678.508, -8747.722, -8816.164, -8883.84, -8950.755, -9016.915, -9082.323, -9146.985, -9210.907, -9274.091999999999, -9336.546, -9398.273000000001, -9459.279, -9519.567, -9579.142, -9638.008, -9696.171, -9753.633, -9810.4, -9866.475, -9921.862, -9976.565999999999, -10030.59, -10083.938, -10136.614, -10188.623, -10239.966999999999, -10290.65, -10340.676, -10390.048, -10438.769, -10486.844, -10534.275, -10581.066, -10627.22, -10672.741000000002, -10717.63, -10761.892, -10805.53, -10848.546, -10890.943000000001, -10932.725, -10973.893999999998, -11014.453000000001, -11054.405, -11093.752, -11132.497, -11170.643, -11208.192, -11245.148000000001, -11281.511999999999, -11317.287, -11352.475, -11387.079, -11421.101999999999, -11454.545, -11487.41, -11519.7, -11551.418, -11582.565, -11613.143999999998, -11643.156, -11672.603000000001, -11701.489, -11729.813999999998, -11757.581, -11784.791000000001, -11811.447, -11837.55, -11863.101999999999, -11888.106000000002, -11912.562, -11936.473, -11959.839, -11982.663999999999, -12004.948999999999, -12026.695, -12047.903, -12068.577, -12088.716, -12108.323, -12127.398000000001, -12145.945, -12163.963, -12181.454, -12198.42, -12214.863000000001, -12230.783000000001, -12246.181, -12261.06, -12275.42, -12289.261999999999, -12302.588, -12315.4, -12327.697, -12339.482, -12350.755, -12361.518, -12371.771, -12381.516000000001, -12390.753999999999, -12399.485, -12407.711000000001, -12415.433, -12422.651000000002, -12429.367, -12435.582, -12441.296, -12446.51, -12451.226, -12455.443000000001, -12459.163999999999, -12462.386999999999, -12465.115, -12467.348999999998, -12469.088, -12470.333, -12471.086000000001, -12471.346000000001, -12471.115, -12470.393999999998, -12469.181999999999, -12467.48, -12465.29, -12462.611, -12459.444, -12455.79, -12451.648000000001, -12447.021, -12441.907, -12436.308, -12430.223999999998, -12423.655, -12416.603000000001, -12409.065, -12401.045, -12392.542, -12383.555, -12374.087, -12364.136, -12353.704, -12342.79, -12331.393999999998, -12319.517, -12307.16, -12294.321000000002, -12281.002, -12267.203000000001, -12252.923, -12238.163999999999, -12222.923999999999, -12207.205, -12191.005, -12174.326000000001, -12157.167, -12139.528, -12121.41, -12102.812, -12083.733999999999, -12064.177, -12044.14, -12023.623, -12002.626, -11981.149, -11959.191, -11936.753999999999, -11913.835, -11890.436000000002, -11866.556999999999, -11842.196000000002, -11817.354, -11792.031, -11766.226, -11739.938999999998, -11713.17, -11685.919, -11658.184, -11629.966, -11601.265, -11572.079, -11542.409, -11512.255, -11481.615, -11450.49, -11418.878, -11386.78, -11354.196000000002, -11321.123, -11287.562, -11253.513, -11218.975, -11183.947, -11148.428999999998, -11112.419, -11075.918, -11038.925, -11001.438999999998, -10963.458999999999, -10924.985, -10886.016000000001, -10846.551000000001, -10806.59, -10766.132, -10725.175, -10683.72, -10641.765, -10599.309, -10556.351999999999, -10512.893, -10468.93, -10424.463, -10379.491, -10334.014000000001, -10288.029, -10241.535, -10194.533000000001, -10147.021, -10098.998, -10050.462, -10001.413, -9951.849, -9901.77, -9851.174, -9800.06, -9748.427, -9696.273000000001, -9643.598, -9590.399, -9536.676, -9482.429, -9427.654, -9372.351, -9316.518, -9260.155, -9203.259, -9145.829, -9087.864, -9029.363000000001, -8970.323, -8910.743, -8850.622, -8789.958, -8728.75, -8666.996, -8604.694, -8541.843, -8478.440999999999, -8414.485999999999, -8349.976999999999, -8284.912, -8219.289, -8153.106, -8086.363, -8019.056, -7951.184, -7882.745, -7813.736999999999, -7744.159000000001, -7674.008000000001, -7603.283, -7531.983, -7460.103, -7387.644, -7314.603, -7240.977, -7166.765, -7091.965999999999, -7016.576, -6940.594, -6864.018, -6786.846, -6709.075, -6630.704000000001, -6551.731, -6472.153, -6391.969, -6311.177, -6229.774, -6147.759, -6065.129, -5981.882, -5898.017, -5813.531, -5728.423000000001, -5642.691, -5556.331999999999, -5469.346, -5381.73, -5293.483, -5204.602, -5115.087, -5024.935, -4934.146, -4842.717000000001, -4750.648, -4657.937, -4564.584, -4470.587, -4375.945, -4280.657999999999, -4184.726, -4088.147, -3990.923, -3893.053, -3794.5359999999996, -3695.375, -3595.5690000000004, -3495.1209999999996, -3394.031, -3292.301, -3189.934, -3086.9320000000002, -2983.2990000000004, -2879.038, -2774.153, -2668.6490000000003, -2562.531, -2455.806, -2348.481, -2240.564, -2132.062, -2022.987, -1913.349, -1803.16, -1692.433, -1581.184, -1469.4289999999999, -1357.1860000000001, -1244.475, -1131.318, -1017.7410000000001, -903.7689999999999, -789.432, -674.7639999999999, -559.8, -444.58, -329.148, -213.55200000000002, -97.845, 17.916, 133.666, 249.335, 364.845, 480.11, 595.038, 709.523, 823.454, 936.705, 1049.139, 1160.603, 1270.931, 1379.942, 1487.435, 1593.1889999999999, 1696.9660000000001, 1798.501, 1897.507, 1993.675, 2086.665, 2176.113, 2261.625, 2342.784, 2419.1420000000003, 2490.229, 2555.5570000000002, 2614.618, 2666.897, 2711.8790000000004, 2749.0559999999996, 2777.9440000000004, 2798.091, 2809.095, 2810.619, 2802.3990000000003, 2784.265, 2756.14, 2718.055, 2670.1440000000002, 2612.6420000000003, 2545.88, 2470.272, 2386.302, 2294.507, 2195.4629999999997, 2089.77, 1978.033, 1860.855, 1738.8229999999999, 1612.503, 1482.43, 1349.1070000000002, 1213.002, 1074.547, 934.1339999999999, 792.125, 648.844, 504.585, 359.611, 214.157, 68.433, -77.372, -223.093, -368.583, -513.712, -658.3660000000001, -802.444, -945.8580000000001, -1088.531, -1230.394, -1371.389, -1511.52, -1650.578, -1788.691, -1925.77, -2061.788, -2196.723, -2330.554, -2463.266, -2594.846, -2725.282, -2854.5690000000004, -2982.7, -3109.671, -3235.48, -3360.1259999999997, -3483.6090000000004, -3605.9309999999996, -3727.095, -3847.103, -3965.962, -4083.6740000000004, -4200.246, -4315.684, -4429.9929999999995, -4543.182, -4655.258, -4766.226, -4876.096, -4984.875, -5092.571, -5199.192, -5304.746999999999, -5409.243, -5512.689, -5615.093000000001, -5716.464, -5816.811, -5916.14, -6014.460999999999, -6111.783, -6208.113, -6303.460999999999, -6397.831999999999, -6491.236999999999, -6583.683000000001, -6675.178000000001, -6765.729, -6855.345, -6944.034000000001, -7031.802, -7118.656999999999, -7204.608, -7289.659000000001, -7373.82, -7457.098000000001, -7539.5, -7621.031, -7701.7, -7781.513000000001, -7860.476, -7938.597, -8015.880999999999, -8092.335, -8167.965, -8242.777, -8316.777, -8389.972, -8462.367, -8533.968, -8604.78, -8674.81, -8744.062, -8812.542, -8880.256, -8947.209, -9013.405999999999, -9078.851999999999, -9143.551, -9207.51, -9270.733, -9333.224, -9394.989, -9456.030999999999, -9516.356, -9575.968, -9634.871, -9693.07, -9750.568000000001, -9807.371, -9863.482, -9918.905999999999, -9973.646, -10027.706, -10081.09, -10133.802, -10185.846, -10237.225, -10287.944, -10338.005, -10387.412, -10436.169, -10484.279, -10531.745, -10578.571000000002, -10624.76, -10670.315, -10715.239, -10759.536, -10803.208, -10846.258, -10888.69, -10930.506000000001, -10971.708999999999, -11012.302, -11052.287, -11091.669, -11130.448, -11168.627, -11206.21, -11243.198999999999, -11279.597, -11315.405, -11350.627, -11385.264, -11419.32, -11452.796, -11485.694, -11518.018, -11549.768, -11580.948, -11611.559, -11641.604, -11671.083999999999, -11700.002, -11728.36, -11756.159, -11783.402, -11810.09, -11836.225, -11861.81, -11886.845, -11911.333, -11935.276000000002, -11958.673999999999, -11981.531, -12003.847, -12025.625, -12046.865, -12067.57, -12087.741000000002, -12107.378999999999, -12126.486, -12145.063999999998, -12163.113000000001, -12180.636, -12197.633, -12214.106000000002, -12230.056999999999, -12245.487, -12260.396, -12274.787, -12288.66, -12302.017, -12314.858999999999, -12327.187, -12339.002, -12350.306, -12361.098999999998, -12371.382, -12381.157, -12390.425, -12399.187, -12407.443000000001, -12415.195, -12422.444, -12429.19, -12435.435, -12441.178999999998, -12446.423, -12451.168, -12455.416000000001, -12459.166000000001, -12462.419, -12465.177, -12467.438999999998, -12469.208, -12470.483, -12471.265, -12471.555, -12471.353000000001, -12470.661, -12469.478000000001, -12467.806, -12465.643999999998, -12462.993999999999, -12459.856000000002, -12456.231000000002, -12452.118999999999, -12447.52, -12442.435, -12436.865, -12430.81, -12424.27, -12417.245, -12409.737, -12401.746000000001, -12393.271, -12384.313, -12374.873, -12364.95, -12354.546, -12343.66, -12332.292, -12320.444, -12308.114, -12295.303999999998, -12282.013, -12268.242, -12253.99, -12239.258999999998, -12224.046999999999, -12208.355, -12192.183, -12175.532, -12158.401000000002, -12140.79, -12122.698999999999, -12104.128999999999, -12085.078000000001, -12065.548, -12045.538999999999, -12025.048999999999, -12004.079, -11982.63, -11960.7, -11938.288999999999, -11915.398000000001, -11892.027, -11868.175, -11843.841, -11819.027, -11793.73, -11767.952, -11741.692, -11714.95, -11687.725, -11660.017, -11631.826000000001, -11603.151000000002, -11573.993, -11544.348999999998, -11514.221000000001, -11483.608, -11452.508999999998, -11420.923999999999, -11388.851999999999, -11356.294, -11323.247, -11289.713, -11255.69, -11221.178, -11186.176000000001, -11150.684, -11114.701000000001, -11078.226, -11041.258999999998, -11003.798999999999, -10965.845, -10927.396999999999, -10888.454, -10849.015, -10809.08, -10768.646999999999, -10727.716999999999, -10686.287, -10644.358, -10601.928, -10558.996000000001, -10515.562, -10471.625, -10427.184000000001, -10382.237, -10336.785, -10290.825, -10244.357, -10197.38, -10149.893, -10101.895, -10053.385, -10004.360999999999, -9954.822, -9904.768, -9854.196, -9803.107, -9751.498, -9699.37, -9646.719000000001, -9593.546, -9539.848, -9485.625, -9430.875, -9375.596, -9319.788, -9263.449, -9206.578000000001, -9149.171999999999, -9091.232, -9032.755, -8973.739, -8914.184000000001, -8854.087, -8793.447, -8732.263, -8670.533000000001, -8608.255, -8545.428, -8482.05, -8418.119, -8353.634, -8288.591999999999, -8222.993, -8156.834, -8090.1140000000005, -8022.831, -7954.982, -7886.566999999999, -7817.5830000000005, -7748.028, -7677.901, -7607.2, -7535.920999999999, -7464.065, -7391.629, -7318.61, -7245.008000000001, -7170.819, -7096.0419999999995, -7020.675, -6944.715999999999, -6868.161999999999, -6791.012, -6713.264, -6634.916, -6555.965, -6476.41, -6396.2480000000005, -6315.477, -6234.096, -6152.103, -6069.494000000001, -5986.27, -5902.4259999999995, -5817.9619999999995, -5732.876, -5647.165, -5560.828, -5473.863, -5386.268, -5298.041, -5209.181, -5119.686, -5029.555, -4938.785, -4847.376, -4755.327, -4662.6359999999995, -4569.302, -4475.3240000000005, -4380.701, -4285.434, -4189.52, -4092.96, -3995.7540000000004, -3897.901, -3799.403, -3700.26, -3600.4709999999995, -3500.04, -3398.967, -3297.2529999999997, -3194.902, -3091.9159999999997, -2988.297, -2884.05, -2779.179, -2673.6890000000003, -2567.585, -2460.8720000000003, -2353.5589999999997, -2245.653, -2137.163, -2028.0970000000002, -1918.4679999999998, -1808.2879999999998, -1697.569, -1586.326, -1474.576, -1362.3370000000002, -1249.629, -1136.475, -1022.898, -908.925, -794.587, -679.915, -564.945, -449.718, -334.276, -218.668, -102.946, 12.832, 128.60299999999998, 244.295, 359.83099999999996, 475.12800000000004, 590.09, 704.6160000000001, 818.591, 931.8919999999999, 1044.379, 1155.905, 1266.302, 1375.389, 1482.9660000000001, 1588.8139999999999, 1692.694, 1794.3429999999998, 1893.475, 1989.781, 2082.922, 2172.536, 2258.23, 2339.587, 2416.161, 2487.482, 2553.062, 2612.396, 2664.967, 2710.261, 2747.77, 2777.007, 2797.52, 2808.905, 2810.823, 2803.005, 2785.2790000000005, 2757.5640000000003, 2719.887, 2672.377, 2615.2670000000003, 2548.885, 2473.639, 2390.013, 2298.541, 2199.799, 2094.385, 1982.902, 1865.957, 1744.1370000000002, 1618.006, 1488.102, 1354.9279999999999, 1218.955, 1080.615, 940.302, 798.3789999999999, 655.1709999999999, 510.973, 366.04900000000004, 220.637, 74.946, -70.834, -216.53799999999998, -362.017, -507.14099999999996, -651.795, -795.878, -939.3, -1081.985, -1223.864, -1364.8770000000002, -1504.975, -1644.112, -1782.25, -1919.3570000000002, -2055.405, -2190.371, -2324.234, -2456.979, -2588.594, -2719.067, -2848.3909999999996, -2976.559, -3103.5690000000004, -3229.4159999999997, -3354.1009999999997, -3477.6240000000003, -3599.987, -3721.191, -3841.241, -3960.1409999999996, -4077.895, -4194.508, -4309.988, -4424.34, -4537.572, -4649.688, -4760.6990000000005, -4870.611, -4979.433, -5087.170999999999, -5193.835, -5299.431, -5403.97, -5507.4580000000005, -5609.905, -5711.318, -5811.706999999999, -5911.079000000001, -6009.443, -6106.807, -6203.179, -6298.568, -6392.981, -6486.428000000001, -6578.915, -6670.45, -6761.043000000001, -6850.7, -6939.43, -7027.2390000000005, -7114.135, -7200.126, -7285.219, -7369.420999999999, -7452.7390000000005, -7535.181, -7616.753000000001, -7697.4619999999995, -7777.315, -7856.318, -7934.478, -8011.8009999999995, -8088.295, -8163.964, -8238.815, -8312.855, -8386.089, -8458.521999999999, -8530.161, -8601.011999999999, -8671.08, -8740.371, -8808.89, -8876.642, -8943.633, -9009.868, -9075.351, -9140.089, -9204.085, -9267.345, -9329.874, -9391.676, -9452.755, -9513.117, -9572.766, -9631.706, -9689.942, -9747.476999999999, -9804.315999999999, -9860.464, -9915.924, -9970.7, -10024.796999999999, -10078.216999999999, -10130.965, -10183.045, -10234.46, -10285.214, -10335.31, -10384.753, -10433.545, -10481.690999999999, -10529.192, -10576.053, -10622.277, -10667.867, -10712.826000000001, -10757.157, -10800.864, -10843.948999999999, -10886.415, -10928.266000000001, -10969.503, -11010.13, -11050.15, -11089.566, -11128.378999999999, -11166.593, -11204.21, -11241.233, -11277.663999999999, -11313.506000000001, -11348.761999999999, -11383.433, -11417.521, -11451.031, -11483.962, -11516.319, -11548.103000000001, -11579.315, -11609.958999999999, -11640.036, -11669.55, -11698.5, -11726.891000000001, -11754.723, -11781.998, -11808.718, -11834.886, -11860.503, -11885.571000000002, -11910.091999999999, -11934.066, -11957.498, -11980.386, -12002.735, -12024.544, -12045.817, -12066.553, -12086.756000000001, -12106.426000000001, -12125.563999999998, -12144.173, -12162.253999999999, -12179.808, -12196.837, -12213.341999999999, -12229.323999999999, -12244.785, -12259.725, -12274.146999999999, -12288.051000000001, -12301.438999999998, -12314.312, -12326.671, -12338.517, -12349.851, -12360.675, -12370.989, -12380.794, -12390.093, -12398.885, -12407.171999999999, -12414.954, -12422.233, -12429.01, -12435.285, -12441.059, -12446.333, -12451.108, -12455.386, -12459.165, -12462.448999999999, -12465.236, -12467.528999999999, -12469.327, -12470.631000000001, -12471.443000000001, -12471.763, -12471.591, -12470.928, -12469.774, -12468.131000000001, -12465.999, -12463.378999999999, -12460.27, -12456.673999999999, -12452.591, -12448.021, -12442.965, -12437.423999999999, -12431.398000000001, -12424.886999999999, -12417.891000000001, -12410.412, -12402.448999999999, -12394.003, -12385.073999999999, -12375.662, -12365.768, -12355.392, -12344.535, -12333.196000000002, -12321.376, -12309.073999999999, -12296.292, -12283.03, -12269.287, -12255.063, -12240.36, -12225.176000000001, -12209.511999999999, -12193.368999999999, -12176.745, -12159.642, -12142.059, -12123.996000000001, -12105.453000000001, -12086.431, -12066.928, -12046.946000000002, -12026.483999999999, -12005.542, -11984.12, -11962.216999999999, -11939.835, -11916.971000000001, -11893.627, -11869.802, -11845.496000000001, -11820.708, -11795.438999999998, -11769.688999999998, -11743.456, -11716.74, -11689.543, -11661.862, -11633.697, -11605.05, -11575.918, -11546.301000000001, -11516.2, -11485.613000000001, -11454.541000000001, -11422.982, -11390.937, -11358.405, -11325.386, -11291.878, -11257.882, -11223.396, -11188.421, -11152.955, -11116.998, -11080.548999999999, -11043.608, -11006.173999999999, -10968.247, -10929.825, -10890.908000000001, -10851.495, -10811.586000000001, -10771.178999999998, -10730.274, -10688.87, -10646.966999999999, -10604.562, -10561.657, -10518.248, -10474.337, -10429.921, -10385.0, -10339.573, -10293.639000000001, -10247.197, -10200.245, -10152.784, -10104.811, -10056.325, -10007.326, -9957.813, -9907.784, -9857.238000000001, -9806.173, -9754.59, -9702.485999999999, -9649.86, -9596.712, -9543.039, -9488.841, -9434.115, -9378.860999999999, -9323.078000000001, -9266.764000000001, -9209.917, -9152.536, -9094.62, -9036.167, -8977.176, -8917.645, -8857.572, -8796.957, -8735.796999999999, -8674.091, -8611.837, -8549.034, -8485.68, -8421.773000000001, -8357.312, -8292.294, -8226.719000000001, -8160.584, -8093.887, -8026.628000000001, -7958.803000000001, -7890.411, -7821.451, -7751.919, -7681.816, -7611.137, -7539.882, -7468.049, -7395.6359999999995, -7322.64, -7249.061, -7174.895, -7100.141, -7024.797, -6948.86, -6872.329000000001, -6795.201999999999, -6717.476, -6639.15, -6560.222, -6480.688, -6400.549, -6319.8, -6238.441, -6156.47, -6073.883000000001, -5990.68, -5906.858, -5822.416, -5737.351, -5651.661, -5565.345, -5478.401, -5390.826999999999, -5302.621, -5213.781, -5124.307, -5034.196, -4943.447, -4852.058, -4760.028, -4667.356, -4574.042, -4480.083, -4385.48, -4290.231, -4194.335999999999, -4097.795, -4000.607, -3902.772, -3804.292, -3705.165, -3605.3940000000002, -3504.9790000000003, -3403.923, -3302.225, -3199.89, -3096.9190000000003, -2993.315, -2889.083, -2784.2259999999997, -2678.7490000000003, -2572.658, -2465.958, -2358.657, -2250.762, -2142.282, -2033.227, -1923.6070000000002, -1813.434, -1702.723, -1591.486, -1479.7420000000002, -1367.507, -1254.802, -1141.65, -1028.073, -914.1, -799.7589999999999, -685.0830000000001, -570.1080000000001, -454.87300000000005, -339.421, -223.8, -108.06299999999999, 7.732, 123.523, 239.239, 354.80300000000005, 470.13, 585.127, 699.692, 813.712, 927.062, 1039.605, 1151.193, 1261.6589999999999, 1370.8220000000001, 1478.484, 1584.4260000000002, 1688.4089999999999, 1790.172, 1889.43, 1985.874, 2079.166, 2168.946, 2254.822, 2336.377, 2413.167, 2484.722, 2550.556, 2610.1620000000003, 2663.026, 2708.633, 2746.474, 2776.06, 2796.941, 2808.708, 2811.02, 2803.6059999999998, 2786.29, 2758.987, 2721.72, 2674.613, 2617.8979999999997, 2551.897, 2477.0170000000003, 2393.738, 2302.592, 2204.154, 2099.021, 1987.797, 1871.0870000000002, 1749.48, 1623.5410000000002, 1493.808, 1360.786, 1224.947, 1086.723, 946.513, 804.677, 661.543, 517.408, 372.536, 227.165, 81.508, -64.247, -209.93200000000002, -355.399, -500.517, -645.17, -789.257, -932.687, -1075.384, -1217.278, -1358.31, -1498.4279999999999, -1637.589, -1775.753, -1912.8870000000002, -2048.965, -2183.9610000000002, -2317.857, -2450.636, -2582.285, -2712.795, -2842.155, -2970.361, -3097.409, -3223.295, -3348.02, -3471.583, -3593.986, -3715.2309999999998, -3835.322, -3954.263, -4072.059, -4188.715, -4304.237, -4418.630999999999, -4531.905, -4644.064, -4755.117, -4865.072, -4973.936, -5081.717000000001, -5188.424, -5294.063, -5398.644, -5502.175, -5604.665, -5706.121, -5806.552, -5905.965999999999, -6004.371999999999, -6101.779, -6198.193, -6293.624, -6388.08, -6481.568, -6574.097, -6665.675, -6756.309, -6846.008000000001, -6934.779, -7022.629, -7109.566999999999, -7195.599, -7280.733, -7364.976, -7448.335, -7530.816999999999, -7612.429, -7693.179, -7773.071999999999, -7852.115, -7930.315, -8007.679, -8084.2119999999995, -8159.920999999999, -8234.812, -8308.891, -8382.164, -8454.636999999999, -8526.315999999999, -8597.205, -8667.312, -8736.642, -8805.2, -8872.99, -8940.02, -9006.293, -9071.815, -9136.59, -9200.625, -9263.923, -9326.489, -9388.329, -9449.446, -9509.845, -9569.532, -9628.509, -9686.782, -9744.354, -9801.231, -9857.415, -9912.912, -9967.725, -10021.858, -10075.315, -10128.1, -10180.216, -10231.667, -10282.457, -10332.589, -10382.068000000001, -10430.896, -10479.077, -10526.614, -10573.511, -10619.771, -10665.396, -10710.39, -10754.757, -10798.499, -10841.618999999999, -10884.12, -10926.006000000001, -10967.278, -11007.94, -11047.993999999999, -11087.444, -11126.292, -11164.541000000001, -11202.192, -11239.249, -11275.715, -11311.591, -11346.88, -11381.585, -11415.708, -11449.251, -11482.216999999999, -11514.607, -11546.423999999999, -11577.671, -11608.348, -11638.458999999999, -11668.005, -11696.989, -11725.413, -11753.278, -11780.586000000001, -11807.34, -11833.54, -11859.19, -11884.291000000001, -11908.844, -11932.851999999999, -11956.315, -11979.237, -12001.618, -12023.46, -12044.764, -12065.533000000001, -12085.768, -12105.47, -12124.641000000001, -12143.282, -12161.395, -12178.981000000002, -12196.041000000001, -12212.578000000001, -12228.591999999999, -12244.083999999999, -12259.056, -12273.51, -12287.446000000002, -12300.865, -12313.768999999998, -12326.159, -12338.037, -12349.402, -12360.257, -12370.601999999999, -12380.438999999998, -12389.768, -12398.591999999999, -12406.909, -12414.723, -12422.032, -12428.84, -12435.145, -12440.95, -12446.255, -12451.061000000002, -12455.368, -12459.178999999998, -12462.492, -12465.31, -12467.633, -12469.461000000001, -12470.796, -12471.638, -12471.988000000001, -12471.846000000001, -12471.213, -12470.089, -12468.476, -12466.374, -12463.783000000001, -12460.704, -12457.138, -12453.083999999999, -12448.544, -12443.518, -12438.006000000001, -12432.008999999998, -12425.528, -12418.562, -12411.112, -12403.178, -12394.761, -12385.862, -12376.479, -12366.614, -12356.267, -12345.438999999998, -12334.128999999999, -12322.337, -12310.065, -12297.312, -12284.078000000001, -12270.364, -12256.169, -12241.493999999999, -12226.339, -12210.704, -12194.589, -12177.993999999999, -12160.919, -12143.364, -12125.33, -12106.815, -12087.821000000002, -12068.347, -12048.393, -12027.958999999999, -12007.045, -11985.651000000002, -11963.777, -11941.421999999999, -11918.586000000001, -11895.27, -11871.473, -11847.195, -11822.435, -11797.194, -11771.47, -11745.265, -11718.578000000001, -11691.407, -11663.753999999999, -11635.617, -11606.997, -11577.892, -11548.303, -11518.229, -11487.67, -11456.624, -11425.093, -11393.076000000001, -11360.571000000002, -11327.578000000001, -11294.098, -11260.128, -11225.67, -11190.721000000001, -11155.282, -11119.351999999999, -11082.93, -11046.016000000001, -11008.608999999999, -10970.708, -10932.313, -10893.421999999999, -10854.036, -10814.153, -10773.773000000001, -10732.895, -10691.517, -10649.64, -10607.261999999999, -10564.383, -10521.001, -10477.115, -10432.726, -10387.831, -10342.43, -10296.521999999999, -10250.106, -10203.18, -10155.745, -10107.796999999999, -10059.338, -10010.365, -9960.878, -9910.874, -9860.354, -9809.315, -9757.757, -9705.679, -9653.079, -9599.956, -9546.308, -9492.135, -9437.435, -9382.207, -9326.449, -9270.16, -9213.338, -9155.982, -9098.091999999999, -9039.664, -8980.697, -8921.190999999999, -8861.144, -8800.553, -8739.418, -8677.737, -8615.508, -8552.73, -8489.4, -8425.518, -8361.081, -8296.088, -8230.537, -8164.427, -8097.755, -8030.519, -7962.719, -7894.351, -7825.415, -7755.908, -7685.828, -7615.174, -7543.941999999999, -7472.133000000001, -7399.744000000001, -7326.772, -7253.215999999999, -7179.0740000000005, -7104.343000000001, -7029.023, -6953.109, -6876.602, -6799.4980000000005, -6721.795, -6643.491999999999, -6564.5869999999995, -6485.076999999999, -6404.96, -6324.234, -6242.898, -6160.9490000000005, -6078.385, -5995.204000000001, -5911.405, -5826.985, -5741.941999999999, -5656.274, -5569.98, -5483.058000000001, -5395.505, -5307.321, -5218.503, -5129.049, -5038.96, -4948.231, -4856.863, -4764.854, -4672.2029999999995, -4578.909000000001, -4484.97, -4390.387, -4295.157999999999, -4199.282, -4102.76, -4005.591, -3907.775, -3809.313, -3710.205, -3610.452, -3510.055, -3409.015, -3307.335, -3205.0159999999996, -3102.0609999999997, -2998.473, -2894.256, -2789.414, -2683.952, -2577.874, -2471.188, -2363.899, -2256.016, -2147.547, -2038.503, -1928.8929999999998, -1818.729, -1708.026, -1596.797, -1485.058, -1372.829, -1260.128, -1146.978, -1033.403, -919.429, -805.086, -690.4069999999999, -575.4259999999999, -460.18300000000005, -344.722, -229.08900000000003, -113.338, 2.475, 118.286, 234.02599999999998, 349.61699999999996, 464.975, 580.008, 694.613, 808.677, 922.078, 1034.678, 1146.328, 1256.865, 1366.106, 1473.854, 1579.892, 1683.98, 1785.86, 1885.247, 1981.8329999999999, 2075.282, 2165.232, 2251.295, 2333.054, 2410.0660000000003, 2481.863, 2547.958, 2607.846, 2661.013, 2706.942, 2745.1259999999997, 2775.075, 2796.336, 2808.4990000000003, 2811.22, 2804.225, 2787.333, 2760.4570000000003, 2723.616, 2676.93, 2620.625, 2555.02, 2480.52, 2397.601, 2306.795, 2208.674, 2103.833, 1992.879, 1876.415, 1755.029, 1629.29, 1499.735, 1366.872, 1231.172, 1093.07, 952.965, 811.22, 668.164, 524.094, 379.276, 233.949, 88.32600000000001, -57.402, -203.06900000000002, -348.524, -493.63599999999997, -638.288, -782.3789999999999, -925.818, -1068.527, -1210.437, -1351.4879999999998, -1492.118, -1630.8139999999999, -1769.005, -1906.1689999999999, -2042.277, -2177.306, -2311.237, -2444.051, -2575.736, -2706.283, -2835.6820000000002, -2963.928, -3091.015, -3216.9429999999998, -3341.7090000000003, -3465.313, -3587.759, -3709.047, -3829.1809999999996, -3948.165, -4066.0040000000004, -4182.704000000001, -4298.27, -4412.708, -4526.026, -4638.229, -4749.327, -4859.327, -4968.235, -5076.061, -5182.812, -5288.496, -5393.121, -5496.696999999999, -5599.231, -5700.731, -5801.206, -5900.665, -5999.115, -6096.566, -6193.024, -6288.499, -6382.999, -6476.531, -6569.103, -6660.724, -6751.401999999999, -6841.144, -6929.9580000000005, -7017.851, -7104.831, -7190.906, -7276.0830000000005, -7360.368, -7443.77, -7526.294, -7607.9490000000005, -7688.74, -7768.675, -7847.76, -7926.0019999999995, -8003.406999999999, -8079.981, -8155.731, -8230.664, -8304.784, -8378.098, -8450.610999999999, -8522.33, -8593.26, -8663.408000000001, -8732.778, -8801.375, -8869.206, -8936.275, -9002.588, -9068.15, -9132.965, -9197.039, -9260.376, -9322.981, -9384.86, -9446.016, -9506.454, -9566.179, -9625.195, -9683.506, -9741.117, -9798.032, -9854.255, -9909.79, -9964.64, -10018.811, -10072.306, -10125.128, -10177.282, -10228.77, -10279.598, -10329.768, -10379.283000000001, -10428.149, -10476.367, -10523.941, -10570.874, -10617.17, -10662.832, -10707.863000000001, -10752.266000000001, -10796.044, -10839.2, -10881.738000000001, -10923.659, -10964.966999999999, -11005.665, -11045.755, -11085.241000000002, -11124.124, -11162.408000000001, -11200.095, -11237.188, -11273.688999999998, -11309.6, -11344.923999999999, -11379.663999999999, -11413.822, -11447.4, -11480.4, -11512.825, -11544.677, -11575.958, -11606.67, -11636.815, -11666.396, -11695.413999999999, -11723.871000000001, -11751.77, -11779.113000000001, -11805.9, -11832.135, -11857.819, -11882.953000000001, -11907.54, -11931.581, -11955.078000000001, -11978.033000000001, -12000.447, -12022.323, -12043.661, -12064.463, -12084.73, -12104.465, -12123.669, -12142.343, -12160.489, -12178.108, -12195.201000000001, -12211.77, -12227.817, -12243.341, -12258.346000000001, -12272.832, -12286.8, -12300.252, -12313.188, -12325.611, -12337.52, -12348.918, -12359.803999999998, -12370.181, -12380.05, -12389.411, -12398.266000000001, -12406.615, -12414.46, -12421.802, -12428.64, -12434.976999999999, -12440.813, -12446.15, -12450.987, -12455.326000000001, -12459.167, -12462.511999999999, -12465.361, -12467.715, -12469.573999999999, -12470.94, -12471.812, -12472.193000000001, -12472.081, -12471.479, -12470.386, -12468.803999999998, -12466.732, -12464.171999999999, -12461.123, -12457.587, -12453.563999999998, -12449.053999999998, -12444.058, -12438.577, -12432.61, -12426.158000000001, -12419.222, -12411.802, -12403.898000000001, -12395.511999999999, -12386.642, -12377.288999999999, -12367.454, -12357.136, -12346.337, -12335.056999999999, -12323.295, -12311.052, -12298.329, -12285.124, -12271.438999999998, -12257.274, -12242.628, -12227.502, -12211.896, -12195.81, -12179.243999999999, -12162.198, -12144.671999999999, -12126.667, -12108.181, -12089.216, -12069.771, -12049.845, -12029.44, -12008.555, -11987.188999999998, -11965.343, -11943.017, -11920.21, -11896.921999999999, -11873.153, -11848.903, -11824.171999999999, -11798.958999999999, -11773.264, -11747.086000000001, -11720.427, -11693.285, -11665.659, -11637.55, -11608.958, -11579.881000000001, -11550.32, -11520.274, -11489.742, -11458.725, -11427.221000000001, -11395.231000000002, -11362.753999999999, -11329.788999999999, -11296.335, -11262.393, -11227.962, -11193.041000000001, -11157.628999999999, -11121.726, -11085.332, -11048.445, -11011.065, -10973.191, -10934.823, -10895.958999999999, -10856.6, -10816.743999999999, -10776.391000000001, -10735.538999999999, -10694.188999999998, -10652.338, -10609.987, -10567.133999999998, -10523.778999999999, -10479.92, -10435.556999999999, -10390.689, -10345.315, -10299.434000000001, -10253.044, -10206.144, -10158.735, -10110.814, -10062.381, -10013.434000000001, -9963.972, -9913.995, -9863.501, -9812.488000000001, -9760.957, -9708.904, -9656.33, -9603.233, -9549.610999999999, -9495.464, -9440.789, -9385.587, -9329.854, -9273.59, -9216.794, -9159.464, -9101.598, -9043.196, -8984.255, -8924.774, -8864.752, -8804.186, -8743.076, -8681.42, -8619.216, -8556.463, -8493.158000000001, -8429.3, -8364.888, -8299.92, -8234.394, -8168.308000000001, -8101.66, -8034.4490000000005, -7966.673000000001, -7898.33, -7829.418000000001, -7759.935, -7689.879, -7619.249, -7548.043000000001, -7476.258000000001, -7403.892, -7330.944, -7257.411999999999, -7183.294, -7108.5869999999995, -7033.289000000001, -6957.4, -6880.916, -6803.835, -6726.156, -6647.876, -6568.993, -6489.505999999999, -6409.411999999999, -6328.71, -6247.396, -6165.47, -6082.928000000001, -5999.77, -5915.993, -5831.595, -5746.5740000000005, -5660.928000000001, -5574.656, -5487.755, -5400.224, -5312.061, -5223.264, -5133.832, -5043.763, -4953.055, -4861.708, -4769.72, -4677.089, -4583.815, -4489.897, -4395.333, -4300.124, -4204.267, -4107.764, -4010.614, -3912.817, -3814.373, -3715.283, -3615.548, -3515.1679999999997, -3414.145, -3312.482, -3210.179, -3107.24, -3003.6679999999997, -2899.466, -2794.638, -2689.19, -2583.126, -2476.452, -2369.176, -2261.305, -2152.847, -2043.8120000000001, -1934.2120000000002, -1824.057, -1713.361, -1602.139, -1490.4070000000002, -1378.182, -1265.485, -1152.337, -1038.762, -924.788, -810.443, -695.7589999999999, -580.773, -465.522, -350.051, -234.405, -118.639, -2.8080000000000003, 113.024, 228.787, 344.406, 459.796, 574.865, 689.51, 803.62, 917.072, 1029.729, 1141.443, 1252.05, 1361.37, 1469.205, 1575.339, 1679.5339999999999, 1781.531, 1881.047, 1977.775, 2071.38, 2161.5, 2247.75, 2329.7129999999997, 2406.947, 2478.985, 2545.341, 2605.511, 2658.98, 2705.232, 2743.758, 2774.0679999999998, 2795.7090000000003, 2808.2670000000003, 2811.395, 2804.8190000000004, 2788.3520000000003, 2761.903, 2725.486, 2679.22, 2623.325, 2558.117, 2483.998, 2401.44, 2310.973, 2213.169, 2108.6220000000003, 1997.9379999999999, 1881.72, 1760.557, 1635.0179999999998, 1505.6429999999998, 1372.9389999999999, 1237.379, 1099.4, 959.4019999999999, 817.748, 674.7710000000001, 530.766, 386.00300000000004, 240.72, 95.133, -50.568999999999996, -196.21599999999998, -341.658, -486.76300000000003, -631.415, -775.5089999999999, -918.956, -1061.677, -1203.603, -1344.6729999999998, -1484.835, -1624.0439999999999, -1762.2620000000002, -1899.454, -2035.5929999999998, -2170.654, -2304.618, -2437.468, -2569.19, -2699.7740000000003, -2829.211, -2957.4959999999996, -3084.623, -3210.591, -3335.3979999999997, -3459.0440000000003, -3581.531, -3702.862, -3823.038, -3942.066, -4059.948, -4176.691, -4292.3009999999995, -4406.782999999999, -4520.145, -4632.394, -4743.536, -4853.58, -4962.532, -5070.402, -5177.197, -5282.9259999999995, -5387.596, -5491.215999999999, -5593.794, -5695.338000000001, -5795.858, -5895.36, -5993.855, -6091.349, -6187.851, -6283.37, -6377.9130000000005, -6471.4890000000005, -6564.105, -6655.77, -6746.49, -6836.275, -6925.132, -7013.068, -7100.090999999999, -7186.209, -7271.428000000001, -7355.755999999999, -7439.1990000000005, -7521.766, -7603.463000000001, -7684.295999999999, -7764.273, -7843.399, -7921.683000000001, -7999.129, -8075.745, -8151.536, -8226.509, -8300.67, -8374.025, -8446.58, -8518.34, -8589.311, -8659.498, -8728.908000000001, -8797.546, -8865.417, -8932.526, -8998.879, -9064.48, -9129.334, -9193.448, -9256.824, -9319.469000000001, -9381.386999999999, -9442.582, -9503.059000000001, -9562.822, -9621.877, -9680.226999999999, -9737.876, -9794.829, -9851.09, -9906.663, -9961.552, -10015.76, -10069.293, -10122.153, -10174.344000000001, -10225.87, -10276.735999999999, -10326.943000000001, -10376.496, -10425.398000000001, -10473.653, -10521.264, -10568.233999999999, -10614.567, -10660.266000000001, -10705.333, -10749.771999999999, -10793.587, -10836.778999999999, -10879.353000000001, -10921.311000000002, -10962.655, -11003.389, -11043.515, -11083.036, -11121.955, -11160.275, -11197.997, -11235.125, -11271.661, -11307.608, -11342.966999999999, -11377.742, -11411.935, -11445.548, -11478.583, -11511.043, -11542.93, -11574.245, -11604.992, -11635.171999999999, -11664.786, -11693.839, -11722.331, -11750.264, -11777.64, -11804.462, -11830.73, -11856.448, -11881.616000000002, -11906.237, -11930.312, -11953.841999999999, -11976.831, -11999.278999999999, -12021.187, -12042.558, -12063.393999999998, -12083.695, -12103.463, -12122.7, -12141.407, -12159.586000000001, -12177.237, -12194.363000000001, -12210.965, -12227.044, -12242.601999999999, -12257.639, -12272.158000000001, -12286.158000000001, -12299.642, -12312.611, -12325.066, -12337.007, -12348.437, -12359.356000000002, -12369.766000000001, -12379.666000000001, -12389.06, -12397.946000000002, -12406.327, -12414.204, -12421.577, -12428.447, -12434.816, -12440.684, -12446.051000000001, -12450.92, -12455.29, -12459.163, -12462.538999999999, -12465.419, -12467.803999999998, -12469.694, -12471.091, -12471.995, -12472.406, -12472.326000000001, -12471.753999999999, -12470.692, -12469.14, -12467.098999999998, -12464.569, -12461.551000000001, -12458.046, -12454.053, -12449.573999999999, -12444.608, -12439.157, -12433.22, -12426.798999999999, -12419.893, -12412.503, -12404.628999999999, -12396.271999999999, -12387.431999999999, -12378.11, -12368.305, -12358.017, -12347.248, -12335.998, -12324.266000000001, -12312.052, -12299.358, -12286.183, -12272.528, -12258.392, -12243.775, -12228.678, -12213.101999999999, -12197.045, -12180.508, -12163.491000000002, -12145.995, -12128.018, -12109.562, -12090.625, -12071.208999999999, -12051.312, -12030.936000000002, -12010.079, -11988.742, -11966.925, -11944.627, -11921.848999999998, -11898.59, -11874.848999999998, -11850.628, -11825.925, -11800.74, -11775.073, -11748.923999999999, -11722.293, -11695.178999999998, -11667.582, -11639.501, -11610.937, -11581.888, -11552.354, -11522.336000000001, -11491.832, -11460.843, -11429.367, -11397.405, -11364.955, -11332.018, -11298.591999999999, -11264.678, -11230.274, -11195.38, -11159.996000000001, -11124.12, -11087.753, -11050.893, -11013.54, -10975.694, -10937.353000000001, -10898.517, -10859.184, -10819.356000000002, -10779.028999999999, -10738.205, -10696.881000000001, -10655.056999999999, -10612.733, -10569.907, -10526.578000000001, -10482.746, -10438.41, -10393.568000000001, -10348.22, -10302.365, -10256.001, -10209.128, -10161.745, -10113.851, -10065.444, -10016.523000000001, -9967.088, -9917.136999999999, -9866.668, -9815.681999999999, -9764.176, -9712.15, -9659.601999999999, -9606.53, -9552.934000000001, -9498.813, -9444.164, -9388.987, -9333.28, -9277.042, -9220.271, -9162.966, -9105.126, -9046.749, -8987.833, -8928.378, -8868.381, -8807.841, -8746.756, -8685.125, -8622.946, -8560.216999999999, -8496.937, -8433.105, -8368.716999999999, -8303.774, -8238.271999999999, -8172.210999999999, -8105.588000000001, -8038.401, -7970.649, -7902.331, -7833.443, -7763.984, -7693.953, -7623.347, -7552.165, -7480.404, -7408.062, -7335.138000000001, -7261.63, -7187.535, -7112.852, -7037.578, -6961.7119999999995, -6885.251, -6808.194, -6730.5380000000005, -6652.281, -6573.422, -6493.9580000000005, -6413.887, -6333.206999999999, -6251.916, -6170.012, -6087.493, -6004.358, -5920.603, -5836.227, -5751.228, -5665.604, -5579.354, -5492.475, -5404.965999999999, -5316.8240000000005, -5228.049, -5138.637, -5048.59, -4957.903, -4866.576, -4774.609, -4681.998, -4588.745, -4494.846, -4400.302, -4305.112, -4209.275, -4112.791, -4015.66, -3917.881, -3819.455, -3720.383, -3620.665, -3520.303, -3419.297, -3317.65, -3215.364, -3112.441, -3008.884, -2904.697, -2799.884, -2694.45, -2588.399, -2481.738, -2374.474, -2266.615, -2158.1679999999997, -2049.144, -1939.5520000000001, -1829.406, -1718.7179999999998, -1607.5020000000002, -1495.776, -1383.556, -1270.862, -1157.7160000000001, -1044.142, -930.1669999999999, -815.819, -701.132, -586.139, -470.88, -355.399, -239.74099999999999, -123.959, -8.111, 107.742, 223.53, 339.17699999999996, 454.598, 569.703, 684.3889999999999, 798.544, 912.047, 1024.762, 1136.539, 1247.2169999999999, 1356.616, 1464.5379999999998, 1570.767, 1675.069, 1777.183, 1876.829, 1973.6989999999998, 2067.46, 2157.752, 2244.189, 2326.356, 2403.812, 2476.093, 2542.71, 2603.161, 2656.933, 2703.508, 2742.3779999999997, 2773.051, 2795.072, 2808.028, 2811.566, 2805.41, 2789.37, 2763.35, 2727.362, 2681.5190000000002, 2626.0370000000003, 2561.229, 2487.493, 2405.3, 2315.176, 2217.6929999999998, 2113.4429999999998, 2003.0320000000002, 1887.0629999999999, 1766.126, 1640.7910000000002, 1511.5970000000002, 1379.055, 1243.637, 1105.7830000000001, 965.893, 824.3330000000001, 681.435, 537.498, 392.791, 247.554, 102.00299999999999, -43.67100000000001, -189.298, -334.726, -479.824, -624.474, -768.571, -912.0260000000001, -1054.759, -1196.7, -1337.7879999999998, -1477.9720000000002, -1617.2060000000001, -1755.45, -1892.67, -2028.84, -2163.933, -2297.931, -2430.815, -2562.574, -2693.195, -2822.671, -2950.994, -3078.1609999999996, -3204.17, -3329.018, -3452.7059999999997, -3575.236, -3696.6090000000004, -3816.828, -3935.8990000000003, -4053.825, -4170.612, -4286.266, -4400.793, -4514.1990000000005, -4626.492, -4737.679, -4847.767, -4956.765, -5064.679, -5171.519, -5277.2919999999995, -5382.007, -5485.672, -5588.294, -5689.883000000001, -5790.446999999999, -5889.995, -5988.534000000001, -6086.071999999999, -6182.619000000001, -6278.182, -6372.769, -6466.388000000001, -6559.049, -6650.757, -6741.522, -6831.35, -6920.25, -7008.23, -7095.295999999999, -7181.456999999999, -7266.719, -7351.09, -7434.576, -7517.186, -7598.925, -7679.8, -7759.819, -7838.988, -7917.314, -7994.802, -8071.46, -8147.293000000001, -8222.306999999999, -8296.51, -8369.905999999999, -8442.502, -8514.302, -8585.314, -8655.543, -8724.994, -8793.671999999999, -8861.583, -8928.733, -8995.126, -9060.767, -9125.662, -9189.815, -9253.231, -9315.916, -9377.873, -9439.107, -9499.624, -9559.427, -9618.52, -9676.909, -9734.597, -9791.589, -9847.889000000001, -9903.5, -9958.427, -10012.674, -10066.245, -10119.143, -10171.373, -10222.937, -10273.84, -10324.085, -10373.676, -10422.616, -10470.908000000001, -10518.556999999999, -10565.563999999998, -10611.934, -10657.67, -10702.774, -10747.251, -10791.101999999999, -10834.331, -10876.942, -10918.936000000002, -10960.316, -11001.087, -11041.249, -11080.806999999999, -11119.761999999999, -11158.117, -11195.876, -11233.04, -11269.612, -11305.594, -11340.989, -11375.8, -11410.028, -11443.677, -11476.747, -11509.242, -11541.163999999999, -11572.515, -11603.296, -11633.511, -11663.16, -11692.248, -11720.775, -11748.742, -11776.153, -11803.01, -11829.313, -11855.065, -11880.267, -11904.921999999999, -11929.031, -11952.596000000001, -11975.618, -11998.1, -12020.043, -12041.448, -12062.317, -12082.652, -12102.453000000001, -12121.723999999998, -12140.464, -12158.677, -12176.362, -12193.521, -12210.156, -12226.268999999998, -12241.858999999999, -12256.93, -12271.481000000002, -12285.514, -12299.031, -12312.033000000001, -12324.52, -12336.495, -12347.957, -12358.909, -12369.351, -12379.284, -12388.71, -12397.628999999999, -12406.042, -12413.951000000001, -12421.356000000002, -12428.258999999998, -12434.659, -12440.559, -12445.958999999999, -12450.858999999999, -12455.261, -12459.166000000001, -12462.573, -12465.485, -12467.902, -12469.823999999999, -12471.252, -12472.187, -12472.63, -12472.581, -12472.04, -12471.01, -12469.489, -12467.479, -12464.98, -12461.993, -12458.518999999998, -12454.556999999999, -12450.108, -12445.173999999999, -12439.753, -12433.847, -12427.457, -12420.581, -12413.222, -12405.378999999999, -12397.052, -12388.243, -12378.951000000001, -12369.176000000001, -12358.919, -12348.18, -12336.96, -12325.258, -12313.075, -12300.41, -12287.265, -12273.64, -12259.534, -12244.947, -12229.88, -12214.333, -12198.306, -12181.798999999999, -12164.812, -12147.345, -12129.398000000001, -12110.971000000001, -12092.063999999998, -12072.677, -12052.81, -12032.463, -12011.635, -11990.328000000001, -11968.538999999999, -11946.271, -11923.521, -11900.291000000001, -11876.58, -11852.386999999999, -11827.713, -11802.556999999999, -11776.919, -11750.798999999999, -11724.197, -11697.111, -11669.543, -11641.49, -11612.955, -11583.934, -11554.43, -11524.44, -11493.964, -11463.003, -11431.555, -11399.621000000001, -11367.2, -11334.29, -11300.893, -11267.007, -11232.631000000001, -11197.765, -11162.409, -11126.561000000002, -11090.222, -11053.39, -11016.065, -10978.246000000001, -10939.933, -10901.124, -10861.819, -10822.018, -10781.719, -10740.921999999999, -10699.626, -10657.829, -10615.532, -10572.733999999999, -10529.431999999999, -10485.627, -10441.318000000001, -10396.504, -10351.183, -10305.354, -10259.018, -10212.171999999999, -10164.815999999999, -10116.948, -10068.568000000001, -10019.674, -9970.266, -9920.341, -9869.9, -9818.94, -9767.461, -9715.461, -9662.939, -9609.894, -9556.324, -9502.229, -9447.607, -9392.456, -9336.775, -9280.563, -9223.819, -9166.54, -9108.726, -9050.375, -8991.485, -8932.055, -8872.084, -8811.569, -8750.51, -8688.905, -8626.751, -8564.048, -8500.794, -8436.987, -8372.625, -8307.707, -8242.231, -8176.194, -8109.597, -8042.435, -7974.709, -7906.415, -7837.552, -7768.118, -7698.111999999999, -7627.531, -7556.3730000000005, -7484.637, -7412.32, -7339.42, -7265.936, -7191.866, -7117.206999999999, -7041.9580000000005, -6966.116, -6889.679, -6812.646, -6735.014, -6656.781, -6577.946, -6498.505, -6418.4580000000005, -6337.8009999999995, -6256.534000000001, -6174.653, -6092.158, -6009.045, -5925.313, -5840.96, -5755.984, -5670.383000000001, -5584.156, -5497.299, -5409.812, -5321.693, -5232.939, -5143.55, -5053.524, -4962.859, -4871.554, -4779.607, -4687.018, -4593.785, -4499.907, -4405.384, -4310.214, -4214.397, -4117.933, -4020.821, -3923.062, -3824.655, -3725.6020000000003, -3625.903, -3525.558, -3424.57, -3322.941, -3220.672, -3117.765, -3014.224, -2910.053, -2805.255, -2699.836, -2593.799, -2487.152, -2379.901, -2272.054, -2163.619, -2054.606, -1945.025, -1834.888, -1724.2079999999999, -1613.0, -1501.279, -1389.0639999999999, -1276.375, -1163.231, -1049.6589999999999, -935.684, -821.334, -706.643, -591.645, -476.37800000000004, -360.88699999999994, -245.217, -129.42, -13.554, 102.32, 218.132, 333.806, 449.259, 564.4, 679.127, 793.329, 906.883, 1019.655, 1131.498, 1242.247, 1351.725, 1459.736, 1566.0639999999999, 1670.474, 1772.7079999999999, 1872.486, 1969.501, 2063.422, 2153.889, 2240.518, 2322.895, 2400.58, 2473.1079999999997, 2539.994, 2600.735, 2654.817, 2701.725, 2740.949, 2771.9959999999996, 2794.409, 2807.7740000000003, 2811.735, 2806.013, 2790.413, 2764.8379999999997, 2729.292, 2683.886, 2628.8320000000003, 2564.438, 2491.1, 2409.284, 2319.5170000000003, 2222.366, 2118.424, 2008.296, 1892.586, 1771.8829999999998, 1646.7579999999998, 1517.753, 1385.378, 1250.109, 1112.384, 972.6060000000001, 831.143, 688.328, 544.46, 399.811, 254.62099999999998, 109.10700000000001, -36.538000000000004, -182.143, -327.559, -472.649, -617.297, -761.398, -904.8610000000001, -1047.606, -1189.563, -1330.671, -1470.557, -1610.136, -1748.408, -1885.6589999999999, -2021.86, -2156.987, -2291.02, -2423.9410000000003, -2555.737, -2686.397, -2815.913, -2944.277, -3071.486, -3197.5370000000003, -3322.428, -3446.159, -3568.7329999999997, -3690.15, -3810.415, -3929.531, -4047.502, -4164.335, -4280.034000000001, -4394.607, -4508.059, -4620.398, -4731.6320000000005, -4841.766, -4950.81, -5058.771, -5165.657999999999, -5271.477, -5376.238, -5479.9490000000005, -5582.618, -5684.254, -5784.8640000000005, -5884.456999999999, -5983.0419999999995, -6080.6269999999995, -6177.219, -6272.828, -6367.460999999999, -6461.126, -6553.831999999999, -6645.585, -6736.395, -6826.269, -6915.214, -7003.238, -7090.349, -7176.555, -7261.861, -7346.276, -7429.807, -7512.46, -7594.244000000001, -7675.1630000000005, -7755.226, -7834.438, -7912.807, -7990.339, -8067.039000000001, -8142.915, -8217.973, -8292.218, -8365.657, -8438.295, -8510.138, -8581.193000000001, -8651.463, -8720.956, -8789.676, -8857.629, -8924.82, -8991.255, -9056.937, -9121.873, -9186.067, -9249.525, -9312.25, -9374.248, -9435.523000000001, -9496.08, -9555.923, -9615.056999999999, -9673.485999999999, -9731.214, -9788.246, -9844.586, -9900.237, -9955.204, -10009.49, -10063.1, -10116.038, -10168.306, -10219.91, -10270.851999999999, -10321.135, -10370.765, -10419.743, -10468.074, -10515.761, -10562.806999999999, -10609.215, -10654.989, -10700.132, -10744.646, -10788.535, -10831.802, -10874.45, -10916.482, -10957.9, -10998.707, -11038.907, -11078.502, -11117.493999999999, -11155.886999999999, -11193.681999999999, -11230.883, -11267.492, -11303.511, -11338.942, -11373.79, -11408.053999999998, -11441.739, -11474.846000000001, -11507.377, -11539.335, -11570.721000000001, -11601.538999999999, -11631.79, -11661.475, -11690.598, -11719.16, -11747.163, -11774.61, -11801.501, -11827.84, -11853.627, -11878.864, -11903.553999999998, -11927.698, -11951.298, -11974.355, -11996.872, -12018.848999999998, -12040.288999999999, -12061.192, -12081.562, -12101.398000000001, -12120.703000000001, -12139.476999999999, -12157.723999999998, -12175.443000000001, -12192.636, -12209.305, -12225.452, -12241.076000000001, -12256.18, -12270.765, -12284.832, -12298.383, -12311.418, -12323.938999999998, -12335.947, -12347.442, -12358.427, -12368.902, -12378.868999999999, -12388.327, -12397.278999999999, -12405.726, -12413.668, -12421.106000000002, -12428.041000000001, -12434.473999999998, -12440.406, -12445.839, -12450.784, -12455.219, -12459.156, -12462.596000000001, -12465.538999999999, -12467.988000000001, -12469.942, -12471.402, -12472.368999999999, -12472.844, -12472.827, -12472.318000000001, -12471.319, -12469.83, -12467.851999999999, -12465.383999999998, -12462.428999999998, -12458.986, -12455.055, -12450.638, -12445.735, -12440.345, -12434.471000000001, -12428.111, -12421.267, -12413.938, -12406.126, -12397.83, -12389.052, -12379.79, -12370.046, -12359.82, -12349.112, -12337.921999999999, -12326.25, -12314.098, -12301.464, -12288.348999999998, -12274.753999999999, -12260.678, -12246.122, -12231.085, -12215.568000000001, -12199.571000000002, -12183.094, -12166.136999999999, -12148.7, -12130.782, -12112.385, -12093.508, -12074.151000000002, -12054.313, -12033.996000000001, -12013.198, -11991.92, -11970.161, -11947.921999999999, -11925.202, -11902.001, -11878.319, -11854.155, -11829.51, -11804.383999999998, -11778.775, -11752.684, -11726.11, -11699.053999999998, -11671.514, -11643.491000000002, -11614.983999999999, -11585.992, -11556.515, -11526.555, -11496.108, -11465.175, -11433.756000000001, -11401.85, -11369.457, -11336.577, -11303.207, -11269.348999999998, -11235.002, -11200.163999999999, -11164.836000000001, -11129.016000000001, -11092.705, -11055.901000000002, -11018.604, -10980.813, -10942.528, -10903.747, -10864.47, -10824.697, -10784.425, -10743.656, -10702.386999999999, -10660.618, -10618.348999999998, -10575.577, -10532.303999999998, -10488.526000000002, -10444.244, -10399.457, -10354.163, -10308.362, -10262.053, -10215.234, -10167.905, -10120.064, -10071.711, -10022.844000000001, -9973.462, -9923.565, -9873.15, -9822.216999999999, -9770.764000000001, -9718.791, -9666.296, -9613.277, -9559.734, -9505.665, -9451.069, -9395.945, -9340.29, -9284.105, -9227.386, -9170.134, -9112.346, -9054.02, -8995.157, -8935.753, -8875.806999999999, -8815.319, -8754.285, -8692.706, -8630.578000000001, -8567.901, -8504.671999999999, -8440.89, -8376.554, -8311.661, -8246.21, -8180.1990000000005, -8113.626, -8046.49, -7978.789000000001, -7910.52, -7841.682, -7772.273, -7702.2919999999995, -7631.735, -7560.602, -7488.891, -7416.598000000001, -7343.723000000001, -7270.264, -7196.218000000001, -7121.5830000000005, -7046.358, -6970.54, -6894.128000000001, -6817.118, -6739.51, -6661.3009999999995, -6582.49, -6503.073, -6423.049, -6342.416, -6261.172, -6179.315, -6096.842, -6013.753000000001, -5930.044, -5845.714, -5760.76, -5675.182, -5588.977, -5502.143, -5414.678000000001, -5326.58, -5237.849, -5148.481, -5058.476, -4967.833, -4876.549, -4784.624, -4692.056, -4598.844, -4504.986, -4410.483, -4315.333, -4219.536, -4123.092000000001, -4025.9990000000003, -3928.261, -3829.8740000000003, -3730.8390000000004, -3631.158, -3530.8309999999997, -3429.861, -3328.248, -3225.9959999999996, -3123.1059999999998, -3019.5809999999997, -2915.426, -2810.643, -2705.238, -2599.215, -2492.581, -2385.343, -2277.508, -2169.084, -2060.0820000000003, -1950.511, -1840.3829999999998, -1729.711, -1618.51, -1506.795, -1394.585, -1281.899, -1168.758, -1055.187, -941.211, -826.8589999999999, -712.164, -597.16, -481.88599999999997, -366.384, -250.701, -134.89, -19.005, 96.89, 212.726, 328.42900000000003, 443.914, 559.091, 673.8589999999999, 788.107, 901.7139999999999, 1014.544, 1126.451, 1237.2730000000001, 1346.8310000000001, 1454.931, 1561.3570000000002, 1665.875, 1768.229, 1868.139, 1965.299, 2059.38, 2150.0229999999997, 2236.843, 2319.429, 2397.341, 2470.116, 2537.27, 2598.299, 2652.691, 2699.93, 2739.506, 2770.925, 2793.7290000000003, 2807.5, 2811.881, 2806.59, 2791.428, 2766.2940000000003, 2731.188, 2686.215, 2631.585, 2567.6020000000003, 2494.658, 2413.218, 2323.804, 2226.9829999999997, 2123.347, 2013.501, 1898.046, 1777.576, 1652.66, 1523.842, 1391.632, 1256.509, 1118.912, 979.245, 837.878, 695.1439999999999, 551.345, 406.75199999999995, 261.60900000000004, 116.132, -29.485, -175.071, -320.473, -465.55699999999996, -610.203, -754.308, -897.78, -1040.538, -1182.511, -1323.639, -1463.868, -1603.1529999999998, -1741.4520000000002, -1878.733, -2014.9660000000001, -2150.126, -2284.194, -2417.152, -2548.986, -2679.685, -2809.24, -2937.6459999999997, -3064.8959999999997, -3190.989, -3315.923, -3439.698, -3562.315, -3683.777, -3804.086, -3923.2470000000003, -4041.263, -4158.141, -4273.8859999999995, -4388.505, -4502.003, -4614.388, -4725.667, -4835.848, -4944.938, -5052.945, -5159.878, -5265.743, -5370.5509999999995, -5474.308000000001, -5577.023, -5678.704000000001, -5779.36, -5878.999, -5977.63, -6075.26, -6171.898, -6267.552, -6362.23, -6455.941, -6548.691999999999, -6640.491, -6731.345, -6821.264, -6910.254, -6998.323, -7085.479, -7171.728, -7257.079000000001, -7341.5380000000005, -7425.111999999999, -7507.809, -7589.6359999999995, -7670.599, -7750.705, -7829.960999999999, -7908.3730000000005, -7985.946999999999, -8062.69, -8138.609, -8213.709, -8287.997, -8361.478000000001, -8434.158000000001, -8506.043, -8577.139000000001, -8647.452, -8716.985999999999, -8785.748, -8853.742, -8920.974, -8987.449, -9053.173, -9118.15, -9182.385, -9245.882, -9308.648000000001, -9370.686, -9432.002, -9492.599, -9552.482, -9611.655999999999, -9670.124, -9727.892, -9784.963, -9841.341999999999, -9897.033000000001, -9952.039, -10006.364, -10060.013, -10112.99, -10165.296999999999, -10216.939, -10267.919, -10318.241, -10367.909, -10416.926, -10465.295, -10513.02, -10560.103000000001, -10606.548999999999, -10652.361, -10697.541000000001, -10742.093, -10786.018999999998, -10829.323999999999, -10872.008999999998, -10914.077, -10955.533000000001, -10996.377, -11036.614, -11076.245, -11115.274, -11153.703000000001, -11191.535, -11228.771999999999, -11265.417, -11301.472, -11336.94, -11371.823, -11406.124, -11439.844, -11472.987, -11505.553999999998, -11537.546999999999, -11568.969, -11599.822, -11630.108, -11659.83, -11688.988000000001, -11717.585, -11745.624, -11773.105, -11800.031, -11826.405, -11852.226, -11877.499, -11902.223, -11926.402, -11950.036, -11973.127, -11995.678, -12017.69, -12039.163, -12060.101, -12080.503999999999, -12100.374, -12119.713, -12138.521999999999, -12156.802, -12174.553999999998, -12191.781, -12208.483999999999, -12224.663999999999, -12240.322, -12255.458999999999, -12270.077, -12284.178, -12297.761, -12310.829, -12323.383, -12335.423999999999, -12346.952, -12357.97, -12368.478000000001, -12378.476999999999, -12387.968, -12396.953000000001, -12405.431999999999, -12413.406, -12420.876, -12427.843, -12434.309, -12440.273000000001, -12445.738000000001, -12450.703000000001, -12455.169, -12459.138, -12462.61, -12465.586000000001, -12468.066, -12470.052, -12471.544, -12472.543, -12473.048999999999, -12473.063, -12472.586000000001, -12471.618999999999, -12470.161, -12468.214, -12465.778, -12462.854, -12459.442, -12455.543, -12451.157, -12446.284, -12440.926000000001, -12435.082, -12428.753, -12421.94, -12414.642, -12406.861, -12398.596000000001, -12389.848, -12380.617, -12370.903, -12360.707, -12350.028999999999, -12338.87, -12327.229, -12315.106000000002, -12302.503, -12289.418, -12275.853000000001, -12261.806999999999, -12247.281, -12232.274, -12216.787, -12200.82, -12184.372, -12167.445, -12150.037, -12132.15, -12113.782, -12094.934, -12075.607, -12055.798999999999, -12035.511, -12014.742, -11993.493, -11971.764, -11949.553999999998, -11926.863000000001, -11903.691, -11880.038, -11855.903, -11831.287, -11806.19, -11780.61, -11754.548, -11728.003, -11700.975, -11673.464, -11645.469, -11616.991000000002, -11588.028, -11558.58, -11528.646999999999, -11498.229, -11467.325, -11435.935, -11404.056999999999, -11371.692, -11338.84, -11305.499, -11271.669, -11237.348999999998, -11202.538999999999, -11167.239, -11131.448, -11095.163999999999, -11058.388, -11021.118999999999, -10983.356000000002, -10945.098, -10906.345, -10867.095, -10827.348999999998, -10787.105, -10746.363000000001, -10705.122, -10663.381000000001, -10621.138, -10578.393999999998, -10535.148000000001, -10491.396999999999, -10447.142, -10402.382, -10357.115, -10311.341, -10265.059000000001, -10218.267, -10170.965, -10123.151, -10074.824, -10025.984, -9976.629, -9926.758, -9876.37, -9825.463, -9774.037, -9722.09, -9669.621, -9616.629, -9563.113000000001, -9509.07, -9454.5, -9399.402, -9343.773000000001, -9287.614, -9230.921, -9173.695, -9115.931999999999, -9057.633, -8998.795, -8939.417, -8879.497, -8819.034, -8758.027, -8696.472, -8634.37, -8571.718, -8508.515, -8444.758, -8380.447, -8315.58, -8250.154, -8184.168000000001, -8117.62, -8050.509, -7982.8330000000005, -7914.589, -7845.776, -7776.392, -7706.435, -7635.903, -7564.794, -7493.107, -7420.839, -7347.9890000000005, -7274.554, -7200.531999999999, -7125.920999999999, -7050.72, -6974.9259999999995, -6898.5380000000005, -6821.552, -6743.968000000001, -6665.783, -6586.995, -6507.601, -6427.601, -6346.991, -6265.77, -6183.936, -6101.486999999999, -6018.42, -5934.734, -5850.427, -5765.496, -5679.94, -5593.757, -5506.945, -5419.503000000001, -5331.427, -5242.718, -5153.373, -5063.39, -4972.768, -4881.505, -4789.601, -4697.053, -4603.862, -4510.025, -4415.542, -4320.413, -4224.635, -4128.210999999999, -4031.138, -3933.4159999999997, -3835.048, -3736.031, -3636.369, -3536.06, -3435.107, -3333.512, -3231.277, -3128.403, -3024.8940000000002, -2920.7540000000004, -2815.987, -2710.5959999999995, -2604.5879999999997, -2497.968, -2390.742, -2282.919, -2174.507, -2065.515, -1955.954, -1845.835, -1735.172, -1623.9779999999998, -1512.27, -1400.065, -1287.383, -1174.245, -1060.675, -946.699, -832.345, -717.6460000000001, -602.637, -487.355, -371.844, -256.149, -140.32299999999998, -24.421, 91.495, 207.355, 323.085, 438.602, 553.815, 668.623, 782.916, 896.574, 1009.461, 1121.432, 1232.325, 1341.9620000000002, 1450.149, 1556.672, 1661.2979999999998, 1763.77, 1863.8110000000001, 1961.115, 2055.353, 2146.17, 2233.18, 2315.973, 2394.111, 2467.132, 2534.551, 2595.868, 2650.5690000000004, 2698.138, 2738.0640000000003, 2769.855, 2793.0490000000004, 2807.2259999999997, 2812.0290000000005, 2807.17, 2792.448, 2767.756, 2733.093, 2688.558, 2634.355, 2570.7870000000003, 2498.242, 2417.18, 2328.124, 2231.637, 2128.311, 2018.75, 1903.556, 1783.3210000000001, 1658.618, 1529.99, 1397.95, 1262.976, 1125.51, 985.957, 844.687, 702.0369999999999, 558.309, 413.775, 268.67900000000003, 123.24, -22.346999999999998, -167.912, -313.29900000000004, -458.375, -603.02, -747.128, -890.6080000000001, -1033.378, -1175.368, -1316.515, -1456.766, -1596.076, -1734.4029999999998, -1871.713, -2007.9779999999998, -2143.173, -2277.276, -2410.27, -2542.1420000000003, -2672.88, -2802.475, -2930.921, -3058.2140000000004, -3184.349, -3309.3259999999996, -3433.145, -3555.8059999999996, -3677.312, -3797.6659999999997, -3916.8720000000003, -4034.934, -4151.858, -4267.649, -4382.314, -4495.858, -4608.29, -4719.615, -4829.843, -4938.979, -5047.032999999999, -5154.012, -5259.925, -5364.778, -5468.581999999999, -5571.344, -5673.071, -5773.774, -5873.46, -5972.1359999999995, -6069.813, -6166.496999999999, -6262.196999999999, -6356.920999999999, -6450.677, -6543.473000000001, -6635.318, -6726.218000000001, -6816.182, -6905.217, -6993.331, -7080.531999999999, -7166.826, -7252.221, -7336.725, -7420.344, -7503.085, -7584.956, -7665.963000000001, -7746.111999999999, -7825.411999999999, -7903.866999999999, -7981.485, -8058.272, -8134.234, -8209.377, -8283.707, -8357.231, -8429.954, -8501.882, -8573.02, -8643.375, -8712.951, -8781.755, -8849.791, -8917.065, -8983.582, -9049.346, -9114.365, -9178.641, -9242.18, -9304.985999999999, -9367.065, -9428.421, -9489.059000000001, -9548.983, -9608.197, -9666.706, -9724.514000000001, -9781.625, -9838.044, -9893.774, -9948.819, -10003.185, -10056.873, -10109.889000000001, -10162.235, -10213.916, -10264.936, -10315.296999999999, -10365.003, -10414.059000000001, -10462.466, -10510.23, -10557.351999999999, -10603.836000000001, -10649.686000000002, -10694.903999999999, -10739.493999999999, -10783.458, -10826.8, -10869.523000000001, -10911.628999999999, -10953.122, -10994.003999999999, -11034.278, -11073.946000000002, -11113.011999999999, -11151.479, -11189.347, -11226.621000000001, -11263.303, -11299.395, -11334.899, -11369.819, -11404.156, -11437.913, -11471.091999999999, -11503.695, -11535.723999999998, -11567.181999999999, -11598.071000000002, -11628.393, -11658.15, -11687.344, -11715.976999999999, -11744.051000000001, -11771.568000000001, -11798.53, -11824.938, -11850.795, -11876.101999999999, -11900.862, -11925.075, -11948.745, -11971.871000000001, -11994.457, -12016.503, -12038.011, -12058.983, -12079.421, -12099.325, -12118.698, -12137.541000000001, -12155.855, -12173.642, -12190.903, -12207.64, -12223.854, -12239.545, -12254.716, -12269.368, -12283.502, -12297.12, -12310.221000000001, -12322.808, -12334.882, -12346.444, -12357.495, -12368.036, -12378.068000000001, -12387.593, -12396.61, -12405.122, -12413.128999999999, -12420.632, -12427.632, -12434.131000000001, -12440.128, -12445.625, -12450.622, -12455.121000000001, -12459.122, -12462.626, -12465.635, -12468.146999999999, -12470.165, -12471.688999999998, -12472.72, -12473.258, -12473.303999999998, -12472.858999999999, -12471.923999999999, -12470.498, -12468.582, -12466.178, -12463.285, -12459.905, -12456.037, -12451.681999999999, -12446.841, -12441.514, -12435.702, -12429.403999999999, -12422.622, -12415.355, -12407.605, -12399.371000000001, -12390.653, -12381.453000000001, -12371.771, -12361.606000000002, -12350.958, -12339.83, -12328.219, -12316.127, -12303.553999999998, -12290.5, -12276.965, -12262.95, -12248.454, -12233.476999999999, -12218.02, -12202.083, -12185.666000000001, -12168.768999999998, -12151.391000000001, -12133.533000000001, -12115.196000000002, -12096.378, -12077.08, -12057.302, -12037.043, -12016.305, -11995.085, -11973.385, -11951.205, -11928.544, -11905.401000000002, -11881.777, -11857.671999999999, -11833.086000000001, -11808.017, -11782.466, -11756.433, -11729.917, -11702.919, -11675.437, -11647.471000000001, -11619.021, -11590.087, -11560.669, -11530.765, -11500.375, -11469.5, -11438.138, -11406.288999999999, -11373.953000000001, -11341.128999999999, -11307.816, -11274.014, -11239.723, -11204.942, -11169.67, -11133.907, -11097.651000000002, -11060.903, -11023.662, -10985.927, -10947.697, -10908.972, -10869.751, -10830.032, -10789.816, -10749.101999999999, -10707.889, -10666.175, -10623.96, -10581.243999999999, -10538.025, -10494.302, -10450.074, -10405.341999999999, -10360.101999999999, -10314.356, -10268.1, -10221.336, -10174.061, -10126.274, -10077.975, -10029.161, -9979.833, -9929.989, -9879.628, -9828.748, -9777.349, -9725.429, -9672.987, -9620.021, -9566.530999999999, -9512.515, -9457.972, -9402.9, -9347.298, -9291.165, -9234.499, -9177.299, -9119.563, -9061.29, -9002.478000000001, -8943.126, -8883.232, -8822.795, -8761.814, -8700.285, -8638.209, -8575.583, -8512.405, -8448.675, -8384.389000000001, -8319.546999999999, -8254.146999999999, -8188.187, -8121.665, -8054.579000000001, -7986.928000000001, -7918.709, -7849.920999999999, -7780.563, -7710.630999999999, -7640.124, -7569.041, -7497.378000000001, -7425.135, -7352.31, -7278.899, -7204.901999999999, -7130.316, -7055.14, -6979.37, -6903.005999999999, -6826.045, -6748.485, -6670.3240000000005, -6591.56, -6512.19, -6432.214, -6351.628000000001, -6270.431, -6188.621, -6106.195, -6023.151, -5939.4890000000005, -5855.205, -5770.297, -5684.764, -5598.604, -5511.815, -5424.395, -5336.342, -5247.655, -5158.332, -5068.371, -4977.771, -4886.531, -4794.648, -4702.122, -4608.952, -4515.1359999999995, -4420.674, -4325.565, -4229.809, -4133.404, -4036.3509999999997, -3938.65, -3840.3, -3741.303, -3641.659, -3541.369, -3440.435, -3338.8579999999997, -3236.639, -3133.783, -3030.2909999999997, -2926.167, -2821.415, -2716.04, -2610.0460000000003, -2503.44, -2396.229, -2288.419, -2180.019, -2071.0389999999998, -1961.4879999999998, -1851.379, -1740.725, -1629.539, -1517.838, -1405.638, -1292.961, -1179.826, -1066.258, -952.2819999999999, -837.927, -723.225, -608.211, -492.92199999999997, -377.402, -261.69599999999997, -145.855, -29.936, 86.0, 201.88299999999998, 317.64099999999996, 433.189, 548.437, 663.2860000000001, 777.625, 891.3330000000001, 1004.278, 1116.313, 1227.278, 1336.994, 1445.27, 1551.891, 1656.625, 1759.2179999999998, 1859.39, 1956.84, 2051.239, 2142.232, 2229.435, 2312.439, 2390.8070000000002, 2464.078, 2531.769, 2593.3779999999997, 2648.393, 2696.2990000000004, 2736.5840000000003, 2768.7540000000004, 2792.3459999999995, 2806.94, 2812.1740000000004, 2807.757, 2793.485, 2769.248, 2735.038, 2690.9509999999996, 2637.188, 2574.0460000000003, 2501.91, 2421.238, 2332.55, 2236.407, 2133.399, 2024.131, 1909.205, 1789.214, 1664.729, 1536.297, 1404.431, 1269.611, 1132.279, 992.8430000000001, 851.675, 709.1110000000001, 565.455, 420.981, 275.935, 130.535, -15.022, -160.565, -305.938, -451.006, -595.649, -739.7610000000001, -883.2489999999999, -1026.032, -1168.038, -1309.2060000000001, -1449.9389999999999, -1588.816, -1727.172, -1864.513, -2000.8110000000001, -2136.04, -2270.18, -2403.212, -2535.123, -2665.902, -2795.538, -2924.027, -3051.362, -3177.5409999999997, -3302.563, -3426.426, -3549.133, -3670.6859999999997, -3791.086, -3910.3390000000004, -4028.448, -4145.419, -4261.2570000000005, -4375.969, -4489.562, -4602.041, -4713.414000000001, -4823.69, -4932.874, -5040.976, -5148.003, -5253.964, -5358.865, -5462.717, -5565.526, -5667.302, -5768.052, -5867.785, -5966.51, -6064.233, -6160.965, -6256.7119999999995, -6351.483, -6445.286999999999, -6538.13, -6630.021, -6720.968000000001, -6810.978, -6900.06, -6988.22, -7075.467, -7161.807, -7247.2480000000005, -7331.797, -7415.4619999999995, -7498.2480000000005, -7580.164000000001, -7661.215999999999, -7741.411, -7820.755, -7899.255, -7976.918000000001, -8053.749, -8129.755, -8204.942, -8279.317, -8352.884, -8425.651, -8497.622, -8568.804, -8639.202, -8708.821, -8777.668, -8845.747, -8913.063, -8979.623, -9045.43, -9110.491, -9174.809000000001, -9238.39, -9301.239, -9363.359, -9424.757, -9485.436, -9545.401, -9604.657, -9663.207, -9721.056, -9778.208, -9834.667, -9890.438, -9945.524, -9999.93, -10053.659, -10106.715, -10159.101, -10210.822, -10261.881, -10312.282, -10362.029, -10411.123, -10459.57, -10507.373, -10554.534, -10601.058, -10646.946000000002, -10692.203000000001, -10736.832, -10780.835, -10824.216, -10866.976999999999, -10909.121000000001, -10950.652, -10991.572, -11031.883999999998, -11071.591, -11110.695, -11149.198999999999, -11187.105, -11224.417, -11261.136, -11297.265, -11332.806999999999, -11367.764, -11402.138, -11435.931999999999, -11469.146999999999, -11501.787, -11533.854, -11565.348, -11596.274, -11626.632, -11656.426000000001, -11685.656, -11714.325, -11742.435, -11769.988000000001, -11796.986, -11823.43, -11849.323, -11874.666000000001, -11899.461000000001, -11923.71, -11947.415, -11970.577, -11993.198, -12015.278999999999, -12036.823, -12057.83, -12078.303, -12098.242, -12117.65, -12136.527, -12154.876, -12172.698, -12189.993999999999, -12206.765, -12223.013, -12238.739, -12253.944, -12268.63, -12282.798999999999, -12296.45, -12309.585, -12322.207, -12334.315, -12345.91, -12356.995, -12367.57, -12377.635, -12387.193000000001, -12396.243999999999, -12404.788999999999, -12412.83, -12420.366000000002, -12427.4, -12433.931, -12439.961000000001, -12445.491000000002, -12450.521, -12455.053, -12459.087, -12462.624, -12465.665, -12468.21, -12470.261, -12471.817, -12472.881000000001, -12473.451000000001, -12473.53, -12473.117, -12472.213, -12470.82, -12468.936000000002, -12466.563999999998, -12463.703000000001, -12460.355, -12456.518999999998, -12452.196000000002, -12447.386, -12442.091, -12436.31, -12430.044, -12423.293, -12416.058, -12408.339, -12400.136999999999, -12391.451000000001, -12382.282, -12372.63, -12362.496000000001, -12351.88, -12340.782, -12329.203000000001, -12317.142, -12304.6, -12291.576000000001, -12278.072, -12264.087, -12249.622, -12234.676000000001, -12219.25, -12203.343, -12186.956, -12170.089, -12152.742, -12134.915, -12116.607, -12097.82, -12078.552, -12058.803999999998, -12038.575, -12017.866000000002, -11996.677, -11975.007, -11952.856000000002, -11930.225, -11907.112, -11883.518, -11859.442, -11834.885, -11809.846000000001, -11784.325, -11758.321000000002, -11731.835, -11704.865, -11677.413, -11649.476, -11621.056, -11592.151000000002, -11562.761, -11532.886, -11502.526000000002, -11471.678999999998, -11440.346000000001, -11408.526000000002, -11376.219, -11343.423, -11310.139, -11276.366000000002, -11242.104, -11207.351, -11172.107, -11136.372, -11100.145, -11063.426000000001, -11026.213, -10988.506000000001, -10950.303999999998, -10911.607, -10872.413999999999, -10832.723999999998, -10792.536, -10751.85, -10710.663999999999, -10668.978000000001, -10626.791000000001, -10584.103000000001, -10540.911, -10497.216, -10453.017, -10408.311, -10363.1, -10317.38, -10271.153, -10224.415, -10177.168, -10129.408000000001, -10081.136, -10032.35, -9983.049, -9933.232, -9882.898000000001, -9832.046, -9780.673, -9728.78, -9676.365, -9623.426, -9569.963, -9515.974, -9461.457, -9406.412, -9350.837, -9294.73, -9238.09, -9180.917, -9123.207, -9064.96, -9006.175, -8946.849, -8886.982, -8826.571, -8765.615, -8704.113000000001, -8642.063, -8579.463, -8516.311, -8452.606, -8388.346, -8323.53, -8258.155999999999, -8192.221, -8125.724, -8058.664000000001, -7991.0380000000005, -7922.845, -7854.0830000000005, -7784.749, -7714.842, -7644.361, -7573.302, -7501.665, -7429.446999999999, -7356.646, -7283.2609999999995, -7209.2880000000005, -7134.727, -7059.575, -6983.83, -6907.491, -6830.554, -6753.018, -6674.880999999999, -6596.141, -6516.795999999999, -6436.843000000001, -6356.281999999999, -6275.108, -6193.321, -6110.919, -6027.899, -5944.26, -5859.999, -5775.115, -5689.605, -5603.468000000001, -5516.701999999999, -5429.304, -5341.274, -5252.61, -5163.309, -5073.37, -4982.792, -4891.573, -4799.712, -4707.208, -4614.059, -4520.264, -4425.823, -4330.735, -4234.998, -4138.6140000000005, -4041.5809999999997, -3943.8990000000003, -3845.5690000000004, -3746.591, -3646.966, -3546.695, -3445.7790000000005, -3344.219, -3242.018, -3139.179, -3035.704, -2931.5959999999995, -2826.86, -2721.5, -2615.521, -2508.929, -2401.731, -2293.9339999999997, -2185.5460000000003, -2076.577, -1967.037, -1856.9379999999999, -1746.2920000000001, -1635.114, -1523.42, -1411.227, -1298.5539999999999, -1185.422, -1071.856, -957.88, -843.5239999999999, -728.819, -613.8, -498.504, -382.974, -267.256, -151.401, -35.465, 80.491, 196.396, 312.181, 427.76, 543.044, 657.933, 772.318, 886.077, 999.08, 1111.1789999999999, 1222.214, 1332.011, 1440.375, 1547.094, 1651.9370000000001, 1754.649, 1854.954, 1952.549, 2047.109, 2138.278, 2225.674, 2308.888, 2387.486, 2461.007, 2528.968, 2590.87, 2646.2, 2694.442, 2735.085, 2767.635, 2791.6259999999997, 2806.636, 2812.3, 2808.3259999999996, 2794.505, 2770.723, 2736.968, 2693.3309999999997, 2640.009, 2577.294, 2505.569, 2425.288, 2336.969, 2241.172, 2138.484, 2029.511, 1914.855, 1795.108, 1670.844, 1542.609, 1410.918, 1276.253, 1139.057, 999.7389999999999, 858.672, 716.195, 572.612, 428.199, 283.203, 137.843, -7.684, -153.204, -298.563, -443.62300000000005, -588.264, -732.3789999999999, -875.8760000000001, -1018.671, -1160.694, -1301.881, -1442.18, -1581.5410000000002, -1719.9260000000002, -1857.2979999999998, -1993.629, -2128.893, -2263.069, -2396.139, -2528.089, -2658.908, -2788.586, -2917.117, -3044.495, -3170.718, -3295.785, -3419.6929999999998, -3542.446, -3664.0440000000003, -3784.491, -3903.79, -4021.947, -4138.965, -4254.851, -4369.611, -4483.251, -4595.778, -4707.1990000000005, -4817.523, -4926.755, -5034.905, -5141.981, -5247.9890000000005, -5352.939, -5456.838000000001, -5559.696, -5661.519, -5762.316999999999, -5862.098000000001, -5960.87, -6058.642, -6155.42, -6251.215, -6346.033, -6439.884, -6532.774, -6624.7119999999995, -6715.706, -6805.764, -6894.892, -6983.098000000001, -7070.391, -7156.776999999999, -7242.264, -7326.859, -7410.569, -7493.401, -7575.363, -7656.46, -7736.7, -7816.089, -7894.634, -7972.340999999999, -8049.215999999999, -8125.267, -8200.498, -8274.917, -8348.528, -8421.338, -8493.353000000001, -8564.578000000001, -8635.02, -8704.681999999999, -8773.572, -8841.694, -8909.053, -8975.655, -9041.505, -9106.608, -9170.968, -9234.591999999999, -9297.482, -9359.645, -9421.084, -9481.805, -9541.811, -9601.108, -9659.699, -9717.589, -9774.783000000001, -9831.283000000001, -9887.094000000001, -9942.221, -9996.667, -10050.436, -10103.532, -10155.959, -10207.72, -10258.819, -10309.26, -10359.046, -10408.18, -10456.667, -10504.508999999998, -10551.708999999999, -10598.271999999999, -10644.198999999999, -10689.495, -10734.163, -10778.204, -10821.624, -10864.423, -10906.606000000002, -10948.176000000001, -10989.133999999998, -11029.483999999999, -11069.228000000001, -11108.37, -11146.912, -11184.856000000002, -11222.205, -11258.962, -11295.128999999999, -11330.708, -11365.702, -11400.113000000001, -11433.944, -11467.196000000002, -11499.873, -11531.976, -11563.508, -11594.47, -11624.865, -11654.695, -11683.962, -11712.668, -11740.813999999998, -11768.403, -11795.437, -11821.917, -11847.845, -11873.223999999998, -11898.055, -11922.34, -11946.08, -11969.277, -11991.933, -12014.05, -12035.628999999999, -12056.671, -12077.178999999998, -12097.153, -12116.596000000001, -12135.508999999998, -12153.892, -12171.749, -12189.079, -12205.885, -12222.167, -12237.927, -12253.167, -12267.888, -12282.09, -12295.775, -12308.945, -12321.6, -12333.742, -12345.371000000001, -12356.49, -12367.098, -12377.197, -12386.788999999999, -12395.873, -12404.452, -12412.525, -12420.095, -12427.162, -12433.726, -12439.79, -12445.351999999999, -12450.416000000001, -12454.981000000002, -12459.046999999999, -12462.617, -12465.691, -12468.268999999998, -12470.351999999999, -12471.941, -12473.036, -12473.639, -12473.75, -12473.37, -12472.498, -12471.136999999999, -12469.286, -12466.945, -12464.117, -12460.8, -12456.996000000001, -12452.705, -12447.927, -12442.663, -12436.913999999999, -12430.678999999998, -12423.96, -12416.757, -12409.069, -12400.898000000001, -12392.243, -12383.105, -12373.485, -12363.382, -12352.796999999999, -12341.73, -12330.181, -12318.151000000002, -12305.64, -12292.648000000001, -12279.173999999999, -12265.22, -12250.785, -12235.87, -12220.473999999998, -12204.598, -12188.241000000002, -12171.405, -12154.088, -12136.291000000001, -12118.013, -12099.256000000001, -12080.018, -12060.3, -12040.101999999999, -12019.423, -11998.263, -11976.623, -11954.502, -11931.9, -11908.817, -11885.253, -11861.207, -11836.678999999998, -11811.67, -11786.178, -11760.204, -11733.746000000001, -11706.806, -11679.383, -11651.475, -11623.083999999999, -11594.208999999999, -11564.848, -11535.003, -11504.671, -11473.853000000001, -11442.548999999999, -11410.758, -11378.479, -11345.713, -11312.457, -11278.713, -11244.479, -11209.755, -11174.54, -11138.833, -11102.633999999998, -11065.943000000001, -11028.758999999998, -10991.08, -10952.906, -10914.237, -10875.072, -10835.41, -10795.25, -10754.591999999999, -10713.434, -10671.776000000002, -10629.617, -10586.956, -10543.792, -10500.125, -10455.953000000001, -10411.275, -10366.091, -10320.399, -10274.199, -10227.489, -10180.269, -10132.536, -10084.292, -10035.533000000001, -9986.259, -9936.469000000001, -9886.162, -9835.336, -9783.991, -9732.125, -9679.735999999999, -9626.825, -9573.388, -9519.425, -9464.936, -9409.917, -9354.368, -9298.288, -9241.675, -9184.528, -9126.844000000001, -9068.624, -9009.865, -8950.565, -8890.724, -8830.339, -8769.41, -8707.933, -8645.909, -8583.335, -8520.209, -8456.53, -8392.296, -8327.505, -8262.155999999999, -8196.247, -8129.776, -8062.741, -7995.141, -7926.973000000001, -7858.236, -7788.927, -7719.045999999999, -7648.59, -7577.556, -7505.944, -7433.751, -7360.975, -7287.6140000000005, -7213.666, -7139.13, -7064.0019999999995, -6988.281999999999, -6911.965999999999, -6835.054, -6757.5419999999995, -6679.43, -6600.714, -6521.393, -6441.464, -6360.9259999999995, -6279.776, -6198.013000000001, -6115.635, -6032.638000000001, -5949.022, -5864.785, -5779.923000000001, -5694.437, -5608.321999999999, -5521.579000000001, -5434.204000000001, -5346.196999999999, -5257.554, -5168.276, -5078.36, -4987.804, -4896.607, -4804.767, -4712.284000000001, -4619.157, -4525.383, -4430.963, -4335.895, -4240.179, -4143.815, -4046.802, -3949.14, -3850.83, -3751.8709999999996, -3652.265, -3552.012, -3451.114, -3349.572, -3247.389, -3144.567, -3041.1079999999997, -2937.0170000000003, -2832.296, -2726.9509999999996, -2620.987, -2514.41, -2407.225, -2299.4410000000003, -2191.065, -2082.1079999999997, -1972.579, -1862.489, -1751.8529999999998, -1640.683, -1528.995, -1416.808, -1304.139, -1191.011, -1077.447, -963.472, -849.1139999999999, -734.4069999999999, -619.382, -504.08, -388.541, -272.812, -156.94299999999998, -40.99, 74.986, 190.917, 306.728, 422.339, 537.658, 652.587, 767.0169999999999, 880.827, 993.8860000000001, 1106.049, 1217.156, 1327.031, 1435.483, 1542.3, 1647.25, 1750.082, 1850.5179999999998, 1948.259, 2042.9779999999998, 2134.323, 2221.911, 2305.335, 2384.1620000000003, 2457.9320000000002, 2526.1639999999998, 2588.357, 2644.0009999999997, 2692.58, 2733.5809999999997, 2766.511, 2790.901, 2806.327, 2812.423, 2808.893, 2795.525, 2772.199, 2738.901, 2695.716, 2642.836, 2580.552, 2509.24, 2429.353, 2341.406, 2245.9570000000003, 2143.593, 2034.918, 1920.533, 1801.0339999999999, 1676.993, 1548.957, 1417.444, 1282.935, 1145.877, 1006.678, 865.715, 723.326, 579.818, 435.467, 290.52099999999996, 145.202, -0.294, -145.792, -291.135, -436.186, -580.825, -724.943, -868.448, -1011.2560000000001, -1153.295, -1294.502, -1434.8239999999998, -1574.211, -1712.624, -1850.0279999999998, -1986.392, -2121.6910000000003, -2255.903, -2389.011, -2521.001, -2651.861, -2781.58, -2910.1540000000005, -3037.5759999999996, -3163.843, -3288.954, -3412.908, -3535.7070000000003, -3657.3509999999997, -3777.845, -3897.192, -4015.395, -4132.460999999999, -4248.395, -4363.2029999999995, -4476.891, -4589.465999999999, -4700.936, -4811.308, -4920.589, -5028.788, -5135.911, -5241.968, -5346.967, -5450.914000000001, -5553.82, -5655.691999999999, -5756.5380000000005, -5856.366999999999, -5955.187, -6053.007, -6149.8330000000005, -6245.6759999999995, -6340.5419999999995, -6434.44, -6527.3769999999995, -6619.363, -6710.403, -6800.508000000001, -6889.683000000001, -6977.936, -7065.276, -7151.7080000000005, -7237.241999999999, -7321.883000000001, -7405.639, -7488.517, -7570.524, -7651.6669999999995, -7731.951999999999, -7811.3859999999995, -7889.976, -7967.728, -8044.649, -8120.744000000001, -8196.02, -8270.483, -8344.138, -8416.993, -8489.052, -8560.321, -8630.806, -8700.511999999999, -8769.445, -8837.61, -8905.013, -8971.658000000001, -9037.55, -9102.696, -9167.099, -9230.764000000001, -9293.697, -9355.902, -9417.384, -9478.146, -9538.195, -9597.533000000001, -9656.166, -9714.097, -9771.332, -9827.873, -9883.726, -9938.893, -9993.38, -10047.19, -10100.327, -10152.794, -10204.595, -10255.735, -10306.215, -10356.041, -10405.216, -10453.742, -10501.623, -10548.863000000001, -10595.465, -10641.431999999999, -10686.767, -10731.473999999998, -10775.553999999998, -10819.013, -10861.851, -10904.073, -10945.681, -10986.677, -11027.066, -11066.848999999998, -11106.028999999999, -11144.608, -11182.59, -11219.976999999999, -11256.771999999999, -11292.976, -11328.593, -11363.625, -11398.073, -11431.941, -11465.231000000002, -11497.945, -11530.085, -11561.653999999999, -11592.653, -11623.085, -11652.951000000001, -11682.255, -11710.997, -11739.18, -11766.805, -11793.875, -11820.392, -11846.356000000002, -11871.771, -11896.638, -11920.958999999999, -11944.733999999999, -11967.966999999999, -11990.659, -12012.811000000002, -12034.426000000001, -12055.503999999999, -12076.046999999999, -12096.056, -12115.534, -12134.482, -12152.9, -12170.791000000001, -12188.157, -12204.997, -12221.313999999998, -12237.108999999999, -12252.383, -12267.138, -12281.375, -12295.095, -12308.298999999999, -12320.988000000001, -12333.163999999999, -12344.827, -12355.98, -12366.622, -12376.755, -12386.381000000001, -12395.499, -12404.111, -12412.218, -12419.821000000002, -12426.921999999999, -12433.518999999998, -12439.616000000002, -12445.212, -12450.309, -12454.907, -12459.007, -12462.608999999999, -12465.716, -12468.327, -12470.442, -12472.063999999998, -12473.193000000001, -12473.828000000001, -12473.972, -12473.624, -12472.785, -12471.455, -12469.636999999999, -12467.329, -12464.532, -12461.248, -12457.475, -12453.216, -12448.471000000001, -12443.239, -12437.521, -12431.319, -12424.631000000001, -12417.458999999999, -12409.803, -12401.663999999999, -12393.04, -12383.934, -12374.345, -12364.274, -12353.72, -12342.684, -12331.167, -12319.168, -12306.688, -12293.726, -12280.284, -12266.361, -12251.957, -12237.072, -12221.707, -12205.862, -12189.536, -12172.73, -12155.443000000001, -12137.677, -12119.43, -12100.703000000001, -12081.495, -12061.806999999999, -12041.639, -12020.99, -11999.861, -11978.251, -11956.16, -11933.588, -11910.535, -11887.001, -11862.983999999999, -11838.487, -11813.507, -11788.045, -11762.1, -11735.671999999999, -11708.761999999999, -11681.368, -11653.49, -11625.128, -11596.282, -11566.951000000001, -11537.133, -11506.832, -11476.043, -11444.768, -11413.006000000001, -11380.756000000001, -11348.018999999998, -11314.792, -11281.077, -11246.871000000001, -11212.176000000001, -11176.99, -11141.312, -11105.142, -11068.479, -11031.323, -10993.673, -10955.528, -10916.886999999999, -10877.751, -10838.117, -10797.985, -10757.355, -10716.225, -10674.595, -10632.464, -10589.831, -10546.696000000002, -10503.056, -10458.912, -10414.261999999999, -10369.106, -10323.442, -10277.269, -10230.587, -10183.394, -10135.69, -10087.472, -10038.741, -9989.495, -9939.732, -9889.452, -9838.654, -9787.336, -9735.497, -9683.136, -9630.251, -9576.841, -9522.905999999999, -9468.443000000001, -9413.451, -9357.929, -9301.876, -9245.29, -9188.169, -9130.513, -9072.319, -9013.586, -8954.313, -8894.498, -8834.14, -8773.237, -8711.787, -8649.789, -8587.241, -8524.141, -8460.488000000001, -8396.280999999999, -8331.516, -8266.193000000001, -8200.31, -8133.865, -8066.856, -7999.281, -7931.139, -7862.428000000001, -7793.145, -7723.289000000001, -7652.858, -7581.85, -7510.263000000001, -7438.095, -7365.344, -7292.009, -7218.085999999999, -7143.575, -7068.472, -6992.776999999999, -6916.486, -6839.599, -6762.111999999999, -6684.024, -6605.331999999999, -6526.036, -6446.130999999999, -6365.618, -6284.491999999999, -6202.753000000001, -6120.399, -6037.4259999999995, -5953.834, -5869.62, -5784.783, -5699.319, -5613.229, -5526.508000000001, -5439.156999999999, -5351.172, -5262.553000000001, -5173.298, -5083.404, -4992.87, -4901.696, -4809.879, -4717.418, -4624.312, -4530.56, -4436.161, -4341.115, -4245.42, -4149.076, -4052.0840000000003, -3954.442, -3856.152, -3757.2129999999997, -3657.6259999999997, -3557.393, -3456.513, -3354.99, -3252.825, -3150.0209999999997, -3046.58, -2942.505, -2837.801, -2732.472, -2626.5240000000003, -2519.9610000000002, -2412.79, -2305.02, -2196.657, -2087.712, -1978.194, -1868.116, -1757.489, -1646.3270000000002, -1534.648, -1422.467, -1309.8039999999999, -1196.68, -1083.118, -969.1439999999999, -854.7860000000001, -740.076, -625.048, -509.73900000000003, -394.19199999999995, -278.452, -162.569, -46.6, 69.395, 185.34900000000002, 301.187, 416.82800000000003, 532.182, 647.151, 761.6260000000001, 875.487, 988.6030000000001, 1100.83, 1212.008, 1321.963, 1430.503, 1537.418, 1642.477, 1745.4289999999999, 1845.999, 1943.886, 2038.767, 2130.2889999999998, 2218.071, 2301.709, 2380.769, 2454.792, 2523.298, 2585.7889999999998, 2641.7529999999997, 2690.6740000000004, 2732.04, 2765.357, 2790.1540000000005, 2806.006, 2812.5429999999997, 2809.467, 2796.5609999999997, 2773.702, 2740.8720000000003, 2698.15, 2645.724, 2583.881, 2512.993, 2433.511, 2345.947, 2250.855, 2148.823, 2040.454, 1926.349, 1807.104, 1683.2920000000001, 1555.461, 1424.131, 1289.7830000000001, 1152.866, 1013.79, 872.933, 730.6339999999999, 587.203, 442.916, 298.022, 152.744, 7.279, -138.195, -283.522, -428.566, -573.202, -717.324, -860.837, -1003.658, -1145.714, -1286.942, -1427.759, -1566.703, -1705.146, -1842.5810000000001, -1978.979, -2114.314, -2248.565, -2381.7129999999997, -2513.743, -2644.6440000000002, -2774.407, -2903.025, -3030.492, -3156.805, -3281.962, -3405.9629999999997, -3528.809, -3650.5009999999997, -3771.0429999999997, -3890.438, -4008.691, -4125.806, -4241.789000000001, -4356.646, -4470.384, -4583.009, -4694.529, -4804.951, -4914.282, -5022.53, -5129.704000000001, -5235.81, -5340.859, -5444.856, -5547.812, -5649.733, -5750.629, -5850.508000000001, -5949.3769999999995, -6047.245, -6144.121, -6240.013000000001, -6334.928000000001, -6428.874, -6521.861, -6613.894, -6704.983, -6795.1359999999995, -6884.359, -6972.661, -7060.048000000001, -7146.528, -7232.109, -7316.797, -7400.6, -7483.526, -7565.579000000001, -7646.769, -7727.101, -7806.581, -7885.218000000001, -7963.016, -8039.982, -8116.1230000000005, -8191.444, -8265.953000000001, -8339.654, -8412.553, -8484.657, -8555.971, -8626.5, -8696.251, -8765.229, -8833.438, -8900.885, -8967.574, -9033.51, -9098.699, -9163.146, -9226.855, -9289.831, -9352.079, -9413.603000000001, -9474.409, -9534.5, -9593.88, -9652.556, -9710.529, -9767.806, -9824.389000000001, -9880.284, -9935.493, -9990.021999999999, -10043.873, -10097.051, -10149.56, -10201.402, -10252.582, -10303.104, -10352.971, -10402.186, -10450.752, -10498.673999999999, -10545.955, -10592.597, -10638.604, -10683.979, -10728.725, -10772.846000000001, -10816.343, -10859.221000000001, -10901.482, -10943.128999999999, -10984.165, -11024.593, -11064.415, -11103.633, -11142.252, -11180.273000000001, -11217.698, -11254.531, -11290.774, -11326.428999999998, -11361.499, -11395.985, -11429.891000000001, -11463.219, -11495.971000000001, -11528.149, -11559.755, -11590.791000000001, -11621.261, -11651.165, -11680.505, -11709.284, -11737.503999999999, -11765.166000000001, -11792.273000000001, -11818.826000000001, -11844.828000000001, -11870.278999999999, -11895.183, -11919.54, -11943.351999999999, -11966.621000000001, -11989.348999999998, -12011.537, -12033.187, -12054.301000000001, -12074.88, -12094.925, -12114.438999999998, -12133.421999999999, -12151.876, -12169.803, -12187.203000000001, -12204.079, -12220.431, -12236.261, -12251.571000000002, -12266.361, -12280.632, -12294.386999999999, -12307.625, -12320.348999999998, -12332.56, -12344.258, -12355.445, -12366.121000000001, -12376.288999999999, -12385.948, -12395.101, -12403.747, -12411.888, -12419.526000000002, -12426.659, -12433.291000000001, -12439.421999999999, -12445.051000000001, -12450.181999999999, -12454.813, -12458.946000000002, -12462.582, -12465.722, -12468.366000000002, -12470.516000000001, -12472.17, -12473.332, -12474.0, -12474.177, -12473.862, -12473.056, -12471.758999999998, -12469.973, -12467.698, -12464.934, -12461.681999999999, -12457.942, -12453.715, -12449.002, -12443.802, -12438.117, -12431.947, -12425.291000000001, -12418.151000000002, -12410.527, -12402.419, -12393.828000000001, -12384.753999999999, -12375.196000000002, -12365.157, -12354.633999999998, -12343.63, -12332.143999999998, -12320.177, -12307.728000000001, -12294.798, -12281.386999999999, -12267.495, -12253.122, -12238.268, -12222.934, -12207.12, -12190.825, -12174.05, -12156.794, -12139.059, -12120.841999999999, -12102.146, -12082.969, -12063.312, -12043.173999999999, -12022.556, -12001.457, -11979.877, -11957.817, -11935.275, -11912.252, -11888.747, -11864.761999999999, -11840.294, -11815.344, -11789.912, -11763.997, -11737.598999999998, -11710.718, -11683.354, -11655.506000000001, -11627.173, -11598.356000000002, -11569.055, -11539.267, -11508.996000000001, -11478.236, -11446.991000000002, -11415.258, -11383.037, -11350.329, -11317.131000000001, -11283.445, -11249.268999999998, -11214.601999999999, -11179.445, -11143.796, -11107.655, -11071.021, -11033.893999999998, -10996.271999999999, -10958.156, -10919.544, -10880.435, -10840.83, -10800.726999999999, -10760.125, -10719.024, -10677.421999999999, -10635.32, -10592.715, -10549.607, -10505.996000000001, -10461.88, -10417.258, -10372.13, -10326.494, -10280.349, -10233.695, -10186.53, -10138.853000000001, -10090.663, -10041.959, -9992.741, -9943.006, -9892.754, -9841.983, -9790.692, -9738.88, -9686.546, -9633.689, -9580.306999999999, -9526.398000000001, -9471.963, -9416.998, -9361.503, -9305.476999999999, -9248.918, -9191.824, -9134.194, -9076.027, -9017.321, -8958.075, -8898.287, -8837.955, -8777.079, -8715.655, -8653.684000000001, -8591.162, -8528.089, -8464.462, -8400.280999999999, -8335.542, -8270.246, -8204.389000000001, -8137.969, -8070.986, -8003.438, -7935.321, -7866.6359999999995, -7797.379, -7727.549, -7657.143, -7586.161, -7514.599, -7442.456999999999, -7369.732, -7296.420999999999, -7222.524, -7148.0380000000005, -7072.960999999999, -6997.29, -6921.025, -6844.161999999999, -6766.7, -6688.637, -6609.97, -6530.698, -6450.818, -6370.329000000001, -6289.228, -6207.513000000001, -6125.183000000001, -6042.235, -5958.6669999999995, -5874.477, -5789.6630000000005, -5704.223000000001, -5618.156, -5531.459, -5444.130999999999, -5356.17, -5267.5740000000005, -5178.340999999999, -5088.47, -4997.959, -4906.807, -4815.012, -4722.5740000000005, -4629.49, -4535.76, -4441.383, -4346.358, -4250.684, -4154.362, -4057.39, -3959.7690000000002, -3861.4990000000003, -3762.58, -3663.013, -3562.7990000000004, -3461.938, -3360.434, -3258.2870000000003, -3155.5009999999997, -3052.077, -2948.02, -2843.333, -2738.02, -2632.087, -2525.5389999999998, -2418.383, -2310.626, -2202.277, -2093.344, -1983.838, -1873.77, -1763.1529999999998, -1652.001, -1540.329, -1428.155, -1315.497, -1202.377, -1088.8210000000001, -974.8480000000001, -860.49, -745.778, -630.746, -515.431, -399.876, -284.125, -168.229, -52.243, 63.771, 179.747, 295.612, 411.283, 526.672, 641.68, 756.2, 870.112, 983.285, 1095.575, 1206.825, 1316.859, 1425.4879999999998, 1532.5020000000002, 1637.67, 1740.743, 1841.445, 1939.48, 2034.5220000000002, 2126.221, 2214.199, 2298.051, 2377.343, 2451.6220000000003, 2520.404, 2583.192, 2639.4770000000003, 2688.743, 2730.4759999999997, 2764.18, 2789.386, 2805.667, 2812.6479999999997, 2810.028, 2797.5890000000004, 2775.2009999999996, 2742.84, 2700.586, 2648.618, 2587.22, 2516.761, 2437.688, 2350.508, 2255.777, 2154.0820000000003, 2046.0220000000002, 1932.201, 1813.213, 1689.632, 1562.01, 1430.8629999999998, 1296.6789999999999, 1159.905, 1020.955, 880.205, 737.998, 594.644, 450.421, 305.58, 160.344, 14.912, -130.539, -275.851, -420.88599999999997, -565.52, -709.645, -853.166, -996.0010000000001, -1138.0739999999998, -1279.3239999999998, -1419.694, -1559.136, -1697.609, -1835.078, -1971.511, -2106.882, -2241.1710000000003, -2374.359, -2506.43, -2637.3740000000003, -2767.1809999999996, -2895.843, -3023.355, -3149.7140000000004, -3274.9179999999997, -3398.966, -3521.86, -3643.6009999999997, -3764.191, -3883.636, -4001.937, -4119.102, -4235.135, -4350.042, -4463.83, -4576.505, -4688.075, -4798.5470000000005, -4907.929, -5016.228, -5123.452, -5229.609, -5334.7080000000005, -5438.755999999999, -5541.7609999999995, -5643.733, -5744.679, -5844.607, -5943.526, -6041.444, -6138.37, -6234.311, -6329.275, -6423.271, -6516.306, -6608.389, -6699.526, -6789.727, -6878.999, -6967.348000000001, -7054.783, -7141.311, -7226.94, -7311.6759999999995, -7395.526999999999, -7478.499, -7560.6, -7641.8369999999995, -7722.215999999999, -7801.743, -7880.4259999999995, -7958.27, -8035.283, -8111.471, -8186.838000000001, -8261.392, -8335.139000000001, -8408.084, -8480.233, -8551.591999999999, -8622.166, -8691.962, -8760.984, -8829.238000000001, -8896.729, -8963.462, -9029.443000000001, -9094.676, -9159.166, -9222.919, -9285.938, -9348.229, -9409.796999999999, -9470.646, -9530.779, -9590.203000000001, -9648.921, -9706.937, -9764.256, -9820.882, -9876.819, -9932.07, -9986.64, -10040.533000000001, -10093.753, -10146.303, -10198.187, -10249.408000000001, -10299.971, -10349.878, -10399.134, -10447.742, -10495.704, -10543.025, -10589.708, -10635.756000000001, -10681.171, -10725.957, -10770.118, -10813.655, -10856.573, -10898.873, -10940.56, -10981.635, -11022.101999999999, -11061.963, -11101.221000000001, -11139.878, -11177.938, -11215.402, -11252.274, -11288.555, -11324.248, -11359.356000000002, -11393.881000000001, -11427.825, -11461.191, -11493.981000000002, -11526.196000000002, -11557.84, -11588.913999999999, -11619.421, -11649.362, -11678.74, -11707.556, -11735.813, -11763.511999999999, -11790.656, -11817.246000000001, -11843.284, -11868.773000000001, -11893.712, -11918.106000000002, -11941.955, -11965.26, -11988.024, -12010.249, -12031.935, -12053.085, -12073.7, -12093.781, -12113.33, -12132.348999999998, -12150.839, -12168.801000000001, -12186.237, -12203.148000000001, -12219.536, -12235.401000000002, -12250.746000000001, -12265.571000000002, -12279.878, -12293.667, -12306.941, -12319.7, -12331.945, -12343.678, -12354.899, -12365.61, -12375.812, -12385.506000000001, -12394.692, -12403.373, -12411.548, -12419.219, -12426.386999999999, -12433.053, -12439.216999999999, -12444.881000000001, -12450.045, -12454.71, -12458.877, -12462.546, -12465.719, -12468.396999999999, -12470.579, -12472.268, -12473.462, -12474.163999999999, -12474.373, -12474.091, -12473.318000000001, -12472.053999999998, -12470.301000000001, -12468.058, -12465.327, -12462.107, -12458.4, -12454.206, -12449.525, -12444.358, -12438.705, -12432.567, -12425.943000000001, -12418.835, -12411.243, -12403.168, -12394.608, -12385.566, -12376.04, -12366.032, -12355.542, -12344.569, -12333.115, -12321.178999999998, -12308.761, -12295.862, -12282.483, -12268.622, -12254.28, -12239.458999999999, -12224.156, -12208.373, -12192.108999999999, -12175.365, -12158.14, -12140.435, -12122.25, -12103.583999999999, -12084.438, -12064.811000000002, -12044.704, -12024.116000000002, -12003.048, -11981.498, -11959.468, -11936.957, -11913.964, -11890.49, -11866.534, -11842.096000000001, -11817.176000000001, -11791.774, -11765.889, -11739.521, -11712.67, -11685.336000000001, -11657.517, -11629.215, -11600.428, -11571.155, -11541.398000000001, -11511.153999999999, -11480.423999999999, -11449.208, -11417.505, -11385.313, -11352.633999999998, -11319.466, -11285.809, -11251.661, -11217.024, -11181.896, -11146.276000000002, -11110.163, -11073.558, -11036.46, -10998.867, -10960.778999999999, -10922.196000000002, -10883.116000000002, -10843.54, -10803.465, -10762.892, -10721.819, -10680.246000000001, -10638.171, -10595.595, -10552.516000000001, -10508.931999999999, -10464.844000000001, -10420.251, -10375.15, -10329.543, -10283.426, -10236.8, -10189.663, -10142.014000000001, -10093.851999999999, -10045.176, -9995.985, -9946.278, -9896.053, -9845.31, -9794.046999999999, -9742.263, -9689.956, -9637.126, -9583.771, -9529.89, -9475.481, -9420.544, -9365.076, -9309.077, -9252.545, -9195.478000000001, -9137.875, -9079.735, -9021.056, -8961.837, -8902.075, -8841.77, -8780.92, -8719.524, -8657.579, -8595.083, -8532.037, -8468.437, -8404.280999999999, -8339.569, -8274.299, -8208.468, -8142.075, -8075.118, -8007.595, -7939.505, -7870.845, -7801.6140000000005, -7731.81, -7661.43, -7590.474, -7518.938, -7446.821, -7374.121, -7300.835999999999, -7226.965, -7152.504, -7077.451999999999, -7001.807, -6925.566999999999, -6848.729, -6771.293000000001, -6693.254, -6614.611999999999, -6535.365, -6455.51, -6375.045, -6293.969, -6212.279, -6129.973000000001, -6047.049, -5963.505, -5879.339, -5794.549, -5709.133000000001, -5623.09, -5536.4169999999995, -5449.111999999999, -5361.174, -5272.601, -5183.392, -5093.543, -5003.055, -4911.9259999999995, -4820.154, -4727.737, -4634.6759999999995, -4540.968, -4446.612, -4351.609, -4255.957, -4159.656, -4062.705, -3965.105, -3866.855, -3767.9570000000003, -3668.409, -3568.215, -3467.3740000000003, -3365.889, -3263.761, -3160.992, -3057.587, -2953.547, -2848.8759999999997, -2743.58, -2637.663, -2531.131, -2423.99, -2316.248, -2207.9120000000003, -2098.992, -1989.4979999999998, -1879.441, -1768.835, -1657.692, -1546.0279999999998, -1433.861, -1321.21, -1208.094, -1094.539, -980.568, -866.211, -751.497, -636.461, -521.141, -405.57800000000003, -289.817, -173.908, -57.907, 58.126999999999995, 174.125, 290.015, 405.717, 521.14, 636.188, 750.752, 864.7139999999999, 977.944, 1090.297, 1201.618, 1311.731, 1420.4479999999999, 1527.56, 1632.8370000000002, 1736.03, 1836.865, 1935.047, 2030.251, 2122.1279999999997, 2210.301, 2294.367, 2373.894, 2448.426, 2517.485, 2580.573, 2637.179, 2686.7909999999997, 2728.8920000000003, 2762.987, 2788.605, 2805.316, 2812.745, 2810.585, 2798.615, 2776.7009999999996, 2744.816, 2703.033, 2651.528, 2590.58, 2520.554, 2441.894, 2355.105, 2260.74, 2159.384, 2051.639, 1938.104, 1819.3770000000002, 1696.031, 1568.619, 1437.66, 1303.641, 1167.013, 1028.1889999999999, 887.548, 745.434, 602.158, 458.001, 313.21299999999997, 168.019, 22.62, -122.807, -268.103, -413.12800000000004, -557.76, -701.8889999999999, -845.419, -988.2669999999999, -1130.358, -1271.629, -1412.024, -1551.494, -1689.9979999999998, -1827.499, -1963.9679999999998, -2099.376, -2233.7039999999997, -2366.9320000000002, -2499.045, -2630.032, -2759.883, -2888.59, -3016.1479999999997, -3142.554, -3267.805, -3391.902, -3514.844, -3636.634, -3757.2740000000003, -3876.768, -3995.12, -4112.335, -4228.418, -4343.376, -4457.214, -4569.941, -4681.561, -4792.084, -4901.517, -5009.867, -5117.142, -5223.35, -5328.5, -5432.598000000001, -5535.655, -5637.677, -5738.673000000001, -5838.651999999999, -5937.621999999999, -6035.59, -6132.566, -6228.557, -6323.571, -6417.616, -6510.701, -6602.8330000000005, -6694.02, -6784.27, -6873.590999999999, -6961.9890000000005, -7049.473000000001, -7136.049, -7221.726, -7306.5109999999995, -7390.409000000001, -7473.43, -7555.579000000001, -7636.861999999999, -7717.2880000000005, -7796.863, -7875.593000000001, -7953.484, -8030.544, -8106.778, -8182.191999999999, -8256.792, -8330.584, -8403.575, -8475.77, -8547.175, -8617.795, -8687.635, -8756.703000000001, -8825.001, -8892.537, -8959.315, -9025.34, -9090.617, -9155.152, -9218.949, -9282.011999999999, -9344.347, -9405.958, -9466.85, -9527.027, -9586.494, -9645.255, -9703.314, -9760.676, -9817.344000000001, -9873.323, -9928.617, -9983.229, -10037.164, -10090.426, -10143.018, -10194.943000000001, -10246.206, -10296.81, -10346.759, -10396.056, -10444.705, -10492.708, -10540.07, -10586.793, -10632.881000000001, -10678.337, -10723.163999999999, -10767.364, -10810.942, -10853.899, -10896.24, -10937.966, -10979.081, -11019.587, -11059.488000000001, -11098.785, -11137.481000000002, -11175.58, -11213.083, -11249.993999999999, -11286.313999999998, -11322.046, -11357.192, -11391.756000000001, -11425.738000000001, -11459.142, -11491.97, -11524.223999999998, -11555.905, -11587.017, -11617.562, -11647.541000000001, -11676.956, -11705.81, -11734.104, -11761.84, -11789.021, -11815.649, -11841.723999999998, -11867.249, -11892.226, -11916.656, -11940.541000000001, -11963.883, -11986.684, -12008.945, -12030.668, -12051.854, -12072.503999999999, -12092.622, -12112.207, -12131.261999999999, -12149.787, -12167.785, -12185.257, -12202.203000000001, -12218.626, -12234.527, -12249.908000000001, -12264.768, -12279.11, -12292.935, -12306.243, -12319.037, -12331.317, -12343.083999999999, -12354.34, -12365.086000000001, -12375.323, -12385.051000000001, -12394.271999999999, -12402.987, -12411.196000000002, -12418.902, -12426.104, -12432.803, -12439.002, -12444.698999999999, -12449.896999999999, -12454.596000000001, -12458.796, -12462.5, -12465.706, -12468.417, -12470.633, -12472.355, -12473.582, -12474.317, -12474.56, -12474.311000000002, -12473.571000000002, -12472.34, -12470.62, -12468.41, -12465.711000000001, -12462.525, -12458.85, -12454.688, -12450.04, -12444.905, -12439.285, -12433.178999999998, -12426.588, -12419.511999999999, -12411.952, -12403.908000000001, -12395.381000000001, -12386.37, -12376.877, -12366.901000000002, -12356.442, -12345.501, -12334.079, -12322.173999999999, -12309.788, -12296.921, -12283.573, -12269.743, -12255.433, -12240.643, -12225.372, -12209.618999999999, -12193.386999999999, -12176.673, -12159.48, -12141.806, -12123.651000000002, -12105.016000000001, -12085.901000000002, -12066.305, -12046.229, -12025.671999999999, -12004.633999999998, -11983.115, -11961.115, -11938.633999999998, -11915.671999999999, -11892.228000000001, -11868.302, -11843.895, -11819.005, -11793.633, -11767.778, -11741.44, -11714.618999999999, -11687.315, -11659.526000000002, -11631.253, -11602.496000000001, -11573.253, -11543.525, -11513.311000000002, -11482.611, -11451.423999999999, -11419.75, -11387.589, -11354.938999999998, -11321.8, -11288.171999999999, -11254.053999999998, -11219.446000000002, -11184.346000000001, -11148.755, -11112.671999999999, -11076.096000000001, -11039.027, -11001.463, -10963.403999999999, -10924.848999999998, -10885.798999999999, -10846.251, -10806.205, -10765.66, -10724.616000000002, -10683.071000000002, -10641.025, -10598.476999999999, -10555.426000000001, -10511.871000000001, -10467.812, -10423.246, -10378.174, -10332.594000000001, -10286.506, -10239.908000000001, -10192.799, -10145.178, -10097.044, -10048.396, -9999.233, -9949.554, -9899.357, -9848.641, -9797.405999999999, -9745.649, -9693.37, -9640.568000000001, -9587.24, -9533.386999999999, -9479.005, -9424.095, -9368.655, -9312.683, -9256.178, -9199.138, -9141.563, -9083.45, -9024.798, -8965.605, -8905.871, -8845.593, -8784.77, -8723.4, -8661.482, -8599.013, -8535.993, -8472.42, -8408.291, -8343.606, -8278.362, -8212.556999999999, -8146.191, -8079.26, -8011.764, -7943.7, -7875.066, -7805.861, -7736.0830000000005, -7665.729, -7594.799, -7523.289000000001, -7451.198, -7378.524, -7305.265, -7231.419, -7156.984, -7081.956999999999, -7006.338000000001, -6930.1230000000005, -6853.311, -6775.9, -6697.887, -6619.27, -6540.048000000001, -6460.218000000001, -6379.778, -6298.727, -6217.061, -6134.78, -6051.880999999999, -5968.361, -5884.22, -5799.455, -5714.063, -5628.044, -5541.395, -5454.1140000000005, -5366.2, -5277.651, -5188.465, -5098.64, -5008.175, -4917.069, -4825.32, -4732.9259999999995, -4639.888, -4546.202, -4451.869000000001, -4356.888, -4261.258, -4164.979, -4068.05, -3970.4709999999995, -3872.242, -3773.364, -3673.8379999999997, -3573.663, -3472.843, -3371.377, -3269.268, -3166.5190000000002, -3063.131, -2959.1090000000004, -2854.4570000000003, -2749.178, -2643.277, -2536.761, -2429.636, -2321.909, -2213.587, -2104.68, -1995.1989999999998, -1885.154, -1774.558, -1663.425, -1551.771, -1439.612, -1326.967, -1213.857, -1100.306, -986.3380000000001, -871.9810000000001, -757.2660000000001, -642.2280000000001, -526.903, -411.333, -295.562, -179.641, -63.625, 52.426, 168.446, 284.362, 400.093, 515.55, 630.636, 745.2439999999999, 859.2560000000001, 972.5419999999999, 1084.9589999999998, 1196.35, 1306.542, 1415.3470000000002, 1522.557, 1627.943, 1731.256, 1832.226, 1930.555, 2025.922, 2117.978, 2206.349, 2290.63, 2370.393, 2445.183, 2514.521, 2577.911, 2634.844, 2684.804, 2727.28, 2761.7709999999997, 2787.8059999999996, 2804.955, 2812.837, 2811.145, 2799.652, 2778.222, 2746.82, 2705.5170000000003, 2654.4840000000004, 2593.995, 2524.411, 2446.173, 2359.782, 2265.792, 2164.784, 2057.359, 1944.118, 1825.656, 1702.5510000000002, 1575.355, 1444.5870000000002, 1310.7379999999998, 1174.258, 1035.563, 895.033, 753.0139999999999, 609.819, 465.72900000000004, 320.995, 175.845, 30.479, -114.92399999999999, -260.204, -405.221, -549.85, -693.9830000000001, -837.523, -980.3839999999999, -1122.494, -1263.787, -1404.75, -1543.7060000000001, -1682.241, -1819.777, -1956.281, -2091.728, -2226.096, -2359.365, -2491.522, -2622.553, -2752.449, -2881.202, -3008.808, -3135.261, -3260.562, -3384.7070000000003, -3507.699, -3629.54, -3750.23, -3869.775, -3988.178, -4105.445, -4221.58, -4336.589, -4450.48, -4563.258, -4674.931, -4785.505999999999, -4894.991, -5003.393, -5110.721, -5216.981, -5322.182, -5426.3330000000005, -5529.441, -5631.515, -5732.563, -5832.594, -5931.615, -6029.635, -6126.661, -6222.703, -6317.768, -6411.865, -6505.0, -6597.183000000001, -6688.42, -6778.72, -6868.09, -6956.539000000001, -7044.071999999999, -7130.698, -7216.424, -7301.258000000001, -7385.206, -7468.275, -7550.472, -7631.804, -7712.279, -7791.901, -7870.679, -7948.618, -8025.725, -8102.005999999999, -8177.468000000001, -8252.115, -8325.954, -8398.992, -8471.233, -8542.684000000001, -8613.35, -8683.237, -8752.35, -8820.694, -8888.276, -8955.099, -9021.169, -9086.492, -9151.071, -9214.912, -9278.02, -9340.4, -9402.055, -9462.991, -9523.212, -9582.723, -9641.528, -9699.63, -9757.035, -9813.747, -9869.769, -9925.106, -9979.761, -10033.739, -10087.043, -10139.677, -10191.644, -10242.95, -10293.596, -10343.586, -10392.925, -10441.615, -10489.66, -10537.063, -10583.828000000001, -10629.957, -10675.454, -10720.321000000002, -10764.562, -10808.181, -10851.178999999998, -10893.56, -10935.326000000001, -10976.481000000002, -11017.027, -11056.966999999999, -11096.303999999998, -11135.041000000001, -11173.178999999998, -11210.721000000001, -11247.671, -11284.03, -11319.802, -11354.987, -11389.589, -11423.611, -11457.053, -11489.92, -11522.212, -11553.931999999999, -11585.082, -11615.665, -11645.681, -11675.135, -11704.026000000002, -11732.358, -11760.133, -11787.351, -11814.016000000001, -11840.128, -11865.691, -11890.705, -11915.171999999999, -11939.094, -11962.473999999998, -11985.311000000002, -12007.608999999999, -12029.368, -12050.59, -12071.278, -12091.431999999999, -12111.053, -12130.143999999998, -12148.706, -12166.74, -12184.247, -12201.23, -12217.688, -12233.625, -12249.041000000001, -12263.937, -12278.313999999998, -12292.173999999999, -12305.518, -12318.347, -12330.662, -12342.465, -12353.756000000001, -12364.536, -12374.806999999999, -12384.57, -12393.826000000001, -12402.576000000001, -12410.82, -12418.56, -12425.796, -12432.53, -12438.761999999999, -12444.493999999999, -12449.726, -12454.458999999999, -12458.693000000001, -12462.43, -12465.671, -12468.416000000001, -12470.665, -12472.42, -12473.681999999999, -12474.45, -12474.726, -12474.51, -12473.803, -12472.606000000002, -12470.918, -12468.741000000002, -12466.076000000001, -12462.921999999999, -12459.28, -12455.152, -12450.536, -12445.434, -12439.846000000001, -12433.771999999999, -12427.214, -12420.171, -12412.643, -12404.631000000001, -12396.136, -12387.158000000001, -12377.696000000002, -12367.752, -12357.326000000001, -12346.417, -12335.026000000002, -12323.153, -12310.798999999999, -12297.964, -12284.646999999999, -12270.848999999998, -12256.57, -12241.811000000002, -12226.571000000002, -12210.85, -12194.649, -12177.966999999999, -12160.803999999998, -12143.161, -12125.038, -12106.434, -12087.35, -12067.785, -12047.739, -12027.213, -12006.205, -11984.716999999999, -11962.748, -11940.298, -11917.366000000002, -11893.952, -11870.056999999999, -11845.68, -11820.82, -11795.479, -11769.653999999999, -11743.346000000001, -11716.555, -11689.281, -11661.521999999999, -11633.278999999999, -11604.551000000001, -11575.339, -11545.64, -11515.456, -11484.786, -11453.628999999999, -11421.983999999999, -11389.851999999999, -11357.231000000002, -11324.122, -11290.523000000001, -11256.435, -11221.856000000002, -11186.786, -11151.223999999998, -11115.17, -11078.623, -11041.582, -11004.046999999999, -10966.017, -10927.492, -10888.47, -10848.951000000001, -10808.933, -10768.417, -10727.402, -10685.886, -10643.868, -10601.348999999998, -10558.326000000001, -10514.8, -10470.769, -10426.231, -10381.188, -10335.636, -10289.576, -10243.006, -10195.925, -10148.332, -10100.226, -10051.606, -10002.471, -9952.82, -9902.65, -9851.963, -9800.755, -9749.026, -9696.775, -9644.0, -9590.7, -9536.874, -9482.52, -9427.636999999999, -9372.225, -9316.28, -9259.802, -9202.79, -9145.241, -9087.155999999999, -9028.530999999999, -8969.365, -8909.658000000001, -8849.407, -8788.610999999999, -8727.268, -8665.376, -8602.935, -8539.940999999999, -8476.395, -8412.293, -8347.634, -8282.416, -8216.638, -8150.298000000001, -8083.394, -8015.924, -7947.887, -7879.279, -7810.101, -7740.348000000001, -7670.021, -7599.116, -7527.633000000001, -7455.568, -7382.92, -7309.686, -7235.866, -7161.456999999999, -7086.456, -7010.861999999999, -6934.673000000001, -6857.887, -6780.5, -6702.513000000001, -6623.922, -6544.725, -6464.920999999999, -6384.505999999999, -6303.48, -6221.839, -6139.5830000000005, -6056.7080000000005, -5973.213000000001, -5889.096, -5804.355, -5718.988, -5632.994000000001, -5546.369000000001, -5459.111999999999, -5371.222, -5282.696999999999, -5193.534000000001, -5103.734, -5013.292, -4922.21, -4830.484, -4738.113, -4645.097, -4551.435, -4457.124, -4362.166, -4266.558, -4170.3, -4073.393, -3975.835, -3877.6279999999997, -3778.7709999999997, -3679.265, -3579.111, -3478.3109999999997, -3376.865, -3274.775, -3172.045, -3068.676, -2964.673, -2860.038, -2754.776, -2648.893, -2542.393, -2435.283, -2327.57, -2219.263, -2110.37, -2000.902, -1890.87, -1780.286, -1669.1629999999998, -1557.5179999999998, -1445.3670000000002, -1332.729, -1219.625, -1106.078, -992.113, -877.758, -763.043, -648.002, -532.672, -417.095, -301.316, -185.38299999999998, -69.352, 46.717, 162.75799999999998, 278.698, 394.458, 509.949, 625.073, 739.725, 853.7860000000001, 967.127, 1079.606, 1191.067, 1301.339, 1410.2320000000002, 1517.5379999999998, 1623.033, 1726.467, 1827.569, 1926.045, 2021.575, 2113.811, 2202.3779999999997, 2286.875, 2366.873, 2441.919, 2511.538, 2575.23, 2632.49, 2682.801, 2725.65, 2760.538, 2786.993, 2804.579, 2812.917, 2811.6940000000004, 2800.6809999999996, 2779.736, 2748.822, 2708.002, 2657.445, 2597.4179999999997, 2528.28, 2450.466, 2364.479, 2270.866, 2170.209, 2063.107, 1950.1629999999998, 1831.971, 1709.109, 1582.13, 1451.558, 1317.879, 1181.549, 1042.984, 902.567, 760.645, 617.531, 473.50800000000004, 328.829, 183.72299999999998, 38.391, -106.98700000000001, -252.25099999999998, -397.259, -541.887, -686.023, -829.572, -972.448, -1114.576, -1255.891, -1396.338, -1535.865, -1674.432, -1812.0020000000002, -1948.5420000000001, -2084.028, -2218.436, -2351.7470000000003, -2483.947, -2615.0229999999997, -2744.966, -2873.7659999999996, -3001.4190000000003, -3127.921, -3253.2709999999997, -3377.466, -3500.509, -3622.3990000000003, -3743.1409999999996, -3862.737, -3981.192, -4098.5109999999995, -4214.698, -4329.76, -4443.7029999999995, -4556.534000000001, -4668.259, -4778.887, -4888.425, -4996.88, -5104.259, -5210.572, -5315.826, -5420.029, -5523.189, -5625.316, -5726.416, -5826.4980000000005, -5925.571, -6023.643, -6120.721, -6216.814, -6311.931, -6406.078, -6499.265, -6591.4980000000005, -6682.786, -6773.137, -6862.558000000001, -6951.057, -7038.64, -7125.316, -7211.092, -7295.975, -7379.972, -7463.09, -7545.335999999999, -7626.717, -7707.24, -7786.911, -7865.736999999999, -7943.724, -8020.878000000001, -8097.206999999999, -8172.715, -8247.41, -8321.296, -8394.381, -8466.669, -8538.166, -8608.879, -8678.813, -8747.972, -8816.363000000001, -8883.99, -8950.858, -9016.974, -9082.341999999999, -9146.966, -9210.851999999999, -9274.005, -9336.429, -9398.129, -9459.109, -9519.375, -9578.929, -9637.778, -9695.924, -9753.373, -9810.128, -9866.193000000001, -9921.573, -9976.271, -10030.292, -10083.638, -10136.315, -10188.325, -10239.671999999999, -10290.360999999999, -10340.394, -10389.775, -10438.507, -10486.593, -10534.038, -10580.843, -10627.013, -10672.551000000001, -10717.458999999999, -10761.741000000002, -10805.4, -10848.438999999998, -10890.86, -10932.667, -10973.862, -11014.448999999999, -11054.428999999998, -11093.806, -11132.582, -11170.758999999998, -11208.341999999999, -11245.331, -11281.729, -11317.54, -11352.764, -11387.405, -11421.466, -11454.947, -11487.851999999999, -11520.183, -11551.941, -11583.13, -11613.751, -11643.806, -11673.298, -11702.226999999999, -11730.597, -11758.409, -11785.665, -11812.367, -11838.517, -11864.117, -11889.168, -11913.673, -11937.632, -11961.048, -11983.923, -12006.257, -12028.053, -12049.312, -12070.036, -12090.226, -12109.883999999998, -12129.011, -12147.608999999999, -12165.678999999998, -12183.222, -12200.241000000002, -12216.735, -12232.708, -12248.159, -12263.09, -12277.502, -12291.398000000001, -12304.777, -12317.641000000001, -12329.991000000002, -12341.829, -12353.155, -12363.971000000001, -12374.277, -12384.075, -12393.366000000002, -12402.15, -12410.428, -12418.203000000001, -12425.473, -12432.242, -12438.508, -12444.274, -12449.54, -12454.306999999999, -12458.575, -12462.346000000001, -12465.621000000001, -12468.399, -12470.681999999999, -12472.471000000001, -12473.766000000001, -12474.567, -12474.877, -12474.694, -12474.02, -12472.856000000002, -12471.202, -12469.058, -12466.426000000001, -12463.305, -12459.696000000002, -12455.6, -12451.017, -12445.947, -12440.392, -12434.351, -12427.825, -12420.813999999998, -12413.318000000001, -12405.339, -12396.876, -12387.93, -12378.501, -12368.589, -12358.194, -12347.318000000001, -12335.958, -12324.118, -12311.795, -12298.991000000002, -12285.706, -12271.94, -12257.692, -12242.964, -12227.755, -12212.066, -12195.895, -12179.245, -12162.113000000001, -12144.501, -12126.409, -12107.836000000001, -12088.782, -12069.248, -12049.233, -12028.738000000001, -12007.761, -11986.303, -11964.365, -11941.945, -11919.043, -11895.66, -11871.795, -11847.448999999999, -11822.618999999999, -11797.308, -11771.513, -11745.236, -11718.475, -11691.23, -11663.501, -11635.288, -11606.59, -11577.408000000001, -11547.739, -11517.585, -11486.944, -11455.817, -11424.202, -11392.098999999998, -11359.508, -11326.428, -11292.858, -11258.798999999999, -11224.249, -11189.208, -11153.676000000001, -11117.651000000002, -11081.133, -11044.121000000001, -11006.615, -10968.614, -10930.118, -10891.124, -10851.633999999998, -10811.645, -10771.158000000001, -10730.171, -10688.683, -10646.695, -10604.204, -10561.21, -10517.712, -10473.709, -10429.2, -10384.184000000001, -10338.661, -10292.628, -10246.086, -10199.033000000001, -10151.468, -10103.39, -10054.798, -10005.690999999999, -9956.068000000001, -9905.927, -9855.267, -9804.087, -9752.386, -9700.162, -9647.415, -9594.143, -9540.344000000001, -9486.018, -9431.162, -9375.777, -9319.86, -9263.409, -9206.424, -9148.903, -9090.844000000001, -9032.247, -8973.108, -8913.428, -8853.204, -8792.435, -8731.118, -8669.254, -8606.839, -8543.873, -8480.353000000001, -8416.277, -8351.645, -8286.454, -8220.703000000001, -8154.389, -8087.512, -8020.068, -7952.057, -7883.476, -7814.323, -7744.598000000001, -7674.297, -7603.419, -7531.960999999999, -7459.922, -7387.3, -7314.093000000001, -7240.298000000001, -7165.914000000001, -7090.939, -7015.371, -6939.206999999999, -6862.446, -6785.085, -6707.1230000000005, -6628.557, -6549.3859999999995, -6469.606, -6389.217, -6308.215, -6226.6, -6144.368, -6061.518, -5978.048000000001, -5893.956, -5809.24, -5723.898, -5637.927, -5551.326999999999, -5464.094, -5376.228, -5287.727, -5198.588, -5108.811, -5018.395, -4927.335, -4835.6320000000005, -4743.285, -4650.292, -4556.653, -4462.365, -4367.429, -4271.843, -4175.608, -4078.722, -3981.187, -3883.0009999999997, -3784.165, -3684.6809999999996, -3584.547, -3483.7670000000003, -3382.341, -3280.272, -3177.5609999999997, -3074.211, -2970.2259999999997, -2865.61, -2760.366, -2654.4990000000003, -2548.016, -2440.922, -2333.225, -2224.933, -2116.054, -2006.6, -1896.58, -1786.007, -1674.896, -1563.26, -1451.118, -1338.4879999999998, -1225.39, -1111.848, -997.8860000000001, -883.5319999999999, -768.818, -653.775, -538.442, -422.85900000000004, -307.07099999999997, -191.127, -75.082, 41.004, 157.066, 273.03, 388.81800000000004, 504.341, 619.503, 734.198, 848.307, 961.704, 1074.245, 1185.776, 1296.125, 1405.105, 1512.5079999999998, 1618.11, 1721.664, 1822.899, 1921.5220000000002, 2017.213, 2109.627, 2198.391, 2283.103, 2363.337, 2438.64, 2508.538, 2572.533, 2630.119, 2680.781, 2724.005, 2759.2909999999997, 2786.1659999999997, 2804.192, 2812.988, 2812.237, 2801.7059999999997, 2781.25, 2750.8259999999996, 2710.492, 2660.414, 2600.8520000000003, 2532.1639999999998, 2454.78, 2369.198, 2275.967, 2175.6639999999998, 2068.89, 1956.245, 1838.326, 1715.71, 1588.951, 1458.575, 1325.069, 1188.891, 1050.4589999999998, 910.1560000000001, 768.331, 625.299, 481.345, 336.722, 191.66, 46.361999999999995, -98.991, -244.239, -389.23800000000006, -533.863, -678.0039999999999, -821.562, -964.452, -1106.599, -1247.937, -1388.41, -1527.967, -1666.566, -1804.17, -1940.7479999999998, -2076.2729999999997, -2210.721, -2344.075, -2476.319, -2607.44, -2737.429, -2866.277, -2993.978, -3120.53, -3245.929, -3370.1740000000004, -3493.268, -3615.21, -3736.0029999999997, -3855.652, -3974.159, -4091.53, -4207.77, -4322.884, -4436.88, -4549.764, -4661.543, -4772.224, -4881.815, -4990.323, -5097.755999999999, -5204.121, -5309.428000000001, -5413.684, -5516.898, -5619.076999999999, -5720.23, -5820.365, -5919.49, -6017.6140000000005, -6114.744000000001, -6210.889, -6306.058000000001, -6400.257, -6493.494000000001, -6585.779, -6677.118, -6767.52, -6856.991999999999, -6945.541, -7033.175, -7119.901, -7205.727, -7290.659000000001, -7374.706, -7457.874, -7540.169, -7621.599, -7702.170999999999, -7781.891, -7860.765, -7938.8009999999995, -8016.003000000001, -8092.38, -8167.936, -8242.678, -8316.612, -8389.744, -8462.079, -8533.624, -8604.383, -8674.364, -8743.569, -8812.006, -8879.679, -8946.593, -9012.755, -9078.168, -9142.838, -9206.769, -9269.966999999999, -9332.436, -9394.18, -9455.205, -9515.515, -9575.114, -9634.006, -9692.197, -9749.689, -9806.488000000001, -9862.596, -9918.02, -9972.761, -10026.825, -10080.214, -10132.933, -10184.985999999999, -10236.376, -10287.107, -10337.181999999999, -10386.605, -10435.379, -10483.507, -10530.993, -10577.84, -10624.052, -10669.631000000001, -10714.58, -10758.903, -10802.603000000001, -10845.681999999999, -10888.143999999998, -10929.992, -10971.226999999999, -11011.854, -11051.874, -11091.291000000001, -11130.107, -11168.323999999999, -11205.946000000002, -11242.975, -11279.413, -11315.261999999999, -11350.526000000002, -11385.207, -11419.306, -11452.826000000001, -11485.77, -11518.139, -11549.936000000002, -11581.163, -11611.823, -11641.915, -11671.445, -11700.413, -11728.821000000002, -11756.671, -11783.965, -11810.705, -11836.892, -11862.528999999999, -11887.618, -11912.159, -11936.156, -11959.608999999999, -11982.52, -12004.892, -12026.723999999998, -12048.02, -12068.78, -12089.007, -12108.701000000001, -12127.865, -12146.499, -12164.605, -12182.184, -12199.239, -12215.768999999998, -12231.777, -12247.264, -12262.231000000002, -12276.678999999998, -12290.61, -12304.024, -12316.923999999999, -12329.309, -12341.181999999999, -12352.543, -12363.393999999998, -12373.735, -12383.568000000001, -12392.893, -12401.712, -12410.025, -12417.833999999999, -12425.139, -12431.942, -12438.242, -12444.042, -12449.341999999999, -12454.143, -12458.446000000002, -12462.251, -12465.559, -12468.371000000001, -12470.688, -12472.51, -12473.838, -12474.673999999999, -12475.016000000001, -12474.867, -12474.226999999999, -12473.096000000001, -12471.473999999998, -12469.364, -12466.764, -12463.676000000001, -12460.1, -12456.037, -12451.486, -12446.45, -12440.927, -12434.918, -12428.425, -12421.446000000002, -12413.983, -12406.036, -12397.606000000002, -12388.691, -12379.294, -12369.413999999999, -12359.052, -12348.207, -12336.88, -12325.071000000002, -12312.78, -12300.008, -12286.753999999999, -12273.018999999998, -12258.803, -12244.107, -12228.928999999998, -12213.271, -12197.132, -12180.511999999999, -12163.412, -12145.831, -12127.77, -12109.228000000001, -12090.205, -12070.702, -12050.716999999999, -12030.253, -12009.306999999999, -11987.88, -11965.972, -11943.582, -11920.711000000001, -11897.358999999999, -11873.524, -11849.208, -11824.409, -11799.127, -11773.363000000001, -11747.115, -11720.383999999998, -11693.17, -11665.471000000001, -11637.288, -11608.62, -11579.466999999999, -11549.828000000001, -11519.703000000001, -11489.093, -11457.995, -11426.409, -11394.336000000001, -11361.774, -11328.723999999998, -11295.184, -11261.153999999999, -11226.633, -11191.622, -11156.118, -11120.122, -11083.633, -11046.651000000002, -11009.173999999999, -10971.202, -10932.733999999999, -10893.77, -10854.308, -10814.348, -10773.889, -10732.931, -10691.472, -10649.511999999999, -10607.05, -10564.083999999999, -10520.614, -10476.64, -10432.159, -10387.171999999999, -10341.677, -10295.673, -10249.159, -10202.134, -10154.597, -10106.546999999999, -10057.983, -10008.904, -9959.309000000001, -9909.196, -9858.564, -9807.411, -9755.738000000001, -9703.542, -9650.823, -9597.578000000001, -9543.806999999999, -9489.508, -9434.681, -9379.323, -9323.433, -9267.01, -9210.052, -9152.558, -9094.527, -9035.956, -8976.845, -8917.192, -8856.995, -8796.253, -8734.964, -8673.126, -8610.738000000001, -8547.799, -8484.306, -8420.257, -8355.652, -8290.488000000001, -8224.763, -8158.476, -8091.625, -8024.2080000000005, -7956.223000000001, -7887.669, -7818.543000000001, -7748.844, -7678.569, -7607.717, -7536.286, -7464.273, -7391.677, -7318.496, -7244.728, -7170.37, -7095.420999999999, -7019.879, -6943.741, -6867.005999999999, -6789.670999999999, -6711.734, -6633.194, -6554.048000000001, -6474.294, -6393.93, -6312.954000000001, -6231.3640000000005, -6149.156999999999, -6066.3330000000005, -5982.888000000001, -5898.821, -5814.13, -5728.812, -5642.866, -5556.29, -5469.0830000000005, -5381.241, -5292.764, -5203.65, -5113.898, -5023.504, -4932.469, -4840.79, -4748.465999999999, -4655.497, -4561.880999999999, -4467.616, -4372.7029999999995, -4277.14, -4180.928, -4084.065, -3986.551, -3888.387, -3789.573, -3690.11, -3589.998, -3489.239, -3387.8340000000003, -3285.784, -3183.094, -3079.764, -2975.798, -2871.2, -2765.974, -2660.1259999999997, -2553.66, -2446.583, -2338.902, -2230.625, -2121.761, -2012.3210000000001, -1902.3139999999999, -1791.754, -1680.654, -1569.029, -1456.896, -1344.274, -1231.184, -1117.647, -1003.689, -889.3380000000001, -774.6239999999999, -659.581, -544.244, -428.656, -312.86, -196.90599999999998, -80.848, 35.254, 151.336, 267.324, 383.139, 498.694, 613.893, 728.63, 842.7869999999999, 956.238, 1068.8410000000001, 1180.44, 1290.867, 1399.933, 1507.433, 1613.1429999999998, 1716.816, 1818.184, 1916.954, 2012.807, 2105.4, 2194.361, 2279.2889999999998, 2359.76, 2435.321, 2505.5, 2569.8, 2627.715, 2678.7309999999998, 2722.333, 2758.0209999999997, 2785.32, 2803.79, 2813.0490000000004, 2812.775, 2802.7329999999997, 2782.7709999999997, 2752.843, 2713.0029999999997, 2663.4109999999996, 2604.322, 2536.09, 2459.1420000000003, 2373.974, 2281.13, 2181.188, 2074.746, 1962.4070000000002, 1844.764, 1722.398, 1595.864, 1465.6870000000001, 1332.358, 1196.335, 1058.037, 917.85, 776.125, 633.1759999999999, 489.291, 344.725, 199.708, 54.445, -90.884, -236.114, -381.105, -525.7280000000001, -669.873, -813.441, -956.346, -1098.513, -1239.874, -1380.345, -1519.961, -1658.5929999999998, -1796.233, -1932.849, -2068.413, -2202.904, -2336.302, -2468.59, -2599.758, -2729.7940000000003, -2858.69, -2986.441, -3113.042, -3238.492, -3362.789, -3485.934, -3607.929, -3728.775, -3848.4759999999997, -3967.0370000000003, -4084.461, -4200.755, -4315.923, -4429.973, -4542.911, -4654.744000000001, -4765.479, -4875.125, -4983.687, -5091.173, -5197.593, -5302.954000000001, -5407.264, -5510.531, -5612.764, -5713.97, -5814.158, -5913.3369999999995, -6011.514, -6108.696999999999, -6204.895, -6300.116, -6394.366999999999, -6487.656999999999, -6579.994000000001, -6671.385, -6761.838000000001, -6851.361999999999, -6939.9619999999995, -7027.647, -7114.424, -7200.3009999999995, -7285.284000000001, -7369.380999999999, -7452.599, -7534.944, -7616.424, -7697.045, -7776.814, -7855.738, -7933.821999999999, -8011.0740000000005, -8087.499, -8163.104, -8237.894, -8311.876, -8385.056, -8457.439, -8529.030999999999, -8599.837, -8669.865, -8739.117, -8807.601, -8875.32, -8942.280999999999, -9008.489, -9073.948, -9138.664, -9202.641, -9265.884, -9328.399, -9390.188, -9451.258, -9511.613000000001, -9571.257, -9630.193000000001, -9688.428, -9745.965, -9802.806999999999, -9858.96, -9914.427, -9969.212, -10023.319, -10076.752, -10129.514000000001, -10181.61, -10233.043, -10283.815999999999, -10333.934000000001, -10383.4, -10432.216, -10480.386, -10527.913999999999, -10574.803, -10621.056, -10666.677, -10711.668, -10756.032, -10799.773000000001, -10842.893, -10885.396, -10927.284, -10968.561000000002, -11009.228000000001, -11049.288999999999, -11088.746000000001, -11127.601999999999, -11165.858999999999, -11203.521, -11240.59, -11277.067, -11312.956, -11348.26, -11382.979, -11417.118, -11450.677, -11483.66, -11516.068000000001, -11547.903999999999, -11579.17, -11609.868, -11639.999, -11669.567, -11698.573999999999, -11727.018999999998, -11754.907, -11782.239, -11809.017, -11835.242, -11860.917, -11886.043, -11910.622, -11934.656, -11958.146, -11981.095, -12003.503, -12025.373, -12046.705, -12067.502, -12087.766000000001, -12107.496000000001, -12126.696000000002, -12145.367, -12163.508999999998, -12181.125, -12198.215, -12214.782, -12230.826000000001, -12246.348, -12261.351, -12275.835, -12289.801000000001, -12303.251, -12316.186000000002, -12328.607, -12340.515, -12351.911, -12362.796999999999, -12373.173, -12383.041000000001, -12392.401000000002, -12401.253999999999, -12409.601999999999, -12417.446000000002, -12424.785, -12431.622, -12437.958, -12443.792, -12449.126, -12453.961000000001, -12458.298, -12462.136999999999, -12465.479, -12468.325, -12470.675, -12472.531, -12473.893, -12474.761999999999, -12475.138, -12475.021999999999, -12474.415, -12473.317, -12471.729, -12469.652, -12467.085, -12464.03, -12460.487, -12456.457, -12451.938999999998, -12446.935, -12441.445, -12435.469, -12429.008, -12422.062, -12414.631000000001, -12406.716999999999, -12398.318000000001, -12389.436000000002, -12380.071000000002, -12370.223, -12359.893, -12349.08, -12337.785, -12326.007, -12313.748, -12301.008, -12287.786, -12274.083, -12259.898000000001, -12245.233, -12230.087, -12214.46, -12198.351999999999, -12181.764, -12164.695, -12147.145, -12129.114, -12110.603000000001, -12091.612, -12072.139, -12052.186000000002, -12031.752, -12010.837, -11989.44, -11967.563, -11945.205, -11922.365, -11899.042, -11875.238000000001, -11850.952, -11826.183, -11800.931999999999, -11775.198, -11748.98, -11722.28, -11695.095, -11667.426000000001, -11639.273000000001, -11610.635, -11581.511, -11551.902, -11521.806999999999, -11491.226, -11460.157, -11428.601, -11396.558, -11364.025, -11331.003999999999, -11297.493999999999, -11263.493, -11229.002, -11194.018999999998, -11158.545, -11122.578000000001, -11086.118999999999, -11049.165, -11011.718, -10973.775, -10935.336000000001, -10896.401000000002, -10856.968, -10817.037, -10776.607, -10735.677, -10694.247, -10652.315, -10609.881000000001, -10566.944, -10523.503, -10479.556999999999, -10435.105, -10390.146, -10344.679, -10298.703000000001, -10252.218, -10205.221, -10157.712, -10109.69, -10061.154, -10012.103000000001, -9962.535, -9912.45, -9861.846, -9810.721, -9759.076, -9706.908000000001, -9654.216999999999, -9601.0, -9547.256, -9492.985, -9438.185, -9382.854, -9326.992, -9270.596, -9213.666, -9156.2, -9098.196, -9039.653, -8980.569, -8920.943000000001, -8860.773000000001, -8800.058, -8738.796, -8676.985, -8614.625, -8551.712, -8488.246, -8424.224, -8359.646, -8294.508, -8228.81, -8162.55, -8095.726, -8028.335999999999, -7960.378000000001, -7891.851, -7822.751, -7753.078, -7682.83, -7612.004, -7540.599, -7468.611999999999, -7396.043000000001, -7322.888000000001, -7249.146, -7174.814, -7099.891, -7024.375, -6948.263000000001, -6871.553000000001, -6794.244000000001, -6716.334, -6637.819, -6558.6990000000005, -6478.97, -6398.632, -6317.681, -6236.116999999999, -6153.936, -6071.138000000001, -5987.718000000001, -5903.6759999999995, -5819.01, -5733.717, -5647.795999999999, -5561.245, -5474.062, -5386.246, -5297.793000000001, -5208.7029999999995, -5118.975, -5028.605, -4937.594, -4845.939, -4753.639, -4660.693, -4567.101, -4472.86, -4377.97, -4282.43, -4186.24, -4089.4, -3991.909, -3893.768, -3794.9759999999997, -3695.535, -3595.4440000000004, -3494.7059999999997, -3393.322, -3291.2929999999997, -3188.6220000000003, -3085.312, -2981.366, -2876.7870000000003, -2771.58, -2665.75, -2559.301, -2452.241, -2344.577, -2236.3160000000003, -2127.467, -2018.0410000000002, -1908.0479999999998, -1797.5, -1686.412, -1574.7979999999998, -1462.6760000000002, -1350.0629999999999, -1236.979, -1123.4489999999998, -1009.4960000000001, -895.148, -780.435, -665.3910000000001, -550.052, -434.458, -318.655, -202.692, -86.62100000000001, 29.497, 145.59799999999998, 261.60900000000004, 377.45099999999996, 493.038, 608.273, 723.051, 837.2560000000001, 950.7610000000001, 1063.424, 1175.093, 1285.596, 1394.747, 1502.3429999999998, 1608.16, 1711.9520000000002, 1813.4520000000002, 1912.369, 2008.384, 2101.155, 2190.311, 2275.455, 2356.163, 2431.982, 2502.4410000000003, 2567.0460000000003, 2625.29, 2676.659, 2720.639, 2756.7290000000003, 2784.4509999999996, 2803.368, 2813.09, 2813.2940000000003, 2803.741, 2784.276, 2754.8459999999995, 2715.5009999999997, 2666.397, 2607.784, 2540.01, 2463.501, 2378.748, 2286.2929999999997, 2186.715, 2080.6079999999997, 1968.575, 1851.2120000000002, 1729.098, 1602.79, 1472.8129999999999, 1339.662, 1203.7939999999999, 1065.632, 925.562, 783.937, 641.073, 497.25699999999995, 352.74800000000005, 207.77599999999998, 62.547, -82.756, -227.97, -372.952, -517.5740000000001, -661.7230000000001, -805.301, -948.222, -1090.4080000000001, -1231.7930000000001, -1372.32, -1511.9379999999999, -1650.604, -1788.28, -1924.934, -2060.5389999999998, -2195.072, -2328.513, -2460.847, -2592.061, -2722.1440000000002, -2851.0890000000004, -2978.89, -3105.542, -3231.0429999999997, -3355.3920000000003, -3478.5890000000004, -3600.636, -3721.5359999999996, -3841.29, -3959.905, -4077.383, -4193.731, -4308.9529999999995, -4423.058, -4536.05, -4647.938, -4758.728, -4868.427, -4977.043, -5084.584, -5191.058, -5296.473000000001, -5400.8369999999995, -5504.158, -5606.444, -5707.704000000001, -5807.946, -5907.178000000001, -6005.409000000001, -6102.646, -6198.897, -6294.17, -6388.474, -6481.816999999999, -6574.205, -6665.648, -6756.153, -6845.728, -6934.379, -7022.116, -7108.944, -7194.871, -7279.905, -7364.052, -7447.32, -7529.717, -7611.246999999999, -7691.918000000001, -7771.736, -7850.709, -7928.842, -8006.143, -8082.616, -8158.27, -8233.108, -8307.138, -8380.366, -8452.796, -8524.436, -8595.289, -8665.363000000001, -8734.663, -8803.193000000001, -8870.96, -8937.966999999999, -9004.221, -9069.726, -9134.488000000001, -9198.511, -9261.8, -9324.359, -9386.194, -9447.309000000001, -9507.708, -9567.396999999999, -9626.378, -9684.657, -9742.238000000001, -9799.124, -9855.321, -9910.832, -9965.66, -10019.81, -10073.286, -10126.091999999999, -10178.232, -10229.707, -10280.523000000001, -10330.683, -10380.19, -10429.048, -10477.261, -10524.831, -10571.761, -10618.056, -10663.718, -10708.75, -10753.156, -10796.938, -10840.098999999998, -10882.643, -10924.572, -10965.889, -11006.596000000001, -11046.697, -11086.194, -11125.091, -11163.388, -11201.09, -11238.198999999999, -11274.716, -11310.645, -11345.987, -11380.746000000001, -11414.923999999999, -11448.521999999999, -11481.543, -11513.99, -11545.865, -11577.169, -11607.905, -11638.075, -11667.681, -11696.725, -11725.208999999999, -11753.133999999998, -11780.503999999999, -11807.319, -11833.582, -11859.294, -11884.458, -11909.073999999999, -11933.145, -11956.671999999999, -11979.658000000001, -12002.103000000001, -12024.01, -12045.378999999999, -12066.213, -12086.513, -12106.28, -12125.516000000001, -12144.223, -12162.401000000002, -12180.053, -12197.178999999998, -12213.782, -12229.861, -12245.42, -12260.458, -12274.976999999999, -12288.979, -12302.464, -12315.434, -12327.89, -12339.833, -12351.264, -12362.184, -12372.595, -12382.497, -12391.892, -12400.78, -12409.163, -12417.041000000001, -12424.415, -12431.286, -12437.656, -12443.524, -12448.892, -12453.761, -12458.131000000001, -12462.003999999999, -12465.38, -12468.258999999998, -12470.643, -12472.533000000001, -12473.928, -12474.83, -12475.24, -12475.157, -12474.583, -12473.518, -12471.963, -12469.918, -12467.385, -12464.362, -12460.851999999999, -12456.854, -12452.368999999999, -12447.396999999999, -12441.938999999998, -12435.996000000001, -12429.567, -12422.653, -12415.255, -12407.373, -12399.007, -12390.157, -12380.823, -12371.007, -12360.708, -12349.926000000001, -12338.663, -12326.917, -12314.688999999998, -12301.98, -12288.79, -12275.118, -12260.965, -12246.331, -12231.216, -12215.62, -12199.543, -12182.986, -12165.947, -12148.428, -12130.428999999998, -12111.948999999999, -12092.987, -12073.546, -12053.623, -12033.219, -12012.333999999999, -11990.969, -11969.122, -11946.794, -11923.983999999999, -11900.692, -11876.918, -11852.661, -11827.923, -11802.701000000001, -11776.997, -11750.81, -11724.138, -11696.983999999999, -11669.344, -11641.221000000001, -11612.612, -11583.518999999998, -11553.938999999998, -11523.873, -11493.321000000002, -11462.282, -11430.755, -11398.741000000002, -11366.238000000001, -11333.246000000001, -11299.764, -11265.793, -11231.331, -11196.377, -11160.931999999999, -11124.993999999999, -11088.563, -11051.638, -11014.219, -10976.305, -10937.895, -10898.988000000001, -10859.583999999999, -10819.681, -10779.28, -10738.378999999999, -10696.976999999999, -10655.073999999999, -10612.668, -10569.758999999998, -10526.346000000001, -10482.428, -10438.004, -10393.073, -10347.634, -10301.687, -10255.229, -10208.26, -10160.779, -10112.785, -10064.277, -10015.253, -9965.713, -9915.655999999999, -9865.079, -9813.982, -9762.364, -9710.224, -9657.56, -9604.37, -9550.654, -9496.411, -9441.638, -9386.335, -9330.499, -9274.131, -9217.228000000001, -9159.789, -9101.812, -9043.295, -8984.239, -8924.64, -8864.497, -8803.809000000001, -8742.574, -8680.79, -8618.456, -8555.57, -8492.13, -8428.135, -8363.584, -8298.473, -8232.801, -8166.568, -8099.77, -8032.406, -7964.475, -7895.974, -7826.901, -7757.254, -7687.031999999999, -7616.232, -7544.853, -7472.893, -7400.349, -7327.22, -7253.504, -7179.198, -7104.3009999999995, -7028.811, -6952.725, -6876.041, -6798.758000000001, -6720.871999999999, -6642.384, -6563.289000000001, -6483.585999999999, -6403.273, -6322.348000000001, -6240.809, -6158.653, -6075.88, -5992.485, -5908.468000000001, -5823.826999999999, -5738.559, -5652.6630000000005, -5566.137, -5478.979, -5391.186, -5302.758000000001, -5213.693, -5123.988, -5033.643, -4942.656, -4851.025, -4758.749, -4665.827, -4572.2570000000005, -4478.04, -4383.173, -4287.656, -4191.4890000000005, -4094.672, -3997.204, -3899.085, -3800.315, -3700.895, -3600.8259999999996, -3500.1090000000004, -3398.7459999999996, -3296.738, -3194.087, -3090.797, -2986.8709999999996, -2882.3109999999997, -2777.123, -2671.31, -2564.88, -2457.837, -2350.19, -2241.945, -2133.111, -2023.6989999999998, -1913.72, -1803.1860000000001, -1692.11, -1580.507, -1468.395, -1355.7910000000002, -1242.715, -1129.191, -1015.243, -900.8989999999999, -786.188, -671.143, -555.802, -440.205, -324.395, -208.422, -92.34, 23.794, 139.91299999999998, 255.946, 371.814, 487.431, 602.701, 717.52, 831.7710000000001, 945.328, 1058.052, 1169.787, 1280.365, 1389.602, 1497.2920000000001, 1603.214, 1707.1229999999998, 1808.753, 1907.8139999999999, 2003.989, 2096.936, 2186.2870000000003, 2271.644, 2352.5860000000002, 2428.66, 2499.397, 2564.305, 2622.875, 2674.595, 2718.9509999999996, 2755.441, 2783.585, 2802.945, 2813.1290000000004, 2813.81, 2804.745, 2785.776, 2756.843, 2717.995, 2669.3779999999997, 2611.241, 2543.928, 2467.8579999999997, 2383.522, 2291.459, 2192.245, 2086.475, 1974.751, 1857.668, 1735.808, 1609.7279999999998, 1479.954, 1346.9820000000002, 1211.271, 1073.246, 933.294, 791.7689999999999, 648.99, 505.245, 360.79400000000004, 215.868, 70.67399999999999, -74.604, -219.801, -364.774, -509.394, -653.547, -797.135, -940.07, -1082.277, -1223.6860000000001, -1364.24, -1503.888, -1642.5870000000002, -1780.299, -1916.9920000000002, -2052.637, -2187.212, -2320.698, -2453.077, -2584.3379999999997, -2714.469, -2843.4629999999997, -2971.3140000000003, -3098.0170000000003, -3223.5690000000004, -3347.97, -3471.22, -3593.32, -3714.272, -3834.0809999999997, -3952.7490000000003, -4070.281, -4186.683, -4301.96, -4416.119000000001, -4529.166, -4641.109, -4751.9529999999995, -4861.707, -4970.377, -5077.973, -5184.502, -5289.971, -5394.389, -5497.764, -5600.105, -5701.419, -5801.715, -5901.0, -5999.284000000001, -6096.575, -6192.879, -6288.205, -6382.562, -6475.956999999999, -6568.398, -6659.893, -6750.45, -6840.076999999999, -6928.78, -7016.566999999999, -7103.446999999999, -7189.425, -7274.51, -7358.7080000000005, -7442.026, -7524.473000000001, -7606.053000000001, -7686.774, -7766.642, -7845.664000000001, -7923.846, -8001.196, -8077.718000000001, -8153.42, -8228.306999999999, -8302.385, -8375.661, -8448.139000000001, -8519.826, -8590.728000000001, -8660.849, -8730.195, -8798.771999999999, -8866.586, -8933.64, -8999.94, -9065.491, -9130.299, -9194.368, -9257.702, -9320.306999999999, -9382.187, -9443.347, -9503.791, -9563.524, -9622.55, -9680.874, -9738.499, -9795.429, -9851.67, -9907.224, -9962.096, -10016.29, -10069.81, -10122.658000000001, -10174.841, -10226.359, -10277.218, -10327.42, -10376.97, -10425.87, -10474.125, -10521.736, -10568.708999999999, -10615.045, -10660.749, -10705.823, -10750.268999999998, -10794.093, -10837.295, -10879.878999999999, -10921.848999999998, -10963.206, -11003.954, -11044.096000000001, -11083.633, -11122.569, -11160.907, -11198.649, -11235.796999999999, -11272.354, -11308.322, -11343.704, -11378.502, -11412.718, -11446.356000000002, -11479.416000000001, -11511.902, -11543.815, -11575.157, -11605.931999999999, -11636.14, -11665.784, -11694.866000000002, -11723.388, -11751.351, -11778.758999999998, -11805.612, -11831.912, -11857.662, -11882.862, -11907.516000000001, -11931.624, -11955.188, -11978.211000000001, -12000.693000000001, -12022.636999999999, -12044.043, -12064.913, -12085.249, -12105.053, -12124.325, -12143.068000000001, -12161.282, -12178.97, -12196.132, -12212.77, -12228.886, -12244.48, -12259.553, -12274.108, -12288.145, -12301.665, -12314.671, -12327.162, -12339.14, -12350.606000000002, -12361.561000000002, -12372.006000000001, -12381.943000000001, -12391.372, -12400.295, -12408.712, -12416.624, -12424.033000000001, -12430.938, -12437.341999999999, -12443.243999999999, -12448.646, -12453.548999999999, -12457.953000000001, -12461.858999999999, -12465.268, -12468.181999999999, -12470.598999999998, -12472.521999999999, -12473.951000000001, -12474.886, -12475.329, -12475.278999999999, -12474.738000000001, -12473.706, -12472.184, -12470.171999999999, -12467.671, -12464.681999999999, -12461.204, -12457.238000000001, -12452.786, -12447.847, -12442.421, -12436.51, -12430.113000000001, -12423.232, -12415.866000000002, -12408.015, -12399.681, -12390.863000000001, -12381.561000000002, -12371.777, -12361.508999999998, -12350.758999999998, -12339.527, -12327.813, -12315.617, -12302.938999999998, -12289.78, -12276.139, -12262.017, -12247.413999999999, -12232.33, -12216.766000000001, -12200.72, -12184.193000000001, -12167.186000000002, -12149.698, -12131.729, -12113.278999999999, -12094.348999999998, -12074.937, -12055.045, -12034.671999999999, -12013.818000000001, -11992.482, -11970.666000000001, -11948.368, -11925.588, -11902.326000000001, -11878.582, -11854.356000000002, -11829.646999999999, -11804.455, -11778.781, -11752.623, -11725.982, -11698.857, -11671.247, -11643.153, -11614.573999999999, -11585.51, -11555.96, -11525.923999999999, -11495.401000000002, -11464.391000000001, -11432.893999999998, -11400.908000000001, -11368.434, -11335.471000000001, -11302.018999999998, -11268.076000000001, -11233.643, -11198.719, -11163.302, -11127.393, -11090.991000000002, -11054.095, -11016.705, -10978.819, -10940.438, -10901.559, -10862.184, -10822.309, -10781.936000000002, -10741.063999999998, -10699.69, -10657.815, -10615.438, -10572.556999999999, -10529.171999999999, -10485.282, -10440.886999999999, -10395.984, -10350.573, -10304.653, -10258.223, -10211.282, -10163.829, -10115.863000000001, -10067.383, -10018.386999999999, -9968.874, -9918.844000000001, -9868.295, -9817.226, -9765.636, -9713.523000000001, -9660.886, -9607.724, -9554.036, -9499.819, -9445.074, -9389.798, -9333.99, -9277.649, -9220.773000000001, -9163.360999999999, -9105.411, -9046.921999999999, -8987.892, -8928.32, -8868.204, -8807.543, -8746.335, -8684.578000000001, -8622.271, -8559.411, -8495.999, -8432.030999999999, -8367.505, -8302.421, -8236.777, -8170.569, -8103.798000000001, -8036.460999999999, -7968.556, -7900.081, -7831.035, -7761.414000000001, -7691.218000000001, -7620.445, -7549.092, -7477.158, -7404.641, -7331.5380000000005, -7257.848000000001, -7183.568, -7108.696999999999, -7033.233, -6957.173000000001, -6880.515, -6803.257, -6725.398, -6646.935, -6567.866, -6488.188, -6407.901, -6327.001, -6245.488, -6163.358, -6080.61, -5997.24, -5913.249, -5828.633000000001, -5743.39, -5657.519, -5571.018, -5483.884, -5396.116999999999, -5307.714, -5218.673, -5128.9929999999995, -5038.6720000000005, -4947.709, -4856.102, -4763.85, -4670.952, -4577.407, -4483.213, -4388.369000000001, -4292.876, -4196.732, -4099.938, -4002.492, -3904.3959999999997, -3805.6490000000003, -3706.2509999999997, -3606.204, -3505.509, -3404.167, -3302.18, -3199.551, -3096.281, -2992.3740000000003, -2887.8340000000003, -2782.665, -2676.8720000000003, -2570.46, -2463.435, -2355.804, -2247.576, -2138.759, -2029.362, -1919.3970000000002, -1808.8770000000002, -1697.8129999999999, -1586.2220000000002, -1474.121, -1361.527, -1248.46, -1134.943, -1021.0010000000001, -906.66, -791.952, -676.908, -561.566, -445.965, -330.15, -214.168, -98.074, 18.073, 134.21, 250.264, 366.158, 481.805, 597.109, 711.9680000000001, 826.2639999999999, 939.873, 1052.655, 1164.4569999999999, 1275.11, 1384.43, 1492.214, 1598.241, 1702.267, 1804.026, 1903.231, 1999.566, 2092.689, 2182.234, 2267.805, 2348.98, 2425.311, 2496.327, 2561.538, 2620.435, 2672.508, 2717.241, 2754.133, 2782.703, 2802.509, 2813.158, 2814.32, 2805.748, 2787.2790000000005, 2758.849, 2720.5009999999997, 2672.3779999999997, 2614.723, 2547.875, 2472.25, 2388.337, 2296.67, 2197.826, 2092.3979999999997, 1980.987, 1864.19, 1742.5870000000002, 1616.737, 1487.1689999999999, 1354.379, 1218.828, 1080.941, 941.1089999999999, 799.687, 656.9939999999999, 513.321, 368.92800000000005, 224.049, 78.891, -66.361, -211.542, -356.505, -501.12300000000005, -645.281, -788.8789999999999, -931.83, -1074.056, -1215.489, -1355.76, -1495.751, -1634.484, -1772.233, -1908.964, -2044.651, -2179.269, -2312.8, -2445.225, -2576.534, -2706.7140000000004, -2835.757, -2963.659, -3090.413, -3216.0170000000003, -3340.4709999999995, -3463.7740000000003, -3585.928, -3706.935, -3826.797, -3945.52, -4063.1079999999997, -4179.565, -4294.897, -4409.111, -4522.214, -4634.212, -4745.112, -4854.920999999999, -4963.647, -5071.298, -5177.880999999999, -5283.406, -5387.879, -5491.309, -5593.705, -5695.073, -5795.424, -5894.763000000001, -5993.102, -6090.446, -6186.804, -6282.184, -6376.594, -6470.0419999999995, -6562.536999999999, -6654.085, -6744.694, -6834.3730000000005, -6923.129, -7010.968000000001, -7097.899, -7183.929, -7269.065, -7353.315, -7436.684, -7519.181, -7600.812, -7681.5830000000005, -7761.501, -7840.573, -7918.806, -7996.204000000001, -8072.776, -8148.526999999999, -8223.463, -8297.59, -8370.914, -8443.440999999999, -8515.176, -8586.125, -8656.294, -8725.688, -8794.312, -8862.171999999999, -8929.273000000001, -8995.62, -9061.216999999999, -9126.071, -9190.186, -9253.567, -9316.216999999999, -9378.143, -9439.349, -9499.838, -9559.616, -9618.687, -9677.055, -9734.725, -9791.7, -9847.985, -9903.583, -9958.5, -10012.738000000001, -10066.301, -10119.193000000001, -10171.418, -10222.979, -10273.881, -10324.126, -10373.718, -10422.661, -10470.958, -10518.612, -10565.627, -10612.005, -10657.75, -10702.865, -10747.354, -10791.218, -10834.462, -10877.088, -10919.098999999998, -10960.497, -11001.286, -11041.468, -11081.045, -11120.021999999999, -11158.399, -11196.181, -11233.368999999999, -11269.965, -11305.973, -11341.393999999998, -11376.232, -11410.487, -11444.163999999999, -11477.263, -11509.788, -11541.74, -11573.121000000001, -11603.935, -11634.181999999999, -11663.864, -11692.985, -11721.544, -11749.546, -11776.991000000002, -11803.882, -11830.22, -11856.007, -11881.245, -11905.936000000002, -11930.082, -11953.683, -11976.743, -11999.261, -12021.241000000002, -12042.684, -12063.591, -12083.964, -12103.803999999998, -12123.112, -12141.892, -12160.143, -12177.867, -12195.065, -12211.739, -12227.89, -12243.52, -12258.628999999999, -12273.219, -12287.291000000001, -12300.847, -12313.888, -12326.413999999999, -12338.427, -12349.928, -12360.918, -12371.398000000001, -12381.37, -12390.833999999999, -12399.791000000001, -12408.242, -12416.188999999998, -12423.631000000001, -12430.571000000002, -12437.008999999998, -12442.945, -12448.381000000001, -12453.318000000001, -12457.756000000001, -12461.696000000002, -12465.139, -12468.086000000001, -12470.537, -12472.493, -12473.955, -12474.923999999999, -12475.4, -12475.383, -12474.875, -12473.876, -12472.386999999999, -12470.408000000001, -12467.94, -12464.983, -12461.538, -12457.605, -12453.185, -12448.278, -12442.885, -12437.006000000001, -12430.642, -12423.793, -12416.458999999999, -12408.64, -12400.337, -12391.551000000001, -12382.281, -12372.528999999999, -12362.293, -12351.575, -12340.374, -12328.691, -12316.527, -12303.88, -12290.752, -12277.143, -12263.052, -12248.48, -12233.427, -12217.893999999998, -12201.878999999999, -12185.383, -12168.406, -12150.948999999999, -12133.011, -12114.593, -12095.693000000001, -12076.312, -12056.451000000001, -12036.108, -12015.284, -11993.979, -11972.192, -11949.923999999999, -11927.173999999999, -11903.942, -11880.228000000001, -11856.032, -11831.353000000001, -11806.192, -11780.546999999999, -11754.419, -11727.806999999999, -11700.712, -11673.132, -11645.068000000001, -11616.518, -11587.483, -11557.963, -11527.956, -11497.463, -11466.483, -11435.015, -11403.058, -11370.614, -11337.68, -11304.256000000001, -11270.343, -11235.938, -11201.043, -11165.655, -11129.775, -11093.402, -11056.534, -11019.171999999999, -10981.315, -10942.962, -10904.112, -10864.765, -10824.919, -10784.575, -10743.73, -10702.385, -10660.538, -10618.19, -10575.338, -10531.981000000002, -10488.118999999999, -10443.752, -10398.877, -10353.494, -10307.601999999999, -10261.2, -10214.287, -10166.862, -10118.924, -10070.471, -10021.503, -9972.018, -9922.016, -9871.494, -9820.453000000001, -9768.89, -9716.804, -9664.195, -9611.06, -9557.399, -9503.21, -9448.492, -9393.244, -9337.463, -9281.149, -9224.301, -9166.916, -9108.993, -9050.530999999999, -8991.528, -8931.983, -8871.894, -8811.26, -8750.079, -8688.349, -8626.068000000001, -8563.235999999999, -8499.85, -8435.909, -8371.41, -8306.353000000001, -8240.735, -8174.554, -8107.81, -8040.499, -7972.621, -7904.172, -7835.151999999999, -7765.558000000001, -7695.389, -7624.642, -7553.316, -7481.408, -7408.9169999999995, -7335.84, -7262.1759999999995, -7187.923000000001, -7113.078, -7037.639, -6961.605, -6884.973000000001, -6807.741999999999, -6729.908, -6651.471, -6572.428000000001, -6492.776999999999, -6412.516, -6331.642, -6250.153, -6168.049, -6085.325, -6001.982, -5918.016, -5833.425, -5748.206999999999, -5662.361999999999, -5575.885, -5488.776999999999, -5401.035, -5312.656, -5223.64, -5133.985, -5043.689, -4952.75, -4861.168, -4768.941, -4676.067, -4582.545999999999, -4488.376, -4393.556, -4298.087, -4201.965999999999, -4105.195, -4007.772, -3909.698, -3810.974, -3711.599, -3611.574, -3510.901, -3409.58, -3307.615, -3205.006, -3101.758, -2997.8720000000003, -2893.3520000000003, -2788.203, -2682.428, -2576.035, -2469.028, -2361.415, -2253.2039999999997, -2144.403, -2035.0220000000002, -1925.0720000000001, -1814.566, -1703.516, -1591.9370000000001, -1479.846, -1367.2620000000002, -1254.204, -1140.695, -1026.759, -912.423, -797.7180000000001, -682.675, -567.332, -451.72900000000004, -335.908, -219.919, -103.815, 12.345999999999998, 128.5, 244.575, 360.494, 476.16900000000004, 591.508, 706.4060000000001, 820.747, 934.4069999999999, 1047.247, 1159.114, 1269.8410000000001, 1379.244, 1487.121, 1593.251, 1697.394, 1799.283, 1898.631, 1995.124, 2088.423, 2178.1620000000003, 2263.945, 2345.355, 2421.9410000000003, 2493.236, 2558.749, 2617.975, 2670.401, 2715.512, 2752.8059999999996, 2781.803, 2802.0559999999996, 2813.171, 2814.816, 2806.738, 2788.7709999999997, 2760.848, 2723.0029999999997, 2675.3759999999997, 2618.206, 2551.827, 2476.652, 2393.1639999999998, 2301.899, 2203.427, 2098.344, 1987.2479999999998, 1870.74, 1749.3970000000002, 1623.78, 1494.42, 1361.8139999999999, 1226.424, 1088.678, 948.967, 807.648, 665.0419999999999, 521.442, 377.108, 232.275, 87.15299999999999, -58.073, -203.236, -348.191, -492.806, -636.969, -780.578, -923.543, -1065.789, -1207.247, -1347.8570000000002, -1487.568, -1626.336, -1764.122, -1900.8929999999998, -2036.622, -2171.283, -2304.859, -2437.3320000000003, -2568.688, -2698.917, -2828.012, -2955.9640000000004, -3082.77, -3208.427, -3332.934, -3456.2909999999997, -3578.4990000000003, -3699.56, -3819.478, -3938.256, -4055.8979999999997, -4172.411, -4287.8, -4402.07, -4515.228, -4627.282, -4738.237, -4848.102, -4956.884, -5064.59, -5171.23, -5276.81, -5381.339, -5484.825, -5587.276, -5688.6990000000005, -5789.104, -5888.499, -5986.891, -6084.289000000001, -6180.701, -6276.135, -6370.599, -6464.101, -6556.649, -6648.251, -6738.9130000000005, -6828.645, -6917.453, -7005.345, -7092.328, -7178.41, -7263.598000000001, -7347.898, -7431.319, -7513.866, -7595.548000000001, -7676.369000000001, -7756.338000000001, -7835.460999999999, -7913.743, -7991.191999999999, -8067.813, -8143.613, -8218.598, -8292.774, -8366.146999999999, -8438.722, -8510.505, -8581.502, -8651.719000000001, -8721.161, -8789.833, -8857.74, -8924.889000000001, -8991.282, -9056.927, -9121.827, -9185.988000000001, -9249.415, -9312.112, -9374.083, -9435.334, -9495.869, -9555.692, -9614.808, -9673.221, -9730.936, -9787.955, -9844.284, -9899.927, -9954.886999999999, -10009.169, -10062.776, -10115.711, -10167.98, -10219.584, -10270.529, -10320.817, -10370.452, -10419.437, -10467.777, -10515.473, -10562.53, -10608.95, -10654.737, -10699.893999999998, -10744.423999999999, -10788.33, -10831.615, -10874.282, -10916.333999999999, -10957.773000000001, -10998.601999999999, -11038.823999999999, -11078.443000000001, -11117.458999999999, -11155.877, -11193.698999999999, -11230.926000000001, -11267.562, -11303.61, -11339.071000000002, -11373.948, -11408.243, -11441.958, -11475.097, -11507.66, -11539.651000000002, -11571.071000000002, -11601.923, -11632.208999999999, -11661.928999999998, -11691.088, -11719.686000000002, -11747.725, -11775.208, -11802.136999999999, -11828.511999999999, -11854.337, -11879.613000000001, -11904.341, -11928.524, -11952.162, -11975.258, -11997.813999999998, -12019.831, -12041.31, -12062.253999999999, -12082.663, -12102.538999999999, -12121.883999999998, -12140.7, -12158.987, -12176.747, -12193.981000000002, -12210.691, -12226.878, -12242.543, -12257.688, -12272.313, -12286.421, -12300.011999999999, -12313.088, -12325.649, -12337.697, -12349.233, -12360.258, -12370.773000000001, -12380.778999999999, -12390.277, -12399.268999999998, -12407.753999999999, -12415.735, -12423.212, -12430.186000000002, -12436.658000000001, -12442.628999999999, -12448.098, -12453.069, -12457.541000000001, -12461.514, -12464.991000000002, -12467.971000000001, -12470.456, -12472.445, -12473.94, -12474.942, -12475.451000000001, -12475.468, -12474.993, -12474.027, -12472.57, -12470.624, -12468.188, -12465.264, -12461.851, -12457.951000000001, -12453.563, -12448.688999999998, -12443.328000000001, -12437.481000000002, -12431.149, -12424.332, -12417.03, -12409.243, -12400.973, -12392.218, -12382.98, -12373.258999999998, -12363.055, -12352.368, -12341.198999999999, -12329.546999999999, -12317.413999999999, -12304.798999999999, -12291.702, -12278.124, -12264.063999999998, -12249.523000000001, -12234.501, -12218.998, -12203.014, -12186.548999999999, -12169.604, -12152.177, -12134.268999999998, -12115.881000000001, -12097.011999999999, -12077.662, -12057.831, -12037.518, -12016.723999999998, -11995.448999999999, -11973.693000000001, -11951.455, -11928.735, -11905.533000000001, -11881.848999999998, -11857.683, -11833.034, -11807.902, -11782.287, -11756.188999999998, -11729.607, -11702.541000000001, -11674.99, -11646.955, -11618.435, -11589.43, -11559.938, -11529.961000000001, -11499.497, -11468.546, -11437.107, -11405.18, -11372.764, -11339.858999999999, -11306.465, -11272.58, -11238.205, -11203.338, -11167.979, -11132.127, -11095.782, -11058.944, -11021.61, -10983.782, -10945.457, -10906.636, -10867.317, -10827.499, -10787.183, -10746.367, -10705.05, -10663.231000000002, -10620.911, -10578.087, -10534.758999999998, -10490.925, -10446.585, -10401.738000000001, -10356.383, -10310.519, -10264.145, -10217.26, -10169.862, -10121.952, -10073.527, -10024.586, -9975.129, -9925.154, -9874.66, -9823.646, -9772.110999999999, -9720.052, -9667.47, -9614.363000000001, -9560.729, -9506.568000000001, -9451.877, -9396.655999999999, -9340.903, -9284.616, -9227.794, -9170.436, -9112.54, -9054.105, -8995.13, -8935.612, -8875.55, -8814.942, -8753.788, -8692.085, -8629.831, -8567.026, -8503.667, -8439.752, -8375.28, -8310.249, -8244.658000000001, -8178.504, -8111.786, -8044.5019999999995, -7976.65, -7908.228, -7839.234, -7769.6669999999995, -7699.524, -7628.803000000001, -7557.503000000001, -7485.621, -7413.156, -7340.106, -7266.468000000001, -7192.241, -7117.422, -7042.01, -6966.0019999999995, -6889.396, -6812.19, -6734.383000000001, -6655.971, -6576.954000000001, -6497.329000000001, -6417.093000000001, -6336.245, -6254.781999999999, -6172.703, -6090.005, -6006.687, -5922.746, -5838.181, -5752.9890000000005, -5667.169, -5580.718000000001, -5493.634, -5405.9169999999995, -5317.563, -5228.572, -5138.942, -5048.67, -4957.755999999999, -4866.1990000000005, -4773.996, -4681.147, -4587.649, -4493.503, -4398.708, -4303.262, -4207.165, -4110.417, -4013.018, -3914.967, -3816.265, -3716.913, -3616.91, -3516.259, -3414.961, -3313.0170000000003, -3210.43, -3107.202, -3003.337, -2898.8379999999997, -2793.708, -2687.953, -2581.5789999999997, -2474.591, -2366.996, -2258.802, -2150.0170000000003, -2040.6529999999998, -1930.7179999999998, -1820.226, -1709.1889999999999, -1597.624, -1485.545, -1372.971, -1259.922, -1146.421, -1032.492, -918.1610000000001, -803.46, -688.419, -573.076, -457.47, -341.645, -225.649, -109.53399999999999, 6.64, 122.81, 238.905, 354.847, 470.551, 585.923, 700.8589999999999, 815.2439999999999, 928.954, 1041.851, 1153.782, 1264.5819999999999, 1374.067, 1482.037, 1588.27, 1692.5279999999998, 1794.545, 1894.0339999999999, 1990.685, 2084.158, 2174.089, 2260.085, 2341.726, 2418.567, 2490.139, 2555.955, 2615.507, 2668.284, 2713.7729999999997, 2751.468, 2780.89, 2801.591, 2813.172, 2815.3, 2807.717, 2790.2529999999997, 2762.836, 2725.4959999999996, 2678.367, 2621.685, 2555.776, 2481.052, 2397.992, 2307.129, 2209.033, 2104.297, 1993.52, 1877.3010000000002, 1756.22, 1630.839, 1501.6889999999999, 1369.267, 1234.04, 1096.4360000000001, 956.847, 815.633, 673.115, 529.5880000000001, 385.314, 240.528, 95.44200000000001, -49.757, -194.903, -339.848, -484.462, -628.629, -772.248, -915.2289999999999, -1057.495, -1198.9769999999999, -1339.616, -1479.359, -1618.161, -1755.984, -1892.795, -2028.566, -2163.271, -2296.8920000000003, -2429.4120000000003, -2560.817, -2691.095, -2820.241, -2948.244, -3075.1020000000003, -3200.813, -3325.373, -3448.784, -3571.047, -3692.163, -3812.136, -3930.969, -4048.6679999999997, -4165.237, -4280.682, -4395.008, -4508.222, -4620.331, -4731.343, -4841.264, -4950.102, -5057.865, -5164.56, -5270.196, -5374.781, -5478.321999999999, -5580.828, -5682.307, -5782.767, -5882.217, -5980.664000000001, -6078.116999999999, -6174.5830000000005, -6270.071, -6364.589, -6458.145, -6550.746, -6642.401999999999, -6733.116999999999, -6822.901999999999, -6911.763000000001, -6999.706999999999, -7086.743, -7172.876, -7258.116, -7342.468000000001, -7425.94, -7508.539000000001, -7590.271, -7671.143, -7751.1630000000005, -7830.335999999999, -7908.668000000001, -7986.1669999999995, -8062.838000000001, -8138.687, -8213.722, -8287.946, -8361.368, -8433.992, -8505.823, -8576.869, -8647.133, -8716.623, -8785.341999999999, -8853.296999999999, -8920.493, -8986.933, -9052.625, -9117.572, -9181.779, -9245.252, -9307.995, -9370.011999999999, -9431.309000000001, -9491.889000000001, -9551.758, -9610.919, -9669.377, -9727.136, -9784.2, -9840.573, -9896.26, -9951.265, -10005.59, -10059.241, -10112.22, -10164.532, -10216.179, -10267.167, -10317.498, -10367.176, -10416.204, -10464.586, -10512.323999999999, -10559.423, -10605.885, -10651.714, -10696.913, -10741.483999999999, -10785.431, -10828.758, -10871.466, -10913.559, -10955.038, -10995.908000000001, -11036.171, -11075.83, -11114.886999999999, -11153.345, -11191.206, -11228.473999999998, -11265.15, -11301.237, -11336.737, -11371.653999999999, -11405.988000000001, -11439.743, -11472.92, -11505.521999999999, -11537.552, -11569.011, -11599.901000000002, -11630.225, -11659.983999999999, -11689.181, -11717.817, -11745.893999999998, -11773.415, -11800.381000000001, -11826.794, -11852.657, -11877.97, -11902.735, -11926.955, -11950.631000000001, -11973.764, -11996.356000000002, -12018.41, -12039.926000000001, -12060.906, -12081.351999999999, -12101.264, -12120.646, -12139.497, -12157.821000000002, -12175.616000000002, -12192.886, -12209.632, -12225.854, -12241.555, -12256.735, -12271.396, -12285.538999999999, -12299.165, -12312.276000000002, -12324.872, -12336.955, -12348.526000000002, -12359.586000000001, -12370.135, -12380.176000000001, -12389.708999999999, -12398.735, -12407.255, -12415.268999999998, -12422.78, -12429.788, -12436.294, -12442.298999999999, -12447.803, -12452.806999999999, -12457.312, -12461.319, -12464.829, -12467.843, -12470.361, -12472.383, -12473.912, -12474.947, -12475.489, -12475.538, -12475.096000000001, -12474.163, -12472.739, -12470.825, -12468.421999999999, -12465.53, -12462.15, -12458.282, -12453.927, -12449.083999999999, -12443.756000000001, -12437.941, -12431.641000000001, -12424.856000000002, -12417.585, -12409.831, -12401.591, -12392.868, -12383.662, -12373.972, -12363.8, -12353.143999999998, -12342.007, -12330.386, -12318.284, -12305.7, -12292.635, -12279.087, -12265.059, -12250.548999999999, -12235.556999999999, -12220.085, -12204.132, -12187.697, -12170.782, -12153.386, -12135.508999999998, -12117.151000000002, -12098.313, -12078.993, -12059.191, -12038.909, -12018.146, -11996.901000000002, -11975.173999999999, -11952.966, -11930.276000000002, -11907.104, -11883.45, -11859.313, -11834.694, -11809.591999999999, -11784.006000000001, -11757.937, -11731.385, -11704.348, -11676.827, -11648.822, -11620.331, -11591.355, -11561.892, -11531.944, -11501.508999999998, -11470.587, -11439.177, -11407.278999999999, -11374.892, -11342.016000000001, -11308.65, -11274.794, -11240.448, -11205.608999999999, -11170.278999999999, -11134.456, -11098.14, -11061.329, -11024.025, -10986.223999999998, -10947.928, -10909.135, -10869.844, -10830.055, -10789.767, -10748.979, -10707.69, -10665.899, -10623.607, -10580.811000000002, -10537.511, -10493.705, -10449.393, -10404.574, -10359.246, -10313.41, -10267.064, -10220.206, -10172.837, -10124.953000000001, -10076.556, -10027.643, -9978.213, -9928.266, -9877.799, -9826.813, -9775.304, -9723.274, -9670.719000000001, -9617.639000000001, -9564.032, -9509.898000000001, -9455.235, -9400.04, -9344.314, -9288.054, -9231.26, -9173.929, -9116.06, -9057.652, -8998.703000000001, -8939.212, -8879.177, -8818.596, -8757.469000000001, -8695.792, -8633.565, -8570.787, -8507.454, -8443.565999999999, -8379.121, -8314.117, -8248.552, -8182.424, -8115.733, -8048.475, -7980.65, -7912.254, -7843.286999999999, -7773.746, -7703.629, -7632.935, -7561.661, -7489.806, -7417.366999999999, -7344.343000000001, -7270.731, -7196.53, -7121.736999999999, -7046.351, -6970.369000000001, -6893.789000000001, -6816.609, -6738.826999999999, -6660.441999999999, -6581.45, -6501.851, -6421.641, -6340.819, -6259.382, -6177.328, -6094.656, -6011.3640000000005, -5927.448, -5842.908, -5757.741999999999, -5671.946, -5585.523, -5498.465, -5410.772, -5322.444, -5233.478, -5143.872, -5053.626, -4962.736, -4871.2029999999995, -4779.024, -4686.1990000000005, -4592.726, -4498.604, -4403.833, -4308.412, -4212.339, -4115.615, -4018.239, -3920.211, -3821.532, -3722.203, -3622.223, -3521.595, -3420.3179999999998, -3318.3959999999997, -3215.8309999999997, -3112.6240000000003, -3008.7790000000005, -2904.301, -2799.192, -2693.4570000000003, -2587.1020000000003, -2480.132, -2372.556, -2264.379, -2155.612, -2046.264, -1936.345, -1825.868, -1714.845, -1603.293, -1491.226, -1378.6629999999998, -1265.625, -1152.132, -1038.21, -923.8860000000001, -809.188, -694.15, -578.808, -463.2, -347.371, -231.368, -115.244, 0.9420000000000001, 117.12799999999999, 233.24200000000002, 349.207, 464.939, 580.342, 695.316, 809.745, 923.5039999999999, 1036.4569999999999, 1148.453, 1259.3239999999998, 1368.891, 1476.951, 1583.287, 1687.658, 1789.8020000000001, 1889.432, 1986.24, 2079.887, 2170.009, 2256.216, 2338.0879999999997, 2415.183, 2487.032, 2553.1479999999997, 2613.026, 2666.156, 2712.0209999999997, 2750.119, 2779.966, 2801.114, 2813.163, 2815.775, 2808.688, 2791.7290000000003, 2764.821, 2727.989, 2681.361, 2625.1679999999997, 2559.734, 2485.465, 2402.837, 2312.379, 2214.6620000000003, 2110.277, 1999.8210000000001, 1883.896, 1763.08, 1637.9370000000001, 1508.997, 1376.764, 1241.702, 1104.241, 964.7760000000001, 823.666, 681.238, 537.785, 393.57199999999995, 248.835, 103.786, -41.386, -186.515, -331.45, -476.06199999999995, -620.234, -763.863, -906.86, -1049.146, -1190.653, -1331.7579999999998, -1471.094, -1609.932, -1747.793, -1884.644, -2020.4560000000001, -2155.2070000000003, -2288.874, -2421.4410000000003, -2552.895, -2683.223, -2812.4190000000003, -2940.474, -3067.385, -3193.1490000000003, -3317.764, -3441.23, -3563.547, -3684.719, -3804.748, -3923.637, -4041.3920000000003, -4158.017, -4273.518, -4387.901, -4501.1720000000005, -4613.338, -4724.406, -4834.384, -4943.278, -5051.097, -5157.849, -5263.5419999999995, -5368.183000000001, -5471.78, -5574.342, -5675.876, -5776.392, -5875.897, -5974.399, -6071.906999999999, -6168.428000000001, -6263.972, -6358.544, -6452.154, -6544.809, -6636.517, -6727.286999999999, -6817.124, -6906.0380000000005, -6994.035, -7081.124, -7167.31, -7252.602, -7337.007, -7420.531, -7503.181, -7584.964, -7665.888000000001, -7745.9580000000005, -7825.181, -7903.563, -7981.111999999999, -8057.8330000000005, -8133.732, -8208.817, -8283.091, -8356.562, -8429.234, -8501.115, -8572.208, -8642.521, -8712.059000000001, -8780.826, -8848.828000000001, -8916.07, -8982.558, -9048.296999999999, -9113.291, -9177.546, -9241.065, -9303.854, -9365.917, -9427.26, -9487.886, -9547.8, -9607.006, -9665.509, -9723.313, -9780.421999999999, -9836.84, -9892.571, -9947.62, -10001.99, -10055.684000000001, -10108.707, -10161.062, -10212.753, -10263.784, -10314.158000000001, -10363.879, -10412.95, -10461.374, -10509.155, -10556.296, -10602.8, -10648.671, -10693.912, -10738.526000000002, -10782.515, -10825.882, -10868.631000000001, -10910.764, -10952.285, -10993.196000000002, -11033.5, -11073.198999999999, -11112.296, -11150.794, -11188.696000000002, -11226.003, -11262.719, -11298.846000000001, -11334.386, -11369.343, -11403.716, -11437.51, -11470.726999999999, -11503.368, -11535.436000000002, -11566.933, -11597.862, -11628.223999999998, -11658.021, -11687.256000000001, -11715.93, -11744.046, -11771.605, -11798.608999999999, -11825.059, -11850.958999999999, -11876.31, -11901.113000000001, -11925.37, -11949.083, -11972.253, -11994.883, -12016.973, -12038.526000000002, -12059.542, -12080.024, -12099.973, -12119.391000000001, -12138.278, -12156.636999999999, -12174.469, -12191.775, -12208.556, -12224.813999999998, -12240.551000000001, -12255.767, -12270.463, -12284.642, -12298.303, -12311.448999999999, -12324.08, -12336.198, -12347.803999999998, -12358.898000000001, -12369.482, -12379.558, -12389.125, -12398.185, -12406.739, -12414.788, -12422.333, -12429.375, -12435.915, -12441.953000000001, -12447.491000000002, -12452.528999999999, -12457.068000000001, -12461.108999999999, -12464.653, -12467.7, -12470.251, -12472.306999999999, -12473.868, -12474.936000000002, -12475.511, -12475.594, -12475.184, -12474.284, -12472.893, -12471.011999999999, -12468.641000000001, -12465.782, -12462.434, -12458.598999999998, -12454.275, -12449.466, -12444.169, -12438.386999999999, -12432.118999999999, -12425.365, -12418.126, -12410.403, -12402.196000000002, -12393.505, -12384.33, -12374.671999999999, -12364.531, -12353.907, -12342.8, -12331.211000000001, -12319.14, -12306.587, -12293.553, -12280.037, -12266.038999999999, -12251.56, -12236.6, -12221.159, -12205.236, -12188.833, -12171.948, -12154.582, -12136.736, -12118.408000000001, -12099.598999999998, -12080.309, -12060.538999999999, -12040.286, -12019.553, -11998.338, -11976.642, -11954.463, -11931.803, -11908.661, -11885.037, -11860.93, -11836.341, -11811.268999999998, -11785.713, -11759.673999999999, -11733.151000000002, -11706.143999999998, -11678.652, -11650.676000000001, -11622.214, -11593.267, -11563.833999999999, -11533.915, -11503.508999999998, -11472.615, -11441.233999999999, -11409.365, -11377.007, -11344.16, -11310.823, -11276.996000000001, -11242.678, -11207.868, -11172.567, -11136.773000000001, -11100.485, -11063.704, -11026.427, -10988.655, -10950.386999999999, -10911.622, -10872.36, -10832.598999999998, -10792.339, -10751.579, -10710.319, -10668.556, -10626.291000000001, -10583.523000000001, -10540.25, -10496.473, -10452.189, -10407.398000000001, -10362.099, -10316.29, -10269.972, -10223.142, -10175.8, -10127.945, -10079.575, -10030.689, -9981.287, -9931.367, -9880.928, -9829.969000000001, -9778.488000000001, -9726.485, -9673.957, -9620.904, -9567.325, -9513.218, -9458.582, -9403.415, -9347.716, -9291.483, -9234.716, -9177.412, -9119.57, -9061.189, -9002.268, -8942.803, -8882.795, -8822.242, -8761.141, -8699.491, -8637.291, -8574.539, -8511.233, -8447.372, -8382.954, -8317.976999999999, -8252.439, -8186.338000000001, -8119.673000000001, -8052.441999999999, -7984.643, -7916.274, -7847.3330000000005, -7777.818, -7707.728, -7637.06, -7565.813, -7493.984, -7421.571, -7348.5740000000005, -7274.988, -7200.813, -7126.047, -7050.688, -6974.732, -6898.178000000001, -6821.025, -6743.269, -6664.91, -6585.944, -6506.37, -6426.186, -6345.389, -6263.978, -6181.951, -6099.305, -6016.0380000000005, -5932.148, -5847.635, -5762.494000000001, -5676.724, -5590.3240000000005, -5503.291, -5415.624, -5327.321, -5238.380999999999, -5148.8, -5058.579000000001, -4967.714, -4876.206, -4784.052, -4691.252, -4597.803, -4503.706, -4408.959, -4313.562, -4217.514, -4120.813, -4023.461, -3925.4570000000003, -3826.802, -3727.4959999999996, -3627.539, -3526.933, -3425.679, -3323.78, -3221.236, -3118.051, -3014.228, -2909.77, -2804.6820000000002, -2698.967, -2592.632, -2485.6820000000002, -2378.124, -2269.966, -2161.216, -2051.885, -1941.9820000000002, -1831.52, -1720.5120000000002, -1608.973, -1496.9189999999999, -1384.368, -1271.34, -1157.857, -1043.943, -929.625, -814.932, -699.8969999999999, -584.556, -468.94699999999995, -353.11400000000003, -237.105, -120.973, -4.775, 111.426, 227.558, 343.546, 459.30400000000003, 574.739, 689.7489999999999, 804.221, 918.029, 1031.038, 1143.096, 1254.04, 1363.6860000000001, 1471.8370000000002, 1578.274, 1682.759, 1785.029, 1884.8010000000002, 1981.765, 2075.585, 2165.8979999999997, 2252.315, 2334.419, 2411.768, 2483.895, 2550.313, 2610.518, 2663.9990000000003, 2710.243, 2748.744, 2779.018, 2800.616, 2813.135, 2816.2340000000004, 2809.647, 2793.196, 2766.801, 2730.48, 2684.357, 2628.659, 2563.703, 2489.893, 2407.701, 2317.653, 2220.32, 2116.288, 2006.158, 1890.529, 1769.981, 1645.079, 1516.354, 1384.31, 1249.415, 1112.099, 972.7589999999999, 831.757, 689.419, 546.04, 401.88800000000003, 257.2, 112.189, -32.955999999999996, -178.06599999999997, -322.993, -467.602, -611.779, -755.418, -898.431, -1040.738, -1182.27, -1322.9660000000001, -1462.773, -1601.645, -1739.5439999999999, -1876.4360000000001, -2012.2920000000001, -2147.087, -2280.801, -2413.416, -2544.919, -2675.298, -2804.545, -2932.653, -3059.617, -3185.435, -3310.105, -3433.6259999999997, -3555.9990000000003, -3677.2270000000003, -3797.312, -3916.258, -4034.0690000000004, -4150.751, -4266.309, -4380.75, -4494.0779999999995, -4606.3009999999995, -4717.4259999999995, -4827.460999999999, -4936.413, -5044.289000000001, -5151.098, -5256.847, -5361.545, -5465.198, -5567.816999999999, -5669.408, -5769.979, -5869.54, -5968.098000000001, -6065.661, -6162.236999999999, -6257.835999999999, -6352.463000000001, -6446.128000000001, -6538.8369999999995, -6630.6, -6721.423000000001, -6811.314, -6900.281999999999, -6988.331999999999, -7075.473000000001, -7161.7119999999995, -7247.057, -7331.514, -7415.09, -7497.7919999999995, -7579.6269999999995, -7660.602, -7740.723000000001, -7819.996999999999, -7898.43, -7976.03, -8052.8009999999995, -8128.75, -8203.884, -8278.208, -8351.728000000001, -8424.45, -8496.379, -8567.521999999999, -8637.883, -8707.469000000001, -8776.284, -8844.334, -8911.624, -8978.159, -9043.945, -9108.987, -9173.288, -9236.853000000001, -9299.689, -9361.799, -9423.187, -9483.859, -9543.819, -9603.07, -9661.619, -9719.468, -9776.622, -9833.084, -9888.86, -9943.953000000001, -9998.367, -10052.106, -10105.171999999999, -10157.571, -10209.306, -10260.38, -10310.798, -10360.561, -10409.675, -10458.142, -10505.965, -10553.149, -10599.696000000002, -10645.608, -10690.891000000001, -10735.546999999999, -10779.577, -10822.986, -10865.776000000002, -10907.951000000001, -10949.513, -10990.464, -11030.809, -11070.548, -11109.686000000002, -11148.225, -11186.166000000001, -11223.514, -11260.27, -11296.436000000002, -11332.016000000001, -11367.011999999999, -11401.425, -11435.258, -11468.514, -11501.194, -11533.301000000001, -11564.837, -11595.805, -11626.205, -11656.041000000001, -11685.313999999998, -11714.026000000002, -11742.18, -11769.776000000002, -11796.818000000001, -11823.306999999999, -11849.243999999999, -11874.632, -11899.472, -11923.767, -11947.517, -11970.723999999998, -11993.391000000001, -12015.518, -12037.107, -12058.16, -12078.678999999998, -12098.663999999999, -12118.118, -12137.041000000001, -12155.436000000002, -12173.303999999998, -12190.646, -12207.463, -12223.756000000001, -12239.528, -12254.78, -12269.511999999999, -12283.726, -12297.421999999999, -12310.603000000001, -12323.268999999998, -12335.421999999999, -12347.062, -12358.192, -12368.81, -12378.92, -12388.521999999999, -12397.617, -12406.205, -12414.288, -12421.867, -12428.943000000001, -12435.517, -12441.589, -12447.16, -12452.232, -12456.805, -12460.878999999999, -12464.456, -12467.536, -12470.121000000001, -12472.21, -12473.805, -12474.906, -12475.514, -12475.628999999999, -12475.252, -12474.385, -12473.026000000002, -12471.178, -12468.84, -12466.013, -12462.697, -12458.893999999998, -12454.603000000001, -12449.825, -12444.561000000002, -12438.811000000002, -12432.573999999999, -12425.851999999999, -12418.646, -12410.954, -12402.778, -12394.118999999999, -12384.975, -12375.348999999998, -12365.239, -12354.646, -12343.571000000002, -12332.013, -12319.973, -12307.451000000001, -12294.448, -12280.962, -12266.996000000001, -12252.546999999999, -12237.618, -12222.208, -12206.316, -12189.943000000001, -12173.088, -12155.753, -12137.937, -12119.639, -12100.861, -12081.601, -12061.861, -12041.639, -12020.935, -11999.75, -11978.083999999999, -11955.935, -11933.305, -11910.192, -11886.598, -11862.521, -11837.961000000001, -11812.918, -11787.392, -11761.382, -11734.889, -11707.911, -11680.448, -11652.501, -11624.069, -11595.151000000002, -11565.747, -11535.857, -11505.48, -11474.615, -11443.263, -11411.423, -11379.093, -11346.275, -11312.966999999999, -11279.168, -11244.878999999999, -11210.098, -11174.825, -11139.06, -11102.8, -11066.046999999999, -11028.798999999999, -10991.055, -10952.815, -10914.079, -10874.845, -10835.112, -10794.88, -10754.148000000001, -10712.916000000001, -10671.181, -10628.944, -10586.204, -10542.958999999999, -10499.208999999999, -10454.953000000001, -10410.19, -10364.918, -10319.138, -10272.847, -10226.044, -10178.73, -10130.902, -10082.56, -10033.702, -9984.327, -9934.434000000001, -9884.023000000001, -9833.091, -9781.636999999999, -9729.661, -9677.161, -9624.135, -9570.583, -9516.503, -9461.894, -9406.755, -9351.082, -9294.877, -9238.136, -9180.859, -9123.045, -9064.690999999999, -9005.796, -8946.358, -8886.377, -8825.85, -8764.776, -8703.153, -8640.98, -8578.255, -8514.976, -8451.141, -8386.749, -8321.799, -8256.288, -8190.214, -8123.575, -8056.371, -7988.598000000001, -7920.255, -7851.340999999999, -7781.852, -7711.7880000000005, -7641.147, -7569.9259999999995, -7498.1230000000005, -7425.736999999999, -7352.766, -7279.206999999999, -7205.058000000001, -7130.318, -7054.985, -6979.055, -6902.526999999999, -6825.4, -6747.670999999999, -6669.3369999999995, -6590.398, -6510.85, -6430.691, -6349.920999999999, -6268.536, -6186.534000000001, -6103.9130000000005, -6020.672, -5936.808000000001, -5852.32, -5767.205, -5681.460999999999, -5595.0869999999995, -5508.079000000001, -5420.438, -5332.16, -5243.244000000001, -5153.689, -5063.4929999999995, -4972.654, -4881.17, -4789.041, -4696.266, -4602.842000000001, -4508.769, -4414.0470000000005, -4318.674, -4222.649, -4125.973, -4028.645, -3930.665, -3832.033, -3732.75, -3632.816, -3532.2329999999997, -3431.002, -3329.125, -3226.6040000000003, -3123.441, -3019.639, -2915.202, -2810.135, -2704.44, -2598.125, -2491.194, -2383.655, -2275.516, -2166.784, -2057.47, -1947.5829999999999, -1837.1370000000002, -1726.144, -1614.619, -1502.578, -1390.039, -1277.022, -1163.548, -1049.642, -935.331, -820.6439999999999, -705.612, -590.2719999999999, -474.662, -358.827, -242.813, -126.67200000000001, -10.463, 105.75200000000001, 221.90200000000002, 337.912, 453.69599999999997, 569.1619999999999, 684.2080000000001, 798.721, 912.577, 1025.641, 1137.761, 1248.775, 1358.501, 1466.7420000000002, 1573.279, 1677.876, 1780.271, 1880.182, 1977.3010000000002, 2071.292, 2161.795, 2248.4210000000003, 2330.755, 2408.356, 2480.758, 2547.476, 2608.005, 2661.837, 2708.4570000000003, 2747.36, 2778.06, 2800.1059999999998, 2813.093, 2816.677, 2810.5890000000004, 2794.6459999999997, 2768.763, 2732.953, 2687.336, 2632.132, 2567.656, 2494.305, 2412.55, 2322.915, 2225.965, 2122.29, 2012.487, 1897.155, 1776.8770000000002, 1652.217, 1523.7079999999999, 1391.855, 1257.128, 1119.958, 980.745, 839.85, 697.6030000000001, 554.3, 410.21, 265.57099999999997, 120.598, -24.52, -169.612, -314.528, -459.135, -603.316, -746.966, -889.995, -1032.322, -1173.879, -1314.6029999999998, -1454.443, -1593.351, -1731.2879999999998, -1868.22, -2004.119, -2138.959, -2272.719, -2405.382, -2536.935, -2667.365, -2796.663, -2924.824, -3051.842, -3177.7140000000004, -3302.438, -3426.015, -3548.4429999999998, -3669.7270000000003, -3789.869, -3908.8720000000003, -4026.74, -4143.479, -4259.094, -4373.592000000001, -4486.977, -4599.258, -4710.44, -4820.532, -4929.541, -5037.475, -5144.34, -5250.146, -5354.901, -5458.611, -5561.286, -5662.933000000001, -5763.561, -5863.178000000001, -5961.791, -6059.41, -6156.0419999999995, -6251.695, -6346.378000000001, -6440.097, -6532.861, -6624.677, -6715.555, -6805.5, -6894.521, -6982.624, -7069.819, -7156.111, -7241.508000000001, -7326.017, -7409.645, -7492.399, -7574.286, -7655.312, -7735.484, -7814.809, -7893.294, -7970.943, -8047.765, -8123.764, -8198.948, -8273.322, -8346.891, -8419.662, -8491.64, -8562.831, -8633.241, -8702.875, -8771.738000000001, -8839.836, -8907.174, -8973.757, -9039.59, -9104.678, -9169.026, -9232.639000000001, -9295.52, -9357.676, -9419.110999999999, -9479.829, -9539.834, -9599.131, -9657.725, -9715.619, -9772.818000000001, -9829.325, -9885.145, -9940.283000000001, -9994.741, -10048.524, -10101.634, -10154.077, -10205.855, -10256.972, -10307.433, -10357.239, -10406.396, -10454.905999999999, -10502.771999999999, -10549.997, -10596.586000000001, -10642.541000000001, -10687.866000000002, -10732.563, -10776.635, -10820.085, -10862.917, -10905.133, -10946.735, -10987.726999999999, -11028.112, -11067.892, -11107.071000000002, -11145.65, -11183.632, -11221.018999999998, -11257.815, -11294.021, -11329.64, -11364.675, -11399.127, -11433.0, -11466.294, -11499.014, -11531.159, -11562.733999999999, -11593.74, -11624.18, -11654.053, -11683.365, -11712.115, -11740.306999999999, -11767.941, -11795.021, -11821.546999999999, -11847.521999999999, -11872.947, -11897.823999999999, -11922.156, -11945.942, -11969.187, -11991.89, -12014.053999999998, -12035.68, -12056.77, -12077.325, -12097.347, -12116.837, -12135.796, -12154.226999999999, -12172.131000000001, -12189.508, -12206.361, -12222.69, -12238.497, -12253.784, -12268.551000000001, -12282.8, -12296.531, -12309.747, -12322.448999999999, -12334.636999999999, -12346.312, -12357.475, -12368.128999999999, -12378.273000000001, -12387.909, -12397.038, -12405.66, -12413.778, -12421.391000000001, -12428.501, -12435.108, -12441.213, -12446.818000000001, -12451.923, -12456.53, -12460.638, -12464.248, -12467.362, -12469.979, -12472.101999999999, -12473.729, -12474.863000000001, -12475.503999999999, -12475.652, -12475.308, -12474.473, -12473.146999999999, -12471.331, -12469.026000000002, -12466.231000000002, -12462.948, -12459.177, -12454.918, -12450.171999999999, -12444.94, -12439.221000000001, -12433.016000000001, -12426.326000000001, -12419.151000000002, -12411.491000000002, -12403.347, -12394.719, -12385.607, -12376.011, -12365.933, -12355.371000000001, -12344.327, -12332.8, -12320.792, -12308.301000000001, -12295.329, -12281.874, -12267.938, -12253.52, -12238.621000000001, -12223.241000000002, -12207.378999999999, -12191.037, -12174.213, -12156.908000000001, -12139.122, -12120.855, -12102.106000000002, -12082.877, -12063.166000000001, -12042.973999999998, -12022.301000000001, -12001.146, -11979.508999999998, -11957.391000000001, -11934.79, -11911.707, -11888.142, -11864.094, -11839.563999999998, -11814.55, -11789.053, -11763.073, -11736.608, -11709.66, -11682.226999999999, -11654.309, -11625.905, -11597.017, -11567.642, -11537.781, -11507.433, -11476.597, -11445.274, -11413.462, -11381.161, -11348.372, -11315.091999999999, -11281.322, -11247.061000000002, -11212.308, -11177.063, -11141.326000000001, -11105.095, -11068.37, -11031.15, -10993.435, -10955.223, -10916.515, -10877.309, -10837.605, -10797.401000000002, -10756.697, -10715.492, -10673.785, -10631.576000000001, -10588.864, -10545.646999999999, -10501.923999999999, -10457.696, -10412.96, -10367.716, -10321.963, -10275.699, -10228.925, -10181.638, -10133.838, -10085.523000000001, -10036.693000000001, -9987.345, -9937.48, -9887.096, -9836.190999999999, -9784.765, -9732.815999999999, -9680.341999999999, -9627.344000000001, -9573.819, -9519.766, -9465.184000000001, -9410.071, -9354.426, -9298.248, -9241.534, -9184.284, -9126.496, -9068.169, -9009.301, -8949.891, -8889.936, -8829.436, -8768.389000000001, -8706.793, -8644.646, -8581.947, -8518.695, -8454.886999999999, -8390.523000000001, -8325.598, -8260.113000000001, -8194.065999999999, -8127.454000000001, -8060.276, -7992.529, -7924.213000000001, -7855.325, -7785.863, -7715.826, -7645.21, -7574.016, -7502.24, -7429.88, -7356.936, -7283.403, -7209.28, -7134.566, -7059.258000000001, -6983.355, -6906.853, -6829.7519999999995, -6752.049, -6673.741, -6594.828, -6515.306, -6435.174, -6354.429, -6273.071, -6191.095, -6108.5, -6025.285, -5941.446999999999, -5856.984, -5771.894, -5686.1759999999995, -5599.826, -5512.845, -5425.229, -5336.976, -5248.0869999999995, -5158.557, -5068.3859999999995, -4977.572, -4886.1140000000005, -4794.01, -4701.259, -4607.86, -4513.812, -4419.1140000000005, -4323.765, -4227.765, -4131.113, -4033.809, -3935.8520000000003, -3837.245, -3737.986, -3638.0759999999996, -3537.5159999999996, -3436.308, -3334.453, -3231.954, -3128.813, -3025.033, -2920.617, -2815.57, -2709.897, -2603.601, -2496.6910000000003, -2389.172, -2281.051, -2172.337, -2063.041, -1953.171, -1842.741, -1731.764, -1620.253, -1508.225, -1395.6989999999998, -1282.693, -1169.229, -1055.3319999999999, -941.0269999999999, -826.345, -711.317, -595.979, -480.37, -364.532, -248.514, -132.366, -16.146, 100.08200000000001, 216.25, 332.281, 448.091, 563.587, 678.668, 793.222, 907.125, 1020.242, 1132.424, 1243.507, 1353.3120000000001, 1461.641, 1568.279, 1672.986, 1775.506, 1875.556, 1972.828, 2066.989, 2157.6820000000002, 2244.516, 2327.08, 2404.931, 2477.6079999999997, 2544.625, 2605.479, 2659.6609999999996, 2706.657, 2745.962, 2777.0890000000004, 2799.5840000000003, 2813.04, 2817.111, 2811.5229999999997, 2796.09, 2770.7209999999995, 2735.426, 2690.3179999999998, 2635.612, 2571.618, 2498.732, 2417.4179999999997, 2328.199, 2231.637, 2128.32, 2018.849, 1903.818, 1783.8120000000001, 1659.3970000000002, 1531.1070000000002, 1399.4479999999999, 1264.89, 1127.868, 988.783, 847.9989999999999, 705.8439999999999, 562.619, 418.591, 274.002, 129.067, -16.023, -161.096, -306.001, -450.605, -594.79, -738.45, -881.495, -1023.8430000000001, -1165.425, -1305.698, -1446.05, -1584.994, -1722.97, -1859.943, -1995.885, -2130.769, -2264.576, -2397.2889999999998, -2528.891, -2659.3720000000003, -2788.723, -2916.9359999999997, -3044.008, -3169.934, -3294.7140000000004, -3418.347, -3540.8320000000003, -3662.172, -3782.3709999999996, -3901.43, -4019.3559999999998, -4136.153, -4251.826, -4366.380999999999, -4479.8240000000005, -4592.163, -4703.403, -4813.553, -4922.619000000001, -5030.611, -5137.534000000001, -5243.397, -5348.209, -5451.976, -5554.7080000000005, -5656.411, -5757.096, -5856.769, -5955.439, -6053.1140000000005, -6149.8009999999995, -6245.51, -6340.246999999999, -6434.021, -6526.84, -6618.7119999999995, -6709.644, -6799.644, -6888.718000000001, -6976.876, -7064.1230000000005, -7150.469, -7235.918000000001, -7320.48, -7404.161, -7486.967, -7568.905, -7649.984, -7730.2080000000005, -7809.584, -7888.12, -7965.82, -8042.691999999999, -8118.741999999999, -8193.975, -8268.399, -8342.017, -8414.838, -8486.866, -8558.107, -8628.565, -8698.248, -8767.159, -8835.305, -8902.690999999999, -8969.322, -9035.202, -9100.337, -9164.733, -9228.392, -9291.321, -9353.523000000001, -9415.004, -9475.768, -9535.819, -9595.162, -9653.801, -9711.741, -9768.984, -9825.537, -9881.403, -9936.585, -9991.087, -10044.913, -10098.068000000001, -10150.554, -10202.376, -10253.537, -10304.041, -10353.891, -10403.09, -10451.643, -10499.552, -10546.821000000002, -10593.452, -10639.448999999999, -10684.816, -10729.553999999998, -10773.668, -10817.16, -10860.033000000001, -10902.29, -10943.933, -10984.966999999999, -11025.393, -11065.214, -11104.433, -11143.053, -11181.075, -11218.502, -11255.338, -11291.583999999999, -11327.243, -11362.317, -11396.809, -11430.721000000001, -11464.055, -11496.813, -11528.998, -11560.611, -11591.656, -11622.133, -11652.046, -11681.396, -11710.185, -11738.413999999999, -11766.086000000001, -11793.204, -11819.768, -11845.78, -11871.243, -11896.157, -11920.526000000002, -11944.35, -11967.631000000001, -11990.371000000001, -12012.572, -12034.233999999999, -12055.361, -12075.953000000001, -12096.011, -12115.537, -12134.533000000001, -12153.0, -12170.938999999998, -12188.351999999999, -12205.241000000002, -12221.606000000002, -12237.448, -12252.77, -12267.573, -12281.857, -12295.623, -12308.874, -12321.611, -12333.833999999999, -12345.544, -12356.742, -12367.43, -12377.608999999999, -12387.278999999999, -12396.442, -12405.098999999998, -12413.25, -12420.896999999999, -12428.041000000001, -12434.681999999999, -12440.822, -12446.445, -12451.583999999999, -12456.223, -12460.365, -12464.008999999998, -12467.156, -12469.806, -12471.962, -12473.622, -12474.788999999999, -12475.463, -12475.643, -12475.332, -12474.53, -12473.236, -12471.453000000001, -12469.18, -12466.417, -12463.166000000001, -12459.427, -12455.201000000001, -12450.487, -12445.287, -12439.6, -12433.427, -12426.768, -12419.625, -12411.996000000001, -12403.883999999998, -12395.287, -12386.206, -12376.642, -12366.595, -12356.063999999998, -12345.051000000001, -12333.556, -12321.578000000001, -12309.118, -12296.177, -12282.753, -12268.847, -12254.46, -12239.591999999999, -12224.242, -12208.411, -12192.098999999998, -12175.305, -12158.03, -12140.275, -12122.038, -12103.319, -12084.12, -12064.438999999998, -12044.277, -12023.633, -12002.508, -11980.902, -11958.813, -11936.242, -11913.188, -11889.653, -11865.633999999998, -11841.133, -11816.149, -11790.681, -11764.73, -11738.295, -11711.375, -11683.971000000001, -11656.082, -11627.708, -11598.848, -11569.503, -11539.669, -11509.351, -11478.544, -11447.249, -11415.466, -11383.194, -11350.433, -11317.181999999999, -11283.44, -11249.208, -11214.483, -11179.267, -11143.558, -11107.355, -11070.658000000001, -11033.466, -10995.778999999999, -10957.596000000001, -10918.916000000001, -10879.738000000001, -10840.061000000002, -10799.885, -10759.208999999999, -10718.032, -10676.354, -10634.171999999999, -10591.487, -10548.298, -10504.603000000001, -10460.402, -10415.694, -10370.478000000001, -10324.752, -10278.516, -10231.769, -10184.51, -10136.737, -10088.449, -10039.646, -9990.326, -9940.488000000001, -9890.131, -9839.253, -9787.854, -9735.931999999999, -9683.485999999999, -9630.515, -9577.017, -9522.991, -9468.435, -9413.349, -9357.732, -9301.58, -9244.894, -9187.67, -9129.909, -9071.609, -9012.768, -8953.384, -8893.456, -8832.983, -8771.962, -8710.393, -8648.273000000001, -8585.601, -8522.375, -8458.594000000001, -8394.256, -8329.358, -8263.899, -8197.878, -8131.293000000001, -8064.141, -7996.420999999999, -7928.130999999999, -7859.269, -7789.834, -7719.823, -7649.234, -7578.066, -7506.316, -7433.983, -7361.064, -7287.557, -7213.460999999999, -7138.773, -7063.491, -6987.6140000000005, -6911.139, -6834.063, -6756.3859999999995, -6678.105, -6599.217, -6519.721, -6439.615, -6358.897, -6277.564, -6195.6140000000005, -6113.045, -6029.855, -5946.043000000001, -5861.606, -5776.5419999999995, -5690.849, -5604.526, -5517.569, -5429.979, -5341.7519999999995, -5252.887, -5163.383, -5073.238, -4982.4490000000005, -4891.016, -4798.937, -4706.210999999999, -4612.837, -4518.813, -4424.14, -4328.816, -4232.84, -4136.212, -4038.9320000000002, -3941.0, -3842.4159999999997, -3743.18, -3643.2940000000003, -3542.757, -3441.572, -3339.74, -3237.263, -3134.145, -3030.386, -2925.993, -2820.967, -2715.3140000000003, -2609.0389999999998, -2502.1479999999997, -2394.649, -2286.547, -2177.8520000000003, -2068.573, -1958.72, -1848.307, -1737.345, -1625.849, -1513.835, -1401.3210000000001, -1288.326, -1174.873, -1060.985, -946.688, -832.012, -716.988, -601.653, -486.04400000000004, -370.204, -254.18099999999998, -138.026, -21.796999999999997, 94.445, 210.62900000000002, 326.68, 442.515, 558.04, 673.1560000000001, 787.7489999999999, 901.699, 1014.8689999999999, 1127.111, 1238.263, 1348.145, 1456.5620000000001, 1563.297, 1668.114, 1770.757, 1870.943, 1968.368, 2062.698, 2153.577, 2240.618, 2323.409, 2401.509, 2474.459, 2541.772, 2602.949, 2657.4790000000003, 2704.849, 2744.554, 2776.105, 2799.048, 2812.973, 2817.53, 2812.4429999999998, 2797.5209999999997, 2772.6679999999997, 2737.889, 2693.2909999999997, 2639.086, 2575.5789999999997, 2503.16, 2422.291, 2333.492, 2237.323, 2134.37, 2025.233, 1910.5079999999998, 1790.779, 1666.612, 1538.543, 1407.0810000000001, 1272.6960000000001, 1135.825, 996.87, 856.197, 714.137, 570.99, 427.027, 282.49, 137.594, -7.466, -152.519, -297.414, -442.014, -586.202, -729.872, -872.931, -1015.3, -1156.906, -1297.6889999999999, -1437.5929999999998, -1576.5720000000001, -1714.586, -1851.599, -1987.5839999999998, -2122.513, -2256.367, -2389.1279999999997, -2520.78, -2651.312, -2780.715, -2908.982, -3036.107, -3162.0879999999997, -3286.923, -3410.611, -3533.153, -3654.55, -3774.805, -3893.922, -4011.906, -4128.76, -4244.491, -4359.104, -4472.605, -4585.001, -4696.299, -4806.5070000000005, -4915.630999999999, -5023.68, -5130.662, -5236.582, -5341.451, -5445.276, -5548.064, -5649.825, -5750.566, -5850.295999999999, -5949.023, -6046.754, -6143.496999999999, -6239.2609999999995, -6334.054, -6427.884, -6520.758000000001, -6612.684, -6703.67, -6793.724, -6882.853, -6971.065, -7058.366, -7144.765, -7230.268, -7314.882, -7398.616, -7481.474, -7563.465, -7644.596, -7724.871999999999, -7804.3, -7882.8859999999995, -7960.638000000001, -8037.561, -8113.661, -8188.945, -8263.418, -8337.087, -8409.958, -8482.035, -8553.324, -8623.832, -8693.563, -8762.524, -8830.718, -8898.152, -8964.83, -9030.759, -9095.940999999999, -9160.384, -9224.091, -9287.065999999999, -9349.315, -9410.843, -9471.653, -9531.75, -9591.139000000001, -9649.824, -9707.809000000001, -9765.098, -9821.696, -9877.607, -9932.834, -9987.38, -10041.251, -10094.45, -10146.981, -10198.847, -10250.052, -10300.599, -10350.492, -10399.735, -10448.33, -10496.282, -10543.594, -10590.268, -10636.308, -10681.716, -10726.497, -10770.652, -10814.186000000002, -10857.101, -10899.399, -10941.085, -10982.159, -11022.626, -11062.488000000001, -11101.748, -11140.409, -11178.471000000001, -11215.938999999998, -11252.815, -11289.101, -11324.8, -11359.913999999999, -11394.445, -11428.396999999999, -11461.77, -11494.567, -11526.791000000001, -11558.444, -11589.528, -11620.043, -11649.995, -11679.383, -11708.21, -11736.478000000001, -11764.188999999998, -11791.344, -11817.946000000002, -11843.996000000001, -11869.496000000001, -11894.448, -11918.854, -11942.716, -11966.034, -11988.811000000002, -12011.048999999999, -12032.748, -12053.912, -12074.54, -12094.635, -12114.197, -12133.23, -12151.733, -12169.708, -12187.158000000001, -12204.082, -12220.483, -12236.361, -12251.719, -12266.556999999999, -12280.876, -12294.678, -12307.964, -12320.736, -12332.993999999999, -12344.738000000001, -12355.972, -12366.694, -12376.908000000001, -12386.613000000001, -12395.81, -12404.502, -12412.687, -12420.368999999999, -12427.546, -12434.221000000001, -12440.395, -12446.067, -12451.24, -12455.913, -12460.088, -12463.766000000001, -12466.946000000002, -12469.63, -12471.819, -12473.513, -12474.712, -12475.419, -12475.633, -12475.355, -12474.585, -12473.323999999999, -12471.573, -12469.333, -12466.603000000001, -12463.383999999998, -12459.678, -12455.483, -12450.802, -12445.633, -12439.978000000001, -12433.837, -12427.211000000001, -12420.098999999998, -12412.503, -12404.421999999999, -12395.856000000002, -12386.806999999999, -12377.275, -12367.258999999998, -12356.76, -12345.778, -12334.313999999998, -12322.367, -12309.938, -12297.028, -12283.635, -12269.76, -12255.403999999999, -12240.567, -12225.247, -12209.447, -12193.165, -12176.402, -12159.158000000001, -12141.433, -12123.226, -12104.538, -12085.368999999999, -12065.718, -12045.586000000001, -12024.972, -12003.877, -11982.301000000001, -11960.241000000002, -11937.7, -11914.677, -11891.171, -11867.181999999999, -11842.711000000001, -11817.756000000001, -11792.318000000001, -11766.396, -11739.99, -11713.1, -11685.725, -11657.865, -11629.52, -11600.69, -11571.373, -11541.57, -11511.278999999999, -11480.501, -11449.235, -11417.481000000002, -11385.238000000001, -11352.506000000001, -11319.283000000001, -11285.57, -11251.366000000002, -11216.671, -11181.483, -11145.802, -11109.627, -11072.958999999999, -11035.796, -10998.136999999999, -10959.981000000002, -10921.33, -10882.18, -10842.532, -10802.383999999998, -10761.736, -10720.587, -10678.936000000002, -10636.782, -10594.125, -10550.964, -10507.296999999999, -10463.124, -10418.443000000001, -10373.255, -10327.556, -10281.348, -10234.629, -10187.396999999999, -10139.652, -10091.392, -10042.616, -9993.323, -9943.513, -9893.183, -9842.333, -9790.961, -9739.065999999999, -9686.648000000001, -9633.703000000001, -9580.233, -9526.234, -9471.705, -9416.646, -9361.056, -9304.931, -9248.271999999999, -9191.076, -9133.341999999999, -9075.068000000001, -9016.254, -8956.896999999999, -8896.997, -8836.55, -8775.556999999999, -8714.014000000001, -8651.921, -8589.275, -8526.076, -8462.322, -8398.01, -8333.139000000001, -8267.707, -8201.713, -8135.154, -8068.029, -8000.335, -7932.071999999999, -7863.236999999999, -7793.828, -7723.843000000001, -7653.281, -7582.139, -7510.415, -7438.109, -7365.215999999999, -7291.736, -7217.666, -7143.004, -7067.749, -6991.898, -6915.4490000000005, -6838.4, -6760.749, -6682.493, -6603.632, -6524.161999999999, -6444.0830000000005, -6363.39, -6282.0830000000005, -6200.158, -6117.616, -6034.451999999999, -5950.665, -5866.254, -5781.215999999999, -5695.549, -5609.251, -5522.321, -5434.755999999999, -5346.555, -5257.715999999999, -5168.237, -5078.116, -4987.353, -4895.945, -4803.891, -4711.19, -4617.840999999999, -4523.842000000001, -4429.194, -4333.894, -4237.943, -4141.34, -4044.0840000000003, -3946.176, -3847.615, -3748.403, -3648.54, -3548.027, -3446.865, -3345.0559999999996, -3242.6020000000003, -3139.505, -3035.77, -2931.3979999999997, -2826.393, -2720.761, -2614.507, -2507.636, -2400.155, -2292.072, -2183.395, -2074.134, -1964.299, -1853.902, -1742.9560000000001, -1631.475, -1519.475, -1406.974, -1293.991, -1180.548, -1066.6689999999999, -952.38, -837.71, -722.69, -607.357, -491.74800000000005, -375.907, -259.879, -143.718, -27.478, 88.77600000000001, 204.977, 321.04900000000004, 436.908, 552.462, 667.612, 782.2460000000001, 896.2410000000001, 1009.4639999999999, 1121.767, 1232.988, 1342.9479999999999, 1451.4520000000002, 1558.2839999999999, 1663.2120000000002, 1765.9779999999998, 1866.3010000000002, 1963.878, 2058.3779999999997, 2149.4429999999998, 2236.6910000000003, 2319.708, 2398.06, 2471.282, 2538.893, 2600.3920000000003, 2655.272, 2703.0170000000003, 2743.1209999999996, 2775.098, 2798.49, 2812.885, 2817.93, 2813.345, 2798.935, 2774.598, 2740.335, 2696.25, 2642.548, 2579.528, 2507.577, 2427.155, 2338.777, 2243.002, 2140.415, 2031.614, 1917.195, 1797.744, 1673.8270000000002, 1545.9820000000002, 1414.717, 1280.507, 1143.788, 1004.965, 864.404, 722.44, 579.373, 435.475, 290.99, 146.135, 1.105, -143.928, -288.81, -433.407, -577.597, -721.2760000000001, -864.3510000000001, -1006.7389999999999, -1148.369, -1289.18, -1429.116, -1568.13, -1706.182, -1843.237, -1979.264, -2114.239, -2248.14, -2380.948, -2512.65, -2643.2329999999997, -2772.688, -2901.008, -3028.188, -3154.224, -3279.114, -3402.8579999999997, -3525.455, -3646.909, -3767.222, -3886.397, -4004.438, -4121.35, -4237.138, -4351.809, -4465.3679999999995, -4577.823, -4689.18, -4799.446, -4908.628, -5016.735, -5123.773, -5229.752, -5334.678000000001, -5438.561, -5541.406999999999, -5643.225, -5744.023, -5843.809, -5942.590999999999, -6040.378000000001, -6137.178000000001, -6232.999, -6327.848000000001, -6421.733, -6514.661999999999, -6606.643, -6697.684, -6787.7919999999995, -6876.976, -6965.241999999999, -7052.597, -7139.049, -7224.606, -7309.274, -7393.06, -7475.971, -7558.014, -7639.196, -7719.524, -7799.004, -7877.642, -7955.445, -8032.419, -8108.57, -8183.905, -8258.428, -8332.146999999999, -8405.068000000001, -8477.195, -8548.534, -8619.09, -8688.871, -8757.88, -8826.123, -8893.605, -8960.331, -9026.308, -9091.539, -9156.028, -9219.782, -9282.805, -9345.101, -9406.675, -9467.530999999999, -9527.675, -9587.11, -9645.841, -9703.871, -9761.207, -9817.85, -9873.805, -9929.077, -9983.668, -10037.584, -10090.827, -10143.402, -10195.312, -10246.56, -10297.152, -10347.089, -10396.375, -10445.014000000001, -10493.008999999998, -10540.363000000001, -10587.079, -10633.161, -10678.612, -10723.435, -10767.633, -10811.208999999999, -10854.165, -10896.506000000001, -10938.233, -10979.348999999998, -11019.857, -11059.76, -11099.06, -11137.761, -11175.864, -11213.372, -11250.288, -11286.615, -11322.353000000001, -11357.507, -11392.079, -11426.07, -11459.483, -11492.32, -11524.583, -11556.275, -11587.396999999999, -11617.952, -11647.942, -11677.368, -11706.233999999999, -11734.54, -11762.288999999999, -11789.483, -11816.123, -11842.211000000001, -11867.749, -11892.739, -11917.181999999999, -11941.081, -11964.437, -11987.251, -12009.525, -12031.261999999999, -12052.462, -12073.126, -12093.257, -12112.857, -12131.925, -12150.465, -12168.476999999999, -12185.963, -12202.923, -12219.358999999999, -12235.274, -12250.667, -12265.54, -12279.895, -12293.733, -12307.053999999998, -12319.86, -12332.153, -12343.933, -12355.202, -12365.958999999999, -12376.207, -12385.947, -12395.178999999998, -12403.905, -12412.125, -12419.84, -12427.052, -12433.761, -12439.969, -12445.675, -12450.881000000001, -12455.588, -12459.796999999999, -12463.508, -12466.722, -12469.438999999998, -12471.661, -12473.388, -12474.621000000001, -12475.361, -12475.608, -12475.363000000001, -12474.626, -12473.398000000001, -12471.678999999998, -12469.471000000001, -12466.774, -12463.588, -12459.913999999999, -12455.752, -12451.101999999999, -12445.966, -12440.343, -12434.233999999999, -12427.64, -12420.56, -12412.995, -12404.946000000002, -12396.412, -12387.395, -12377.893, -12367.909, -12357.441, -12346.491000000002, -12335.058, -12323.143, -12310.745, -12297.865, -12284.503, -12270.659, -12256.333999999999, -12241.527, -12226.239, -12210.469, -12194.218, -12177.485, -12160.271, -12142.576000000001, -12124.4, -12105.743, -12086.604, -12066.983999999999, -12046.882, -12026.298, -12005.233, -11983.685, -11961.656, -11939.145, -11916.151000000002, -11892.675, -11868.716, -11844.274, -11819.348999999998, -11793.94, -11768.046999999999, -11741.671, -11714.811000000002, -11687.466, -11659.635, -11631.319, -11602.517, -11573.229, -11543.455, -11513.193000000001, -11482.444, -11451.207, -11419.482, -11387.267, -11354.563, -11321.37, -11287.686000000002, -11253.511, -11218.844, -11183.684, -11148.032, -11111.886, -11075.246000000001, -11038.111, -11000.48, -10962.353000000001, -10923.729, -10884.607, -10844.987, -10804.867, -10764.247, -10723.126, -10681.503, -10639.378, -10596.749, -10553.616000000002, -10509.976999999999, -10465.831, -10421.178, -10376.017, -10330.347, -10284.166, -10237.474, -10190.27, -10142.552, -10094.319, -10045.571, -9996.306, -9946.523000000001, -9896.221, -9845.398000000001, -9794.053, -9742.186, -9689.794, -9636.877, -9583.434000000001, -9529.462, -9474.961, -9419.929, -9364.365, -9308.267, -9251.635, -9194.466, -9136.759, -9078.511999999999, -9019.725, -8960.395, -8900.521, -8840.101, -8779.134, -8717.618, -8655.552, -8592.933, -8529.761, -8466.033000000001, -8401.747, -8336.903, -8271.498, -8205.53, -8138.9980000000005, -8071.899, -8004.232, -7935.996, -7867.187, -7797.804, -7727.846, -7657.31, -7586.195, -7514.496999999999, -7442.217, -7369.351, -7295.897, -7221.854, -7147.218000000001, -7071.9890000000005, -6996.164000000001, -6919.741, -6842.718000000001, -6765.093000000001, -6686.8640000000005, -6608.029, -6528.585999999999, -6448.531999999999, -6367.865, -6286.584, -6204.686, -6122.169, -6039.031, -5955.271, -5870.885, -5785.8730000000005, -5700.231, -5613.959, -5527.054, -5439.515, -5351.34, -5262.526, -5173.073, -5082.978, -4992.2390000000005, -4900.857, -4808.8279999999995, -4716.152, -4622.8279999999995, -4528.854, -4434.231, -4338.956, -4243.03, -4146.45, -4049.219, -3951.335, -3852.798, -3753.61, -3653.77, -3553.28, -3452.1420000000003, -3350.3559999999998, -3247.9240000000004, -3144.85, -3041.137, -2936.7859999999996, -2831.803, -2726.192, -2619.959, -2513.1079999999997, -2405.647, -2297.583, -2188.925, -2079.6820000000002, -1969.864, -1859.483, -1748.5529999999999, -1637.0870000000002, -1525.101, -1412.6129999999998, -1299.642, -1186.2089999999998, -1072.34, -958.059, -843.395, -728.38, -613.05, -497.44199999999995, -381.599, -265.568, -149.399, -33.15, 83.117, 199.334, 315.425, 431.30800000000005, 546.8919999999999, 662.076, 776.7489999999999, 890.79, 1004.065, 1116.427, 1227.7160000000001, 1337.753, 1446.3429999999998, 1553.274, 1658.31, 1761.1979999999999, 1861.658, 1959.386, 2054.054, 2145.306, 2232.759, 2316.0029999999997, 2394.6020000000003, 2468.097, 2536.004, 2597.826, 2653.053, 2701.172, 2741.677, 2774.078, 2797.9179999999997, 2812.783, 2818.316, 2814.232, 2800.335, 2776.5159999999996, 2742.772, 2699.2, 2646.0029999999997, 2583.473, 2511.993, 2432.02, 2344.065, 2248.687, 2146.469, 2038.006, 1923.8970000000002, 1804.727, 1681.0620000000001, 1553.443, 1422.378, 1288.345, 1151.78, 1013.09, 872.6439999999999, 730.7760000000001, 587.79, 443.959, 299.528, 154.715, 9.716000000000001, -135.296, -280.166, -424.75800000000004, -568.951, -712.6389999999999, -855.727, -998.135, -1139.79, -1280.362, -1420.596, -1559.646, -1697.735, -1834.8310000000001, -1970.901, -2105.92, -2239.868, -2372.725, -2504.4770000000003, -2635.111, -2764.618, -2892.991, -3020.225, -3146.316, -3271.262, -3395.0609999999997, -3517.716, -3639.2270000000003, -3759.597, -3878.829, -3996.928, -4113.898, -4229.745, -4344.474, -4458.090999999999, -4570.604, -4682.019, -4792.343, -4901.584, -5009.749, -5116.845, -5222.8820000000005, -5327.866, -5431.806, -5534.71, -5636.585, -5737.44, -5837.284000000001, -5936.1230000000005, -6033.967, -6130.823, -6226.6990000000005, -6321.604, -6415.545, -6508.53, -6600.566, -6691.661999999999, -6781.825, -6871.063, -6959.384, -7046.793000000001, -7133.299, -7218.909000000001, -7303.63, -7387.47, -7470.434, -7552.53, -7633.764, -7714.144, -7793.677, -7872.366, -7950.221, -8027.246, -8103.448, -8178.8330000000005, -8253.407, -8327.176, -8400.146999999999, -8472.324, -8543.712, -8614.318000000001, -8684.148000000001, -8753.206, -8821.497, -8889.028, -8955.803, -9021.827, -9087.106, -9151.644, -9215.445, -9278.515, -9340.858, -9402.479, -9463.382, -9523.572, -9583.053, -9641.83, -9699.907, -9757.288, -9813.976999999999, -9869.976999999999, -9925.294, -9979.93, -10033.891, -10087.178, -10139.798, -10191.752, -10243.045, -10293.679, -10343.661, -10392.991, -10441.673, -10489.711000000001, -10537.108, -10583.867, -10629.992, -10675.485, -10720.351, -10764.59, -10808.208, -10851.207, -10893.589, -10935.358, -10976.515, -11017.065, -11057.008999999998, -11096.35, -11135.091, -11173.235, -11210.784, -11247.741000000002, -11284.107, -11319.886, -11355.08, -11389.692, -11423.723, -11457.175, -11490.052, -11522.354, -11554.085, -11585.247, -11615.841, -11645.868999999999, -11675.333999999999, -11704.238000000001, -11732.583, -11760.37, -11787.601999999999, -11814.28, -11840.406, -11865.982, -11891.01, -11915.491000000002, -11939.427, -11962.82, -11985.671999999999, -12007.983, -12029.757, -12050.993999999999, -12071.695, -12091.863000000001, -12111.499, -12130.604, -12149.18, -12167.229, -12184.75, -12201.747, -12218.219, -12234.169, -12249.598, -12264.507, -12278.898000000001, -12292.771, -12306.128, -12318.969, -12331.296999999999, -12343.112, -12354.415, -12365.208, -12375.491000000002, -12385.265, -12394.532, -12403.292, -12411.546999999999, -12419.296, -12426.543, -12433.286, -12439.527, -12445.268, -12450.508, -12455.249, -12459.491000000002, -12463.236, -12466.483, -12469.233999999999, -12471.489, -12473.25, -12474.516000000001, -12475.288999999999, -12475.568000000001, -12475.356000000002, -12474.652, -12473.457, -12471.771, -12469.596000000001, -12466.931, -12463.777, -12460.136, -12456.006000000001, -12451.389, -12446.285, -12440.694, -12434.617, -12428.055, -12421.007, -12413.473999999998, -12405.456, -12396.954, -12387.968, -12378.499, -12368.546, -12358.108999999999, -12347.19, -12335.788999999999, -12323.905, -12311.538, -12298.688999999998, -12285.358, -12271.545, -12257.251, -12242.475, -12227.216999999999, -12211.478000000001, -12195.257, -12178.555, -12161.372, -12143.707, -12125.562, -12106.935, -12087.826000000001, -12068.236, -12048.163999999999, -12027.61, -12006.575, -11985.058, -11963.058, -11940.577, -11917.613000000001, -11894.166000000001, -11870.237, -11845.823999999999, -11820.928999999998, -11795.55, -11769.687, -11743.34, -11716.508999999998, -11689.193000000001, -11661.391000000001, -11633.105, -11604.332, -11575.073, -11545.328000000001, -11515.095, -11484.375, -11453.167, -11421.47, -11389.285, -11356.608999999999, -11323.444, -11289.788999999999, -11255.642, -11221.003999999999, -11185.873, -11150.249, -11114.132, -11077.52, -11040.413, -11002.811000000002, -10964.712, -10926.116000000002, -10887.023000000001, -10847.43, -10807.338, -10766.746000000001, -10725.653, -10684.059, -10641.961000000001, -10599.36, -10556.255, -10512.643, -10468.526, -10423.901, -10378.767, -10333.124, -10286.971, -10240.306999999999, -10193.13, -10145.439, -10097.234, -10048.513, -9999.276, -9949.52, -9899.245, -9848.45, -9797.133, -9745.292, -9692.928, -9640.038, -9586.622, -9532.677, -9478.203000000001, -9423.198, -9367.661, -9311.59, -9254.985, -9197.843, -9140.163, -9081.944, -9023.183, -8963.88, -8904.033000000001, -8843.64, -8782.699, -8721.21, -8659.171, -8596.579, -8533.433, -8469.732, -8405.473, -8340.655, -8275.277, -8209.336, -8142.83, -8075.758000000001, -8008.118, -7939.906999999999, -7871.125, -7801.769, -7731.8369999999995, -7661.328, -7590.238, -7518.568, -7446.314, -7373.474, -7300.045999999999, -7226.029, -7151.42, -7076.217, -7000.418000000001, -6924.022, -6847.025, -6769.4259999999995, -6691.223000000001, -6612.414000000001, -6532.996999999999, -6452.969, -6372.328, -6291.073, -6209.201, -6126.71, -6043.598000000001, -5959.863, -5875.504, -5790.517, -5704.901999999999, -5618.655, -5531.776, -5444.263000000001, -5356.113, -5267.325, -5177.897, -5087.827, -4997.1140000000005, -4905.755999999999, -4813.753, -4721.102, -4627.803, -4533.854, -4439.255, -4344.005999999999, -4248.104, -4151.549, -4054.342, -3956.482, -3857.969, -3758.805, -3658.989, -3558.522, -3457.407, -3355.6440000000002, -3253.235, -3150.183, -3046.492, -2942.164, -2837.202, -2731.612, -2625.3990000000003, -2518.569, -2411.127, -2303.083, -2194.4429999999998, -2085.218, -1975.418, -1865.0539999999999, -1754.14, -1642.6889999999999, -1530.717, -1418.241, -1305.282, -1191.861, -1078.001, -963.7280000000001, -849.071, -734.061, -618.7330000000001, -503.126, -387.282, -271.247, -155.07299999999998, -38.815, 77.465, 193.69799999999998, 309.809, 425.716, 541.328, 656.545, 771.257, 885.3430000000001, 998.67, 1111.0919999999999, 1222.448, 1332.5610000000001, 1441.237, 1548.264, 1653.4089999999999, 1756.418, 1857.013, 1954.891, 2049.7270000000003, 2141.163, 2228.821, 2312.29, 2391.137, 2464.902, 2533.105, 2595.2470000000003, 2650.82, 2699.312, 2740.216, 2773.0409999999997, 2797.328, 2812.6620000000003, 2818.6809999999996, 2815.1, 2801.7140000000004, 2778.413, 2745.188, 2702.131, 2649.438, 2587.4, 2516.393, 2436.87, 2349.341, 2254.362, 2152.513, 2044.391, 1930.5929999999998, 1811.7060000000001, 1688.295, 1560.904, 1430.0410000000002, 1296.185, 1159.776, 1021.221, 880.89, 739.1210000000001, 596.217, 452.454, 308.07599999999996, 163.306, 18.338, -126.652, -271.509, -416.095, -560.29, -703.9860000000001, -847.0889999999999, -989.5160000000001, -1131.194, -1272.058, -1412.057, -1551.141, -1689.269, -1826.405, -1962.5179999999998, -2097.583, -2231.576, -2364.482, -2496.283, -2626.969, -2756.5290000000005, -2884.955, -3012.243, -3138.388, -3263.389, -3387.245, -3509.9570000000003, -3631.525, -3751.952, -3871.242, -3989.3979999999997, -4106.427, -4222.332, -4337.119000000001, -4450.795, -4563.366, -4674.839, -4785.222, -4894.521, -5002.744000000001, -5109.899, -5215.9929999999995, -5321.035, -5425.033, -5527.994000000001, -5629.927, -5730.84, -5830.74, -5929.6359999999995, -6027.536, -6124.4490000000005, -6220.382, -6315.343000000001, -6409.339, -6502.38, -6594.471, -6685.6230000000005, -6775.840999999999, -6865.134, -6953.508000000001, -7040.971, -7127.531, -7213.195, -7297.97, -7381.863, -7464.88, -7547.029, -7628.316, -7708.7480000000005, -7788.331, -7867.073, -7944.979, -8022.055, -8098.309, -8173.745, -8248.37, -8322.189, -8395.209, -8467.436, -8538.874, -8609.53, -8679.409, -8748.516, -8816.857, -8884.436, -8951.259, -9017.331, -9082.658000000001, -9147.243, -9211.091, -9274.209, -9336.6, -9398.267, -9459.216999999999, -9519.454, -9578.982, -9637.804, -9695.927, -9753.354, -9810.088, -9866.134, -9921.496, -9976.177, -10030.181999999999, -10083.515, -10136.178, -10188.177, -10239.513, -10290.192, -10340.216999999999, -10389.591, -10438.315999999999, -10486.396999999999, -10533.837, -10580.64, -10626.806999999999, -10672.343, -10717.251, -10761.533000000001, -10805.194, -10848.233999999999, -10890.658000000001, -10932.468, -10973.667, -11014.257, -11054.242, -11093.625, -11132.407, -11170.591999999999, -11208.181, -11245.178999999998, -11281.586000000001, -11317.405, -11352.639, -11387.29, -11421.361, -11454.853000000001, -11487.768, -11520.11, -11551.88, -11583.081, -11613.714, -11643.782, -11673.286, -11702.229, -11730.612, -11758.437, -11785.707, -11812.423, -11838.587, -11864.2, -11889.266000000001, -11913.784, -11937.758, -11961.188999999998, -11984.078000000001, -12006.427, -12028.238000000001, -12049.511, -12070.25, -12090.454, -12110.127, -12129.268, -12147.88, -12165.965, -12183.521999999999, -12200.555, -12217.063999999998, -12233.05, -12248.515, -12263.46, -12277.886, -12291.794, -12305.186000000002, -12318.063, -12330.426000000001, -12342.276000000002, -12353.614, -12364.441, -12374.758999999998, -12384.569, -12393.87, -12402.663999999999, -12410.953000000001, -12418.737, -12426.018, -12432.795, -12439.071000000002, -12444.845, -12450.118999999999, -12454.893, -12459.169, -12462.947, -12466.228000000001, -12469.013, -12471.302, -12473.095, -12474.395, -12475.2, -12475.513, -12475.333999999999, -12474.663, -12473.5, -12471.847, -12469.705, -12467.073, -12463.952, -12460.341999999999, -12456.245, -12451.66, -12446.588, -12441.028999999999, -12434.983999999999, -12428.453000000001, -12421.437, -12413.936000000002, -12405.95, -12397.48, -12388.525, -12379.087, -12369.166000000001, -12358.761, -12347.874, -12336.503, -12324.65, -12312.313999999998, -12299.496000000001, -12286.196000000002, -12272.413999999999, -12258.15, -12243.405, -12228.178, -12212.47, -12196.28, -12179.608999999999, -12162.456, -12144.822, -12126.706, -12108.108999999999, -12089.03, -12069.47, -12049.428, -12028.903999999999, -12007.899, -11986.412, -11964.442, -11941.99, -11919.056, -11895.64, -11871.74, -11847.357, -11822.491000000002, -11797.141000000001, -11771.308, -11744.99, -11718.188, -11690.901000000002, -11663.128999999999, -11634.871000000001, -11606.127, -11576.896999999999, -11547.181, -11516.976999999999, -11486.287, -11455.107, -11423.44, -11391.283000000001, -11358.636, -11325.5, -11291.873, -11257.753999999999, -11223.143999999998, -11188.042, -11152.446000000002, -11116.357, -11079.774, -11042.696000000002, -11005.122, -10967.051000000001, -10928.483, -10889.418, -10849.853000000001, -10809.79, -10769.226, -10728.16, -10686.593, -10644.523000000001, -10601.95, -10558.872, -10515.288999999999, -10471.199, -10426.601999999999, -10381.496, -10335.881, -10289.755, -10243.118, -10195.969000000001, -10148.305, -10100.128, -10051.434000000001, -10002.224, -9952.496, -9902.248, -9851.48, -9800.19, -9748.377, -9696.039, -9643.177, -9589.787, -9535.87, -9481.423, -9426.445, -9370.934000000001, -9314.891, -9258.312, -9201.197, -9143.544, -9085.351, -9026.617, -8967.341, -8907.52, -8847.154, -8786.241, -8724.778, -8662.765, -8600.2, -8537.082, -8473.407, -8409.175, -8344.383, -8279.030999999999, -8213.116, -8146.637, -8079.590999999999, -8011.977, -7943.793000000001, -7875.0380000000005, -7805.7080000000005, -7735.803000000001, -7665.32, -7594.257, -7522.613, -7450.385, -7377.571, -7304.169, -7230.178000000001, -7155.595, -7080.418000000001, -7004.646, -6928.276, -6851.306, -6773.733, -6695.556, -6616.773, -6537.380999999999, -6457.379, -6376.764, -6295.535, -6213.689, -6131.224, -6048.138000000001, -5964.43, -5880.096, -5795.135, -5709.545, -5623.3240000000005, -5536.471, -5448.983, -5360.858, -5272.095, -5182.693, -5092.649, -5001.960999999999, -4910.629, -4818.651, -4726.025, -4632.751, -4538.827, -4444.252, -4349.027, -4253.149, -4156.619000000001, -4059.437, -3961.6009999999997, -3863.112, -3763.972, -3664.179, -3563.736, -3462.6440000000002, -3360.9040000000005, -3258.518, -3155.489, -3051.8190000000004, -2947.513, -2842.573, -2737.0040000000004, -2630.812, -2524.002, -2416.58, -2308.555, -2199.9339999999997, -2090.7270000000003, -1980.945, -1870.598, -1759.6989999999998, -1648.263, -1536.305, -1423.8429999999998, -1310.896, -1197.486, -1083.635, -969.3710000000001, -854.72, -739.716, -624.391, -508.786, -392.941, -276.902, -160.722, -44.455, 71.836, 188.085, 304.215, 420.145, 535.785, 651.035, 765.7860000000001, 879.916, 993.294, 1105.774, 1217.197, 1327.385, 1436.1470000000002, 1543.269, 1648.521, 1751.651, 1852.379, 1950.4070000000002, 2045.408, 2137.028, 2224.889, 2308.5820000000003, 2387.674, 2461.708, 2530.205, 2592.666, 2648.585, 2697.448, 2738.7490000000003, 2771.9970000000003, 2796.73, 2812.53, 2819.0370000000003, 2815.9559999999997, 2803.083, 2780.3, 2747.595, 2705.053, 2652.867, 2591.321, 2520.7889999999998, 2441.719, 2354.619, 2260.04, 2158.564, 2050.786, 1937.3020000000001, 1818.7, 1695.547, 1568.384, 1437.727, 1304.05, 1167.799, 1029.38, 889.1669999999999, 747.497, 604.677, 460.983, 316.66200000000003, 171.935, 27.0, -117.96700000000001, -262.81, -407.39099999999996, -551.587, -695.291, -838.408, -980.8530000000001, -1122.5539999999999, -1263.448, -1403.4779999999998, -1542.5970000000002, -1680.7620000000002, -1817.9379999999999, -1954.094, -2089.203, -2223.243, -2356.197, -2488.047, -2618.784, -2748.3959999999997, -2876.8759999999997, -3004.218, -3130.4179999999997, -3255.474, -3379.386, -3502.155, -3623.78, -3744.264, -3863.612, -3981.8259999999996, -4098.913, -4214.876, -4329.722, -4443.456, -4556.085999999999, -4667.617, -4778.059, -4887.417, -4995.698, -5102.911, -5209.063, -5314.1630000000005, -5418.22, -5521.2390000000005, -5623.229, -5724.1990000000005, -5824.156, -5923.11, -6021.066999999999, -6118.036, -6214.026, -6309.043000000001, -6403.095, -6496.191, -6588.339, -6679.545, -6769.819, -6859.166, -6947.595, -7035.113, -7121.727, -7207.445, -7292.273, -7376.219, -7459.29, -7541.491999999999, -7622.831, -7703.316, -7782.951999999999, -7861.745, -7939.701999999999, -8016.83, -8093.1359999999995, -8168.6230000000005, -8243.298, -8317.169, -8390.239, -8462.515, -8534.004, -8604.709, -8674.638, -8743.794, -8812.184000000001, -8879.812, -8946.684000000001, -9012.804, -9078.179, -9142.812, -9206.708, -9269.874, -9332.311, -9394.026, -9455.023000000001, -9515.306999999999, -9574.881, -9633.75, -9691.919, -9749.391, -9806.171999999999, -9862.263, -9917.67, -9972.396999999999, -10026.447, -10079.824, -10132.532, -10184.575, -10235.956, -10286.679, -10336.748, -10386.166, -10434.935, -10483.059000000001, -10530.543, -10577.388, -10623.598999999998, -10669.177, -10714.128, -10758.453000000001, -10802.155, -10845.238000000001, -10887.703000000001, -10929.555, -10970.796, -11011.428, -11051.455, -11090.878, -11129.702, -11167.927, -11205.558, -11242.596000000001, -11279.044, -11314.903, -11350.178, -11384.868999999999, -11418.979, -11452.511, -11485.466, -11517.848, -11549.657, -11580.896999999999, -11611.57, -11641.677, -11671.22, -11700.201000000001, -11728.623, -11756.487, -11783.795, -11810.548999999999, -11836.751, -11862.403, -11887.506000000001, -11912.063, -11936.073999999999, -11959.543, -11982.469, -12004.856000000002, -12026.703000000001, -12048.014, -12068.788999999999, -12089.031, -12108.74, -12127.918, -12146.567, -12164.688, -12182.282, -12199.35, -12215.896, -12231.918, -12247.419, -12262.4, -12276.861, -12290.805, -12304.233, -12317.145, -12329.543, -12341.428, -12352.802, -12363.663999999999, -12374.017, -12383.861, -12393.197, -12402.027, -12410.35, -12418.169, -12425.483999999999, -12432.295, -12438.605, -12444.413, -12449.721000000001, -12454.53, -12458.84, -12462.651000000002, -12465.966, -12468.784, -12471.107, -12472.934, -12474.267, -12475.106000000002, -12475.452, -12475.305, -12474.667, -12473.538, -12471.918, -12469.808, -12467.208999999999, -12464.12, -12460.543, -12456.478000000001, -12451.926000000001, -12446.886, -12441.358999999999, -12435.347, -12428.848, -12421.864, -12414.395, -12406.441, -12398.002, -12389.08, -12379.673, -12369.784, -12359.411, -12348.553999999998, -12337.215, -12325.393, -12313.089, -12300.302, -12287.033000000001, -12273.282, -12259.05, -12244.335, -12229.139, -12213.461000000001, -12197.303, -12180.662, -12163.54, -12145.936000000002, -12127.851, -12109.284, -12090.236, -12070.706, -12050.694, -12030.201000000001, -12009.225, -11987.768, -11965.828000000001, -11943.407, -11920.503, -11897.116000000002, -11873.246000000001, -11848.893, -11824.056999999999, -11798.736, -11772.931999999999, -11746.643999999998, -11719.871000000001, -11692.614, -11664.871000000001, -11636.642, -11607.928, -11578.726999999999, -11549.04, -11518.866000000002, -11488.204, -11457.053999999998, -11425.415, -11393.287, -11360.669, -11327.561000000002, -11293.963, -11259.873, -11225.292, -11190.218, -11154.651000000002, -11118.591, -11082.036, -11044.986, -11007.44, -10969.398000000001, -10930.858999999999, -10891.821000000002, -10852.285, -10812.25, -10771.714, -10730.677, -10689.138, -10647.096000000001, -10604.55, -10561.5, -10517.945, -10473.883, -10429.314, -10384.235, -10338.648000000001, -10292.55, -10245.940999999999, -10198.819, -10151.183, -10103.033000000001, -10054.367, -10005.184000000001, -9955.484, -9905.263, -9854.523000000001, -9803.26, -9751.474, -9699.164, -9646.329, -9592.966999999999, -9539.076, -9484.655999999999, -9429.706, -9374.223, -9318.206, -9261.655, -9204.567, -9146.940999999999, -9088.775, -9030.068000000001, -8970.819, -8911.025, -8850.686, -8789.799, -8728.364, -8666.377, -8603.839, -8540.747, -8477.099, -8412.894, -8348.129, -8282.804, -8216.916, -8150.463000000001, -8083.444, -8015.857, -7947.7, -7878.97, -7809.6669999999995, -7739.789000000001, -7669.331999999999, -7598.295999999999, -7526.678000000001, -7454.477, -7381.689, -7308.314, -7234.349, -7159.793000000001, -7084.643, -7008.897, -6932.553000000001, -6855.609, -6778.063, -6699.911999999999, -6621.155, -6541.79, -6461.814, -6381.225, -6300.022, -6218.201999999999, -6135.763000000001, -6052.704000000001, -5969.021, -5884.713000000001, -5799.778, -5714.214, -5628.02, -5541.191999999999, -5453.73, -5365.630999999999, -5276.894, -5187.516, -5097.498, -5006.837, -4915.53, -4823.577, -4730.977, -4637.728, -4543.829000000001, -4449.28, -4354.079000000001, -4258.226, -4161.721, -4064.563, -3966.752, -3868.2870000000003, -3769.171, -3669.402, -3568.9829999999997, -3467.914, -3366.197, -3263.835, -3160.828, -3057.1809999999996, -2952.897, -2847.9790000000003, -2742.4320000000002, -2636.26, -2529.471, -2422.07, -2314.064, -2205.462, -2096.274, -1986.509, -1876.18, -1765.297, -1653.876, -1541.933, -1429.485, -1316.5510000000002, -1203.152, -1089.3110000000001, -975.055, -860.4119999999999, -745.413, -630.092, -514.488, -398.642, -282.601, -166.415, -50.14, 66.163, 182.42700000000002, 298.57599999999996, 414.529, 530.197, 645.479, 760.268, 874.443, 987.872, 1100.411, 1211.899, 1322.1629999999998, 1431.009, 1538.2279999999998, 1643.5870000000002, 1746.8370000000002, 1847.7, 1945.878, 2041.045, 2132.849, 2220.9139999999998, 2304.8320000000003, 2384.17, 2458.475, 2527.2670000000003, 2590.049, 2646.315, 2695.551, 2737.252, 2770.926, 2796.1090000000004, 2812.381, 2819.377, 2816.803, 2804.447, 2782.188, 2750.008, 2707.988, 2656.3140000000003, 2595.268, 2525.217, 2446.606, 2359.9410000000003, 2265.769, 2164.672, 2057.243, 1944.078, 1825.766, 1702.875, 1575.9460000000001, 1445.497, 1312.004, 1175.914, 1037.635, 897.541, 755.9730000000001, 613.239, 469.616, 325.35200000000003, 180.67, 35.769, -109.175, -254.003, -398.577, -542.773, -686.485, -829.6139999999999, -972.078, -1113.803, -1254.563, -1394.785, -1533.9389999999999, -1672.141, -1809.358, -1945.557, -2080.7110000000002, -2214.798, -2347.8, -2479.701, -2610.489, -2740.1540000000005, -2868.687, -2996.0840000000003, -3122.3390000000004, -3247.452, -3371.421, -3494.2459999999996, -3615.929, -3736.472, -3855.8779999999997, -3974.151, -4091.296, -4207.319, -4322.223, -4436.017, -4548.706, -4660.295999999999, -4770.7970000000005, -4880.214, -4988.554, -5095.826, -5202.038, -5307.196999999999, -5411.311, -5514.389, -5616.437, -5717.465999999999, -5817.481, -5916.491999999999, -6014.507, -6111.534000000001, -6207.581, -6302.654, -6396.763000000001, -6489.916, -6582.12, -6673.382, -6763.7119999999995, -6853.115, -6941.599, -7029.172, -7115.840999999999, -7201.613, -7286.495, -7370.496, -7453.62, -7535.876, -7617.269, -7697.806, -7777.495, -7856.340999999999, -7934.351, -8011.531, -8087.888000000001, -8163.427, -8238.154, -8312.076, -8385.197, -8457.524, -8529.063, -8599.819, -8669.798, -8739.004, -8807.443000000001, -8875.121, -8942.042, -9008.211, -9073.635, -9138.315999999999, -9202.261, -9265.474, -9327.96, -9389.723, -9450.767, -9511.098, -9570.719000000001, -9629.635, -9687.851, -9745.37, -9802.197, -9858.334, -9913.787, -9968.56, -10022.655, -10076.078000000001, -10128.832, -10180.92, -10232.346, -10283.113000000001, -10333.226, -10382.688, -10431.502, -10479.67, -10527.197, -10574.086000000001, -10620.34, -10665.963, -10710.956, -10755.323999999999, -10799.069, -10842.195, -10884.703000000001, -10926.597, -10967.88, -11008.553999999998, -11048.623, -11088.088, -11126.953000000001, -11165.22, -11202.892, -11239.971000000001, -11276.46, -11312.361, -11347.675, -11382.407, -11416.558, -11450.13, -11483.126, -11515.546999999999, -11547.396999999999, -11578.676000000001, -11609.388, -11639.534, -11669.116000000002, -11698.136999999999, -11726.598, -11754.501, -11781.848, -11808.642, -11834.883, -11860.573, -11885.715, -11910.309, -11934.358999999999, -11957.865, -11980.829, -12003.253, -12025.139, -12046.487, -12067.301000000001, -12087.58, -12107.326000000001, -12126.541000000001, -12145.226999999999, -12163.385, -12181.016000000001, -12198.121000000001, -12214.702, -12230.761, -12246.298, -12261.316, -12275.813999999998, -12289.794, -12303.258, -12316.206, -12328.64, -12340.56, -12351.969, -12362.867, -12373.255, -12383.133999999998, -12392.506000000001, -12401.37, -12409.729, -12417.583, -12424.931999999999, -12431.778999999999, -12438.123, -12443.966, -12449.308, -12454.151000000002, -12458.495, -12462.341, -12465.69, -12468.542, -12470.898000000001, -12472.758999999998, -12474.126, -12474.999, -12475.378, -12475.265, -12474.661, -12473.565, -12471.978000000001, -12469.901000000002, -12467.335, -12464.28, -12460.736, -12456.704, -12452.184, -12447.177, -12441.683, -12435.703000000001, -12429.236, -12422.285, -12414.848, -12406.926000000001, -12398.52, -12389.63, -12380.256000000001, -12370.398000000001, -12360.056, -12349.232, -12337.923999999999, -12326.133999999998, -12313.861, -12301.106000000002, -12287.868999999999, -12274.149, -12259.948, -12245.265, -12230.101, -12214.454, -12198.326000000001, -12181.716, -12164.625, -12147.052, -12128.997, -12110.461000000001, -12091.444, -12071.945, -12051.964, -12031.501, -12010.556, -11989.13, -11967.221000000001, -11944.829, -11921.955, -11898.598, -11874.758, -11850.435, -11825.628999999999, -11800.338, -11774.563999999998, -11748.306, -11721.563, -11694.336000000001, -11666.623, -11638.423999999999, -11609.739, -11580.568000000001, -11550.91, -11520.765, -11490.132, -11459.011, -11427.401000000002, -11395.302, -11362.714, -11329.636, -11296.067, -11262.007, -11227.454, -11192.409, -11156.871000000001, -11120.839, -11084.313, -11047.292, -11009.775, -10971.761, -10933.25, -10894.242, -10854.735, -10814.728000000001, -10774.22, -10733.212, -10691.701000000001, -10649.687, -10607.17, -10564.148000000001, -10520.621000000001, -10476.587, -10432.046, -10386.996, -10341.437, -10295.367, -10248.786, -10201.692, -10154.084, -10105.962, -10057.324, -10008.169, -9958.495, -9908.303, -9857.59, -9806.356, -9754.598, -9702.315, -9649.508, -9596.173, -9542.31, -9487.918, -9432.995, -9377.539, -9321.55, -9265.026, -9207.966, -9150.367, -9092.228000000001, -9033.549, -8974.327, -8914.56, -8854.248, -8793.389000000001, -8731.981, -8670.021999999999, -8607.511, -8544.446, -8480.825, -8416.646999999999, -8351.909, -8286.610999999999, -8220.75, -8154.3240000000005, -8087.331999999999, -8019.772, -7951.642, -7882.94, -7813.664000000001, -7743.812, -7673.382, -7602.3730000000005, -7530.781999999999, -7458.607, -7385.846, -7312.4980000000005, -7238.56, -7164.031, -7088.908, -7013.189, -6936.871, -6859.954000000001, -6782.434, -6704.31, -6625.58, -6546.241, -6466.2919999999995, -6385.73, -6304.554, -6222.76, -6140.348000000001, -6057.314, -5973.658, -5889.3769999999995, -5804.468000000001, -5718.93, -5632.762, -5545.960999999999, -5458.525, -5370.453, -5281.741999999999, -5192.391, -5102.398, -5011.762, -4920.481, -4828.554, -4735.979, -4642.7570000000005, -4548.884, -4454.36, -4359.184, -4263.357, -4166.876, -4069.743, -3971.9559999999997, -3873.5170000000003, -3774.426, -3674.6820000000002, -3574.2859999999996, -3473.242, -3371.548, -3269.2090000000003, -3166.2259999999997, -3062.6009999999997, -2958.3390000000004, -2853.4440000000004, -2747.9190000000003, -2641.7690000000002, -2535.001, -2427.62, -2319.634, -2211.052, -2101.883, -1992.136, -1881.8229999999999, -1770.9579999999999, -1659.5539999999999, -1547.626, -1435.191, -1322.27, -1208.883, -1095.052, -980.805, -866.169, -751.176, -635.859, -520.257, -404.411, -288.367, -172.176, -55.891999999999996, 60.422, 176.7, 292.868, 408.845, 524.54, 639.855, 754.682, 868.9010000000001, 982.3810000000001, 1094.978, 1206.5339999999999, 1316.8729999999998, 1425.8039999999999, 1533.119, 1638.5870000000002, 1741.957, 1842.955, 1941.2839999999999, 2036.618, 2128.609, 2216.879, 2301.022, 2380.61, 2455.187, 2524.276, 2587.382, 2643.998, 2693.612, 2735.717, 2769.82, 2795.4570000000003, 2812.2059999999997, 2819.698, 2817.636, 2805.803, 2784.075, 2752.427, 2710.937, 2659.783, 2599.243, 2529.68, 2451.5370000000003, 2365.312, 2271.555, 2170.843, 2063.769, 1950.931, 1832.914, 1710.29, 1583.6, 1453.3629999999998, 1320.058, 1184.132, 1045.995, 906.025, 764.562, 621.915, 478.36400000000003, 334.159, 189.523, 44.657, -100.262, -245.074, -389.64099999999996, -533.8380000000001, -677.556, -820.698, -963.18, -1104.928, -1245.877, -1385.97, -1525.158, -1663.399, -1800.656, -1936.8970000000002, -2072.097, -2206.232, -2339.283, -2471.235, -2602.075, -2731.7929999999997, -2860.381, -2987.833, -3114.145, -3239.3140000000003, -3363.34, -3486.224, -3607.965, -3728.566, -3848.031, -3966.364, -4083.5690000000004, -4199.651, -4314.616, -4428.469, -4541.218, -4652.869000000001, -4763.43, -4872.906, -4981.306, -5088.638, -5194.909000000001, -5300.128000000001, -5404.302, -5507.439, -5609.545999999999, -5710.633000000001, -5810.7080000000005, -5909.778, -6007.851, -6104.936, -6201.04, -6296.170999999999, -6390.338000000001, -6483.548000000001, -6575.809, -6667.128000000001, -6757.514, -6846.973000000001, -6935.513000000001, -7023.142, -7109.866999999999, -7195.695, -7280.632, -7364.687, -7447.866, -7530.175, -7611.6230000000005, -7692.215, -7771.956999999999, -7850.857, -7928.92, -8006.153, -8082.561, -8158.153, -8232.933, -8306.905999999999, -8380.079, -8452.458, -8524.048, -8594.854, -8664.883, -8734.141, -8802.63, -8870.358, -8937.329, -9003.548, -9069.021, -9133.751, -9197.745, -9261.007, -9323.542, -9385.353000000001, -9446.445, -9506.824, -9566.493, -9625.457, -9683.719000000001, -9741.286, -9798.159, -9854.344000000001, -9909.843, -9964.662, -10018.804, -10072.273000000001, -10125.072, -10177.205, -10228.677, -10279.491, -10329.649, -10379.155, -10428.013, -10476.226, -10523.798, -10570.731000000002, -10617.028999999999, -10662.695, -10707.733, -10752.143999999998, -10795.931999999999, -10839.101, -10881.652, -10923.589, -10964.915, -11005.632, -11045.743, -11085.251, -11124.158000000001, -11162.466999999999, -11200.181, -11237.301000000001, -11273.831, -11309.773000000001, -11345.128999999999, -11379.902, -11414.094, -11447.707, -11480.743999999999, -11513.206, -11545.096000000001, -11576.416000000001, -11607.168, -11637.354, -11666.976, -11696.037, -11724.537, -11752.48, -11779.867, -11806.698999999999, -11832.979, -11858.708999999999, -11883.889, -11908.523000000001, -11932.611, -11956.155, -11979.158000000001, -12001.62, -12023.544, -12044.931, -12065.782, -12086.098999999998, -12105.883, -12125.136, -12143.858999999999, -12162.053999999998, -12179.722, -12196.865, -12213.483, -12229.579, -12245.153, -12260.207, -12274.742, -12288.758, -12302.258, -12315.243, -12327.713, -12339.67, -12351.115, -12362.048, -12372.472, -12382.386999999999, -12391.794, -12400.695, -12409.089, -12416.978000000001, -12424.362, -12431.243999999999, -12437.623, -12443.501, -12448.878999999999, -12453.756000000001, -12458.135, -12462.015, -12465.399, -12468.285, -12470.676000000001, -12472.571000000002, -12473.972, -12474.878999999999, -12475.292, -12475.214, -12474.643, -12473.58, -12472.027, -12469.983999999999, -12467.451000000001, -12464.43, -12460.919, -12456.92, -12452.433, -12447.458999999999, -12441.999, -12436.051000000001, -12429.618, -12422.698999999999, -12415.295, -12407.406, -12399.032, -12390.175, -12380.833, -12371.008, -12360.698, -12349.906, -12338.631000000001, -12326.872, -12314.632, -12301.908000000001, -12288.703000000001, -12275.015, -12260.846000000001, -12246.195, -12231.062, -12215.447, -12199.35, -12182.771999999999, -12165.712, -12148.17, -12130.146999999999, -12111.642, -12092.656, -12073.187, -12053.237, -12032.805, -12011.892, -11990.496000000001, -11968.618, -11946.257, -11923.413, -11900.087, -11876.277, -11851.985, -11827.208999999999, -11801.948999999999, -11776.205, -11749.976999999999, -11723.264, -11696.067, -11668.383999999998, -11640.215, -11611.56, -11582.419, -11552.791000000001, -11522.675, -11492.072, -11460.981000000002, -11429.401000000002, -11397.332, -11364.773000000001, -11331.725, -11298.185, -11264.153999999999, -11229.631000000001, -11194.615, -11159.106000000002, -11123.103000000001, -11086.606000000002, -11049.614, -11012.126, -10974.142, -10935.66, -10896.681, -10857.202, -10817.223999999998, -10776.745, -10735.765, -10694.284, -10652.298999999999, -10609.81, -10566.817, -10523.318000000001, -10479.313, -10434.8, -10389.779, -10344.248, -10298.207, -10251.654, -10204.588, -10157.009, -10108.915, -10060.305, -10011.178, -9961.533000000001, -9911.368, -9860.684000000001, -9809.476999999999, -9757.747, -9705.493, -9652.713, -9599.405999999999, -9545.572, -9491.207, -9436.312, -9380.884, -9324.923, -9268.427, -9211.394, -9153.823, -9095.712, -9037.06, -8977.866, -8918.127, -8857.843, -8797.011, -8735.63, -8673.699, -8611.215, -8548.178, -8484.585, -8420.434000000001, -8355.724, -8290.453000000001, -8224.619, -8158.221, -8091.255999999999, -8023.723000000001, -7955.62, -7886.946, -7817.696999999999, -7747.8730000000005, -7677.47, -7606.488, -7534.924, -7462.776, -7390.043000000001, -7316.722, -7242.811, -7168.309, -7093.213000000001, -7017.521, -6941.23, -6864.34, -6786.847, -6708.75, -6630.047, -6550.735, -6470.813, -6390.278, -6309.129, -6227.363, -6144.977, -6061.97, -5978.340999999999, -5894.085999999999, -5809.204000000001, -5723.693, -5637.552, -5550.776999999999, -5463.368, -5375.321999999999, -5286.638000000001, -5197.313, -5107.346, -5016.737, -4925.482, -4833.581, -4741.032999999999, -4647.835999999999, -4553.9890000000005, -4459.491, -4364.340999999999, -4268.539000000001, -4172.085, -4074.9770000000003, -3977.215, -3878.801, -3779.735, -3680.015, -3579.645, -3478.6240000000003, -3376.955, -3274.64, -3171.68, -3068.079, -2963.84, -2858.967, -2753.4640000000004, -2647.337, -2540.589, -2433.23, -2325.265, -2216.702, -2107.552, -1997.8239999999998, -1887.529, -1776.681, -1665.293, -1553.38, -1440.961, -1328.0520000000001, -1214.677, -1100.858, -986.62, -871.992, -757.005, -641.692, -526.092, -410.246, -294.2, -178.00400000000002, -61.711999999999996, 54.614, 170.907, 287.093, 403.092, 518.815, 634.1619999999999, 749.0269999999999, 863.291, 976.822, 1089.478, 1201.1, 1311.515, 1420.533, 1527.944, 1633.521, 1737.0120000000002, 1838.146, 1936.6270000000002, 2032.129, 2124.3070000000002, 2212.783, 2297.155, 2376.994, 2451.846, 2521.235, 2584.667, 2641.636, 2691.631, 2734.1440000000002, 2768.6809999999996, 2794.777, 2812.008, 2820.002, 2818.458, 2807.156, 2785.965, 2754.857, 2713.9040000000005, 2663.278, 2603.2529999999997, 2534.187, 2456.518, 2370.743, 2277.407, 2177.0879999999997, 2070.377, 1957.87, 1840.155, 1717.8029999999999, 1591.358, 1461.338, 1328.224, 1192.4660000000001, 1054.476, 914.6310000000001, 773.2760000000001, 630.719, 487.24300000000005, 343.098, 198.51, 53.68, -91.212, -236.00799999999998, -380.56699999999995, -524.764, -668.488, -811.643, -954.143, -1095.914, -1236.891, -1377.015, -1516.239, -1654.5179999999998, -1791.816, -1928.101, -2063.347, -2197.529, -2330.63, -2462.633, -2593.526, -2723.298, -2851.941, -2979.449, -3105.817, -3231.0440000000003, -3355.1290000000004, -3478.071, -3599.8709999999996, -3720.532, -3840.0570000000002, -3958.45, -4075.716, -4191.858, -4306.884, -4420.798, -4533.607, -4645.319, -4755.941, -4865.478, -4973.939, -5081.332, -5187.663, -5292.943, -5397.177, -5500.3730000000005, -5602.541, -5703.688, -5803.821999999999, -5902.951999999999, -6001.084, -6098.228, -6194.39, -6289.58, -6383.805, -6477.0740000000005, -6569.393, -6660.77, -6751.2119999999995, -6840.728, -6929.326, -7017.0109999999995, -7103.793000000001, -7189.6759999999995, -7274.67, -7358.78, -7442.014, -7524.379, -7605.882, -7686.528, -7766.325, -7845.278, -7923.395, -8000.682, -8077.144, -8152.789000000001, -8227.622, -8301.648000000001, -8374.873, -8447.304, -8518.946, -8589.804, -8659.885, -8729.193000000001, -8797.734, -8865.513, -8932.534, -8998.804, -9064.327, -9129.107, -9193.151, -9256.462, -9319.046, -9380.905999999999, -9442.048, -9502.475, -9562.192, -9621.204, -9679.515, -9737.129, -9794.05, -9850.282, -9905.829, -9960.695, -10014.884, -10068.399, -10121.245, -10173.425, -10224.943000000001, -10275.802, -10326.006, -10375.558, -10424.461, -10472.72, -10520.336000000001, -10567.313999999998, -10613.657, -10659.368, -10704.45, -10748.905, -10792.738000000001, -10835.95, -10878.545, -10920.526000000002, -10961.895, -11002.655, -11042.809, -11082.36, -11121.31, -11159.662, -11197.418, -11234.581, -11271.153, -11307.136999999999, -11342.535, -11377.348999999998, -11411.583, -11445.237, -11478.315, -11510.819, -11542.75, -11574.111, -11604.903, -11635.13, -11664.793, -11693.893, -11722.434, -11750.417, -11777.844, -11804.716, -11831.036, -11856.805, -11882.025, -11906.698, -11930.825, -11954.409, -11977.45, -11999.951000000001, -12021.913999999999, -12043.339, -12064.229, -12084.583999999999, -12104.407, -12123.698, -12142.458999999999, -12160.692, -12178.398000000001, -12195.578000000001, -12212.233999999999, -12228.367, -12243.979, -12259.07, -12273.642, -12287.696000000002, -12301.233, -12314.253999999999, -12326.761, -12338.753999999999, -12350.236, -12361.206, -12371.666000000001, -12381.617, -12391.06, -12399.997, -12408.427, -12416.351999999999, -12423.771999999999, -12430.69, -12437.105, -12443.018, -12448.431, -12453.344, -12457.757, -12461.673, -12465.091, -12468.013, -12470.438999999998, -12472.368999999999, -12473.803999999998, -12474.745, -12475.194, -12475.149, -12474.613000000001, -12473.585, -12472.066, -12470.056, -12467.558, -12464.57, -12461.093, -12457.128, -12452.675, -12447.735, -12442.306999999999, -12436.393999999998, -12429.993999999999, -12423.108, -12415.737, -12407.881000000001, -12399.541000000001, -12390.716, -12381.408000000001, -12371.615, -12361.338, -12350.579, -12339.336000000001, -12327.61, -12315.402, -12302.711000000001, -12289.538, -12275.883, -12261.745, -12247.126, -12232.026000000002, -12216.443000000001, -12200.378, -12183.831, -12166.803, -12149.293, -12131.302, -12112.829, -12093.874, -12074.437, -12054.518999999998, -12034.118999999999, -12013.236, -11991.871000000001, -11970.024, -11947.694, -11924.882, -11901.586000000001, -11877.808, -11853.546999999999, -11828.802, -11803.573, -11777.86, -11751.662, -11724.98, -11697.812, -11670.16, -11642.021, -11613.396999999999, -11584.286, -11554.688, -11524.603000000001, -11494.031, -11462.97, -11431.42, -11399.381000000001, -11366.851999999999, -11333.833, -11300.323, -11266.321000000002, -11231.828000000001, -11196.841999999999, -11161.363000000001, -11125.39, -11088.923, -11051.961000000001, -11014.502, -10976.546999999999, -10938.095, -10899.143999999998, -10859.695, -10819.746000000001, -10779.296999999999, -10738.347, -10696.893999999998, -10654.938999999998, -10612.479, -10569.515, -10526.045, -10482.069, -10437.585, -10392.591999999999, -10347.09, -10301.077, -10254.553, -10207.517, -10159.966999999999, -10111.902, -10063.32, -10014.222, -9964.605, -9914.469000000001, -9863.813, -9812.634, -9760.933, -9708.707, -9655.956, -9602.678, -9548.872, -9494.536, -9439.669, -9384.269, -9328.336, -9271.868, -9214.863000000001, -9157.32, -9099.238000000001, -9040.614, -8981.448, -8921.737, -8861.481, -8800.677, -8739.325, -8677.421, -8614.965, -8551.955, -8488.39, -8424.268, -8359.586, -8294.343, -8228.537, -8162.166, -8095.229, -8027.724, -7959.649, -7891.0019999999995, -7821.781999999999, -7751.985, -7681.61, -7610.655, -7539.119000000001, -7466.999, -7394.294, -7321.0, -7247.116999999999, -7172.642, -7097.5740000000005, -7021.909000000001, -6945.646, -6868.783, -6791.318, -6713.249, -6634.573, -6555.289000000001, -6475.394, -6394.8859999999995, -6313.765, -6232.025, -6149.6669999999995, -6066.688, -5983.085999999999, -5898.858, -5814.004, -5728.52, -5642.406, -5555.659000000001, -5468.276, -5380.257, -5291.599, -5202.302, -5112.362, -5021.779, -4930.5509999999995, -4838.678, -4746.156, -4652.985, -4559.164000000001, -4464.693, -4369.569, -4273.793, -4177.365, -4080.283, -3982.548, -3884.159, -3785.117, -3685.423, -3585.078, -3484.0820000000003, -3382.437, -3280.147, -3177.212, -3073.634, -2969.4190000000003, -2864.5690000000004, -2759.0879999999997, -2652.9829999999997, -2546.258, -2438.919, -2330.975, -2222.4339999999997, -2113.304, -2003.595, -1893.318, -1782.487, -1671.116, -1559.219, -1446.8129999999999, -1333.9189999999999, -1220.556, -1106.748, -992.5210000000001, -877.9010000000001, -762.92, -647.613, -532.015, -416.17, -300.121, -183.92, -67.62, 48.716, 165.024, 281.22900000000004, 397.251, 513.001, 628.381, 743.285, 857.5930000000001, 971.176, 1083.891, 1195.58, 1306.0710000000001, 1415.175, 1522.684, 1628.369, 1731.984, 1833.256, 1931.889, 2027.5620000000001, 2119.928, 2208.612, 2293.215, 2373.3070000000002, 2448.437, 2518.13, 2581.8920000000003, 2639.219, 2689.6, 2732.525, 2767.502, 2794.0640000000003, 2811.784, 2820.2859999999996, 2819.2690000000002, 2808.505, 2787.861, 2757.301, 2716.893, 2666.8059999999996, 2607.304, 2538.745, 2461.56, 2376.243, 2283.3379999999997, 2183.4210000000003, 2077.08, 1964.912, 1847.506, 1725.432, 1599.237, 1469.4389999999999, 1336.5220000000002, 1200.937, 1063.097, 923.3810000000001, 782.135, 639.673, 496.273, 352.191, 207.65200000000002, 62.86, -82.005, -226.78400000000002, -371.334, -515.53, -659.26, -802.427, -944.946, -1086.74, -1228.008, -1367.9, -1507.1589999999999, -1645.476, -1782.816, -1919.146, -2054.438, -2188.669, -2321.82, -2453.875, -2584.821, -2714.6479999999997, -2843.347, -2970.9109999999996, -3097.3379999999997, -3222.6240000000003, -3346.7670000000003, -3469.7690000000002, -3591.6290000000004, -3712.35, -3831.937, -3950.3909999999996, -4067.718, -4183.920999999999, -4299.009, -4412.985, -4525.857, -4637.63, -4748.313, -4857.912, -4966.436, -5073.89, -5180.282999999999, -5285.6230000000005, -5389.918000000001, -5493.177, -5595.406, -5696.613, -5796.808000000001, -5895.996999999999, -5994.19, -6091.394, -6187.616999999999, -6282.866, -6377.151, -6470.478, -6562.855, -6654.291, -6744.7919999999995, -6834.366999999999, -6923.022, -7010.764, -7097.603, -7183.544, -7268.595, -7352.762, -7436.052, -7518.473000000001, -7600.031, -7680.733, -7760.585, -7839.594, -7917.766, -7995.107, -8071.624, -8147.321999999999, -8222.209, -8296.289, -8369.567, -8442.051, -8513.746, -8584.657, -8654.79, -8724.151, -8792.744, -8860.574, -8927.646999999999, -8993.968, -9059.541, -9124.373, -9188.468, -9251.829, -9314.463, -9376.373, -9437.564, -9498.041, -9557.806999999999, -9616.869, -9675.229, -9732.892, -9789.860999999999, -9846.141, -9901.735999999999, -9956.649, -10010.886, -10064.449, -10117.343, -10169.57, -10221.134, -10272.04, -10322.29, -10371.888, -10420.838, -10469.142, -10516.805, -10563.829, -10610.218, -10655.973999999998, -10701.1, -10745.601, -10789.478000000001, -10832.733999999999, -10875.374, -10917.399, -10958.813, -10999.617, -11039.815, -11079.409, -11118.403, -11156.798, -11194.597, -11231.803, -11268.419, -11304.445, -11339.886, -11374.743, -11409.018999999998, -11442.715, -11475.835, -11508.38, -11540.353000000001, -11571.755, -11602.59, -11632.858, -11662.562, -11691.704, -11720.286, -11748.309, -11775.776000000002, -11802.688999999998, -11829.048999999999, -11854.858, -11880.118, -11904.831, -11928.999, -11952.623, -11975.704, -11998.243999999999, -12020.246000000001, -12041.71, -12062.639, -12083.033000000001, -12102.895, -12122.225, -12141.025, -12159.296999999999, -12177.041000000001, -12194.26, -12210.954, -12227.125, -12242.774, -12257.903, -12272.513, -12286.605, -12300.18, -12313.239, -12325.783000000001, -12337.813999999998, -12349.332, -12360.339, -12370.837, -12380.823999999999, -12390.303999999998, -12399.277, -12407.743999999999, -12415.705, -12423.163, -12430.116000000002, -12436.567, -12442.517, -12447.966, -12452.913999999999, -12457.364, -12461.315, -12464.768999999998, -12467.726999999999, -12470.188, -12472.153, -12473.624, -12474.6, -12475.083, -12475.073999999999, -12474.572, -12473.579, -12472.095, -12470.12, -12467.656, -12464.703000000001, -12461.261, -12457.33, -12452.911, -12448.005, -12442.612, -12436.732, -12430.366000000002, -12423.514, -12416.178, -12408.356000000002, -12400.048999999999, -12391.258, -12381.982, -12372.223, -12361.98, -12351.253, -12340.044, -12328.351, -12316.176000000001, -12303.518, -12290.378, -12276.756000000001, -12262.652, -12248.065, -12232.996000000001, -12217.446000000002, -12201.413999999999, -12184.9, -12167.903999999999, -12150.426000000001, -12132.466999999999, -12114.026000000002, -12095.103000000001, -12075.698999999999, -12055.812, -12035.444, -12014.593, -11993.26, -11971.444, -11949.146, -11926.365, -11903.101, -11879.355, -11855.125, -11830.411, -11805.213, -11779.532, -11753.365, -11726.714, -11699.578000000001, -11671.956, -11643.848999999998, -11615.255, -11586.175, -11556.608, -11526.553999999998, -11496.011999999999, -11464.982, -11433.463, -11401.454, -11368.956, -11335.966999999999, -11302.487, -11268.516000000001, -11234.053, -11199.098, -11163.649, -11127.706, -11091.268999999998, -11054.337, -11016.909, -10978.983, -10940.561000000002, -10901.64, -10862.221000000001, -10822.302, -10781.882, -10740.962, -10699.538999999999, -10657.613000000001, -10615.183, -10572.249, -10528.808, -10484.860999999999, -10440.407, -10395.444, -10349.971, -10303.988000000001, -10257.493, -10210.485, -10162.965, -10114.929, -10066.376, -10017.306999999999, -9967.72, -9917.613000000001, -9866.985, -9815.836, -9764.163, -9711.966, -9659.244, -9605.995, -9552.218, -9497.911, -9443.072, -9387.702, -9331.796999999999, -9275.358, -9218.381, -9160.867, -9102.814, -9044.219000000001, -8985.081, -8925.399, -8865.171, -8804.396, -8743.072, -8681.197, -8618.769, -8555.788, -8492.251, -8428.157, -8363.504, -8298.289, -8232.511, -8166.169, -8099.26, -8031.784000000001, -7963.736999999999, -7895.118, -7825.9259999999995, -7756.156999999999, -7685.81, -7614.884, -7543.376, -7471.284000000001, -7398.607, -7325.340999999999, -7251.486, -7177.04, -7101.999, -7026.363, -6950.128000000001, -6873.293000000001, -6795.856, -6717.814, -6639.1669999999995, -6559.91, -6480.043000000001, -6399.564, -6318.47, -6236.758000000001, -6154.428000000001, -6071.477, -5987.901999999999, -5903.701999999999, -5818.875, -5733.42, -5647.3330000000005, -5560.613, -5473.258000000001, -5385.267, -5296.637, -5207.366, -5117.454000000001, -5026.899, -4935.698, -4843.852, -4751.357, -4658.213, -4564.419, -4469.975, -4374.878, -4279.129, -4182.726, -4085.671, -3987.962, -3889.599, -3790.583, -3690.915, -3590.595, -3489.625, -3388.005, -3285.739, -3182.829, -3079.276, -2975.0840000000003, -2870.258, -2764.8, -2658.718, -2552.015, -2444.699, -2336.776, -2228.255, -2119.145, -2009.4560000000001, -1899.1979999999999, -1788.385, -1677.031, -1565.15, -1452.76, -1339.88, -1226.53, -1112.733, -998.5160000000001, -883.904, -768.931, -653.628, -538.033, -422.18800000000005, -306.137, -189.93099999999998, -73.624, 42.723, 159.045, 275.269, 391.31300000000005, 507.091, 622.504, 737.446, 851.8, 965.434, 1078.208, 1189.965, 1300.5330000000001, 1409.725, 1517.332, 1623.128, 1726.8670000000002, 1828.277, 1927.065, 2022.9089999999999, 2115.466, 2204.362, 2289.197, 2369.5460000000003, 2444.9570000000003, 2514.956, 2579.053, 2636.741, 2687.512, 2730.855, 2766.278, 2793.312, 2811.526, 2820.546, 2820.0609999999997, 2809.844, 2789.755, 2759.752, 2719.9, 2670.3590000000004, 2611.391, 2543.347, 2466.654, 2381.806, 2289.34, 2189.831, 2083.868, 1972.047, 1854.9560000000001, 1733.1670000000001, 1607.2279999999998, 1477.658, 1344.942, 1209.5330000000001, 1071.847, 932.2639999999999, 791.1310000000001, 648.764, 505.444, 361.426, 216.93900000000002, 72.186, -72.652, -217.412, -361.95300000000003, -506.147, -649.883, -793.062, -935.5989999999999, -1077.4160000000002, -1218.448, -1358.636, -1497.93, -1636.287, -1773.668, -1910.043, -2045.382, -2179.6620000000003, -2312.864, -2444.972, -2575.972, -2705.8540000000003, -2834.6090000000004, -2962.232, -3088.716, -3214.062, -3338.265, -3461.327, -3583.2490000000003, -3704.032, -3823.68, -3942.196, -4059.585, -4175.851, -4291.001, -4405.041, -4517.975, -4629.811, -4740.557, -4850.218, -4958.805, -5066.322, -5172.777, -5278.18, -5382.536999999999, -5485.857, -5588.148, -5689.418000000001, -5789.674, -5888.925, -5987.179, -6084.444, -6180.727, -6276.036999999999, -6370.380999999999, -6463.768, -6556.206, -6647.701, -6738.262, -6827.895, -6916.609, -7004.41, -7091.307, -7177.306, -7262.414000000001, -7346.639, -7429.986, -7512.464, -7594.079000000001, -7674.838000000001, -7754.746, -7833.811, -7912.0380000000005, -7989.435, -8066.005999999999, -8141.76, -8216.701, -8290.835, -8364.168, -8436.706, -8508.455, -8579.419, -8649.605, -8719.019, -8787.665, -8855.546999999999, -8922.673, -8989.046, -9054.671, -9119.554, -9183.7, -9247.113000000001, -9309.798, -9371.758, -9433.0, -9493.527, -9553.344000000001, -9612.455, -9670.865, -9728.577, -9785.595, -9841.924, -9897.568000000001, -9952.530999999999, -10006.815999999999, -10060.427, -10113.369, -10165.644, -10217.256, -10268.209, -10318.506, -10368.151, -10417.148000000001, -10465.499, -10513.208999999999, -10560.278999999999, -10606.714, -10652.516000000001, -10697.688, -10742.233999999999, -10786.157, -10829.458999999999, -10872.143, -10914.214, -10955.671999999999, -10996.521, -11036.764, -11076.402, -11115.44, -11153.878999999999, -11191.722, -11228.972, -11265.631000000001, -11301.701000000001, -11337.185, -11372.085, -11406.403999999999, -11440.143, -11473.306, -11505.893, -11537.908000000001, -11569.353000000001, -11600.23, -11630.54, -11660.286, -11689.469, -11718.093, -11746.157, -11773.666000000001, -11800.62, -11827.021, -11852.871000000001, -11878.171999999999, -11902.926000000001, -11927.133999999998, -11950.798, -11973.919, -11996.5, -12018.542, -12040.046, -12061.014, -12081.448, -12101.35, -12120.719, -12139.559, -12157.868999999999, -12175.653, -12192.911, -12209.643999999998, -12225.854, -12241.541000000001, -12256.708999999999, -12271.357, -12285.487, -12299.1, -12312.197, -12324.778999999999, -12336.848, -12348.403999999999, -12359.448999999999, -12369.983999999999, -12380.008999999998, -12389.527, -12398.536, -12407.04, -12415.038999999999, -12422.533000000001, -12429.524, -12436.011999999999, -12441.998, -12447.483, -12452.469, -12456.955, -12460.942, -12464.431999999999, -12467.426000000001, -12469.923, -12471.923999999999, -12473.431, -12474.443000000001, -12474.962, -12474.988000000001, -12474.521999999999, -12473.563999999998, -12472.115, -12470.176000000001, -12467.747, -12464.829, -12461.421999999999, -12457.526000000002, -12453.142, -12448.27, -12442.912, -12437.067, -12430.735, -12423.918, -12416.615, -12408.828000000001, -12400.555, -12391.798, -12382.556, -12372.831, -12362.622, -12351.928999999998, -12340.753, -12329.095, -12316.953000000001, -12304.329, -12291.222, -12277.633, -12263.562, -12249.008999999998, -12233.973, -12218.456, -12202.457, -12185.976, -12169.013, -12151.568000000001, -12133.641000000001, -12115.233, -12096.343, -12076.971000000001, -12057.117, -12036.781, -12015.963, -11994.662, -11972.878999999999, -11950.613000000001, -11927.864, -11904.632, -11880.917, -11856.719, -11832.038, -11806.872, -11781.222, -11755.087, -11728.468, -11701.363000000001, -11673.773000000001, -11645.697, -11617.135, -11588.086000000001, -11558.551000000001, -11528.528, -11498.017, -11467.018, -11435.53, -11403.552, -11371.085, -11338.127, -11304.678999999998, -11270.738000000001, -11236.306, -11201.381000000001, -11165.963, -11130.051000000001, -11093.645, -11056.743, -11019.345, -10981.451000000001, -10943.059, -10904.168, -10864.778999999999, -10824.891000000001, -10784.501, -10743.612, -10702.219, -10660.323, -10617.923999999999, -10575.018999999998, -10531.608999999999, -10487.692, -10443.267, -10398.334, -10352.891, -10306.938, -10260.473, -10213.495, -10166.004, -10117.998, -10069.476, -10020.436, -9970.878, -9920.801, -9870.203000000001, -9819.083, -9767.44, -9715.273000000001, -9662.58, -9609.36, -9555.612, -9501.334, -9446.525, -9391.184000000001, -9335.308, -9278.898000000001, -9221.952, -9164.466999999999, -9106.442, -9047.876, -8988.767, -8929.114, -8868.916, -8808.169, -8746.874, -8685.028, -8622.63, -8559.678, -8496.17, -8432.104, -8367.48, -8302.294, -8236.545, -8170.232, -8103.352, -8035.904, -7967.887, -7899.295999999999, -7830.132, -7760.392, -7690.0740000000005, -7619.177, -7547.696999999999, -7475.634, -7402.986, -7329.75, -7255.923000000001, -7181.505, -7106.493, -7030.884, -6954.678000000001, -6877.871999999999, -6800.464, -6722.451, -6643.831999999999, -6564.604, -6484.765, -6404.314, -6323.2480000000005, -6241.565, -6159.264, -6076.340999999999, -5992.795, -5908.6230000000005, -5823.825, -5738.397, -5652.338000000001, -5565.646, -5478.32, -5390.357, -5301.755, -5212.512, -5122.628, -5032.1, -4940.927, -4849.108, -4756.641, -4663.525, -4569.759, -4475.342000000001, -4380.272, -4284.55, -4188.175, -4091.1459999999997, -3993.4640000000004, -3895.1279999999997, -3796.139, -3696.4970000000003, -3596.203, -3495.258, -3393.664, -3291.4240000000004, -3188.538, -3085.01, -2980.843, -2876.0409999999997, -2770.607, -2664.548, -2557.868, -2450.575, -2342.674, -2234.174, -2125.085, -2015.415, -1905.1770000000001, -1794.3829999999998, -1683.046, -1571.182, -1458.808, -1345.942, -1232.606, -1118.8210000000001, -1004.613, -890.0110000000001, -775.044, -659.7460000000001, -544.155, -428.31, -312.258, -196.047, -79.733, 36.625, 152.96200000000002, 269.204, 385.27099999999996, 501.07599999999996, 616.5219999999999, 731.503, 845.9010000000001, 959.5880000000001, 1072.422, 1184.248, 1294.893, 1404.172, 1511.879, 1617.787, 1721.651, 1823.201, 1922.145, 2018.164, 2110.9139999999998, 2200.0229999999997, 2285.094, 2365.702, 2441.3979999999997, 2511.709, 2576.144, 2634.2, 2685.366, 2729.134, 2765.009, 2792.5209999999997, 2811.239, 2820.784, 2820.842, 2811.1809999999996, 2791.656, 2762.223, 2722.935, 2673.952, 2615.529, 2548.011, 2471.823, 2387.452, 2295.436, 2196.345, 2090.77, 1979.3039999999999, 1862.537, 1741.04, 1615.3629999999998, 1486.026, 1353.5179999999998, 1218.29, 1080.763, 941.316, 800.3, 658.0319999999999, 514.793, 370.842, 226.408, 81.696, -63.111999999999995, -207.85299999999998, -352.38300000000004, -496.575, -640.316, -783.508, -926.062, -1067.903, -1208.962, -1349.182, -1488.5120000000002, -1626.908, -1764.3329999999999, -1900.7520000000002, -2036.139, -2170.469, -2303.723, -2435.885, -2566.94, -2696.8779999999997, -2825.69, -2953.3720000000003, -3079.9159999999997, -3205.321, -3329.585, -3452.71, -3574.6929999999998, -3695.539, -3815.2490000000003, -3933.829, -4051.281, -4167.612, -4282.825, -4396.928, -4509.9259999999995, -4621.827, -4732.6359999999995, -4842.362, -4951.0109999999995, -5058.593, -5165.112, -5270.578, -5374.999, -5478.382, -5580.736999999999, -5682.069, -5782.388000000001, -5881.701, -5980.017, -6077.344, -6173.69, -6269.061, -6363.467, -6456.916, -6549.414000000001, -6640.97, -6731.59, -6821.284000000001, -6910.057, -6997.919, -7084.875, -7170.933000000001, -7256.1, -7340.383000000001, -7423.789000000001, -7506.326, -7587.9980000000005, -7668.814, -7748.779, -7827.901, -7906.185, -7983.639, -8060.267, -8136.076999999999, -8211.073, -8285.263, -8358.651, -8431.245, -8503.048, -8574.067, -8644.306999999999, -8713.775, -8782.474, -8850.41, -8917.589, -8984.015, -9049.694, -9114.629, -9178.827, -9242.292, -9305.029, -9367.042, -9428.335, -9488.913, -9548.780999999999, -9607.943000000001, -9666.403, -9724.165, -9781.234, -9837.614, -9893.306999999999, -9948.319, -10002.653, -10056.314, -10109.304, -10161.628, -10213.289, -10264.291, -10314.636, -10364.33, -10413.374, -10461.773000000001, -10509.53, -10556.648000000001, -10603.128999999999, -10648.978000000001, -10694.197, -10738.79, -10782.758999999998, -10826.107, -10868.838, -10910.955, -10952.458, -10993.353000000001, -11033.64, -11073.323999999999, -11112.407, -11150.891000000001, -11188.778999999999, -11226.073999999999, -11262.777, -11298.891000000001, -11334.419, -11369.363000000001, -11403.726, -11437.508999999998, -11470.715, -11503.347, -11535.405, -11566.893, -11597.812, -11628.165, -11657.953000000001, -11687.178999999998, -11715.845, -11743.952, -11771.503, -11798.499, -11824.942, -11850.833999999999, -11876.176000000001, -11900.971000000001, -11925.22, -11948.926000000001, -11972.088, -11994.71, -12016.793, -12038.338, -12059.347, -12079.821000000002, -12099.763, -12119.171999999999, -12138.052, -12156.402, -12174.226, -12191.524, -12208.296999999999, -12224.546, -12240.273000000001, -12255.48, -12270.167, -12284.336000000001, -12297.988000000001, -12311.124, -12323.745, -12335.853000000001, -12347.447, -12358.531, -12369.104, -12379.167, -12388.723, -12397.771, -12406.312, -12414.348999999998, -12421.881000000001, -12428.909, -12435.434, -12441.458, -12446.981000000002, -12452.003, -12456.526000000002, -12460.551000000001, -12464.078000000001, -12467.108, -12469.642, -12471.68, -12473.223, -12474.271999999999, -12474.827, -12474.89, -12474.46, -12473.538, -12472.125, -12470.222, -12467.829, -12464.946000000002, -12461.575, -12457.714, -12453.366000000002, -12448.53, -12443.207, -12437.396999999999, -12431.101, -12424.318000000001, -12417.051000000001, -12409.298, -12401.061000000002, -12392.338, -12383.131000000001, -12373.44, -12363.266000000001, -12352.608, -12341.466, -12329.841999999999, -12317.735, -12305.145, -12292.073, -12278.518, -12264.48, -12249.961000000001, -12234.958999999999, -12219.475, -12203.51, -12187.062, -12170.133, -12152.722, -12134.83, -12116.455, -12097.598, -12078.258999999998, -12058.438, -12038.133999999998, -12017.348999999998, -11996.081, -11974.331, -11952.098, -11929.383, -11906.184, -11882.501, -11858.335, -11833.686000000002, -11808.552, -11782.935, -11756.832, -11730.246000000001, -11703.173999999999, -11675.616000000002, -11647.572, -11619.042, -11590.026000000002, -11560.521999999999, -11530.531, -11500.051000000001, -11469.083999999999, -11437.627, -11405.681, -11373.246000000001, -11340.32, -11306.903, -11272.995, -11238.594, -11203.701000000001, -11168.313999999998, -11132.433, -11096.056999999999, -11059.187, -11021.82, -10983.957, -10945.596000000001, -10906.737, -10867.378999999999, -10827.521, -10787.163, -10746.303, -10704.941, -10663.076000000001, -10620.707, -10577.833999999999, -10534.454, -10490.567, -10446.173, -10401.271, -10355.858, -10309.935, -10263.501, -10216.554, -10169.093, -10121.117, -10072.625, -10023.615, -9974.088, -9924.04, -9873.472, -9822.383, -9770.77, -9718.633, -9665.97, -9612.78, -9559.062, -9504.814, -9450.035, -9394.723, -9338.878, -9282.498, -9225.581, -9168.126, -9110.131, -9051.594000000001, -8992.515, -8932.892, -8872.723, -8812.006, -8750.74, -8688.924, -8626.555, -8563.633, -8500.155, -8436.119, -8371.523000000001, -8306.367, -8240.648000000001, -8174.3640000000005, -8107.513000000001, -8040.095, -7972.107, -7903.545999999999, -7834.411, -7764.7, -7694.411999999999, -7623.543000000001, -7552.093000000001, -7480.06, -7407.441, -7334.233, -7260.436, -7186.047, -7111.064, -7035.485, -6959.308000000001, -6882.531, -6805.151999999999, -6727.168000000001, -6648.578, -6569.379, -6489.57, -6409.147, -6328.11, -6246.456999999999, -6164.184, -6081.29, -5997.773, -5913.63, -5828.86, -5743.460999999999, -5657.431, -5570.769, -5483.471, -5395.536, -5306.963000000001, -5217.749, -5127.893, -5037.394, -4946.249, -4854.458, -4762.019, -4668.932, -4575.194, -4480.804, -4385.763, -4290.068, -4193.721, -4096.719, -3999.065, -3900.756, -3801.7940000000003, -3702.178, -3601.9109999999996, -3500.993, -3399.425, -3297.211, -3194.3509999999997, -3090.848, -2986.7059999999997, -2881.928, -2776.5190000000002, -2670.4840000000004, -2563.828, -2456.5570000000002, -2348.679, -2240.201, -2131.133, -2021.484, -1911.265, -1800.49, -1689.171, -1577.3239999999998, -1464.9660000000001, -1352.116, -1238.7930000000001, -1125.02, -1010.823, -896.23, -781.2710000000001, -665.9780000000001, -550.39, -434.54699999999997, -318.493, -202.278, -85.956, 30.413, 146.764, 263.024, 379.11400000000003, 494.94699999999995, 610.4259999999999, 725.446, 839.8889999999999, 953.6289999999999, 1066.5230000000001, 1178.4180000000001, 1289.143, 1398.511, 1506.318, 1612.339, 1716.33, 1818.0220000000002, 1917.124, 2013.319, 2106.265, 2195.59, 2280.9, 2361.771, 2437.755, 2508.382, 2573.161, 2631.5890000000004, 2683.156, 2727.355, 2763.69, 2791.688, 2810.9179999999997, 2820.9959999999996, 2821.6059999999998, 2812.511, 2793.562, 2764.7070000000003, 2725.9959999999996, 2677.5820000000003, 2619.714, 2552.734, 2477.061, 2393.179, 2301.6220000000003, 2202.96, 2097.782, 1986.68, 1870.244, 1749.047, 1623.639, 1494.543, 1362.247, 1227.2060000000001, 1089.8410000000001, 950.535, 809.64, 667.4730000000001, 524.319, 380.43699999999995, 236.058, 91.38799999999999, -53.388999999999996, -198.109, -342.62800000000004, -486.81699999999995, -630.563, -773.7660000000001, -916.3380000000001, -1058.202, -1199.3039999999999, -1339.5410000000002, -1478.908, -1617.344, -1754.8110000000001, -1891.276, -2026.711, -2161.091, -2294.3979999999997, -2426.614, -2557.725, -2687.72, -2816.592, -2944.333, -3070.937, -3196.4040000000005, -3320.73, -3443.917, -3565.9640000000004, -3686.873, -3806.6479999999997, -3925.2909999999997, -4042.808, -4159.2029999999995, -4274.482, -4388.649, -4501.713, -4613.679, -4724.554, -4834.344, -4943.059, -5050.705, -5157.29, -5262.82, -5367.306, -5470.753000000001, -5573.172, -5674.568, -5774.951, -5874.328, -5972.7080000000005, -6070.098000000001, -6166.505999999999, -6261.941, -6356.409000000001, -6449.92, -6542.481, -6634.098000000001, -6724.78, -6814.535, -6903.37, -6991.2919999999995, -7078.309, -7164.427, -7249.654, -7333.996, -7417.4619999999995, -7500.057, -7581.789000000001, -7662.664000000001, -7742.687, -7821.866999999999, -7900.209, -7977.721, -8054.406, -8130.273, -8205.326, -8279.572, -8353.017, -8425.667, -8497.526, -8568.6, -8638.896, -8708.418, -8777.171999999999, -8845.163, -8912.396999999999, -8978.877, -9044.609, -9109.598, -9173.85, -9237.368, -9300.158000000001, -9362.223, -9423.569, -9484.199, -9544.119, -9603.333, -9661.844000000001, -9719.658000000001, -9776.778, -9833.209, -9888.953000000001, -9944.016, -9998.4, -10052.110999999999, -10105.151, -10157.525, -10209.235, -10260.286, -10310.681, -10360.423, -10409.516, -10457.964, -10505.768999999998, -10552.935, -10599.465, -10645.362, -10690.628999999999, -10735.268999999998, -10779.285, -10822.681, -10865.458999999999, -10907.622, -10949.171999999999, -10990.113000000001, -11030.447, -11070.177, -11109.306, -11147.836000000001, -11185.768999999998, -11223.11, -11259.858, -11296.017, -11331.59, -11366.579, -11400.987, -11434.813999999998, -11468.065, -11500.741000000002, -11532.843, -11564.375, -11595.338, -11625.733999999999, -11655.566, -11684.836000000001, -11713.544, -11741.695, -11769.288, -11796.327, -11822.813, -11848.747, -11874.132, -11898.97, -11923.261, -11947.008, -11970.213, -11992.876, -12015.001, -12036.588, -12057.638, -12078.153, -12098.136, -12117.586000000001, -12136.507, -12154.898000000001, -12172.761999999999, -12190.101, -12206.913999999999, -12223.204, -12238.971000000001, -12254.218, -12268.945, -12283.153999999999, -12296.845, -12310.021, -12322.681999999999, -12334.829, -12346.463, -12357.586000000001, -12368.198, -12378.3, -12387.893999999998, -12396.981000000002, -12405.561000000002, -12413.636999999999, -12421.207, -12428.274, -12434.837, -12440.899, -12446.46, -12451.52, -12456.081, -12460.143, -12463.708, -12466.776000000002, -12469.347, -12471.423, -12473.003, -12474.089, -12474.681999999999, -12474.781, -12474.388, -12473.503, -12472.127, -12470.26, -12467.903999999999, -12465.058, -12461.723, -12457.899, -12453.587, -12448.787, -12443.5, -12437.726, -12431.465, -12424.719, -12417.487, -12409.77, -12401.568000000001, -12392.881000000001, -12383.71, -12374.053999999998, -12363.915, -12353.292, -12342.186000000002, -12330.596000000001, -12318.524, -12305.969, -12292.931999999999, -12279.411, -12265.409, -12250.923999999999, -12235.957, -12220.507, -12204.576000000001, -12188.163, -12171.268, -12153.891000000001, -12136.033000000001, -12117.692, -12098.868999999999, -12079.563999999998, -12059.776000000002, -12039.507, -12018.755, -11997.521, -11975.803999999998, -11953.605, -11930.923, -11907.757, -11884.108, -11859.976, -11835.36, -11810.258999999998, -11784.675, -11758.605, -11732.051000000001, -11705.011999999999, -11677.488000000001, -11649.476999999999, -11620.979, -11591.995, -11562.524, -11532.565, -11502.118999999999, -11471.184, -11439.76, -11407.846000000001, -11375.443000000001, -11342.548999999999, -11309.165, -11275.288, -11240.92, -11206.058, -11170.703000000001, -11134.854, -11098.511, -11061.671999999999, -11024.337, -10986.506000000001, -10948.177, -10909.348999999998, -10870.023000000001, -10830.196000000002, -10789.868999999999, -10749.041000000001, -10707.71, -10665.877, -10623.54, -10580.697, -10537.348999999998, -10493.493999999999, -10449.131, -10404.259, -10358.878, -10312.985999999999, -10266.583, -10219.666, -10172.237, -10124.292, -10075.83, -10026.851999999999, -9977.355, -9927.339, -9876.801, -9825.742, -9774.16, -9722.054, -9669.421999999999, -9616.263, -9562.576, -9508.358, -9453.61, -9398.329, -9342.514000000001, -9286.164, -9229.277, -9171.851999999999, -9113.888, -9055.382, -8996.333, -8936.74, -8876.601999999999, -8815.915, -8754.68, -8692.894, -8630.556, -8567.663, -8504.215, -8440.209, -8375.643, -8310.517, -8244.828000000001, -8178.5740000000005, -8111.755, -8044.366, -7976.406999999999, -7907.876, -7838.771, -7769.090999999999, -7698.831999999999, -7627.994000000001, -7556.5740000000005, -7484.57, -7411.981, -7338.803000000001, -7265.036, -7190.6759999999995, -7115.723000000001, -7040.174, -6964.026999999999, -6887.28, -6809.93, -6731.976, -6653.416, -6574.246, -6494.465999999999, -6414.0740000000005, -6333.066999999999, -6251.443, -6169.1990000000005, -6086.335, -6002.847, -5918.734, -5833.993, -5748.624, -5662.624, -5575.99, -5488.722, -5400.816, -5312.272, -5223.088, -5133.2609999999995, -5042.791, -4951.675, -4859.913, -4767.503, -4674.444, -4580.735, -4486.374, -4391.361, -4295.695, -4199.376, -4102.402, -4004.775, -3906.494, -3807.56, -3707.972, -3607.732, -3506.841, -3405.3, -3303.112, -3200.278, -3096.801, -2992.685, -2887.933, -2782.5490000000004, -2676.538, -2569.905, -2462.658, -2354.802, -2246.347, -2137.301, -2027.6729999999998, -1917.474, -1806.7179999999998, -1695.418, -1583.589, -1471.247, -1358.411, -1245.103, -1131.343, -1017.158, -902.574, -787.622, -672.336, -556.751, -440.909, -324.85400000000004, -208.635, -92.306, 24.074, 140.44, 256.719, 372.832, 488.69300000000004, 604.205, 719.265, 833.7539999999999, 947.547, 1060.503, 1172.468, 1283.272, 1392.73, 1500.639, 1606.774, 1710.894, 1812.729, 1911.9920000000002, 2008.365, 2101.509, 2191.055, 2276.607, 2357.745, 2434.021, 2504.967, 2570.095, 2628.901, 2680.8759999999997, 2725.512, 2762.313, 2790.8059999999996, 2810.5559999999996, 2821.176, 2822.348, 2813.829, 2795.465, 2767.2, 2729.077, 2681.243, 2623.9429999999998, 2557.511, 2482.363, 2398.981, 2307.895, 2209.6710000000003, 2104.897, 1994.1689999999999, 1878.0729999999999, 1757.183, 1632.0520000000001, 1503.201, 1371.124, 1236.275, 1099.077, 959.916, 819.145, 677.082, 534.015, 390.205, 245.88299999999998, 101.257, -43.488, -188.18599999999998, -332.69300000000004, -476.879, -620.629, -763.8430000000001, -906.432, -1048.318, -1189.434, -1329.72, -1469.1229999999998, -1607.599, -1745.109, -1881.621, -2017.105, -2151.536, -2284.896, -2417.167, -2548.335, -2678.388, -2807.3190000000004, -2935.119, -3061.7870000000003, -3187.315, -3311.705, -3434.954, -3557.066, -3678.04, -3797.88, -3916.5890000000004, -4034.172, -4150.633, -4265.977, -4380.210999999999, -4493.340999999999, -4605.373, -4716.314, -4826.170999999999, -4934.952, -5042.664000000001, -5149.314, -5254.911, -5359.4619999999995, -5462.976, -5565.459, -5666.920999999999, -5767.368, -5866.811, -5965.255, -6062.709, -6159.182, -6254.68, -6349.213000000001, -6442.786999999999, -6535.41, -6627.09, -6717.835, -6807.653, -6896.55, -6984.534000000001, -7071.611999999999, -7157.7919999999995, -7243.08, -7327.484, -7411.01, -7493.665, -7575.456, -7656.391, -7736.475, -7815.713000000001, -7894.1140000000005, -7971.684, -8048.428000000001, -8124.353, -8199.464, -8273.768, -8347.27, -8419.976, -8491.892, -8563.024, -8633.376, -8702.954, -8771.764000000001, -8839.81, -8907.099, -8973.635, -9039.421999999999, -9104.466, -9168.771999999999, -9232.344000000001, -9295.187, -9357.306, -9418.706, -9479.39, -9539.363000000001, -9598.629, -9657.194, -9715.06, -9772.232, -9828.714, -9884.51, -9939.624, -9994.06, -10047.822, -10100.913, -10153.338, -10205.098, -10256.199, -10306.644, -10356.436, -10405.58, -10454.077, -10501.931, -10549.146, -10595.725, -10641.67, -10686.985, -10731.673999999999, -10775.739, -10819.183, -10862.008999999998, -10904.219, -10945.817, -10986.805, -11027.186000000002, -11066.963, -11106.139, -11144.716, -11182.696000000002, -11220.082, -11256.877, -11293.082, -11328.701000000001, -11363.736, -11398.188999999998, -11432.062, -11465.358, -11498.078000000001, -11530.226, -11561.802, -11592.81, -11623.252, -11653.128, -11682.442, -11711.194, -11739.388, -11767.026000000002, -11794.108, -11820.636999999999, -11846.615, -11872.044, -11896.923999999999, -11921.258999999998, -11945.048999999999, -11968.296, -11991.002, -12013.168, -12034.796999999999, -12055.89, -12076.448, -12096.472, -12115.965, -12134.927, -12153.36, -12171.265, -12188.645, -12205.499, -12221.83, -12237.639, -12252.927, -12267.695, -12281.944, -12295.676000000001, -12308.892, -12321.593, -12333.78, -12345.454, -12356.617, -12367.268999999998, -12377.412, -12387.045, -12396.171999999999, -12404.791000000001, -12412.905, -12420.515, -12427.62, -12434.223999999998, -12440.325, -12445.923999999999, -12451.023000000001, -12455.623, -12459.723999999998, -12463.327, -12466.431999999999, -12469.042, -12471.156, -12472.774, -12473.899, -12474.528999999999, -12474.666000000001, -12474.311000000002, -12473.464, -12472.125, -12470.296, -12467.976999999999, -12465.168, -12461.87, -12458.083, -12453.808, -12449.045, -12443.794, -12438.056999999999, -12431.833999999999, -12425.124, -12417.928999999998, -12410.248, -12402.082, -12393.431, -12384.296, -12374.677, -12364.573, -12353.986, -12342.916000000001, -12331.363000000001, -12319.326000000001, -12306.806999999999, -12293.803999999998, -12280.319, -12266.351999999999, -12251.902, -12236.97, -12221.556999999999, -12205.661, -12189.283000000001, -12172.423, -12155.081, -12137.257, -12118.95, -12100.162, -12080.892, -12061.139, -12040.903999999999, -12020.187, -11998.988000000001, -11977.305, -11955.14, -11932.491000000002, -11909.36, -11885.745, -11861.646, -11837.063999999998, -11811.998, -11786.447, -11760.412, -11733.892, -11706.886, -11679.393999999998, -11651.417, -11622.953000000001, -11594.002, -11564.565, -11534.639, -11504.226, -11473.323999999999, -11441.934, -11410.053, -11377.683, -11344.822, -11311.47, -11277.626, -11243.291000000001, -11208.462, -11173.14, -11137.323999999999, -11101.013, -11064.206, -11026.903999999999, -10989.105, -10950.808, -10912.013, -10872.719, -10832.925, -10792.631000000001, -10751.833999999999, -10710.536, -10668.733999999999, -10626.428999999998, -10583.618, -10540.302, -10496.479, -10452.149, -10407.309000000001, -10361.959, -10316.099, -10269.726999999999, -10222.843, -10175.444, -10127.530999999999, -10079.101, -10030.155, -9980.69, -9930.705, -9880.199, -9829.171, -9777.621, -9725.545, -9672.944, -9619.815999999999, -9566.16, -9511.974, -9457.257, -9402.007, -9346.223, -9289.904, -9233.049, -9175.655, -9117.722, -9059.247, -9000.23, -8940.668, -8880.56, -8819.904, -8758.7, -8696.945, -8634.638, -8571.776, -8508.358, -8444.383, -8379.849, -8314.753, -8249.095, -8182.871999999999, -8116.0830000000005, -8048.725, -7980.797, -7912.297, -7843.223000000001, -7773.571999999999, -7703.344, -7632.536999999999, -7561.148, -7489.175, -7416.616, -7343.469, -7269.732, -7195.403, -7120.48, -7044.9619999999995, -6968.845, -6892.129, -6814.809, -6736.8859999999995, -6658.356, -6579.217, -6499.467, -6419.105, -6338.129, -6256.535, -6174.321999999999, -6091.486999999999, -6008.03, -5923.946999999999, -5839.236999999999, -5753.898, -5667.928000000001, -5581.3240000000005, -5494.085, -5406.21, -5317.695, -5228.541, -5138.745, -5048.304, -4957.219, -4865.486, -4773.106, -4680.076, -4586.396, -4492.065, -4397.081, -4301.444, -4205.154, -4108.209, -4010.611, -3912.3579999999997, -3813.452, -3713.893, -3613.6809999999996, -3512.817, -3411.304, -3309.143, -3206.336, -3102.886, -2998.796, -2894.07, -2788.711, -2682.725, -2576.117, -2468.894, -2361.062, -2252.63, -2143.606, -2034.0, -1923.8220000000001, -1813.086, -1701.805, -1589.994, -1477.6689999999999, -1364.849, -1251.555, -1137.809, -1023.635, -909.061, -794.118, -678.837, -563.257, -447.416, -331.36, -215.137, -98.8, 17.59, 133.97, 250.268, 366.404, 482.293, 597.84, 712.938, 827.475, 941.322, 1054.34, 1166.375, 1277.26, 1386.81, 1494.8220000000001, 1601.0739999999998, 1705.3239999999998, 1807.305, 1906.731, 2003.286, 2096.631, 2186.4, 2272.199, 2353.6079999999997, 2430.1820000000002, 2501.4539999999997, 2566.936, 2626.127, 2678.5170000000003, 2723.599, 2760.875, 2789.873, 2810.152, 2821.3259999999996, 2823.072, 2815.1420000000003, 2797.377, 2769.7140000000004, 2732.192, 2684.952, 2628.2329999999997, 2562.364, 2487.756, 2404.886, 2314.283, 2216.51, 2112.153, 2001.808, 1886.0610000000001, 1765.489, 1640.642, 1512.045, 1380.193, 1245.542, 1108.517, 969.505, 828.862, 686.9069999999999, 543.931, 400.195, 255.93200000000002, 111.352, -33.359, -178.03400000000002, -322.528, -466.71, -610.4630000000001, -753.688, -896.295, -1038.204, -1179.348, -1319.6670000000001, -1459.1070000000002, -1597.624, -1735.1779999999999, -1871.737, -2007.271, -2141.755, -2275.169, -2407.495, -2538.722, -2668.8340000000003, -2797.825, -2925.688, -3052.4179999999997, -3178.01, -3302.4640000000004, -3425.778, -3547.9559999999997, -3668.9959999999996, -3788.902, -3907.678, -4025.328, -4141.856, -4257.268, -4371.57, -4484.768, -4596.867, -4707.876, -4817.8, -4926.649, -5034.429, -5141.146, -5246.81, -5351.429, -5455.01, -5557.56, -5659.088000000001, -5759.602, -5859.111, -5957.621999999999, -6055.142, -6151.679, -6247.243, -6341.840999999999, -6435.48, -6528.168000000001, -6619.9130000000005, -6710.722, -6800.603, -6889.564, -6977.611, -7064.7519999999995, -7150.994000000001, -7236.345, -7320.811, -7404.399, -7487.116, -7568.969, -7649.964, -7730.109, -7809.408, -7887.869000000001, -7965.499, -8042.303000000001, -8118.286999999999, -8193.458, -8267.82, -8341.381, -8414.145, -8486.12, -8557.309000000001, -8627.719000000001, -8697.355, -8766.221, -8834.325, -8901.67, -8968.261999999999, -9034.105, -9099.205, -9163.565999999999, -9227.194, -9290.091999999999, -9352.266, -9413.721, -9474.459, -9534.485999999999, -9593.806999999999, -9652.425, -9710.345, -9767.57, -9824.105, -9879.954, -9935.121, -9989.609, -10043.424, -10096.567, -10149.043, -10200.856, -10252.008, -10302.504, -10352.347, -10401.541, -10450.089, -10497.993999999999, -10545.258999999998, -10591.888, -10637.883, -10683.248, -10727.986, -10772.101, -10815.594, -10858.468, -10900.726999999999, -10942.374, -10983.41, -11023.84, -11063.665, -11102.889, -11141.513, -11179.541000000001, -11216.973999999998, -11253.816, -11290.069, -11325.733999999999, -11360.816, -11395.316, -11429.236, -11462.577, -11495.344, -11527.537, -11559.16, -11590.213, -11620.7, -11650.622, -11679.98, -11708.778999999999, -11737.018, -11764.7, -11791.827, -11818.4, -11844.423, -11869.896, -11894.82, -11919.198, -11943.032, -11966.323, -11989.073, -12011.283000000001, -12032.955, -12054.091, -12074.692, -12094.758999999998, -12114.294, -12133.298999999999, -12151.774, -12169.722, -12187.143999999998, -12204.04, -12220.413999999999, -12236.265, -12251.594, -12266.403, -12280.694, -12294.468, -12307.725, -12320.466999999999, -12332.695, -12344.411, -12355.614, -12366.306999999999, -12376.49, -12386.165, -12395.331, -12403.991000000002, -12412.146, -12419.795, -12426.941, -12433.583999999999, -12439.725, -12445.364, -12450.503, -12455.142, -12459.282, -12462.923999999999, -12466.069, -12468.718, -12470.871000000001, -12472.528999999999, -12473.692, -12474.361, -12474.536, -12474.22, -12473.411, -12472.111, -12470.32, -12468.038999999999, -12465.268, -12462.008, -12458.258999999998, -12454.021999999999, -12449.296, -12444.083999999999, -12438.383999999998, -12432.198, -12425.526000000002, -12418.368, -12410.723999999998, -12402.596000000001, -12393.982, -12384.883999999998, -12375.301000000001, -12365.235, -12354.684, -12343.651000000002, -12332.133999999998, -12320.133999999998, -12307.651000000002, -12294.685, -12281.236, -12267.305, -12252.892, -12237.996000000001, -12222.618, -12206.758, -12190.416000000001, -12173.591999999999, -12156.285, -12138.497, -12120.226, -12101.473, -12082.238000000001, -12062.521, -12042.321000000002, -12021.64, -12000.475, -11978.828000000001, -11956.697, -11934.083999999999, -11910.987, -11887.407, -11863.343, -11838.796, -11813.764, -11788.248, -11762.247, -11735.761, -11708.79, -11681.333, -11653.39, -11624.96, -11596.043, -11566.64, -11536.748, -11506.368999999999, -11475.502, -11444.145, -11412.298, -11379.961000000001, -11347.133999999998, -11313.816, -11280.006000000001, -11245.704, -11210.909, -11175.62, -11139.838, -11103.56, -11066.787, -11029.518, -10991.751, -10953.488000000001, -10914.726, -10875.465, -10835.705, -10795.443000000001, -10754.68, -10713.413999999999, -10671.645, -10629.372, -10586.595, -10543.311000000002, -10499.521, -10455.223, -10410.416, -10365.099, -10319.271, -10272.931999999999, -10226.08, -10178.714, -10130.832, -10082.436, -10033.521, -9984.088, -9934.136, -9883.662, -9832.667, -9781.148000000001, -9729.105, -9676.536, -9623.44, -9569.815999999999, -9515.662, -9460.976999999999, -9405.76, -9350.008, -9293.721, -9236.896999999999, -9179.535, -9121.633, -9063.19, -9004.204, -8944.675, -8884.599, -8823.975, -8762.802, -8701.078000000001, -8638.802, -8575.973, -8512.587, -8448.643, -8384.14, -8319.076, -8253.449, -8187.258000000001, -8120.5, -8053.174, -7985.276999999999, -7916.809, -7847.766, -7778.147, -7707.951, -7637.174, -7565.816, -7493.874, -7421.347, -7348.231, -7274.526, -7200.228, -7125.3369999999995, -7049.85, -6973.764, -6897.079000000001, -6819.791, -6741.898, -6663.399, -6584.2919999999995, -6504.573, -6424.241999999999, -6343.297, -6261.734, -6179.552, -6096.749, -6013.321999999999, -5929.27, -5844.590999999999, -5759.283, -5673.343000000001, -5586.771, -5499.563, -5411.718000000001, -5323.234, -5234.111, -5144.345, -5053.935, -4962.879, -4871.177, -4778.827, -4685.827, -4592.178, -4497.876, -4402.923, -4307.315, -4211.055, -4114.14, -4016.571, -3918.348, -3819.4709999999995, -3719.94, -3619.756, -3518.921, -3417.4359999999997, -3315.303, -3212.5240000000003, -3109.1009999999997, -3005.038, -2900.3379999999997, -2795.005, -2689.045, -2582.4629999999997, -2475.265, -2367.4570000000003, -2259.048, -2150.047, -2040.463, -1930.307, -1819.592, -1708.3310000000001, -1596.5379999999998, -1484.231, -1371.4270000000001, -1258.1480000000001, -1144.415, -1030.253, -915.689, -800.7539999999999, -685.48, -569.904, -454.065, -338.00800000000004, -221.78099999999998, -105.43799999999999, 10.963, 127.35799999999999, 243.674, 359.834, 475.75199999999995, 591.3330000000001, 706.472, 821.056, 934.957, 1048.037, 1160.144, 1271.112, 1380.754, 1488.872, 1595.2420000000002, 1699.6229999999998, 1801.754, 1901.344, 1998.0839999999998, 2091.634, 2181.629, 2267.678, 2349.363, 2426.24, 2497.842, 2563.685, 2623.2659999999996, 2676.079, 2721.613, 2759.373, 2788.883, 2809.703, 2821.441, 2823.7709999999997, 2816.441, 2799.2859999999996, 2772.238, 2735.3309999999997, 2688.698, 2632.572, 2567.279, 2493.223, 2410.8779999999997, 2320.768, 2223.4570000000003, 2119.529, 2009.5770000000002, 1894.1889999999999, 1773.941, 1649.386, 1521.0510000000002, 1389.4289999999999, 1254.982, 1118.136, 979.278, 838.7660000000001, 696.924, 554.0409999999999, 410.38199999999995, 266.181, 121.649, -23.026, -167.678, -312.158, -456.334, -600.091, -743.326, -885.95, -1027.883, -1169.066, -1309.407, -1448.884, -1587.443, -1725.043, -1861.649, -1997.233, -2131.77, -2265.24, -2397.623, -2528.907, -2659.08, -2788.134, -2916.059, -3042.8520000000003, -3168.509, -3293.0290000000005, -3416.41, -3538.6540000000005, -3659.761, -3779.736, -3898.58, -4016.297, -4132.894, -4248.375, -4362.746, -4476.012, -4588.18, -4699.259, -4809.253, -4918.17, -5026.018, -5132.805, -5238.538, -5343.225, -5446.8730000000005, -5549.493, -5651.089, -5751.670999999999, -5851.246, -5949.8240000000005, -6047.411999999999, -6144.017, -6239.647, -6334.311, -6428.017, -6520.77, -6612.58, -6703.455, -6793.401, -6882.427, -6970.5380000000005, -7057.744000000001, -7144.05, -7229.465, -7313.994000000001, -7397.645, -7480.425, -7562.34, -7643.398, -7723.604, -7802.965999999999, -7881.488, -7959.179, -8036.044, -8112.089, -8187.32, -8261.742, -8335.363000000001, -8408.188, -8480.221, -8551.469000000001, -8621.938, -8691.632, -8760.556999999999, -8828.718, -8896.122, -8962.771, -9028.671, -9093.828000000001, -9158.246, -9221.93, -9284.885, -9347.115, -9408.625, -9469.419, -9529.501, -9588.878, -9647.55, -9705.525, -9762.804, -9819.394, -9875.296, -9930.517, -9985.06, -10038.927, -10092.123, -10144.652, -10196.517, -10247.722, -10298.27, -10348.166, -10397.412, -10446.011, -10493.966999999999, -10541.284, -10587.964, -10634.01, -10679.426000000001, -10724.215, -10768.378999999999, -10811.921999999999, -10854.846000000001, -10897.155, -10938.851, -10979.938, -11020.417, -11060.291000000001, -11099.563, -11138.236, -11176.312, -11213.794, -11250.684, -11286.985, -11322.698999999999, -11357.828000000001, -11392.375, -11426.341999999999, -11459.731000000002, -11492.545, -11524.786, -11556.455, -11587.555, -11618.088, -11648.056, -11677.46, -11706.305, -11734.59, -11762.318000000001, -11789.49, -11816.108999999999, -11842.177, -11867.694, -11892.663999999999, -11917.088, -11940.966, -11964.302, -11987.096000000001, -12009.35, -12031.067, -12052.246000000001, -12072.891000000001, -12093.002, -12112.581, -12131.63, -12150.149, -12168.14, -12185.605, -12202.544, -12218.96, -12234.853000000001, -12250.226, -12265.078000000001, -12279.411, -12293.226999999999, -12306.527, -12319.311000000002, -12331.581, -12343.338, -12354.583999999999, -12365.318000000001, -12375.543, -12385.258999999998, -12394.466999999999, -12403.168, -12411.363000000001, -12419.053999999998, -12426.24, -12432.923999999999, -12439.106000000002, -12444.785, -12449.965, -12454.643999999998, -12458.825, -12462.507, -12465.692, -12468.38, -12470.573, -12472.271, -12473.473, -12474.181999999999, -12474.396999999999, -12474.12, -12473.35, -12472.09, -12470.338, -12468.096000000001, -12465.364, -12462.142, -12458.431999999999, -12454.233, -12449.546999999999, -12444.373, -12438.711000000001, -12432.563999999998, -12425.93, -12418.81, -12411.204, -12403.113000000001, -12394.537, -12385.476999999999, -12375.931999999999, -12365.903, -12355.39, -12344.393999999998, -12332.915, -12320.952, -12308.506000000001, -12295.577, -12282.166000000001, -12268.271999999999, -12253.895, -12239.037, -12223.696000000002, -12207.872, -12191.567, -12174.778999999999, -12157.508999999998, -12139.757, -12121.521999999999, -12102.806, -12083.607, -12063.926000000001, -12043.763, -12023.117, -12001.988000000001, -11980.376, -11958.282, -11935.704, -11912.643, -11889.098, -11865.07, -11840.558, -11815.562, -11790.081, -11764.115, -11737.665, -11710.728000000001, -11683.306, -11655.398000000001, -11627.003999999999, -11598.123, -11568.753999999999, -11538.896999999999, -11508.552, -11477.719, -11446.396999999999, -11414.583999999999, -11382.282, -11349.49, -11316.206, -11282.431, -11248.163, -11213.402, -11178.146999999999, -11142.398000000001, -11106.155, -11069.417, -11032.181, -10994.448999999999, -10956.219, -10917.491000000002, -10878.264, -10838.537, -10798.309, -10757.579, -10716.348, -10674.613000000001, -10632.374, -10589.628999999999, -10546.378999999999, -10502.622, -10458.357, -10413.583, -10368.3, -10322.506, -10276.2, -10229.381, -10182.048, -10134.2, -10085.835, -10036.954, -9987.554, -9937.635, -9887.194, -9836.232, -9784.746, -9732.735999999999, -9680.199, -9627.136, -9573.544, -9519.423, -9464.771, -9409.586, -9353.867, -9297.612, -9240.821, -9183.491, -9125.622, -9067.211, -9008.258, -8948.761, -8888.716999999999, -8828.126, -8766.985, -8705.294, -8643.05, -8580.253, -8516.899, -8452.988000000001, -8388.517, -8323.485, -8257.891, -8191.731, -8125.005, -8057.710999999999, -7989.847, -7921.411, -7852.4, -7782.813, -7712.649, -7641.904, -7570.578, -7498.668000000001, -7426.173000000001, -7353.09, -7279.416, -7205.151, -7130.291, -7054.835999999999, -6978.781999999999, -6902.129, -6824.8730000000005, -6747.012, -6668.545, -6589.469, -6509.781999999999, -6429.483, -6348.569, -6267.0380000000005, -6184.888000000001, -6102.116, -6018.721, -5934.701, -5850.053000000001, -5764.776999999999, -5678.869000000001, -5592.328, -5505.151, -5417.338000000001, -5328.885, -5239.793, -5150.058, -5059.679, -4968.655, -4876.984, -4784.665, -4691.696, -4598.077, -4503.807, -4408.883, -4313.306, -4217.076, -4120.191, -4022.652, -3924.4590000000003, -3825.611, -3726.11, -3625.9559999999997, -3525.15, -3423.6929999999998, -3321.5890000000004, -3218.8379999999997, -3115.4429999999998, -3011.407, -2906.735, -2801.429, -2695.495, -2588.938, -2481.765, -2373.9829999999997, -2265.598, -2156.62, -2047.058, -1936.924, -1826.23, -1714.989, -1603.2160000000001, -1490.9260000000002, -1378.14, -1264.876, -1151.157, -1037.007, -922.454, -807.5269999999999, -692.26, -576.688, -460.851, -344.793, -228.563, -112.212, 4.2, 120.60799999999999, 236.94400000000002, 353.12800000000004, 469.074, 584.69, 699.87, 814.5010000000001, 928.457, 1041.6019999999999, 1153.782, 1264.8319999999999, 1374.569, 1482.7920000000001, 1589.2820000000002, 1693.7979999999998, 1796.078, 1895.836, 1992.763, 2086.52, 2176.745, 2263.048, 2345.012, 2422.196, 2494.134, 2560.342, 2620.32, 2673.5609999999997, 2719.5559999999996, 2757.8070000000002, 2787.8379999999997, 2809.2059999999997, 2821.518, 2824.442, 2817.722, 2801.188, 2774.768, 2738.486, 2692.472, 2636.952, 2572.246, 2498.754, 2416.945, 2327.341, 2230.5029999999997, 2127.013, 2017.464, 1902.443, 1782.529, 1658.274, 1530.207, 1398.8220000000001, 1264.585, 1127.921, 989.222, 848.846, 707.1189999999999, 564.3340000000001, 420.754, 276.616, 132.134, -12.504000000000001, -157.13, -301.595, -445.765, -589.525, -732.77, -875.4110000000001, -1017.367, -1158.568, -1298.953, -1438.4679999999998, -1577.068, -1714.713, -1851.368, -1987.003, -2121.594, -2255.119, -2387.561, -2518.905, -2649.139, -2778.255, -2906.244, -3033.1020000000003, -3158.824, -3283.4109999999996, -3406.86, -3529.171, -3650.347, -3770.39, -3889.303, -4007.091, -4123.7570000000005, -4239.308, -4353.749, -4467.085, -4579.3240000000005, -4690.472, -4800.536, -4909.524, -5017.442, -5124.299, -5230.102, -5334.858, -5438.576999999999, -5541.265, -5642.931, -5743.581999999999, -5843.226, -5941.871999999999, -6039.529, -6136.201999999999, -6231.9, -6326.630999999999, -6420.404, -6513.225, -6605.102, -6696.043000000001, -6786.055, -6875.147, -6963.3240000000005, -7050.595, -7136.967, -7222.446, -7307.04, -7390.755, -7473.599, -7555.578, -7636.7, -7716.969, -7796.393, -7874.979, -7952.731, -8029.658, -8105.765, -8181.058000000001, -8255.541, -8329.223, -8402.108, -8474.202, -8545.511, -8616.039, -8685.792, -8754.777, -8822.998, -8890.46, -8957.167, -9023.126, -9088.341, -9152.817, -9216.559000000001, -9279.571, -9341.858, -9403.425, -9464.275, -9524.414, -9583.846, -9642.575, -9700.605, -9757.94, -9814.585, -9870.543, -9925.818000000001, -9980.415, -10034.337, -10087.587, -10140.17, -10192.089, -10243.347, -10293.949, -10343.898000000001, -10393.196, -10441.848, -10489.857, -10537.225, -10583.957, -10630.056, -10675.524, -10720.364, -10764.579, -10808.173, -10851.148000000001, -10893.508, -10935.255, -10976.392, -11016.921, -11056.845, -11096.167, -11134.89, -11173.015, -11210.546, -11247.486, -11283.836000000001, -11319.598999999998, -11354.776000000002, -11389.372, -11423.386999999999, -11456.825, -11489.687, -11521.975, -11553.692, -11584.839, -11615.419, -11645.435, -11674.886999999999, -11703.778, -11732.11, -11759.885, -11787.103000000001, -11813.768999999998, -11839.882, -11865.446000000002, -11890.462, -11914.931, -11938.855, -11962.236, -11985.076000000001, -12007.376, -12029.136999999999, -12050.361, -12071.051000000001, -12091.207, -12110.831, -12129.923999999999, -12148.487, -12166.521999999999, -12184.031, -12201.014, -12217.473999999998, -12233.411, -12248.827, -12263.723, -12278.1, -12291.958999999999, -12305.301000000001, -12318.128, -12330.441, -12342.241000000002, -12353.528999999999, -12364.306, -12374.573, -12384.331, -12393.582, -12402.325, -12410.562, -12418.294, -12425.523000000001, -12432.248, -12438.471000000001, -12444.192, -12449.413, -12454.133999999998, -12458.355, -12462.079, -12465.305, -12468.034, -12470.267, -12472.005, -12473.249, -12473.998, -12474.253, -12474.016000000001, -12473.287, -12472.066, -12470.354, -12468.152, -12465.46, -12462.278, -12458.607, -12454.448, -12449.801000000001, -12444.666000000001, -12439.044, -12432.935, -12426.34, -12419.258999999998, -12411.693000000001, -12403.64, -12395.103000000001, -12386.081, -12376.575, -12366.585, -12356.11, -12345.152, -12333.711000000001, -12321.787, -12309.378999999999, -12296.488000000001, -12283.114, -12269.258, -12254.919, -12240.098, -12224.795, -12209.008999999998, -12192.741000000002, -12175.99, -12158.757, -12141.042, -12122.845, -12104.166000000001, -12085.003999999999, -12065.36, -12045.233999999999, -12024.624, -12003.532, -11981.957, -11959.899, -11937.358, -11914.333, -11890.825, -11866.833, -11842.358, -11817.398000000001, -11791.953000000001, -11766.023000000001, -11739.608, -11712.708, -11685.322, -11657.45, -11629.091, -11600.246000000001, -11570.912, -11541.091, -11510.782, -11479.983999999999, -11448.697, -11416.921, -11384.653999999999, -11351.896999999999, -11318.648000000001, -11284.908000000001, -11250.675, -11215.948999999999, -11180.729, -11145.015, -11108.806999999999, -11072.103000000001, -11034.903, -10997.206, -10959.011999999999, -10920.318000000001, -10881.125, -10841.431999999999, -10801.239, -10760.544, -10719.346000000001, -10677.646999999999, -10635.442, -10592.731000000002, -10549.515, -10505.793, -10461.562, -10416.822, -10371.573, -10325.813, -10279.541, -10232.756, -10185.457, -10137.643, -10089.312, -10040.464, -9991.098, -9941.213, -9890.806, -9839.877, -9788.425, -9736.448, -9683.946, -9630.916, -9577.358, -9523.27, -9468.651, -9413.5, -9357.814, -9301.593, -9244.835, -9187.539, -9129.703000000001, -9071.326, -9012.405999999999, -8952.942, -8892.931, -8832.373, -8771.266, -8709.608, -8647.398000000001, -8584.633, -8521.312, -8457.434000000001, -8392.996, -8327.998, -8262.436, -8196.31, -8129.616999999999, -8062.356, -7994.525, -7926.121, -7857.143, -7787.59, -7717.4580000000005, -7646.746999999999, -7575.454000000001, -7503.576999999999, -7431.1140000000005, -7358.063, -7284.423000000001, -7210.19, -7135.3640000000005, -7059.941, -6983.92, -6907.299, -6830.075, -6752.246999999999, -6673.814, -6594.771, -6515.116999999999, -6434.85, -6353.968000000001, -6272.469, -6190.352, -6107.613, -6024.251, -5940.263000000001, -5855.648, -5770.404, -5684.528, -5598.019, -5510.875, -5423.094, -5334.674, -5245.613, -5155.91, -5065.564, -4974.572, -4882.933, -4790.645, -4697.708, -4604.121, -4509.8820000000005, -4414.99, -4319.444, -4223.245, -4126.391, -4028.883, -3930.7209999999995, -3831.903, -3732.4320000000002, -3632.308, -3531.532, -3430.1059999999998, -3328.031, -3225.308, -3121.942, -3017.935, -2913.29, -2808.012, -2702.105, -2595.576, -2488.428, -2380.6710000000003, -2272.311, -2163.357, -2053.819, -1943.7079999999999, -1833.036, -1721.815, -1610.0610000000001, -1497.79, -1385.021, -1271.7730000000001, -1158.068, -1043.932, -929.39, -814.4730000000001, -699.212, -583.645, -467.81, -351.751, -235.517, -119.16, -2.737, 113.686, 230.041, 346.24800000000005, 462.224, 577.874, 693.095, 807.775, 921.788, 1034.997, 1147.251, 1258.385, 1368.2179999999998, 1476.549, 1583.161, 1687.8129999999999, 1790.246, 1890.175, 1987.2920000000001, 2081.26, 2171.719, 2258.281, 2340.53, 2418.026, 2490.3070000000002, 2556.887, 2617.271, 2670.948, 2717.4120000000003, 2756.165, 2786.7270000000003, 2808.656, 2821.554, 2825.085, 2818.99, 2803.092, 2777.3140000000003, 2741.673, 2696.2940000000003, 2641.395, 2577.292, 2504.379, 2423.121, 2334.038, 2237.686, 2134.646, 2025.5120000000002, 1910.87, 1791.299, 1667.3529999999998, 1539.5620000000001, 1408.424, 1274.403, 1137.928, 999.393, 859.158, 717.55, 574.865, 431.36699999999996, 287.296, 142.866, -1.734, -146.333, -290.781, -434.945, -578.707, -721.962, -864.62, -1006.5989999999999, -1147.828, -1288.247, -1427.8010000000002, -1566.444, -1704.134, -1840.838, -1976.525, -2111.17, -2244.7529999999997, -2377.254, -2508.658, -2638.9559999999997, -2768.135, -2896.1890000000003, -3023.113, -3148.9040000000005, -3273.558, -3397.075, -3519.4559999999997, -3640.703, -3760.816, -3879.8, -3997.659, -4114.397, -4230.019, -4344.532, -4457.94, -4570.25, -4681.47, -4791.606, -4900.666, -5008.656, -5115.584, -5221.459, -5326.286999999999, -5430.076, -5532.835999999999, -5634.571999999999, -5735.293000000001, -5835.008000000001, -5933.725, -6031.451, -6128.193, -6223.960999999999, -6318.762, -6412.604, -6505.493, -6597.438, -6688.448, -6778.528, -6867.687, -6955.931, -7043.269, -7129.706999999999, -7215.253000000001, -7299.9130000000005, -7383.694, -7466.604, -7548.649, -7629.834, -7710.168000000001, -7789.656999999999, -7868.307, -7946.1230000000005, -8023.1140000000005, -8099.283, -8174.638000000001, -8249.185, -8322.93, -8395.877, -8468.032, -8539.402, -8609.992, -8679.806999999999, -8748.851999999999, -8817.133, -8884.655, -8951.423, -9017.442, -9082.716, -9147.251, -9211.051, -9274.122, -9336.468, -9398.093, -9459.001, -9519.198, -9578.687, -9637.473, -9695.56, -9752.952, -9809.653, -9865.668, -9920.999, -9975.651, -10029.629, -10082.935, -10135.573, -10187.546, -10238.86, -10289.516, -10339.519, -10388.872, -10437.578000000001, -10485.64, -10533.062, -10579.847, -10625.999, -10671.518999999998, -10716.412, -10760.68, -10804.326000000001, -10847.354, -10889.765, -10931.565, -10972.753, -11013.333, -11053.308, -11092.681, -11131.455, -11169.631000000001, -11207.213, -11244.203000000001, -11280.603000000001, -11316.415, -11351.643, -11386.288, -11420.353000000001, -11453.84, -11486.751, -11519.088, -11550.853000000001, -11582.048999999999, -11612.678, -11642.743, -11672.243, -11701.181999999999, -11729.561000000002, -11757.383, -11784.65, -11811.362, -11837.524, -11863.135, -11888.197, -11912.713, -11936.684, -11960.112, -11982.998, -12005.344, -12027.152, -12048.421999999999, -12069.158000000001, -12089.358999999999, -12109.028, -12128.166000000001, -12146.775, -12164.856000000002, -12182.41, -12199.438999999998, -12215.943000000001, -12231.925, -12247.385, -12262.325, -12276.746000000001, -12290.649, -12304.036, -12316.907, -12329.264, -12341.108, -12352.438999999998, -12363.26, -12373.57, -12383.372, -12392.665, -12401.452, -12409.732, -12417.507, -12424.778, -12431.546, -12437.811000000002, -12443.575, -12448.838, -12453.601, -12457.865, -12461.63, -12464.898000000001, -12467.669, -12469.944, -12471.723, -12473.008, -12473.798, -12474.095, -12473.899, -12473.211000000001, -12472.031, -12470.36, -12468.198999999999, -12465.546999999999, -12462.406, -12458.775, -12454.656, -12450.048999999999, -12444.955, -12439.373, -12433.305, -12426.749, -12419.708, -12412.181, -12404.169, -12395.671, -12386.688999999998, -12377.222, -12367.271, -12356.836000000001, -12345.917, -12334.515, -12322.628999999999, -12310.26, -12297.408000000001, -12284.073, -12270.256000000001, -12255.956, -12241.173, -12225.908000000001, -12210.16, -12193.93, -12177.218, -12160.023000000001, -12142.346000000001, -12124.188, -12105.546999999999, -12086.421999999999, -12066.816, -12046.726999999999, -12026.155, -12005.101, -11983.563, -11961.543, -11939.04, -11916.052, -11892.581, -11868.626, -11844.188, -11819.264, -11793.857, -11767.964, -11741.586000000001, -11714.723, -11687.373, -11659.538, -11631.215, -11602.406, -11573.11, -11543.323999999999, -11513.052, -11482.291000000001, -11451.04, -11419.3, -11387.069, -11354.347, -11321.133999999998, -11287.43, -11253.233, -11218.544, -11183.36, -11147.681999999999, -11111.508999999998, -11074.84, -11037.676000000001, -11000.014, -10961.855, -10923.197, -10884.038999999999, -10844.382, -10804.223999999998, -10763.563999999998, -10722.402, -10680.737, -10638.567, -10595.892, -10552.711000000001, -10509.023000000001, -10464.827, -10420.123, -10374.908000000001, -10329.183, -10282.946, -10236.196, -10188.931, -10141.152, -10092.856, -10044.043, -9994.711, -9944.86, -9894.488000000001, -9843.594000000001, -9792.176, -9740.234, -9687.765, -9634.77, -9581.247, -9527.193000000001, -9472.608, -9417.491, -9361.839, -9305.652, -9248.928, -9191.666, -9133.864, -9075.521999999999, -9016.636, -8957.205, -8897.228000000001, -8836.704, -8775.631, -8714.007, -8651.831, -8589.1, -8525.813, -8461.969000000001, -8397.565, -8332.6, -8267.073, -8200.979, -8134.321, -8067.093000000001, -7999.295, -7930.925, -7861.981, -7792.460999999999, -7722.3640000000005, -7651.686, -7580.427, -7508.5830000000005, -7436.153, -7363.1359999999995, -7289.529, -7215.331, -7140.536999999999, -7065.148, -6989.161, -6912.573, -6835.383000000001, -6757.588000000001, -6679.188, -6600.178000000001, -6520.558000000001, -6440.3240000000005, -6359.476, -6278.0109999999995, -6195.9259999999995, -6113.221, -6029.892, -5945.937, -5861.355, -5776.144, -5690.302, -5603.826, -5516.714, -5428.965999999999, -5340.579000000001, -5251.5509999999995, -5161.8820000000005, -5071.568, -4980.608, -4889.001, -4796.746, -4703.842000000001, -4610.286, -4516.08, -4421.22, -4325.706, -4229.539000000001, -4132.717000000001, -4035.24, -3937.1090000000004, -3838.323, -3738.883, -3638.789, -3538.0440000000003, -3436.6479999999997, -3334.6020000000003, -3231.91, -3128.573, -3024.594, -2919.978, -2814.728, -2708.849, -2602.347, -2495.226, -2387.495, -2279.16, -2170.231, -2060.717, -1950.629, -1839.979, -1728.779, -1617.045, -1504.793, -1392.0420000000001, -1278.81, -1165.12, -1050.997, -936.466, -821.559, -706.305, -590.743, -474.91, -358.851, -242.613, -126.249, -9.816, 106.62299999999999, 222.99599999999998, 339.228, 455.233, 570.918, 686.182, 800.91, 914.98, 1028.255, 1140.5839999999998, 1251.803, 1361.733, 1470.1729999999998, 1576.908, 1681.6989999999998, 1784.2879999999998, 1884.389, 1981.6979999999999, 2075.881, 2166.577, 2253.4, 2335.938, 2413.751, 2486.379, 2553.337, 2614.131, 2668.2509999999997, 2715.192, 2754.453, 2785.555, 2808.052, 2821.546, 2825.6940000000004, 2820.2340000000004, 2804.9840000000004, 2779.8590000000004, 2744.8709999999996, 2700.137, 2645.873, 2582.385, 2510.063, 2429.368, 2340.8160000000003, 2244.9610000000002, 2142.383, 2033.674, 1919.42, 1800.201, 1676.5720000000001, 1549.065, 1418.1789999999999, 1284.38, 1148.099, 1009.732, 869.6419999999999, 728.1569999999999, 585.575, 442.163, 298.161, 153.785, 9.226, -135.345, -279.776, -423.93300000000005, -567.696, -710.96, -853.6339999999999, -995.637, -1136.799, -1277.347, -1416.9389999999999, -1555.625, -1693.362, -1830.116, -1965.855, -2100.556, -2234.197, -2366.757, -2498.224, -2628.5840000000003, -2757.829, -2885.949, -3012.941, -3138.7990000000004, -3263.522, -3387.1090000000004, -3509.5609999999997, -3630.8779999999997, -3751.063, -3870.119, -3988.05, -4104.86, -4220.555, -4335.14, -4448.622, -4561.005999999999, -4672.298, -4782.508, -4891.64, -4999.7029999999995, -5106.704000000001, -5212.652, -5317.552, -5421.414000000001, -5524.245, -5626.053000000001, -5726.847, -5826.634, -5925.420999999999, -6023.219, -6120.031999999999, -6215.87, -6310.741, -6404.653, -6497.611999999999, -6589.6269999999995, -6680.706, -6770.855, -6860.0830000000005, -6948.396, -7035.802, -7122.308000000001, -7207.920999999999, -7292.648, -7376.496, -7459.472, -7541.584, -7622.835999999999, -7703.235, -7782.789000000001, -7861.504, -7939.3859999999995, -8016.441, -8092.675, -8168.094, -8242.704, -8316.511999999999, -8389.521999999999, -8461.741, -8533.173, -8603.826, -8673.703000000001, -8742.81, -8811.152, -8878.735, -8945.564, -9011.644, -9076.979, -9141.574, -9205.434000000001, -9268.565, -9330.97, -9392.654, -9453.622, -9513.877, -9573.424, -9632.269, -9690.414, -9747.864, -9804.623, -9860.694, -9916.083, -9970.792, -10024.825, -10078.188, -10130.882, -10182.912, -10234.280999999999, -10284.993, -10335.051, -10384.459, -10433.22, -10481.337, -10528.813, -10575.653, -10621.858, -10667.433, -10712.378999999999, -10756.701000000001, -10800.4, -10843.481000000002, -10885.945, -10927.796999999999, -10969.037, -11009.67, -11049.698, -11089.123, -11127.948, -11166.176000000001, -11203.809, -11240.85, -11277.301000000001, -11313.163999999999, -11348.443000000001, -11383.139, -11417.253999999999, -11450.791000000001, -11483.752, -11516.139, -11547.954, -11579.2, -11609.878, -11639.992, -11669.541000000001, -11698.528999999999, -11726.957, -11754.828000000001, -11782.143, -11808.903999999999, -11835.113000000001, -11860.771999999999, -11885.883, -11910.446000000002, -11934.465, -11957.94, -11980.873, -12003.267, -12025.121000000001, -12046.438999999998, -12067.221000000001, -12087.469, -12107.184, -12126.368999999999, -12145.024, -12163.15, -12180.751, -12197.825, -12214.375, -12230.403, -12245.908000000001, -12260.893, -12275.36, -12289.308, -12302.74, -12315.656, -12328.058, -12339.946000000002, -12351.322, -12362.186000000002, -12372.541000000001, -12382.386999999999, -12391.725, -12400.555, -12408.878999999999, -12416.697, -12424.011999999999, -12430.823999999999, -12437.131000000001, -12442.938999999998, -12448.245, -12453.051000000001, -12457.358, -12461.166000000001, -12464.476, -12467.29, -12469.607, -12471.428999999998, -12472.756000000001, -12473.589, -12473.928, -12473.774, -12473.127, -12471.989, -12470.36, -12468.241000000002, -12465.63, -12462.53, -12458.941, -12454.864, -12450.298, -12445.245, -12439.703000000001, -12433.676000000001, -12427.162, -12420.161, -12412.675, -12404.703000000001, -12396.245, -12387.303, -12377.877, -12367.966, -12357.572, -12346.693000000001, -12335.33, -12323.483999999999, -12311.155, -12298.341999999999, -12285.048, -12271.27, -12257.008999999998, -12242.266000000001, -12227.04, -12211.331, -12195.14, -12178.466999999999, -12161.312, -12143.673999999999, -12125.553999999998, -12106.951000000001, -12087.866000000002, -12068.298, -12048.247, -12027.714, -12006.698999999999, -11985.2, -11963.216999999999, -11940.752, -11917.803, -11894.37, -11870.453000000001, -11846.052, -11821.167, -11795.796999999999, -11769.942, -11743.601999999999, -11716.776000000002, -11689.464, -11661.666000000001, -11633.381000000001, -11604.608999999999, -11575.35, -11545.603000000001, -11515.367, -11484.642, -11453.428999999998, -11421.726, -11389.532, -11356.848, -11323.671999999999, -11290.003999999999, -11255.843, -11221.19, -11186.043, -11150.402, -11114.266000000001, -11077.633999999998, -11040.505, -11002.88, -10964.756000000001, -10926.135, -10887.014, -10847.393, -10807.271, -10766.646999999999, -10725.521, -10683.891000000001, -10641.758, -10599.118999999999, -10555.973999999998, -10512.322, -10468.162, -10423.493, -10378.314, -10332.624, -10286.421999999999, -10239.708, -10192.479, -10144.735999999999, -10096.475, -10047.697, -9998.401, -9948.585, -9898.248, -9847.389000000001, -9796.007, -9744.1, -9691.667, -9638.707, -9585.218, -9531.2, -9476.65, -9421.568000000001, -9365.951, -9309.799, -9253.11, -9195.883, -9138.116, -9079.809000000001, -9020.957, -8961.562, -8901.62, -8841.13, -8780.091999999999, -8718.503, -8656.360999999999, -8593.665, -8530.413, -8466.603000000001, -8402.234, -8337.304, -8271.811, -8205.753, -8139.128000000001, -8071.935, -8004.172, -7935.8369999999995, -7866.927, -7797.441999999999, -7727.379, -7656.735, -7585.51, -7513.701, -7441.306, -7368.3240000000005, -7294.751, -7220.585999999999, -7145.826999999999, -7070.472, -6994.519, -6917.965, -6840.81, -6763.05, -6684.683000000001, -6605.7080000000005, -6526.121999999999, -6445.922, -6365.109, -6283.678000000001, -6201.6269999999995, -6118.955, -6035.66, -5951.74, -5867.191999999999, -5782.015, -5696.206, -5609.764, -5522.686, -5434.972, -5346.619000000001, -5257.625, -5167.9890000000005, -5077.708, -4986.782, -4895.209, -4802.988, -4710.116, -4616.594, -4522.42, -4427.593, -4332.113, -4235.978, -4139.188, -4041.744, -3943.6440000000002, -3844.8909999999996, -3745.4829999999997, -3645.421, -3544.7059999999997, -3443.341, -3341.3259999999996, -3238.664, -3135.3579999999997, -3031.409, -2926.822, -2821.6009999999997, -2715.75, -2609.275, -2502.1820000000002, -2394.478, -2286.169, -2177.265, -2067.776, -1957.711, -1847.0839999999998, -1735.9070000000002, -1624.194, -1511.9620000000002, -1399.2279999999998, -1286.013, -1172.339, -1058.229, -943.711, -828.813, -713.567, -598.01, -482.18, -366.12, -249.87900000000002, -133.50799999999998, -17.064, 99.389, 215.782, 332.038, 448.07199999999995, 563.794, 679.0989999999999, 793.878, 908.005, 1021.346, 1133.751, 1245.058, 1355.085, 1463.6370000000002, 1570.497, 1675.4279999999999, 1778.174, 1878.4520000000002, 1975.957, 2070.357, 2161.294, 2248.383, 2331.215, 2409.35, 2482.33, 2549.673, 2610.884, 2665.4559999999997, 2712.881, 2752.66, 2784.313, 2807.39, 2821.489, 2826.268, 2821.4559999999997, 2806.866, 2782.408, 2748.0879999999997, 2704.0159999999996, 2650.4, 2587.541, 2515.825, 2435.708, 2347.701, 2252.356, 2150.252, 2041.9779999999998, 1928.1229999999998, 1809.266, 1685.964, 1558.7479999999998, 1428.121, 1294.5510000000002, 1158.47, 1020.2769999999999, 880.337, 738.98, 596.504, 453.18, 309.249, 164.929, 20.412, -124.12899999999999, -268.54200000000003, -412.69, -556.4540000000001, -699.727, -842.418, -984.442, -1125.73, -1266.2169999999999, -1405.848, -1544.576, -1682.361, -1819.165, -1954.9589999999998, -2089.716, -2223.4139999999998, -2356.0370000000003, -2487.5660000000003, -2617.99, -2747.301, -2875.489, -3002.5490000000004, -3128.4770000000003, -3253.2709999999997, -3376.929, -3499.453, -3620.843, -3741.1, -3860.23, -3978.235, -4095.119, -4210.888, -4325.548, -4439.104, -4551.562, -4662.929, -4773.213, -4882.42, -4990.557, -5097.633, -5203.654, -5308.628000000001, -5412.564, -5515.469, -5617.351, -5718.218000000001, -5818.076999999999, -5916.939, -6014.808000000001, -6111.694, -6207.604, -6302.547, -6396.53, -6489.561, -6581.647, -6672.795999999999, -6763.016, -6852.313, -6940.696999999999, -7028.172, -7114.746999999999, -7200.429, -7285.225, -7369.142, -7452.186, -7534.3640000000005, -7615.684, -7696.151, -7775.772, -7854.553000000001, -7932.501, -8009.621999999999, -8085.922, -8161.406, -8236.082, -8309.954, -8383.029, -8455.312, -8526.808, -8597.524, -8667.464, -8736.635, -8805.04, -8872.686, -8939.576, -9005.718, -9071.115, -9135.771999999999, -9199.694, -9262.885, -9325.351, -9387.096, -9448.123, -9508.438, -9568.046, -9626.949, -9685.154, -9742.663, -9799.48, -9855.61, -9911.056999999999, -9965.825, -10019.916, -10073.336, -10126.087, -10178.174, -10229.6, -10280.369, -10330.484, -10379.948, -10428.764000000001, -10476.937, -10524.47, -10571.365, -10617.625, -10663.253999999999, -10708.255, -10752.632, -10796.385, -10839.52, -10882.038999999999, -10923.944, -10965.238000000001, -11005.923999999999, -11046.005, -11085.483999999999, -11124.362, -11162.643, -11200.328000000001, -11237.421, -11273.923999999999, -11309.84, -11345.17, -11379.918, -11414.083999999999, -11447.671999999999, -11480.684, -11513.122, -11544.989, -11576.285, -11607.014, -11637.177, -11666.776000000002, -11695.813999999998, -11724.293, -11752.214, -11779.578000000001, -11806.389, -11832.646999999999, -11858.355, -11883.514, -11908.127, -11932.194, -11955.718, -11978.698999999999, -12001.14, -12023.043, -12044.409, -12065.239, -12085.535, -12105.298, -12124.528999999999, -12143.231000000002, -12161.405, -12179.052, -12196.173999999999, -12212.771, -12228.844, -12244.396999999999, -12259.428, -12273.94, -12287.935, -12301.412, -12314.374, -12326.822, -12338.755, -12350.177, -12361.087, -12371.486, -12381.377, -12390.76, -12399.635, -12408.003999999999, -12415.867, -12423.226, -12430.082, -12436.435, -12442.286, -12447.636, -12452.486, -12456.837, -12460.688999999998, -12464.043, -12466.9, -12469.261, -12471.126, -12472.496000000001, -12473.372, -12473.753999999999, -12473.643, -12473.038999999999, -12471.944, -12470.357, -12468.28, -12465.712, -12462.655, -12459.108, -12455.073, -12450.548999999999, -12445.537, -12440.038999999999, -12434.053, -12427.58, -12420.621000000001, -12413.176000000001, -12405.245, -12396.829, -12387.928999999998, -12378.544, -12368.673999999999, -12358.32, -12347.482, -12336.16, -12324.355, -12312.066, -12299.295, -12286.04, -12272.303, -12258.082, -12243.378999999999, -12228.193000000001, -12212.525, -12196.374, -12179.74, -12162.625, -12145.027, -12126.947, -12108.383, -12089.337, -12069.809, -12049.798, -12029.303999999998, -12008.328000000001, -11986.868, -11964.925, -11942.498, -11919.588, -11896.194, -11872.316, -11847.954, -11823.108, -11797.776000000002, -11771.96, -11745.658000000001, -11718.87, -11691.597, -11663.837, -11635.591, -11606.857, -11577.636, -11547.927, -11517.729, -11487.043, -11455.867, -11424.202, -11392.046, -11359.399, -11326.261, -11292.631000000001, -11258.508, -11223.892, -11188.783000000001, -11153.178999999998, -11117.08, -11080.485, -11043.393999999998, -11005.806, -10967.719, -10929.135, -10890.051000000001, -10850.466999999999, -10810.382, -10769.795, -10728.706, -10687.113000000001, -10645.016000000001, -10602.413999999999, -10559.306, -10515.691, -10471.567, -10426.935, -10381.792, -10336.139000000001, -10289.974, -10243.295, -10196.103000000001, -10148.396, -10100.171999999999, -10051.43, -10002.17, -9952.39, -9902.09, -9851.267, -9799.921, -9748.05, -9695.653, -9642.729, -9589.276, -9535.293, -9480.78, -9425.733, -9370.153, -9314.037, -9257.384, -9200.192, -9142.461, -9084.189, -9025.373, -8966.013, -8906.107, -8845.653, -8784.651, -8723.097, -8660.991, -8598.33, -8535.114, -8471.339, -8407.006, -8342.110999999999, -8276.654, -8210.631, -8144.0419999999995, -8076.884, -8009.156, -7940.856, -7871.983, -7802.533, -7732.505, -7661.896, -7590.706, -7518.933000000001, -7446.573, -7373.626, -7300.088000000001, -7225.959, -7151.235, -7075.915, -6999.996999999999, -6923.479, -6846.359, -6768.634, -6690.302, -6611.361999999999, -6531.811, -6451.647, -6370.868, -6289.472, -6207.456, -6124.819, -6041.559, -5957.674, -5873.161, -5788.019, -5702.245, -5615.8369999999995, -5528.794, -5441.115, -5352.795999999999, -5263.8369999999995, -5174.235, -5083.9890000000005, -4993.097, -4901.558, -4809.371, -4716.534000000001, -4623.045999999999, -4528.905, -4434.112, -4338.666, -4242.564, -4145.808, -4048.397, -3950.33, -3851.6090000000004, -3752.2340000000004, -3652.204, -3551.522, -3450.188, -3348.205, -3245.575, -3142.2990000000004, -3038.381, -2933.824, -2828.632, -2722.8109999999997, -2616.365, -2509.3, -2401.623, -2293.341, -2184.464, -2074.999, -1964.9589999999998, -1854.355, -1743.201, -1631.509, -1519.297, -1406.582, -1293.385, -1179.726, -1065.631, -951.125, -836.237, -720.9989999999999, -605.447, -489.62, -373.561, -257.316, -140.938, -24.484, 91.984, 208.396, 324.676, 440.741, 556.498, 671.847, 786.675, 900.8610000000001, 1014.2689999999999, 1126.752, 1238.146, 1348.274, 1456.9379999999999, 1563.925, 1668.999, 1771.905, 1872.361, 1970.065, 2064.686, 2155.868, 2243.228, 2326.357, 2404.82, 2478.158, 2545.893, 2607.528, 2662.558, 2710.4770000000003, 2750.783, 2782.9959999999996, 2806.664, 2821.381, 2826.802, 2822.65, 2808.735, 2784.958, 2751.32, 2707.9240000000004, 2654.97, 2592.757, 2521.661, 2442.135, 2354.686, 2259.865, 2158.2470000000003, 2050.4210000000003, 1936.976, 1818.49, 1695.523, 1568.608, 1438.2479999999998, 1304.913, 1169.038, 1031.025, 891.238, 750.013, 607.6469999999999, 464.414, 320.558, 176.296, 31.823, -112.68700000000001, -257.08, -401.219, -544.9830000000001, -688.265, -830.972, -973.0189999999999, -1114.336, -1254.858, -1394.5279999999998, -1533.3010000000002, -1671.1329999999998, -1807.989, -1943.8370000000002, -2078.651, -2212.409, -2345.093, -2476.687, -2607.177, -2736.555, -2864.812, -2991.941, -3117.94, -3242.8059999999996, -3366.5370000000003, -3489.134, -3610.598, -3730.93, -3850.134, -3968.2140000000004, -4085.1740000000004, -4201.018, -4315.754, -4429.3859999999995, -4541.92, -4653.363, -4763.723, -4873.005999999999, -4981.219, -5088.371, -5194.467000000001, -5299.517, -5403.528, -5506.508000000001, -5608.465, -5709.406999999999, -5809.340999999999, -5908.276, -6006.22, -6103.179, -6199.1630000000005, -6294.18, -6388.235, -6481.339, -6573.496999999999, -6664.719, -6755.01, -6844.379, -6932.834, -7020.38, -7107.026, -7192.778, -7277.644, -7361.63, -7444.744000000001, -7526.991, -7608.38, -7688.915, -7768.604, -7847.453, -7925.469, -8002.658, -8079.024, -8154.575, -8229.317, -8303.255, -8376.396, -8448.745, -8520.306, -8591.087, -8661.091, -8730.326, -8798.796, -8866.505, -8933.46, -8999.664, -9065.124, -9129.844000000001, -9193.828000000001, -9257.082, -9319.609, -9381.416, -9442.505, -9502.881, -9562.549, -9621.514000000001, -9679.779, -9737.348, -9794.225, -9850.415, -9905.921, -9960.748, -10014.898000000001, -10068.377, -10121.187, -10173.332, -10224.815999999999, -10275.643, -10325.815, -10375.336, -10424.21, -10472.439, -10520.028999999999, -10566.98, -10613.296999999999, -10658.982, -10704.04, -10748.471000000001, -10792.281, -10835.471000000001, -10878.045, -10920.005, -10961.354, -11002.094, -11042.229, -11081.761999999999, -11120.694, -11159.028999999999, -11196.768, -11233.913999999999, -11270.47, -11306.438999999998, -11341.822, -11376.622, -11410.841, -11444.482, -11477.546, -11510.036, -11541.954, -11573.302, -11604.082, -11634.296999999999, -11663.947, -11693.036, -11721.566, -11749.537, -11776.952, -11803.813, -11830.122, -11855.878999999999, -11881.089, -11905.751, -11929.868, -11953.441, -11976.472, -11998.962, -12020.913999999999, -12042.328000000001, -12063.207, -12083.551000000001, -12103.363000000001, -12122.643, -12141.393999999998, -12159.615, -12177.31, -12194.479, -12211.124, -12227.245, -12242.845, -12257.923999999999, -12272.483, -12286.524, -12300.048999999999, -12313.056999999999, -12325.552, -12337.532, -12349.0, -12359.956, -12370.402, -12380.338, -12389.767, -12398.688, -12407.103000000001, -12415.011999999999, -12422.416000000001, -12429.317, -12435.715, -12441.611, -12447.007, -12451.902, -12456.296999999999, -12460.193000000001, -12463.591999999999, -12466.493999999999, -12468.899, -12470.808, -12472.223, -12473.142, -12473.568000000001, -12473.501, -12472.941, -12471.889, -12470.346000000001, -12468.313, -12465.788, -12462.774, -12459.27, -12455.278, -12450.796999999999, -12445.828000000001, -12440.372, -12434.428999999998, -12427.999, -12421.082, -12413.68, -12405.791000000001, -12397.418, -12388.559, -12379.216, -12369.388, -12359.076000000001, -12348.28, -12337.0, -12325.236, -12312.989, -12300.258999999998, -12287.046, -12273.348999999998, -12259.17, -12244.508, -12229.363000000001, -12213.736, -12197.626, -12181.034, -12163.958999999999, -12146.401000000002, -12128.361, -12109.839, -12090.833, -12071.346000000001, -12051.375, -12030.921, -12009.985, -11988.565, -11966.661, -11944.275, -11921.405, -11898.051000000001, -11874.213, -11849.89, -11825.083, -11799.791000000001, -11774.014, -11747.752, -11721.003999999999, -11693.77, -11666.048999999999, -11637.841999999999, -11609.146999999999, -11579.965, -11550.294, -11520.136, -11489.488000000001, -11458.351, -11426.723999999998, -11394.607, -11361.999, -11328.899, -11295.308, -11261.223999999998, -11226.646, -11191.575, -11156.008999999998, -11119.948, -11083.392, -11046.339, -11008.788999999999, -10970.741000000002, -10932.194, -10893.148000000001, -10853.601999999999, -10813.553999999998, -10773.005, -10731.954, -10690.399, -10648.34, -10605.775, -10562.704, -10519.126, -10475.04, -10430.446, -10385.341, -10339.725, -10293.597, -10246.956, -10199.801, -10152.13, -10103.944, -10055.24, -10006.017, -9956.274, -9906.01, -9855.224, -9803.915, -9752.081, -9699.721, -9646.834, -9593.418, -9539.472, -9484.995, -9429.985, -9374.440999999999, -9318.362, -9261.746, -9204.591, -9146.896, -9088.66, -9029.881, -8970.558, -8910.689, -8850.271999999999, -8789.305, -8727.788, -8665.716999999999, -8603.094000000001, -8539.914, -8476.176, -8411.879, -8347.02, -8281.598, -8215.612, -8149.06, -8081.939, -8014.246999999999, -7945.983, -7877.145, -7807.731, -7737.7390000000005, -7667.168000000001, -7596.014, -7524.276, -7451.953, -7379.041, -7305.54, -7231.446999999999, -7156.759, -7081.476, -7005.594, -6929.111, -6852.026999999999, -6774.339, -6696.043000000001, -6617.138000000001, -6537.6230000000005, -6457.495, -6376.7519999999995, -6295.392, -6213.411999999999, -6130.811, -6047.585999999999, -5963.736999999999, -5879.26, -5794.153, -5708.415, -5622.043000000001, -5535.036, -5447.392, -5359.109, -5270.185, -5180.6179999999995, -5090.407, -4999.55, -4908.0470000000005, -4815.895, -4723.092000000001, -4629.639, -4535.532999999999, -4440.775, -4345.363, -4249.295999999999, -4152.5740000000005, -4055.196, -3957.164, -3858.4759999999997, -3759.134, -3659.138, -3558.489, -3457.188, -3355.237, -3252.638, -3149.3940000000002, -3045.507, -2940.9809999999998, -2835.82, -2730.0290000000005, -2623.613, -2516.576, -2408.927, -2300.673, -2191.822, -2082.384, -1972.37, -1861.79, -1750.658, -1638.9879999999998, -1526.797, -1414.102, -1300.923, -1187.281, -1073.2, -958.706, -843.828, -728.5989999999999, -613.053, -497.22900000000004, -381.17, -264.922, -148.53799999999998, -32.073, 84.40899999999999, 200.84099999999998, 317.14599999999996, 433.241, 549.035, 664.427, 779.306, 893.551, 1007.0269999999999, 1119.588, 1231.0710000000001, 1341.3, 1450.079, 1557.195, 1662.414, 1765.4820000000002, 1866.119, 1964.024, 2058.869, 2150.3, 2237.935, 2321.367, 2400.1620000000003, 2473.864, 2541.996, 2604.062, 2659.559, 2707.9790000000003, 2748.821, 2781.6020000000003, 2805.8709999999996, 2821.218, 2827.292, 2823.813, 2810.585, 2787.5029999999997, 2754.5609999999997, 2711.8540000000003, 2659.579, 2598.024, 2527.563, 2448.6420000000003, 2361.765, 2267.48, 2166.36, 2058.994, 1945.969, 1827.865, 1705.2420000000002, 1578.636, 1448.549, 1315.4560000000001, 1179.7939999999999, 1041.965, 902.3380000000001, 761.247, 618.996, 475.858, 332.077, 187.87599999999998, 43.449, -101.029, -245.40099999999998, -389.529, -533.293, -676.5830000000001, -819.306, -961.377, -1102.463, -1243.279, -1382.989, -1521.807, -1659.6870000000001, -1796.595, -1932.4979999999998, -2067.371, -2201.19, -2333.937, -2465.596, -2596.153, -2725.599, -2853.925, -2981.1259999999997, -3107.197, -3232.136, -3355.941, -3478.612, -3600.151, -3720.559, -3839.8390000000004, -3957.995, -4075.033, -4190.954000000001, -4305.767, -4419.476, -4532.088, -4643.608, -4754.045, -4863.406, -4971.696, -5078.924, -5185.099, -5290.226, -5394.313, -5497.37, -5599.404, -5700.420999999999, -5800.431, -5899.441999999999, -5997.460999999999, -6094.496, -6190.555, -6285.646, -6379.776, -6472.953, -6565.186, -6656.481, -6746.845, -6836.286999999999, -6924.814, -7012.433000000001, -7099.15, -7184.974, -7269.911, -7353.969, -7437.153, -7519.471, -7600.929, -7681.535, -7761.293000000001, -7840.210999999999, -7918.295999999999, -7995.553000000001, -8071.986999999999, -8147.607, -8222.416, -8296.421999999999, -8369.63, -8442.045, -8513.673, -8584.519, -8654.591, -8723.891, -8792.425, -8860.2, -8927.219000000001, -8993.489, -9059.011999999999, -9123.796, -9187.843, -9251.161, -9313.752, -9375.62, -9436.771999999999, -9497.211, -9556.940999999999, -9615.968, -9674.294, -9731.924, -9788.862, -9845.113000000001, -9900.68, -9955.567, -10009.777, -10063.315, -10116.185, -10168.39, -10219.933, -10270.818000000001, -10321.049, -10370.629, -10419.561, -10467.849, -10515.496000000001, -10562.505, -10608.878999999999, -10654.622, -10699.736, -10744.225, -10788.091, -10831.337, -10873.966999999999, -10915.983, -10957.388, -10998.184, -11038.375, -11077.962, -11116.948999999999, -11155.338, -11193.132, -11230.333, -11266.944, -11302.966, -11338.403, -11373.257, -11407.53, -11441.223999999998, -11474.341, -11506.883999999998, -11538.854, -11570.255, -11601.088, -11631.355, -11661.058, -11690.198999999999, -11718.78, -11746.802, -11774.268999999998, -11801.181999999999, -11827.542, -11853.351, -11878.611, -11903.323, -11927.491000000002, -11951.114, -11974.196000000002, -11996.737, -12018.738000000001, -12040.202, -12061.13, -12081.524, -12101.386, -12120.715, -12139.515, -12157.785, -12175.528999999999, -12192.747, -12209.44, -12225.61, -12241.258, -12256.385, -12270.993, -12285.082, -12298.653999999999, -12311.71, -12324.252, -12336.28, -12347.795, -12358.798, -12369.291000000001, -12379.275, -12388.75, -12397.718, -12406.178999999998, -12414.135, -12421.585, -12428.532, -12434.988000000001, -12440.93, -12446.371000000001, -12451.311000000002, -12455.752, -12459.693000000001, -12463.136999999999, -12466.083, -12468.533000000001, -12470.487, -12471.946000000002, -12472.91, -12473.38, -12473.357, -12472.841999999999, -12471.833999999999, -12470.335, -12468.345, -12465.864, -12462.893, -12459.433, -12455.483999999999, -12451.046999999999, -12446.121000000001, -12440.708, -12434.808, -12428.421, -12421.546999999999, -12414.187, -12406.341999999999, -12398.011, -12389.195, -12379.893999999998, -12370.108999999999, -12359.839, -12349.085, -12337.847, -12326.125, -12313.92, -12301.232, -12288.06, -12274.405, -12260.268, -12245.646999999999, -12230.544, -12214.958, -12198.889, -12182.338, -12165.305, -12147.788, -12129.788999999999, -12111.306999999999, -12092.341999999999, -12072.895, -12052.966, -12032.553, -12011.656, -11990.277, -11968.413999999999, -11946.068000000001, -11923.238000000001, -11899.923999999999, -11876.126, -11851.844, -11827.076000000001, -11801.823999999999, -11776.087, -11749.864, -11723.156, -11695.962, -11668.281, -11640.113000000001, -11611.458, -11582.315, -11552.684, -11522.565, -11491.957, -11460.858999999999, -11429.271, -11397.193000000001, -11364.623, -11331.563, -11298.01, -11263.965, -11229.427, -11194.393999999998, -11158.867, -11122.845, -11086.327, -11049.312, -11011.801000000001, -10973.791000000001, -10935.283000000001, -10896.275, -10856.767, -10816.758, -10776.247, -10735.233999999999, -10693.718, -10651.696000000002, -10609.17, -10566.136999999999, -10522.597, -10478.549, -10433.992, -10388.925, -10343.347, -10297.257, -10250.653, -10203.536, -10155.903, -10107.754, -10059.088, -10009.902, -9960.197, -9909.971, -9859.222, -9807.95, -9756.154, -9703.831, -9650.981, -9597.603000000001, -9543.694, -9489.254, -9434.282, -9378.775, -9322.733, -9266.154, -9209.036, -9151.379, -9093.18, -9034.438, -8975.152, -8915.32, -8854.94, -8794.01, -8732.529, -8670.496, -8607.909, -8544.767, -8481.065999999999, -8416.805, -8351.984, -8286.599, -8220.65, -8154.134, -8087.05, -8019.395, -7951.168000000001, -7882.366999999999, -7812.9890000000005, -7743.035, -7672.5, -7601.383000000001, -7529.682, -7457.395, -7384.52, -7311.056, -7236.999, -7162.348000000001, -7087.101, -7011.255999999999, -6934.81, -6857.763000000001, -6780.111, -6701.852, -6622.984, -6543.505, -6463.4130000000005, -6382.706999999999, -6301.384, -6219.44, -6136.876, -6053.688, -5969.874, -5885.434, -5800.3640000000005, -5714.661999999999, -5628.326, -5541.355, -5453.746999999999, -5365.501, -5276.613, -5187.082, -5096.907, -5006.085999999999, -4914.619000000001, -4822.503, -4729.736, -4636.318, -4542.248, -4447.525, -4352.148, -4256.116, -4159.429, -4062.086, -3964.0879999999997, -3865.4359999999997, -3766.1279999999997, -3666.165, -3565.55, -3464.282, -3362.365, -3259.7990000000004, -3156.587, -3052.7329999999997, -2948.238, -2843.1079999999997, -2737.348, -2630.962, -2523.955, -2416.335, -2308.109, -2199.286, -2089.875, -1979.886, -1869.3310000000001, -1758.223, -1646.576, -1534.406, -1421.731, -1308.5710000000001, -1194.9460000000001, -1080.88, -966.4, -851.533, -736.313, -620.774, -504.95300000000003, -388.895, -272.645, -156.254, -39.779, 76.718, 193.169, 309.498, 425.62300000000005, 541.453, 656.888, 771.818, 886.122, 999.6669999999999, 1112.307, 1223.879, 1334.21, 1443.104, 1550.349, 1655.714, 1758.945, 1859.765, 1957.874, 2052.945, 2144.625, 2232.5370000000003, 2316.274, 2395.405, 2469.474, 2538.006, 2600.506, 2656.472, 2705.397, 2746.78, 2780.136, 2805.011, 2820.994, 2827.7290000000003, 2824.9320000000002, 2812.401, 2790.0240000000003, 2757.788, 2715.784, 2664.199, 2603.315, 2533.5029999999997, 2455.2, 2368.909, 2275.1710000000003, 2174.561, 2067.663, 1955.068, 1837.3529999999998, 1715.0810000000001, 1588.789, 1458.9820000000002, 1326.135, 1190.6889999999999, 1053.047, 913.581, 772.627, 630.492, 487.449, 343.74699999999996, 199.606, 55.225, -89.219, -233.57, -377.689, -521.452, -664.7510000000001, -807.49, -949.585, -1090.96, -1231.552, -1371.3029999999999, -1510.1660000000002, -1648.096, -1785.056, -1921.016, -2055.949, -2189.8289999999997, -2322.64, -2454.365, -2584.991, -2714.506, -2842.9040000000005, -2970.177, -3096.322, -3221.335, -3345.216, -3467.962, -3589.577, -3710.063, -3829.421, -3947.655, -4064.77, -4180.77, -4295.661, -4409.4490000000005, -4522.139, -4633.738, -4744.254, -4853.693, -4962.062, -5069.369000000001, -5175.621, -5280.826, -5384.991999999999, -5488.1269999999995, -5590.238, -5691.3330000000005, -5791.42, -5890.508000000001, -5988.603, -6085.714, -6181.849, -6277.016, -6371.221, -6464.472, -6556.779, -6648.149, -6738.5869999999995, -6828.103, -6916.703, -7004.396, -7091.186, -7177.081999999999, -7262.092, -7346.222, -7429.477, -7511.866999999999, -7593.397, -7674.071999999999, -7753.901, -7832.89, -7911.044, -7988.37, -8064.874, -8140.562, -8215.44, -8289.514000000001, -8362.789, -8435.271999999999, -8506.968, -8577.882, -8648.019, -8717.385, -8785.985999999999, -8853.827, -8920.911, -8987.246, -9052.835, -9117.683, -9181.795, -9245.176, -9307.831, -9369.764000000001, -9430.979, -9491.48, -9551.273000000001, -9610.362, -9668.751, -9726.443000000001, -9783.443000000001, -9839.755, -9895.383, -9950.331, -10004.603000000001, -10058.201, -10111.131, -10163.396, -10214.999, -10265.944, -10316.234, -10365.873, -10414.864, -10463.211, -10510.916000000001, -10557.983, -10604.415, -10650.215, -10695.386999999999, -10739.933, -10783.857, -10827.16, -10869.846000000001, -10911.918, -10953.38, -10994.232, -11034.478000000001, -11074.122, -11113.163999999999, -11151.608999999999, -11189.458, -11226.714, -11263.378999999999, -11299.456, -11334.948, -11369.856000000002, -11404.181999999999, -11437.93, -11471.101, -11503.697, -11535.722, -11567.176000000001, -11598.061000000002, -11628.381000000001, -11658.136, -11687.329, -11715.963, -11744.038, -11771.556999999999, -11798.521, -11824.931999999999, -11850.792, -11876.104, -11900.868, -11925.087, -11948.761, -11971.893, -11994.483999999999, -12016.537, -12038.051000000001, -12059.03, -12079.473, -12099.383999999998, -12118.763, -12137.613000000001, -12155.933, -12173.726, -12190.993, -12207.735, -12223.953000000001, -12239.65, -12254.826000000001, -12269.482, -12283.62, -12297.24, -12310.344, -12322.934, -12335.008999999998, -12346.572, -12357.624, -12368.163999999999, -12378.195, -12387.716999999999, -12396.732, -12405.24, -12413.243, -12420.741000000002, -12427.733999999999, -12434.225, -12440.213, -12445.701000000001, -12450.688, -12455.175, -12459.163, -12462.653, -12465.646, -12468.141000000001, -12470.142, -12471.646999999999, -12472.657, -12473.171999999999, -12473.195, -12472.725, -12471.761999999999, -12470.308, -12468.364, -12465.928, -12463.002, -12459.587, -12455.683, -12451.29, -12446.409, -12441.041000000001, -12435.185, -12428.841999999999, -12422.013, -12414.697, -12406.896, -12398.608999999999, -12389.837, -12380.579, -12370.837, -12360.611, -12349.9, -12338.706, -12327.028, -12314.866000000002, -12302.221000000001, -12289.091999999999, -12275.48, -12261.385, -12246.808, -12231.748, -12216.204, -12200.178, -12183.669, -12166.678, -12149.204, -12131.247, -12112.808, -12093.885, -12074.48, -12054.591999999999, -12034.221000000001, -12013.366000000002, -11992.028, -11970.208, -11947.903, -11925.115, -11901.841999999999, -11878.086000000001, -11853.845, -11829.118999999999, -11803.908000000001, -11778.212, -11752.031, -11725.363000000001, -11698.208999999999, -11670.569, -11642.443000000001, -11613.828000000001, -11584.726, -11555.136, -11525.056999999999, -11494.489, -11463.431, -11431.883999999998, -11399.847, -11367.318000000001, -11334.296999999999, -11300.785, -11266.778999999999, -11232.28, -11197.288, -11161.801000000001, -11125.819, -11089.341, -11052.366000000002, -11014.895, -10976.925, -10938.456, -10899.488000000001, -10860.02, -10820.05, -10779.579, -10738.605, -10697.128, -10655.146, -10612.658000000001, -10569.665, -10526.163999999999, -10482.155, -10437.636999999999, -10392.61, -10347.071, -10301.019, -10254.455, -10207.376, -10159.782, -10111.671999999999, -10063.045, -10013.898000000001, -9964.232, -9914.044, -9863.334, -9812.101, -9760.343, -9708.059000000001, -9655.248, -9601.908000000001, -9548.038, -9493.636999999999, -9438.703000000001, -9383.235, -9327.231, -9270.69, -9213.610999999999, -9155.991, -9097.831, -9039.128, -8979.88, -8920.085, -8859.743, -8798.851999999999, -8737.41, -8675.416, -8612.867, -8549.761, -8486.098, -8421.876, -8357.093, -8291.747, -8225.836, -8159.358, -8092.311, -8024.695, -7956.505999999999, -7887.743, -7818.404, -7748.486, -7677.9890000000005, -7606.91, -7535.2480000000005, -7462.999, -7390.161999999999, -7316.735, -7242.715999999999, -7168.104, -7092.895, -7017.088000000001, -6940.68, -6863.67, -6786.055, -6707.834, -6629.005, -6549.564, -6469.51, -6388.840999999999, -6307.554, -6225.649, -6143.1230000000005, -6059.973000000001, -5976.196999999999, -5891.794, -5806.762, -5721.097, -5634.799, -5547.866, -5460.295, -5372.085999999999, -5283.235, -5193.742, -5103.604, -5012.82, -4921.39, -4829.311, -4736.581, -4643.2, -4549.166, -4454.48, -4359.139, -4263.144, -4166.4929999999995, -4069.1859999999997, -3971.225, -3872.607, -3773.3340000000003, -3673.407, -3572.8259999999996, -3471.594, -3369.71, -3267.178, -3164.0, -3060.178, -2955.717, -2850.62, -2744.8909999999996, -2638.5359999999996, -2531.56, -2423.97, -2315.774, -2206.979, -2097.596, -1987.6329999999998, -1877.104, -1766.02, -1654.3970000000002, -1542.25, -1429.5970000000002, -1316.455, -1202.848, -1088.798, -974.332, -859.4780000000001, -744.2669999999999, -628.735, -512.919, -396.861, -280.60900000000004, -164.21200000000002, -47.727, 68.78399999999999, 185.25400000000002, 301.608, 417.764, 533.631, 649.11, 764.092, 878.456, 992.071, 1104.79, 1216.454, 1326.888, 1435.9, 1543.277, 1648.7910000000002, 1752.1879999999999, 1853.195, 1951.5120000000002, 2046.8139999999999, 2138.751, 2226.946, 2310.995, 2390.469, 2464.9139999999998, 2533.856, 2596.802, 2653.25, 2702.6940000000004, 2744.631, 2778.577, 2804.0759999999996, 2820.711, 2828.1259999999997, 2826.03, 2814.2140000000004, 2792.562, 2761.053, 2719.7690000000002, 2668.893, 2608.699, 2539.552, 2461.885, 2376.195, 2283.022, 2182.936, 2076.5229999999997, 1964.372, 1847.06, 1725.152, 1599.1860000000001, 1469.6689999999999, 1337.079, 1201.858, 1064.412, 925.115, 784.306, 642.2919999999999, 499.35, 355.72900000000004, 211.653, 67.322, -77.086, -221.41400000000002, -365.522, -509.283, -652.59, -795.345, -937.4630000000001, -1078.868, -1219.495, -1359.2879999999998, -1498.1960000000001, -1636.1760000000002, -1773.191, -1909.2079999999999, -2044.2, -2178.144, -2311.02, -2442.813, -2573.508, -2703.095, -2831.565, -2958.9120000000003, -3085.132, -3210.222, -3334.178, -3457.0029999999997, -3578.697, -3699.261, -3818.698, -3937.012, -4054.2070000000003, -4170.287, -4285.258, -4399.127, -4511.898, -4623.5779999999995, -4734.174, -4843.693, -4952.143, -5059.53, -5165.862, -5271.148, -5375.394, -5478.608, -5580.798000000001, -5681.973000000001, -5782.139, -5881.305, -5979.479, -6076.669, -6172.882, -6268.126, -6362.409000000001, -6455.738, -6548.1230000000005, -6639.569, -6730.0830000000005, -6819.675, -6908.351, -6996.118, -7082.983, -7168.954000000001, -7254.0380000000005, -7338.241999999999, -7421.571, -7504.034000000001, -7585.6359999999995, -7666.384, -7746.285, -7825.346, -7903.571999999999, -7980.969, -8057.544, -8133.303000000001, -8208.252, -8282.395, -8355.74, -8428.292, -8500.056999999999, -8571.04, -8641.246, -8710.68, -8779.349, -8847.257, -8914.409, -8980.81, -9046.466, -9111.381, -9175.559000000001, -9239.006, -9301.726, -9363.724, -9425.005, -9485.571, -9545.429, -9604.581, -9663.034, -9720.79, -9777.854, -9834.229, -9889.92, -9944.93, -9999.265, -10052.925, -10105.917, -10158.244, -10209.908000000001, -10260.914, -10311.265, -10360.965, -10410.017, -10458.424, -10506.188999999998, -10553.316, -10599.808, -10645.667, -10690.899, -10735.503999999999, -10779.486, -10822.848, -10865.591999999999, -10907.723, -10949.242, -10990.152, -11030.456, -11070.157, -11109.256000000001, -11147.758, -11185.663999999999, -11222.976, -11259.698, -11295.831, -11331.378999999999, -11366.343, -11400.725, -11434.528, -11467.753999999999, -11500.405, -11532.485, -11563.993999999999, -11594.934, -11625.308, -11655.117, -11684.365, -11713.052, -11741.181, -11768.753, -11795.771, -11822.235, -11848.149, -11873.513, -11898.33, -11922.601, -11946.328000000001, -11969.511999999999, -11992.156, -12014.26, -12035.827, -12056.857, -12077.351999999999, -12097.313999999998, -12116.743999999999, -12135.645, -12154.016000000001, -12171.86, -12189.177, -12205.97, -12222.239, -12237.986, -12253.212, -12267.919, -12282.106000000002, -12295.776000000002, -12308.93, -12321.569, -12333.693000000001, -12345.306, -12356.406, -12366.996000000001, -12377.075, -12386.646, -12395.71, -12404.266000000001, -12412.317, -12419.863000000001, -12426.905, -12433.444, -12439.48, -12445.016000000001, -12450.05, -12454.585, -12458.62, -12462.158000000001, -12465.197, -12467.74, -12469.788, -12471.339, -12472.396, -12472.958999999999, -12473.028, -12472.604, -12471.688, -12470.28, -12468.382, -12465.992, -12463.113000000001, -12459.743, -12455.885, -12451.537, -12446.702, -12441.378999999999, -12435.569, -12429.271, -12422.487, -12415.216, -12407.46, -12399.218, -12390.491000000002, -12381.278, -12371.581, -12361.399, -12350.733, -12339.583, -12327.948999999999, -12315.831, -12303.23, -12290.146, -12276.578000000001, -12262.527, -12247.993, -12232.976, -12217.476999999999, -12201.493999999999, -12185.028999999999, -12168.08, -12150.65, -12132.736, -12114.34, -12095.461000000001, -12076.098999999998, -12056.253, -12035.925, -12015.113000000001, -11993.818000000001, -11972.04, -11949.778, -11927.032, -11903.802, -11880.088, -11855.889, -11831.206, -11806.037, -11780.383, -11754.243, -11727.618, -11700.506000000001, -11672.908000000001, -11644.823, -11616.25, -11587.19, -11557.641000000001, -11527.603000000001, -11497.077, -11466.061000000002, -11434.555, -11402.559, -11370.071000000002, -11337.091999999999, -11303.62, -11269.656, -11235.198, -11200.247, -11164.801000000001, -11128.86, -11092.421999999999, -11055.488000000001, -11018.056999999999, -10980.128, -10941.7, -10902.773000000001, -10863.345, -10823.415, -10782.983999999999, -10742.051000000001, -10700.614, -10658.673, -10616.225, -10573.271999999999, -10529.811000000002, -10485.841999999999, -10441.365, -10396.377, -10350.878, -10304.867, -10258.341999999999, -10211.304, -10163.749, -10115.679, -10067.091, -10017.985, -9968.358, -9918.21, -9867.54, -9816.346, -9764.628, -9712.383, -9659.612, -9606.311, -9552.48, -9498.119, -9443.224, -9387.796, -9331.831, -9275.329, -9218.289, -9160.71, -9102.589, -9043.925, -8984.716, -8924.961, -8864.658000000001, -8803.806, -8742.403, -8680.448, -8617.938, -8554.872, -8491.248, -8427.065, -8362.32, -8297.013, -8231.141, -8164.701999999999, -8097.695, -8030.116999999999, -7961.968000000001, -7893.243, -7823.943, -7754.065, -7683.607, -7612.566999999999, -7540.943, -7468.733, -7395.935, -7322.547, -7248.566999999999, -7173.993, -7098.8240000000005, -7023.055, -6946.686, -6869.715, -6792.139, -6713.956999999999, -6635.166, -6555.764, -6475.749, -6395.119000000001, -6313.871, -6232.005, -6149.517, -6066.405, -5982.668000000001, -5898.304, -5813.31, -5727.684, -5641.425, -5554.53, -5466.996999999999, -5378.826, -5290.014, -5200.559, -5110.459, -5019.714, -4928.321, -4836.28, -4743.588, -4650.245, -4556.249, -4461.6, -4366.295999999999, -4270.338, -4173.724, -4076.455, -3978.53, -3879.949, -3780.712, -3680.821, -3580.276, -3479.079, -3377.2309999999998, -3274.7329999999997, -3171.59, -3067.802, -2963.3740000000003, -2858.31, -2752.614, -2646.2909999999997, -2539.346, -2431.7870000000003, -2323.621, -2214.856, -2105.501, -1995.566, -1885.0629999999999, -1774.005, -1662.406, -1550.2820000000002, -1437.65, -1324.529, -1210.94, -1096.906, -982.455, -867.613, -752.4119999999999, -636.887, -521.076, -405.02, -288.765, -172.362, -55.867, 60.656000000000006, 177.146, 293.525, 409.711, 525.616, 641.14, 756.174, 870.5989999999999, 984.284, 1097.085, 1208.8419999999999, 1319.381, 1428.511, 1536.024, 1641.6889999999999, 1745.256, 1846.451, 1944.979, 2040.516, 2132.7129999999997, 2221.196, 2305.562, 2385.385, 2460.212, 2529.57, 2592.969, 2649.908, 2699.8779999999997, 2742.38, 2776.927, 2803.059, 2820.36, 2828.466, 2827.083, 2815.9970000000003, 2795.083, 2764.315, 2723.768, 2673.616, 2614.129, 2545.6620000000003, 2468.645, 2383.571, 2290.976, 2191.429, 2085.513, 1973.816, 1856.9189999999999, 1735.385, 1609.754, 1480.536, 1348.21, 1213.221, 1075.9769999999999, 936.8539999999999, 796.193, 654.304, 511.466, 367.931, 223.923, 79.643, -64.72800000000001, -209.032, -353.126, -496.88599999999997, -640.2, -782.97, -925.11, -1066.594, -1207.21, -1347.0439999999999, -1485.9979999999998, -1624.0279999999998, -1761.098, -1897.1729999999998, -2032.226, -2166.234, -2299.177, -2431.038, -2561.804, -2691.4629999999997, -2820.007, -2947.43, -3073.725, -3198.8920000000003, -3322.928, -3445.8309999999997, -3567.605, -3688.2490000000003, -3807.7659999999996, -3926.1620000000003, -4043.438, -4159.6, -4274.653, -4388.603, -4501.456, -4613.219, -4723.897, -4833.498, -4942.03, -5049.499, -5155.913, -5261.28, -5365.607, -5468.901999999999, -5571.174, -5672.429, -5772.675, -5871.922, -5970.1759999999995, -6067.445, -6163.738, -6259.061, -6353.422, -6446.831, -6539.293000000001, -6630.816, -6721.409000000001, -6811.078, -6899.831, -6987.674, -7074.616999999999, -7160.6630000000005, -7245.821999999999, -7330.101, -7413.505999999999, -7496.043000000001, -7577.719, -7658.5419999999995, -7738.517, -7817.65, -7895.948, -7973.419, -8050.066, -8125.897, -8200.916, -8275.132, -8348.548, -8421.171, -8493.006, -8564.059000000001, -8634.335, -8703.839, -8772.576, -8840.554, -8907.774, -8974.244, -9039.966999999999, -9104.949, -9169.196, -9232.71, -9295.497, -9357.561, -9418.908000000001, -9479.54, -9539.464, -9598.681999999999, -9657.2, -9715.021, -9772.149, -9828.589, -9884.344000000001, -9939.419, -9993.815999999999, -10047.54, -10100.595, -10152.985, -10204.712, -10255.78, -10306.194, -10355.955, -10405.069, -10453.537, -10501.364, -10548.552, -10595.105, -10641.025, -10686.317, -10730.982, -10775.023000000001, -10818.445, -10861.25, -10903.44, -10945.017, -10985.986, -11026.348999999998, -11066.108, -11105.266000000001, -11143.826000000001, -11181.788999999999, -11219.16, -11255.938999999998, -11292.13, -11327.733999999999, -11362.755, -11397.193000000001, -11431.053, -11464.336000000001, -11497.044, -11529.178999999998, -11560.743, -11591.739, -11622.169, -11652.034, -11681.337, -11710.079, -11738.261999999999, -11765.889, -11792.961000000001, -11819.481000000002, -11845.448, -11870.866000000002, -11895.737, -11920.061000000002, -11943.841999999999, -11967.08, -11989.777, -12011.934, -12033.553, -12054.636, -12075.184, -12095.198999999999, -12114.681999999999, -12133.633999999998, -12152.056999999999, -12169.953000000001, -12187.322, -12204.167, -12220.487, -12236.285, -12251.562, -12266.319, -12280.558, -12294.278999999999, -12307.483999999999, -12320.173, -12332.348, -12344.011, -12355.162, -12365.801000000001, -12375.931, -12385.551000000001, -12394.663999999999, -12403.27, -12411.371000000001, -12418.966, -12426.056999999999, -12432.645, -12438.73, -12444.313999999998, -12449.396999999999, -12453.98, -12458.065, -12461.65, -12464.738000000001, -12467.329, -12469.425, -12471.024, -12472.128999999999, -12472.739, -12472.856000000002, -12472.479, -12471.611, -12470.25, -12468.399, -12466.056999999999, -12463.223999999998, -12459.901000000002, -12456.09, -12451.79, -12447.001, -12441.723999999998, -12435.96, -12429.708, -12422.97, -12415.746000000001, -12408.035, -12399.84, -12391.158000000001, -12381.991000000002, -12372.339, -12362.203000000001, -12351.582, -12340.478000000001, -12328.889, -12316.817, -12304.26, -12291.221000000001, -12277.698, -12263.692, -12249.203000000001, -12234.231000000002, -12218.776000000002, -12202.838, -12186.417, -12169.513, -12152.127, -12134.258, -12115.905, -12097.07, -12077.751, -12057.95, -12037.665, -12016.898000000001, -11995.646999999999, -11973.912, -11951.693000000001, -11928.991000000002, -11905.805, -11882.133999999998, -11857.978000000001, -11833.338, -11808.212, -11782.601, -11756.503999999999, -11729.921999999999, -11702.853000000001, -11675.298, -11647.255, -11618.725, -11589.707, -11560.201000000001, -11530.207, -11499.722, -11468.749, -11437.285, -11405.331, -11372.885, -11339.948999999999, -11306.518999999998, -11272.597, -11238.181, -11203.271999999999, -11167.867, -11131.968, -11095.572, -11058.68, -11021.291000000001, -10983.403, -10945.017, -10906.131000000001, -10866.745, -10826.857, -10786.468, -10745.575, -10704.178999999998, -10662.278999999999, -10619.873, -10576.961000000001, -10533.542, -10489.614, -10445.177, -10400.23, -10354.771999999999, -10308.802, -10262.319, -10215.321, -10167.806999999999, -10119.778, -10071.231, -10022.165, -9972.579, -9922.471, -9871.841999999999, -9820.689, -9769.011, -9716.806999999999, -9664.076, -9610.815999999999, -9557.026, -9502.704, -9447.85, -9392.461, -9336.538, -9280.077, -9223.077, -9165.537, -9107.457, -9048.833, -8989.664, -8929.949, -8869.687, -8808.875, -8747.511999999999, -8685.597, -8623.127, -8560.101, -8496.518, -8432.375, -8367.671, -8302.403, -8236.571, -8170.172, -8103.204000000001, -8035.6669999999995, -7967.557, -7898.8730000000005, -7829.613, -7759.774, -7689.356, -7618.356, -7546.772, -7474.602, -7401.844, -7328.496, -7254.557, -7180.023, -7104.892, -7029.164000000001, -6952.834, -6875.903, -6798.368, -6720.225, -6641.474, -6562.111, -6482.1359999999995, -6401.545999999999, -6320.338000000001, -6238.5109999999995, -6156.063, -6072.991, -5989.294, -5904.969, -5820.014, -5734.428000000001, -5648.2080000000005, -5561.352, -5473.86, -5385.728, -5296.955, -5207.539000000001, -5117.479, -5026.773, -4935.419, -4843.416, -4750.763, -4657.459, -4563.501, -4468.89, -4373.625, -4277.705, -4181.129, -4083.8979999999997, -3986.01, -3887.466, -3788.2670000000003, -3688.413, -3587.905, -3486.743, -3384.9309999999996, -3282.47, -3179.362, -3075.6090000000004, -2971.216, -2866.185, -2760.5229999999997, -2654.2329999999997, -2547.321, -2439.7929999999997, -2331.658, -2222.923, -2113.597, -2003.69, -1893.215, -1782.183, -1670.609, -1558.5079999999998, -1445.898, -1332.7979999999998, -1219.2269999999999, -1105.211, -990.7739999999999, -875.944, -760.7539999999999, -645.237, -529.43, -413.376, -297.119, -180.71099999999998, -64.206, 52.333999999999996, 168.843, 285.247, 401.465, 517.408, 632.977, 748.064, 862.551, 976.308, 1089.191, 1201.042, 1311.6879999999999, 1420.9389999999999, 1528.588, 1634.4070000000002, 1738.145, 1839.533, 1938.275, 2034.05, 2126.511, 2215.286, 2299.974, 2380.15, 2455.365, 2525.146, 2589.005, 2646.441, 2696.947, 2740.022, 2775.178, 2801.955, 2819.9320000000002, 2828.742, 2828.086, 2817.743, 2797.5820000000003, 2767.57, 2727.7740000000003, 2678.361, 2619.594, 2551.823, 2475.471, 2391.027, 2299.024, 2200.027, 2094.621, 1983.391, 1866.9189999999999, 1745.769, 1620.4820000000002, 1491.5710000000001, 1359.516, 1224.765, 1087.729, 948.785, 808.278, 666.518, 523.7869999999999, 380.34, 236.40200000000002, 92.176, -52.157, -196.43400000000003, -340.515, -484.27099999999996, -627.592, -770.377, -912.54, -1054.006, -1194.7060000000001, -1334.5810000000001, -1473.582, -1611.664, -1748.789, -1884.9229999999998, -2020.0379999999998, -2154.111, -2287.121, -2419.052, -2549.89, -2679.6220000000003, -2808.241, -2935.74, -3062.113, -3187.3579999999997, -3311.474, -3434.4570000000003, -3556.312, -3677.038, -3796.637, -3915.115, -4032.474, -4148.719, -4263.856, -4377.889, -4490.825, -4602.670999999999, -4713.432, -4823.117, -4931.732, -5039.284000000001, -5145.782, -5251.232, -5355.641, -5459.019, -5561.3730000000005, -5662.71, -5763.039000000001, -5862.366999999999, -5960.701999999999, -6058.052, -6154.4259999999995, -6249.829000000001, -6344.271, -6437.759, -6530.3009999999995, -6621.904, -6712.575, -6802.323, -6891.154, -6979.075, -7066.095, -7152.219, -7237.455, -7321.81, -7405.291, -7487.904, -7569.656, -7650.554, -7730.603, -7809.811, -7888.184, -7965.728, -8042.4490000000005, -8118.353, -8193.445, -8267.734, -8341.222, -8413.917, -8485.824, -8556.948, -8627.294, -8696.869, -8765.677, -8833.724, -8901.015, -8967.554, -9033.347, -9098.398000000001, -9162.713, -9226.295, -9289.15, -9351.282, -9412.696, -9473.396, -9533.386, -9592.671, -9651.255, -9709.143, -9766.337, -9822.841999999999, -9878.663, -9933.802, -9988.264000000001, -10042.053, -10095.171999999999, -10147.626, -10199.417, -10250.549, -10301.025, -10350.85, -10400.026, -10448.558, -10496.447, -10543.697, -10590.311000000002, -10636.294, -10681.646999999999, -10726.373, -10770.476, -10813.958, -10856.823, -10899.073999999999, -10940.712, -10981.741000000002, -11022.163, -11061.981000000002, -11101.198999999999, -11139.818000000001, -11177.841, -11215.268999999998, -11252.108, -11288.357, -11324.018999999998, -11359.098, -11393.594, -11427.511999999999, -11460.851999999999, -11493.617, -11525.809, -11557.431, -11588.483, -11618.969, -11648.89, -11678.25, -11707.048, -11735.287, -11762.97, -11790.097, -11816.671999999999, -11842.695, -11868.168, -11893.093, -11917.473, -11941.308, -11964.6, -11987.351, -12009.562, -12031.235, -12052.372, -12072.973999999998, -12093.042, -12112.578000000001, -12131.583, -12150.06, -12168.008, -12185.431, -12202.328000000001, -12218.701000000001, -12234.551000000001, -12249.88, -12264.688999999998, -12278.98, -12292.753, -12306.008999999998, -12318.75, -12330.976999999999, -12342.69, -12353.892, -12364.583, -12374.763, -12384.435, -12393.598, -12402.255, -12410.405, -12418.051000000001, -12425.192, -12431.83, -12437.965, -12443.598999999998, -12448.731000000002, -12453.364, -12457.498, -12461.133, -12464.271, -12466.911, -12469.055, -12470.704, -12471.857, -12472.516000000001, -12472.681, -12472.353000000001, -12471.533000000001, -12470.221000000001, -12468.417, -12466.123, -12463.338, -12460.063, -12456.3, -12452.046999999999, -12447.306, -12442.077, -12436.36, -12430.155, -12423.464, -12416.287, -12408.624, -12400.475, -12391.84, -12382.719, -12373.114, -12363.024, -12352.45, -12341.392, -12329.85, -12317.823, -12305.313, -12292.32, -12278.843, -12264.883, -12250.44, -12235.513, -12220.103000000001, -12204.211000000001, -12187.835, -12170.976999999999, -12153.636, -12135.812, -12117.503999999999, -12098.714, -12079.441, -12059.684, -12039.444, -12018.722, -11997.515, -11975.825, -11953.651000000002, -11930.993, -11907.851, -11884.223999999998, -11860.113000000001, -11835.517, -11810.435, -11784.868, -11758.815, -11732.277, -11705.252, -11677.74, -11649.741000000002, -11621.255, -11592.281, -11562.818000000001, -11532.867, -11502.426000000001, -11471.496000000001, -11440.076000000001, -11408.163999999999, -11375.761999999999, -11342.868, -11309.482, -11275.603000000001, -11241.23, -11206.363000000001, -11171.002, -11135.145, -11098.793, -11061.943000000001, -11024.596000000001, -10986.751, -10948.408000000001, -10909.565, -10870.221000000001, -10830.375, -10790.028, -10749.178, -10707.825, -10665.966999999999, -10623.603000000001, -10580.733, -10537.356000000002, -10493.471000000001, -10449.076, -10404.171, -10358.755, -10312.826, -10266.384, -10219.429, -10171.958, -10123.97, -10075.464, -10026.44, -9976.895, -9926.83, -9876.242, -9825.131, -9773.495, -9721.332, -9668.642, -9615.424, -9561.676, -9507.395, -9452.582, -9397.235, -9341.351999999999, -9284.933, -9227.975, -9170.476999999999, -9112.437, -9053.854, -8994.726999999999, -8935.054, -8874.832, -8814.062, -8752.74, -8690.865, -8628.437, -8565.452, -8501.91, -8437.808, -8373.145, -8307.919, -8242.128, -8175.77, -8108.844, -8041.347, -7973.278, -7904.635, -7835.416, -7765.619000000001, -7695.241, -7624.281999999999, -7552.74, -7480.611, -7407.893, -7334.585999999999, -7260.687, -7186.194, -7111.105, -7035.4169999999995, -6959.129, -6882.2390000000005, -6804.743, -6726.642, -6647.932, -6568.61, -6488.6759999999995, -6408.126, -6326.96, -6245.173000000001, -6162.766, -6079.734, -5996.076999999999, -5911.793000000001, -5826.879, -5741.3330000000005, -5655.154, -5568.339, -5480.887, -5392.795, -5304.062, -5214.687, -5124.667, -5034.001, -4942.687, -4850.724, -4758.111, -4664.847, -4570.929, -4476.358, -4381.1320000000005, -4285.251, -4188.714, -4091.5209999999997, -3993.672, -3895.167, -3796.006, -3696.19, -3595.719, -3494.595, -3392.82, -3290.3959999999997, -3187.324, -3083.607, -2979.2490000000003, -2874.2540000000004, -2768.6259999999997, -2662.369, -2555.49, -2447.995, -2339.8920000000003, -2231.188, -2121.8920000000003, -2012.014, -1901.567, -1790.5620000000001, -1679.014, -1566.9370000000001, -1454.35, -1341.271, -1227.72, -1113.721, -999.3, -884.4839999999999, -769.304, -653.795, -537.993, -421.94, -305.682, -189.268, -72.753, 43.802, 160.33, 276.76, 393.009, 508.98900000000003, 624.604, 739.745, 854.296, 968.125, 1081.0910000000001, 1193.038, 1303.792, 1413.1660000000002, 1520.954, 1626.9279999999999, 1730.8410000000001, 1832.424, 1931.384, 2027.4, 2120.13, 2209.201, 2294.217, 2374.7529999999997, 2450.361, 2520.572, 2584.899, 2642.84, 2693.8909999999996, 2737.55, 2773.327, 2800.76, 2819.425, 2828.953, 2829.0370000000003, 2819.452, 2800.059, 2770.8190000000004, 2731.7909999999997, 2683.134, 2625.1040000000003, 2558.045, 2482.374, 2398.577, 2307.18, 2208.749, 2103.865, 1993.115, 1877.079, 1756.3229999999999, 1631.391, 1502.796, 1371.021, 1236.515, 1099.693, 960.933, 820.584, 678.9580000000001, 536.339, 392.98199999999997, 249.11599999999999, 104.946, -39.346, -183.59599999999998, -327.66200000000003, -471.414, -614.74, -757.54, -899.727, -1041.222, -1181.958, -1321.876, -1460.924, -1599.058, -1736.2379999999998, -1872.432, -2007.611, -2141.749, -2274.828, -2406.83, -2537.74, -2667.548, -2796.243, -2923.8190000000004, -3050.272, -3175.597, -3299.7929999999997, -3422.8590000000004, -3544.795, -3665.605, -3785.288, -3903.85, -4021.2929999999997, -4137.622, -4252.843, -4366.962, -4479.983, -4591.914000000001, -4702.76, -4812.53, -4921.23, -5028.867, -5135.4490000000005, -5240.983, -5345.477, -5448.939, -5551.3769999999995, -5652.798000000001, -5753.21, -5852.621, -5951.039000000001, -6048.472, -6144.928000000001, -6240.4130000000005, -6334.937, -6428.505999999999, -6521.129, -6612.812, -6703.564, -6793.392, -6882.302, -6970.303000000001, -7057.401999999999, -7143.605, -7228.919, -7313.352, -7396.91, -7479.601, -7561.429, -7642.404, -7722.53, -7801.814, -7880.263000000001, -7957.882, -8034.678000000001, -8110.656, -8185.8240000000005, -8260.186, -8333.747, -8406.515, -8478.495, -8549.692, -8620.110999999999, -8689.758, -8758.638, -8826.756, -8894.118, -8960.726999999999, -9026.591, -9091.713, -9156.097, -9219.749, -9282.674, -9344.875, -9406.357, -9467.125, -9527.184000000001, -9586.537, -9645.189, -9703.143, -9760.404, -9816.976999999999, -9872.864, -9928.069, -9982.597, -10036.452, -10089.638, -10142.155999999999, -10194.011999999999, -10245.209, -10295.75, -10345.639000000001, -10394.879, -10443.474, -10491.427, -10538.74, -10585.418, -10631.463, -10676.878, -10721.667, -10765.832, -10809.377, -10852.303999999998, -10894.615, -10936.315, -10977.406, -11017.889, -11057.768, -11097.046, -11135.725, -11173.808, -11211.296999999999, -11248.194, -11284.502, -11320.225, -11355.363000000001, -11389.918, -11423.893999999998, -11457.293, -11490.116000000002, -11522.367, -11554.046, -11585.157, -11615.7, -11645.678999999998, -11675.096000000001, -11703.951000000001, -11732.247, -11759.986, -11787.17, -11813.801000000001, -11839.881000000001, -11865.41, -11890.392, -11914.827, -11938.716999999999, -11962.065, -11984.872, -12007.138, -12028.866000000002, -12050.056999999999, -12070.713, -12090.836000000001, -12110.427, -12129.487, -12148.017, -12166.02, -12183.496000000001, -12200.447, -12216.873, -12232.777, -12248.16, -12263.021999999999, -12277.365, -12291.191, -12304.5, -12317.294, -12329.573, -12341.338, -12352.591999999999, -12363.335, -12373.567, -12383.291000000001, -12392.506000000001, -12401.214, -12409.416000000001, -12417.113000000001, -12424.306, -12430.995, -12437.181, -12442.865, -12448.048, -12452.732, -12456.916000000001, -12460.601999999999, -12463.788999999999, -12466.48, -12468.673999999999, -12470.372, -12471.576000000001, -12472.284, -12472.499, -12472.22, -12471.448999999999, -12470.187, -12468.431999999999, -12466.187, -12463.451000000001, -12460.225, -12456.51, -12452.306999999999, -12447.614, -12442.433, -12436.765, -12430.608999999999, -12423.966, -12416.836000000001, -12409.221000000001, -12401.12, -12392.533000000001, -12383.46, -12373.903, -12363.861, -12353.333999999999, -12342.323, -12330.828000000001, -12318.848999999998, -12306.386, -12293.438999999998, -12280.008999999998, -12266.096000000001, -12251.698999999999, -12236.819, -12221.456, -12205.61, -12189.281, -12172.469, -12155.173999999999, -12137.396999999999, -12119.135, -12100.391000000001, -12081.163999999999, -12061.453000000001, -12041.26, -12020.582, -11999.421, -11977.777, -11955.648000000001, -11933.035, -11909.938999999998, -11886.357, -11862.291000000001, -11837.74, -11812.704, -11787.181999999999, -11761.175, -11734.681, -11707.701000000001, -11680.233999999999, -11652.278999999999, -11623.838, -11594.908000000001, -11565.49, -11535.583999999999, -11505.187, -11474.301000000001, -11442.925, -11411.059, -11378.701000000001, -11345.851, -11312.508, -11278.673, -11244.344, -11209.521999999999, -11174.204, -11138.392, -11102.083, -11065.277, -11027.973999999998, -10990.171999999999, -10951.872, -10913.072, -10873.771999999999, -10833.97, -10793.666000000001, -10752.858999999999, -10711.548999999999, -10669.735, -10627.413999999999, -10584.587, -10541.253, -10497.411, -10453.06, -10408.197, -10362.824, -10316.939, -10270.54, -10223.627, -10176.199, -10128.254, -10079.791, -10030.809000000001, -9981.306999999999, -9931.284, -9880.739, -9829.671, -9778.077, -9725.957, -9673.31, -9620.134, -9566.428, -9512.190999999999, -9457.42, -9402.115, -9346.275, -9289.898000000001, -9232.982, -9175.527, -9117.529, -9058.988000000001, -8999.904, -8940.273000000001, -8880.094000000001, -8819.365, -8758.085, -8696.253, -8633.867, -8570.925, -8507.425, -8443.365, -8378.743, -8313.56, -8247.811, -8181.495, -8114.611, -8047.156, -7979.129, -7910.528, -7841.351, -7771.596, -7701.2609999999995, -7630.344, -7558.843000000001, -7486.755999999999, -7414.081, -7340.816, -7266.959, -7192.507, -7117.46, -7041.815, -6965.569, -6888.72, -6811.267, -6733.206999999999, -6654.539000000001, -6575.259, -6495.366, -6414.859, -6333.734, -6251.99, -6169.624, -6086.634, -6003.019, -5918.776, -5833.904, -5748.4, -5662.262, -5575.4890000000005, -5488.079000000001, -5400.028, -5311.3369999999995, -5222.002, -5132.024, -5041.399, -4950.126, -4858.204000000001, -4765.6320000000005, -4672.409000000001, -4578.532, -4484.001, -4388.815, -4292.974, -4196.478, -4099.325, -4001.515, -3903.05, -3803.928, -3704.151, -3603.719, -3502.633, -3400.8959999999997, -3298.509, -3195.475, -3091.795, -2987.474, -2882.515, -2776.922, -2670.7, -2563.855, -2456.393, -2348.322, -2239.65, -2130.385, -2020.537, -1910.119, -1799.142, -1687.62, -1575.568, -1463.005, -1349.9470000000001, -1236.4160000000002, -1122.4360000000001, -1008.0310000000001, -893.2289999999999, -778.06, -662.559, -546.763, -430.712, -314.452, -198.033, -81.508, 35.061, 151.61, 268.064, 384.345, 500.36400000000003, 616.025, 731.221, 845.835, 959.738, 1072.789, 1184.8319999999999, 1295.697, 1405.195, 1513.1229999999998, 1619.255, 1723.346, 1825.1270000000002, 1924.307, 2020.569, 2113.571, 2202.9429999999998, 2288.291, 2369.192, 2445.2, 2515.848, 2580.649, 2639.1040000000003, 2690.708, 2734.96, 2771.367, 2799.468, 2818.835, 2829.092, 2829.93, 2821.117, 2802.508, 2774.055, 2735.81, 2687.926, 2630.6490000000003, 2564.3179999999998, 2489.345, 2406.208, 2315.4339999999997, 2217.5820000000003, 2113.234, 2002.976, 1887.388, 1767.0379999999998, 1642.469, 1514.1979999999999, 1382.711, 1248.4569999999999, 1111.855, 973.2860000000001, 833.1, 691.6110000000001, 549.107, 405.844, 262.05400000000003, 117.941, -26.308000000000003, -170.53, -314.579, -458.32599999999996, -601.658, -744.472, -886.682, -1028.345, -1168.979, -1308.94, -1448.036, -1586.2220000000002, -1723.4589999999998, -1859.714, -1994.9560000000001, -2129.1620000000003, -2262.31, -2394.384, -2525.368, -2655.252, -2784.0240000000003, -2911.68, -3038.2129999999997, -3163.619, -3287.8979999999997, -3411.047, -3533.067, -3653.961, -3773.7290000000003, -3892.3759999999997, -4009.905, -4126.321, -4241.628, -4355.833, -4468.941, -4580.958, -4691.891, -4801.747, -4910.534000000001, -5018.2570000000005, -5124.925, -5230.545, -5335.125, -5438.673000000001, -5541.196, -5642.701999999999, -5743.1990000000005, -5842.694, -5941.196999999999, -6038.714, -6135.253000000001, -6230.821999999999, -6325.429, -6419.081, -6511.786, -6603.552, -6694.3859999999995, -6784.295, -6873.286, -6961.366999999999, -7048.547, -7134.83, -7220.224, -7304.736999999999, -7388.374, -7471.142, -7553.05, -7634.102, -7714.306, -7793.6669999999995, -7872.193, -7949.889, -8026.7609999999995, -8102.815, -8178.058000000001, -8252.495, -8326.132, -8398.974, -8471.028, -8542.299, -8612.792, -8682.511999999999, -8751.466, -8819.655999999999, -8887.09, -8953.771999999999, -9019.707, -9084.9, -9149.356, -9213.079, -9276.074, -9338.345, -9399.898000000001, -9460.735999999999, -9520.863000000001, -9580.286, -9639.006, -9697.029, -9754.359, -9810.999, -9866.954, -9922.226999999999, -9976.822, -10030.744, -10083.996, -10136.581, -10188.503, -10239.766, -10290.373, -10340.328000000001, -10389.633, -10438.292, -10486.31, -10533.688, -10580.43, -10626.538999999999, -10672.018, -10716.87, -10761.098999999998, -10804.707, -10847.697, -10890.071000000002, -10931.833, -10972.986, -11013.53, -11053.471000000001, -11092.811000000002, -11131.552, -11169.696000000002, -11207.245, -11244.204, -11280.573, -11316.356000000002, -11351.553, -11386.169, -11420.205, -11453.663, -11486.546, -11518.856000000002, -11550.594, -11581.764, -11612.367, -11642.403999999999, -11671.878, -11700.792, -11729.146, -11756.944, -11784.186000000002, -11810.874, -11837.01, -11862.597, -11887.635, -11912.128, -11936.075, -11959.479, -11982.341, -12004.663999999999, -12026.448999999999, -12047.696000000002, -12068.408000000001, -12088.586000000001, -12108.232, -12127.347, -12145.933, -12163.991000000002, -12181.521, -12198.527, -12215.008, -12230.966999999999, -12246.403, -12261.32, -12275.716999999999, -12289.596000000001, -12302.958999999999, -12315.806, -12328.139, -12339.958, -12351.265, -12362.061000000002, -12372.347, -12382.123, -12391.391000000001, -12400.152, -12408.406, -12416.156, -12423.4, -12430.141000000001, -12436.378999999999, -12442.115, -12447.35, -12452.085, -12456.321000000002, -12460.058, -12463.296999999999, -12466.038, -12468.284, -12470.033000000001, -12471.287, -12472.046, -12472.312, -12472.083999999999, -12471.363000000001, -12470.151000000002, -12468.447, -12466.251, -12463.566, -12460.39, -12456.723999999998, -12452.57, -12447.927, -12442.796, -12437.176000000001, -12431.07, -12424.476, -12417.396, -12409.829, -12401.777, -12393.239, -12384.215, -12374.706, -12364.713, -12354.235, -12343.271999999999, -12331.825, -12319.893999999998, -12307.479, -12294.581, -12281.198999999999, -12267.333, -12252.983999999999, -12238.151000000002, -12222.836000000001, -12207.038, -12190.756000000001, -12173.992, -12156.743999999999, -12139.013, -12120.798999999999, -12102.101999999999, -12082.921999999999, -12063.258, -12043.111, -12022.48, -12001.366000000002, -11979.768, -11957.686000000002, -11935.12, -11912.069, -11888.534, -11864.514, -11840.01, -11815.02, -11789.544, -11763.582, -11737.133999999998, -11710.2, -11682.778, -11654.87, -11626.473999999998, -11597.59, -11568.216999999999, -11538.356000000002, -11508.006000000001, -11477.165, -11445.833999999999, -11414.013, -11381.7, -11348.895, -11315.598, -11281.808, -11247.524, -11212.746000000001, -11177.473999999998, -11141.705, -11105.441, -11068.681, -11031.421999999999, -10993.665, -10955.409, -10916.653999999999, -10877.398000000001, -10837.641000000001, -10797.382, -10756.618999999999, -10715.353000000001, -10673.582, -10631.306, -10588.524, -10545.233999999999, -10501.436000000002, -10457.128, -10412.31, -10366.982, -10321.14, -10274.785, -10227.916, -10180.530999999999, -10132.63, -10084.211, -10035.273000000001, -9985.815, -9935.836, -9885.335, -9834.31, -9782.76, -9730.684000000001, -9678.08, -9624.947, -9571.285, -9517.091, -9462.364, -9407.103000000001, -9351.306, -9294.972, -9238.1, -9180.687, -9122.733, -9064.235999999999, -9005.194, -8945.607, -8885.471, -8824.785, -8763.549, -8701.76, -8639.417, -8576.518, -8513.061, -8449.044, -8384.466, -8319.326, -8253.62, -8187.347, -8120.505999999999, -8053.095, -7985.111, -7916.553000000001, -7847.419, -7777.706999999999, -7707.415, -7636.541, -7565.0830000000005, -7493.039000000001, -7420.406999999999, -7347.185, -7273.371999999999, -7198.963000000001, -7123.959, -7048.356, -6972.153, -6895.347, -6817.938, -6739.920999999999, -6661.295, -6582.059, -6502.209, -6421.744000000001, -6340.661999999999, -6258.96, -6176.637, -6093.691, -6010.119000000001, -5925.919, -5841.089, -5755.628000000001, -5669.533, -5582.802, -5495.434, -5407.4259999999995, -5318.776999999999, -5229.485, -5139.549, -5048.965999999999, -4957.735, -4865.855, -4773.326, -4680.143, -4586.308, -4491.819, -4396.675, -4300.876, -4204.42, -4107.308, -4009.539, -3911.114, -3812.032, -3712.295, -3611.903, -3510.857, -3409.159, -3306.81, -3203.8140000000003, -3100.172, -2995.888, -2890.965, -2785.409, -2679.223, -2572.413, -2464.986, -2356.948, -2248.308, -2139.075, -2029.259, -1918.87, -1807.921, -1696.4260000000002, -1584.401, -1471.861, -1358.826, -1245.316, -1131.355, -1016.966, -902.178, -787.0210000000001, -671.529, -555.739, -439.69, -323.42900000000003, -207.00400000000002, -90.47, 26.114, 142.68200000000002, 259.163, 375.476, 491.534, 607.241, 722.492, 837.171, 951.148, 1064.2839999999999, 1176.4260000000002, 1287.402, 1397.027, 1505.0970000000002, 1611.389, 1715.66, 1817.641, 1917.045, 2013.556, 2106.834, 2196.511, 2282.195, 2363.466, 2439.88, 2510.971, 2576.254, 2635.23, 2687.397, 2732.2490000000003, 2769.298, 2798.077, 2818.156, 2829.155, 2830.76, 2822.7329999999997, 2804.921, 2777.27, 2739.824, 2692.728, 2636.22, 2570.632, 2496.3720000000003, 2413.911, 2323.772, 2226.515, 2122.715, 2012.961, 1897.832, 1777.8970000000002, 1653.7020000000002, 1525.764, 1394.5720000000001, 1260.578, 1124.202, 985.83, 845.81, 704.4639999999999, 562.078, 418.912, 275.199, 131.14700000000002, -13.057, -157.249, -301.281, -445.023, -588.359, -731.188, -873.419, -1014.9739999999999, -1155.7839999999999, -1295.787, -1434.932, -1573.172, -1710.4660000000001, -1846.781, -1982.089, -2116.363, -2249.5820000000003, -2381.728, -2512.788, -2642.748, -2771.6, -2899.335, -3025.95, -3151.4390000000003, -3275.801, -3399.035, -3521.14, -3642.12, -3761.974, -3880.708, -3998.324, -4114.827, -4230.222, -4344.515, -4457.71, -4569.816, -4680.837, -4790.781, -4899.655, -5007.465999999999, -5114.221, -5219.929, -5324.596, -5428.231, -5530.840999999999, -5632.433000000001, -5733.016, -5832.598000000001, -5931.186, -6028.789000000001, -6125.4130000000005, -6221.066, -6315.758000000001, -6409.494000000001, -6502.283, -6594.132, -6685.049, -6775.041, -6864.115, -6952.279, -7039.539000000001, -7125.903, -7211.379, -7295.972, -7379.69, -7462.539000000001, -7544.525, -7625.656999999999, -7705.939, -7785.38, -7863.983, -7941.757, -8018.706999999999, -8094.838000000001, -8170.158, -8244.671, -8318.385, -8391.303, -8463.431999999999, -8534.779, -8605.346, -8675.141, -8744.168, -8812.433, -8879.94, -8946.696, -9012.704, -9077.969000000001, -9142.497, -9206.292, -9269.359, -9331.702, -9393.325, -9454.234, -9514.431999999999, -9573.925, -9632.716, -9690.808, -9748.207, -9804.917, -9860.94, -9916.282, -9970.946, -10024.936, -10078.255, -10130.908000000001, -10182.896999999999, -10234.226999999999, -10284.901, -10334.921999999999, -10384.294, -10433.02, -10481.103000000001, -10528.546999999999, -10575.354, -10621.528, -10667.072, -10711.99, -10756.282, -10799.954, -10843.008, -10885.446000000002, -10927.271999999999, -10968.487, -11009.096000000001, -11049.1, -11088.502, -11127.305, -11165.511, -11203.123, -11240.143999999998, -11276.575, -11312.418, -11347.678, -11382.354, -11416.451000000001, -11449.97, -11482.913999999999, -11515.284, -11547.082, -11578.312, -11608.973999999998, -11639.071000000002, -11668.605, -11697.578000000001, -11725.991000000002, -11753.848, -11781.148000000001, -11807.895, -11834.09, -11859.733999999999, -11884.831, -11909.381000000001, -11933.386, -11956.847, -11979.767, -12002.148000000001, -12023.989, -12045.293, -12066.062, -12086.296999999999, -12105.999, -12125.171, -12143.813, -12161.926000000001, -12179.513, -12196.573999999999, -12213.111, -12229.125, -12244.617, -12259.589, -12274.041000000001, -12287.975, -12301.392, -12314.294, -12326.681999999999, -12338.555, -12349.916000000001, -12360.766000000001, -12371.106000000002, -12380.936000000002, -12390.258, -12399.072, -12407.38, -12415.181999999999, -12422.48, -12429.274, -12435.565, -12441.354, -12446.642, -12451.43, -12455.718, -12459.507, -12462.798, -12465.591999999999, -12467.889, -12469.691, -12470.996000000001, -12471.806999999999, -12472.124, -12471.948, -12471.278999999999, -12470.117, -12468.464, -12466.32, -12463.685, -12460.56, -12456.946000000002, -12452.841999999999, -12448.25, -12443.169, -12437.6, -12431.543, -12425.0, -12417.97, -12410.453000000001, -12402.451000000001, -12393.962, -12384.988000000001, -12375.528999999999, -12365.585, -12355.157, -12344.243, -12332.845, -12320.963, -12308.598, -12295.749, -12282.415, -12268.598, -12254.298, -12239.514, -12224.247, -12208.498, -12192.265, -12175.548, -12158.348999999998, -12140.666000000001, -12122.5, -12103.851999999999, -12084.719, -12065.103000000001, -12045.003999999999, -12024.421, -12003.354, -11981.803999999998, -11959.768999999998, -11937.251, -11914.248, -11890.76, -11866.787, -11842.33, -11817.386999999999, -11791.958, -11766.043, -11739.642, -11712.755, -11685.38, -11657.518999999998, -11629.17, -11600.332, -11571.006000000001, -11541.191, -11510.886999999999, -11480.093, -11448.809, -11417.033000000001, -11384.766000000001, -11352.008, -11318.757, -11285.013, -11250.775, -11216.043, -11180.816, -11145.094, -11108.876, -11072.161, -11034.948, -10997.237, -10959.027, -10920.317, -10881.107, -10841.395, -10801.181, -10760.464, -10719.243, -10677.518, -10635.287, -10592.55, -10549.305, -10505.552, -10461.289, -10416.517, -10371.233, -10325.437, -10279.127, -10232.302, -10184.963, -10137.106, -10088.732, -10039.84, -9990.426, -9940.492, -9890.035, -9839.055, -9787.55, -9735.518, -9682.959, -9629.872, -9576.254, -9522.104, -9467.421999999999, -9412.205, -9356.453000000001, -9300.163, -9243.336, -9185.968, -9128.058, -9069.605, -9010.608, -8951.065, -8890.974, -8830.333, -8769.141, -8707.396, -8645.097, -8582.243, -8518.83, -8454.858, -8390.324, -8325.226999999999, -8259.565999999999, -8193.338, -8126.541, -8059.174, -7991.234, -7922.721, -7853.630999999999, -7783.963000000001, -7713.715, -7642.8859999999995, -7571.472, -7499.473000000001, -7426.885, -7353.706999999999, -7279.937, -7205.5740000000005, -7130.613, -7055.055, -6978.896, -6902.134, -6824.769, -6746.795999999999, -6668.214, -6589.022, -6509.217, -6428.795999999999, -6347.758000000001, -6266.1, -6183.821, -6100.919, -6017.391, -5933.235, -5848.4490000000005, -5763.031999999999, -5676.981, -5590.294, -5502.969, -5415.005, -5326.399, -5237.151, -5147.259, -5056.719, -4965.532, -4873.696, -4781.209, -4688.069, -4594.277, -4499.831, -4404.73, -4308.972, -4212.559, -4115.4890000000005, -4017.762, -3919.3790000000004, -3820.3379999999997, -3720.6420000000003, -3620.2909999999997, -3519.2859999999996, -3417.6279999999997, -3315.3190000000004, -3212.362, -3108.759, -3004.514, -2899.6290000000004, -2794.11, -2687.961, -2581.187, -2473.795, -2365.792, -2257.186, -2147.985, -2038.201, -1927.8429999999998, -1816.9229999999998, -1705.4560000000001, -1593.4579999999999, -1480.943, -1367.932, -1254.443, -1140.501, -1026.13, -911.357, -796.212, -680.73, -564.945, -448.9, -332.63800000000003, -216.208, -99.664, 16.934, 133.52200000000002, 250.028, 366.374, 482.471, 598.226, 713.5319999999999, 828.2760000000001, 942.329, 1055.55, 1167.79, 1278.88, 1388.632, 1496.8470000000002, 1603.3020000000001, 1707.755, 1809.94, 1909.5720000000001, 2006.335, 2099.894, 2189.881, 2275.907, 2357.555, 2434.381, 2505.922, 2571.695, 2631.202, 2683.94, 2729.405, 2767.107, 2796.5759999999996, 2817.38, 2829.136, 2831.5240000000003, 2824.298, 2807.302, 2780.4709999999995, 2743.842, 2697.551, 2641.8309999999997, 2577.005, 2503.475, 2421.7070000000003, 2332.222, 2235.573, 2132.337, 2023.101, 1908.445, 1788.9370000000001, 1665.126, 1537.5320000000002, 1406.6429999999998, 1272.917, 1136.774, 998.6039999999999, 858.757, 717.558, 575.294, 432.22900000000004, 288.597, 144.608, 0.45, -143.711, -287.724, -431.46, -574.8009999999999, -717.643, -859.8969999999999, -1001.4830000000001, -1142.33, -1282.376, -1421.569, -1559.862, -1697.2160000000001, -1833.594, -1968.967, -2103.31, -2236.601, -2368.822, -2499.9570000000003, -2629.9959999999996, -2758.929, -2886.7459999999996, -3013.4440000000004, -3139.0170000000003, -3263.465, -3386.784, -3508.9770000000003, -3630.0440000000003, -3749.986, -3868.808, -3986.513, -4103.106, -4218.59, -4332.972, -4446.258, -4558.452, -4669.563, -4779.597, -4888.56, -4996.46, -5103.305, -5209.102, -5313.859, -5417.581, -5520.28, -5621.960999999999, -5722.630999999999, -5822.3009999999995, -5920.977, -6018.666, -6115.3769999999995, -6211.116999999999, -6305.894, -6399.717, -6492.590999999999, -6584.525, -6675.526999999999, -6765.603, -6854.76, -6943.008000000001, -7030.352, -7116.799, -7202.357, -7287.031999999999, -7370.831999999999, -7453.763000000001, -7535.831, -7617.043000000001, -7697.406, -7776.9259999999995, -7855.609, -7933.4619999999995, -8010.491, -8086.701, -8162.1, -8236.690999999999, -8310.482, -8383.478000000001, -8455.684000000001, -8527.106, -8597.75, -8667.621, -8736.724, -8805.064, -8872.646, -8939.476999999999, -9005.559000000001, -9070.898000000001, -9135.5, -9199.369, -9262.508, -9324.924, -9386.62, -9447.601, -9507.871, -9567.435, -9626.296999999999, -9684.461, -9741.931, -9798.71, -9854.804, -9910.216, -9964.95, -10019.009, -10072.398000000001, -10125.119, -10177.177, -10228.576, -10279.318000000001, -10329.405999999999, -10378.845, -10427.638, -10475.789, -10523.298999999999, -10570.173, -10616.413999999999, -10662.024, -10707.007, -10751.366000000002, -10795.103000000001, -10838.222, -10880.726, -10922.616000000002, -10963.896, -11004.569, -11044.636999999999, -11084.103000000001, -11122.97, -11161.239, -11198.913999999999, -11235.998, -11272.492, -11308.398000000001, -11343.72, -11378.458999999999, -11412.618, -11446.198999999999, -11479.204, -11511.635, -11543.496000000001, -11574.786, -11605.508999999998, -11635.667, -11665.261, -11694.294, -11722.768, -11750.684, -11778.045, -11804.851, -11831.106000000002, -11856.81, -11881.966, -11906.575, -11930.638, -11954.159, -11977.138, -11999.576000000001, -12021.475, -12042.838, -12063.665, -12083.957, -12103.716999999999, -12122.946000000002, -12141.645, -12159.815, -12177.458999999999, -12194.577, -12211.171, -12227.241000000002, -12242.79, -12257.818000000001, -12272.326000000001, -12286.317, -12299.79, -12312.747, -12325.19, -12337.118999999999, -12348.536, -12359.441, -12369.835, -12379.72, -12389.096000000001, -12397.966, -12406.328000000001, -12414.185, -12421.537, -12428.385, -12434.731000000002, -12440.573999999999, -12445.915, -12450.757, -12455.098, -12458.941, -12462.286, -12465.132, -12467.483, -12469.337, -12470.696000000002, -12471.56, -12471.928999999998, -12471.805, -12471.188, -12470.079, -12468.479, -12466.386999999999, -12463.803999999998, -12460.731000000002, -12457.168, -12453.116000000002, -12448.576000000001, -12443.546, -12438.028999999999, -12432.024, -12425.532, -12418.553, -12411.087, -12403.135, -12394.698, -12385.775, -12376.367, -12366.473, -12356.094, -12345.231000000002, -12333.883999999998, -12322.052, -12309.737, -12296.937, -12283.653999999999, -12269.886999999999, -12255.636999999999, -12240.903, -12225.686000000002, -12209.986, -12193.802, -12177.135, -12159.985, -12142.351999999999, -12124.235, -12105.635, -12086.552, -12066.985, -12046.934, -12026.4, -12005.382, -11983.881000000001, -11961.895, -11939.423999999999, -11916.47, -11893.031, -11869.107, -11844.697, -11819.802, -11794.421999999999, -11768.555, -11742.202, -11715.363000000001, -11688.036, -11660.222, -11631.921, -11603.131000000001, -11573.853000000001, -11544.085, -11513.828000000001, -11483.082, -11451.845, -11420.117, -11387.898000000001, -11355.186000000002, -11321.982, -11288.286, -11254.095, -11219.41, -11184.231000000002, -11148.555, -11112.383999999998, -11075.716, -11038.55, -11000.885, -10962.722, -10924.059, -10884.895, -10845.23, -10805.062, -10764.392, -10723.218, -10681.538999999999, -10639.354, -10596.663, -10553.465, -10509.758, -10465.542, -10420.815, -10375.578000000001, -10329.827, -10283.564, -10236.786, -10189.492, -10141.681999999999, -10093.354, -10044.507, -9995.139000000001, -9945.251, -9894.84, -9843.905999999999, -9792.446, -9740.46, -9687.947, -9634.905, -9581.333, -9527.229, -9472.591999999999, -9417.421999999999, -9361.715, -9305.472, -9248.689, -9191.367, -9133.503, -9075.096, -9016.144, -8956.646, -8896.6, -8836.005, -8774.858, -8713.16, -8650.905999999999, -8588.097, -8524.729, -8460.803, -8396.315, -8331.264000000001, -8265.646999999999, -8199.465, -8132.714, -8065.392, -7997.4980000000005, -7929.03, -7859.986, -7790.363, -7720.161, -7649.376, -7578.007, -7506.053000000001, -7433.5109999999995, -7360.379, -7286.654, -7212.335999999999, -7137.420999999999, -7061.908, -6985.795, -6909.079000000001, -6831.758000000001, -6753.831, -6675.295, -6596.147, -6516.387, -6436.0109999999995, -6355.019, -6273.406999999999, -6191.173000000001, -6108.316, -6024.8330000000005, -5940.722, -5855.981, -5770.609, -5684.603, -5597.960999999999, -5510.681, -5422.762, -5334.201999999999, -5244.9980000000005, -5155.15, -5064.655, -4973.512, -4881.721, -4789.278, -4696.182, -4602.434, -4508.032, -4412.975, -4317.2609999999995, -4220.891, -4123.865, -4026.1809999999996, -3927.84, -3828.843, -3729.1890000000003, -3628.8790000000004, -3527.915, -3426.298, -3324.031, -3221.115, -3117.552, -3013.345, -2908.5, -2803.0190000000002, -2696.908, -2590.1710000000003, -2482.8160000000003, -2374.848, -2266.277, -2157.11, -2047.3570000000002, -1937.031, -1826.142, -1714.704, -1602.733, -1490.244, -1377.256, -1263.7910000000002, -1149.869, -1035.515, -920.757, -805.6260000000001, -690.153, -574.375, -458.334, -342.07099999999997, -225.636, -109.083, 7.53, 124.137, 240.669, 357.04699999999997, 473.185, 588.987, 704.35, 819.159, 933.289, 1046.6, 1158.941, 1270.145, 1380.0279999999998, 1488.389, 1595.0079999999998, 1699.646, 1802.039, 1901.9, 1998.92, 2092.762, 2183.064, 2269.438, 2351.467, 2428.7110000000002, 2500.708, 2566.978, 2627.0229999999997, 2680.341, 2726.428, 2764.792, 2794.962, 2816.5040000000004, 2829.0290000000005, 2832.2129999999997, 2825.804, 2809.637, 2783.6409999999996, 2747.844, 2702.375, 2647.4590000000003, 2583.411, 2510.627, 2429.569, 2340.751, 2244.726, 2142.0679999999998, 2033.362, 1919.19, 1800.12, 1676.704, 1549.461, 1418.884, 1285.433, 1149.53, 1011.567, 871.8989999999999, 730.8510000000001, 588.7130000000001, 445.75199999999995, 302.203, 158.279, 14.169, -129.958, -273.952, -417.68, -561.025, -703.8810000000001, -846.1569999999999, -987.6519999999999, -1128.657, -1268.747, -1407.99, -1546.3370000000002, -1683.75, -1820.191, -1955.631, -2090.044, -2223.408, -2355.7039999999997, -2486.917, -2617.036, -2746.05, -2873.95, -3000.732, -3126.3909999999996, -3250.925, -3374.3320000000003, -3496.613, -3617.7690000000002, -3737.801, -3856.7129999999997, -3974.508, -4091.191, -4206.766, -4321.2390000000005, -4434.616, -4546.901, -4658.103, -4768.228, -4877.282, -4985.273, -5092.209, -5198.096, -5302.943, -5406.755999999999, -5509.544, -5611.315, -5712.075, -5811.8330000000005, -5910.598000000001, -6008.375, -6105.175, -6201.003000000001, -6295.866999999999, -6389.776999999999, -6482.738, -6574.759, -6665.846, -6756.008000000001, -6845.251, -6933.584, -7021.012, -7107.543000000001, -7193.186, -7277.944, -7361.826999999999, -7444.84, -7526.991, -7608.285, -7688.73, -7768.331, -7847.095, -7925.029, -8002.138000000001, -8078.428000000001, -8153.906, -8228.577, -8302.446, -8375.521, -8447.805, -8519.305, -8590.026, -8659.974, -8729.154, -8797.571, -8865.229, -8932.135, -8998.293, -9063.708, -9128.384, -9192.328000000001, -9255.541, -9318.030999999999, -9379.801, -9440.855, -9501.199, -9560.835, -9619.769, -9678.005, -9735.546999999999, -9792.398000000001, -9848.564, -9904.046999999999, -9958.851, -10012.981, -10066.44, -10119.231, -10171.359, -10222.827, -10273.638, -10323.796, -10373.303, -10422.165, -10470.383, -10517.962, -10564.903999999999, -10611.211000000001, -10656.889, -10701.938999999998, -10746.365, -10790.168, -10833.353000000001, -10875.923, -10917.878999999999, -10959.225, -10999.963, -11040.096000000001, -11079.627, -11118.559, -11156.893, -11194.632, -11231.78, -11268.338, -11304.308, -11339.693000000001, -11374.495, -11408.718, -11442.361, -11475.428999999998, -11507.923, -11539.846000000001, -11571.198, -11601.983, -11632.203000000001, -11661.858999999999, -11690.953000000001, -11719.488000000001, -11747.466, -11774.886999999999, -11801.753999999999, -11828.069, -11853.833999999999, -11879.05, -11903.719, -11927.841999999999, -11951.421999999999, -11974.461000000001, -11996.958, -12018.917, -12040.338, -12061.223999999998, -12081.576000000001, -12101.393999999998, -12120.681, -12139.438999999998, -12157.667, -12175.368999999999, -12192.545, -12209.196000000002, -12225.323999999999, -12240.93, -12256.015, -12270.581, -12284.628, -12298.158000000001, -12311.173, -12323.671999999999, -12335.658000000001, -12347.13, -12358.091, -12368.542, -12378.483, -12387.915, -12396.84, -12405.258, -12413.17, -12420.577, -12427.481000000002, -12433.881000000001, -12439.778999999999, -12445.176000000001, -12450.072, -12454.468, -12458.365, -12461.764, -12464.665, -12467.069, -12468.978000000001, -12470.391000000001, -12471.308, -12471.731000000002, -12471.661, -12471.098, -12470.042, -12468.493999999999, -12466.456, -12463.926000000001, -12460.906, -12457.396, -12453.396, -12448.908000000001, -12443.931999999999, -12438.466, -12432.514, -12426.073999999999, -12419.148000000001, -12411.733999999999, -12403.833999999999, -12395.448, -12386.577, -12377.22, -12367.378, -12357.051000000001, -12346.24, -12334.943000000001, -12323.163, -12310.899, -12298.15, -12284.918, -12271.202, -12257.002, -12242.32, -12227.153, -12211.503, -12195.37, -12178.753, -12161.653999999999, -12144.071000000002, -12126.003999999999, -12107.454, -12088.421, -12068.903999999999, -12048.903999999999, -12028.42, -12007.451000000001, -11985.999, -11964.063, -11941.643, -11918.738000000001, -11895.347, -11871.472, -11847.112, -11822.266000000001, -11796.935, -11771.118, -11744.813999999998, -11718.023000000001, -11690.745, -11662.98, -11634.728000000001, -11605.987, -11576.757, -11547.038, -11516.83, -11486.132, -11454.943000000001, -11423.264, -11391.093, -11358.43, -11325.274, -11291.626, -11257.483, -11222.846000000001, -11187.715, -11152.087, -11115.964, -11079.343, -11042.225, -11004.608, -10966.492, -10927.877, -10888.761, -10849.143, -10809.024, -10768.401000000002, -10727.274, -10685.643, -10643.506000000001, -10600.862, -10557.711000000001, -10514.051000000001, -10469.883, -10425.203000000001, -10380.011999999999, -10334.309000000001, -10288.093, -10241.362, -10194.116, -10146.351999999999, -10098.071, -10049.271, -9999.951, -9950.109, -9899.746, -9848.858, -9797.445, -9745.506, -9693.04, -9640.045, -9586.519, -9532.462, -9477.873, -9422.748, -9367.088, -9310.891, -9254.155999999999, -9196.88, -9139.063, -9080.702, -9021.796999999999, -8962.346, -8902.347, -8841.798, -8780.698, -8719.046, -8656.839, -8594.076, -8530.756, -8466.875, -8402.433, -8337.429, -8271.86, -8205.723, -8139.018, -8071.743, -8003.896, -7935.474, -7866.476, -7796.9, -7726.745, -7656.007, -7584.685, -7512.776999999999, -7440.281, -7367.196, -7293.517, -7219.245, -7144.3769999999995, -7068.91, -6992.843000000001, -6916.174, -6838.899, -6761.018, -6682.529, -6603.428000000001, -6523.714, -6443.385, -6362.439, -6280.8730000000005, -6198.686, -6115.875, -6032.438, -5948.374, -5863.679, -5778.352, -5692.392, -5605.795999999999, -5518.563, -5430.69, -5342.175, -5253.018, -5163.215, -5072.766, -4981.669, -4889.923, -4797.525, -4704.476, -4610.773, -4516.416, -4421.403, -4325.734, -4229.409000000001, -4132.4259999999995, -4034.7859999999996, -3936.489, -3837.535, -3737.9240000000004, -3637.658, -3536.737, -3435.163, -3332.937, -3230.062, -3126.54, -3022.375, -2917.5690000000004, -2812.1279999999997, -2706.055, -2599.356, -2492.038, -2384.107, -2275.571, -2166.439, -2056.72, -1946.425, -1835.568, -1724.16, -1612.2160000000001, -1499.754, -1386.7920000000001, -1273.349, -1159.448, -1045.113, -930.3710000000001, -815.252, -699.79, -584.02, -467.981, -351.719, -235.27900000000002, -118.71700000000001, -2.09, 114.538, 231.09599999999998, 347.506, 463.684, 579.534, 694.954, 809.83, 924.0369999999999, 1037.437, 1149.88, 1261.2, 1371.214, 1479.723, 1586.509, 1691.3339999999998, 1793.9360000000001, 1894.031, 1991.31, 2085.44, 2176.062, 2262.785, 2345.201, 2422.869, 2495.33, 2562.1020000000003, 2622.6929999999998, 2676.598, 2723.316, 2762.3520000000003, 2793.235, 2815.525, 2828.8309999999997, 2832.823, 2827.244, 2811.921, 2786.775, 2751.827, 2707.195, 2653.099, 2589.846, 2517.823, 2437.49, 2349.354, 2253.967, 2151.9, 2043.7379999999998, 1930.0620000000001, 1811.443, 1688.43, 1561.5479999999998, 1431.2920000000001, 1298.123, 1162.4660000000001, 1024.7169999999999, 885.2330000000001, 744.3389999999999, 602.3330000000001, 459.47900000000004, 316.01599999999996, 172.15900000000002, 28.099, -115.994, -259.967, -403.686, -547.033, -689.9019999999999, -832.201, -973.846, -1114.768, -1254.902, -1394.195, -1532.598, -1670.07, -1806.575, -1942.082, -2076.5660000000003, -2210.004, -2342.376, -2473.669, -2603.868, -2732.9640000000004, -2860.949, -2987.817, -3113.563, -3238.184, -3361.6809999999996, -3484.051, -3605.296, -3725.42, -3844.423, -3962.31, -4079.0840000000003, -4194.752, -4309.317, -4422.786, -4535.164000000001, -4646.459, -4756.6759999999995, -4865.822, -4973.905, -5080.933, -5186.912, -5291.851, -5395.755, -5498.635, -5600.496, -5701.347, -5801.196999999999, -5900.05, -5997.918000000001, -6094.807, -6190.724, -6285.677, -6379.675, -6472.724, -6564.8330000000005, -6656.008000000001, -6746.257, -6835.5869999999995, -6924.005999999999, -7011.52, -7098.137, -7183.8640000000005, -7268.706999999999, -7352.674, -7435.772, -7518.005999999999, -7599.384, -7679.911999999999, -7759.595, -7838.441999999999, -7916.4580000000005, -7993.648, -8070.02, -8145.578, -8220.329, -8294.278, -8367.433, -8439.796999999999, -8511.376, -8582.176, -8652.202, -8721.46, -8789.954, -8857.690999999999, -8924.673, -8990.908000000001, -9056.399, -9121.152, -9185.17, -9248.46, -9311.025, -9372.869, -9433.998, -9494.415, -9554.126, -9613.134, -9671.443000000001, -9729.058, -9785.982, -9842.22, -9897.775, -9952.651, -10006.853000000001, -10060.383, -10113.245, -10165.444, -10216.983, -10267.864, -10318.091999999999, -10367.67, -10416.601, -10464.888, -10512.535, -10559.546, -10605.923, -10651.669, -10696.786, -10741.28, -10785.151000000002, -10828.403999999999, -10871.04, -10913.063, -10954.476, -10995.281, -11035.48, -11075.077, -11114.075, -11152.475, -11190.28, -11227.492, -11264.114, -11300.149, -11335.598999999998, -11370.466, -11404.752, -11438.46, -11471.591999999999, -11504.15, -11536.135, -11567.551000000001, -11598.399, -11628.681999999999, -11658.4, -11687.556999999999, -11716.155, -11744.194, -11771.677, -11798.606000000002, -11824.983, -11850.809, -11876.087, -11900.816, -11925.001, -11948.641000000001, -11971.74, -11994.298, -12016.317, -12037.798999999999, -12058.743999999999, -12079.156, -12099.034, -12118.381000000001, -12137.198, -12155.485, -12173.246000000001, -12190.481000000002, -12207.191, -12223.378, -12239.042, -12254.186000000002, -12268.81, -12282.915, -12296.503, -12309.575, -12322.131000000001, -12334.173999999999, -12345.705, -12356.723, -12367.231000000002, -12377.228000000001, -12386.718, -12395.698999999999, -12404.173999999999, -12412.142, -12419.606000000002, -12426.566, -12433.021999999999, -12438.976, -12444.428999999998, -12449.38, -12453.832, -12457.785, -12461.239, -12464.195, -12466.655, -12468.618, -12470.086000000001, -12471.058, -12471.536, -12471.52, -12471.011999999999, -12470.01, -12468.517, -12466.532, -12464.056999999999, -12461.09, -12457.633999999998, -12453.688999999998, -12449.253999999999, -12444.331, -12438.919, -12433.02, -12426.633999999998, -12419.76, -12412.4, -12404.553, -12396.22, -12387.402, -12378.098, -12368.308, -12358.034, -12347.275, -12336.031, -12324.303, -12312.091, -12299.393999999998, -12286.214, -12272.55, -12258.402, -12243.771, -12228.656, -12213.058, -12196.976, -12180.411, -12163.363000000001, -12145.831, -12127.816, -12109.317, -12090.335, -12070.868999999999, -12050.92, -12030.486, -12009.569, -11988.167, -11966.282, -11943.912, -11921.056999999999, -11897.718, -11873.893, -11849.583, -11824.787, -11799.506000000001, -11773.739, -11747.485, -11720.745, -11693.517, -11665.802, -11637.598999999998, -11608.908000000001, -11579.728000000001, -11550.058, -11519.9, -11489.252, -11458.113000000001, -11426.482, -11394.36, -11361.747, -11328.641000000001, -11295.041000000001, -11260.948, -11226.36, -11191.278, -11155.7, -11119.625, -11083.053, -11045.983999999999, -11008.416000000001, -10970.348999999998, -10931.783000000001, -10892.715, -10853.146999999999, -10813.075, -10772.501, -10731.423, -10689.841, -10647.752, -10605.157, -10562.053999999998, -10518.443000000001, -10474.323, -10429.692, -10384.549, -10338.894, -10292.726, -10246.044, -10198.845, -10151.13, -10102.896999999999, -10054.145, -10004.873, -9955.08, -9904.764000000001, -9853.924, -9802.559000000001, -9750.669, -9698.25, -9645.303, -9591.825, -9537.815999999999, -9483.275, -9428.198, -9372.586, -9316.437, -9259.749, -9202.521999999999, -9144.752, -9086.439, -9027.582, -8968.179, -8908.226999999999, -8847.726, -8786.674, -8725.069, -8662.91, -8600.195, -8536.923, -8473.09, -8408.696, -8343.739, -8278.216999999999, -8212.129, -8145.472, -8078.244000000001, -8010.445, -7942.071, -7873.12, -7803.592, -7733.484, -7662.794, -7591.52, -7519.659000000001, -7447.2119999999995, -7374.174, -7300.543000000001, -7226.318, -7151.4980000000005, -7076.079000000001, -7000.059, -6923.438, -6846.210999999999, -6768.378000000001, -6689.936, -6610.883000000001, -6531.217, -6450.935, -6370.036999999999, -6288.518, -6206.378000000001, -6123.615, -6040.226, -5956.209, -5871.562, -5786.283, -5700.37, -5613.821, -5526.635, -5438.809, -5350.342, -5261.231, -5171.476, -5081.0740000000005, -4990.023, -4898.3240000000005, -4805.973, -4712.97, -4619.313, -4525.002, -4430.036, -4334.413, -4238.133, -4141.196, -4043.6020000000003, -3945.35, -3846.44, -3746.8740000000003, -3646.652, -3545.775, -3444.244, -3342.062, -3239.2290000000003, -3135.75, -3031.625, -2926.861, -2821.46, -2715.427, -2608.768, -2501.488, -2393.595, -2285.095, -2175.998, -2066.314, -1956.0529999999999, -1845.227, -1733.85, -1621.935, -1509.501, -1396.5639999999999, -1283.145, -1169.265, -1054.9489999999998, -940.2239999999999, -825.1189999999999, -709.668, -593.905, -477.871, -361.608, -245.165, -128.593, -11.952, 104.696, 221.28, 337.723, 453.941, 569.84, 685.318, 800.2610000000001, 914.546, 1028.037, 1140.5819999999999, 1252.02, 1362.1670000000001, 1470.826, 1577.7820000000002, 1682.797, 1785.611, 1885.942, 1983.485, 2077.907, 2168.851, 2255.9320000000002, 2338.739, 2416.8379999999997, 2489.7670000000003, 2557.051, 2618.195, 2672.698, 2720.0559999999996, 2759.775, 2791.381, 2814.4320000000002, 2828.533, 2833.349, 2828.615, 2814.152, 2789.873, 2755.79, 2712.014, 2658.755, 2596.313, 2525.07, 2445.478, 2358.042, 2263.308, 2161.847, 2054.242, 1941.075, 1822.9170000000001, 1700.32, 1573.809, 1443.8829999999998, 1311.004, 1175.601, 1038.072, 898.7760000000001, 758.043, 616.1709999999999, 473.42800000000005, 330.05400000000003, 186.267, 42.25899999999999, -101.79700000000001, -245.748, -389.458, -532.807, -675.689, -818.0089999999999, -959.685, -1100.644, -1240.823, -1380.1660000000002, -1518.624, -1656.1570000000002, -1792.727, -1928.3020000000001, -2062.8579999999997, -2196.371, -2328.821, -2460.194, -2590.475, -2719.655, -2847.725, -2974.68, -3100.514, -3225.225, -3348.812, -3471.2729999999997, -3592.6079999999997, -3712.824, -3831.92, -3949.9, -4066.768, -4182.529, -4297.188, -4410.751, -4523.223, -4634.611, -4744.923, -4854.163, -4962.340999999999, -5069.462, -5175.535, -5280.566, -5384.564, -5487.536, -5589.4890000000005, -5690.433000000001, -5790.374, -5889.319, -5987.279, -6084.258000000001, -6180.266, -6275.31, -6369.397, -6462.536999999999, -6554.734, -6645.9980000000005, -6736.335, -6825.753000000001, -6914.26, -7001.861999999999, -7088.566, -7174.38, -7259.309, -7343.361999999999, -7426.545, -7508.8640000000005, -7590.326999999999, -7670.938, -7750.706999999999, -7829.637, -7907.735, -7985.009, -8061.463000000001, -8137.103, -8211.937, -8285.966999999999, -8359.202, -8431.646999999999, -8503.306999999999, -8574.187, -8644.293, -8713.63, -8782.203000000001, -8850.018, -8917.079, -8983.391, -9048.961, -9113.79, -9177.886, -9241.252, -9303.894, -9365.814, -9427.019, -9487.511, -9547.296999999999, -9606.38, -9664.764000000001, -9722.453000000001, -9779.451, -9835.763, -9891.391, -9946.34, -10000.615, -10054.216999999999, -10107.152, -10159.423, -10211.033000000001, -10261.985999999999, -10312.285, -10361.934000000001, -10410.936, -10459.294, -10507.011999999999, -10554.091999999999, -10600.538, -10646.353000000001, -10691.541000000001, -10736.103000000001, -10780.043, -10823.364, -10866.069, -10908.161, -10949.641000000001, -10990.513, -11030.78, -11070.444, -11109.508, -11147.975, -11185.846000000001, -11223.125, -11259.813999999998, -11295.915, -11331.431, -11366.363000000001, -11400.715, -11434.488000000001, -11467.684, -11500.306, -11532.357, -11563.837, -11594.749, -11625.095, -11654.878, -11684.098999999998, -11712.758999999998, -11740.862, -11768.408000000001, -11795.4, -11821.84, -11847.728000000001, -11873.068000000001, -11897.86, -11922.107, -11945.809, -11968.969, -11991.589, -12013.67, -12035.213, -12056.219, -12076.691, -12096.63, -12116.037, -12134.913999999999, -12153.263, -12171.083999999999, -12188.378, -12205.148000000001, -12221.393999999998, -12237.118, -12252.321000000002, -12267.003999999999, -12281.169, -12294.816, -12307.947, -12320.562, -12332.663999999999, -12344.253, -12355.329, -12365.895, -12375.951000000001, -12385.498, -12394.537, -12403.07, -12411.096000000001, -12418.616000000002, -12425.633, -12432.146999999999, -12438.158000000001, -12443.668, -12448.676000000001, -12453.185, -12457.194, -12460.704, -12463.716999999999, -12466.233, -12468.252, -12469.776000000002, -12470.803999999998, -12471.338, -12471.378, -12470.923999999999, -12469.978000000001, -12468.541000000001, -12466.611, -12464.191, -12461.278999999999, -12457.878, -12453.988000000001, -12449.608, -12444.739, -12439.382, -12433.537, -12427.205, -12420.386, -12413.08, -12405.287, -12397.008, -12388.243, -12378.993, -12369.258, -12359.037, -12348.331, -12337.141000000001, -12325.466, -12313.306999999999, -12300.663999999999, -12287.537, -12273.926000000001, -12259.832, -12245.253, -12230.191, -12214.645, -12198.616000000002, -12182.104, -12165.108, -12147.628, -12129.666000000001, -12111.219, -12092.288999999999, -12072.875, -12052.978000000001, -12032.596000000001, -12011.731000000002, -11990.381000000001, -11968.546999999999, -11946.229, -11923.426000000001, -11900.138, -11876.365, -11852.106000000002, -11827.363000000001, -11802.133, -11776.416000000001, -11750.214, -11723.524, -11696.348, -11668.684, -11640.531, -11611.891000000001, -11582.761999999999, -11553.143999999998, -11523.036, -11492.438, -11461.348999999998, -11429.77, -11397.698999999999, -11365.136, -11332.08, -11298.53, -11264.488000000001, -11229.95, -11194.918, -11159.39, -11123.365, -11086.844, -11049.825, -11012.306999999999, -10974.29, -10935.773000000001, -10896.756000000001, -10857.237, -10817.216, -10776.691, -10735.662, -10694.128999999999, -10652.09, -10609.545, -10566.492, -10522.93, -10478.859, -10434.278, -10389.185, -10343.58, -10297.461, -10250.827, -10203.678, -10156.013, -10107.829, -10059.126, -10009.904, -9960.16, -9909.893, -9859.103000000001, -9807.787, -9755.945, -9703.576, -9650.678, -9597.249, -9543.289, -9488.796999999999, -9433.77, -9378.207, -9322.106, -9265.468, -9208.289, -9150.568000000001, -9092.304, -9033.496, -8974.142, -8914.239, -8853.787, -8792.784, -8731.228000000001, -8669.118, -8606.452, -8543.228000000001, -8479.444, -8415.099, -8350.190999999999, -8284.719000000001, -8218.679, -8152.071, -8084.892, -8017.141, -7948.816, -7879.915, -7810.435, -7740.376, -7669.735, -7598.51, -7526.698, -7454.299, -7381.31, -7307.729, -7233.553000000001, -7158.781, -7083.411999999999, -7007.441, -6930.868, -6853.69, -6775.906, -6697.513000000001, -6618.508000000001, -6538.891, -6458.659000000001, -6377.809, -6296.339, -6214.2480000000005, -6131.533, -6048.193, -5964.224, -5879.626, -5794.395, -5708.531999999999, -5622.031999999999, -5534.894, -5447.116, -5358.698, -5269.635, -5179.928, -5089.5740000000005, -4998.572, -4906.92, -4814.617, -4721.662, -4628.053, -4533.789000000001, -4438.869000000001, -4343.294, -4247.061, -4150.17, -4052.623, -3954.417, -3855.554, -3756.033, -3655.857, -3555.025, -3453.538, -3351.3990000000003, -3248.61, -3145.1740000000004, -3041.093, -2936.3709999999996, -2831.011, -2725.0190000000002, -2618.4, -2511.159, -2403.304, -2294.842, -2185.782, -2076.133, -1965.906, -1855.114, -1743.7679999999998, -1631.8829999999998, -1519.477, -1406.566, -1293.172, -1179.3139999999999, -1065.018, -950.31, -835.22, -719.78, -604.025, -487.995, -371.733, -255.285, -138.705, -22.049, 94.618, 211.229, 327.705, 443.964, 559.9119999999999, 675.448, 790.459, 904.823, 1018.405, 1131.055, 1242.611, 1352.8929999999998, 1461.7060000000001, 1568.8329999999999, 1674.039, 1777.068, 1877.639, 1975.4479999999999, 2070.167, 2161.438, 2248.88, 2332.084, 2410.618, 2484.024, 2551.826, 2613.531, 2668.64, 2716.647, 2757.058, 2789.3990000000003, 2813.223, 2828.132, 2833.784, 2829.908, 2816.32, 2792.9240000000004, 2759.722, 2716.8179999999998, 2664.413, 2602.799, 2532.353, 2453.518, 2366.797, 2272.732, 2171.891, 2064.857, 1952.2120000000002, 1834.527, 1712.355, 1586.225, 1456.6370000000002, 1324.056, 1188.914, 1051.611, 912.51, 771.942, 630.2080000000001, 487.57800000000003, 344.29699999999997, 200.582, 56.629, -87.389, -231.31599999999997, -375.01599999999996, -518.367, -661.26, -803.6010000000001, -945.5930000000001, -1086.3039999999999, -1226.528, -1365.921, -1504.4360000000001, -1642.03, -1778.665, -1914.31, -2048.939, -2182.527, -2315.056, -2446.51, -2576.874, -2706.14, -2834.297, -2961.34, -3087.263, -3212.065, -3335.743, -3458.296, -3579.7270000000003, -3700.0359999999996, -3819.2259999999997, -3937.301, -4054.263, -4170.12, -4284.874, -4398.532, -4511.1, -4622.584, -4732.99, -4842.326, -4950.599, -5057.814, -5163.982, -5269.108, -5373.201, -5476.267, -5578.314, -5679.351, -5779.385, -5878.424, -5976.476, -6073.547, -6169.647, -6264.783, -6358.9619999999995, -6452.191999999999, -6544.48, -6635.834, -6726.2609999999995, -6815.769, -6904.3640000000005, -6992.055, -7078.847, -7164.749, -7249.766, -7333.906, -7417.1759999999995, -7499.581, -7581.129, -7661.826, -7741.68, -7820.695, -7898.878000000001, -7976.236, -8052.773, -8128.496999999999, -8203.413, -8277.527, -8350.844000000001, -8423.371, -8495.112, -8566.073, -8636.26, -8705.677, -8774.331, -8842.226, -8909.366, -8975.758, -9041.405, -9106.314, -9170.488000000001, -9233.931999999999, -9296.651, -9358.648000000001, -9419.93, -9480.499, -9540.360999999999, -9599.52, -9657.98, -9715.744, -9772.817, -9829.204, -9884.905999999999, -9939.93, -9994.279, -10047.955, -10100.963, -10153.306999999999, -10204.99, -10256.015, -10306.386999999999, -10356.108, -10405.181, -10453.610999999999, -10501.4, -10548.552, -10595.069, -10640.954, -10686.212, -10730.845, -10774.855, -10818.245, -10861.018999999998, -10903.18, -10944.729, -10985.67, -11026.005, -11065.738000000001, -11104.87, -11143.405, -11181.344, -11218.69, -11255.446000000002, -11291.614, -11327.196000000002, -11362.195, -11396.613000000001, -11430.452, -11463.714, -11496.402, -11528.518, -11560.063999999998, -11591.041000000001, -11621.453000000001, -11651.3, -11680.586000000001, -11709.311000000002, -11737.476999999999, -11765.088, -11792.143999999998, -11818.646999999999, -11844.598999999998, -11870.002, -11894.857, -11919.167, -11942.933, -11966.155, -11988.838, -12010.981000000002, -12032.586000000001, -12053.653999999999, -12074.188, -12094.188999999998, -12113.658000000001, -12132.596000000001, -12151.006000000001, -12168.888, -12186.243, -12203.073999999999, -12219.381000000001, -12235.166000000001, -12250.428999999998, -12265.171999999999, -12279.396999999999, -12293.104, -12306.295, -12318.97, -12331.131000000001, -12342.778999999999, -12353.916000000001, -12364.54, -12374.655, -12384.261, -12393.358999999999, -12401.95, -12410.035, -12417.614, -12424.69, -12431.261999999999, -12437.331, -12442.898000000001, -12447.964, -12452.53, -12456.597, -12460.165, -12463.235, -12465.808, -12467.885, -12469.465, -12470.551000000001, -12471.141000000001, -12471.238000000001, -12470.841, -12469.951000000001, -12468.57, -12466.697, -12464.333, -12461.476999999999, -12458.132, -12454.296999999999, -12449.973, -12445.16, -12439.858999999999, -12434.069, -12427.793, -12421.028999999999, -12413.778, -12406.04, -12397.816, -12389.106000000002, -12379.911, -12370.23, -12360.063999999998, -12349.412, -12338.277, -12326.657, -12314.552, -12301.963, -12288.89, -12275.333, -12261.293, -12246.768, -12231.76, -12216.268, -12200.293, -12183.833999999999, -12166.891000000001, -12149.465, -12131.555, -12113.162, -12094.286, -12074.925, -12055.08, -12034.752, -12013.938999999998, -11992.642, -11970.861, -11948.596000000001, -11925.845, -11902.61, -11878.889, -11854.683, -11829.992, -11804.813999999998, -11779.15, -11753.0, -11726.363000000001, -11699.238000000001, -11671.626, -11643.526000000002, -11614.937, -11585.86, -11556.294, -11526.238000000001, -11495.691, -11464.653999999999, -11433.127, -11401.107, -11368.595, -11335.591, -11302.093, -11268.101999999999, -11233.616000000002, -11198.635, -11163.157, -11127.184, -11090.714, -11053.746000000001, -11016.278999999999, -10978.313, -10939.848, -10900.881000000001, -10861.413, -10821.443000000001, -10780.969, -10739.991000000002, -10698.51, -10656.521999999999, -10614.027, -10571.024, -10527.514, -10483.494, -10438.962, -10393.92, -10348.365, -10302.296999999999, -10255.713, -10208.615, -10161.0, -10112.867, -10064.215, -10015.042, -9965.348, -9915.132, -9864.392, -9813.126, -9761.335, -9709.016, -9656.168, -9602.789, -9548.88, -9494.437, -9439.46, -9383.948, -9327.896999999999, -9271.308, -9214.18, -9156.51, -9098.296, -9039.538, -8980.233, -8920.381, -8859.979, -8799.025, -8737.52, -8675.46, -8612.844000000001, -8549.669, -8485.936, -8421.641, -8356.783000000001, -8291.360999999999, -8225.371, -8158.813, -8091.684, -8023.984, -7955.709, -7886.857, -7817.428000000001, -7747.418000000001, -7676.826999999999, -7605.651999999999, -7533.891, -7461.5419999999995, -7388.602, -7315.071, -7240.945, -7166.224, -7090.904, -7014.983, -6938.46, -6861.3330000000005, -6783.599, -6705.255, -6626.3009999999995, -6546.734, -6466.55, -6385.751, -6304.331, -6222.29, -6139.626, -6056.334, -5972.416, -5887.868, -5802.686, -5716.8730000000005, -5630.422, -5543.3330000000005, -5455.606, -5367.236, -5278.224, -5188.566, -5098.2609999999995, -5007.308, -4915.705, -4823.451, -4730.544, -4636.984, -4542.769, -4447.898, -4352.37, -4256.185, -4159.342000000001, -4061.842, -3963.684, -3864.868, -3765.3940000000002, -3665.264, -3564.4770000000003, -3463.0370000000003, -3360.9429999999998, -3258.2, -3154.8070000000002, -3050.77, -2946.091, -2840.7740000000003, -2734.823, -2628.244, -2521.044, -2413.229, -2304.806, -2195.783, -2086.17, -1975.9779999999998, -1865.219, -1753.905, -1642.0520000000001, -1529.674, -1416.7910000000002, -1303.421, -1189.586, -1075.3110000000001, -960.62, -845.545, -730.1160000000001, -614.37, -498.344, -382.082, -265.63, -149.041, -32.372, 84.316, 200.952, 317.462, 433.76199999999994, 549.759, 665.3539999999999, 780.434, 894.8789999999999, 1008.552, 1121.308, 1232.985, 1343.4029999999998, 1452.369, 1559.6689999999999, 1665.0710000000001, 1768.316, 1869.13, 1967.2089999999998, 2062.2270000000003, 2153.8289999999997, 2241.637, 2325.243, 2404.217, 2478.104, 2546.43, 2608.7039999999997, 2664.4240000000004, 2713.0890000000004, 2754.202, 2787.2859999999996, 2811.8940000000002, 2827.62, 2834.1209999999996, 2831.118, 2818.4179999999997, 2795.9190000000003, 2763.613, 2721.597, 2670.0609999999997, 2609.292, 2539.657, 2461.596, 2375.604, 2282.222, 2182.015, 2075.565, 1963.454, 1846.253, 1724.517, 1598.7779999999998, 1469.535, 1337.26, 1202.387, 1065.316, 926.414, 786.0160000000001, 644.425, 501.913, 358.727, 215.088, 71.191, -72.78699999999999, -216.68900000000002, -360.37699999999995, -503.728, -646.633, -788.9960000000001, -930.732, -1071.767, -1212.0339999999999, -1351.479, -1490.05, -1627.705, -1764.4070000000002, -1900.122, -2034.8239999999998, -2168.488, -2301.097, -2432.632, -2563.0820000000003, -2692.4320000000002, -2820.677, -2947.81, -3073.824, -3198.717, -3322.488, -3445.136, -3566.66, -3687.0640000000003, -3806.35, -3924.52, -4041.579, -4157.531, -4272.3820000000005, -4386.137, -4498.8009999999995, -4610.380999999999, -4720.885, -4830.317, -4938.686, -5045.998, -5152.262, -5257.484, -5361.672, -5464.834, -5566.977, -5668.108, -5768.236, -5867.37, -5965.515, -6062.681, -6158.874, -6254.102, -6348.374, -6441.695, -6534.075, -6625.521, -6716.04, -6805.638000000001, -6894.3240000000005, -6982.104, -7068.985, -7154.976, -7240.081999999999, -7324.31, -7407.6669999999995, -7490.161, -7571.797, -7652.581999999999, -7732.521, -7811.621999999999, -7889.89, -7967.3330000000005, -8043.956, -8119.765, -8194.764000000001, -8268.962, -8342.362, -8414.972, -8486.796, -8557.84, -8628.108, -8697.608, -8766.341999999999, -8834.318000000001, -8901.539, -8968.011, -9033.738000000001, -9098.726999999999, -9162.979, -9226.503, -9289.3, -9351.377, -9412.735999999999, -9473.383, -9533.323, -9592.558, -9651.095, -9708.936, -9766.086, -9822.548, -9878.326, -9933.425, -9987.849, -10041.6, -10094.681999999999, -10147.101, -10198.858, -10249.957, -10300.401, -10350.195, -10399.341999999999, -10447.844000000001, -10495.706, -10542.93, -10589.518999999998, -10635.476, -10680.805, -10725.508, -10769.59, -10813.051000000001, -10855.896, -10898.126, -10939.745, -10980.756000000001, -11021.161, -11060.963, -11100.163999999999, -11138.768, -11176.775, -11214.191, -11251.015, -11287.25, -11322.9, -11357.966, -11392.452, -11426.358999999999, -11459.688, -11492.444, -11524.625, -11556.238000000001, -11587.282, -11617.758, -11647.671999999999, -11677.023000000001, -11705.813999999998, -11734.046, -11761.721000000001, -11788.841999999999, -11815.41, -11841.427, -11866.895, -11891.813999999998, -11916.188, -11940.017, -11963.305, -11986.05, -12008.256000000001, -12029.925, -12051.056999999999, -12071.653999999999, -12091.716999999999, -12111.249, -12130.25, -12148.722, -12166.666000000001, -12184.083999999999, -12200.976, -12217.345, -12233.192, -12248.516000000001, -12263.321000000002, -12277.607, -12291.375, -12304.626, -12317.362, -12329.583999999999, -12341.293, -12352.489, -12363.175, -12373.35, -12383.016000000001, -12392.173999999999, -12400.823999999999, -12408.968, -12416.608, -12423.742, -12430.373, -12436.502, -12442.128, -12447.253, -12451.878, -12456.003, -12459.63, -12462.758, -12465.39, -12467.524, -12469.163999999999, -12470.306999999999, -12470.955, -12471.11, -12470.771, -12469.938999999998, -12468.614, -12466.798999999999, -12464.492, -12461.694, -12458.406, -12454.628, -12450.36, -12445.604, -12440.358999999999, -12434.627, -12428.407, -12421.698999999999, -12414.503999999999, -12406.822, -12398.655, -12390.001, -12380.862, -12371.236, -12361.126, -12350.531, -12339.45, -12327.886, -12315.837, -12303.303, -12290.285, -12276.784, -12262.798, -12248.328000000001, -12233.375, -12217.938999999998, -12202.017, -12185.613000000001, -12168.726, -12151.354, -12133.499, -12115.16, -12096.338, -12077.032, -12057.242, -12036.966999999999, -12016.208999999999, -11994.966, -11973.239, -11951.027, -11928.331, -11905.149, -11881.482, -11857.329, -11832.692, -11807.568000000001, -11781.957, -11755.86, -11729.276000000002, -11702.204, -11674.646, -11646.598999999998, -11618.063999999998, -11589.038999999999, -11559.526000000002, -11529.521999999999, -11499.03, -11468.046, -11436.571000000002, -11404.604, -11372.143999999998, -11339.193000000001, -11305.748, -11271.808, -11237.376, -11202.447, -11167.021999999999, -11131.101, -11094.683, -11057.767, -11020.353000000001, -10982.44, -10944.026000000002, -10905.111, -10865.695, -10825.778, -10785.356000000002, -10744.43, -10703.0, -10661.063999999998, -10618.621000000001, -10575.67, -10532.211000000001, -10488.243, -10443.764000000001, -10398.773000000001, -10353.27, -10307.253, -10260.722, -10213.676, -10166.112, -10118.03, -10069.43, -10020.308, -9970.666, -9920.502, -9869.813, -9818.6, -9766.859, -9714.591999999999, -9661.796, -9608.468, -9554.61, -9500.219000000001, -9445.293, -9389.832, -9333.834, -9277.296999999999, -9220.219000000001, -9162.6, -9104.438, -9045.73, -8986.478000000001, -8926.677, -8866.326, -8805.425, -8743.97, -8681.962, -8619.396999999999, -8556.274, -8492.591999999999, -8428.349, -8363.542, -8298.171, -8232.232, -8165.725, -8098.648, -8030.9980000000005, -7962.774, -7893.975, -7824.597, -7754.639, -7684.1, -7612.976, -7541.266, -7468.968000000001, -7396.079000000001, -7322.6, -7248.526, -7173.855, -7098.5869999999995, -7022.718000000001, -6946.246, -6869.17, -6791.488, -6713.195, -6634.2919999999995, -6554.776, -6474.646, -6393.897, -6312.528, -6230.539000000001, -6147.925, -6064.685, -5980.818, -5896.32, -5811.191, -5725.428000000001, -5639.029, -5551.991999999999, -5464.315, -5375.996, -5287.034000000001, -5197.4259999999995, -5107.173, -5016.27, -4924.718, -4832.514, -4739.657999999999, -4646.147, -4551.982, -4457.16, -4361.683, -4265.5470000000005, -4168.753, -4071.302, -3973.1929999999998, -3874.425, -3774.998, -3674.9159999999997, -3574.177, -3472.784, -3370.737, -3268.039, -3164.692, -3060.699, -2956.065, -2850.792, -2744.885, -2638.349, -2531.189, -2423.4139999999998, -2315.03, -2206.047, -2096.471, -1986.315, -1875.5910000000001, -1764.309, -1652.4879999999998, -1540.14, -1427.285, -1313.941, -1200.13, -1085.875, -971.203, -856.1439999999999, -740.727, -624.99, -508.969, -392.707, -276.252, -159.655, -42.972, 73.737, 190.399, 306.943, 423.284, 539.332, 654.986, 770.1360000000001, 884.66, 998.428, 1111.2910000000002, 1223.09, 1333.6470000000002, 1442.769, 1550.245, 1655.8429999999998, 1759.3110000000001, 1860.37, 1958.724, 2054.045, 2145.984, 2234.1620000000003, 2318.176, 2397.597, 2471.974, 2540.8320000000003, 2603.6820000000002, 2660.026, 2709.3590000000004, 2751.1859999999997, 2785.026, 2810.43, 2826.991, 2834.355, 2832.242, 2820.448, 2798.863, 2767.473, 2726.363, 2675.717, 2615.811, 2547.006, 2469.737, 2384.494, 2291.812, 2192.256, 2086.405, 1974.8410000000001, 1858.138, 1736.851, 1611.513, 1482.628, 1350.6670000000001, 1216.068, 1079.236, 940.541, 800.318, 658.8739999999999, 516.485, 373.398, 229.83599999999998, 85.99799999999999, -57.938, -201.81400000000002, -345.49, -488.841, -631.756, -774.1389999999999, -915.905, -1056.9769999999999, -1197.2910000000002, -1336.787, -1475.4160000000002, -1613.1329999999998, -1749.901, -1885.6879999999999, -2020.464, -2154.2070000000003, -2286.896, -2418.515, -2549.05, -2678.488, -2806.823, -2934.046, -3060.151, -3185.139, -3309.0029999999997, -3431.7459999999996, -3553.367, -3673.867, -3793.2490000000003, -3911.5170000000003, -4028.675, -4144.725, -4259.673, -4373.526, -4486.289000000001, -4597.968, -4708.569, -4818.1, -4926.567, -5033.977, -5140.338, -5245.658, -5349.943, -5453.201999999999, -5555.441999999999, -5656.67, -5756.895, -5856.124, -5954.365, -6051.626, -6147.914000000001, -6243.236, -6337.601, -6431.017, -6523.49, -6615.028, -6705.639, -6795.33, -6884.107, -6971.979, -7058.951999999999, -7145.033, -7230.229, -7314.547, -7397.994000000001, -7480.576999999999, -7562.3009999999995, -7643.174, -7723.201, -7802.389, -7880.745, -7958.274, -8034.983, -8110.878000000001, -8185.963000000001, -8260.246, -8333.732, -8406.426, -8478.334, -8549.461, -8619.813, -8689.395, -8758.213, -8826.271, -8893.574, -8960.128, -9025.937, -9091.005, -9155.339, -9218.943000000001, -9281.82, -9343.976, -9405.415, -9466.142, -9526.16, -9585.474, -9644.089, -9702.008, -9759.234, -9815.774, -9871.629, -9926.805, -9981.304, -10035.132, -10088.291, -10140.784, -10192.616, -10243.79, -10294.31, -10344.178, -10393.399, -10441.975, -10489.91, -10537.207, -10583.868999999999, -10629.9, -10675.301000000001, -10720.077, -10764.23, -10807.764, -10850.68, -10892.982, -10934.671999999999, -10975.753999999999, -11016.23, -11056.101999999999, -11095.374, -11134.048, -11172.125, -11209.608999999999, -11246.503, -11282.808, -11318.527, -11353.662, -11388.216999999999, -11422.192, -11455.589, -11488.412, -11520.662, -11552.341999999999, -11583.453000000001, -11613.998, -11643.978000000001, -11673.396, -11702.253, -11730.552, -11758.294, -11785.481000000002, -11812.115, -11838.197, -11863.73, -11888.715, -11913.155, -11937.048999999999, -11960.401000000002, -11983.211000000001, -12005.482, -12027.215, -12048.411, -12069.072, -12089.2, -12108.796, -12127.86, -12146.396, -12164.403, -12181.883999999998, -12198.84, -12215.271, -12231.18, -12246.568000000001, -12261.435, -12275.783000000001, -12289.614, -12302.927, -12315.725, -12328.008999999998, -12339.778999999999, -12351.037, -12361.784, -12372.02, -12381.747, -12390.966, -12399.677, -12407.883, -12415.583, -12422.778, -12429.469, -12435.657, -12441.344, -12446.528999999999, -12451.214, -12455.399, -12459.085, -12462.274, -12464.964, -12467.158000000001, -12468.856000000002, -12470.058, -12470.766000000001, -12470.98, -12470.7, -12469.927, -12468.661, -12466.903999999999, -12464.655, -12461.916000000001, -12458.686000000002, -12454.966, -12450.756000000001, -12446.058, -12440.871000000001, -12435.196000000002, -12429.034, -12422.383, -12415.246000000001, -12407.622, -12399.511999999999, -12390.915, -12381.832, -12372.264, -12362.211000000001, -12351.671999999999, -12340.649, -12329.14, -12317.148000000001, -12304.671, -12291.708999999999, -12278.264, -12264.333999999999, -12249.921, -12235.024, -12219.643, -12203.778, -12187.43, -12170.598, -12153.282, -12135.483, -12117.198999999999, -12098.431999999999, -12079.181, -12059.447, -12039.228000000001, -12018.524, -11997.337, -11975.665, -11953.508, -11930.867, -11907.74, -11884.127, -11860.03, -11835.447, -11810.377, -11784.821000000002, -11758.778999999999, -11732.249, -11705.233, -11677.728000000001, -11649.735, -11621.253999999999, -11592.284, -11562.825, -11532.876, -11502.437, -11471.506000000001, -11440.085, -11408.173, -11375.768, -11342.868999999999, -11309.478000000001, -11275.593, -11241.213, -11206.338, -11170.966999999999, -11135.1, -11098.735, -11061.873, -11024.511999999999, -10986.652, -10948.291000000001, -10909.431, -10870.068000000001, -10830.203000000001, -10789.833999999999, -10748.962, -10707.585, -10665.702, -10623.312, -10580.413999999999, -10537.008999999998, -10493.093, -10448.667, -10403.729, -10358.279, -10312.315999999999, -10265.838, -10218.843, -10171.332, -10123.304, -10074.756, -10025.688, -9976.098, -9925.985999999999, -9875.351, -9824.19, -9772.502, -9720.287, -9667.543, -9614.27, -9560.464, -9506.125, -9451.252, -9395.843, -9339.898000000001, -9283.413, -9226.388, -9168.821, -9110.712, -9052.058, -8992.857, -8933.108, -8872.811, -8811.962, -8750.561, -8688.605, -8626.091999999999, -8563.021999999999, -8499.392, -8435.202, -8370.448, -8305.128, -8239.243, -8172.789000000001, -8105.764, -8038.1669999999995, -7969.996, -7901.249, -7831.924, -7762.018, -7691.53, -7620.459, -7548.802, -7476.557, -7403.722, -7330.294, -7256.273, -7181.655, -7106.439, -7030.6230000000005, -6954.204000000001, -6877.18, -6799.55, -6721.31, -6642.46, -6562.996999999999, -6482.918000000001, -6402.222, -6320.906, -6238.969, -6156.406999999999, -6073.221, -5989.406, -5904.960999999999, -5819.884, -5734.173000000001, -5647.826, -5560.840999999999, -5473.215999999999, -5384.95, -5296.039000000001, -5206.484, -5116.282, -5025.431, -4933.93, -4841.778, -4748.973, -4655.514, -4561.399, -4466.629, -4371.202, -4275.117, -4178.373, -4080.972, -3982.9120000000003, -3884.1929999999998, -3784.817, -3684.783, -3584.093, -3482.7470000000003, -3380.7470000000003, -3278.097, -3174.797, -3070.85, -2966.261, -2861.032, -2755.1690000000003, -2648.676, -2541.5589999999997, -2433.826, -2325.482, -2216.5370000000003, -2107.0, -1996.881, -1886.192, -1774.945, -1663.156, -1550.839, -1438.0120000000002, -1324.694, -1210.907, -1096.674, -982.0219999999999, -866.9780000000001, -751.575, -635.846, -519.831, -403.57, -287.112, -170.50599999999997, -53.808, 62.92, 179.61, 296.187, 412.57, 528.668, 644.382, 759.6030000000001, 874.21, 988.072, 1101.0430000000001, 1212.965, 1323.662, 1432.942, 1540.5970000000002, 1646.394, 1750.0839999999998, 1851.3929999999998, 1950.023, 2045.651, 2137.93, 2226.4829999999997, 2310.91, 2390.784, 2465.655, 2535.051, 2598.486, 2655.4590000000003, 2705.468, 2748.0170000000003, 2782.6240000000003, 2808.836, 2826.24, 2834.4809999999998, 2833.27, 2822.3959999999997, 2801.741, 2771.281, 2731.093, 2681.3509999999997, 2622.325, 2554.368, 2477.906, 2393.426, 2301.46, 2202.5679999999998, 2097.331, 1986.3270000000002, 1870.1329999999998, 1749.306, 1624.379, 1495.859, 1364.221, 1229.905, 1093.319, 954.834, 814.7919999999999, 673.5, 531.236, 388.251, 244.769, 100.993, -42.898999999999994, -186.747, -330.409, -473.75800000000004, -616.684, -759.0880000000001, -900.9789999999999, -1041.993, -1182.351, -1321.899, -1460.585, -1598.366, -1735.201, -1871.059, -2005.912, -2139.7329999999997, -2272.504, -2404.2070000000003, -2534.828, -2664.355, -2792.78, -2920.095, -3046.2940000000003, -3171.375, -3295.336, -3418.175, -3539.893, -3660.491, -3779.972, -3898.3379999999997, -4015.594, -4131.7429999999995, -4246.792, -4360.744000000001, -4473.606, -4585.385, -4696.085, -4805.715999999999, -4914.282, -5021.792, -5128.252, -5233.67, -5338.054, -5441.411, -5543.749, -5645.075, -5745.397, -5844.723000000001, -5943.061, -6040.418000000001, -6136.802, -6232.221, -6326.681, -6420.191999999999, -6512.76, -6604.392, -6695.097, -6784.880999999999, -6873.751, -6961.715999999999, -7048.78, -7134.953, -7220.241, -7304.65, -7388.188, -7470.86, -7552.674, -7633.637, -7713.753000000001, -7793.03, -7871.474, -7949.090999999999, -8025.887, -8101.869000000001, -8177.041, -8251.41, -8324.982, -8397.761, -8469.755, -8540.966999999999, -8611.403, -8681.07, -8749.971, -8818.112, -8885.498, -8952.135, -9018.026, -9083.177, -9147.593, -9211.278, -9274.235999999999, -9336.473, -9397.992, -9458.799, -9518.896999999999, -9578.291, -9636.984, -9694.982, -9752.287, -9808.905, -9864.839, -9920.091999999999, -9974.669, -10028.573, -10081.809000000001, -10134.379, -10186.287, -10237.537, -10288.133, -10338.076, -10387.372, -10436.024, -10484.033000000001, -10531.405, -10578.141000000001, -10624.245, -10669.721000000001, -10714.57, -10758.796, -10802.403, -10845.391000000001, -10887.766000000001, -10929.528999999999, -10970.683, -11011.23, -11051.173999999999, -11090.517, -11129.261999999999, -11167.41, -11204.965, -11241.928999999998, -11278.305, -11314.094, -11349.298999999999, -11383.921999999999, -11417.966999999999, -11451.434, -11484.325, -11516.643999999998, -11548.393, -11579.573, -11610.185, -11640.233999999999, -11669.72, -11698.645, -11727.01, -11754.82, -11782.073999999999, -11808.775, -11834.923999999999, -11860.524, -11885.575, -11910.081, -11934.042, -11957.458999999999, -11980.335, -12002.671999999999, -12024.47, -12045.732, -12066.458, -12086.651000000002, -12106.311000000002, -12125.441, -12144.04, -12162.112, -12179.657, -12196.677, -12213.173, -12229.145, -12244.596000000001, -12259.527, -12273.938999999998, -12287.832, -12301.208999999999, -12314.07, -12326.417, -12338.249, -12349.57, -12360.378999999999, -12370.677, -12380.466999999999, -12389.748, -12398.521, -12406.788, -12414.548999999999, -12421.806, -12428.558, -12434.808, -12440.556, -12445.802, -12450.548, -12454.794, -12458.541000000001, -12461.79, -12464.541000000001, -12466.795, -12468.553, -12469.816, -12470.583999999999, -12470.857, -12470.636999999999, -12469.923999999999, -12468.718, -12467.02, -12464.83, -12462.15, -12458.98, -12455.319, -12451.168, -12446.528999999999, -12441.401000000002, -12435.785, -12429.681, -12423.089, -12416.01, -12408.444, -12400.392, -12391.854, -12382.829, -12373.319, -12363.323, -12352.843, -12341.877, -12330.426000000001, -12318.491000000002, -12306.072, -12293.168, -12279.78, -12265.907, -12251.551000000001, -12236.711000000001, -12221.388, -12205.58, -12189.288, -12172.513, -12155.253999999999, -12137.511, -12119.285, -12100.573999999999, -12081.378999999999, -12061.701000000001, -12041.538999999999, -12020.891000000001, -11999.76, -11978.143999999998, -11956.043, -11933.458, -11910.386999999999, -11886.831, -11862.788999999999, -11838.261999999999, -11813.248, -11787.748, -11761.76, -11735.287, -11708.325, -11680.876, -11652.938999999998, -11624.513, -11595.598, -11566.194, -11536.301000000001, -11505.916000000001, -11475.041000000001, -11443.675, -11411.817, -11379.466999999999, -11346.624, -11313.287, -11279.457, -11245.132, -11210.312, -11174.995, -11139.181999999999, -11102.873, -11066.065, -11028.758999999998, -10990.953000000001, -10952.646999999999, -10913.84, -10874.532, -10834.722, -10794.408000000001, -10753.59, -10712.267, -10670.438999999998, -10628.103000000001, -10585.258999999998, -10541.908000000001, -10498.046, -10453.674, -10408.791, -10363.394, -10317.485, -10271.061, -10224.121, -10176.664, -10128.689, -10080.195, -10031.181, -9981.645, -9931.587, -9881.005, -9829.898000000001, -9778.265, -9726.103000000001, -9673.413, -9620.193000000001, -9566.440999999999, -9512.155999999999, -9457.337, -9401.982, -9346.09, -9289.659, -9232.688, -9175.175, -9117.119, -9058.519, -8999.372, -8939.677, -8879.433, -8818.638, -8757.29, -8695.388, -8632.929, -8569.912, -8506.336, -8442.199, -8377.499, -8312.234, -8246.401, -8180.001, -8113.03, -8045.486999999999, -7977.369000000001, -7908.6759999999995, -7839.405, -7769.553000000001, -7699.119000000001, -7628.102, -7556.4980000000005, -7484.307, -7411.525, -7338.151999999999, -7264.184, -7189.62, -7114.456999999999, -7038.695, -6962.33, -6885.36, -6807.783, -6729.598000000001, -6650.8009999999995, -6571.391, -6491.366, -6410.724, -6329.4619999999995, -6247.578, -6165.071, -6081.937, -5998.1759999999995, -5913.785, -5828.7609999999995, -5743.103, -5656.81, -5569.878000000001, -5482.307, -5394.093000000001, -5305.236, -5215.734, -5125.585, -5034.787, -4943.339, -4851.2390000000005, -4758.486, -4665.079000000001, -4571.018, -4476.299, -4380.923, -4284.89, -4188.198, -4090.848, -3992.8379999999997, -3894.17, -3794.844, -3694.86, -3594.218, -3492.922, -3390.972, -3288.369, -3185.116, -3081.217, -2976.6740000000004, -2871.491, -2765.672, -2659.223, -2552.15, -2444.459, -2336.157, -2227.252, -2117.754, -2007.6729999999998, -1897.02, -1785.807, -1674.0510000000002, -1561.765, -1448.967, -1335.6770000000001, -1221.914, -1107.704, -993.071, -878.044, -762.653, -646.934, -530.924, -414.665, -298.203, -181.58900000000003, -64.877, 51.871, 168.588, 285.2, 401.625, 517.774, 633.548, 748.84, 863.53, 977.488, 1090.568, 1202.615, 1313.453, 1422.8929999999998, 1530.727, 1636.726, 1740.641, 1842.2020000000002, 1941.112, 2037.05, 2129.672, 2218.604, 2303.447, 2383.779, 2459.149, 2529.089, 2593.113, 2650.723, 2701.4159999999997, 2744.696, 2780.077, 2807.1059999999998, 2825.366, 2834.494, 2834.197, 2824.256, 2804.5440000000003, 2775.028, 2735.777, 2686.9559999999997, 2628.8259999999996, 2561.73, 2486.091, 2402.39, 2311.154, 2212.9410000000003, 2108.3289999999997, 1997.899, 1882.225, 1761.8670000000002, 1637.361, 1509.215, 1377.908, 1243.882, 1107.548, 969.2810000000001, 829.424, 688.2869999999999, 546.153, 403.273, 259.876, 116.163, -27.683000000000003, -171.502, -315.14799999999997, -458.495, -601.431, -743.855, -885.679, -1026.827, -1167.23, -1306.83, -1445.5729999999999, -1583.4170000000001, -1720.3210000000001, -1856.251, -1991.1789999999999, -2125.08, -2257.933, -2389.721, -2520.429, -2650.046, -2778.562, -2905.97, -3032.263, -3157.44, -3281.4970000000003, -3404.434, -3526.25, -3646.946, -3766.527, -3884.993, -4002.349, -4118.598, -4233.747, -4347.8, -4460.763, -4572.642, -4683.444, -4793.175, -4901.840999999999, -5009.452, -5116.012, -5221.53, -5326.014, -5429.47, -5531.906999999999, -5633.3330000000005, -5733.753000000001, -5833.178000000001, -5931.613, -6029.068, -6125.549, -6221.064, -6315.621999999999, -6409.228, -6501.892, -6593.62, -6684.419, -6774.297, -6863.262, -6951.32, -7038.478, -7124.744000000001, -7210.124, -7294.626, -7378.255, -7461.018, -7542.924, -7623.977, -7704.183000000001, -7783.55, -7862.0830000000005, -7939.789000000001, -8016.674, -8092.744000000001, -8168.004, -8242.46, -8316.119, -8388.985, -8461.064, -8532.363000000001, -8602.885, -8672.636, -8741.623, -8809.848, -8877.318000000001, -8944.039, -9010.013, -9075.247, -9139.746, -9203.513, -9266.553, -9328.872, -9390.473, -9451.360999999999, -9511.54, -9571.014000000001, -9629.788, -9687.865, -9745.25, -9801.947, -9857.96, -9913.292, -9967.947, -10021.929, -10075.243, -10127.89, -10179.876, -10231.203000000001, -10281.875, -10331.895, -10381.267, -10429.995, -10478.08, -10525.527, -10572.338, -10618.518, -10664.068000000001, -10708.991000000002, -10753.292, -10796.972, -10840.035, -10882.482, -10924.318000000001, -10965.545, -11006.166000000001, -11046.183, -11085.598, -11124.413999999999, -11162.635, -11200.261999999999, -11237.296999999999, -11273.743999999999, -11309.604, -11344.88, -11379.573999999999, -11413.688999999998, -11447.226, -11480.188, -11512.577, -11544.395, -11575.643999999998, -11606.326000000001, -11636.444, -11665.998, -11694.991000000002, -11723.426000000001, -11751.303999999998, -11778.626, -11805.395, -11831.612, -11857.28, -11882.399, -11906.971000000001, -11930.999, -11954.483999999999, -11977.427, -11999.83, -12021.694, -12043.021999999999, -12063.815, -12084.073999999999, -12103.8, -12122.995, -12141.661, -12159.798, -12177.408000000001, -12194.493, -12211.053999999998, -12227.091, -12242.607, -12257.601999999999, -12272.078000000001, -12286.036, -12299.476, -12312.402, -12324.812, -12336.708, -12348.091999999999, -12358.965, -12369.327, -12379.178999999998, -12388.523000000001, -12397.358999999999, -12405.688999999998, -12413.513, -12420.832, -12427.646999999999, -12433.958999999999, -12439.768999999998, -12445.078000000001, -12449.886, -12454.193000000001, -12458.002, -12461.312, -12464.125, -12466.441, -12468.26, -12469.583999999999, -12470.412, -12470.747, -12470.588, -12469.935, -12468.79, -12467.153, -12465.024, -12462.403999999999, -12459.293, -12455.693000000001, -12451.601999999999, -12447.023000000001, -12441.955, -12436.399, -12430.354, -12423.822, -12416.802, -12409.296, -12401.303, -12392.823999999999, -12383.858999999999, -12374.407, -12364.471000000001, -12354.048999999999, -12343.142, -12331.75, -12319.874, -12307.513, -12294.668, -12281.338, -12267.524, -12253.226, -12238.444, -12223.178999999998, -12207.428999999998, -12191.195, -12174.478000000001, -12157.277, -12139.591999999999, -12121.423, -12102.77, -12083.633, -12064.011999999999, -12043.907, -12023.317, -12002.243999999999, -11980.685, -11958.641000000001, -11936.112, -11913.098999999998, -11889.6, -11865.615, -11841.143999999998, -11816.187, -11790.743999999999, -11764.813999999998, -11738.396999999999, -11711.492, -11684.098999999998, -11656.218, -11627.848999999998, -11598.991000000002, -11569.643, -11539.805, -11509.476999999999, -11478.659, -11447.348999999998, -11415.546999999999, -11383.252, -11350.466, -11317.185, -11283.411, -11249.141000000001, -11214.377, -11179.117, -11143.36, -11107.106000000002, -11070.353000000001, -11033.103000000001, -10995.353000000001, -10957.103000000001, -10918.351, -10879.098999999998, -10839.344, -10799.085, -10758.323, -10717.056, -10675.282, -10633.002, -10590.214, -10546.917, -10503.111, -10458.795, -10413.966, -10368.625, -10322.771, -10276.402, -10229.517, -10182.115, -10134.195, -10085.757, -10036.798, -9987.317, -9937.314, -9886.787, -9835.735, -9784.157, -9732.051, -9679.415, -9626.25, -9572.554, -9518.324, -9463.559000000001, -9408.259, -9352.421999999999, -9296.046, -9239.13, -9181.671999999999, -9123.671, -9065.126, -9006.034, -8946.394, -8886.205, -8825.465, -8764.171999999999, -8702.325, -8639.921, -8576.959, -8513.438, -8449.356, -8384.711, -8319.501, -8253.723, -8187.378000000001, -8120.4619999999995, -8052.974, -7984.911, -7916.273, -7847.057, -7777.26, -7706.880999999999, -7635.919, -7564.371, -7492.234, -7419.508000000001, -7346.189, -7272.276999999999, -7197.768, -7122.66, -7046.953, -6970.643, -6893.728, -6816.206, -6738.076, -6659.334, -6579.98, -6500.009, -6419.422, -6338.215, -6256.387, -6173.934, -6090.856, -6007.149, -5922.813, -5837.844, -5752.241, -5666.0019999999995, -5579.125, -5491.608, -5403.4490000000005, -5314.647, -5225.1990000000005, -5135.104, -5044.36, -4952.965999999999, -4860.920999999999, -4768.221, -4674.8679999999995, -4580.859, -4486.194, -4390.872, -4294.891, -4198.252, -4100.954000000001, -4002.9959999999996, -3904.38, -3805.105, -3705.172, -3604.5809999999997, -3503.335, -3401.435, -3298.881, -3195.678, -3091.8259999999996, -2987.33, -2882.1940000000004, -2776.422, -2670.018, -2562.989, -2455.342, -2347.0820000000003, -2238.218, -2128.76, -2018.717, -1908.102, -1796.925, -1685.203, -1572.9489999999998, -1460.181, -1346.918, -1233.182, -1118.994, -1004.3810000000001, -889.3710000000001, -773.9939999999999, -658.285, -542.281, -426.024, -309.559, -192.93599999999998, -76.21, 40.559, 157.30200000000002, 273.948, 390.416, 506.61699999999996, 622.452, 737.816, 852.59, 966.6439999999999, 1079.835, 1192.008, 1302.988, 1412.5910000000001, 1520.606, 1626.809, 1730.9520000000002, 1832.7679999999998, 1931.96, 2028.213, 2121.1820000000002, 2210.4970000000003, 2295.762, 2376.5570000000002, 2452.433, 2522.923, 2587.545, 2645.8, 2697.1859999999997, 2741.205, 2777.3720000000003, 2805.2290000000003, 2824.3579999999997, 2834.388, 2835.0190000000002, 2826.026, 2807.2740000000003, 2778.72, 2740.423, 2692.54, 2635.323, 2569.1079999999997, 2494.31, 2411.405, 2320.9139999999998, 2223.396, 2119.425, 2009.582, 1894.442, 1774.565, 1650.4920000000002, 1522.73, 1391.7620000000002, 1258.0339999999999, 1121.9589999999998, 983.915, 844.2489999999999, 703.273, 561.2719999999999, 418.501, 275.19, 131.543, -12.255, -156.042, -299.672, -443.01599999999996, -585.96, -728.403, -870.257, -1011.442, -1151.89, -1291.542, -1430.344, -1568.2520000000002, -1705.224, -1841.227, -1976.2320000000002, -2110.214, -2243.15, -2375.025, -2505.821, -2635.526, -2764.134, -2891.636, -3018.025, -3143.2990000000004, -3267.453, -3390.489, -3512.4040000000005, -3633.202, -3752.883, -3871.45, -3988.907, -4105.259, -4220.51, -4334.665, -4447.73, -4559.712, -4670.615, -4780.448, -4889.217000000001, -4996.929, -5103.590999999999, -5209.210999999999, -5313.795, -5417.353, -5519.89, -5621.416, -5721.937, -5821.460999999999, -5919.996, -6017.55, -6114.129, -6209.743, -6304.398, -6398.102, -6490.863, -6582.687, -6673.5830000000005, -6763.558000000001, -6852.618, -6940.77, -7028.024, -7114.384, -7199.857, -7284.451999999999, -7368.174, -7451.031, -7533.028, -7614.172, -7694.47, -7773.928000000001, -7852.553000000001, -7930.349, -8007.323, -8083.483, -8158.831999999999, -8233.377, -8307.124, -8380.078000000001, -8452.244, -8523.63, -8594.239, -8664.077, -8733.149, -8801.461, -8869.017, -8935.821, -9001.881, -9067.199, -9131.780999999999, -9195.632, -9258.756, -9321.157, -9382.841, -9443.811, -9504.072, -9563.628, -9622.483, -9680.641, -9738.107, -9794.885, -9850.976999999999, -9906.389000000001, -9961.124, -10015.186, -10068.578000000001, -10121.304, -10173.369, -10224.774, -10275.523000000001, -10325.621, -10375.071, -10423.876, -10472.038, -10519.561000000002, -10566.448999999999, -10612.704, -10658.33, -10703.329, -10747.705, -10791.46, -10834.597, -10877.12, -10919.03, -10960.331, -11001.026000000002, -11041.116000000002, -11080.605, -11119.493999999999, -11157.788, -11195.487, -11232.595, -11269.114, -11305.046, -11340.395, -11375.16, -11409.346000000001, -11442.955, -11475.988000000001, -11508.448, -11540.336000000001, -11571.656, -11602.408000000001, -11632.596000000001, -11662.221000000001, -11691.285, -11719.788999999999, -11747.735, -11775.127, -11801.965, -11828.251, -11853.987, -11879.173999999999, -11903.815, -11927.911, -11951.464, -11974.473999999998, -11996.946000000002, -12018.878, -12040.273000000001, -12061.132, -12081.458, -12101.251, -12120.513, -12139.246000000001, -12157.448999999999, -12175.126, -12192.277, -12208.903, -12225.007, -12240.588, -12255.649, -12270.19, -12284.213, -12297.719, -12310.708999999999, -12323.184, -12335.145, -12346.594, -12357.531, -12367.958, -12377.874, -12387.282, -12396.181999999999, -12404.576000000001, -12412.464, -12419.847, -12426.725, -12433.1, -12438.973, -12444.345, -12449.216, -12453.586000000001, -12457.458, -12460.831, -12463.706, -12466.083999999999, -12467.966, -12469.351, -12470.243, -12470.639, -12470.542, -12469.951000000001, -12468.868, -12467.292, -12465.223999999998, -12462.666000000001, -12459.617, -12456.077, -12452.048, -12447.528999999999, -12442.521999999999, -12437.027, -12431.043, -12424.571000000002, -12417.612, -12410.167, -12402.233999999999, -12393.815, -12384.91, -12375.518999999998, -12365.643, -12355.281, -12344.434, -12333.101999999999, -12321.286, -12308.983999999999, -12296.198, -12282.928, -12269.173999999999, -12254.935, -12240.213, -12225.006000000001, -12209.315, -12193.141000000001, -12176.483, -12159.34, -12141.714, -12123.604, -12105.01, -12085.931999999999, -12066.368999999999, -12046.323, -12025.792, -12004.776000000002, -11983.275, -11961.29, -11938.82, -11915.864, -11892.423, -11868.496000000001, -11844.083999999999, -11819.185, -11793.798999999999, -11767.927, -11741.567, -11714.72, -11687.385, -11659.562, -11631.25, -11602.448999999999, -11573.159, -11543.378999999999, -11513.108999999999, -11482.348, -11451.095, -11419.35, -11387.113000000001, -11354.383, -11321.16, -11287.442, -11253.23, -11218.521999999999, -11183.319, -11147.618999999999, -11111.421999999999, -11074.726999999999, -11037.533000000001, -10999.84, -10961.646, -10922.952, -10883.756000000001, -10844.056999999999, -10803.856000000002, -10763.15, -10721.938999999998, -10680.222, -10637.998, -10595.267, -10552.027, -10508.277, -10464.017, -10419.245, -10373.96, -10328.162, -10281.85, -10235.021, -10187.675, -10139.812, -10091.43, -10042.527, -9993.103000000001, -9943.155999999999, -9892.686, -9841.69, -9790.167, -9738.118, -9685.539, -9632.43, -9578.789, -9524.615, -9469.907, -9414.663, -9358.882, -9302.562, -9245.703000000001, -9188.301, -9130.356, -9071.866, -9012.831, -8953.247, -8893.115, -8832.431, -8771.194, -8709.402, -8647.055, -8584.15, -8520.685, -8456.659, -8392.069, -8326.915, -8261.195, -8194.905, -8128.045, -8060.613, -7992.607, -7924.025, -7854.8640000000005, -7785.124, -7714.802, -7643.896, -7572.404, -7500.3240000000005, -7427.654, -7354.391, -7280.535, -7206.0830000000005, -7131.031, -7055.38, -6979.126, -6902.268, -6824.802, -6746.728, -6668.043000000001, -6588.745, -6508.831, -6428.3, -6347.149, -6265.376, -6182.98, -6099.9580000000005, -6016.307, -5932.026999999999, -5847.1140000000005, -5761.566999999999, -5675.384, -5588.563, -5501.102, -5412.9980000000005, -5324.2519999999995, -5234.859, -5144.82, -5054.1320000000005, -4962.793, -4870.802, -4778.157999999999, -4684.86, -4590.906, -4496.295, -4401.027, -4305.1, -4208.514, -4111.27, -4013.366, -3914.802, -3815.579, -3715.699, -3615.16, -3513.966, -3412.116, -3309.612, -3206.458, -3102.656, -2998.2090000000003, -2893.12, -2787.395, -2681.038, -2574.054, -2466.45, -2358.234, -2249.413, -2139.996, -2029.993, -1919.415, -1808.275, -1696.5870000000002, -1584.3670000000002, -1471.63, -1358.395, -1244.685, -1130.521, -1015.929, -900.936, -785.573, -669.8739999999999, -553.877, -437.621, -321.154, -204.52200000000002, -87.78299999999999, 29.006, 145.776, 262.457, 378.968, 495.22, 611.117, 726.553, 841.4110000000001, 955.563, 1068.865, 1181.165, 1292.29, 1402.056, 1510.255, 1616.664, 1721.0379999999998, 1823.109, 1922.588, 2019.158, 2112.4770000000003, 2202.18, 2287.871, 2369.132, 2445.519, 2516.5660000000003, 2581.791, 2640.697, 2692.784, 2737.551, 2774.513, 2803.21, 2823.216, 2834.16, 2835.732, 2827.7009999999996, 2809.923, 2782.3459999999995, 2745.02, 2698.092, 2641.804, 2576.486, 2502.545, 2420.451, 2330.724, 2233.9139999999998, 2130.598, 2021.355, 1906.761, 1787.378, 1663.746, 1536.378, 1405.759, 1272.337, 1136.528, 998.7130000000001, 859.243, 718.433, 576.569, 433.91, 290.688, 147.11, 3.361, -140.393, -284.005, -427.344, -570.2959999999999, -712.758, -854.6410000000001, -995.862, -1136.356, -1276.0610000000001, -1414.922, -1552.8929999999998, -1689.934, -1826.0120000000002, -1961.094, -2095.157, -2228.178, -2360.139, -2491.026, -2620.825, -2749.527, -2877.1240000000003, -3003.61, -3128.982, -3253.235, -3376.37, -3498.386, -3619.285, -3739.0679999999998, -3857.738, -3975.298, -4091.7529999999997, -4207.107, -4321.366, -4434.534000000001, -4546.619000000001, -4657.626, -4767.562, -4876.435, -4984.25, -5091.015, -5196.737, -5301.424, -5405.084, -5507.723000000001, -5609.35, -5709.972, -5809.597, -5908.233, -6005.887, -6102.566, -6198.279, -6293.033, -6386.835999999999, -6479.695, -6571.616999999999, -6662.61, -6752.682, -6841.839, -6930.088000000001, -7017.437, -7103.892, -7189.460999999999, -7274.15, -7357.967, -7440.916, -7523.007, -7604.244000000001, -7684.635, -7764.185, -7842.901, -7920.7880000000005, -7997.854, -8074.104, -8149.543000000001, -8224.177, -8298.014000000001, -8371.056999999999, -8443.312, -8514.786, -8585.483, -8655.409, -8724.568000000001, -8792.966, -8860.608, -8927.499, -8993.644, -9059.048, -9123.715, -9187.65, -9250.859, -9313.344000000001, -9375.110999999999, -9436.164, -9496.509, -9556.146999999999, -9615.085, -9673.325, -9730.873, -9787.732, -9843.905999999999, -9899.398000000001, -9954.214, -10008.356, -10061.828000000001, -10114.634, -10166.777, -10218.261999999999, -10269.09, -10319.267, -10368.795, -10417.677, -10465.918, -10513.518, -10560.483, -10606.816, -10652.518, -10697.594, -10742.046, -10785.877, -10829.09, -10871.688, -10913.673999999999, -10955.05, -10995.819, -11035.983999999999, -11075.546999999999, -11114.511, -11152.878, -11190.652, -11227.833, -11264.425, -11300.431, -11335.851999999999, -11370.69, -11404.948999999999, -11438.628999999999, -11471.735, -11504.266000000001, -11536.226, -11567.617, -11598.441, -11628.7, -11658.396, -11687.53, -11716.105, -11744.122, -11771.583, -11798.492, -11824.847, -11850.653, -11875.91, -11900.62, -11924.785, -11948.407, -11971.486, -11994.026000000002, -12016.027, -12037.49, -12058.418, -12078.811000000002, -12098.671999999999, -12118.002, -12136.802, -12155.073, -12172.817, -12190.035, -12206.728000000001, -12222.898000000001, -12238.546999999999, -12253.673999999999, -12268.281, -12282.371000000001, -12295.943000000001, -12308.999, -12321.538999999999, -12333.566, -12345.081, -12356.083, -12366.575, -12376.556999999999, -12386.03, -12394.995, -12403.453000000001, -12411.406, -12418.853000000001, -12425.796, -12432.235, -12438.173, -12443.608999999999, -12448.543, -12452.978000000001, -12456.913, -12460.348999999998, -12463.288, -12465.73, -12467.675, -12469.124, -12470.078000000001, -12470.537, -12470.503, -12469.975, -12468.954, -12467.441, -12465.436000000002, -12462.938999999998, -12459.953000000001, -12456.476, -12452.508, -12448.052, -12443.106000000002, -12437.673, -12431.751, -12425.341, -12418.443000000001, -12411.059, -12403.188, -12394.83, -12385.986, -12376.656, -12366.841, -12356.54, -12345.753999999999, -12334.483, -12322.726999999999, -12310.486, -12297.761, -12284.551000000001, -12270.857, -12256.678999999998, -12242.016000000001, -12226.87, -12211.239, -12195.125, -12178.527, -12161.445, -12143.878, -12125.828000000001, -12107.293, -12088.274, -12068.771999999999, -12048.785, -12028.313, -12007.356000000002, -11985.915, -11963.989, -11941.578000000001, -11918.681999999999, -11895.3, -11871.431999999999, -11847.078000000001, -11822.238000000001, -11796.912, -11771.098, -11744.796999999999, -11718.008999999998, -11690.732, -11662.968, -11634.715, -11605.972, -11576.74, -11547.018, -11516.806, -11486.103000000001, -11454.909, -11423.222, -11391.043, -11358.372, -11325.207, -11291.546999999999, -11257.393, -11222.743, -11187.598, -11151.956, -11115.817, -11079.18, -11042.044, -11004.408000000001, -10966.271999999999, -10927.636, -10888.498, -10848.857, -10808.712, -10768.063999999998, -10726.91, -10685.251, -10643.085, -10600.411, -10557.228000000001, -10513.536, -10469.333, -10424.619, -10379.392, -10333.651, -10287.396, -10240.625, -10193.337, -10145.530999999999, -10097.205, -10048.36, -9998.993, -9949.104, -9898.69, -9847.751, -9796.286, -9744.294, -9691.771999999999, -9638.721, -9585.136999999999, -9531.021, -9476.37, -9421.183, -9365.459, -9309.197, -9252.394, -9195.049, -9137.162, -9078.73, -9019.751, -8960.224, -8900.148000000001, -8839.521999999999, -8778.341999999999, -8716.608, -8654.318000000001, -8591.47, -8528.062, -8464.093, -8399.562, -8334.464, -8268.801, -8202.569, -8135.767, -8068.392, -8000.441999999999, -7931.918000000001, -7862.815, -7793.132, -7722.866999999999, -7652.018, -7580.5830000000005, -7508.56, -7435.948, -7362.743, -7288.943, -7214.548000000001, -7139.555, -7063.960999999999, -6987.764, -6910.9619999999995, -6833.555, -6755.5380000000005, -6676.91, -6597.669, -6517.812, -6437.338000000001, -6356.245, -6274.529, -6192.19, -6109.225, -6025.632, -5941.408, -5856.552, -5771.063, -5684.937, -5598.173000000001, -5510.768, -5422.722, -5334.031, -5244.696, -5154.713, -5064.08, -4972.798, -4880.863, -4788.275, -4695.032, -4601.134, -4506.579000000001, -4411.365, -4315.4929999999995, -4218.963, -4121.773, -4023.923, -3925.413, -3826.244, -3726.417, -3625.9309999999996, -3524.788, -3422.989, -3320.538, -3217.434, -3113.6820000000002, -3009.284, -2904.245, -2798.567, -2692.257, -2585.32, -2477.761, -2369.589, -2260.81, -2151.4339999999997, -2041.471, -1930.932, -1819.83, -1708.1770000000001, -1595.99, -1483.2839999999999, -1370.079, -1256.395, -1142.255, -1027.684, -912.71, -797.3610000000001, -681.673, -565.682, -449.42900000000003, -332.959, -216.31900000000002, -99.566, 17.243, 134.04, 250.75599999999997, 367.309, 483.61400000000003, 599.573, 715.082, 830.025, 944.275, 1057.69, 1170.118, 1281.389, 1391.317, 1499.701, 1606.318, 1710.9229999999998, 1813.253, 1913.019, 2009.908, 2103.581, 2193.673, 2279.7929999999997, 2361.5229999999997, 2438.425, 2510.032, 2575.864, 2635.427, 2688.219, 2733.74, 2771.5040000000004, 2801.046, 2821.9390000000003, 2833.804, 2836.327, 2829.2690000000002, 2812.475, 2785.887, 2749.5429999999997, 2703.583, 2648.237, 2583.83, 2510.76, 2429.491, 2340.538, 2244.451, 2141.802, 2033.171, 1919.1329999999998, 1800.253, 1677.0720000000001, 1550.1070000000002, 1419.844, 1286.734, 1151.197, 1013.617, 874.3480000000001, 733.707, 591.985, 449.44199999999995, 306.311, 162.804, 19.107, -124.61200000000001, -268.204, -411.538, -554.497, -696.977, -838.887, -980.1469999999999, -1120.685, -1260.442, -1399.362, -1537.398, -1674.5079999999998, -1810.66, -1945.82, -2079.964, -2213.07, -2345.119, -2476.096, -2605.987, -2734.783, -2862.4759999999997, -2989.06, -3114.53, -3238.883, -3362.119, -3484.238, -3605.238, -3725.1240000000003, -3843.897, -3961.5609999999997, -4078.119, -4193.577, -4307.941, -4421.214, -4533.403, -4644.514, -4754.555, -4863.531, -4971.45, -5078.318, -5184.145, -5288.935, -5392.696999999999, -5495.44, -5597.169, -5697.893, -5797.62, -5896.357, -5994.111999999999, -6090.893, -6186.706, -6281.56, -6375.4619999999995, -6468.42, -6560.441, -6651.531999999999, -6741.701999999999, -6830.956, -6919.302, -7006.7480000000005, -7093.3, -7178.965, -7263.749, -7347.66, -7430.705, -7512.89, -7594.221, -7674.705, -7754.347, -7833.156, -7911.1359999999995, -7988.293000000001, -8064.634, -8140.164000000001, -8214.89, -8288.815999999999, -8361.949, -8434.294, -8505.856, -8576.642, -8646.655999999999, -8715.903, -8784.389000000001, -8852.118, -8919.096, -8985.328000000001, -9050.818000000001, -9115.571, -9179.591999999999, -9242.885, -9305.455, -9367.306999999999, -9428.445, -9488.872, -9548.594000000001, -9607.615, -9665.938, -9723.569, -9780.509, -9836.765, -9892.34, -9947.237, -10001.459, -10055.013, -10107.899, -10160.123, -10211.688, -10262.596, -10312.851999999999, -10362.459, -10411.42, -10459.738000000001, -10507.418, -10554.461000000001, -10600.871000000001, -10646.651000000002, -10691.803999999998, -10736.333, -10780.242, -10823.531, -10866.206, -10908.267, -10949.719, -10990.563999999998, -11030.803999999998, -11070.442, -11109.481000000002, -11147.923999999999, -11185.771, -11223.027, -11259.693000000001, -11295.773000000001, -11331.268, -11366.18, -11400.511, -11434.265, -11467.443000000001, -11500.048, -11532.08, -11563.543, -11594.44, -11624.77, -11654.537, -11683.743, -11712.389, -11740.478000000001, -11768.01, -11794.989, -11821.415, -11847.291000000001, -11872.618999999999, -11897.4, -11921.635, -11945.326000000001, -11968.475, -11991.083999999999, -12013.153999999999, -12034.687, -12055.683, -12076.146, -12096.076000000001, -12115.473999999998, -12134.341999999999, -12152.681, -12170.493, -12187.778999999999, -12204.54, -12220.778, -12236.493999999999, -12251.688, -12266.363000000001, -12280.52, -12294.159, -12307.281, -12319.889, -12331.982, -12343.563, -12354.632, -12365.188999999998, -12375.237, -12384.776000000002, -12393.806999999999, -12402.331, -12410.348999999998, -12417.862, -12424.871000000001, -12431.375, -12437.378, -12442.878, -12447.878, -12452.377, -12456.377, -12459.878, -12462.881000000001, -12465.386999999999, -12467.396, -12468.909, -12469.927, -12470.451000000001, -12470.48, -12470.016000000001, -12469.059, -12467.608999999999, -12465.667, -12463.233999999999, -12460.31, -12456.896, -12452.992, -12448.598, -12443.716, -12438.345, -12432.486, -12426.138, -12419.303, -12411.981000000002, -12404.171999999999, -12395.877, -12387.096000000001, -12377.828000000001, -12368.073999999999, -12357.835, -12347.111, -12335.901000000002, -12324.207, -12312.028, -12299.364, -12286.215, -12272.583, -12258.466, -12243.865, -12228.778999999999, -12213.21, -12197.156, -12180.618999999999, -12163.598, -12146.091999999999, -12128.103000000001, -12109.628999999999, -12090.67, -12071.228000000001, -12051.301000000001, -12030.89, -12009.993999999999, -11988.613000000001, -11966.747, -11944.396999999999, -11921.56, -11898.238000000001, -11874.43, -11850.136, -11825.356000000002, -11800.09, -11774.336000000001, -11748.095, -11721.366000000002, -11694.15, -11666.445, -11638.251, -11609.568000000001, -11580.396, -11550.733, -11520.581, -11489.937, -11458.802, -11427.175, -11395.055, -11362.442, -11329.336000000001, -11295.736, -11261.641000000001, -11227.05, -11191.964, -11156.381000000001, -11120.301000000001, -11083.723, -11046.645, -11009.069, -10970.991000000002, -10932.413999999999, -10893.333999999999, -10853.752, -10813.667, -10773.077, -10731.982, -10690.382, -10648.274, -10605.658000000001, -10562.534, -10518.901000000002, -10474.757, -10430.101, -10384.933, -10339.25, -10293.053, -10246.341, -10199.110999999999, -10151.364, -10103.097, -10054.309000000001, -10005.001, -9955.17, -9904.815, -9853.935, -9802.528, -9750.594000000001, -9698.131, -9645.138, -9591.613000000001, -9537.554, -9482.962, -9427.833, -9372.168, -9315.964, -9259.219000000001, -9201.933, -9144.104, -9085.73, -9026.81, -8967.341999999999, -8907.324, -8846.756, -8785.635, -8723.959, -8661.726999999999, -8598.938, -8535.588, -8471.678, -8407.205, -8342.166, -8276.561, -8210.386999999999, -8143.643, -8076.326999999999, -8008.436, -7939.97, -7870.9259999999995, -7801.3009999999995, -7731.095, -7660.305, -7588.928000000001, -7516.964, -7444.41, -7371.264, -7297.523, -7223.186, -7148.251, -7072.715999999999, -6996.578, -6919.835, -6842.486, -6764.528, -6685.9580000000005, -6606.776, -6526.978, -6446.562, -6365.526999999999, -6283.87, -6201.589, -6118.683000000001, -6035.148, -5950.983, -5866.185, -5780.754, -5694.686, -5607.98, -5520.634, -5432.646, -5344.013000000001, -5254.735, -5164.81, -5074.235, -4983.01, -4891.133, -4798.602, -4705.416, -4611.575, -4517.076, -4421.919, -4326.104, -4229.629, -4132.495, -4034.7, -3936.2459999999996, -3837.131, -3737.3579999999997, -3636.926, -3535.837, -3434.091, -3331.692, -3228.64, -3124.9390000000003, -3020.592, -2915.6020000000003, -2809.974, -2703.712, -2596.822, -2489.3089999999997, -2381.1820000000002, -2272.447, -2163.114, -2053.192, -1942.693, -1831.629, -1720.013, -1607.859, -1495.1860000000001, -1382.011, -1268.355, -1154.239, -1039.69, -924.7339999999999, -809.4010000000001, -693.7239999999999, -577.74, -461.49, -345.017, -228.37, -111.603, 5.224, 122.04799999999999, 238.798, 355.395, 471.75199999999995, 587.774, 703.357, 818.385, 932.7330000000001, 1046.262, 1158.818, 1270.236, 1380.33, 1488.9, 1595.726, 1700.565, 1803.1570000000002, 1903.213, 2000.424, 2094.453, 2184.938, 2271.491, 2353.697, 2431.118, 2503.29, 2569.737, 2629.9629999999997, 2683.468, 2729.752, 2768.327, 2798.725, 2820.515, 2833.315, 2836.802, 2830.73, 2814.937, 2789.353, 2754.009, 2709.032, 2654.6479999999997, 2591.1679999999997, 2518.986, 2438.5589999999997, 2350.397, 2255.048, 2153.081, 2045.076, 1931.608, 1813.2420000000002, 1690.524, 1563.971, 1434.0720000000001, 1301.282, 1166.024, 1028.687, 889.623, 749.1569999999999, 607.58, 465.156, 322.121, 178.687, 35.045, -108.63799999999999, -252.21, -395.537, -538.503, -681.0, -822.939, -964.235, -1104.819, -1244.628, -1383.606, -1521.707, -1658.888, -1795.114, -1930.354, -2064.58, -2197.772, -2329.909, -2460.9770000000003, -2590.962, -2719.8540000000003, -2847.6440000000002, -2974.3259999999996, -3099.8959999999997, -3224.3509999999997, -3347.6890000000003, -3469.91, -3591.015, -3711.0040000000004, -3829.882, -3947.65, -4064.315, -4179.879, -4294.347, -4407.726, -4520.02, -4631.238, -4741.383, -4850.465, -4958.49, -5065.464, -5171.394, -5276.29, -5380.156, -5483.0019999999995, -5584.835999999999, -5685.664000000001, -5785.493, -5884.3330000000005, -5982.19, -6079.071999999999, -6174.988, -6269.943, -6363.946, -6457.004, -6549.125, -6640.316, -6730.585, -6819.937, -6908.382, -6995.9259999999995, -7082.575, -7168.335999999999, -7253.218000000001, -7337.225, -7420.365, -7502.646, -7584.071999999999, -7664.65, -7744.387, -7823.289000000001, -7901.361999999999, -7978.611999999999, -8055.045999999999, -8130.668000000001, -8205.485999999999, -8279.503, -8352.726999999999, -8425.162, -8496.815, -8567.69, -8637.793, -8707.129, -8775.703000000001, -8843.521, -8910.588, -8976.907, -9042.484, -9107.324, -9171.431, -9234.81, -9297.466, -9359.404, -9420.627, -9481.139000000001, -9540.946, -9600.05, -9658.458, -9716.171999999999, -9773.196, -9829.535, -9885.192, -9940.171, -9994.476999999999, -10048.110999999999, -10101.079, -10153.384, -10205.029, -10256.018, -10306.355, -10356.042, -10405.082, -10453.48, -10501.239, -10548.361, -10594.851, -10640.708999999999, -10685.94, -10730.546999999999, -10774.533000000001, -10817.901000000002, -10860.652, -10902.791000000001, -10944.32, -10985.241000000002, -11025.558, -11065.273000000001, -11104.386999999999, -11142.905, -11180.828000000001, -11218.159, -11254.901000000002, -11291.053999999998, -11326.624, -11361.61, -11396.017, -11429.845, -11463.096000000001, -11495.774, -11527.88, -11559.417, -11590.386, -11620.788999999999, -11650.628999999999, -11679.907, -11708.625, -11736.786, -11764.39, -11791.441, -11817.938999999998, -11843.886999999999, -11869.285, -11894.136, -11918.442, -11942.204, -11965.423999999999, -11988.104, -12010.243999999999, -12031.846000000001, -12052.913, -12073.445, -12093.445, -12112.912, -12131.848999999998, -12150.258, -12168.139, -12185.493, -12202.323, -12218.628999999999, -12234.413, -12249.676000000001, -12264.42, -12278.643999999998, -12292.351, -12305.542, -12318.216, -12330.377, -12342.025, -12353.161, -12363.786, -12373.9, -12383.506000000001, -12392.604, -12401.195, -12409.278999999999, -12416.858, -12423.931999999999, -12430.503, -12436.572, -12442.138, -12447.204, -12451.768999999998, -12455.833999999999, -12459.4, -12462.469, -12465.04, -12467.114, -12468.692, -12469.775, -12470.363000000001, -12470.457, -12470.056999999999, -12469.165, -12467.778999999999, -12465.902, -12463.533000000001, -12460.673, -12457.323, -12453.483, -12449.153, -12444.333999999999, -12439.027, -12433.231000000002, -12426.947, -12420.176000000001, -12412.917, -12405.171, -12396.938999999998, -12388.22, -12379.016000000001, -12369.325, -12359.148000000001, -12348.486, -12337.34, -12325.708, -12313.591, -12300.99, -12287.903, -12274.333, -12260.278999999999, -12245.74, -12230.716999999999, -12215.208999999999, -12199.216999999999, -12182.741000000002, -12165.782, -12148.338, -12130.41, -12111.998, -12093.101, -12073.72, -12053.855, -12033.505, -12012.67, -11991.351, -11969.546, -11947.256000000001, -11924.481000000002, -11901.22, -11877.473, -11853.24, -11828.521, -11803.313999999998, -11777.622, -11751.441, -11724.774, -11697.618, -11669.973, -11641.84, -11613.216999999999, -11584.105, -11554.503999999999, -11524.411, -11493.827, -11462.752, -11431.186000000002, -11399.126, -11366.573999999999, -11333.527, -11299.987, -11265.952, -11231.421999999999, -11196.396, -11160.873, -11124.851999999999, -11088.333, -11051.316, -11013.798999999999, -10975.782, -10937.264, -10898.243999999999, -10858.722, -10818.696000000002, -10778.166000000001, -10737.131000000001, -10695.59, -10653.542, -10610.986, -10567.921999999999, -10524.348, -10480.263, -10435.666, -10390.556999999999, -10344.934000000001, -10298.796999999999, -10252.144, -10204.974, -10157.286, -10109.078000000001, -10060.351, -10011.101, -9961.33, -9911.034, -9860.213, -9808.866, -9756.991, -9704.587, -9651.653, -9598.187, -9544.188, -9489.655, -9434.586, -9378.98, -9322.836, -9266.15, -9208.923, -9151.154, -9092.839, -9033.978000000001, -8974.57, -8914.610999999999, -8854.101999999999, -8793.041, -8731.424, -8669.252, -8606.521999999999, -8543.232, -8479.381, -8414.966999999999, -8349.988000000001, -8284.442, -8218.328000000001, -8151.644, -8084.387, -8016.556, -7948.149, -7879.164000000001, -7809.599, -7739.451999999999, -7668.722, -7597.405, -7525.5, -7453.005, -7379.919, -7306.236999999999, -7231.96, -7157.085, -7081.609, -7005.531, -6928.848000000001, -6851.558000000001, -6773.659000000001, -6695.149, -6616.026, -6536.2880000000005, -6455.932, -6374.956, -6293.359, -6211.138000000001, -6128.291, -6044.815, -5960.709, -5875.972, -5790.599, -5704.59, -5617.943, -5530.656, -5442.727, -5354.154, -5264.935, -5175.068, -5084.552, -4993.385, -4901.566, -4809.093, -4715.965999999999, -4622.182, -4527.741, -4432.642, -4336.883, -4240.465999999999, -4143.388, -4045.6490000000003, -3947.2509999999997, -3848.192, -3748.474, -3648.0959999999995, -3547.062, -3445.37, -3343.0240000000003, -3240.026, -3136.3759999999997, -3032.0809999999997, -2927.1420000000003, -2821.563, -2715.35, -2608.507, -2501.042, -2392.9610000000002, -2284.271, -2174.981, -2065.1020000000003, -1954.6429999999998, -1843.6170000000002, -1732.0379999999998, -1619.9189999999999, -1507.279, -1394.134, -1280.506, -1166.4160000000002, -1051.889, -936.951, -821.6339999999999, -705.9689999999999, -589.993, -473.746, -357.27099999999996, -240.61599999999999, -123.836, -6.9879999999999995, 109.86399999999999, 226.649, 343.288, 459.69800000000004, 575.7819999999999, 691.438, 806.553, 920.9989999999999, 1034.642, 1147.328, 1258.893, 1369.1529999999998, 1477.911, 1584.9460000000001, 1690.021, 1792.874, 1893.2220000000002, 1990.756, 2085.143, 2176.0229999999997, 2263.011, 2345.694, 2423.636, 2496.3779999999997, 2563.4410000000003, 2624.3340000000003, 2678.5559999999996, 2725.6079999999997, 2764.998, 2796.258, 2818.953, 2832.6940000000004, 2837.1540000000005, 2832.078, 2817.2940000000003, 2792.7259999999997, 2758.3920000000003, 2714.4120000000003, 2661.0, 2598.462, 2527.18, 2447.609, 2360.252, 2265.652, 2164.379, 2057.011, 1944.1229999999998, 1826.283, 1704.036, 1577.9029999999998, 1448.376, 1315.914, 1180.942, 1043.851, 904.9989999999999, 764.712, 623.284, 480.98199999999997, 338.045, 194.687, 51.101000000000006, -92.54299999999999, -236.093, -379.413, -522.383, -664.898, -806.867, -948.196, -1088.825, -1228.6860000000001, -1367.724, -1505.889, -1643.141, -1779.442, -1914.76, -2049.07, -2182.348, -2314.574, -2445.734, -2575.813, -2704.801, -2832.6890000000003, -2959.47, -3085.1409999999996, -3209.697, -3333.138, -3455.4629999999997, -3576.672, -3696.7659999999996, -3815.7490000000003, -3933.6240000000003, -4050.3940000000002, -4166.064, -4280.639, -4394.124, -4506.525, -4617.849, -4728.102, -4837.289000000001, -4945.42, -5052.5, -5158.536, -5263.536999999999, -5367.509, -5470.46, -5572.398, -5673.33, -5773.263000000001, -5872.206999999999, -5970.1669999999995, -6067.151999999999, -6163.17, -6258.227, -6352.331, -6445.491, -6537.713000000001, -6629.004, -6719.371999999999, -6808.8240000000005, -6897.368, -6985.01, -7071.758000000001, -7157.616999999999, -7242.596, -7326.701, -7409.937, -7492.313, -7573.835, -7654.509, -7734.340999999999, -7813.3369999999995, -7891.504, -7968.848000000001, -8045.374, -8121.09, -8196.0, -8270.109, -8343.424, -8415.951, -8487.695, -8558.66, -8628.854, -8698.279, -8766.943000000001, -8834.85, -8902.005, -8968.412, -9034.077, -9099.004, -9163.199, -9226.665, -9289.408000000001, -9351.431, -9412.74, -9473.339, -9533.23, -9592.42, -9650.912, -9708.71, -9765.818000000001, -9822.24, -9877.981, -9933.044, -9987.431999999999, -10041.149, -10094.199, -10146.586, -10198.312, -10249.383, -10299.8, -10349.568000000001, -10398.689, -10447.167, -10495.006000000001, -10542.208, -10588.777, -10634.715, -10680.025, -10724.71, -10768.775, -10812.22, -10855.05, -10897.266000000001, -10938.873, -10979.871000000001, -11020.265, -11060.056999999999, -11099.248, -11137.841, -11175.84, -11213.247, -11250.063999999998, -11286.294, -11321.938, -11357.0, -11391.481000000002, -11425.383999999998, -11458.71, -11491.462, -11523.642, -11555.253, -11586.296, -11616.773000000001, -11646.685, -11676.037, -11704.828000000001, -11733.062, -11760.739, -11787.861, -11814.431, -11840.451000000001, -11865.921999999999, -11890.845, -11915.223, -11939.056, -11962.347, -11985.097, -12007.308, -12028.982, -12050.118999999999, -12070.721000000001, -12090.791000000001, -12110.329, -12129.336000000001, -12147.813999999998, -12165.765, -12183.188999999998, -12200.088, -12216.464, -12232.317, -12247.649, -12262.461000000001, -12276.753999999999, -12290.528999999999, -12303.788, -12316.532, -12328.761, -12340.476999999999, -12351.68, -12362.373, -12372.555, -12382.229, -12391.393999999998, -12400.052, -12408.203000000001, -12415.963, -12423.097, -12429.726999999999, -12435.855, -12441.48, -12446.605, -12451.228000000001, -12455.351999999999, -12458.976999999999, -12462.104, -12464.733999999999, -12466.866000000002, -12468.502, -12469.643, -12470.288999999999, -12470.441, -12470.098999999998, -12469.264, -12467.936000000002, -12466.116000000002, -12463.803999999998, -12461.002, -12457.708999999999, -12453.926000000001, -12449.653, -12444.891000000001, -12439.641000000001, -12433.902, -12427.675, -12420.96, -12413.758, -12406.068000000001, -12397.892, -12389.23, -12380.082, -12370.447, -12360.327, -12349.722, -12338.631000000001, -12327.053999999998, -12314.993, -12302.448, -12289.418, -12275.903, -12261.903, -12247.42, -12232.452, -12217.0, -12201.063999999998, -12184.643999999998, -12167.739, -12150.351, -12132.478000000001, -12114.121000000001, -12095.278999999999, -12075.953000000001, -12056.143, -12035.848, -12015.068000000001, -11993.803, -11972.053, -11949.819, -11927.098, -11903.892, -11880.198999999999, -11856.021, -11831.356000000002, -11806.205, -11780.567, -11754.441, -11727.827, -11700.725, -11673.135, -11645.056999999999, -11616.489, -11587.431999999999, -11557.883, -11527.845, -11497.316, -11466.296, -11434.783000000001, -11402.778, -11370.28, -11337.288, -11303.802, -11269.821000000002, -11235.345, -11200.373, -11164.903999999999, -11128.938, -11092.473, -11055.51, -11018.046999999999, -10980.083999999999, -10941.62, -10902.655, -10863.186000000002, -10823.215, -10782.739, -10741.758, -10700.271999999999, -10658.278, -10615.776000000002, -10572.766000000001, -10529.246000000001, -10485.216, -10440.674, -10395.619, -10350.051, -10303.968, -10257.369, -10210.253, -10162.62, -10114.466999999999, -10065.793, -10016.599, -9966.882, -9916.641, -9865.875, -9814.582, -9762.761999999999, -9710.413, -9657.533000000001, -9604.123, -9550.179, -9495.701, -9440.687, -9385.135, -9329.045, -9272.416, -9215.244, -9157.53, -9099.27, -9040.464, -8981.110999999999, -8921.209, -8860.755, -8799.749, -8738.188, -8676.071, -8613.396999999999, -8550.163, -8486.368, -8422.01, -8357.087, -8291.597, -8225.54, -8158.911999999999, -8091.710999999999, -8023.936, -7955.585999999999, -7886.656999999999, -7817.149, -7747.059, -7676.385, -7605.125, -7533.276999999999, -7460.84, -7387.81, -7314.186, -7239.965999999999, -7165.148, -7089.73, -7013.709, -6937.084, -6859.851, -6782.01, -6703.558000000001, -6624.493, -6544.813, -6464.515, -6383.597, -6302.058000000001, -6219.895, -6137.106, -6053.689, -5969.641, -5884.9619999999995, -5799.649, -5713.6990000000005, -5627.11, -5539.880999999999, -5452.0109999999995, -5363.496, -5274.335999999999, -5184.527, -5094.071, -5002.963, -4911.2029999999995, -4818.789000000001, -4725.72, -4631.994000000001, -4537.612, -4442.571, -4346.872, -4250.512, -4153.492, -4055.812, -3957.4709999999995, -3858.47, -3758.809, -3658.489, -3557.511, -3455.8759999999997, -3353.585, -3250.6420000000003, -3147.0490000000004, -3042.808, -2937.923, -2832.3979999999997, -2726.238, -2619.447, -2512.034, -2404.002, -2295.362, -2186.12, -2076.288, -1965.875, -1854.894, -1743.358, -1631.281, -1518.6789999999999, -1405.5720000000001, -1291.979, -1177.922, -1063.425, -948.515, -833.221, -717.576, -601.616, -485.381, -368.914, -252.262, -135.47899999999998, -18.621, 98.24600000000001, 215.054, 331.725, 448.17400000000004, 564.307, 680.0239999999999, 795.21, 909.742, 1023.4830000000001, 1136.2839999999999, 1247.979, 1358.39, 1467.317, 1574.545, 1679.8370000000002, 1782.933, 1883.5539999999999, 1981.391, 2076.116, 2167.369, 2254.77, 2337.907, 2416.348, 2489.634, 2557.291, 2618.826, 2673.739, 2721.533, 2761.7129999999997, 2793.809, 2817.382, 2832.039, 2837.445, 2833.3390000000004, 2819.54, 2795.962, 2762.615, 2719.607, 2667.1440000000002, 2605.5229999999997, 2535.12, 2456.383, 2369.8089999999997, 2275.939, 2175.34, 2068.589, 1956.263, 1838.9279999999999, 1717.134, 1591.404, 1462.233, 1330.08, 1195.376, 1058.516, 919.8589999999999, 779.735, 638.441, 496.24699999999996, 353.39300000000003, 210.097, 66.553, -77.066, -220.606, -363.93, -506.917, -649.46, -791.4630000000001, -932.8439999999999, -1073.527, -1213.451, -1352.557, -1490.796, -1628.126, -1764.51, -1899.915, -2034.315, -2167.686, -2300.008, -2431.265, -2561.444, -2690.534, -2818.5240000000003, -2945.41, -3071.1859999999997, -3195.849, -3319.3959999999997, -3441.828, -3563.1440000000002, -3683.347, -3802.4390000000003, -3920.421, -4037.3, -4153.0779999999995, -4267.7609999999995, -4381.355, -4493.8640000000005, -4605.295999999999, -4715.656, -4824.951, -4933.188, -5040.374, -5146.516, -5251.6230000000005, -5355.7, -5458.755999999999, -5560.798000000001, -5661.834, -5761.871, -5860.916, -5958.979, -6056.066, -6152.184, -6247.342, -6341.547, -6434.806, -6527.126, -6618.517, -6708.983, -6798.531999999999, -6887.173000000001, -6974.911, -7061.754, -7147.709, -7232.783, -7316.981, -7400.312, -7482.781, -7564.395, -7645.16, -7725.084, -7804.172, -7882.43, -7959.863, -8036.48, -8112.284000000001, -8187.283, -8261.48, -8334.883, -8407.498, -8479.328000000001, -8550.38, -8620.659, -8690.171, -8758.92, -8826.911, -8894.149, -8960.641, -9026.389000000001, -9091.4, -9155.677, -9219.225, -9282.05, -9344.154, -9405.544, -9466.223, -9526.195, -9585.465, -9644.036, -9701.913, -9759.1, -9815.601, -9871.419, -9926.559000000001, -9981.025, -10034.819, -10087.946, -10140.409, -10192.212, -10243.358, -10293.851, -10343.695, -10392.891, -10441.443000000001, -10489.356000000002, -10536.632, -10583.274, -10629.285, -10674.668, -10719.427, -10763.563999999998, -10807.082, -10849.983999999999, -10892.271999999999, -10933.95, -10975.02, -11015.483999999999, -11055.346000000001, -11094.608, -11133.271999999999, -11171.341999999999, -11208.818000000001, -11245.705, -11282.003, -11317.716999999999, -11352.847, -11387.396999999999, -11421.368, -11454.761999999999, -11487.582, -11519.83, -11551.508, -11582.618, -11613.162, -11643.142, -11672.56, -11701.418, -11729.716999999999, -11757.461000000001, -11784.649, -11811.285, -11837.37, -11862.906, -11887.893999999998, -11912.337, -11936.235, -11959.59, -11982.405, -12004.681, -12026.418, -12047.618999999999, -12068.285, -12088.418, -12108.02, -12127.09, -12145.632, -12163.645, -12181.132, -12198.094, -12214.532, -12230.447, -12245.841999999999, -12260.716, -12275.071000000002, -12288.908000000001, -12302.228000000001, -12315.033000000001, -12327.323999999999, -12339.1, -12350.365, -12361.118999999999, -12371.362, -12381.096000000001, -12390.322, -12399.04, -12407.252, -12414.958, -12422.159, -12428.857, -12435.052, -12440.745, -12445.937, -12450.627, -12454.818000000001, -12458.51, -12461.704, -12464.4, -12466.598999999998, -12468.301000000001, -12469.508999999998, -12470.221000000001, -12470.438999999998, -12470.163, -12469.393999999998, -12468.132, -12466.378, -12464.132, -12461.395, -12458.168, -12454.45, -12450.242, -12445.546, -12440.36, -12434.686000000002, -12428.524, -12421.874, -12414.737, -12407.112, -12399.001, -12390.403, -12381.319, -12371.749, -12361.693000000001, -12351.152, -12340.125, -12328.613000000001, -12316.616000000002, -12304.133999999998, -12291.168, -12277.716999999999, -12263.781, -12249.361, -12234.457, -12219.069, -12203.196000000002, -12186.84, -12169.998, -12152.673, -12134.863000000001, -12116.569, -12097.791000000001, -12078.528, -12058.781, -12038.548999999999, -12017.832, -11996.628999999999, -11974.942, -11952.77, -11930.112, -11906.968, -11883.339, -11859.223, -11834.621000000001, -11809.532, -11783.956, -11757.892, -11731.341, -11704.301000000001, -11676.773000000001, -11648.757, -11620.251, -11591.255, -11561.77, -11531.793, -11501.326000000001, -11470.368, -11438.917, -11406.973999999998, -11374.537, -11341.607, -11308.183, -11274.264, -11239.848999999998, -11204.938999999998, -11169.531, -11133.627, -11097.223999999998, -11060.322, -11022.921, -10985.02, -10946.617, -10907.713, -10868.306, -10828.396, -10787.981000000002, -10747.062, -10705.636999999999, -10663.704, -10621.264, -10578.315, -10534.856000000002, -10490.886999999999, -10446.405999999999, -10401.413, -10355.905999999999, -10309.884, -10263.346, -10216.292, -10168.719000000001, -10120.628, -10072.015, -10022.882, -9973.226, -9923.046, -9872.341, -9821.11, -9769.351, -9717.063, -9664.245, -9610.895, -9557.011999999999, -9502.596, -9447.643, -9392.153, -9336.124, -9279.555, -9222.445, -9164.792, -9106.594000000001, -9047.85, -8988.556999999999, -8928.716, -8868.323, -8807.378, -8745.879, -8683.824, -8621.211, -8558.038, -8494.304, -8430.007, -8365.146, -8299.718, -8233.721, -8167.154, -8100.015, -8032.302, -7964.013000000001, -7895.146, -7825.6990000000005, -7755.67, -7685.058000000001, -7613.86, -7542.073, -7469.696999999999, -7396.728, -7323.166, -7249.008000000001, -7174.2519999999995, -7098.895, -7022.936, -6946.371, -6869.201, -6791.422, -6713.031, -6634.026999999999, -6554.408, -6474.172, -6393.316, -6311.838000000001, -6229.736999999999, -6147.009, -6063.653, -5979.668000000001, -5895.05, -5809.797, -5723.908, -5637.380999999999, -5550.213000000001, -5462.404, -5373.9490000000005, -5284.85, -5195.103, -5104.707, -5013.659000000001, -4921.959, -4829.605, -4736.596, -4642.931, -4548.608, -4453.627, -4357.985, -4261.685, -4164.724, -4067.1009999999997, -3968.8179999999998, -3869.875, -3770.2709999999997, -3670.008, -3569.086, -3467.506, -3365.2709999999997, -3262.383, -3158.844, -3054.656, -2949.823, -2844.349, -2738.24, -2631.5, -2524.134, -2416.151, -2307.5570000000002, -2198.361, -2088.572, -1978.201, -1867.26, -1755.761, -1643.721, -1531.154, -1418.079, -1304.515, -1190.485, -1076.011, -961.12, -845.8439999999999, -730.212, -614.261, -498.03, -381.561, -264.903, -148.106, -31.23, 85.664, 202.50599999999997, 319.22, 435.721, 551.9169999999999, 667.7080000000001, 782.98, 897.6110000000001, 1011.466, 1124.397, 1236.241, 1346.819, 1455.9360000000001, 1563.375, 1668.9029999999998, 1772.264, 1873.1779999999999, 1971.3410000000001, 2066.427, 2158.08, 2245.919, 2329.538, 2408.505, 2482.366, 2550.645, 2612.855, 2668.495, 2717.065, 2758.072, 2791.0429999999997, 2815.534, 2831.1479999999997, 2837.545, 2834.453, 2821.6859999999997, 2799.1459999999997, 2766.8340000000003, 2724.848, 2673.385, 2612.732, 2543.258, 2465.403, 2379.66, 2286.567, 2186.687, 2080.596, 1968.872, 1852.0839999999998, 1730.781, 1605.489, 1476.704, 1344.894, 1210.488, 1073.886, 935.45, 795.513, 654.377, 512.312, 369.56199999999995, 226.347, 82.863, -60.714, -204.229, -347.54400000000004, -490.534, -633.0930000000001, -775.122, -916.539, -1057.268, -1197.243, -1336.408, -1474.713, -1612.114, -1748.5729999999999, -1884.059, -2018.543, -2152.001, -2284.415, -2415.765, -2546.0389999999998, -2675.2259999999997, -2803.316, -2930.303, -3056.1820000000002, -3180.948, -3304.6, -3427.137, -3548.56, -3668.869, -3788.0679999999998, -3906.159, -4023.145, -4139.032, -4253.823, -4367.525, -4480.143, -4591.683, -4702.151, -4811.555, -4919.9, -5027.193, -5133.444, -5238.657, -5342.840999999999, -5446.004, -5548.151999999999, -5649.294, -5749.437, -5848.588000000001, -5946.755, -6043.946999999999, -6140.169, -6235.43, -6329.7390000000005, -6423.101, -6515.524, -6607.016, -6697.584, -6787.235, -6875.976, -6963.815, -7050.758000000001, -7136.812, -7221.984, -7306.281999999999, -7389.710999999999, -7472.276999999999, -7553.9890000000005, -7634.852, -7714.871999999999, -7794.055, -7872.408, -7949.938, -8026.648, -8102.547, -8177.639, -8251.931, -8325.427, -8398.134, -8470.056999999999, -8541.201, -8611.572, -8681.175, -8750.014000000001, -8818.096, -8885.425, -8952.005, -9017.843, -9082.943000000001, -9147.309000000001, -9210.946, -9273.858, -9336.05, -9397.528, -9458.293, -9518.351999999999, -9577.708, -9636.365, -9694.328000000001, -9751.601, -9808.187, -9864.09, -9919.315, -9973.864, -10027.742, -10080.952, -10133.499, -10185.385, -10236.614, -10287.19, -10337.114, -10386.392, -10435.027, -10483.021999999999, -10530.378999999999, -10577.101, -10623.193000000001, -10668.657, -10713.496000000001, -10757.712, -10801.309, -10844.29, -10886.658000000001, -10928.413999999999, -10969.563, -11010.106000000002, -11050.045, -11089.385, -11128.128, -11166.275, -11203.829, -11240.792, -11277.168, -11312.958, -11348.165, -11382.79, -11416.837, -11450.306999999999, -11483.203000000001, -11515.527, -11547.28, -11578.465, -11609.083, -11639.138, -11668.63, -11697.563, -11725.936000000002, -11753.753999999999, -11781.016000000001, -11807.725, -11833.883, -11859.493, -11884.553999999998, -11909.069, -11933.04, -11956.468, -11979.355, -12001.703000000001, -12023.513, -12044.786, -12065.524, -12085.728000000001, -12105.401000000002, -12124.543, -12143.155, -12161.24, -12178.798, -12195.83, -12212.339, -12228.325, -12243.788999999999, -12258.733, -12273.158000000001, -12287.065, -12300.455, -12313.33, -12325.69, -12337.536, -12348.87, -12359.693000000001, -12370.005, -12379.808, -12389.103000000001, -12397.89, -12406.17, -12413.944, -12421.214, -12427.98, -12434.243, -12440.003, -12445.261999999999, -12450.021, -12454.28, -12458.038999999999, -12461.3, -12464.063999999998, -12466.33, -12468.098999999998, -12469.373, -12470.153, -12470.437, -12470.228000000001, -12469.526000000002, -12468.33, -12466.642, -12464.463, -12461.792, -12458.631000000001, -12454.979, -12450.838, -12446.207, -12441.087, -12435.479, -12429.382, -12422.798, -12415.726, -12408.166000000001, -12400.12, -12391.587, -12382.569, -12373.063999999998, -12363.073, -12352.597, -12341.633999999998, -12330.187, -12318.255, -12305.838, -12292.936000000002, -12279.55, -12265.678999999998, -12251.323, -12236.483, -12221.158000000001, -12205.35, -12189.056999999999, -12172.28, -12155.018, -12137.271999999999, -12119.042, -12100.327, -12081.128, -12061.445, -12041.276000000002, -12020.623, -11999.483999999999, -11977.86, -11955.751, -11933.157, -11910.077, -11886.51, -11862.458, -11837.918, -11812.892, -11787.378999999999, -11761.378999999999, -11734.89, -11707.913, -11680.448, -11652.495, -11624.052, -11595.118999999999, -11565.696000000002, -11535.783000000001, -11505.378, -11474.481000000002, -11443.093, -11411.213, -11378.839, -11345.971000000001, -11312.61, -11278.753, -11244.4, -11209.552, -11174.207, -11138.364, -11102.024, -11065.184, -11027.845, -10990.006000000001, -10951.666000000001, -10912.823999999999, -10873.479, -10833.631000000001, -10793.278, -10752.421, -10711.058, -10669.187, -10626.809, -10583.923, -10540.526000000002, -10496.618, -10452.199, -10407.268, -10361.823, -10315.863000000001, -10269.386999999999, -10222.394, -10174.884, -10126.854, -10078.304, -10029.233, -9979.638, -9929.52, -9878.877, -9827.708, -9776.011, -9723.785, -9671.029, -9617.74, -9563.919, -9509.564, -9454.674, -9399.245, -9343.278, -9286.771, -9229.723, -9172.132, -9113.996, -9055.314, -8996.083, -8936.304, -8875.973, -8815.09, -8753.653, -8691.66, -8629.109, -8565.998, -8502.326, -8438.091, -8373.292, -8307.926, -8241.992, -8175.486999999999, -8108.41, -8040.759, -7972.531999999999, -7903.727, -7834.342, -7764.375, -7693.825, -7622.689, -7550.965, -7478.651, -7405.745, -7332.245, -7258.149, -7183.455, -7108.161, -7032.263000000001, -6955.7609999999995, -6878.653, -6800.936, -6722.608, -6643.666, -6564.109, -6483.936, -6403.142, -6321.726, -6239.687, -6157.021, -6073.728, -5989.804, -5905.2480000000005, -5820.057, -5734.23, -5647.765, -5560.659000000001, -5472.911, -5384.519, -5295.481, -5205.795, -5115.46, -5024.474, -4932.834, -4840.541, -4747.593, -4653.988, -4559.726, -4464.804, -4369.223, -4272.982, -4176.08, -4078.5159999999996, -3980.292, -3881.407, -3781.861, -3681.655, -3580.79, -3479.2659999999996, -3377.087, -3274.2540000000004, -3170.7690000000002, -3066.635, -2961.855, -2856.434, -2750.3759999999997, -2643.6859999999997, -2536.369, -2428.4339999999997, -2319.887, -2210.736, -2100.992, -1990.6629999999998, -1879.763, -1768.3029999999999, -1656.3, -1543.7679999999998, -1430.725, -1317.191, -1203.187, -1088.737, -973.868, -858.6080000000001, -742.9889999999999, -627.047, -510.82, -394.35, -277.685, -160.877, -43.981, 72.939, 189.815, 306.57099999999997, 423.124, 539.383, 655.247, 770.605, 885.335, 999.305, 1112.366, 1224.358, 1335.1029999999998, 1444.408, 1552.058, 1657.8229999999999, 1761.4479999999999, 1862.655, 1961.145, 2056.592, 2148.643, 2236.9210000000003, 2321.021, 2400.515, 2474.949, 2543.853, 2606.737, 2663.103, 2712.4509999999996, 2754.2859999999996, 2788.132, 2813.545, 2830.12, 2837.509, 2835.437, 2823.7070000000003, 2802.212, 2770.941, 2729.985, 2679.53, 2619.853, 2551.317, 2474.353, 2389.451, 2297.144, 2197.992, 2092.571, 1981.4589999999998, 1865.223, 1744.418, 1619.5710000000001, 1491.182, 1359.719, 1225.617, 1089.278, 951.068, 811.322, 670.346, 528.413, 385.769, 242.638, 99.21600000000001, -44.317, -187.80599999999998, -331.10900000000004, -474.1, -616.672, -758.743, -900.179, -1040.952, -1180.979, -1320.204, -1458.5739999999998, -1596.045, -1732.58, -1868.146, -2002.714, -2136.26, -2268.764, -2400.2070000000003, -2530.577, -2659.862, -2788.052, -2915.14, -3041.1209999999996, -3165.991, -3289.7470000000003, -3412.3909999999996, -3533.92, -3654.336, -3773.6420000000003, -3891.841, -4008.9359999999997, -4124.931, -4239.831, -4353.642, -4466.3679999999995, -4578.017, -4688.593, -4798.105, -4906.559, -5013.960999999999, -5120.319, -5225.641, -5329.932, -5433.201, -5535.456999999999, -5636.705, -5736.953, -5836.21, -5934.483, -6031.779, -6128.106, -6223.472, -6317.884, -6411.349, -6503.875, -6595.469, -6686.139, -6775.891, -6864.734, -6952.673000000001, -7039.715999999999, -7125.87, -7211.142, -7295.5380000000005, -7379.065, -7461.73, -7543.54, -7624.5, -7704.616, -7783.896, -7862.345, -7939.97, -8016.776, -8092.769, -8167.956, -8242.341, -8315.931, -8388.731, -8460.746, -8531.983, -8602.445, -8672.139000000001, -8741.07, -8809.243, -8876.663, -8943.333, -9009.261, -9074.45, -9138.905, -9202.63, -9265.631, -9327.911, -9389.476, -9450.329, -9510.475, -9569.917, -9628.661, -9686.71, -9744.068000000001, -9800.74, -9856.728000000001, -9912.037, -9966.671, -10020.634, -10073.928, -10126.558, -10178.527, -10229.839, -10280.497, -10330.505, -10379.865, -10428.581, -10476.657, -10524.096000000001, -10570.9, -10617.072, -10662.617, -10707.536, -10751.833, -10795.51, -10838.571000000002, -10881.017, -10922.853000000001, -10964.081, -11004.702, -11044.721000000001, -11084.139, -11122.958999999999, -11161.183, -11198.815, -11235.856000000002, -11272.31, -11308.176000000001, -11343.46, -11378.162, -11412.285, -11445.832, -11478.803999999998, -11511.203000000001, -11543.031, -11574.291000000001, -11604.985, -11635.115, -11664.681999999999, -11693.688, -11722.136, -11750.028, -11777.365, -11804.148000000001, -11830.38, -11856.062, -11881.197, -11905.786, -11929.83, -11953.331, -11976.291000000001, -11998.711000000001, -12020.593, -12041.938, -12062.749, -12083.025, -12102.77, -12121.983, -12140.667, -12158.823, -12176.452, -12193.556, -12210.135, -12226.192, -12241.726999999999, -12256.741000000002, -12271.237, -12285.214, -12298.675, -12311.618999999999, -12324.048999999999, -12335.965, -12347.368999999999, -12358.261, -12368.642, -12378.515, -12387.878, -12396.733, -12405.083, -12412.926000000001, -12420.265, -12427.098999999998, -12433.431, -12439.26, -12444.587, -12449.413, -12453.74, -12457.567, -12460.896, -12463.726999999999, -12466.061000000002, -12467.898000000001, -12469.239, -12470.086000000001, -12470.438, -12470.296, -12469.66, -12468.531, -12466.91, -12464.796999999999, -12462.193000000001, -12459.098999999998, -12455.514, -12451.438999999998, -12446.874, -12441.82, -12436.278, -12430.247, -12423.729, -12416.723, -12409.229, -12401.249, -12392.782, -12383.828000000001, -12374.388, -12364.463, -12354.052, -12343.155, -12331.773000000001, -12319.905, -12307.553, -12294.716, -12281.395, -12267.589, -12253.298, -12238.521999999999, -12223.261999999999, -12207.518, -12191.29, -12174.577, -12157.38, -12139.698999999999, -12121.533000000001, -12102.882, -12083.747, -12064.127, -12044.023000000001, -12023.433, -12002.358999999999, -11980.798999999999, -11958.753999999999, -11936.223, -11913.206, -11889.703000000001, -11865.714, -11841.239, -11816.277, -11790.827, -11764.889, -11738.464, -11711.551000000001, -11684.15, -11656.258999999998, -11627.878999999999, -11599.01, -11569.65, -11539.798999999999, -11509.458, -11478.625, -11447.298999999999, -11415.481000000002, -11383.17, -11350.365, -11317.066, -11283.273000000001, -11248.983, -11214.198, -11178.915, -11143.135, -11106.858, -11070.081, -11032.805, -10995.028, -10956.751, -10917.971000000001, -10878.688999999998, -10838.903, -10798.613000000001, -10757.819, -10716.518, -10674.71, -10632.393999999998, -10589.569, -10546.235, -10502.39, -10458.034, -10413.165, -10367.783000000001, -10321.885, -10275.471, -10228.541, -10181.093, -10133.125, -10084.638, -10035.629, -9986.097, -9936.041, -9885.46, -9834.353000000001, -9782.718, -9730.554, -9677.86, -9624.635, -9570.877, -9516.584, -9461.755, -9406.389000000001, -9350.485, -9294.04, -9237.055, -9179.526, -9121.452, -9062.832, -9003.664, -8943.947, -8883.679, -8822.859, -8761.484, -8699.553, -8637.064, -8574.016, -8510.407, -8446.234, -8381.498, -8316.194, -8250.322, -8183.88, -8116.865, -8049.276999999999, -7981.113, -7912.371, -7843.049, -7773.145, -7702.656999999999, -7631.584, -7559.922, -7487.670999999999, -7414.826999999999, -7341.39, -7267.357, -7192.726, -7117.494000000001, -7041.659000000001, -6965.22, -6888.175, -6810.52, -6732.255, -6653.376, -6573.882, -6493.77, -6413.039000000001, -6331.687, -6249.71, -6167.107, -6083.876, -6000.014, -5915.521, -5830.393, -5744.628000000001, -5658.225, -5571.181, -5483.495, -5395.165, -5306.189, -5216.565, -5126.292, -5035.366, -4943.789000000001, -4851.557, -4758.67, -4665.125, -4570.923, -4476.063, -4380.542, -4284.36, -4187.517, -4090.014, -3991.849, -3893.022, -3793.534, -3693.385, -3592.577, -3491.111, -3388.988, -3286.21, -3182.78, -3078.7, -2973.973, -2868.605, -2762.599, -2655.9590000000003, -2548.692, -2440.805, -2332.305, -2223.2, -2113.5, -2003.214, -1892.355, -1780.935, -1668.9679999999998, -1556.471, -1443.461, -1329.9560000000001, -1215.98, -1101.5539999999999, -986.706, -871.4630000000001, -755.8580000000001, -639.925, -523.702, -407.23199999999997, -290.561, -173.74, -56.826, 60.12, 177.03, 293.829, 410.43300000000005, 526.754, 642.691, 758.135, 872.9639999999999, 987.047, 1100.238, 1212.377, 1323.2879999999998, 1432.781, 1540.642, 1646.642, 1750.529, 1852.03, 1950.845, 2046.65, 2139.097, 2227.812, 2312.391, 2392.41, 2467.417, 2536.942, 2600.498, 2657.5879999999997, 2707.711, 2750.3720000000003, 2785.093, 2811.425, 2828.9590000000003, 2837.342, 2836.29, 2825.598, 2805.15, 2774.925, 2735.002, 2685.559, 2626.865, 2559.2729999999997, 2483.2070000000003, 2399.153, 2307.639, 2209.222, 2104.478, 1993.983, 1878.309, 1758.0079999999998, 1633.612, 1505.6229999999998, 1374.5120000000002, 1240.718, 1104.647, 966.666, 827.117, 686.304, 544.505, 401.971, 258.925, 115.569, -27.919, -171.38, -314.67, -457.663, -600.249, -742.329, -883.815, -1024.63, -1164.7089999999998, -1303.991, -1442.4260000000002, -1579.967, -1716.578, -1852.223, -1986.875, -2120.507, -2253.101, -2384.637, -2515.103, -2644.485, -2772.7740000000003, -2899.9629999999997, -3026.046, -3151.02, -3274.881, -3397.63, -3519.265, -3639.788, -3759.202, -3877.509, -3994.711, -4110.815, -4225.8240000000005, -4339.7429999999995, -4452.5779999999995, -4564.335, -4675.02, -4784.641, -4893.2029999999995, -5000.712, -5107.178, -5212.607, -5317.005999999999, -5420.382, -5522.745, -5624.099, -5724.453, -5823.816, -5922.194, -6019.595, -6116.026999999999, -6211.496999999999, -6306.012, -6399.58, -6492.209, -6583.906, -6674.677, -6764.531, -6853.475, -6941.515, -7028.658, -7114.911999999999, -7200.283, -7284.779, -7368.404, -7451.1669999999995, -7533.0740000000005, -7614.130999999999, -7694.345, -7773.721, -7852.266, -7929.986999999999, -8006.888000000001, -8082.976, -8158.257, -8232.735999999999, -8306.42, -8379.312, -8451.421, -8522.75, -8593.304, -8663.09, -8732.112, -8800.376, -8867.886, -8934.646999999999, -9000.664, -9065.942, -9130.487, -9194.301, -9257.39, -9319.758, -9381.411, -9442.351, -9502.584, -9562.113000000001, -9620.943000000001, -9679.079, -9736.523000000001, -9793.28, -9849.353000000001, -9904.747, -9959.466, -10013.513, -10066.891, -10119.605, -10171.657, -10223.053, -10273.794, -10323.884, -10373.326, -10422.125, -10470.283000000001, -10517.803, -10564.688, -10610.942, -10656.567, -10701.567, -10745.944, -10789.702, -10832.841999999999, -10875.368, -10917.283000000001, -10958.59, -10999.291000000001, -11039.388, -11078.883999999998, -11117.783000000001, -11156.085, -11193.795, -11230.913999999999, -11267.444, -11303.388, -11338.748, -11373.527, -11407.726999999999, -11441.35, -11474.398000000001, -11506.873, -11538.778, -11570.113000000001, -11600.883, -11631.088, -11660.73, -11689.811000000002, -11718.333999999999, -11746.3, -11773.711000000001, -11800.569, -11826.874, -11852.631000000001, -11877.839, -11902.501, -11926.618, -11950.192, -11973.225, -11995.719, -12017.673999999999, -12039.091, -12059.973999999998, -12080.322, -12100.139, -12119.423999999999, -12138.18, -12156.408000000001, -12174.108, -12191.283000000001, -12207.934, -12224.062, -12239.668, -12254.753999999999, -12269.32, -12283.368, -12296.899, -12309.913, -12322.413, -12334.399, -12345.873, -12356.835, -12367.287, -12377.228000000001, -12386.661, -12395.586000000001, -12404.003999999999, -12411.917, -12419.325, -12426.228000000001, -12432.628, -12438.526000000002, -12443.921, -12448.816, -12453.211000000001, -12457.107, -12460.503999999999, -12463.403, -12465.805, -12467.71, -12469.118999999999, -12470.033000000001, -12470.452, -12470.378, -12469.809, -12468.748, -12467.194, -12465.148000000001, -12462.611, -12459.583, -12456.065, -12452.056999999999, -12447.559, -12442.572, -12437.096000000001, -12431.131000000001, -12424.678999999998, -12417.739, -12410.312, -12402.398000000001, -12393.997, -12385.108999999999, -12375.735, -12365.875, -12355.53, -12344.698999999999, -12333.383, -12321.581, -12309.294, -12296.521999999999, -12283.266000000001, -12269.525, -12255.298999999999, -12240.589, -12225.395, -12209.716, -12193.552, -12176.903999999999, -12159.771999999999, -12142.155, -12124.053, -12105.468, -12086.396999999999, -12066.841999999999, -12046.802, -12026.277, -12005.266000000001, -11983.771, -11961.79, -11939.323, -11916.371000000001, -11892.931999999999, -11869.007, -11844.596000000001, -11819.697, -11794.311000000002, -11768.438, -11742.077, -11715.228000000001, -11687.89, -11660.063, -11631.746000000001, -11602.94, -11573.643999999998, -11543.857, -11513.58, -11482.81, -11451.548, -11419.794, -11387.546, -11354.805, -11321.569, -11287.839, -11253.613000000001, -11218.891000000001, -11183.671, -11147.954, -11111.74, -11075.026000000002, -11037.813, -11000.1, -10961.886, -10923.169, -10883.95, -10844.226999999999, -10804.0, -10763.268999999998, -10722.031, -10680.286, -10638.033000000001, -10595.271, -10552.0, -10508.218, -10463.925, -10419.119, -10373.799, -10327.965, -10281.615, -10234.747, -10187.360999999999, -10139.457, -10091.032, -10042.086, -9992.617, -9942.625, -9892.107, -9841.062, -9789.49, -9737.389000000001, -9684.758, -9631.596, -9577.901, -9523.67, -9468.904, -9413.601999999999, -9357.76, -9301.379, -9244.456, -9186.99, -9128.979, -9070.421999999999, -9011.317, -8951.663, -8891.458, -8830.701, -8769.389000000001, -8707.521, -8645.095, -8582.11, -8518.564, -8454.455, -8389.780999999999, -8324.541, -8258.732, -8192.353000000001, -8125.401999999999, -8057.8769999999995, -7989.776, -7921.097, -7851.8369999999995, -7781.996999999999, -7711.573, -7640.563, -7568.965, -7496.776, -7423.996, -7350.621999999999, -7276.651999999999, -7202.084, -7126.916, -7051.145, -6974.769, -6897.786999999999, -6820.195, -6741.993, -6663.178000000001, -6583.7480000000005, -6503.6990000000005, -6423.031, -6341.741, -6259.828, -6177.2880000000005, -6094.12, -6010.321999999999, -5925.891, -5840.826, -5755.124, -5668.784000000001, -5581.803000000001, -5494.18, -5405.911999999999, -5316.9980000000005, -5227.437, -5137.226, -5046.363, -4954.847, -4862.677, -4769.851, -4676.369000000001, -4582.228, -4487.428, -4391.967000000001, -4295.846, -4199.064, -4101.62, -4003.514, -3904.7459999999996, -3805.317, -3705.2270000000003, -3604.4759999999997, -3503.0679999999998, -3401.0009999999997, -3298.2790000000005, -3194.9040000000005, -3090.8779999999997, -2986.2059999999997, -2880.8909999999996, -2774.9359999999997, -2668.348, -2561.131, -2453.2929999999997, -2344.84, -2235.782, -2126.126, -2015.884, -1905.065, -1793.685, -1681.756, -1569.2939999999999, -1456.317, -1342.8429999999998, -1228.894, -1114.493, -999.665, -884.44, -768.8480000000001, -652.925, -536.707, -420.236, -303.559, -186.727, -69.794, 47.178000000000004, 164.12099999999998, 280.962, 397.61800000000005, 514.001, 630.01, 745.539, 860.467, 974.663, 1087.983, 1200.269, 1311.346, 1421.026, 1529.0970000000002, 1635.332, 1739.4820000000002, 1841.274, 1940.412, 2036.575, 2129.419, 2218.569, 2303.627, 2384.169, 2459.7470000000003, 2529.8920000000003, 2594.119, 2651.933, 2702.83, 2746.3179999999998, 2781.914, 2809.165, 2827.6609999999996, 2837.039, 2837.011, 2827.36, 2807.9629999999997, 2778.788, 2739.905, 2691.4829999999997, 2633.778, 2567.137, 2491.979, 2408.78, 2318.067, 2220.394, 2116.335, 2006.4660000000001, 1891.36, 1771.57, 1647.631, 1520.0479999999998, 1389.297, 1255.816, 1120.017, 982.27, 842.92, 702.2739999999999, 560.613, 418.191, 275.23400000000004, 131.944, -11.497, -154.92700000000002, -298.203, -441.19599999999997, -583.794, -725.8969999999999, -867.416, -1008.2739999999999, -1148.403, -1287.743, -1426.241, -1563.852, -1700.537, -1836.2620000000002, -1970.997, -2104.717, -2237.4, -2369.029, -2499.59, -2629.0690000000004, -2757.458, -2884.748, -3010.933, -3136.01, -3259.9770000000003, -3382.8309999999997, -3504.572, -3625.203, -3744.724, -3863.138, -3980.449, -4096.661, -4211.779, -4325.806, -4438.751, -4550.617, -4661.41, -4771.139, -4879.81, -4987.428, -5094.002, -5199.539000000001, -5304.045, -5407.529, -5509.996999999999, -5611.4580000000005, -5711.92, -5811.388000000001, -5909.871, -6007.3769999999995, -6103.914000000001, -6199.486999999999, -6294.107, -6387.779, -6480.5109999999995, -6572.309, -6663.183000000001, -6753.139, -6842.184, -6930.325, -7017.569, -7103.923000000001, -7189.394, -7273.986999999999, -7357.7119999999995, -7440.573, -7522.578, -7603.732, -7684.043000000001, -7763.516, -7842.158, -7919.973000000001, -7996.97, -8073.153, -8148.529, -8223.101999999999, -8296.88, -8369.866, -8442.067, -8513.488000000001, -8584.136, -8654.013, -8723.127, -8791.481, -8859.082, -8925.934000000001, -8992.041, -9057.409, -9122.042, -9185.946, -9249.124, -9311.58, -9373.32, -9434.348, -9494.669, -9554.285, -9613.202, -9671.423, -9728.953000000001, -9785.796, -9841.955, -9897.435, -9952.238000000001, -10006.369, -10059.832, -10112.63, -10164.766, -10216.245, -10267.069, -10317.242, -10366.767, -10415.649, -10463.888, -10511.49, -10558.456, -10604.792, -10650.498, -10695.579, -10740.037, -10783.875, -10827.095, -10869.701000000001, -10911.696000000002, -10953.082, -10993.862, -11034.038, -11073.613000000001, -11112.59, -11150.971000000001, -11188.758999999998, -11225.955, -11262.563, -11298.585, -11334.021999999999, -11368.878, -11403.155, -11436.855, -11469.979, -11502.531, -11534.511, -11565.923, -11596.768, -11627.048, -11656.766000000001, -11685.923, -11714.52, -11742.561000000002, -11770.046, -11796.979, -11823.358999999999, -11849.19, -11874.472, -11899.208, -11923.398000000001, -11947.046, -11970.153, -11992.719, -12014.747, -12036.238000000001, -12057.193000000001, -12077.614, -12097.503, -12116.861, -12135.688999999998, -12153.988000000001, -12171.761, -12189.007, -12205.729, -12221.928999999998, -12237.606000000002, -12252.763, -12267.4, -12281.518999999998, -12295.121000000001, -12308.206, -12320.776000000002, -12332.833, -12344.377, -12355.409, -12365.93, -12375.942, -12385.445, -12394.438999999998, -12402.927, -12410.909, -12418.386, -12425.358999999999, -12431.828000000001, -12437.795, -12443.258999999998, -12448.223, -12452.687, -12456.651000000002, -12460.116000000002, -12463.083999999999, -12465.553999999998, -12467.527, -12469.003999999999, -12469.986, -12470.473, -12470.466, -12469.966, -12468.972, -12467.486, -12465.507, -12463.038, -12460.077, -12456.626, -12452.685, -12448.253999999999, -12443.333999999999, -12437.923999999999, -12432.027, -12425.641000000001, -12418.768, -12411.407, -12403.56, -12395.225, -12386.403, -12377.096000000001, -12367.302, -12357.023000000001, -12346.258, -12335.007, -12323.271999999999, -12311.051000000001, -12298.344, -12285.153999999999, -12271.478000000001, -12257.318000000001, -12242.673999999999, -12227.545, -12211.931, -12195.833, -12179.25, -12162.183, -12144.631000000001, -12126.595, -12108.073999999999, -12089.069, -12069.578000000001, -12049.603000000001, -12029.143, -12008.197, -11986.766000000001, -11964.85, -11942.448, -11919.56, -11896.186000000002, -11872.326000000001, -11847.978000000001, -11823.143999999998, -11797.823, -11772.014, -11745.716999999999, -11718.931999999999, -11691.658000000001, -11663.896, -11635.643, -11606.901000000002, -11577.669, -11547.946000000002, -11517.733, -11487.027, -11455.829, -11424.138, -11391.954, -11359.277, -11326.105, -11292.438999999998, -11258.276000000002, -11223.618, -11188.462, -11152.809, -11116.658000000001, -11080.008, -11042.858999999999, -11005.208999999999, -10967.058, -10928.405, -10889.25, -10849.591, -10809.427, -10768.758999999998, -10727.585, -10685.903, -10643.714, -10601.016000000001, -10557.808, -10514.09, -10469.86, -10425.117, -10379.860999999999, -10334.089, -10287.803, -10240.998, -10193.676, -10145.835, -10097.474, -10048.591, -9999.185, -9949.256, -9898.802, -9847.821, -9796.312, -9744.275, -9691.707, -9638.608, -9584.976, -9530.809000000001, -9476.107, -9420.868, -9365.089, -9308.771, -9251.912, -9194.509, -9136.562, -9078.068000000001, -9019.027, -8959.436, -8899.295, -8838.601, -8777.351999999999, -8715.548, -8653.186, -8590.264000000001, -8526.780999999999, -8462.735999999999, -8398.126, -8332.949, -8267.204, -8200.889000000001, -8134.001, -8066.539000000001, -7998.5019999999995, -7929.887, -7860.691999999999, -7790.915, -7720.554, -7649.607, -7578.073, -7505.9490000000005, -7433.233, -7359.923000000001, -7286.017, -7211.512, -7136.406999999999, -7060.7, -6984.388000000001, -6907.47, -6829.941999999999, -6751.804, -6673.052, -6593.685, -6513.7, -6433.096, -6351.87, -6270.02, -6187.544, -6104.439, -6020.705, -5936.338000000001, -5851.335999999999, -5765.696999999999, -5679.42, -5592.5019999999995, -5504.941999999999, -5416.738, -5327.887, -5238.388, -5148.2390000000005, -5057.439, -4965.986, -4873.878, -4781.1140000000005, -4687.693, -4593.6140000000005, -4498.875, -4403.476, -4307.416, -4210.694, -4113.31, -4015.263, -3916.555, -3817.185, -3717.153, -3616.461, -3515.1090000000004, -3413.099, -3310.434, -3207.115, -3103.1440000000002, -2998.526, -2893.263, -2787.361, -2680.824, -2573.658, -2465.869, -2357.464, -2248.451, -2138.84, -2028.641, -1917.865, -1806.525, -1694.634, -1582.2079999999999, -1469.263, -1355.82, -1241.8980000000001, -1127.522, -1012.716, -897.5089999999999, -781.931, -666.0169999999999, -549.804, -433.333, -316.65, -199.80599999999998, -82.855, 34.141999999999996, 151.119, 268.001, 384.709, 501.152, 617.235, 732.8480000000001, 847.8739999999999, 962.183, 1075.631, 1188.0639999999999, 1299.307, 1409.172, 1517.4520000000002, 1623.921, 1728.3310000000001, 1830.4129999999998, 1929.874, 2026.395, 2119.632, 2209.216, 2294.75, 2375.813, 2451.959, 2522.722, 2587.618, 2646.152, 2697.823, 2742.133, 2778.6009999999997, 2806.7709999999997, 2826.2259999999997, 2836.6, 2837.593, 2828.985, 2810.64, 2782.5190000000002, 2744.68, 2697.28, 2640.57, 2574.886, 2500.64, 2418.303, 2328.3979999999997, 2231.475, 2128.107, 2018.871, 1904.338, 1785.066, 1661.59, 1534.418, 1404.029, 1270.868, 1135.343, 997.835, 858.686, 718.211, 576.692, 434.384, 291.517, 148.295, 4.904, -138.494, -281.754, -424.745, -567.354, -709.9630000000001, -851.03, -991.93, -1132.108, -1271.504, -1410.066, -1547.747, -1684.506, -1820.309, -1955.126, -2088.933, -2221.706, -2353.427, -2484.083, -2613.659, -2742.147, -2869.5370000000003, -2995.825, -3121.006, -3245.0759999999996, -3368.035, -3489.883, -3610.62, -3730.2490000000003, -3848.7709999999997, -3966.19, -4082.51, -4197.736, -4311.873, -4424.925, -4536.9, -4647.803, -4757.64, -4866.418, -4974.145, -5080.827, -5186.471, -5291.084, -5394.675, -5497.251, -5598.818, -5699.385, -5798.959, -5897.548000000001, -5995.159000000001, -6091.8, -6187.478, -6282.201, -6375.976, -6468.811, -6560.713000000001, -6651.689, -6741.746, -6830.892, -6919.134, -7006.478, -7092.932, -7178.5019999999995, -7263.195, -7347.019, -7429.978, -7512.08, -7593.331999999999, -7673.74, -7753.31, -7832.047, -7909.9580000000005, -7987.0509999999995, -8063.329000000001, -8138.799, -8213.466, -8287.337, -8360.417, -8432.711, -8504.226, -8574.965, -8644.933, -8714.139000000001, -8782.585, -8850.276, -8917.218, -8983.415, -9048.873, -9113.596, -9177.588, -9240.855, -9303.399, -9365.228000000001, -9426.344000000001, -9486.751, -9546.455, -9605.458, -9663.766, -9721.382, -9778.311, -9834.555, -9890.119, -9945.008, -9999.224, -10052.771, -10105.653, -10157.873, -10209.435, -10260.341999999999, -10310.599, -10360.207, -10409.171, -10457.493, -10505.176000000001, -10552.223999999998, -10598.641000000001, -10644.428, -10689.59, -10734.128, -10778.046, -10821.347, -10864.033000000001, -10906.108, -10947.573999999999, -10988.433, -11028.687, -11068.341, -11107.396999999999, -11145.857, -11183.723, -11220.997, -11257.681999999999, -11293.782, -11329.296999999999, -11364.23, -11398.583999999999, -11432.36, -11465.561000000002, -11498.188, -11530.245, -11561.733, -11592.653999999999, -11623.011, -11652.803999999998, -11682.036, -11710.708999999999, -11738.823999999999, -11766.383999999998, -11793.391000000001, -11819.846000000001, -11845.751, -11871.108, -11895.917, -11920.181999999999, -11943.903, -11967.083, -11989.723, -12011.823999999999, -12033.386999999999, -12054.415, -12074.909, -12094.871000000001, -12114.301000000001, -12133.201000000001, -12151.573, -12169.418, -12186.736, -12203.53, -12219.801000000001, -12235.55, -12250.778, -12265.486, -12279.676000000001, -12293.348, -12306.503999999999, -12319.146, -12331.273000000001, -12342.888, -12353.99, -12364.582, -12374.663999999999, -12384.236, -12393.301000000001, -12401.858, -12409.91, -12417.456, -12424.499, -12431.037, -12437.073, -12442.607, -12447.639, -12452.171999999999, -12456.205, -12459.739, -12462.775, -12465.313999999998, -12467.355, -12468.901000000002, -12469.951000000001, -12470.506000000001, -12470.568000000001, -12470.135, -12469.208999999999, -12467.791000000001, -12465.88, -12463.478000000001, -12460.585, -12457.201000000001, -12453.327, -12448.964, -12444.111, -12438.768, -12432.938, -12426.618999999999, -12419.813, -12412.518999999998, -12404.738000000001, -12396.47, -12387.715, -12378.473999999998, -12368.747, -12358.534, -12347.835, -12336.651000000002, -12324.981000000002, -12312.827, -12300.187, -12287.062, -12273.452, -12259.358, -12244.778999999999, -12229.716, -12214.168, -12198.135, -12181.618, -12164.616000000002, -12147.13, -12129.159, -12110.703000000001, -12091.763, -12072.338, -12052.428, -12032.033000000001, -12011.153, -11989.787, -11967.935, -11945.598, -11922.776000000002, -11899.466, -11875.671, -11851.388, -11826.618, -11801.362, -11775.617, -11749.385, -11722.665, -11695.456, -11667.757, -11639.57, -11610.892, -11581.723999999998, -11552.066, -11521.916000000001, -11491.275, -11460.142, -11428.516000000001, -11396.396, -11363.783000000001, -11330.675, -11297.072, -11262.973999999998, -11228.378999999999, -11193.288, -11157.7, -11121.612, -11085.026000000002, -11047.94, -11010.355, -10972.268, -10933.678999999998, -10894.588, -10854.992, -10814.893, -10774.288, -10733.177, -10691.56, -10649.434, -10606.8, -10563.656, -10520.001, -10475.835, -10431.155999999999, -10385.963, -10340.256, -10294.033000000001, -10247.293, -10200.034, -10152.256, -10103.959, -10055.14, -10005.798, -9955.933, -9905.542, -9854.625, -9803.18, -9751.206, -9698.702, -9645.667, -9592.098, -9537.996, -9483.357, -9428.181999999999, -9372.466999999999, -9316.212, -9259.417, -9202.078000000001, -9144.195, -9085.765, -9026.788, -8967.261, -8907.183, -8846.553, -8785.368, -8723.628, -8661.33, -8598.472, -8535.053, -8471.072, -8406.526, -8341.413, -8275.732, -8209.48, -8142.656, -8075.259, -8007.286, -7938.735, -7869.604, -7799.891, -7729.594, -7658.710999999999, -7587.241, -7515.181, -7442.529, -7369.283, -7295.441, -7221.001, -7145.96, -7070.316999999999, -6994.069, -6917.215, -6839.7519999999995, -6761.677, -6682.9890000000005, -6603.686, -6523.766, -6443.226, -6362.064, -6280.278, -6197.865, -6114.825, -6031.154, -5946.851, -5861.9130000000005, -5776.338000000001, -5690.124, -5603.27, -5515.774, -5427.632, -5338.845, -5249.408, -5159.323, -5068.585, -4977.195, -4885.15, -4792.448, -4699.09, -4605.072, -4510.394, -4415.057, -4319.058, -4222.397, -4125.073, -4027.087, -3928.438, -3829.127, -3729.1540000000005, -3628.52, -3527.2259999999997, -3425.2729999999997, -3322.665, -3219.401, -3115.486, -3010.922, -2905.712, -2799.863, -2693.3779999999997, -2586.262, -2478.522, -2370.165, -2261.199, -2151.634, -2041.4779999999998, -1930.744, -1819.444, -1707.5910000000001, -1595.2, -1482.289, -1368.876, -1254.983, -1140.631, -1025.847, -910.6569999999999, -795.0939999999999, -679.189, -562.981, -446.51099999999997, -329.82300000000004, -212.967, -95.99799999999999, 21.024, 138.034, 254.958, 371.716, 488.22, 604.375, 720.072, 835.196, 949.617, 1063.193, 1175.77, 1287.178, 1397.227, 1505.714, 1612.4160000000002, 1717.086, 1819.457, 1919.2379999999998, 2016.1129999999998, 2109.742, 2199.757, 2285.765, 2367.346, 2444.058, 2515.437, 2580.999, 2640.25, 2692.69, 2737.821, 2775.159, 2804.245, 2824.658, 2836.025, 2838.0409999999997, 2830.4759999999997, 2813.185, 2786.118, 2749.325, 2702.952, 2647.241, 2582.52, 2509.192, 2427.724, 2338.632, 2242.467, 2139.7960000000003, 2031.1979999999999, 1917.245, 1798.496, 1675.489, 1548.735, 1418.713, 1285.873, 1150.629, 1013.362, 874.42, 734.117, 592.742, 450.551, 307.777, 164.627, 21.285999999999998, -122.07799999999999, -265.32, -408.30800000000005, -550.927, -693.073, -834.655, -975.595, -1115.822, -1255.274, -1393.898, -1531.6470000000002, -1668.48, -1804.361, -1939.261, -2073.153, -2206.015, -2337.8289999999997, -2468.5789999999997, -2598.252, -2726.837, -2854.328, -2980.718, -3106.002, -3230.176, -3353.241, -3475.195, -3596.038, -3715.7729999999997, -3834.403, -3951.9309999999996, -4068.3590000000004, -4183.693, -4297.938, -4411.099, -4523.181, -4634.193, -4744.139, -4853.025, -4960.859, -5067.649, -5173.401, -5278.121999999999, -5381.819, -5484.5019999999995, -5586.1759999999995, -5686.848000000001, -5786.528, -5885.222, -5982.938, -6079.684, -6175.465999999999, -6270.2919999999995, -6364.170999999999, -6457.109, -6549.111999999999, -6640.19, -6730.35, -6819.597, -6907.939, -6995.383000000001, -7081.937, -7167.607, -7252.4, -7336.321, -7419.379, -7501.579000000001, -7582.928000000001, -7663.433000000001, -7743.098000000001, -7821.932, -7899.94, -7977.1269999999995, -8053.5, -8129.065, -8203.826, -8277.791, -8350.964, -8423.351, -8494.957, -8565.789, -8635.85, -8705.146999999999, -8773.684000000001, -8841.465, -8908.498, -8974.785, -9040.333, -9105.145, -9169.226999999999, -9232.581, -9295.215, -9357.131, -9418.335, -9478.83, -9538.62, -9597.71, -9656.104, -9713.806999999999, -9770.821, -9827.152, -9882.801, -9937.774, -9992.075, -10045.706, -10098.671999999999, -10150.976999999999, -10202.622, -10253.612, -10303.951, -10353.642, -10402.688, -10451.093, -10498.858, -10545.988000000001, -10592.486, -10638.355, -10683.597, -10728.216999999999, -10772.215, -10815.597, -10858.363000000001, -10900.517, -10942.062, -10983.0, -11023.335, -11063.068000000001, -11102.202, -11140.74, -11178.684, -11216.037, -11252.8, -11288.976999999999, -11324.57, -11359.581, -11394.011, -11427.864, -11461.142, -11493.846000000001, -11525.979, -11557.544, -11588.54, -11618.972, -11648.84, -11678.148000000001, -11706.896, -11735.087, -11762.722, -11789.803, -11816.333, -11842.312, -11867.743, -11892.627, -11916.966, -11940.761, -11964.015, -11986.726999999999, -12008.901000000002, -12030.538, -12051.64, -12072.207, -12092.241000000002, -12111.743999999999, -12130.716, -12149.16, -12167.077, -12184.466999999999, -12201.333999999999, -12217.676000000001, -12233.497, -12248.796, -12263.576000000001, -12277.837, -12291.581, -12304.808, -12317.52, -12329.718, -12341.403, -12352.576000000001, -12363.238000000001, -12373.39, -12383.033000000001, -12392.168, -12400.795, -12408.917, -12416.533000000001, -12423.645, -12430.253, -12436.358, -12441.961000000001, -12447.063, -12451.665, -12455.767, -12459.37, -12462.475, -12465.083, -12467.193000000001, -12468.806999999999, -12469.925, -12470.548999999999, -12470.678999999998, -12470.313999999998, -12469.457, -12468.106000000002, -12466.263, -12463.928999999998, -12461.104, -12457.788, -12453.981000000002, -12449.685, -12444.9, -12439.625, -12433.862, -12427.611, -12420.871000000001, -12413.643999999998, -12405.93, -12397.729, -12389.041000000001, -12379.867, -12370.207, -12360.06, -12349.427, -12338.31, -12326.707, -12314.618, -12302.045, -12288.986, -12275.443000000001, -12261.413999999999, -12246.902, -12231.903999999999, -12216.421999999999, -12200.456, -12184.003999999999, -12167.069, -12149.648000000001, -12131.743, -12113.353000000001, -12094.478000000001, -12075.118, -12055.274, -12034.944, -12014.128999999999, -11992.829, -11971.043, -11948.771, -11926.013, -11902.768999999998, -11879.038, -11854.821000000002, -11830.117, -11804.925, -11779.246000000001, -11753.079, -11726.423, -11699.278, -11671.645, -11643.521999999999, -11614.909, -11585.806, -11556.213, -11526.127, -11495.55, -11464.481000000002, -11432.92, -11400.865, -11368.316, -11335.273000000001, -11301.735, -11267.701000000001, -11233.17, -11198.143, -11162.618999999999, -11126.596000000001, -11090.075, -11053.053999999998, -11015.532, -10977.51, -10938.985, -10899.957, -10860.426000000001, -10820.391000000001, -10779.851, -10738.803999999998, -10697.251, -10655.188999999998, -10612.618999999999, -10569.538999999999, -10525.948999999999, -10481.847, -10437.232, -10392.103000000001, -10346.46, -10300.301, -10253.625, -10206.43, -10158.716999999999, -10110.483, -10061.728000000001, -10012.451, -9962.649, -9912.322, -9861.469000000001, -9810.088, -9758.179, -9705.739, -9652.768, -9599.263, -9545.225, -9490.65, -9435.538, -9379.888, -9323.698, -9266.966999999999, -9209.692, -9151.873, -9093.508, -9034.594000000001, -8975.131, -8915.118, -8854.552, -8793.431999999999, -8731.756, -8669.521999999999, -8606.728000000001, -8543.374, -8479.457, -8414.975, -8349.926, -8284.31, -8218.123, -8151.3640000000005, -8084.03, -8016.121, -7947.634, -7878.568, -7808.919, -7738.687, -7667.869000000001, -7596.463000000001, -7524.467, -7451.88, -7378.698, -7304.920999999999, -7230.545, -7155.568, -7079.99, -7003.806, -6927.017, -6849.618, -6771.608, -6692.985, -6613.746999999999, -6533.89, -6453.414000000001, -6372.316999999999, -6290.595, -6208.246999999999, -6125.271, -6041.664000000001, -5957.424, -5872.55, -5787.04, -5700.89, -5614.1, -5526.6669999999995, -5438.589, -5349.865, -5260.493, -5170.47, -5079.795999999999, -4988.468, -4896.485, -4803.846, -4710.55, -4616.595, -4521.979, -4426.7029999999995, -4330.765, -4234.165, -4136.902, -4038.9770000000003, -3940.388, -3841.137, -3741.222, -3640.647, -3539.4109999999996, -3437.5159999999996, -3334.9640000000004, -3231.756, -3127.8959999999997, -3023.386, -2918.2309999999998, -2812.434, -2706.0009999999997, -2598.936, -2491.246, -2382.937, -2274.018, -2164.498, -2054.386, -1943.694, -1832.433, -1720.618, -1608.263, -1495.386, -1382.004, -1268.139, -1153.812, -1039.05, -923.878, -808.329, -692.434, -576.231, -459.76099999999997, -343.06800000000004, -226.201, -109.214, 7.832999999999999, 124.875, 241.84, 358.649, 475.214, 591.439, 707.22, 822.44, 936.9730000000001, 1050.677, 1163.3980000000001, 1274.969, 1385.203, 1493.8970000000002, 1600.83, 1705.7579999999998, 1808.4160000000002, 1908.515, 2005.743, 2099.762, 2190.205, 2276.6839999999997, 2358.78, 2436.055, 2508.044, 2574.268, 2634.2329999999997, 2687.438, 2733.386, 2771.591, 2801.59, 2822.9570000000003, 2835.316, 2838.353, 2831.829, 2815.592, 2789.5809999999997, 2753.835, 2708.493, 2653.783, 2590.027, 2517.6220000000003, 2437.027, 2348.755, 2253.351, 2151.383, 2043.43, 1930.0620000000001, 1811.842, 1689.307, 1562.974, 1433.325, 1300.8110000000001, 1165.8519999999999, 1028.829, 890.096, 749.97, 608.741, 466.66900000000004, 323.99, 180.91299999999998, 37.626, -105.704, -248.926, -391.91, -534.536, -676.702, -818.315, -959.294, -1099.568, -1239.076, -1377.7620000000002, -1515.578, -1652.484, -1788.442, -1923.4229999999998, -2057.401, -2190.351, -2322.256, -2453.1, -2582.87, -2711.553, -2839.1440000000002, -2965.635, -3091.022, -3215.3, -3338.469, -3460.528, -3581.478, -3701.32, -3820.0570000000002, -3937.692, -4054.228, -4169.67, -4284.023, -4397.293, -4509.483, -4620.603, -4730.656, -4839.651, -4947.593, -5054.49, -5160.349, -5265.177, -5368.981, -5471.77, -5573.55, -5674.328, -5774.113, -5872.911999999999, -5970.733, -6067.5830000000005, -6163.469, -6258.399, -6352.38, -6445.420999999999, -6537.526999999999, -6628.706999999999, -6718.967, -6808.315, -6896.758000000001, -6984.302, -7070.956, -7156.725, -7241.616999999999, -7325.637, -7408.7919999999995, -7491.09, -7572.536999999999, -7653.138000000001, -7732.9, -7811.829000000001, -7889.933000000001, -7967.215, -8043.683000000001, -8119.342, -8194.197, -8268.255, -8341.521999999999, -8414.002, -8485.701, -8556.624, -8626.777, -8696.165, -8764.793, -8832.665, -8899.788, -8966.166, -9031.803, -9096.702, -9160.873, -9224.315999999999, -9287.038, -9349.042, -9410.333, -9470.915, -9530.793, -9589.97, -9648.45, -9706.238000000001, -9763.339, -9819.754, -9875.489, -9930.548, -9984.933, -10038.648000000001, -10091.698, -10144.086, -10195.815, -10246.889000000001, -10297.312, -10347.085, -10396.213, -10444.699, -10492.546999999999, -10539.758999999998, -10586.339, -10632.288999999999, -10677.612, -10722.312, -10766.391000000001, -10809.851999999999, -10852.698, -10894.933, -10936.558, -10977.575, -11017.989, -11057.801000000001, -11097.014, -11135.63, -11173.652, -11211.083, -11247.925, -11284.18, -11319.85, -11354.938, -11389.445, -11423.375, -11456.73, -11489.511, -11521.72, -11553.361, -11584.433, -11614.941, -11644.886, -11674.268, -11703.091999999999, -11731.358, -11759.068000000001, -11786.223999999998, -11812.829, -11838.882, -11864.386999999999, -11889.345, -11913.758, -11937.627, -11960.954, -11983.741000000002, -12005.989, -12027.698999999999, -12048.873, -12069.513, -12089.62, -12109.195, -12128.241000000002, -12146.757, -12164.746000000001, -12182.208999999999, -12199.148000000001, -12215.562, -12231.454, -12246.825, -12261.676000000001, -12276.008999999998, -12289.823999999999, -12303.122, -12315.906, -12328.175, -12339.93, -12351.173999999999, -12361.906, -12372.128999999999, -12381.841999999999, -12391.046999999999, -12399.745, -12407.937, -12415.623, -12422.803999999998, -12429.482, -12435.656, -12441.329, -12446.501, -12451.171999999999, -12455.343, -12459.016000000001, -12462.188999999998, -12464.866000000002, -12467.045, -12468.726999999999, -12469.915, -12470.607, -12470.805, -12470.508999999998, -12469.719, -12468.437, -12466.662, -12464.396, -12461.639, -12458.391000000001, -12454.652, -12450.423999999999, -12445.706, -12440.499, -12434.803999999998, -12428.618999999999, -12421.947, -12414.787, -12407.14, -12399.006000000001, -12390.386, -12381.278999999999, -12371.685, -12361.606000000002, -12351.04, -12339.989, -12328.452, -12316.43, -12303.923, -12290.931, -12277.455, -12263.493, -12249.046, -12234.115, -12218.698999999999, -12202.798999999999, -12186.413, -12169.543, -12152.188999999998, -12134.35, -12116.026000000002, -12097.216999999999, -12077.923, -12058.143999999998, -12037.88, -12017.131000000001, -11995.896, -11974.175, -11951.969, -11929.277, -11906.098, -11882.433, -11858.281, -11833.642, -11808.515, -11782.901000000002, -11756.798999999999, -11730.208, -11703.128999999999, -11675.561000000002, -11647.503, -11618.955, -11589.917, -11560.389, -11530.368, -11499.856000000002, -11468.851999999999, -11437.355, -11405.365, -11372.881000000001, -11339.903, -11306.428999999998, -11272.46, -11237.993999999999, -11203.032, -11167.572, -11131.614, -11095.157, -11058.201000000001, -11020.743999999999, -10982.786, -10944.325, -10905.362, -10865.896, -10825.925, -10785.448999999999, -10744.466999999999, -10702.979, -10660.982, -10618.476, -10575.461000000001, -10531.935, -10487.896, -10443.346, -10398.282, -10352.703000000001, -10306.608, -10259.997, -10212.867, -10165.218, -10117.049, -10068.358, -10019.144, -9969.407, -9919.145, -9868.357, -9817.04, -9765.195, -9712.82, -9659.913, -9606.473, -9552.498, -9497.988000000001, -9442.942, -9387.356, -9331.23, -9274.563, -9217.353000000001, -9159.598, -9101.296999999999, -9042.448, -8983.05, -8923.101999999999, -8862.6, -8801.544, -8739.933, -8677.763, -8615.034, -8551.745, -8487.892, -8423.475, -8358.491, -8292.939, -8226.817, -8160.121999999999, -8092.854, -8025.01, -7956.588000000001, -7887.585999999999, -7818.0019999999995, -7747.835, -7677.081999999999, -7605.74, -7533.809, -7461.286999999999, -7388.17, -7314.456999999999, -7240.146, -7165.235, -7089.721, -7013.602, -6936.8769999999995, -6859.543000000001, -6781.598000000001, -6703.04, -6623.866, -6544.075, -6463.664000000001, -6382.63, -6300.973000000001, -6218.69, -6135.778, -6052.236, -5968.061, -5883.251, -5797.805, -5711.719, -5624.993, -5537.624, -5449.611, -5360.95, -5271.641, -5181.682, -5091.071, -4999.807, -4907.887, -4815.311, -4722.0779999999995, -4628.184, -4533.630999999999, -4438.417, -4342.541, -4246.002, -4148.8, -4050.935, -3952.406, -3853.2140000000004, -3753.36, -3652.843, -3551.665, -3449.828, -3347.333, -3244.1820000000002, -3140.377, -3035.922, -2930.821, -2825.077, -2718.696, -2611.681, -2504.041, -2395.781, -2286.908, -2177.4339999999997, -2067.366, -1956.7160000000001, -1845.496, -1733.72, -1621.401, -1508.557, -1395.2060000000001, -1281.369, -1167.068, -1052.327, -937.174, -821.6389999999999, -705.755, -589.558, -473.088, -356.39, -239.512, -122.508, -5.437, 111.63799999999999, 228.643, 345.50199999999995, 462.12699999999995, 578.424, 694.288, 809.605, 924.247, 1038.077, 1150.942, 1262.6760000000002, 1373.0929999999998, 1481.9920000000002, 1589.155, 1694.339, 1797.2820000000002, 1897.6979999999999, 1995.277, 2089.6820000000002, 2180.551, 2267.498, 2350.107, 2427.9410000000003, 2500.5389999999998, 2567.422, 2628.097, 2682.065, 2728.827, 2767.8959999999997, 2798.805, 2821.125, 2834.473, 2838.5290000000005, 2833.047, 2817.864, 2792.91, 2758.215, 2713.9040000000005, 2660.202, 2597.416, 2525.939, 2446.223, 2358.775, 2264.139, 2162.881, 2055.577, 1942.8010000000002, 1825.114, 1703.059, 1577.152, 1447.88, 1315.6970000000001, 1181.026, 1044.251, 905.73, 765.784, 624.7040000000001, 482.754, 340.17199999999997, 197.17, 53.938, -89.355, -232.55700000000002, -375.534, -518.1669999999999, -660.202, -801.993, -943.0110000000001, -1083.3319999999999, -1222.894, -1361.641, -1499.524, -1636.5020000000002, -1772.537, -1907.6, -2041.662, -2174.701, -2306.697, -2437.634, -2567.499, -2696.281, -2823.972, -2950.563, -3076.052, -3200.434, -3323.708, -3445.8720000000003, -3566.927, -3686.8759999999997, -3805.72, -3923.462, -4040.1059999999998, -4155.656, -4270.117, -4383.4929999999995, -4495.793, -4607.02, -4717.182, -4826.284000000001, -4934.333, -5041.338, -5147.304, -5252.2390000000005, -5356.15, -5459.044, -5560.93, -5661.815, -5761.705, -5860.609, -5958.534000000001, -6055.488, -6151.478, -6246.5109999999995, -6340.595, -6433.738, -6525.946999999999, -6617.228, -6707.59, -6797.039000000001, -6885.581999999999, -6973.227, -7059.98, -7145.848000000001, -7230.838000000001, -7314.956, -7398.21, -7480.606, -7562.149, -7642.846, -7722.705, -7801.731, -7879.93, -7957.307, -8033.869000000001, -8109.621999999999, -8184.571999999999, -8258.724, -8332.083, -8404.655999999999, -8476.447, -8547.463, -8617.707, -8687.187, -8755.905999999999, -8823.869, -8891.082, -8957.549, -9023.276, -9088.266, -9152.525, -9216.058, -9278.868, -9340.96, -9402.338, -9463.008, -9522.972, -9582.235999999999, -9640.803, -9698.677, -9755.863000000001, -9812.364, -9868.184000000001, -9923.327, -9977.796999999999, -10031.597, -10084.731, -10137.202, -10189.015, -10240.171999999999, -10290.678, -10340.534, -10389.745, -10438.313, -10486.242, -10533.536, -10580.197, -10626.228000000001, -10671.633, -10716.413999999999, -10760.573, -10804.114, -10847.041000000001, -10889.355, -10931.059, -10972.157, -11012.65, -11052.541000000001, -11091.832, -11130.527, -11168.628, -11206.136999999999, -11243.056, -11279.389, -11315.136999999999, -11350.302, -11384.886999999999, -11418.893999999998, -11452.325, -11485.181999999999, -11517.469, -11549.185, -11580.333999999999, -11610.917, -11640.938, -11670.396, -11699.295, -11727.636, -11755.421999999999, -11782.653, -11809.332, -11835.46, -11861.038999999999, -11886.072, -11910.559, -11934.502, -11957.903, -11980.763, -12003.085, -12024.868, -12046.116000000002, -12066.828000000001, -12087.008, -12106.657, -12125.775, -12144.364, -12162.425, -12179.961000000001, -12196.971000000001, -12213.457, -12229.421, -12244.864, -12259.787, -12274.191, -12288.078000000001, -12301.448, -12314.302, -12326.642, -12338.469, -12349.783000000001, -12360.586000000001, -12370.878999999999, -12380.663, -12389.938999999998, -12398.707, -12406.969, -12414.725, -12421.976, -12428.723999999998, -12434.968, -12440.711000000001, -12445.952, -12450.692, -12454.933, -12458.675, -12461.918, -12464.663, -12466.911, -12468.663, -12469.919, -12470.68, -12470.946000000002, -12470.719, -12469.998, -12468.784, -12467.078000000001, -12464.88, -12462.191, -12459.011, -12455.34, -12451.18, -12446.53, -12441.391000000001, -12435.763, -12429.646, -12423.042, -12415.948999999999, -12408.37, -12400.303, -12391.75, -12382.71, -12373.184, -12363.171, -12352.673, -12341.688999999998, -12330.219, -12318.264, -12305.823999999999, -12292.898000000001, -12279.488000000001, -12265.593, -12251.213, -12236.348999999998, -12220.999, -12205.165, -12188.846000000001, -12172.042, -12154.753999999999, -12136.981000000002, -12118.723, -12099.98, -12080.753, -12061.04, -12040.841999999999, -12020.158000000001, -11998.989, -11977.333999999999, -11955.194, -11932.567, -11909.454, -11885.855, -11861.768, -11837.195, -11812.133999999998, -11786.585, -11760.548, -11734.023000000001, -11707.008999999998, -11679.507, -11651.514, -11623.032, -11594.059, -11564.596000000001, -11534.641000000001, -11504.194, -11473.253999999999, -11441.823, -11409.898000000001, -11377.479, -11344.566, -11311.157, -11277.253, -11242.853000000001, -11207.956, -11172.561000000002, -11136.667, -11100.275, -11063.383999999998, -11025.992, -10988.098, -10949.703000000001, -10910.805, -10871.403999999999, -10831.498, -10791.086000000001, -10750.169, -10708.745, -10666.813, -10624.372, -10581.421999999999, -10537.961000000001, -10493.988000000001, -10449.502, -10404.502, -10358.988000000001, -10312.958, -10266.411, -10219.346, -10171.761999999999, -10123.658000000001, -10075.032, -10025.883, -9976.211, -9926.013, -9875.289, -9824.038, -9772.257, -9719.947, -9667.105, -9613.73, -9559.82, -9505.375, -9450.392, -9394.872, -9338.811, -9282.209, -9225.063, -9167.374, -9109.138, -9050.354, -8991.02, -8931.136, -8870.7, -8809.709, -8748.163, -8686.058, -8623.394, -8560.169, -8496.382, -8432.03, -8367.110999999999, -8301.624, -8235.567, -8168.938, -8101.734, -8033.955, -7965.598000000001, -7896.661, -7827.143, -7757.04, -7686.352, -7615.076999999999, -7543.210999999999, -7470.753000000001, -7397.701, -7324.054, -7249.808000000001, -7174.9619999999995, -7099.513000000001, -7023.46, -6946.8, -6869.531, -6791.651, -6713.156999999999, -6634.049, -6554.323, -6473.977, -6393.009, -6311.4169999999995, -6229.198, -6146.351, -6062.874, -5978.764, -5894.019, -5808.637, -5722.616, -5635.954000000001, -5548.649, -5460.7, -5372.104, -5282.86, -5192.965, -5102.417, -5011.215999999999, -4919.36, -4826.847, -4733.6759999999995, -4639.846, -4545.356, -4450.204000000001, -4354.39, -4257.912, -4160.771, -4062.967, -3964.4990000000003, -3865.367, -3765.573, -3665.115, -3563.9959999999996, -3462.216, -3359.778, -3256.684, -3152.935, -3048.5359999999996, -2943.489, -2837.798, -2731.468, -2624.505, -2516.9139999999998, -2408.703, -2299.879, -2190.45, -2080.427, -1969.819, -1858.639, -1746.901, -1634.619, -1521.809, -1408.49, -1294.681, -1180.406, -1065.687, -950.553, -835.0319999999999, -719.158, -602.966, -486.49800000000005, -369.795, -252.907, -135.885, -18.79, 98.316, 215.362, 332.27, 448.955, 565.322, 681.268, 796.68, 911.433, 1025.389, 1138.397, 1250.2910000000002, 1360.89, 1469.994, 1577.385, 1682.8239999999998, 1786.0510000000002, 1886.781, 1984.7079999999999, 2079.499, 2170.7929999999997, 2258.205, 2341.324, 2419.715, 2492.9179999999997, 2560.4570000000003, 2621.8390000000004, 2676.567, 2724.14, 2764.07, 2795.887, 2819.158, 2833.495, 2838.57, 2834.13, 2820.002, 2796.1079999999997, 2762.466, 2719.192, 2666.4990000000003, 2604.69, 2534.145, 2455.314, 2368.698, 2274.8360000000002, 2174.294, 2067.647, 1955.4679999999998, 1838.3210000000001, 1716.75, 1591.274, 1462.3829999999998, 1330.537, 1196.156, 1059.635, 921.329, 781.565, 640.637, 498.81300000000005, 356.33, 213.405, 70.23, -73.024, -216.204, -359.17400000000004, -501.81300000000005, -644.015, -785.685, -926.74, -1067.108, -1206.723, -1345.53, -1483.479, -1620.529, -1756.641, -1891.7839999999999, -2025.93, -2159.0570000000002, -2291.144, -2422.175, -2552.135, -2681.014, -2808.804, -2935.4970000000003, -3061.0879999999997, -3185.573, -3308.95, -3431.22, -3552.382, -3672.437, -3791.387, -3909.237, -4025.988, -4141.645, -4256.214, -4369.6990000000005, -4482.107, -4593.441, -4703.71, -4812.92, -4921.0779999999995, -5028.189, -5134.262, -5239.304, -5343.321999999999, -5446.323, -5548.314, -5649.304, -5749.299, -5848.308000000001, -5946.338000000001, -6043.396, -6139.4890000000005, -6234.626, -6328.813, -6422.059, -6514.369000000001, -6605.7519999999995, -6696.215, -6785.765, -6874.409000000001, -6962.154, -7049.005999999999, -7134.973000000001, -7220.062, -7304.279, -7387.630999999999, -7470.1230000000005, -7551.763000000001, -7632.558000000001, -7712.513000000001, -7791.635, -7869.929, -7947.401, -8024.058000000001, -8099.906, -8174.9490000000005, -8249.195, -8322.646999999999, -8395.312, -8467.196, -8538.304, -8608.641, -8678.211, -8747.021, -8815.075, -8882.378, -8948.935, -9014.751, -9079.831, -9144.179, -9207.8, -9270.698, -9332.878, -9394.344000000001, -9455.101, -9515.153, -9574.503, -9633.155999999999, -9691.117, -9748.388, -9804.975, -9860.88, -9916.108, -9970.662, -10024.546999999999, -10077.765, -10130.321, -10182.216999999999, -10233.458, -10284.046, -10333.984, -10383.278, -10431.929, -10479.94, -10527.316, -10574.059, -10620.171, -10665.657, -10710.518, -10754.758, -10798.38, -10841.386999999999, -10883.781, -10925.565, -10966.742, -11007.313999999998, -11047.284, -11086.653999999999, -11125.428, -11163.607, -11201.195, -11238.193000000001, -11274.603000000001, -11310.428, -11345.671, -11380.333, -11414.417, -11447.925, -11480.86, -11513.223, -11545.016000000001, -11576.241000000002, -11606.9, -11636.996000000001, -11666.53, -11695.505, -11723.921999999999, -11751.782, -11779.089, -11805.843, -11832.045, -11857.698999999999, -11882.806, -11907.367, -11931.385, -11954.86, -11977.794, -12000.188999999998, -12022.046, -12043.367, -12064.153, -12084.406, -12104.128, -12123.319, -12141.981000000002, -12160.115, -12177.723, -12194.805, -12211.364, -12227.4, -12242.915, -12257.91, -12272.385, -12286.344, -12299.785, -12312.711000000001, -12325.122, -12337.02, -12348.405, -12359.278999999999, -12369.643, -12379.498, -12388.844, -12397.683, -12406.015, -12413.841999999999, -12421.163999999999, -12427.981000000002, -12434.295, -12440.108, -12445.419, -12450.229, -12454.538999999999, -12458.351, -12461.663, -12464.478000000001, -12466.795, -12468.616000000002, -12469.941, -12470.771, -12471.107, -12470.948, -12470.296, -12469.151000000002, -12467.513, -12465.383, -12462.763, -12459.651000000002, -12456.048999999999, -12451.957, -12447.375, -12442.303999999998, -12436.743999999999, -12430.695, -12424.159, -12417.133999999998, -12409.622, -12401.623, -12393.138, -12384.165, -12374.706, -12364.761, -12354.33, -12343.413, -12332.011, -12320.123, -12307.75, -12294.891000000001, -12281.548, -12267.72, -12253.407, -12238.608999999999, -12223.327, -12207.559, -12191.306, -12174.569, -12157.348, -12139.641000000001, -12121.45, -12102.774, -12083.612, -12063.966, -12043.833999999999, -12023.216999999999, -12002.114, -11980.525, -11958.451000000001, -11935.89, -11912.843, -11889.31, -11865.29, -11840.782, -11815.787, -11790.303999999998, -11764.333, -11737.874, -11710.926000000001, -11683.489, -11655.562, -11627.145, -11598.238000000001, -11568.84, -11538.951000000001, -11508.57, -11477.696000000002, -11446.33, -11414.47, -11382.117, -11349.268999999998, -11315.926000000001, -11282.088, -11247.753, -11212.921, -11177.591, -11141.763, -11105.437, -11068.61, -11031.284, -10993.456, -10955.126, -10916.293, -10876.957, -10837.116000000002, -10796.77, -10755.918, -10714.559, -10672.692, -10630.317, -10587.431, -10544.035, -10500.128, -10455.707, -10410.773000000001, -10365.323, -10319.359, -10272.877, -10225.877, -10178.358, -10130.319, -10081.759, -10032.675, -9983.068000000001, -9932.935, -9882.276, -9831.09, -9779.375, -9727.13, -9674.353000000001, -9621.043, -9567.199, -9512.819, -9457.902, -9402.446, -9346.451, -9289.914, -9232.834, -9175.21, -9117.039, -9058.321, -8999.053, -8939.234, -8878.863000000001, -8817.937, -8756.456, -8694.418, -8631.819, -8568.66, -8504.938, -8440.651, -8375.798, -8310.376, -8244.385, -8177.821, -8110.683000000001, -8042.969, -7974.68, -7905.808000000001, -7836.355, -7766.319, -7695.696, -7624.486, -7552.686, -7480.294, -7407.309, -7333.726, -7259.545999999999, -7184.765, -7109.382, -7033.395, -6956.8009999999995, -6879.598000000001, -6801.783, -6723.355, -6644.312, -6564.651999999999, -6484.371, -6403.469, -6321.941999999999, -6239.789000000001, -6157.008000000001, -6073.596, -5989.5509999999995, -5904.871, -5819.554, -5733.599, -5647.0019999999995, -5559.763000000001, -5471.878000000001, -5383.347, -5294.166, -5204.335, -5113.852, -5022.715999999999, -4930.924, -4838.475, -4745.367, -4651.6, -4557.1720000000005, -4462.083, -4366.331, -4269.916, -4172.838, -4075.095, -3976.688, -3877.616, -3777.881, -3677.4829999999997, -3576.423, -3474.702, -3372.322, -3269.285, -3165.593, -3061.2490000000003, -2956.256, -2850.619, -2744.342, -2637.4309999999996, -2529.891, -2421.729, -2312.952, -2203.569, -2093.59, -1983.025, -1871.8870000000002, -1760.1879999999999, -1647.942, -1535.1670000000001, -1421.88, -1308.1, -1193.85, -1079.154, -964.038, -848.533, -732.67, -616.485, -500.01800000000003, -383.311, -266.41200000000003, -149.374, -32.255, 84.883, 201.968, 318.925, 435.66900000000004, 552.106, 668.135, 783.6419999999999, 898.5039999999999, 1012.584, 1125.734, 1237.789, 1348.569, 1457.876, 1565.495, 1671.1870000000001, 1774.6970000000001, 1875.7420000000002, 1974.016, 2069.19, 2160.907, 2248.783, 2332.411, 2411.356, 2485.163, 2553.357, 2615.446, 2670.9309999999996, 2719.3140000000003, 2760.1040000000003, 2792.829, 2817.051, 2832.3779999999997, 2838.474, 2835.078, 2822.009, 2799.179, 2766.594, 2724.363, 2672.687, 2611.86, 2542.257, 2464.319, 2378.541, 2285.462, 2185.644, 2079.66, 1968.086, 1851.486, 1730.405, 1605.3670000000002, 1476.864, 1345.3570000000002, 1211.2730000000001, 1075.008, 936.922, 797.3430000000001, 656.571, 514.873, 372.49199999999996, 229.646, 86.53, -56.684, -199.84099999999998, -342.80199999999996, -485.44599999999997, -627.664, -769.362, -910.454, -1050.867, -1190.535, -1329.402, -1467.418, -1604.539, -1740.7279999999998, -1875.951, -2010.181, -2143.396, -2275.573, -2406.697, -2536.7529999999997, -2665.73, -2793.619, -2920.413, -3046.1059999999998, -3170.6940000000004, -3294.177, -3416.552, -3537.82, -3657.9809999999998, -3777.038, -3894.995, -4011.8540000000003, -4127.62, -4242.295999999999, -4355.889, -4468.404, -4579.848, -4690.224, -4799.542, -4907.807, -5015.026, -5121.206, -5226.354, -5330.479, -5433.585999999999, -5535.684, -5636.78, -5736.880999999999, -5835.994000000001, -5934.128000000001, -6031.29, -6127.488, -6222.728, -6317.018, -6410.366, -6502.779, -6594.264, -6684.829000000001, -6774.479, -6863.223000000001, -6951.068, -7038.02, -7124.0869999999995, -7209.274, -7293.589, -7377.039000000001, -7459.63, -7541.368, -7622.259, -7702.311, -7781.528, -7859.9169999999995, -7937.485, -8014.236999999999, -8090.179, -8165.316999999999, -8239.655, -8313.201, -8385.959, -8457.936, -8529.136, -8599.564, -8669.226, -8738.126, -8806.271, -8873.665, -8940.312, -9006.218, -9071.386999999999, -9135.824, -9199.533000000001, -9262.52, -9324.788, -9386.341999999999, -9447.187, -9507.325, -9566.763, -9625.503, -9683.549, -9740.905999999999, -9797.579, -9853.57, -9908.883, -9963.521999999999, -10017.491, -10070.793, -10123.431999999999, -10175.412, -10226.735999999999, -10277.408000000001, -10327.43, -10376.806, -10425.539, -10473.632, -10521.09, -10567.913999999999, -10614.108, -10659.675, -10704.618, -10748.938999999998, -10792.641000000001, -10835.728000000001, -10878.202, -10920.066, -10961.322, -11001.973999999998, -11042.024, -11081.473, -11120.326000000001, -11158.583999999999, -11196.249, -11233.325, -11269.813, -11305.716999999999, -11341.037, -11375.777, -11409.938999999998, -11443.524, -11476.535, -11508.973999999998, -11540.843, -11572.145, -11602.881000000001, -11633.053, -11662.663999999999, -11691.714, -11720.206, -11748.141000000001, -11775.523000000001, -11802.351999999999, -11828.63, -11854.358999999999, -11879.541000000001, -11904.176000000001, -11928.268, -11951.817, -11974.823999999999, -11997.293, -12019.225, -12040.618999999999, -12061.479, -12081.806, -12101.6, -12120.864, -12139.598999999998, -12157.806, -12175.486, -12192.641000000001, -12209.271999999999, -12225.381000000001, -12240.968, -12256.035, -12270.583, -12284.613000000001, -12298.126, -12311.123, -12323.605, -12335.575, -12347.032, -12357.976999999999, -12368.412, -12378.338, -12387.755, -12396.663999999999, -12405.067, -12412.963, -12420.355, -12427.243, -12433.628, -12439.511, -12444.892, -12449.771999999999, -12454.152, -12458.033000000001, -12461.415, -12464.298999999999, -12466.686000000002, -12468.577, -12469.971000000001, -12470.87, -12471.275, -12471.186000000002, -12470.601999999999, -12469.526000000002, -12467.958, -12465.896999999999, -12463.345, -12460.301000000001, -12456.767, -12452.743999999999, -12448.23, -12443.228000000001, -12437.736, -12431.756000000001, -12425.287, -12418.331, -12410.886999999999, -12402.956, -12394.537, -12385.633, -12376.242, -12366.364, -12356.001, -12345.152, -12333.817, -12321.996000000001, -12309.69, -12296.899, -12283.623, -12269.862, -12255.616000000002, -12240.885, -12225.67, -12209.969, -12193.784, -12177.114, -12159.958999999999, -12142.319, -12124.194, -12105.583999999999, -12086.49, -12066.91, -12046.845, -12026.294, -12005.258, -11983.736, -11961.728000000001, -11939.233999999999, -11916.253, -11892.786, -11868.831, -11844.39, -11819.461000000001, -11794.045, -11768.14, -11741.747, -11714.865, -11687.493999999999, -11659.633, -11631.282, -11602.441, -11573.108999999999, -11543.285, -11512.97, -11482.163, -11450.863000000001, -11419.069, -11386.781, -11353.999, -11320.721000000001, -11286.948, -11252.678999999998, -11217.913, -11182.649, -11146.886999999999, -11110.626, -11073.866000000002, -11036.604, -10998.841999999999, -10960.577, -10921.81, -10882.538999999999, -10842.764, -10802.483999999999, -10761.698, -10720.405, -10678.603000000001, -10636.293, -10593.473999999998, -10550.143, -10506.3, -10461.945, -10417.076, -10371.693000000001, -10325.794, -10279.378, -10232.444, -10184.99, -10137.016, -10088.521, -10039.503, -9989.961, -9939.895, -9889.302, -9838.181, -9786.530999999999, -9734.351999999999, -9681.64, -9628.396, -9574.617, -9520.303, -9465.452, -9410.062, -9354.132, -9297.661, -9240.646, -9183.087, -9124.982, -9066.329, -9007.127, -8947.375, -8887.069, -8826.21, -8764.795, -8702.822, -8640.289, -8577.196, -8513.54, -8449.319, -8384.530999999999, -8319.175, -8253.25, -8186.7519999999995, -8119.68, -8052.033, -7983.808000000001, -7915.0019999999995, -7845.615, -7775.644, -7705.088000000001, -7633.944, -7562.21, -7489.884, -7416.965, -7343.448, -7269.334, -7194.619000000001, -7119.303000000001, -7043.380999999999, -6966.853, -6889.715999999999, -6811.968000000001, -6733.606, -6654.628000000001, -6575.034000000001, -6494.819, -6413.983, -6332.522, -6250.435, -6167.72, -6084.3730000000005, -6000.394, -5915.779, -5830.528, -5744.638000000001, -5658.107, -5570.933000000001, -5483.113, -5394.647, -5305.531, -5215.765, -5125.347, -5034.274, -4942.5470000000005, -4850.162, -4757.1179999999995, -4663.415, -4569.05, -4474.024, -4378.335, -4281.982, -4184.965999999999, -4087.285, -3988.9390000000003, -3889.928, -3790.2540000000004, -3689.9159999999997, -3588.915, -3487.2529999999997, -3384.9309999999996, -3281.9509999999996, -3178.316, -3074.027, -2969.0890000000004, -2863.506, -2757.283, -2650.423, -2542.9339999999997, -2434.821, -2326.093, -2216.757, -2106.823, -1996.3010000000002, -1885.204, -1773.5439999999999, -1661.336, -1548.595, -1435.34, -1321.59, -1207.366, -1092.693, -977.596, -862.107, -746.255, -630.076, -513.611, -396.9, -279.991, -162.937, -45.795, 71.374, 188.49900000000002, 305.504, 422.306, 538.813, 654.922, 770.5239999999999, 885.4939999999999, 999.698, 1112.989, 1225.204, 1336.164, 1445.6729999999998, 1553.517, 1659.4620000000002, 1763.2520000000002, 1864.609, 1963.229, 2058.784, 2150.9210000000003, 2239.259, 2323.3920000000003, 2402.889, 2477.297, 2546.141, 2608.933, 2665.1740000000004, 2714.364, 2756.011, 2789.6420000000003, 2814.813, 2831.127, 2838.244, 2835.893, 2823.883, 2802.118, 2770.594, 2729.409, 2678.755, 2618.916, 2550.26, 2473.22, 2388.288, 2295.999, 2196.91, 2091.597, 1980.6329999999998, 1864.585, 1744.0020000000002, 1619.4070000000002, 1491.295, 1360.1329999999998, 1226.351, 1090.346, 952.4830000000001, 813.0930000000001, 672.4780000000001, 530.909, 388.63300000000004, 245.868, 102.811, -40.361, -183.49200000000002, -326.444, -469.091, -611.3430000000001, -753.05, -894.178, -1034.635, -1174.356, -1313.283, -1451.364, -1588.556, -1724.8210000000001, -1860.124, -1994.4389999999999, -2127.741, -2260.009, -2391.226, -2521.3779999999997, -2650.4509999999996, -2778.44, -2905.3340000000003, -3031.13, -3155.822, -3279.408, -3401.888, -3523.261, -3643.53, -3762.6940000000004, -3880.758, -3997.724, -4113.597, -4228.3820000000005, -4342.084, -4454.707, -4566.258, -4676.742, -4786.168, -4894.54, -5001.867, -5108.155, -5213.41, -5317.64, -5420.854, -5523.058000000001, -5624.259, -5724.465999999999, -5823.684, -5921.923000000001, -6019.189, -6115.49, -6210.834, -6305.228, -6398.678000000001, -6491.193, -6582.779, -6673.445, -6763.196999999999, -6852.0419999999995, -6939.986999999999, -7027.0380000000005, -7113.204000000001, -7198.491, -7282.905, -7366.453, -7449.141, -7530.976, -7611.963000000001, -7692.111, -7771.425, -7849.91, -7927.573, -8004.42, -8080.456, -8155.687, -8230.12, -8303.759, -8376.61, -8448.679, -8519.971, -8590.492, -8660.245, -8729.235999999999, -8797.472, -8864.956, -8931.693000000001, -8997.689, -9062.947, -9127.474, -9191.271999999999, -9254.346, -9316.702, -9378.344000000001, -9439.276, -9499.502, -9559.026, -9617.853000000001, -9675.985999999999, -9733.429, -9790.186, -9846.261999999999, -9901.661, -9956.385, -10010.438, -10063.825, -10116.549, -10168.613000000001, -10220.02, -10270.774, -10320.879, -10370.337, -10419.153, -10467.329, -10514.868999999999, -10561.775, -10608.05, -10653.698, -10698.721000000001, -10743.123, -10786.906, -10830.073999999999, -10872.628, -10914.572, -10955.908000000001, -10996.639, -11036.768, -11076.296999999999, -11115.228000000001, -11153.563999999998, -11191.309, -11228.463, -11265.028999999999, -11301.011, -11336.409, -11371.226, -11405.465, -11439.128, -11472.215, -11504.731000000002, -11536.678, -11568.056, -11598.868, -11629.116000000002, -11658.803, -11687.928999999998, -11716.497, -11744.508, -11771.965, -11798.868, -11825.221000000001, -11851.025, -11876.281, -11900.992, -11925.158000000001, -11948.781, -11971.864, -11994.407, -12016.411, -12037.88, -12058.813, -12079.212, -12099.08, -12118.417, -12137.225, -12155.505, -12173.258, -12190.486, -12207.19, -12223.371000000001, -12239.03, -12254.169, -12268.788999999999, -12282.89, -12296.475, -12309.545, -12322.098999999998, -12334.14, -12345.668, -12356.685, -12367.191, -12377.188, -12386.676000000001, -12395.655, -12404.128999999999, -12412.096000000001, -12419.559, -12426.518, -12432.973, -12438.926000000001, -12444.377, -12449.328000000001, -12453.778, -12457.728000000001, -12461.18, -12464.133999999998, -12466.59, -12468.55, -12470.015, -12470.983, -12471.457, -12471.437, -12470.923, -12469.916000000001, -12468.416000000001, -12466.425, -12463.941, -12460.966, -12457.501, -12453.546, -12449.101, -12444.167, -12438.743999999999, -12432.832, -12426.431999999999, -12419.544, -12412.168, -12404.305, -12395.955, -12387.118, -12377.794, -12367.985, -12357.688999999998, -12346.908000000001, -12335.64, -12323.888, -12311.649, -12298.926000000001, -12285.718, -12272.024, -12257.845, -12243.181, -12228.033000000001, -12212.399, -12196.281, -12179.678, -12162.591, -12145.018, -12126.96, -12108.418, -12089.39, -12069.877, -12049.878999999999, -12029.393999999998, -12008.425, -11986.969, -11965.028, -11942.6, -11919.686000000002, -11896.285, -11872.398000000001, -11848.023000000001, -11823.161, -11797.811000000002, -11771.972, -11745.645, -11718.829, -11691.524, -11663.73, -11635.445, -11606.67, -11577.405, -11547.648000000001, -11517.399, -11486.657, -11455.423, -11423.695, -11391.473999999998, -11358.757, -11325.546, -11291.839, -11257.636, -11222.936000000002, -11187.738000000001, -11152.042, -11115.847, -11079.152, -11041.957, -11004.26, -10966.062, -10927.36, -10888.155, -10848.446000000002, -10808.231000000002, -10767.511, -10726.284, -10684.548, -10642.303999999998, -10599.55, -10556.285, -10512.508999999998, -10468.22, -10423.417, -10378.099, -10332.265, -10285.915, -10239.046, -10191.659, -10143.751, -10095.322, -10046.37, -9996.894, -9946.893, -9896.366, -9845.311, -9793.726999999999, -9741.613000000001, -9688.968, -9635.79, -9582.077, -9527.829, -9473.044, -9417.72, -9361.856, -9305.451, -9248.502, -9191.009, -9132.97, -9074.383, -9015.248, -8955.561, -8895.322, -8834.528, -8773.179, -8711.271999999999, -8648.806, -8585.779, -8522.188, -8458.034, -8393.313, -8328.024, -8262.164, -8195.733, -8128.727, -8061.146, -7992.986999999999, -7924.2480000000005, -7854.927, -7785.023, -7714.533, -7643.455, -7571.7880000000005, -7499.528, -7426.675, -7353.226, -7279.178000000001, -7204.53, -7129.279, -7053.424, -6976.9619999999995, -6899.891, -6822.209, -6743.914000000001, -6665.004, -6585.475, -6505.326999999999, -6424.556, -6343.161999999999, -6261.141, -6178.491, -6095.210999999999, -6011.298000000001, -5926.75, -5841.565, -5755.741, -5669.275, -5582.166, -5494.411999999999, -5406.0109999999995, -5316.960999999999, -5227.26, -5136.907, -5045.899, -4954.236, -4861.915, -4768.936, -4675.295999999999, -4580.996, -4486.032999999999, -4390.407, -4294.1179999999995, -4197.164000000001, -4099.545, -4001.261, -3902.3109999999997, -3802.697, -3702.4190000000003, -3601.4790000000003, -3499.8759999999997, -3397.612, -3294.69, -3191.112, -3086.88, -2981.9970000000003, -2876.468, -2770.298, -2663.491, -2556.053, -2447.99, -2339.31, -2230.021, -2120.133, -2009.655, -1898.599, -1786.9779999999998, -1674.808, -1562.102, -1448.879, -1335.1589999999999, -1220.962, -1106.312, -991.2360000000001, -875.762, -759.922, -643.751, -527.2869999999999, -410.57199999999995, -293.655, -176.585, -59.419, 57.78, 174.94299999999998, 291.996, 408.856, 525.431, 641.621, 757.316, 872.3939999999999, 986.722, 1100.153, 1212.526, 1323.664, 1433.374, 1541.443, 1647.639, 1751.7079999999999, 1853.375, 1952.3370000000002, 2048.272, 2140.826, 2229.624, 2314.26, 2394.3070000000002, 2469.313, 2538.806, 2602.298, 2659.2909999999997, 2709.2859999999996, 2751.788, 2786.322, 2812.442, 2829.743, 2837.881, 2836.574, 2825.625, 2804.928, 2774.467, 2734.3320000000003, 2684.704, 2625.8579999999997, 2558.154, 2482.02, 2397.94, 2306.446, 2208.094, 2103.458, 1993.111, 1877.622, 1757.5410000000002, 1633.394, 1505.68, 1374.8670000000002, 1241.39, 1105.649, 968.012, 828.814, 688.3589999999999, 546.923, 404.75300000000004, 262.07099999999997, 119.07700000000001, -24.052, -167.158, -310.098, -452.74800000000005, -594.997, -736.747, -877.91, -1018.4119999999999, -1158.185, -1297.171, -1435.317, -1572.58, -1708.92, -1844.3029999999999, -1978.7020000000002, -2112.091, -2244.449, -2375.759, -2506.006, -2635.177, -2763.265, -2890.26, -3016.157, -3140.953, -3264.6440000000002, -3387.228, -3508.708, -3629.0820000000003, -3748.3540000000003, -3866.525, -3983.599, -4099.58, -4214.473, -4328.282, -4441.013, -4552.6720000000005, -4663.265, -4772.798, -4881.278, -4988.712, -5095.107, -5200.469, -5304.806, -5408.1269999999995, -5510.436, -5611.743, -5712.055, -5811.378000000001, -5909.722, -6007.092, -6103.496999999999, -6198.945, -6293.441, -6386.994000000001, -6479.611, -6571.3, -6662.066999999999, -6751.92, -6840.865, -6928.91, -7016.062, -7102.326999999999, -7187.7119999999995, -7272.224, -7355.87, -7438.656, -7520.588000000001, -7601.673000000001, -7681.9169999999995, -7761.326, -7839.906999999999, -7917.666, -7994.607, -8070.738, -8146.063, -8220.589, -8294.322, -8367.266, -8439.428, -8510.812, -8581.423, -8651.268, -8720.351, -8788.677, -8856.252, -8923.079, -8989.165, -9054.513, -9119.127, -9183.014000000001, -9246.177, -9308.622, -9370.351, -9431.371, -9491.684000000001, -9551.295, -9610.208, -9668.426, -9725.956, -9782.799, -9838.961, -9894.444, -9949.253, -10003.392, -10056.863000000001, -10109.67, -10161.817, -10213.308, -10264.146, -10314.334, -10363.875, -10412.774, -10461.032, -10508.653999999999, -10555.641000000001, -10601.998, -10647.726999999999, -10692.832, -10737.315, -10781.178, -10824.426000000001, -10867.061000000002, -10909.085, -10950.501, -10991.311000000002, -11031.518999999998, -11071.127, -11110.136999999999, -11148.553, -11186.375, -11223.608, -11260.253, -11296.312, -11331.788, -11366.683, -11400.999, -11434.738000000001, -11467.903999999999, -11500.497, -11532.52, -11563.975, -11594.863000000001, -11625.188, -11654.95, -11684.152, -11712.796, -11740.883, -11768.415, -11795.393999999998, -11821.822, -11847.701000000001, -11873.032, -11897.817, -11922.056999999999, -11945.755, -11968.912, -11991.528999999999, -12013.608, -12035.15, -12056.157, -12076.63, -12096.571000000002, -12115.982, -12134.863000000001, -12153.216, -12171.042, -12188.341999999999, -12205.118999999999, -12221.373, -12237.104, -12252.315, -12267.007, -12281.181, -12294.838, -12307.979, -12320.605, -12332.718, -12344.317, -12355.406, -12365.983, -12376.051000000001, -12385.61, -12394.661, -12403.205, -12411.243999999999, -12418.777, -12425.806, -12432.332, -12438.356000000002, -12443.877, -12448.898000000001, -12453.418, -12457.438999999998, -12460.961000000001, -12463.983999999999, -12466.511, -12468.54, -12470.073999999999, -12471.112, -12471.656, -12471.705, -12471.26, -12470.323, -12468.892, -12466.97, -12464.555, -12461.65, -12458.253, -12454.367, -12449.991000000002, -12445.125, -12439.771, -12433.927, -12427.596000000001, -12420.776000000002, -12413.469, -12405.673999999999, -12397.392, -12388.623, -12379.368, -12369.626, -12359.399, -12348.685, -12337.486, -12325.801000000001, -12313.631000000001, -12300.975, -12287.833999999999, -12274.208, -12260.097, -12245.501, -12230.42, -12214.854, -12198.803, -12182.268, -12165.247, -12147.742, -12129.751, -12111.276000000002, -12092.315, -12072.868999999999, -12052.938, -12032.521, -12011.618, -11990.229, -11968.355, -11945.993999999999, -11923.146999999999, -11899.813, -11875.993, -11851.685, -11826.889, -11801.606000000002, -11775.833999999999, -11749.573999999999, -11722.823999999999, -11695.586000000001, -11667.858, -11639.64, -11610.931999999999, -11581.732, -11552.042, -11521.858999999999, -11491.184, -11460.016000000001, -11428.355, -11396.2, -11363.55, -11330.406, -11296.765, -11262.628, -11227.993, -11192.862, -11157.232, -11121.103000000001, -11084.475, -11047.346000000001, -11009.716, -10971.583, -10932.948, -10893.81, -10854.167, -10814.018, -10773.364, -10732.202, -10690.533000000001, -10648.355, -10605.667, -10562.469, -10518.758999999998, -10474.536, -10429.799, -10384.548, -10338.78, -10292.496, -10245.693000000001, -10198.372, -10150.530999999999, -10102.168, -10053.282, -10003.872, -9953.938, -9903.476999999999, -9852.489, -9800.971, -9748.923, -9696.344000000001, -9643.232, -9589.586, -9535.404, -9480.685, -9425.428, -9369.63, -9313.291, -9256.409, -9198.983, -9141.01, -9082.49, -9023.42, -8963.8, -8903.628, -8842.901, -8781.618, -8719.778, -8657.379, -8594.418, -8530.895, -8466.806, -8402.152, -8336.929, -8271.136, -8204.771999999999, -8137.8330000000005, -8070.319, -8002.227, -7933.555, -7864.3009999999995, -7794.463000000001, -7724.04, -7653.029, -7581.428000000001, -7509.236, -7436.4490000000005, -7363.066999999999, -7289.085999999999, -7214.505, -7139.321999999999, -7063.533, -6987.138000000001, -6910.134, -6832.519, -6754.291, -6675.446999999999, -6595.985, -6515.904, -6435.201, -6353.8730000000005, -6271.918000000001, -6189.335, -6106.121, -6022.275, -5937.793000000001, -5852.675, -5766.9169999999995, -5680.518, -5593.475, -5505.786999999999, -5417.451, -5328.467, -5238.832, -5148.544, -5057.602, -4966.004, -4873.749, -4780.834, -4687.259, -4593.023, -4498.124, -4402.562, -4306.335, -4209.444, -4111.888, -4013.6659999999997, -3914.7790000000005, -3815.2270000000003, -3715.01, -3614.1290000000004, -3512.585, -3410.38, -3307.5170000000003, -3203.9959999999996, -3099.821, -2994.995, -2889.5209999999997, -2783.405, -2676.651, -2569.263, -2461.251, -2352.62, -2243.3779999999997, -2133.536, -2023.102, -1912.089, -1800.509, -1688.376, -1575.7060000000001, -1462.516, -1348.826, -1234.656, -1120.03, -1004.9739999999999, -889.5169999999999, -773.689, -657.525, -541.064, -424.347, -307.421, -190.33599999999998, -73.148, 44.08, 161.282, 278.382, 395.29900000000004, 511.94199999999995, 628.212, 744.0, 859.184, 973.635, 1087.204, 1199.734, 1311.0510000000002, 1420.96, 1529.253, 1635.6979999999999, 1740.045, 1842.02, 1941.325, 2037.6370000000002, 2130.6079999999997, 2219.862, 2305.001, 2385.595, 2461.197, 2531.337, 2595.527, 2653.272, 2704.07, 2747.426, 2782.863, 2809.9320000000002, 2828.2209999999995, 2837.38, 2837.12, 2827.237, 2807.611, 2778.22, 2739.14, 2690.545, 2632.7009999999996, 2565.9570000000003, 2490.736, 2407.5170000000003, 2316.827, 2219.221, 2115.269, 2005.5479999999998, 1890.625, 1771.0520000000001, 1647.359, 1520.049, 1389.59, 1256.423, 1120.95, 983.543, 844.54, 704.2489999999999, 562.948, 420.88699999999994, 278.29, 135.359, -7.725, -150.803, -293.731, -436.38300000000004, -578.646, -720.421, -861.62, -1002.166, -1141.991, -1281.035, -1419.246, -1556.579, -1692.995, -1828.4579999999999, -1962.941, -2096.4179999999997, -2228.866, -2360.269, -2490.611, -2619.881, -2748.0679999999998, -2875.164, -3001.163, -3126.062, -3249.8579999999997, -3372.548, -3494.134, -3614.615, -3733.993, -3852.272, -3969.454, -4085.5440000000003, -4200.545, -4314.462, -4427.3009999999995, -4539.068, -4649.77, -4759.411, -4867.999, -4975.54, -5082.042, -5187.512, -5291.956999999999, -5395.384, -5497.8, -5599.2119999999995, -5699.629, -5799.058000000001, -5897.507, -5994.982, -6091.491, -6187.041, -6281.641, -6375.297, -6468.017, -6559.808000000001, -6650.6759999999995, -6740.63, -6829.6759999999995, -6917.821, -7005.073, -7091.438, -7176.922, -7261.533, -7345.276999999999, -7428.161, -7510.19, -7591.371999999999, -7671.713000000001, -7751.218000000001, -7829.895, -7907.749, -7984.785, -8061.01, -8136.43, -8211.05, -8284.876, -8357.913, -8430.168, -8501.644, -8572.348, -8642.284, -8711.458, -8779.875, -8847.54, -8914.458, -8980.633, -9046.071, -9110.775, -9174.75, -9238.002, -9300.535, -9362.353000000001, -9423.459, -9483.86, -9543.558, -9602.558, -9660.863000000001, -9718.478000000001, -9775.408000000001, -9831.655, -9887.223, -9942.117, -9996.34, -10049.896, -10102.787, -10155.018, -10206.593, -10257.514000000001, -10307.785, -10357.41, -10406.391, -10454.731, -10502.435, -10549.505, -10595.943000000001, -10641.753, -10686.938999999998, -10731.503, -10775.448, -10818.776000000002, -10861.491000000002, -10903.595, -10945.091, -10985.981000000002, -11026.268, -11065.956, -11105.045, -11143.538999999999, -11181.441, -11218.752, -11255.475, -11291.612, -11327.166000000001, -11362.139, -11396.533000000001, -11430.348999999998, -11463.591999999999, -11496.261999999999, -11528.362, -11559.893999999998, -11590.858999999999, -11621.26, -11651.098, -11680.376, -11709.096000000001, -11737.258999999998, -11764.866000000002, -11791.921, -11818.423999999999, -11844.378, -11869.784, -11894.643999999998, -11918.958999999999, -11942.731000000002, -11965.962, -11988.653999999999, -12010.806999999999, -12032.423, -12053.503, -12074.05, -12094.065, -12113.548999999999, -12132.503999999999, -12150.93, -12168.829, -12186.203000000001, -12203.052, -12219.378, -12235.183, -12250.466, -12265.23, -12279.476, -12293.205, -12306.419, -12319.117, -12331.301000000001, -12342.973, -12354.132, -12364.781, -12374.921, -12384.551000000001, -12393.673, -12402.288, -12410.398000000001, -12418.002, -12425.101999999999, -12431.698999999999, -12437.793, -12443.385, -12448.476, -12453.067, -12457.158000000001, -12460.75, -12463.844, -12466.44, -12468.54, -12470.143, -12471.252, -12471.865, -12471.983, -12471.608, -12470.74, -12469.378999999999, -12467.526000000002, -12465.181, -12462.344, -12459.017, -12455.2, -12450.893, -12446.096000000001, -12440.81, -12435.036, -12428.773000000001, -12422.021999999999, -12414.783000000001, -12407.056999999999, -12398.844, -12390.143999999998, -12380.957, -12371.284, -12361.124, -12350.478000000001, -12339.347, -12327.731000000002, -12315.628, -12303.041000000001, -12289.968, -12276.41, -12262.367, -12247.838, -12232.825, -12217.327, -12201.344, -12184.876, -12167.923, -12150.485, -12132.562, -12114.153999999999, -12095.261, -12075.882, -12056.018, -12035.669, -12014.833999999999, -11993.511999999999, -11971.705, -11949.412, -11926.632, -11903.365, -11879.61, -11855.368999999999, -11830.641000000001, -11805.425, -11779.72, -11753.527, -11726.845, -11699.673, -11672.013, -11643.861, -11615.22, -11586.087, -11556.464, -11526.348, -11495.739, -11464.638, -11433.043, -11400.955, -11368.372, -11335.294, -11301.72, -11267.65, -11233.083, -11198.018, -11162.455, -11126.393, -11089.831, -11052.768, -11015.204, -10977.138, -10938.57, -10899.498, -10859.921999999999, -10819.84, -10779.252, -10738.158000000001, -10696.555, -10654.444, -10611.823, -10568.691, -10525.046999999999, -10480.89, -10436.22, -10391.035, -10345.335, -10299.117, -10252.382, -10205.127, -10157.351999999999, -10109.056, -10060.237, -10010.894, -9961.026, -9910.632, -9859.71, -9808.259, -9756.278, -9703.766, -9650.72, -9597.141, -9543.026, -9488.374, -9433.184000000001, -9377.453000000001, -9321.181, -9264.366, -9207.007, -9149.101, -9090.646999999999, -9031.645, -8972.091999999999, -8911.985999999999, -8851.326, -8790.110999999999, -8728.338, -8666.006, -8603.112, -8539.655999999999, -8475.635, -8411.046999999999, -8345.892, -8280.166, -8213.869, -8146.9980000000005, -8079.5509999999995, -8011.526, -7942.920999999999, -7873.735, -7803.965, -7733.609, -7662.666, -7591.132, -7519.007, -7446.2880000000005, -7372.973000000001, -7299.059, -7224.545999999999, -7149.43, -7073.709, -6997.382, -6920.445, -6842.898, -6764.736999999999, -6685.96, -6606.566, -6526.552, -6445.916, -6364.655, -6282.769, -6200.253000000001, -6117.107, -6033.326999999999, -5948.911999999999, -5863.86, -5778.169, -5691.8369999999995, -5604.861, -5517.24, -5428.971, -5340.054, -5250.485, -5160.263, -5069.387, -4977.855, -4885.664000000001, -4792.815, -4699.306, -4605.134, -4510.3, -4414.803, -4318.64, -4221.813, -4124.32, -4026.1609999999996, -3927.336, -3827.845, -3727.69, -3626.87, -3525.387, -3423.242, -3320.438, -3216.975, -3112.857, -3008.087, -2902.6690000000003, -2796.6079999999997, -2689.907, -2582.573, -2474.611, -2366.03, -2256.837, -2147.041, -2036.652, -1925.682, -1814.1429999999998, -1702.0479999999998, -1589.414, -1476.2579999999998, -1362.599, -1248.4569999999999, -1133.856, -1018.821, -903.3810000000001, -787.566, -671.4110000000001, -554.953, -438.23400000000004, -321.3, -204.201, -86.992, 30.266, 147.505, 264.651, 381.624, 498.335, 614.683, 730.563, 845.8530000000001, 960.425, 1074.133, 1186.82, 1298.312, 1408.42, 1516.935, 1623.629, 1728.2520000000002, 1830.535, 1930.18, 2026.869, 2120.255, 2209.966, 2295.603, 2376.744, 2452.942, 2523.7270000000003, 2588.615, 2647.11, 2698.711, 2742.923, 2779.264, 2807.281, 2826.5609999999997, 2836.745, 2837.5359999999996, 2828.722, 2810.1740000000004, 2781.8590000000004, 2743.843, 2696.289, 2639.455, 2573.681, 2499.382, 2417.034, 2327.157, 2230.305, 2127.047, 2017.96, 1903.611, 1784.555, 1661.3239999999998, 1534.4229999999998, 1404.325, 1271.472, 1136.272, 999.1, 860.296, 720.171, 579.008, 437.05699999999996, 294.547, 151.68200000000002, 8.644, -134.405, -277.32, -419.973, -562.438, -704.049, -845.283, -985.872, -1125.748, -1264.851, -1403.128, -1540.5320000000002, -1677.023, -1812.567, -1947.134, -2080.698, -2213.237, -2344.734, -2475.172, -2604.54, -2732.827, -2860.025, -2986.127, -3111.13, -3235.03, -3357.827, -3479.5190000000002, -3600.1079999999997, -3719.594, -3837.98, -3955.2709999999997, -4071.469, -4186.579000000001, -4300.605, -4413.554, -4525.429, -4636.2390000000005, -4745.9890000000005, -4854.686, -4962.335999999999, -5068.946, -5174.523, -5279.075, -5382.608, -5485.130999999999, -5586.651, -5687.174, -5786.7080000000005, -5885.262, -5982.842, -6079.455, -6175.11, -6269.814, -6363.573, -6456.396, -6548.2880000000005, -6639.259, -6729.315, -6818.4619999999995, -6906.7080000000005, -6994.06, -7080.525, -7166.109, -7250.818, -7334.661, -7417.642, -7499.77, -7581.049, -7661.486999999999, -7741.089, -7819.861, -7897.81, -7974.941999999999, -8051.263000000001, -8126.776999999999, -8201.492, -8275.411, -8348.542, -8420.889000000001, -8492.458, -8563.254, -8633.282, -8702.548, -8771.056, -8838.812, -8905.82, -8972.086, -9037.613000000001, -9102.407, -9166.471, -9229.812, -9292.433, -9354.339, -9415.534, -9476.021, -9535.806999999999, -9594.893, -9653.285, -9710.987, -9768.002, -9824.335, -9879.989, -9934.969000000001, -9989.276, -10042.917, -10095.893, -10148.208, -10199.867, -10250.871, -10301.225, -10350.933, -10399.997, -10448.42, -10496.206, -10543.358, -10589.878, -10635.771, -10681.038, -10725.683, -10769.708, -10813.117, -10855.912, -10898.097, -10939.673, -10980.643, -11021.01, -11060.777, -11099.946000000002, -11138.518999999998, -11176.499, -11213.889, -11250.69, -11286.906, -11322.538, -11357.589, -11392.06, -11425.955, -11459.275, -11492.023000000001, -11524.198999999999, -11555.808, -11586.848999999998, -11617.326000000001, -11647.241000000002, -11676.595, -11705.391000000001, -11733.628999999999, -11761.313, -11788.443000000001, -11815.021999999999, -11841.052, -11866.533000000001, -11891.468, -11915.858, -11939.704, -11963.01, -11985.775, -12008.002, -12029.693000000001, -12050.848, -12071.469, -12091.558, -12111.115, -12130.143, -12148.642, -12166.615, -12184.061000000002, -12200.983, -12217.382, -12233.26, -12248.616000000002, -12263.453000000001, -12277.771999999999, -12291.573, -12304.858, -12317.628999999999, -12329.885, -12341.628, -12352.86, -12363.58, -12373.791000000001, -12383.492, -12392.686000000002, -12401.373, -12409.553999999998, -12417.229, -12424.4, -12431.068000000001, -12437.233, -12442.895, -12448.056999999999, -12452.718, -12456.88, -12460.542, -12463.706, -12466.373, -12468.542, -12470.216, -12471.393999999998, -12472.077, -12472.266000000001, -12471.96, -12471.162, -12469.87, -12468.086000000001, -12465.811000000002, -12463.044, -12459.786, -12456.037, -12451.8, -12447.072, -12441.855, -12436.15, -12429.956, -12423.274, -12416.104, -12408.446000000002, -12400.302, -12391.67, -12382.552, -12372.947, -12362.856000000002, -12352.278, -12341.215, -12329.667, -12317.633, -12305.113000000001, -12292.108999999999, -12278.618, -12264.643, -12250.183, -12235.238000000001, -12219.808, -12203.893, -12187.492, -12170.607, -12153.237, -12135.381000000001, -12117.041000000001, -12098.215, -12078.903999999999, -12059.108, -12038.826000000001, -12018.058, -11996.803999999998, -11975.063999999998, -11952.838, -11930.125, -11906.925, -11883.239, -11859.065, -11834.403, -11809.253999999999, -11783.617, -11757.49, -11730.876, -11703.771, -11676.177, -11648.093, -11619.518999999998, -11590.453000000001, -11560.896, -11530.847, -11500.306, -11469.271, -11437.743999999999, -11405.722, -11373.206, -11340.195, -11306.688, -11272.684, -11238.184, -11203.186000000002, -11167.688999999998, -11131.694, -11095.198999999999, -11058.203000000001, -11020.706, -10982.707, -10944.205, -10905.2, -10865.69, -10825.675, -10785.153999999999, -10744.126, -10702.591999999999, -10660.546999999999, -10617.993, -10574.927, -10531.351, -10487.261, -10442.658000000001, -10397.54, -10351.905999999999, -10305.755, -10259.086, -10211.898000000001, -10164.189, -10115.96, -10067.208, -10017.931999999999, -9968.131, -9917.803, -9866.949, -9815.565, -9763.651, -9711.206, -9658.226999999999, -9604.715, -9550.667, -9496.082, -9440.958, -9385.294, -9329.089, -9272.341, -9215.049, -9157.21, -9098.824, -9039.889000000001, -8980.403, -8920.365, -8859.771999999999, -8798.624, -8736.918, -8674.653, -8611.827, -8548.438, -8484.484, -8419.964, -8354.876, -8289.218, -8222.988000000001, -8156.184, -8088.804, -8020.847, -7952.31, -7883.191, -7813.488, -7743.2, -7672.325, -7600.859, -7528.8009999999995, -7456.149, -7382.901, -7309.056, -7234.61, -7159.561, -7083.908, -7007.649, -6930.78, -6853.3, -6775.206999999999, -6696.4980000000005, -6617.170999999999, -6537.225, -6456.656, -6375.463000000001, -6293.643, -6211.195, -6128.116, -6044.404, -5960.057, -5875.071999999999, -5789.448, -5703.183000000001, -5616.274, -5528.72, -5440.518, -5351.666, -5262.164000000001, -5172.008, -5081.198, -4989.732, -4897.608, -4804.8240000000005, -4711.38, -4617.274, -4522.504, -4427.071, -4330.973, -4234.21, -4136.78, -4038.684, -3939.922, -3840.493, -3740.3990000000003, -3639.6409999999996, -3538.218, -3436.133, -3333.388, -3229.9840000000004, -3125.9240000000004, -3021.211, -2915.849, -2809.842, -2703.195, -2595.9120000000003, -2488.002, -2379.471, -2270.326, -2160.577, -2050.2329999999997, -1939.306, -1827.808, -1715.753, -1603.156, -1490.0339999999999, -1376.406, -1262.292, -1147.7160000000001, -1032.703, -917.279, -801.477, -685.331, -568.877, -452.156, -335.214, -218.101, -100.87200000000001, 16.414, 133.689, 250.882, 367.91, 484.686, 601.113, 717.082, 832.477, 947.169, 1061.014, 1173.856, 1285.5230000000001, 1395.828, 1504.5629999999999, 1611.5020000000002, 1716.401, 1818.9879999999998, 1918.97, 2016.0320000000002, 2109.83, 2199.992, 2286.126, 2367.8089999999997, 2444.597, 2516.0229999999997, 2581.604, 2640.844, 2693.244, 2738.305, 2775.545, 2804.508, 2824.775, 2835.98, 2837.821, 2830.074, 2812.6020000000003, 2785.363, 2748.4120000000003, 2701.902, 2646.0809999999997, 2581.28, 2507.909, 2426.435, 2337.377, 2241.285, 2138.728, 2030.2779999999998, 1916.509, 1797.975, 1675.2089999999998, 1548.7220000000002, 1418.989, 1286.455, 1151.532, 1014.597, 875.995, 736.04, 595.016, 453.17800000000005, 310.757, 167.96, 24.969, -118.04899999999999, -260.95, -403.602, -545.891, -687.715, -828.982, -969.6139999999999, -1109.5410000000002, -1248.702, -1387.0439999999999, -1524.5179999999998, -1661.085, -1796.7079999999999, -1931.359, -2065.011, -2197.64, -2329.229, -2459.764, -2589.229, -2717.615, -2844.914, -2971.12, -3096.2259999999997, -3220.2309999999998, -3343.133, -3464.9320000000002, -3585.6279999999997, -3705.222, -3823.717, -3941.115, -4057.421, -4172.639, -4286.774, -4399.832, -4511.816, -4622.735, -4732.593, -4841.398, -4949.155, -5055.873, -5161.558, -5266.217, -5369.858, -5472.488, -5574.113, -5674.741999999999, -5774.382, -5873.041, -5970.725, -6067.443, -6163.201999999999, -6258.009, -6351.871999999999, -6444.797, -6536.793000000001, -6627.865, -6718.022, -6807.27, -6895.616, -6983.069, -7069.633000000001, -7155.316, -7240.125, -7324.066, -7407.146, -7489.371, -7570.746999999999, -7651.281, -7730.98, -7809.848000000001, -7887.893, -7965.12, -8041.535, -8117.144, -8191.953, -8265.966, -8339.19, -8411.629, -8483.291, -8554.179, -8624.299, -8693.657, -8762.256, -8830.101999999999, -8897.201, -8963.556, -9029.173, -9094.056, -9158.21, -9221.639000000001, -9284.349, -9346.343, -9407.625, -9468.2, -9528.073, -9587.246, -9645.725, -9703.513, -9760.615, -9817.033000000001, -9872.771999999999, -9927.836, -9982.229, -10035.954, -10089.014000000001, -10141.414, -10193.155999999999, -10244.244, -10294.681999999999, -10344.473, -10393.619, -10442.125, -10489.993, -10537.226, -10583.829, -10629.803, -10675.152, -10719.878, -10763.983999999999, -10807.473999999998, -10850.35, -10892.615, -10934.271, -10975.321000000002, -11015.768, -11055.614, -11094.861, -11133.513, -11171.573, -11209.041000000001, -11245.921, -11282.215, -11317.925, -11353.053999999998, -11387.603000000001, -11421.576000000001, -11454.973, -11487.798, -11520.051000000001, -11551.737, -11582.855, -11613.409, -11643.4, -11672.83, -11701.701000000001, -11730.016000000001, -11757.775, -11784.981000000002, -11811.636, -11837.74, -11863.296999999999, -11888.306, -11912.771, -11936.693000000001, -11960.073, -11982.913, -12005.215, -12026.98, -12048.208, -12068.903, -12089.065, -12108.696000000002, -12127.798, -12146.371000000001, -12164.416000000001, -12181.936000000002, -12198.931999999999, -12215.403999999999, -12231.354, -12246.783000000001, -12261.693000000001, -12276.083999999999, -12289.958, -12303.315, -12316.157, -12328.485, -12340.3, -12351.604, -12362.396, -12372.678, -12382.452, -12391.716999999999, -12400.475, -12408.726999999999, -12416.473999999998, -12423.716, -12430.455, -12436.69, -12442.423999999999, -12447.656, -12452.388, -12456.62, -12460.351999999999, -12463.587, -12466.323999999999, -12468.563999999998, -12470.308, -12471.556, -12472.309, -12472.568000000001, -12472.332, -12471.603000000001, -12470.381000000001, -12468.667, -12466.461000000001, -12463.764, -12460.576000000001, -12456.896999999999, -12452.728000000001, -12448.069, -12442.921999999999, -12437.285, -12431.16, -12424.546999999999, -12417.446000000002, -12409.858, -12401.782, -12393.219, -12384.17, -12374.633999999998, -12364.611, -12354.103000000001, -12343.108, -12331.628, -12319.663, -12307.211000000001, -12294.274, -12280.851999999999, -12266.945, -12252.553, -12237.676000000001, -12222.313999999998, -12206.466999999999, -12190.135, -12173.318000000001, -12156.016000000001, -12138.228000000001, -12119.956, -12101.198, -12081.955, -12062.226, -12042.011999999999, -12021.311000000002, -12000.125, -11978.452, -11956.294, -11933.649, -11910.517, -11886.898000000001, -11862.792, -11838.198, -11813.116000000002, -11787.546, -11761.487, -11734.94, -11707.903, -11680.376, -11652.358999999999, -11623.851999999999, -11594.853000000001, -11565.363000000001, -11535.382, -11504.908000000001, -11473.941, -11442.48, -11410.526000000002, -11378.077, -11345.133, -11311.693000000001, -11277.757, -11243.323999999999, -11208.393, -11172.964, -11137.035, -11100.607, -11063.678999999998, -11026.249, -10988.317, -10949.883, -10910.944, -10871.501, -10831.553999999998, -10791.1, -10750.139, -10708.67, -10666.693000000001, -10624.206, -10581.208, -10537.698, -10493.675, -10449.139000000001, -10404.089, -10358.521999999999, -10312.438, -10265.837, -10218.716, -10171.075, -10122.912, -10074.226999999999, -10025.019, -9975.285, -9925.025, -9874.237, -9822.921, -9771.074, -9718.697, -9665.786, -9612.341, -9558.36, -9503.843, -9448.786, -9393.19, -9337.052, -9280.372, -9223.146999999999, -9165.376, -9107.058, -9048.19, -8988.771999999999, -8928.801, -8868.277, -8807.196, -8745.558, -8683.360999999999, -8620.603000000001, -8557.282, -8493.396, -8428.943000000001, -8363.923, -8298.333, -8232.171, -8165.435, -8098.124, -8030.234, -7961.765, -7892.715, -7823.08, -7752.861, -7682.053000000001, -7610.655, -7538.666, -7466.081999999999, -7392.903, -7319.125, -7244.7480000000005, -7169.768, -7094.183000000001, -7017.991, -6941.191, -6863.779, -6785.754, -6707.1140000000005, -6627.856, -6547.977, -6467.477, -6386.351, -6304.6, -6222.22, -6139.209, -6055.565, -5971.286, -5886.369000000001, -5800.813, -5714.616, -5627.775, -5540.2880000000005, -5452.154, -5363.369000000001, -5273.934, -5183.845, -5093.102, -5001.7029999999995, -4909.645, -4816.928, -4723.55, -4629.51, -4534.806, -4439.438, -4343.405, -4246.706, -4149.340999999999, -4051.309, -3952.61, -3853.245, -3753.2129999999997, -3652.5159999999996, -3551.155, -3449.131, -3346.446, -3243.1009999999997, -3139.099, -3034.4440000000004, -2929.139, -2823.188, -2716.595, -2609.367, -2501.509, -2393.029, -2283.933, -2174.231, -2063.933, -1953.05, -1841.594, -1729.579, -1617.02, -1503.933, -1390.3370000000002, -1276.252, -1161.702, -1046.711, -931.306, -815.5189999999999, -699.382, -582.933, -466.212, -349.264, -232.138, -114.889, 2.425, 119.736, 236.97299999999998, 354.056, 470.897, 587.401, 703.46, 818.959, 933.77, 1047.75, 1160.746, 1272.588, 1383.0870000000002, 1492.0410000000002, 1599.227, 1704.398, 1807.289, 1907.608, 2005.0420000000001, 2099.25, 2189.865, 2276.494, 2358.718, 2436.097, 2508.1639999999998, 2574.437, 2634.4240000000004, 2687.623, 2733.5359999999996, 2771.678, 2801.5890000000004, 2822.847, 2835.078, 2837.974, 2831.302, 2814.915, 2788.761, 2752.884, 2707.428, 2652.63, 2588.815, 2516.382, 2435.795, 2347.5679999999998, 2252.2470000000003, 2150.399, 2042.599, 1929.4189999999999, 1811.414, 1689.124, 1563.057, 1433.695, 1301.487, 1166.844, 1030.151, 891.7560000000001, 751.9739999999999, 611.0930000000001, 469.371, 327.04200000000003, 184.313, 41.372, -101.616, -244.50099999999998, -387.153, -529.4540000000001, -671.3, -812.602, -953.2769999999999, -1093.256, -1232.476, -1370.882, -1508.4270000000001, -1645.069, -1780.773, -1915.5079999999998, -2049.2470000000003, -2181.968, -2313.652, -2444.283, -2573.847, -2702.333, -2829.7340000000004, -2956.042, -3081.2540000000004, -3205.365, -3328.3740000000003, -3450.28, -3571.0840000000003, -3690.7859999999996, -3809.389, -3926.897, -4043.312, -4158.64, -4272.885, -4386.052, -4498.146, -4609.174, -4719.14, -4828.054, -4935.920999999999, -5042.747, -5148.541, -5253.308000000001, -5357.056, -5459.793000000001, -5561.526, -5662.2609999999995, -5762.007, -5860.772, -5958.562, -6055.385, -6151.249, -6246.16, -6340.126, -6433.155, -6525.253000000001, -6616.428000000001, -6706.687, -6796.036999999999, -6884.484, -6972.036999999999, -7058.701999999999, -7144.485, -7229.393, -7313.433000000001, -7396.611, -7478.934, -7560.408, -7641.04, -7720.835999999999, -7799.8009999999995, -7877.941999999999, -7955.264, -8031.775, -8107.478, -8182.380999999999, -8256.488000000001, -8329.805, -8402.339, -8474.093, -8545.074, -8615.287, -8684.735999999999, -8753.427, -8821.364, -8888.554, -8954.999, -9020.706, -9085.678, -9149.921999999999, -9213.440999999999, -9276.239, -9338.321, -9399.692, -9460.355, -9520.315, -9579.575, -9638.141, -9696.016, -9753.203000000001, -9809.707, -9865.533000000001, -9920.681999999999, -9975.16, -10028.97, -10082.115, -10134.599, -10186.425, -10237.597, -10288.119, -10337.992, -10387.222, -10435.81, -10483.761, -10531.077, -10577.761, -10623.817, -10669.248, -10714.055, -10758.243, -10801.813999999998, -10844.77, -10887.115, -10928.851999999999, -10969.982, -11010.508999999998, -11050.435, -11089.761999999999, -11128.493, -11166.631000000001, -11204.178999999998, -11241.136999999999, -11277.51, -11313.298, -11348.505, -11383.132, -11417.181999999999, -11450.657, -11483.559, -11515.891000000001, -11547.653, -11578.848, -11609.478000000001, -11639.546, -11669.053, -11698.001, -11726.391000000001, -11754.226999999999, -11781.508, -11808.238000000001, -11834.418, -11860.05, -11885.135, -11909.675, -11933.671999999999, -11957.127, -11980.041000000001, -12002.417, -12024.256000000001, -12045.559, -12066.328000000001, -12086.563999999998, -12106.268999999998, -12125.445, -12144.091, -12162.21, -12179.803999999998, -12196.872, -12213.417, -12229.441, -12244.943000000001, -12259.925, -12274.389, -12288.335, -12301.765, -12314.678999999998, -12327.079, -12338.966999999999, -12350.341999999999, -12361.207, -12371.561000000002, -12381.406, -12390.743, -12399.573, -12407.896, -12415.714, -12423.027, -12429.837, -12436.143999999998, -12441.948, -12447.252, -12452.053999999998, -12456.357, -12460.16, -12463.465, -12466.273000000001, -12468.583, -12470.396999999999, -12471.716, -12472.538999999999, -12472.867, -12472.702, -12472.043, -12470.891000000001, -12469.247, -12467.111, -12464.483, -12461.364, -12457.755, -12453.655, -12449.066, -12443.988000000001, -12438.421, -12432.365, -12425.821000000002, -12418.788999999999, -12411.27, -12403.263, -12394.768999999998, -12385.788, -12376.321000000002, -12366.367, -12355.927, -12345.002, -12333.59, -12321.693000000001, -12309.31, -12296.441, -12283.088, -12269.249, -12254.926000000001, -12240.117, -12224.823, -12209.044, -12192.78, -12176.031, -12158.796999999999, -12141.077, -12122.873, -12104.183, -12085.008, -12065.347, -12045.2, -12024.568000000001, -12003.45, -11981.845, -11959.753999999999, -11937.176000000001, -11914.112, -11890.561000000002, -11866.521999999999, -11841.996000000001, -11816.981000000002, -11791.479, -11765.488000000001, -11739.008, -11712.038, -11684.579, -11656.63, -11628.19, -11599.258999999998, -11569.837, -11539.923, -11509.516000000001, -11478.616000000002, -11447.223, -11415.336000000001, -11382.954, -11350.077, -11316.705, -11282.836000000001, -11248.47, -11213.606000000002, -11178.243999999999, -11142.383, -11106.023000000001, -11069.161, -11031.798999999999, -10993.934, -10955.567, -10916.696000000002, -10877.32, -10837.44, -10797.053, -10756.16, -10714.758, -10672.848, -10630.428, -10587.497, -10544.055, -10500.1, -10455.631, -10410.648000000001, -10365.148000000001, -10319.132, -10272.598, -10225.545, -10177.971, -10129.876, -10081.258, -10032.117, -9982.45, -9932.258, -9881.538, -9830.289, -9778.51, -9726.2, -9673.356, -9619.979, -9566.065999999999, -9511.616, -9456.628, -9401.099, -9345.03, -9288.417, -9231.259, -9173.556, -9115.306, -9056.506, -8997.155, -8937.253, -8876.796, -8815.783000000001, -8754.213, -8692.084, -8629.393, -8566.14, -8502.323, -8437.939, -8372.987, -8307.465, -8241.371, -8174.703, -8107.459, -8039.638000000001, -7971.238, -7902.255, -7832.689, -7762.5380000000005, -7691.798000000001, -7620.469, -7548.548000000001, -7476.034000000001, -7402.923000000001, -7329.213000000001, -7254.904, -7179.991999999999, -7104.476, -7028.353, -6951.621, -6874.276999999999, -6796.321, -6717.749, -6638.559, -6558.749, -6478.316999999999, -6397.2609999999995, -6315.578, -6233.266, -6150.323, -6066.746999999999, -5982.536, -5897.687, -5812.1990000000005, -5726.069, -5639.295999999999, -5551.8769999999995, -5463.81, -5375.094, -5285.726, -5195.705, -5105.029, -5013.696, -4921.705, -4829.054, -4735.742, -4641.768, -4547.13, -4451.8279999999995, -4355.86, -4259.226, -4161.925, -4063.9570000000003, -3965.322, -3866.0209999999997, -3766.051, -3665.4159999999997, -3564.117, -3462.1540000000005, -3359.528, -3256.243, -3152.3, -3047.703, -2942.455, -2836.559, -2730.022, -2622.847, -2515.042, -2406.612, -2297.5660000000003, -2187.9120000000003, -2077.66, -1966.8220000000001, -1855.408, -1743.433, -1630.912, -1517.86, -1404.297, -1290.242, -1175.718, -1060.749, -945.363, -829.591, -713.4639999999999, -597.02, -480.29900000000004, -363.345, -246.207, -128.939, -11.599, 105.74700000000001, 223.028, 340.164, 457.07, 573.649, 689.797, 805.3989999999999, 920.327, 1034.442, 1147.59, 1259.603, 1370.297, 1479.4679999999998, 1586.896, 1692.338, 1795.529, 1896.182, 1993.985, 2088.6, 2179.6620000000003, 2266.782, 2349.544, 2427.508, 2500.21, 2567.172, 2627.9, 2681.893, 2728.652, 2767.69, 2798.546, 2820.789, 2834.0429999999997, 2837.991, 2832.3920000000003, 2817.0890000000004, 2792.02, 2757.218, 2712.8179999999998, 2659.046, 2596.219, 2524.729, 2445.034, 2357.6420000000003, 2263.096, 2161.9629999999997, 2054.8179999999998, 1942.231, 1824.761, 1702.95, 1577.308, 1448.3220000000001, 1316.444, 1182.087, 1045.639, 907.452, 767.845, 627.11, 485.506, 343.269, 200.611, 57.721000000000004, -85.234, -228.10299999999998, -370.75199999999995, -513.253, -654.934, -796.268, -936.9860000000001, -1077.015, -1216.292, -1354.763, -1492.3770000000002, -1629.095, -1764.879, -1899.6989999999998, -2033.526, -2166.3379999999997, -2298.115, -2428.842, -2558.504, -2687.091, -2814.593, -2941.005, -3066.321, -3190.538, -3313.653, -3435.6659999999997, -3556.577, -3676.388, -3795.1009999999997, -3912.717, -4029.241, -4144.678, -4259.032, -4372.308, -4484.512, -4595.649, -4705.725, -4814.748, -4922.723, -5029.657, -5135.559, -5240.434, -5344.29, -5447.134, -5548.973000000001, -5649.815, -5749.668000000001, -5848.5380000000005, -5946.434, -6043.361, -6139.329000000001, -6234.344, -6328.414000000001, -6421.545, -6513.746, -6605.024, -6695.385, -6784.835999999999, -6873.385, -6961.0380000000005, -7047.802, -7133.685, -7218.691999999999, -7302.831, -7386.108, -7468.529, -7550.101, -7630.83, -7710.722, -7789.783, -7868.02, -7945.438, -8022.043000000001, -8097.840999999999, -8172.838000000001, -8247.039, -8320.45, -8393.077, -8464.924, -8535.997, -8606.302, -8675.841999999999, -8744.625, -8812.653, -8879.933, -8946.468, -9012.265, -9077.328000000001, -9141.66, -9205.268, -9268.155, -9330.325, -9391.783000000001, -9452.534, -9512.581, -9571.929, -9630.582, -9688.543, -9745.817, -9802.407, -9858.317, -9913.552, -9968.114, -10022.009, -10075.238000000001, -10127.806, -10179.716, -10230.972, -10281.577, -10331.534, -10380.847, -10429.518, -10477.551, -10524.948999999999, -10571.716, -10617.853000000001, -10663.364, -10708.253, -10752.521999999999, -10796.173, -10839.21, -10881.636, -10923.452, -10964.663, -11005.268999999998, -11045.274, -11084.681, -11123.492, -11161.708999999999, -11199.335, -11236.372, -11272.823, -11308.69, -11343.973999999998, -11378.678999999998, -11412.806, -11446.358999999999, -11479.338, -11511.746000000001, -11543.586000000001, -11574.858, -11605.565, -11635.708999999999, -11665.292, -11694.316, -11722.783000000001, -11750.694, -11778.052, -11804.857, -11831.112, -11856.818000000001, -11881.978000000001, -11906.593, -11930.665, -11954.194, -11977.183, -11999.633999999998, -12021.546999999999, -12042.923999999999, -12063.767, -12084.078000000001, -12103.856000000002, -12123.105, -12141.825, -12160.018, -12177.684, -12194.826000000001, -12211.444, -12227.54, -12243.114, -12258.169, -12272.705, -12286.723999999998, -12300.226, -12313.213, -12325.685, -12337.645, -12349.091999999999, -12360.028, -12370.454, -12380.371000000001, -12389.778999999999, -12398.681, -12407.075, -12414.964, -12422.348999999998, -12429.23, -12435.607, -12441.482, -12446.856000000002, -12451.729, -12456.101999999999, -12459.976999999999, -12463.351999999999, -12466.23, -12468.611, -12470.495, -12471.883999999998, -12472.777, -12473.175, -12473.08, -12472.491000000002, -12471.409, -12469.833999999999, -12467.767, -12465.208999999999, -12462.16, -12458.62, -12454.591, -12450.071000000002, -12445.061000000002, -12439.563, -12433.576000000001, -12427.101, -12420.138, -12412.688, -12404.75, -12396.325, -12387.413, -12378.014, -12368.13, -12357.758, -12346.901000000002, -12335.558, -12323.73, -12311.415, -12298.616000000002, -12285.331, -12271.56, -12257.305, -12242.563999999998, -12227.338, -12211.627, -12195.431, -12178.75, -12161.583999999999, -12143.933, -12125.796, -12107.173999999999, -12088.067, -12068.473999999998, -12048.395, -12027.831, -12006.78, -11985.243, -11963.22, -11940.711000000001, -11917.714, -11894.23, -11870.258999999998, -11845.8, -11820.854, -11795.418, -11769.493999999999, -11743.082, -11716.18, -11688.788, -11660.906, -11632.534, -11603.67, -11574.315, -11544.469, -11514.128999999999, -11483.296999999999, -11451.972, -11420.152, -11387.838, -11355.028, -11321.723, -11287.921, -11253.623, -11218.826000000001, -11183.531, -11147.737, -11111.443000000001, -11074.649, -11037.354, -10999.556999999999, -10961.257, -10922.454, -10883.146, -10843.332, -10803.013, -10762.187, -10720.853000000001, -10679.01, -10636.657, -10593.794, -10550.419, -10506.531, -10462.13, -10417.213, -10371.780999999999, -10325.832, -10279.365, -10232.379, -10184.873, -10136.845, -10088.295, -10039.222, -9989.623, -9939.498, -9888.845, -9837.664, -9785.953000000001, -9733.71, -9680.934000000001, -9627.624, -9573.779, -9519.396999999999, -9464.476, -9409.015, -9353.011999999999, -9296.466999999999, -9239.378, -9181.743, -9123.56, -9064.828000000001, -9005.546, -8945.711, -8885.322, -8824.377, -8762.875, -8700.814, -8638.192, -8575.007, -8511.258, -8446.942, -8382.058, -8316.604, -8250.578000000001, -8183.979, -8116.803000000001, -8049.05, -7980.718000000001, -7911.804, -7842.306, -7772.223000000001, -7701.552, -7630.2919999999995, -7558.439, -7485.993, -7412.95, -7339.31, -7265.069, -7190.226, -7114.778, -7038.723000000001, -6962.059, -6884.785, -6806.897, -6728.393, -6649.272, -6569.53, -6489.1669999999995, -6408.179, -6326.565, -6244.321, -6161.446999999999, -6077.939, -5993.797, -5909.016, -5823.596, -5737.535, -5650.829000000001, -5563.477, -5475.478, -5386.83, -5297.529, -5207.576, -5116.967000000001, -5025.701, -4933.777, -4841.193, -4747.948, -4654.04, -4559.468, -4464.231, -4368.3279999999995, -4271.759, -4174.522, -4076.619, -3978.048, -3878.809, -3778.903, -3678.3309999999997, -3577.093, -3475.191, -3372.6259999999997, -3269.401, -3165.5170000000003, -3060.978, -2955.7870000000003, -2849.948, -2743.465, -2636.344, -2528.59, -2420.212, -2311.216, -2201.611, -2091.406, -1980.612, -1869.241, -1757.307, -1644.8229999999999, -1531.807, -1418.277, -1304.252, -1189.754, -1074.809, -959.443, -843.686, -727.57, -611.131, -494.411, -377.45099999999996, -260.302, -143.015, -25.649, 91.73100000000001, 209.054, 326.243, 443.211, 559.865, 676.1, 791.803, 906.847, 1021.0939999999999, 1134.392, 1246.576, 1357.461, 1466.8470000000002, 1574.514, 1680.224, 1783.714, 1884.6970000000001, 1982.865, 2077.883, 2169.389, 2256.996, 2340.291, 2418.835, 2492.169, 2559.814, 2621.278, 2676.06, 2723.66, 2763.592, 2795.387, 2818.613, 2832.887, 2837.885, 2833.3579999999997, 2819.138, 2795.155, 2761.4309999999996, 2718.0890000000004, 2665.348, 2603.514, 2532.973, 2454.174, 2367.623, 2273.86, 2173.449, 2066.9629999999997, 1954.977, 1838.0479999999998, 1716.7220000000002, 1591.5120000000002, 1462.904, 1331.3570000000002, 1197.29, 1061.0910000000001, 923.1160000000001, 783.688, 643.1, 501.616, 359.475, 216.89, 74.05199999999999, -68.868, -211.71900000000002, -354.366, -496.68699999999995, -638.578, -779.945, -920.704, -1060.7830000000001, -1200.118, -1338.652, -1476.336, -1613.129, -1748.993, -1883.896, -2017.81, -2150.7129999999997, -2282.584, -2413.406, -2543.167, -2671.8540000000003, -2799.4570000000003, -2925.972, -3051.393, -3175.715, -3298.937, -3421.0570000000002, -3542.0759999999996, -3661.995, -3780.816, -3898.5409999999997, -4015.1740000000004, -4130.721, -4245.184, -4358.569, -4470.8820000000005, -4582.128, -4692.314, -4801.446, -4909.529, -5016.572, -5122.581, -5227.564, -5331.528, -5434.479, -5536.425, -5637.374, -5737.3330000000005, -5836.309, -5934.309, -6031.342, -6127.414000000001, -6222.533, -6316.706, -6409.941, -6502.245, -6593.625, -6684.0869999999995, -6773.64, -6862.29, -6950.044, -7036.908, -7122.89, -7207.996999999999, -7292.235, -7375.61, -7458.129, -7539.798000000001, -7620.624, -7700.613, -7779.771, -7858.103, -7935.616999999999, -8012.315, -8088.2080000000005, -8163.299, -8237.594000000001, -8311.099, -8383.819, -8455.758, -8526.924, -8597.32, -8666.953000000001, -8735.826, -8803.945, -8871.315, -8937.942, -9003.828000000001, -9068.981, -9133.403, -9197.099, -9260.074, -9322.333, -9383.879, -9444.718, -9504.851999999999, -9564.287, -9623.026, -9681.074, -9738.434000000001, -9795.11, -9851.106, -9906.427, -9961.074, -10015.053, -10068.367, -10121.019, -10173.013, -10224.351999999999, -10275.04, -10325.08, -10374.476, -10423.23, -10471.346, -10518.826000000001, -10565.673999999999, -10611.893999999998, -10657.487, -10702.457, -10746.806999999999, -10790.538999999999, -10833.657, -10876.163, -10918.059, -10959.35, -11000.036, -11040.121000000001, -11079.607, -11118.497, -11156.793, -11194.497, -11231.613000000001, -11268.142, -11304.087, -11339.45, -11374.233, -11408.438, -11442.068000000001, -11475.124, -11507.61, -11539.526000000002, -11570.875, -11601.659, -11631.88, -11661.538999999999, -11690.639, -11719.181999999999, -11747.169, -11774.601999999999, -11801.483, -11827.813999999998, -11853.596000000001, -11878.831, -11903.521, -11927.667, -11951.271, -11974.335, -11996.86, -12018.847, -12040.298, -12061.215, -12081.598999999998, -12101.452, -12120.774, -12139.568000000001, -12157.833999999999, -12175.573, -12192.788, -12209.479, -12225.648000000001, -12241.296, -12256.423999999999, -12271.033000000001, -12285.124, -12298.698, -12311.758, -12324.303, -12336.333999999999, -12347.853000000001, -12358.861, -12369.358999999999, -12379.348, -12388.828000000001, -12397.8, -12406.266000000001, -12414.226, -12421.681999999999, -12428.633, -12435.082, -12441.028, -12446.473, -12451.417, -12455.862, -12459.806, -12463.253, -12466.201000000001, -12468.652, -12470.607, -12472.066, -12473.028999999999, -12473.498, -12473.472, -12472.953000000001, -12471.941, -12470.436000000002, -12468.438999999998, -12465.951000000001, -12462.971000000001, -12459.501, -12455.541000000001, -12451.09, -12446.151000000002, -12440.722, -12434.805, -12428.399, -12421.505, -12414.123, -12406.253999999999, -12397.898000000001, -12389.055, -12379.725, -12369.909, -12359.607, -12348.818000000001, -12337.544, -12325.784, -12313.538, -12300.806999999999, -12287.591, -12273.889, -12259.702, -12245.03, -12229.872, -12214.23, -12198.101999999999, -12181.489, -12164.392, -12146.808, -12128.74, -12110.186000000002, -12091.146999999999, -12071.622, -12051.611, -12031.115, -12010.132, -11988.663, -11966.708, -11944.265, -11921.337, -11897.921, -11874.017, -11849.626, -11824.748, -11799.38, -11773.524, -11747.178999999998, -11720.345, -11693.021, -11665.207, -11636.902, -11608.106000000002, -11578.819, -11549.04, -11518.768, -11488.003999999999, -11456.746000000001, -11424.993, -11392.747, -11360.005, -11326.767, -11293.033000000001, -11258.802, -11224.073, -11188.846000000001, -11153.12, -11116.893999999998, -11080.167, -11042.938999999998, -11005.208999999999, -10966.976999999999, -10928.241000000002, -10889.0, -10849.255, -10809.003, -10768.243999999999, -10726.976999999999, -10685.202, -10642.917, -10600.121000000001, -10556.813999999998, -10512.993999999999, -10468.66, -10423.811, -10378.447, -10332.565999999999, -10286.167, -10239.249, -10191.81, -10143.85, -10095.368, -10046.362, -9996.831, -9946.774, -9896.189, -9845.076, -9793.431999999999, -9741.256, -9688.548, -9635.306999999999, -9581.529, -9527.215, -9472.362, -9416.969000000001, -9361.036, -9304.559000000001, -9247.538, -9189.971, -9131.856, -9073.193000000001, -9013.978000000001, -8954.212, -8893.891, -8833.015, -8771.581, -8709.588, -8647.034, -8583.918, -8520.237, -8455.99, -8391.175, -8325.789, -8259.832, -8193.302, -8126.195, -8058.51, -7990.246, -7921.401, -7851.972, -7781.9580000000005, -7711.356, -7640.164000000001, -7568.38, -7496.003000000001, -7423.029, -7349.4580000000005, -7275.286, -7200.512, -7125.133000000001, -7049.147, -6972.553000000001, -6895.347, -6817.528, -6739.094, -6660.041, -6580.369000000001, -6500.0740000000005, -6419.155, -6337.61, -6255.435, -6172.629, -6089.19, -6005.116, -5920.404, -5835.053000000001, -5749.06, -5662.423000000001, -5575.14, -5487.21, -5398.629, -5309.397, -5219.5109999999995, -5128.97, -5037.772, -4945.915, -4853.399, -4760.22, -4666.379, -4571.873, -4476.7029999999995, -4380.866, -4284.363, -4187.192, -4089.3520000000003, -3990.845, -3891.671, -3791.829, -3691.3190000000004, -3590.1440000000002, -3488.303, -3385.8, -3282.634, -3178.81, -3074.33, -2969.196, -2863.414, -2756.987, -2649.921, -2542.221, -2433.895, -2324.95, -2215.393, -2105.236, -1994.487, -1883.16, -1771.266, -1658.8210000000001, -1545.8410000000001, -1432.344, -1318.35, -1203.88, -1088.9589999999998, -973.613, -857.8710000000001, -741.7669999999999, -625.336, -508.61699999999996, -391.653, -274.493, -157.189, -39.798, 77.615, 194.98, 312.22, 429.251, 545.9780000000001, 662.3, 778.102, 893.2610000000001, 1007.6389999999999, 1121.087, 1233.438, 1344.513, 1454.112, 1562.019, 1667.995, 1771.78, 1873.0929999999998, 1971.624, 2067.0429999999997, 2158.991, 2247.083, 2330.908, 2410.032, 2483.996, 2552.322, 2614.52, 2670.09, 2718.532, 2759.355, 2792.091, 2816.302, 2831.599, 2837.65, 2834.197, 2821.0679999999998, 2798.176, 2765.5370000000003, 2723.262, 2671.559, 2610.728, 2541.143, 2463.2529999999997, 2377.553, 2284.5820000000003, 2184.901, 2079.0860000000002, 1967.707, 1851.329, 1730.494, 1605.721, 1477.5, 1346.2920000000001, 1212.519, 1076.5739999999998, 938.815, 799.57, 659.133, 517.7719999999999, 375.728, 233.217, 90.43299999999999, -52.451, -195.283, -337.925, -480.256, -622.168, -763.566, -904.3660000000001, -1044.495, -1183.886, -1322.485, -1460.239, -1597.108, -1733.0510000000002, -1868.039, -2002.0410000000002, -2135.035, -2266.999, -2397.9179999999997, -2527.778, -2656.565, -2784.2709999999997, -2910.89, -3036.415, -3160.843, -3284.172, -3406.4, -3527.527, -3647.555, -3766.485, -3884.32, -4001.0640000000003, -4116.72, -4231.293, -4344.788, -4457.21, -4568.566, -4678.861, -4788.102, -4896.295, -5003.448, -5109.566, -5214.657, -5318.729, -5421.7880000000005, -5523.840999999999, -5624.897, -5724.9619999999995, -5824.044, -5922.15, -6019.2880000000005, -6115.465, -6210.689, -6304.967, -6398.305, -6490.7119999999995, -6582.194, -6672.759, -6762.414000000001, -6851.165, -6939.02, -7025.986, -7112.068, -7197.274, -7281.611, -7365.085, -7447.701999999999, -7529.469, -7610.393, -7690.478, -7769.733, -7848.161999999999, -7925.771, -8002.566999999999, -8078.555, -8153.741, -8228.131, -8301.729, -8374.542, -8446.575, -8517.834, -8588.322, -8658.046999999999, -8727.011999999999, -8795.222, -8862.683, -8929.4, -8995.377, -9060.619, -9125.13, -9188.916, -9251.98, -9314.327, -9375.962, -9436.888, -9497.11, -9556.632, -9615.458, -9673.593, -9731.039, -9787.801, -9843.884, -9899.289, -9954.021999999999, -10008.086, -10061.485, -10114.221, -10166.299, -10217.722, -10268.494, -10318.618, -10368.096, -10416.933, -10465.132, -10512.694, -10559.625, -10605.926000000001, -10651.601, -10696.653, -10741.083999999999, -10784.896999999999, -10828.096000000001, -10870.681999999999, -10912.659, -10954.028999999999, -10994.796, -11034.96, -11074.526000000002, -11113.495, -11151.87, -11189.653999999999, -11226.848, -11263.456, -11299.479, -11334.92, -11369.781, -11404.063999999998, -11437.771999999999, -11470.906, -11503.469, -11535.462, -11566.888, -11597.749, -11628.046, -11657.782, -11686.958999999999, -11715.577, -11743.64, -11771.149, -11798.106000000002, -11824.513, -11850.37, -11875.681, -11900.446000000002, -11924.667, -11948.346000000001, -11971.483999999999, -11994.083, -12016.145, -12037.671, -12058.662, -12079.12, -12099.046999999999, -12118.443000000001, -12137.31, -12155.65, -12173.463, -12190.751, -12207.516000000001, -12223.758, -12239.479, -12254.678999999998, -12269.361, -12283.525, -12297.171999999999, -12310.303999999998, -12322.921, -12335.025, -12346.616000000002, -12357.696000000002, -12368.266000000001, -12378.326000000001, -12387.878, -12396.921999999999, -12405.46, -12413.492, -12421.018, -12428.041000000001, -12434.561000000002, -12440.579, -12446.095, -12451.11, -12455.625, -12459.641000000001, -12463.158000000001, -12466.177, -12468.698999999999, -12470.723999999998, -12472.253, -12473.287, -12473.826000000001, -12473.87, -12473.421, -12472.479, -12471.044, -12469.117, -12466.698999999999, -12463.788999999999, -12460.389, -12456.498, -12452.118, -12447.248, -12441.888, -12436.04, -12429.704, -12422.88, -12415.567, -12407.767, -12399.48, -12390.706, -12381.446000000002, -12371.698999999999, -12361.465, -12350.746000000001, -12339.541000000001, -12327.848999999998, -12315.673, -12303.01, -12289.862, -12276.229, -12262.111, -12247.507, -12232.419, -12216.845, -12200.786, -12184.241000000002, -12167.212, -12149.697, -12131.697, -12113.211000000001, -12094.24, -12074.784, -12054.841, -12034.413, -12013.499, -11992.098, -11970.211000000001, -11947.837, -11924.976, -11901.628, -11877.793, -11853.47, -11828.659, -11803.36, -11777.572, -11751.295, -11724.528, -11697.271999999999, -11669.526000000002, -11641.288999999999, -11612.561000000002, -11583.341999999999, -11553.631000000001, -11523.427, -11492.73, -11461.54, -11429.855, -11397.676000000001, -11365.002, -11331.833, -11298.166000000001, -11264.003, -11229.341999999999, -11194.183, -11158.524, -11122.366000000002, -11085.708, -11048.546999999999, -11010.885, -10972.72, -10934.052, -10894.88, -10855.202, -10815.018, -10774.327, -10733.128, -10691.421, -10649.204, -10606.476, -10563.236, -10519.483999999999, -10475.218, -10430.438, -10385.141, -10339.328000000001, -10292.997, -10246.146999999999, -10198.777, -10150.885, -10102.471, -10053.533000000001, -10004.07, -9954.081, -9903.564, -9852.519, -9800.944, -9748.837, -9696.198, -9643.024, -9589.314, -9535.068000000001, -9480.284, -9424.96, -9369.094000000001, -9312.686, -9255.733, -9198.235, -9140.189, -9081.594000000001, -9022.448, -8962.75, -8902.499, -8841.690999999999, -8780.326, -8718.402, -8655.917, -8592.87, -8529.258, -8465.079, -8400.333, -8335.017, -8269.13, -8202.667, -8135.63, -8068.015, -7999.82, -7931.044, -7861.684, -7791.7390000000005, -7721.206, -7650.084, -7578.369000000001, -7506.061, -7433.156999999999, -7359.655, -7285.553000000001, -7210.848000000001, -7135.539000000001, -7059.6230000000005, -6983.098000000001, -6905.960999999999, -6828.2119999999995, -6749.847, -6670.8640000000005, -6591.2609999999995, -6511.036, -6430.187, -6348.71, -6266.605, -6183.869000000001, -6100.5, -6016.495, -5931.852, -5846.57, -5760.646, -5674.078, -5586.8640000000005, -5499.0019999999995, -5410.49, -5321.326999999999, -5231.51, -5141.037, -5049.907, -4958.119000000001, -4865.67, -4772.559, -4678.785, -4584.346, -4489.2429999999995, -4393.473, -4297.035, -4199.93, -4102.157, -4003.715, -3904.605, -3804.8259999999996, -3704.381, -3603.268, -3501.49, -3399.048, -3295.9440000000004, -3192.18, -3087.759, -2982.684, -2876.9590000000003, -2770.5890000000004, -2663.578, -2555.933, -2447.659, -2338.765, -2229.258, -2119.149, -2008.4470000000001, -1897.1629999999998, -1785.3120000000001, -1672.9070000000002, -1559.965, -1446.5020000000002, -1332.539, -1218.097, -1103.201, -987.8760000000001, -872.1510000000001, -756.059, -639.636, -522.919, -405.952, -288.782, -171.46200000000002, -54.047, 63.397, 180.803, 298.094, 415.186, 531.985, 648.3919999999999, 764.293, 879.565, 994.072, 1107.6680000000001, 1220.187, 1331.45, 1441.2620000000002, 1549.406, 1655.646, 1759.726, 1861.365, 1960.2579999999998, 2056.077, 2148.465, 2237.04, 2321.394, 2401.095, 2475.687, 2544.6929999999998, 2607.625, 2663.982, 2713.265, 2754.9809999999998, 2788.658, 2813.8540000000003, 2830.176, 2837.283, 2834.9120000000003, 2822.8759999999997, 2801.0820000000003, 2769.535, 2728.335, 2677.6809999999996, 2617.861, 2549.245, 2472.272, 2387.433, 2295.265, 2196.325, 2091.189, 1980.4279999999999, 1864.6070000000002, 1744.2720000000002, 1619.944, 1492.1170000000002, 1361.2520000000002, 1227.779, 1092.0919999999999, 954.554, 815.4939999999999, 675.211, 533.976, 392.033, 249.59900000000002, 106.87100000000001, -35.977, -178.78900000000002, -321.426, -464.342, -605.698, -747.128, -887.9689999999999, -1028.1480000000001, -1167.597, -1306.259, -1444.0839999999998, -1581.0279999999998, -1717.0520000000001, -1852.124, -1986.214, -2119.3, -2251.359, -2382.375, -2512.333, -2641.2209999999995, -2769.031, -2895.7540000000004, -3021.385, -3145.92, -3269.3559999999998, -3391.6929999999998, -3512.929, -3633.066, -3752.1059999999998, -3870.052, -3986.906, -4102.673, -4217.355, -4330.960999999999, -4443.494000000001, -4554.960999999999, -4665.366, -4774.718, -4883.021, -4990.282999999999, -5096.51, -5201.71, -5305.891, -5409.058000000001, -5511.219, -5612.383000000001, -5712.555, -5811.743, -5909.956, -6007.2, -6103.483, -6198.811, -6293.194, -6386.6359999999995, -6479.147, -6570.733, -6661.4, -6751.156999999999, -6840.0109999999995, -6927.967, -7015.033, -7101.215999999999, -7186.522, -7270.9580000000005, -7354.531, -7437.2480000000005, -7519.113, -7600.135, -7680.318, -7759.669, -7838.195, -7915.901, -7992.7919999999995, -8068.876, -8144.156999999999, -8218.641, -8292.333, -8365.24, -8437.367, -8508.718, -8579.299, -8649.116, -8718.171999999999, -8786.474, -8854.027, -8920.834, -8986.902, -9052.234, -9116.835, -9180.71, -9243.864, -9306.3, -9368.023000000001, -9429.037, -9489.347, -9548.956, -9607.87, -9666.091, -9723.624, -9780.473, -9836.641, -9892.132, -9946.951, -10001.1, -10054.583, -10107.404, -10159.565999999999, -10211.074, -10261.929, -10312.136, -10361.698, -10410.618, -10458.899, -10506.545, -10553.558, -10599.941, -10645.698, -10690.831, -10735.343, -10779.238000000001, -10822.517, -10865.184, -10907.242, -10948.692, -10989.538999999999, -11029.783000000001, -11069.428999999998, -11108.476999999999, -11146.931999999999, -11184.794, -11222.067, -11258.753999999999, -11294.855, -11330.375, -11365.313999999998, -11399.675, -11433.46, -11466.671999999999, -11499.312, -11531.382, -11562.885, -11593.823, -11624.197, -11654.01, -11683.263, -11711.958, -11740.097, -11767.681999999999, -11794.714, -11821.196000000002, -11847.128999999999, -11872.515, -11897.355, -11921.652, -11945.405, -11968.618, -11991.292, -12013.428, -12035.028999999999, -12056.094, -12076.626, -12096.627, -12116.097, -12135.038, -12153.451000000001, -12171.338, -12188.698999999999, -12205.537, -12221.851999999999, -12237.646, -12252.919, -12267.673999999999, -12281.91, -12295.63, -12308.833999999999, -12321.524, -12333.7, -12345.363000000001, -12356.515, -12367.157, -12377.288999999999, -12386.913, -12396.035, -12404.643999999998, -12412.746000000001, -12420.343, -12427.437, -12434.027, -12440.115, -12445.701000000001, -12450.786, -12455.371000000001, -12459.457, -12463.044, -12466.132, -12468.723999999998, -12470.819, -12472.417, -12473.52, -12474.128999999999, -12474.243, -12473.863000000001, -12472.99, -12471.624, -12469.766000000001, -12467.417, -12464.576000000001, -12461.243999999999, -12457.423, -12453.111, -12448.309, -12443.018999999998, -12437.239, -12430.971000000001, -12424.215, -12416.971000000001, -12409.24, -12401.021, -12392.315, -12383.123, -12373.444, -12363.278, -12352.627, -12341.489, -12329.866000000002, -12317.757, -12305.163, -12292.083, -12278.517, -12264.466, -12249.931, -12234.909, -12219.403, -12203.411, -12186.934, -12169.972, -12152.525, -12134.591999999999, -12116.173999999999, -12097.27, -12077.881000000001, -12058.006000000001, -12037.645, -12016.798, -11995.464, -11973.643999999998, -11951.338, -11928.544, -11905.263, -11881.495, -11857.239, -11832.495, -11807.263, -11781.542, -11755.332, -11728.633, -11701.444, -11673.764, -11645.594, -11616.933, -11587.781, -11558.136, -11527.999, -11497.368999999999, -11466.245, -11434.627, -11402.515, -11369.908000000001, -11336.805, -11303.205, -11269.108999999999, -11234.515, -11199.421999999999, -11163.831, -11127.739, -11091.146999999999, -11054.053999999998, -11016.458999999999, -10978.362, -10939.76, -10900.655, -10861.044, -10820.927, -10780.303, -10739.171, -10697.53, -10655.38, -10612.719, -10569.546, -10525.861, -10481.662, -10436.948, -10391.719000000001, -10345.973, -10299.709, -10252.926, -10205.622, -10157.798, -10109.451, -10060.58, -10011.184000000001, -9961.261999999999, -9910.813, -9859.834, -9808.326, -9756.286, -9703.714, -9650.608, -9596.966, -9542.788, -9488.071, -9432.814, -9377.016, -9320.675, -9263.79, -9206.359, -9148.381, -9089.854, -9030.776, -8971.145, -8910.961, -8850.221, -8788.924, -8727.068000000001, -8664.651, -8601.671, -8538.127, -8474.017, -8409.339, -8344.091, -8278.271, -8211.878, -8144.908, -8077.361999999999, -8009.235, -7940.528, -7871.236, -7801.36, -7730.895, -7659.840999999999, -7588.194, -7515.955, -7443.119000000001, -7369.686, -7295.651999999999, -7221.016, -7145.775, -7069.927, -6993.471, -6916.403, -6838.723000000001, -6760.4259999999995, -6681.512, -6601.978, -6521.821, -6441.04, -6359.633000000001, -6277.597, -6194.929, -6111.628000000001, -6027.691999999999, -5943.118, -5857.904, -5772.049, -5685.549, -5598.403, -5510.61, -5422.166, -5333.07, -5243.321, -5152.916, -5061.853, -4970.1320000000005, -4877.749, -4784.706, -4690.998, -4596.627, -4501.589, -4405.885, -4309.513, -4212.474, -4114.766, -4016.388, -3917.343, -3817.6279999999997, -3717.2459999999996, -3616.196, -3514.48, -3412.099, -3309.0559999999996, -3205.3520000000003, -3100.99, -2995.973, -2890.3059999999996, -2783.992, -2677.0359999999996, -2569.444, -2461.224, -2352.381, -2242.924, -2132.862, -2022.2060000000001, -1910.967, -1799.158, -1686.793, -1573.888, -1460.46, -1346.529, -1232.117, -1117.246, -1001.943, -886.2360000000001, -770.158, -653.743, -537.029, -420.061, -302.883, -185.547, -68.111, 49.364, 166.808, 284.147, 401.29699999999997, 518.1659999999999, 634.654, 750.65, 866.0319999999999, 980.6669999999999, 1094.405, 1207.086, 1318.533, 1428.55, 1536.925, 1643.4229999999998, 1747.79, 1849.7479999999998, 1948.995, 2045.204, 2138.021, 2227.069, 2311.9410000000003, 2392.2070000000003, 2467.413, 2537.0860000000002, 2600.737, 2657.867, 2707.975, 2750.567, 2785.1690000000003, 2811.335, 2828.665, 2836.813, 2835.508, 2824.552, 2803.845, 2773.3790000000004, 2733.245, 2683.63, 2624.815, 2557.161, 2481.099, 2397.119, 2305.748, 2207.548, 2103.0879999999997, 1992.942, 1877.6770000000001, 1757.84, 1633.9560000000001, 1506.5220000000002, 1376.001, 1242.826, 1107.397, 970.078, 831.203, 691.074, 549.964, 408.12, 265.763, 123.09, -19.721, -162.513, -305.145, -447.494, -589.447, -730.908, -871.791, -1012.0189999999999, -1151.525, -1290.251, -1428.1470000000002, -1565.1660000000002, -1701.27, -1836.4260000000002, -1970.605, -2103.781, -2235.9339999999997, -2367.047, -2497.104, -2626.094, -2754.006, -2880.833, -3006.5690000000004, -3131.21, -3254.7540000000004, -3377.198, -3498.5429999999997, -3618.789, -3737.938, -3855.993, -3972.9570000000003, -4088.833, -4203.627, -4317.343, -4429.985, -4541.561, -4652.076, -4761.536, -4869.9490000000005, -4977.319, -5083.655, -5188.964, -5293.2519999999995, -5396.526, -5498.795, -5600.065, -5700.344, -5799.639, -5897.956999999999, -5995.306, -6091.693, -6187.126, -6281.611999999999, -6375.158, -6467.771, -6559.4580000000005, -6650.227, -6740.085999999999, -6829.04, -6917.097, -7004.263000000001, -7090.545, -7175.951, -7260.486, -7344.156999999999, -7426.971, -7508.934, -7590.052, -7670.331999999999, -7749.779, -7828.4, -7906.201, -7983.188, -8059.365, -8134.74, -8209.318000000001, -8283.103000000001, -8356.103000000001, -8428.322, -8499.764000000001, -8570.437, -8640.345, -8709.492, -8777.885, -8845.528, -8912.425, -8978.582, -9044.003, -9108.693000000001, -9172.655999999999, -9235.896999999999, -9298.421, -9360.231, -9421.333, -9481.729, -9541.425, -9600.425, -9658.731, -9716.35, -9773.284, -9829.537, -9885.113000000001, -9940.015, -9994.248, -10047.815999999999, -10100.72, -10152.966, -10204.556, -10255.494, -10305.783000000001, -10355.427, -10404.429, -10452.792, -10500.518999999998, -10547.613000000001, -10594.077, -10639.913999999999, -10685.128, -10729.72, -10773.695, -10817.053999999998, -10859.801000000001, -10901.938, -10943.466999999999, -10984.392, -11024.716, -11064.44, -11103.567, -11142.098999999998, -11180.04, -11217.391000000001, -11254.155, -11290.333999999999, -11325.931, -11360.947, -11395.383999999998, -11429.246000000001, -11462.534, -11495.251, -11527.396999999999, -11558.976, -11589.989, -11620.438, -11650.326000000001, -11679.653999999999, -11708.423999999999, -11736.638, -11764.298, -11791.405, -11817.962, -11843.969, -11869.428999999998, -11894.343, -11918.714, -11942.541000000001, -11965.828000000001, -11988.576000000001, -12010.786, -12032.458999999999, -12053.598, -12074.203000000001, -12094.276000000002, -12113.819, -12132.832, -12151.318000000001, -12169.277, -12186.711000000001, -12203.621000000001, -12220.008, -12235.873, -12251.219, -12266.045, -12280.353000000001, -12294.143999999998, -12307.419, -12320.18, -12332.427, -12344.162, -12355.385, -12366.097, -12376.3, -12385.993999999999, -12395.18, -12403.86, -12412.034, -12419.702, -12426.867, -12433.528, -12439.687, -12445.344, -12450.5, -12455.155, -12459.311000000002, -12462.969, -12466.128, -12468.79, -12470.955, -12472.623, -12473.796999999999, -12474.475, -12474.659, -12474.348999999998, -12473.546, -12472.25, -12470.462, -12468.181999999999, -12465.41, -12462.148000000001, -12458.396, -12454.153, -12449.421, -12444.2, -12438.49, -12432.291000000001, -12425.604, -12418.428999999998, -12410.767, -12402.617, -12393.98, -12384.857, -12375.246000000001, -12365.149, -12354.566, -12343.498, -12331.943000000001, -12319.902, -12307.376, -12294.365, -12280.868, -12266.886, -12252.418, -12237.465, -12222.027, -12206.104, -12189.695, -12172.801000000001, -12155.421999999999, -12137.556999999999, -12119.207, -12100.372, -12081.05, -12061.243, -12040.95, -12020.171, -11998.905, -11977.153, -11954.915, -11932.188999999998, -11908.976, -11885.276000000002, -11861.088, -11836.412, -11811.247, -11785.594, -11759.452, -11732.82, -11705.698999999999, -11678.087, -11649.985, -11621.391000000001, -11592.306999999999, -11562.73, -11532.66, -11502.098, -11471.041000000001, -11439.492, -11407.447, -11374.907, -11341.872, -11308.34, -11274.311000000002, -11239.785, -11204.76, -11169.236, -11133.212, -11096.688, -11059.663, -11022.135, -10984.105, -10945.572, -10906.534, -10866.99, -10826.941, -10786.385, -10745.321000000002, -10703.748, -10661.665, -10619.072, -10575.966999999999, -10532.35, -10488.219, -10443.573, -10398.411, -10352.733, -10306.537, -10259.822, -10212.586, -10164.83, -10116.551, -10067.748, -10018.42, -9968.565999999999, -9918.185, -9867.274, -9815.834, -9763.863000000001, -9711.359, -9658.321, -9604.748, -9550.636999999999, -9495.989, -9440.8, -9385.071, -9328.798, -9271.982, -9214.619, -9156.71, -9098.253, -9039.243, -8979.681999999999, -8919.565999999999, -8858.895, -8797.667, -8735.879, -8673.530999999999, -8610.62, -8547.145, -8483.104, -8418.495, -8353.315999999999, -8287.565, -8221.24, -8154.34, -8086.863, -8018.806, -7950.1669999999995, -7880.945, -7811.138000000001, -7740.741999999999, -7669.758000000001, -7598.181, -7526.0109999999995, -7453.245, -7379.880999999999, -7305.9169999999995, -7231.35, -7156.179, -7080.401, -7004.014, -6927.016, -6849.405, -6771.178000000001, -6692.3330000000005, -6612.868, -6532.781999999999, -6452.07, -6370.732, -6288.765, -6206.1669999999995, -6122.936, -6039.069, -5954.565, -5869.42, -5783.634, -5697.203, -5610.1269999999995, -5522.401999999999, -5434.026999999999, -5345.001, -5255.319, -5164.983, -5073.988, -4982.335, -4890.021, -4797.045, -4703.406, -4609.101, -4514.130999999999, -4418.494000000001, -4322.189, -4225.215, -4127.573, -4029.261, -3930.28, -3830.63, -3730.3109999999997, -3629.325, -3527.672, -3425.353, -3322.3709999999996, -3218.728, -3114.426, -3009.468, -2903.8590000000004, -2797.6009999999997, -2690.702, -2583.165, -2474.9970000000003, -2366.206, -2256.8, -2146.7870000000003, -2036.1779999999999, -1924.984, -1813.2179999999998, -1700.894, -1588.027, -1474.635, -1360.736, -1246.353, -1131.508, -1016.227, -900.538, -784.4739999999999, -668.068, -551.3580000000001, -434.38800000000003, -317.202, -199.852, -82.39399999999999, 35.111, 152.594, 269.981, 387.189, 504.12800000000004, 620.698, 736.789, 852.2810000000001, 967.041, 1080.924, 1193.768, 1305.399, 1415.6229999999998, 1524.229, 1630.986, 1735.641, 1837.918, 1937.52, 2034.12, 2127.37, 2216.891, 2302.282, 2383.116, 2458.94, 2529.283, 2593.657, 2651.5640000000003, 2702.502, 2745.978, 2781.512, 2808.655, 2827.0029999999997, 2836.204, 2835.975, 2826.113, 2806.506, 2777.134, 2738.08, 2689.5209999999997, 2631.728, 2565.052, 2489.919, 2406.813, 2316.257, 2218.81, 2115.042, 2005.5279999999998, 1890.832, 1771.507, 1648.078, 1521.047, 1390.88, 1258.014, 1122.851, 985.7589999999999, 847.076, 707.107, 566.128, 424.389, 282.112, 139.498, -3.273, -146.042, -288.66700000000003, -431.022, -572.994, -714.485, -855.408, -995.684, -1135.247, -1274.037, -1412.001, -1549.096, -1685.28, -1820.52, -1954.787, -2088.055, -2220.303, -2351.513, -2481.669, -2610.76, -2738.775, -2865.7070000000003, -2991.5490000000004, -3116.297, -3239.948, -3362.5009999999997, -3483.955, -3604.3109999999997, -3723.57, -3841.735, -3958.81, -4074.797, -4189.702, -4303.528, -4416.282, -4527.969, -4638.595, -4748.165, -4856.688, -4964.168, -5070.6140000000005, -5176.031, -5280.428000000001, -5383.811, -5486.188, -5587.566, -5687.951999999999, -5787.354, -5885.778, -5983.233, -6079.726, -6175.264, -6269.855, -6363.505, -6456.222, -6548.014, -6638.8859999999995, -6728.846, -6817.901999999999, -6906.06, -6993.326999999999, -7079.710999999999, -7165.215999999999, -7249.851, -7333.621999999999, -7416.534000000001, -7498.596, -7579.812, -7660.189, -7739.734, -7818.451, -7896.349, -7973.431, -8049.704000000001, -8125.174, -8199.846, -8273.726, -8346.819, -8419.131, -8490.667, -8561.433, -8631.433, -8700.673, -8769.157, -8836.891, -8903.879, -8970.126, -9035.636999999999, -9100.417, -9164.47, -9227.8, -9290.412, -9352.311, -9413.5, -9473.985, -9533.768, -9592.855, -9651.248, -9708.953000000001, -9765.973, -9822.312, -9877.974, -9932.962, -9987.28, -10040.931999999999, -10093.921, -10146.251, -10197.926, -10248.948, -10299.321, -10349.048, -10398.133, -10446.578000000001, -10494.386999999999, -10541.563, -10588.11, -10634.028999999999, -10679.323999999999, -10723.998, -10768.053, -10811.493, -10854.321000000002, -10896.538, -10938.148000000001, -10979.153, -11019.556, -11059.358999999999, -11098.566, -11137.177, -11175.197, -11212.627, -11249.469, -11285.726999999999, -11321.401000000002, -11356.495, -11391.011, -11424.95, -11458.316, -11491.108999999999, -11523.333, -11554.989, -11586.079, -11616.605, -11646.569, -11675.973, -11704.819, -11733.108999999999, -11760.845, -11788.027, -11814.659, -11840.742, -11866.277, -11891.267, -11915.712, -11939.614, -11962.976, -11985.798, -12008.082, -12029.829, -12051.042, -12071.721000000001, -12091.868, -12111.485, -12130.572, -12149.131000000001, -12167.163, -12184.67, -12201.653, -12218.113000000001, -12234.052, -12249.47, -12264.368, -12278.749, -12292.613000000001, -12305.96, -12318.793, -12331.113000000001, -12342.919, -12354.214, -12364.998, -12375.273000000001, -12385.038999999999, -12394.296999999999, -12403.048, -12411.293, -12419.033000000001, -12426.268999999998, -12433.001, -12439.231000000002, -12444.958999999999, -12450.185, -12454.912, -12459.138, -12462.866000000002, -12466.096000000001, -12468.828000000001, -12471.063, -12472.802, -12474.046, -12474.794, -12475.048, -12474.808, -12474.075, -12472.848999999998, -12471.13, -12468.92, -12466.218, -12463.026000000002, -12459.343, -12455.169, -12450.507, -12445.355, -12439.714, -12433.583999999999, -12426.966, -12419.861, -12412.267, -12404.187, -12395.618999999999, -12386.563999999998, -12377.023000000001, -12366.995, -12356.481000000002, -12345.481000000002, -12333.995, -12322.023000000001, -12309.565, -12296.622, -12283.194, -12269.28, -12254.881000000001, -12239.996000000001, -12224.626, -12208.771, -12192.431, -12175.605, -12158.294, -12140.498, -12122.216, -12103.448, -12084.195, -12064.456, -12044.231000000002, -12023.518999999998, -12002.322, -11980.638, -11958.466999999999, -11935.809, -11912.663999999999, -11889.032, -11864.911, -11840.303, -11815.206, -11789.621000000001, -11763.546, -11736.982, -11709.928999999998, -11682.385, -11654.35, -11625.823999999999, -11596.806999999999, -11567.298, -11537.296, -11506.801000000001, -11475.813, -11444.33, -11412.353000000001, -11379.881000000001, -11346.913999999999, -11313.448999999999, -11279.488000000001, -11245.028999999999, -11210.072, -11174.616000000002, -11138.659, -11102.203000000001, -11065.245, -11027.785, -10989.823, -10951.357, -10912.386, -10872.911, -10832.928999999998, -10792.44, -10751.444, -10709.938999999998, -10667.923999999999, -10625.398000000001, -10582.361, -10538.811000000002, -10494.748, -10450.17, -10405.076, -10359.466, -10313.338, -10266.69, -10219.523000000001, -10171.834, -10123.623, -10074.888, -10025.628, -9975.841999999999, -9925.529, -9874.687, -9823.315, -9771.412, -9718.976, -9666.006, -9612.501, -9558.459, -9503.879, -9448.759, -9393.097, -9336.893, -9280.145, -9222.851, -9165.01, -9106.619, -9047.678, -8988.185, -8928.138, -8867.536, -8806.376, -8744.657, -8682.378, -8619.536, -8556.129, -8492.157, -8427.617, -8362.506, -8296.824, -8230.569, -8163.738, -8096.329000000001, -8028.340999999999, -7959.772, -7890.619000000001, -7820.880999999999, -7750.555, -7679.639, -7608.132, -7536.031, -7463.334, -7390.04, -7316.145, -7241.647, -7166.545, -7090.8369999999995, -7014.519, -6937.590999999999, -6860.049, -6781.892, -6703.116999999999, -6623.721, -6543.704000000001, -6463.062, -6381.794, -6299.896, -6217.366999999999, -6134.205, -6050.408, -5965.972, -5880.897, -5795.18, -5708.819, -5621.811, -5534.155, -5445.85, -5356.891, -5267.278, -5177.01, -5086.084, -4994.499, -4902.254, -4809.345, -4715.773, -4621.536, -4526.633, -4431.062, -4334.823, -4237.916, -4140.339, -4042.093, -3943.177, -3843.591, -3743.337, -3642.414, -3540.823, -3438.567, -3335.6459999999997, -3232.0640000000003, -3127.822, -3022.923, -2917.3709999999996, -2811.171, -2704.328, -2596.845, -2488.731, -2379.994, -2270.638, -2160.674, -2050.112, -1938.963, -1827.24, -1714.957, -1602.129, -1488.7720000000002, -1374.9070000000002, -1260.553, -1145.734, -1030.476, -914.806, -798.7560000000001, -682.36, -565.655, -448.68300000000005, -331.49, -214.12599999999998, -96.647, 20.886, 138.406, 255.84, 373.105, 490.11199999999997, 606.762, 722.947, 838.547, 953.431, 1067.455, 1180.4589999999998, 1292.271, 1402.6979999999999, 1511.5320000000002, 1618.5439999999999, 1723.483, 1826.076, 1926.027, 2023.014, 2116.689, 2206.68, 2292.584, 2373.979, 2450.4139999999998, 2521.419, 2586.509, 2645.185, 2696.946, 2741.297, 2777.756, 2805.8709999999996, 2825.2309999999998, 2835.4770000000003, 2836.32, 2827.548, 2809.0370000000003, 2780.76, 2742.785, 2695.283, 2638.511, 2572.817, 2498.616, 2416.387, 2326.651, 2229.9629999999997, 2126.8920000000003, 2018.0120000000002, 1903.892, 1785.082, 1662.114, 1535.489, 1405.68, 1273.126, 1138.232, 1001.3710000000001, 862.883, 723.077, 582.231, 440.598, 298.403, 155.851, 13.120999999999999, -129.624, -272.24, -414.64599999999996, -556.59, -698.11, -839.071, -979.395, -1119.014, -1257.866, -1395.9, -1533.069, -1669.332, -1804.656, -1939.011, -2072.37, -2204.712, -2336.018, -2466.274, -2595.465, -2723.583, -2850.619, -2976.567, -3101.421, -3225.18, -3347.841, -3469.4040000000005, -3589.87, -3709.239, -3827.514, -3944.699, -4060.797, -4175.812, -4289.75, -4402.6140000000005, -4514.411, -4625.147, -4734.8279999999995, -4843.460999999999, -4951.0509999999995, -5057.606, -5163.1320000000005, -5267.638000000001, -5371.13, -5473.6140000000005, -5575.1, -5675.593000000001, -5775.101, -5873.632, -5971.193, -6067.7919999999995, -6163.435, -6258.13, -6351.884, -6444.705, -6536.6, -6627.575, -6717.638000000001, -6806.795999999999, -6895.055, -6982.424, -7068.906999999999, -7154.513000000001, -7239.246999999999, -7323.116999999999, -7406.128000000001, -7488.2880000000005, -7569.602, -7650.076, -7729.718000000001, -7808.531999999999, -7886.525, -7963.703, -8040.071, -8115.6359999999995, -8190.401999999999, -8264.377, -8337.563, -8409.969000000001, -8481.598, -8552.456, -8622.548, -8691.879, -8760.455, -8828.279, -8895.358, -8961.696, -9027.296999999999, -9092.166, -9156.308, -9219.726999999999, -9282.428, -9344.415, -9405.692, -9466.264000000001, -9526.135, -9585.308, -9643.789, -9701.58, -9758.686, -9815.11, -9870.857, -9925.931, -9980.334, -10034.07, -10087.144, -10139.558, -10191.315999999999, -10242.421999999999, -10292.878, -10342.688, -10391.855, -10440.383, -10488.275, -10535.533000000001, -10582.161, -10628.162, -10673.538, -10718.293, -10762.428999999998, -10805.95, -10848.857, -10891.155, -10932.844, -10973.928999999998, -11014.412, -11054.295, -11093.58, -11132.271, -11170.368999999999, -11207.877, -11244.798, -11281.133999999998, -11316.886, -11352.058, -11386.651000000002, -11420.668, -11454.111, -11486.981000000002, -11519.282, -11551.014, -11582.181, -11612.783000000001, -11642.823999999999, -11672.303999999998, -11701.226, -11729.591999999999, -11757.403, -11784.661, -11811.368, -11837.526000000002, -11863.136, -11888.2, -11912.72, -11936.697, -11960.133, -11983.028999999999, -12005.386999999999, -12027.208999999999, -12048.496000000001, -12069.248, -12089.469, -12109.159, -12128.319, -12146.951000000001, -12165.056999999999, -12182.636999999999, -12199.693000000001, -12216.225, -12232.236, -12247.726999999999, -12262.698, -12277.151000000002, -12291.087, -12304.506000000001, -12317.411, -12329.802, -12341.681, -12353.046999999999, -12363.903, -12374.249, -12384.086000000001, -12393.416000000001, -12402.238000000001, -12410.553999999998, -12418.365, -12425.671999999999, -12432.475, -12438.775, -12444.573, -12449.87, -12454.667, -12458.964, -12462.761999999999, -12466.062, -12468.865, -12471.17, -12472.979, -12474.292, -12475.11, -12475.434, -12475.264, -12474.6, -12473.443000000001, -12471.794, -12469.653, -12467.021, -12463.898000000001, -12460.284, -12456.18, -12451.586000000001, -12446.503, -12440.931, -12434.871000000001, -12428.322, -12421.285, -12413.76, -12405.748, -12397.249, -12388.263, -12378.79, -12368.83, -12358.385, -12347.453000000001, -12336.035, -12324.132, -12311.743, -12298.868, -12285.507, -12271.662, -12257.33, -12242.514, -12227.212, -12211.425, -12195.153, -12178.395, -12161.152, -12143.423, -12125.208999999999, -12106.508999999998, -12087.323, -12067.652, -12047.493999999999, -12026.851, -12005.721000000001, -11984.104, -11962.001, -11939.411, -11916.333, -11892.768, -11868.715, -11844.175, -11819.145, -11793.627, -11767.62, -11741.124, -11714.136999999999, -11686.661, -11658.693000000001, -11630.235, -11601.285, -11571.843, -11541.909, -11511.481000000002, -11480.56, -11449.146, -11417.236, -11384.831, -11351.931, -11318.534, -11284.64, -11250.248, -11215.358, -11179.969, -11144.08, -11107.69, -11070.8, -11033.407, -10995.511999999999, -10957.113000000001, -10918.21, -10878.802, -10838.886999999999, -10798.466, -10757.537, -10716.098999999998, -10674.151000000002, -10631.693000000001, -10588.723, -10545.241000000002, -10501.245, -10456.734, -10411.708, -10366.165, -10320.104, -10273.524, -10226.424, -10178.803, -10130.659, -10081.992, -10032.8, -9983.081, -9932.836, -9882.061, -9830.757, -9778.921999999999, -9726.553, -9673.651, -9620.214, -9566.239, -9511.726999999999, -9456.675, -9401.081, -9344.945, -9288.265, -9231.039, -9173.265, -9114.943000000001, -9056.07, -8996.645, -8936.666, -8876.132, -8815.04, -8753.39, -8691.178, -8628.405, -8565.067, -8501.163, -8436.690999999999, -8371.649, -8306.035, -8239.848, -8173.085999999999, -8105.746, -8037.826, -7969.326, -7900.241, -7830.571999999999, -7760.314, -7689.468000000001, -7618.029, -7545.996999999999, -7473.369000000001, -7400.143, -7326.316999999999, -7251.889, -7176.856, -7101.215999999999, -7024.968000000001, -6948.108, -6870.635, -6792.547, -6713.840999999999, -6634.514, -6554.566, -6473.993, -6392.793000000001, -6310.965, -6228.505, -6145.411999999999, -6061.683000000001, -5977.316, -5892.31, -5806.661, -5720.368, -5633.429, -5545.842, -5457.604, -5368.714, -5279.17, -5188.97, -5098.112, -5006.595, -4914.416, -4821.575, -4728.07, -4633.9, -4539.063, -4443.558, -4347.3859999999995, -4250.544, -4153.032, -4054.8509999999997, -3955.9990000000003, -3856.4770000000003, -3756.2859999999996, -3655.426, -3553.8979999999997, -3451.703, -3348.844, -3245.321, -3141.138, -3036.298, -2930.804, -2824.6609999999996, -2717.873, -2610.445, -2502.384, -2393.696, -2284.39, -2174.475, -2063.96, -1952.856, -1841.175, -1728.933, -1616.142, -1502.8210000000001, -1388.989, -1274.665, -1159.872, -1044.637, -928.9860000000001, -812.95, -696.564, -579.864, -462.89099999999996, -345.691, -228.315, -110.815, 6.746, 124.303, 241.782, 359.103, 476.176, 592.905, 709.181, 824.887, 939.893, 1054.056, 1167.218, 1279.2069999999999, 1389.8339999999998, 1498.892, 1606.154, 1711.372, 1814.275, 1914.57, 2011.9370000000001, 2106.031, 2196.482, 2282.8920000000003, 2364.839, 2441.875, 2513.532, 2579.327, 2638.761, 2691.3340000000003, 2736.548, 2773.921, 2802.9959999999996, 2823.3559999999998, 2834.637, 2836.542, 2828.85, 2811.427, 2784.236, 2747.336, 2700.884, 2645.131, 2580.415, 2507.145, 2425.7929999999997, 2336.877, 2240.948, 2138.575, 2030.332, 1916.7879999999998, 1798.496, 1675.991, 1549.776, 1420.3270000000002, 1288.087, 1153.465, 1016.8380000000001, 878.547, 738.9069999999999, 598.196, 456.67199999999997, 314.562, 172.07299999999998, 29.386999999999997, -113.33200000000001, -255.938, -398.30199999999996, -540.308, -681.8560000000001, -822.8539999999999, -963.225, -1102.8980000000001, -1241.8110000000001, -1379.912, -1517.154, -1653.496, -1788.9029999999998, -1923.3429999999998, -2056.792, -2189.2270000000003, -2320.629, -2450.9829999999997, -2580.274, -2708.494, -2835.633, -2961.685, -3086.645, -3210.511, -3333.2790000000005, -3454.95, -3575.5240000000003, -3695.0029999999997, -3813.387, -3930.6820000000002, -4046.89, -4162.015, -4276.062, -4389.036, -4500.943, -4611.788, -4721.579000000001, -4830.32, -4938.019, -5044.683, -5150.318, -5254.931, -5358.53, -5461.121999999999, -5562.714, -5663.314, -5762.929, -5861.565, -5959.232, -6055.935, -6151.682, -6246.481, -6340.339, -6433.263000000001, -6525.26, -6616.3369999999995, -6706.5019999999995, -6795.762, -6884.121999999999, -6971.590999999999, -7058.174, -7143.88, -7228.713000000001, -7312.681, -7395.791, -7478.048000000001, -7559.459, -7640.03, -7719.768, -7798.678000000001, -7876.767, -7954.04, -8030.503000000001, -8106.161999999999, -8181.022, -8255.09, -8328.37, -8400.868, -8472.589, -8543.539, -8613.723, -8683.145, -8751.812, -8819.726999999999, -8886.896, -8953.323, -9019.014000000001, -9083.972, -9148.203000000001, -9211.71, -9274.499, -9336.574, -9397.939, -9458.598, -9518.555, -9577.815, -9636.382, -9694.259, -9751.451, -9807.961, -9863.793, -9918.951, -9973.438, -10027.259, -10080.416, -10132.914, -10184.756, -10235.944, -10286.483, -10336.376, -10385.626, -10434.235999999999, -10482.209, -10529.548999999999, -10576.258999999998, -10622.341, -10667.798, -10712.633, -10756.85, -10800.451000000001, -10843.438999999998, -10885.816, -10927.585, -10968.75, -11009.311000000002, -11049.273000000001, -11088.636999999999, -11127.407, -11165.583, -11203.17, -11240.169, -11276.582, -11312.412, -11347.662, -11382.332, -11416.426000000001, -11449.946000000002, -11482.893, -11515.27, -11547.079, -11578.322, -11609.001, -11639.118, -11668.673999999999, -11697.671999999999, -11726.113000000001, -11754.0, -11781.333, -11808.115, -11834.348, -11860.032, -11885.171, -11909.765, -11933.817, -11957.327, -11980.296999999999, -12002.729, -12024.625, -12045.985, -12066.811000000002, -12087.105, -12106.868, -12126.101999999999, -12144.806999999999, -12162.985, -12180.638, -12197.766000000001, -12214.372, -12230.455, -12246.018, -12261.061000000002, -12275.586000000001, -12289.594, -12303.086000000001, -12316.063, -12328.525, -12340.475, -12351.913, -12362.841, -12373.258, -12383.166000000001, -12392.567, -12401.46, -12409.847, -12417.729, -12425.106000000002, -12431.98, -12438.351, -12444.22, -12449.587, -12454.454, -12458.822, -12462.69, -12466.06, -12468.931999999999, -12471.308, -12473.186000000002, -12474.569, -12475.457, -12475.851, -12475.75, -12475.156, -12474.069, -12472.489, -12470.418, -12467.854, -12464.8, -12461.256000000001, -12457.221000000001, -12452.696000000002, -12447.681999999999, -12442.178999999998, -12436.187, -12429.707, -12422.739, -12415.283000000001, -12407.34, -12398.909, -12389.991000000002, -12380.587, -12370.696000000002, -12360.319, -12349.456, -12338.106000000002, -12326.271, -12313.95, -12301.143, -12287.851, -12274.073999999999, -12259.81, -12245.062, -12229.828000000001, -12214.108999999999, -12197.905, -12181.215, -12164.038999999999, -12146.378999999999, -12128.232, -12109.6, -12090.483, -12070.878999999999, -12050.788999999999, -12030.213, -12009.151000000002, -11987.601999999999, -11965.566, -11943.044, -11920.034, -11896.536, -11872.551000000001, -11848.078000000001, -11823.116000000002, -11797.665, -11771.726, -11745.296999999999, -11718.378, -11690.969, -11663.069, -11634.678, -11605.796, -11576.421999999999, -11546.555, -11516.194, -11485.341, -11453.993999999999, -11422.152, -11389.813999999998, -11356.981000000002, -11323.651000000002, -11289.825, -11255.5, -11220.678, -11185.356000000002, -11149.535, -11113.213, -11076.389, -11039.063999999998, -11001.237, -10962.905, -10924.069, -10884.729, -10844.882, -10804.528, -10763.666000000001, -10722.296, -10680.415, -10638.025, -10595.123, -10551.708, -10507.778999999999, -10463.336, -10418.378, -10372.902, -10326.909, -10280.396999999999, -10233.364, -10185.811, -10137.735, -10089.135, -10040.011, -9990.36, -9940.183, -9889.476, -9838.24, -9786.472, -9734.171999999999, -9681.338, -9627.968, -9574.062, -9519.618, -9464.634, -9409.108, -9353.04, -9296.428, -9239.27, -9181.565, -9123.311, -9064.507, -9005.15, -8945.24, -8884.774, -8823.751, -8762.169, -8700.027, -8637.321, -8574.052, -8510.216999999999, -8445.814, -8380.841, -8315.296, -8249.178, -8182.484, -8115.213000000001, -8047.363, -7978.931, -7909.916, -7840.315, -7770.1269999999995, -7699.35, -7627.981, -7556.018, -7483.459, -7410.303000000001, -7336.545999999999, -7262.187, -7187.223000000001, -7111.653, -7035.474, -6958.684, -6881.28, -6803.2609999999995, -6724.625, -6645.368, -6565.4890000000005, -6484.985, -6403.855, -6322.096, -6239.706, -6156.682, -6073.023, -5988.725, -5903.7880000000005, -5818.209, -5731.985, -5645.115, -5557.597, -5469.428000000001, -5380.607, -5291.132, -5201.001, -5110.212, -5018.762, -4926.652, -4833.879, -4740.442, -4646.339, -4551.569, -4456.1320000000005, -4360.026, -4263.25, -4165.804, -4067.6890000000003, -3968.902, -3869.445, -3769.3179999999998, -3668.522, -3567.0570000000002, -3464.925, -3362.127, -3258.665, -3154.5429999999997, -3049.762, -2944.327, -2838.241, -2731.509, -2624.137, -2516.129, -2407.495, -2298.24, -2188.374, -2077.906, -1966.848, -1855.2120000000002, -1743.011, -1630.26, -1516.975, -1403.1760000000002, -1288.883, -1174.118, -1058.906, -943.275, -827.255, -710.88, -594.186, -477.214, -360.009, -242.62, -125.102, -7.513999999999999, 110.07799999999999, 227.601, 344.976, 462.115, 578.9209999999999, 695.288, 811.0989999999999, 926.2239999999999, 1040.524, 1153.8419999999999, 1266.008, 1376.8329999999999, 1486.114, 1593.625, 1699.121, 1802.3329999999999, 1902.97, 2000.7160000000001, 2095.228, 2186.14, 2273.054, 2355.552, 2433.189, 2505.5, 2572.0, 2632.1940000000004, 2685.58, 2731.66, 2769.95, 2799.989, 2821.3559999999998, 2833.679, 2836.6540000000005, 2830.051, 2813.7270000000003, 2787.634, 2751.82, 2706.4320000000002, 2651.7129999999997, 2587.989, 2515.6639999999998, 2435.203, 2347.123, 2251.967, 2150.305, 2042.7120000000002, 1929.756, 1811.993, 1689.96, 1564.164, 1435.0839999999998, 1303.1660000000002, 1168.822, 1032.433, 894.3439999999999, 754.8710000000001, 614.3, 472.88699999999994, 330.865, 188.44, 45.799, -96.89200000000001, -239.487, -381.853, -523.875, -665.45, -806.4860000000001, -946.903, -1086.63, -1225.606, -1363.775, -1501.0910000000001, -1637.5120000000002, -1773.0020000000002, -1907.53, -2041.07, -2173.599, -2305.098, -2435.55, -2564.9429999999998, -2693.2659999999996, -2820.509, -2946.667, -3071.7340000000004, -3195.7070000000003, -3318.585, -3440.365, -3561.0490000000004, -3680.638, -3799.133, -3916.539, -4032.8579999999997, -4148.094, -4262.252, -4375.337, -4487.355, -4598.312, -4708.213, -4817.064, -4924.874, -5031.647, -5137.392, -5242.115, -5345.823, -5448.523, -5550.223000000001, -5650.931, -5750.653, -5849.396, -5947.169, -6043.978, -6139.831, -6234.735, -6328.696999999999, -6421.725, -6513.826, -6605.007, -6695.274, -6784.6359999999995, -6873.099, -6960.669, -7047.353, -7133.158, -7218.092, -7302.159000000001, -7385.368, -7467.724, -7549.233, -7629.901999999999, -7709.736999999999, -7788.744000000001, -7866.927, -7944.295999999999, -8020.855, -8096.61, -8171.565, -8245.726999999999, -8319.101, -8391.693000000001, -8463.507, -8534.55, -8604.826, -8674.341, -8743.099, -8811.105, -8878.365, -8944.883, -9010.663, -9075.711, -9140.032, -9203.628, -9266.506, -9328.669, -9390.122, -9450.869, -9510.914, -9570.261, -9628.915, -9686.878, -9744.155999999999, -9800.752, -9856.67, -9911.913, -9966.485999999999, -10020.392, -10073.634, -10126.216, -10178.141, -10229.413, -10280.036, -10330.011999999999, -10379.345, -10428.037, -10476.093, -10523.515, -10570.306999999999, -10616.471000000001, -10662.01, -10706.927, -10751.223999999998, -10794.906, -10837.973999999998, -10880.431999999999, -10922.281, -10963.526000000002, -11004.167, -11044.208, -11083.652, -11122.5, -11160.756000000001, -11198.421, -11235.498, -11271.99, -11307.898000000001, -11343.225, -11377.973, -11412.145, -11445.742, -11478.766000000001, -11511.22, -11543.106000000002, -11574.426000000001, -11605.181, -11635.374, -11665.006000000001, -11694.08, -11722.596000000001, -11750.558, -11777.966999999999, -11804.825, -11831.133, -11856.893, -11882.106000000002, -11906.775, -11930.901000000002, -11954.486, -11977.53, -12000.036, -12022.006000000001, -12043.44, -12064.34, -12084.708, -12104.544, -12123.851, -12142.63, -12160.881000000001, -12178.607, -12195.809, -12212.487, -12228.643, -12244.278, -12259.395, -12273.992, -12288.072, -12301.636, -12314.685, -12327.22, -12339.241000000002, -12350.751, -12361.75, -12372.239, -12382.219, -12391.69, -12400.655, -12409.113000000001, -12417.066, -12424.514, -12431.458999999999, -12437.9, -12443.84, -12449.278, -12454.216, -12458.653999999999, -12462.591999999999, -12466.032, -12468.975, -12471.42, -12473.368999999999, -12474.822, -12475.78, -12476.243, -12476.212, -12475.688, -12474.67, -12473.16, -12471.158000000001, -12468.663999999999, -12465.68, -12462.204, -12458.239, -12453.783000000001, -12448.838, -12443.403999999999, -12437.481000000002, -12431.07, -12424.171, -12416.784, -12408.909, -12400.546999999999, -12391.698, -12382.362, -12372.54, -12362.231000000002, -12351.436000000002, -12340.155, -12328.389, -12316.136, -12303.398000000001, -12290.173999999999, -12276.464, -12262.268999999998, -12247.589, -12232.423999999999, -12216.773000000001, -12200.636999999999, -12184.015, -12166.907, -12149.315, -12131.236, -12112.671999999999, -12093.622, -12074.086000000001, -12054.063999999998, -12033.556, -12012.561000000002, -11991.08, -11969.112, -11946.657, -11923.715, -11900.285, -11876.367, -11851.961000000001, -11827.067, -11801.684, -11775.812, -11749.45, -11722.598999999998, -11695.257, -11667.425, -11639.101, -11610.286, -11580.979, -11551.18, -11520.886999999999, -11490.101, -11458.821000000002, -11427.046, -11394.776000000002, -11362.01, -11328.748, -11294.989, -11260.732, -11225.976, -11190.722, -11154.968, -11118.713, -11081.958, -11044.7, -11006.938999999998, -10968.675, -10929.907, -10890.633999999998, -10850.854, -10810.568000000001, -10769.773000000001, -10728.47, -10686.658000000001, -10644.335, -10601.5, -10558.153, -10514.292, -10469.916, -10425.025, -10379.617, -10333.692, -10287.248, -10240.283000000001, -10192.798, -10144.789, -10096.257, -10047.201, -9997.618, -9947.508, -9896.87, -9845.701, -9794.001, -9741.769, -9689.003, -9635.701, -9581.863000000001, -9527.487, -9472.571, -9417.114, -9361.114, -9304.57, -9247.48, -9189.844000000001, -9131.658000000001, -9072.921999999999, -9013.634, -8953.792, -8893.394, -8832.44, -8770.926, -8708.851999999999, -8646.216, -8583.015, -8519.248, -8454.914, -8390.01, -8324.534, -8258.484, -8191.86, -8124.658, -8056.876, -7988.513000000001, -7919.566999999999, -7850.036, -7779.9169999999995, -7709.2080000000005, -7637.908, -7566.015, -7493.525, -7420.438, -7346.75, -7272.460999999999, -7197.566, -7122.066, -7045.956999999999, -6969.236, -6891.901999999999, -6813.953, -6735.385, -6656.198, -6576.388000000001, -6495.954000000001, -6414.894, -6333.204000000001, -6250.883000000001, -6167.928000000001, -6084.338000000001, -6000.11, -5915.241999999999, -5829.732, -5743.578, -5656.776999999999, -5569.326999999999, -5481.228, -5392.475, -5303.069, -5213.005, -5122.284000000001, -5030.904, -4938.861, -4846.156, -4752.786, -4658.751, -4564.049, -4468.678, -4372.639, -4275.929, -4178.55, -4080.5, -3981.778, -3882.386, -3782.324, -3681.591, -3580.1890000000003, -3478.119, -3375.384, -3271.9829999999997, -3167.921, -3063.2, -2957.823, -2851.795, -2745.12, -2637.803, -2529.851, -2421.269, -2312.065, -2202.249, -2091.8289999999997, -1980.818, -1869.225, -1757.066, -1644.355, -1531.1070000000002, -1417.3429999999998, -1303.08, -1188.343, -1073.156, -957.545, -841.5419999999999, -725.178, -608.491, -491.52, -374.311, -256.911, -139.374, -21.761, 95.865, 213.43200000000002, 330.85900000000004, 448.06199999999995, 564.944, 681.3989999999999, 797.312, 912.556, 1026.991, 1140.462, 1252.802, 1363.8229999999999, 1473.3229999999999, 1581.0810000000001, 1686.851, 1790.368, 1891.3429999999998, 1989.464, 2084.389, 2175.755, 2263.1679999999997, 2346.212, 2424.445, 2497.402, 2564.601, 2625.548, 2679.742, 2726.683, 2765.883, 2796.881, 2819.248, 2832.61, 2836.652, 2831.136, 2815.9109999999996, 2790.915, 2756.188, 2711.869, 2658.1859999999997, 2595.459, 2524.084, 2444.522, 2357.28, 2262.904, 2161.96, 2055.0229999999997, 1942.661, 1825.434, 1703.879, 1578.507, 1449.8, 1318.2089999999998, 1184.1480000000001, 1048.002, 910.1189999999999, 770.819, 630.39, 489.091, 347.158, 204.801, 62.207, -80.455, -223.037, -365.945, -507.44199999999995, -649.0419999999999, -790.115, -930.577, -1070.359, -1209.395, -1347.6329999999998, -1485.023, -1621.5220000000002, -1757.095, -1891.711, -2025.3410000000001, -2157.964, -2289.5589999999997, -2420.111, -2549.605, -2678.03, -2805.3779999999997, -2931.6420000000003, -3056.816, -3180.897, -3303.883, -3425.7729999999997, -3546.567, -3666.2670000000003, -3784.873, -3902.389, -4018.8190000000004, -4134.167, -4248.436, -4361.633, -4473.762, -4584.829000000001, -4694.840999999999, -4803.803, -4911.723, -5018.607, -5124.462, -5229.294, -5333.111, -5435.92, -5537.729, -5638.544, -5738.3730000000005, -5837.223000000001, -5935.103, -6032.018, -6127.976, -6222.986, -6317.053000000001, -6410.185, -6502.389, -6593.673000000001, -6684.043000000001, -6773.507, -6862.071, -6949.743, -7036.528, -7122.434, -7207.467, -7291.635, -7374.941999999999, -7457.397, -7539.004, -7619.771, -7699.704000000001, -7778.808000000001, -7857.089, -7934.554, -8011.209, -8087.059, -8162.109, -8236.365, -8309.833, -8382.518, -8454.426, -8525.562, -8595.93, -8665.537, -8734.386, -8802.484, -8869.835, -8936.443000000001, -9002.314, -9067.452, -9131.862, -9195.548, -9258.514000000001, -9320.766, -9382.306999999999, -9443.142, -9503.274, -9562.708, -9621.449, -9679.499, -9736.863000000001, -9793.545, -9849.548, -9904.877, -9959.535, -10013.525, -10066.851999999999, -10119.518, -10171.527, -10222.883, -10273.589, -10323.649, -10373.064, -10421.84, -10469.978000000001, -10517.482, -10564.355, -10610.601, -10656.221000000001, -10701.22, -10745.598, -10789.361, -10832.508999999998, -10875.046999999999, -10916.976999999999, -10958.301000000001, -10999.021999999999, -11039.142, -11078.665, -11117.591999999999, -11155.927, -11193.67, -11230.826000000001, -11267.396, -11303.382, -11338.787, -11373.613000000001, -11407.862, -11441.536, -11474.638, -11507.169, -11539.131000000001, -11570.527, -11601.358999999999, -11631.628, -11661.336000000001, -11690.486, -11719.078000000001, -11747.116000000002, -11774.6, -11801.533000000001, -11827.916000000001, -11853.751, -11879.038999999999, -11903.783000000001, -11927.983, -11951.642, -11974.761, -11997.341, -12019.385, -12040.892, -12061.866000000002, -12082.308, -12102.218, -12121.598, -12140.448999999999, -12158.774, -12176.573, -12193.847, -12210.598, -12226.826000000001, -12242.534, -12257.722, -12272.392, -12286.544, -12300.18, -12313.3, -12325.907, -12338.0, -12349.582, -12360.652, -12371.212, -12381.264, -12390.806999999999, -12399.843, -12408.372, -12416.395, -12423.915, -12430.93, -12437.442, -12443.452, -12448.961000000001, -12453.969, -12458.476999999999, -12462.486, -12465.996000000001, -12469.008, -12471.524, -12473.542, -12475.065, -12476.093, -12476.626, -12476.663999999999, -12476.208999999999, -12475.261, -12473.82, -12471.886999999999, -12469.463, -12466.546999999999, -12463.141000000001, -12459.243999999999, -12454.858, -12449.982, -12444.617, -12438.763, -12432.42, -12425.589, -12418.271, -12410.465, -12402.171, -12393.391000000001, -12384.123, -12374.37, -12364.13, -12353.403, -12342.191, -12330.492, -12318.306999999999, -12305.636999999999, -12292.481000000002, -12278.839, -12264.712, -12250.1, -12235.002, -12219.419, -12203.35, -12186.796, -12169.756000000001, -12152.231000000002, -12134.22, -12115.723999999998, -12096.741000000002, -12077.273000000001, -12057.318000000001, -12036.878, -12015.951000000001, -11994.537, -11972.636, -11950.249, -11927.374, -11904.011, -11880.161, -11855.822, -11830.995, -11805.678999999998, -11779.874, -11753.58, -11726.796, -11699.521, -11671.756000000001, -11643.5, -11614.752, -11585.511999999999, -11555.78, -11525.555, -11494.836000000001, -11463.623, -11431.915, -11399.712, -11367.013, -11333.818000000001, -11300.126, -11265.936000000002, -11231.248, -11196.06, -11160.373, -11124.186000000002, -11087.497, -11050.306, -11012.613000000001, -10974.416000000001, -10935.715, -10896.508999999998, -10856.796, -10816.577, -10775.85, -10734.614, -10692.868, -10650.612, -10607.845, -10564.565, -10520.771, -10476.463, -10431.639000000001, -10386.298, -10340.44, -10294.062, -10247.165, -10199.746, -10151.805, -10103.341, -10054.351999999999, -10004.837, -9954.795, -9904.224, -9853.123, -9801.49, -9749.326, -9696.627, -9643.393, -9589.623, -9535.314, -9480.465, -9425.076, -9369.144, -9312.668, -9255.646, -9198.077, -9139.959, -9081.291, -9022.071, -8962.296999999999, -8901.966999999999, -8841.081, -8779.635, -8717.63, -8655.061, -8591.929, -8528.23, -8463.964, -8399.128, -8333.721, -8267.74, -8201.183, -8134.05, -8066.3369999999995, -7998.043000000001, -7929.165, -7859.701999999999, -7789.651999999999, -7719.013000000001, -7647.781999999999, -7575.956999999999, -7503.536, -7430.517, -7356.899, -7282.678000000001, -7207.852, -7132.42, -7056.379, -6979.728, -6902.4619999999995, -6824.581999999999, -6746.0830000000005, -6666.965, -6587.224, -6506.859, -6425.866999999999, -6344.246, -6261.994000000001, -6179.109, -6095.5869999999995, -6011.428000000001, -5926.629, -5841.187, -5755.102, -5668.369000000001, -5580.988, -5492.956999999999, -5404.273, -5314.935, -5224.94, -5134.287, -5042.974, -4950.999, -4858.361, -4765.059, -4671.09, -4576.454000000001, -4481.15, -4385.177, -4288.534000000001, -4191.22, -4093.2340000000004, -3994.578, -3895.25, -3795.2509999999997, -3694.5820000000003, -3593.243, -3491.235, -3388.5609999999997, -3285.2209999999995, -3181.219, -3076.5570000000002, -2971.238, -2865.2670000000003, -2758.6479999999997, -2651.386, -2543.487, -2434.9570000000003, -2325.805, -2216.0389999999998, -2105.667, -1994.701, -1883.1529999999998, -1771.035, -1658.3629999999998, -1545.1529999999998, -1431.422, -1317.191, -1202.482, -1087.319, -971.7289999999999, -855.742, -739.39, -622.71, -505.741, -388.527, -271.117, -153.563, -35.925, 81.734, 199.342, 316.822, 434.087, 551.043, 667.585, 783.5989999999999, 898.959, 1013.5260000000001, 1127.1480000000001, 1239.6580000000001, 1350.871, 1460.588, 1568.586, 1674.625, 1778.442, 1879.75, 1978.239, 2073.571, 2165.385, 2253.2889999999998, 2336.87, 2415.689, 2489.283, 2557.173, 2618.863, 2673.8520000000003, 2721.643, 2761.743, 2793.69, 2817.048, 2831.438, 2836.538, 2832.1009999999997, 2817.966, 2794.062, 2760.4190000000003, 2717.1620000000003, 2664.513, 2602.782, 2532.3579999999997, 2453.6929999999998, 2367.2929999999997, 2273.699, 2173.476, 2067.196, 1955.433, 1838.745, 1717.671, 1592.727, 1464.3970000000002, 1333.136, 1199.361, 1063.46, 925.7860000000001, 786.6610000000001, 646.376, 505.195, 363.35400000000004, 221.06599999999997, 78.521, -64.11, -206.67700000000002, -349.045, -491.094, -632.72, -773.827, -914.334, -1054.1680000000001, -1193.264, -1331.568, -1469.03, -1605.6070000000002, -1741.2620000000002, -1875.963, -2009.683, -2142.399, -2274.09, -2404.74, -2534.335, -2662.862, -2790.3140000000003, -2916.6820000000002, -3041.9629999999997, -3166.151, -3289.245, -3411.244, -3532.147, -3651.9559999999997, -3770.673, -3888.2990000000004, -4004.84, -4120.298, -4234.678, -4347.985, -4460.225, -4571.403, -4681.525, -4790.598, -4898.627, -5005.62, -5111.584, -5216.525, -5320.45, -5423.368, -5525.284000000001, -5626.206, -5726.142, -5825.099, -5923.085, -6020.106, -6116.169, -6211.283, -6305.455, -6398.691, -6490.9980000000005, -6582.385, -6672.859, -6762.425, -6851.09, -6938.863, -7025.749, -7111.755, -7196.888000000001, -7281.154, -7364.561, -7447.1140000000005, -7528.819, -7609.683000000001, -7689.713000000001, -7768.9130000000005, -7847.291, -7924.852, -8001.601, -8077.545999999999, -8152.69, -8227.041, -8300.601999999999, -8373.381, -8445.381, -8516.61, -8587.071, -8656.769, -8725.711, -8793.899, -8861.341, -8928.039, -8994.0, -9059.228000000001, -9123.726999999999, -9187.502, -9250.556999999999, -9312.896999999999, -9374.526, -9435.448, -9495.668, -9555.189, -9614.016, -9672.152, -9729.603000000001, -9786.37, -9842.459, -9897.873, -9952.616, -10006.690999999999, -10060.101, -10112.851999999999, -10164.945, -10216.384, -10267.173, -10317.315999999999, -10366.815, -10415.673, -10463.893, -10511.479, -10558.434, -10604.761, -10650.462, -10695.541000000001, -10740.001, -10783.844, -10827.073, -10869.691, -10911.7, -10953.104, -10993.903999999999, -11034.104, -11073.706, -11112.712, -11151.125, -11188.947, -11226.181, -11262.829, -11298.893, -11334.376, -11369.278999999999, -11403.605, -11437.357, -11470.535, -11503.143, -11535.181999999999, -11566.653999999999, -11597.562, -11627.907, -11657.692, -11686.918, -11715.586000000001, -11743.698999999999, -11771.258999999998, -11798.267, -11824.723999999998, -11850.633999999998, -11875.997, -11900.815, -11925.09, -11948.823, -11972.016000000001, -11994.671, -12016.788, -12038.368999999999, -12059.417, -12079.931999999999, -12099.915, -12119.368, -12138.293, -12156.691, -12174.562, -12191.909, -12208.732, -12225.034, -12240.813999999998, -12256.073999999999, -12270.816, -12285.04, -12298.748, -12311.94, -12324.618, -12336.783000000001, -12348.436000000002, -12359.578000000001, -12370.208999999999, -12380.332, -12389.946000000002, -12399.053, -12407.653, -12415.748, -12423.337, -12430.423, -12437.006000000001, -12443.087, -12448.666000000001, -12453.743999999999, -12458.322, -12462.401000000002, -12465.981000000002, -12469.063999999998, -12471.649, -12473.738000000001, -12475.33, -12476.427, -12477.03, -12477.138, -12476.752, -12475.873, -12474.502, -12472.638, -12470.283000000001, -12467.437, -12464.098999999998, -12460.271999999999, -12455.954, -12451.146999999999, -12445.85, -12440.065, -12433.791000000001, -12427.028999999999, -12419.778999999999, -12412.042, -12403.817, -12395.105, -12385.906, -12376.22, -12366.048999999999, -12355.39, -12344.246000000001, -12332.615, -12320.499, -12307.896, -12294.808, -12281.235, -12267.176000000001, -12252.631000000001, -12237.601, -12222.086000000001, -12206.085, -12189.598, -12172.626, -12155.169, -12137.226, -12118.796999999999, -12099.882, -12080.481000000002, -12060.594, -12040.221000000001, -12019.361, -11998.015, -11976.181999999999, -11953.862, -11931.055, -11907.758999999998, -11883.976, -11859.705, -11834.945, -11809.697, -11783.958999999999, -11757.732, -11731.015, -11703.808, -11676.11, -11647.92, -11619.24, -11590.067, -11560.402, -11530.243, -11499.591, -11468.445, -11436.805, -11404.669, -11372.037, -11338.909, -11305.284, -11271.161, -11236.54, -11201.42, -11165.8, -11129.68, -11093.058, -11055.935, -11018.309, -10980.178999999998, -10941.545, -10902.406, -10862.761, -10822.608999999999, -10781.948999999999, -10740.78, -10699.101999999999, -10656.913, -10614.212, -10571.0, -10527.273000000001, -10483.032, -10438.275, -10393.002, -10347.211, -10300.901, -10254.071, -10206.72, -10158.847, -10110.449, -10061.528, -10012.08, -9962.105, -9911.601, -9860.568000000001, -9809.003, -9756.907, -9704.276, -9651.11, -9597.407, -9543.166, -9488.385, -9433.064, -9377.2, -9320.791, -9263.838, -9206.337, -9148.287, -9089.687, -9030.534, -8970.829, -8910.567, -8849.749, -8788.372, -8726.434000000001, -8663.934000000001, -8600.87, -8537.24, -8473.042, -8408.275, -8342.936, -8277.023000000001, -8210.536, -8143.471, -8075.826999999999, -8007.602, -7938.793000000001, -7869.399, -7799.4169999999995, -7728.846, -7657.684, -7585.928000000001, -7513.576, -7440.626, -7367.076999999999, -7292.925, -7218.168000000001, -7142.805, -7066.834, -6990.251, -6913.055, -6835.244000000001, -6756.814, -6677.765, -6598.094, -6517.798000000001, -6436.875, -6355.323, -6273.141, -6190.325, -6106.871999999999, -6022.781999999999, -5938.052, -5852.679, -5766.661999999999, -5679.999, -5592.687, -5504.724, -5416.108, -5326.838000000001, -5236.912, -5146.327, -5055.082, -4963.175, -4870.605, -4777.37, -4683.468, -4588.9, -4493.663, -4397.755999999999, -4301.179, -4203.931, -4106.012, -4007.42, -3908.157, -3808.222, -3707.617, -3606.341, -3504.3959999999997, -3401.783, -3298.505, -3194.563, -3089.961, -2984.7009999999996, -2878.788, -2772.225, -2665.0190000000002, -2557.174, -2448.697, -2339.596, -2229.879, -2119.556, -2008.6370000000002, -1897.1329999999998, -1785.058, -1672.4270000000001, -1559.254, -1445.558, -1331.359, -1216.6789999999999, -1101.5410000000002, -985.972, -870.002, -753.663, -636.991, -520.025, -402.80800000000005, -285.388, -167.81799999999998, -50.156000000000006, 67.535, 185.18400000000003, 302.714, 420.04, 537.068, 653.696, 769.809, 885.283, 999.9810000000001, 1113.752, 1226.431, 1337.836, 1447.765, 1556.003, 1662.309, 1766.424, 1868.0620000000001, 1966.918, 2062.654, 2154.9120000000003, 2243.305, 2327.422, 2406.825, 2481.054, 2549.631, 2612.062, 2667.848, 2716.487, 2757.488, 2790.382, 2814.7340000000004, 2830.155, 2836.317, 2832.9640000000004, 2819.925, 2797.1209999999996, 2764.5690000000004, 2722.385, 2670.781, 2610.056, 2540.594, 2462.8379999999997, 2377.292, 2284.492, 2185.001, 2079.391, 1968.236, 1852.096, 1731.513, 1607.005, 1479.0610000000001, 1348.136, 1214.653, 1079.004, 941.543, 802.5980000000001, 662.461, 521.401, 379.655, 237.44, 94.947, -47.652, -190.203, -332.569, -474.631, -616.28, -757.422, -897.9730000000001, -1037.859, -1177.015, -1315.385, -1452.9189999999999, -1589.5739999999998, -1725.3110000000001, -1860.099, -1993.91, -2126.719, -2258.506, -2389.254, -2518.949, -2647.579, -2775.136, -2901.611, -3026.998, -3151.295, -3274.498, -3396.6059999999998, -3517.619, -3637.539, -3756.367, -3874.105, -3990.757, -4106.326, -4220.818, -4334.237, -4446.589, -4557.878, -4668.111, -4777.295, -4885.435, -4992.538, -5098.612, -5203.662, -5307.696999999999, -5410.724, -5512.749, -5613.779, -5713.823, -5812.888000000001, -5910.981, -6008.108, -6104.278, -6199.4980000000005, -6293.774, -6387.115, -6479.526999999999, -6571.017, -6661.593000000001, -6751.262, -6840.03, -6927.904, -7014.892, -7100.999, -7186.232, -7270.599, -7354.105, -7436.757, -7518.562, -7599.525, -7679.651999999999, -7758.95, -7837.425, -7915.081999999999, -7991.927, -8067.967, -8143.206999999999, -8217.652, -8291.308, -8364.181, -8436.275, -8507.597, -8578.15, -8647.940999999999, -8716.974, -8785.255, -8852.788, -8919.578000000001, -8985.629, -9050.947, -9115.536, -9179.4, -9242.545, -9304.974, -9366.690999999999, -9427.702, -9488.009, -9547.618, -9606.532, -9664.756, -9722.293, -9779.146999999999, -9835.322, -9890.821, -9945.649, -9999.809000000001, -10053.305, -10106.14, -10158.318000000001, -10209.841999999999, -10260.715, -10310.940999999999, -10360.521999999999, -10409.463, -10457.766, -10505.435, -10552.472, -10598.881000000001, -10644.663999999999, -10689.825, -10734.365, -10778.288999999999, -10821.598999999998, -10864.298, -10906.388, -10947.871000000001, -10988.752, -11029.031, -11068.713, -11107.798, -11146.291000000001, -11184.192, -11221.505, -11258.232, -11294.374, -11329.935, -11364.916000000001, -11399.32, -11433.149, -11466.405, -11499.09, -11531.206, -11562.756000000001, -11593.74, -11624.162, -11654.021999999999, -11683.323999999999, -11712.068000000001, -11740.257, -11767.892, -11794.976, -11821.508999999998, -11847.493999999999, -11872.931999999999, -11897.825, -11922.175, -11945.983, -11969.25, -11991.979, -12014.171, -12035.827, -12056.948999999999, -12077.537, -12097.594, -12117.121000000001, -12136.12, -12154.59, -12172.535, -12189.955, -12206.851, -12223.226, -12239.078000000001, -12254.411, -12269.226, -12283.521999999999, -12297.302, -12310.567, -12323.317, -12335.553999999998, -12347.278999999999, -12358.492, -12369.195, -12379.389, -12389.075, -12398.253, -12406.923999999999, -12415.09, -12422.751, -12429.908000000001, -12436.562, -12442.714, -12448.363000000001, -12453.511999999999, -12458.161, -12462.311000000002, -12465.961000000001, -12469.114, -12471.768999999998, -12473.928, -12475.591, -12476.758, -12477.43, -12477.608, -12477.292, -12476.483, -12475.181999999999, -12473.388, -12471.101999999999, -12468.325, -12465.056999999999, -12461.298999999999, -12457.05, -12452.312, -12447.085, -12441.368999999999, -12435.163999999999, -12428.471000000001, -12421.29, -12413.622, -12405.466, -12396.823, -12387.692, -12378.075, -12367.972, -12357.382, -12346.306, -12334.743999999999, -12322.696000000002, -12310.162, -12297.142, -12283.636999999999, -12269.646, -12255.17, -12240.208, -12224.761, -12208.828000000001, -12192.409, -12175.505, -12158.116000000002, -12140.241000000002, -12121.88, -12103.033000000001, -12083.7, -12063.881000000001, -12043.575, -12022.783000000001, -12001.505, -11979.74, -11957.488000000001, -11934.748, -11911.52, -11887.805, -11863.601, -11838.909, -11813.728000000001, -11788.058, -11761.899, -11735.249, -11708.11, -11680.479, -11652.357, -11623.743999999999, -11594.639, -11565.041000000001, -11534.95, -11504.366000000002, -11473.287, -11441.714, -11409.646, -11377.082, -11344.021, -11310.463, -11276.408000000001, -11241.854, -11206.802, -11171.249, -11135.196000000002, -11098.642, -11061.586000000001, -11024.028, -10985.966, -10947.4, -10908.328000000001, -10868.75, -10828.665, -10788.073, -10746.972, -10705.361, -10663.24, -10620.607, -10577.462, -10533.803, -10489.63, -10444.940999999999, -10399.735, -10354.011999999999, -10307.77, -10261.008, -10213.724, -10165.919, -10117.589, -10068.735, -10019.357, -9969.449, -9919.014000000001, -9868.048, -9816.552, -9764.523000000001, -9711.96, -9658.862, -9605.226999999999, -9551.055, -9496.343, -9441.09, -9385.294, -9328.954, -9272.068000000001, -9214.636, -9156.654, -9098.123, -9039.039, -8979.402, -8919.209, -8858.459, -8797.151, -8735.282, -8672.851, -8609.855, -8546.294, -8482.165, -8417.466999999999, -8352.197, -8286.354, -8219.935, -8152.939, -8085.3640000000005, -8017.2080000000005, -7948.469, -7879.144, -7809.232, -7738.73, -7667.637, -7595.951, -7523.668000000001, -7450.7880000000005, -7377.308000000001, -7303.226, -7228.539000000001, -7153.246, -7077.344, -7000.831, -6923.704000000001, -6845.9619999999995, -6767.603, -6688.624, -6609.022, -6528.797, -6447.944, -6366.4619999999995, -6284.348000000001, -6201.602, -6118.219, -6034.1990000000005, -5949.5380000000005, -5864.235, -5778.2880000000005, -5691.694, -5604.451, -5516.557, -5428.0109999999995, -5338.81, -5248.953, -5158.437, -5067.2609999999995, -4975.423, -4882.920999999999, -4789.755, -4695.9220000000005, -4601.420999999999, -4506.251, -4410.412, -4313.901, -4216.72, -4118.867, -4020.341, -3921.143, -3821.2740000000003, -3720.7329999999997, -3619.5209999999997, -3517.639, -3415.0890000000004, -3311.873, -3207.993, -3103.452, -2998.252, -2892.397, -2785.8920000000003, -2678.742, -2570.952, -2462.53, -2353.482, -2243.8160000000003, -2133.542, -2022.67, -1911.2120000000002, -1799.18, -1686.589, -1573.455, -1459.795, -1345.629, -1230.978, -1115.867, -1000.321, -884.37, -768.045, -651.382, -534.42, -417.20099999999996, -299.774, -182.18900000000002, -64.50399999999999, 53.217, 170.90599999999998, 288.485, 405.871, 522.971, 639.682, 755.8939999999999, 871.4810000000001, 986.309, 1100.2269999999999, 1213.073, 1324.6660000000002, 1434.808, 1543.2839999999999, 1649.856, 1754.2679999999998, 1856.236, 1955.455, 2051.594, 2144.297, 2233.179, 2317.83, 2397.817, 2472.681, 2541.946, 2605.12, 2661.704, 2711.1929999999998, 2753.099, 2786.947, 2812.297, 2828.756, 2835.988, 2833.7290000000003, 2821.798, 2800.105, 2768.658, 2727.5609999999997, 2677.0159999999996, 2617.314, 2548.8289999999997, 2472.001, 2387.323, 2295.3320000000003, 2196.587, 2091.663, 1981.129, 1865.55, 1745.47, 1621.408, 1493.858, 1363.279, 1230.096, 1094.705, 957.4639999999999, 818.704, 678.72, 537.785, 396.13699999999994, 253.99599999999998, 111.557, -31.006999999999998, -173.53900000000002, -315.469, -457.976, -599.648, -740.824, -881.419, -1021.3580000000001, -1160.5739999999998, -1299.011, -1436.618, -1573.351, -1709.172, -1844.0479999999998, -1977.9489999999998, -2110.853, -2242.737, -2373.5860000000002, -2503.383, -2632.118, -2759.78, -2886.362, -3011.8579999999997, -3136.264, -3259.577, -3381.797, -3502.922, -3622.954, -3741.8940000000002, -3859.745, -3976.51, -4092.1940000000004, -4206.799, -4320.33, -4432.795, -4544.197, -4654.543, -4763.838, -4872.090999999999, -4979.306, -5085.491, -5190.653, -5294.8, -5397.937, -5500.071999999999, -5601.213000000001, -5701.366, -5800.539000000001, -5898.74, -5995.975, -6092.2519999999995, -6187.579000000001, -6281.9619999999995, -6375.409000000001, -6467.927, -6559.523, -6650.204000000001, -6739.976, -6828.848000000001, -6916.826, -7003.916, -7090.125, -7175.46, -7259.928000000001, -7343.535, -7426.286999999999, -7508.191, -7589.253000000001, -7669.48, -7748.8769999999995, -7827.45, -7905.205, -7982.148, -8058.284000000001, -8133.621, -8208.162, -8281.913, -8354.881, -8427.07, -8498.485999999999, -8569.133, -8639.017, -8708.144, -8776.517, -8844.143, -8911.024, -8977.168, -9042.577, -9107.256, -9171.211, -9234.446, -9296.965, -9358.771999999999, -9419.871, -9480.268, -9539.965, -9598.966999999999, -9657.279, -9714.903, -9771.844000000001, -9828.106, -9883.692, -9938.607, -9992.854, -10046.435, -10099.356, -10151.618, -10203.226999999999, -10254.184000000001, -10304.494, -10354.16, -10403.185, -10451.571, -10499.323, -10546.443000000001, -10592.935, -10638.8, -10684.043, -10728.666000000001, -10772.671999999999, -10816.063, -10858.844, -10901.015, -10942.58, -10983.541000000001, -11023.901000000002, -11063.662, -11102.828000000001, -11141.4, -11179.38, -11216.771999999999, -11253.578000000001, -11289.798999999999, -11325.438999999998, -11360.499, -11394.981000000002, -11428.888, -11462.222, -11494.985, -11527.178999999998, -11558.806, -11589.868, -11620.367, -11650.305, -11679.683, -11708.503999999999, -11736.768999999998, -11764.481000000002, -11791.64, -11818.25, -11844.31, -11869.823999999999, -11894.793, -11919.218, -11943.101, -11966.443000000001, -11989.247, -12011.513, -12033.243999999999, -12054.44, -12075.101999999999, -12095.233999999999, -12114.835, -12133.907, -12152.452, -12170.471000000001, -12187.964, -12204.934, -12221.382, -12237.308, -12252.714, -12267.601, -12281.97, -12295.823, -12309.16, -12321.983, -12334.292, -12346.089, -12357.375, -12368.15, -12378.416000000001, -12388.173, -12397.423, -12406.166000000001, -12414.403, -12422.135, -12429.364, -12436.089, -12442.312, -12448.033000000001, -12453.253, -12457.973, -12462.193000000001, -12465.913999999999, -12469.138, -12471.864, -12474.093, -12475.826000000001, -12477.063999999998, -12477.806, -12478.053999999998, -12477.809, -12477.07, -12475.838, -12474.114, -12471.898000000001, -12469.19, -12465.992, -12462.303, -12458.125, -12453.456, -12448.298, -12442.651000000002, -12436.516000000001, -12429.893, -12422.781, -12415.181, -12407.094, -12398.52, -12389.458999999999, -12379.91, -12369.876, -12359.355, -12348.347, -12336.854, -12324.874, -12312.409, -12299.458, -12286.021, -12272.098999999998, -12257.691, -12242.796999999999, -12227.418, -12211.553999999998, -12195.204, -12178.368, -12161.046, -12143.239, -12124.947, -12106.168, -12086.903999999999, -12067.153, -12046.915, -12026.191, -12004.981000000002, -11983.283000000001, -11961.098, -11938.426000000001, -11915.266000000001, -11891.618999999999, -11867.483, -11842.858999999999, -11817.745, -11792.143, -11766.051000000001, -11739.469, -11712.396999999999, -11684.833999999999, -11656.78, -11628.235, -11599.197, -11569.667, -11539.643999999998, -11509.127, -11478.117, -11446.611, -11414.61, -11382.114, -11349.121000000001, -11315.631000000001, -11281.643, -11247.157, -11212.171, -11176.686000000002, -11140.701000000001, -11104.214, -11067.226, -11029.735, -10991.74, -10953.241000000002, -10914.237, -10874.726, -10834.708999999999, -10794.185, -10753.151000000002, -10711.608, -10669.555, -10626.99, -10583.913, -10540.321000000002, -10496.216, -10451.595, -10406.457, -10360.801, -10314.627, -10267.931999999999, -10220.716999999999, -10172.979, -10124.716999999999, -10075.931, -10026.619, -9976.78, -9926.412, -9875.515, -9824.086, -9772.125, -9719.63, -9666.6, -9613.034, -9558.929, -9504.286, -9449.101, -9393.373, -9337.101, -9280.284, -9222.92, -9165.007, -9106.544, -9047.529, -8987.96, -8927.836, -8867.155, -8805.915, -8744.114, -8681.752, -8618.825, -8555.333, -8491.273000000001, -8426.643, -8361.442, -8295.668, -8229.318000000001, -8162.391, -8094.885, -8026.799, -7958.128000000001, -7888.8730000000005, -7819.03, -7748.597, -7677.5740000000005, -7605.956, -7533.743, -7460.933000000001, -7387.522, -7313.509, -7238.892, -7163.668000000001, -7087.835, -7011.392, -6934.335, -6856.6630000000005, -6778.3730000000005, -6699.463000000001, -6619.932, -6539.776, -6458.991999999999, -6377.58, -6295.536, -6212.859, -6129.545999999999, -6045.595, -5961.004, -5875.771, -5789.893, -5703.368, -5616.194, -5528.37, -5439.893, -5350.7609999999995, -5260.972, -5170.525, -5079.418, -4987.649, -4895.215, -4802.117, -4708.352, -4613.919, -4518.816, -4423.045999999999, -4326.603, -4229.488, -4131.701, -4033.241, -3934.1090000000004, -3834.304, -3733.827, -3632.679, -3530.861, -3428.3740000000003, -3325.22, -3221.401, -3116.92, -3011.78, -2905.9840000000004, -2799.5359999999996, -2692.4429999999998, -2584.709, -2476.34, -2367.344, -2257.73, -2147.505, -2036.681, -1925.269, -1813.28, -1700.731, -1587.636, -1474.0120000000002, -1359.88, -1245.259, -1130.175, -1014.6519999999999, -898.7189999999999, -782.409, -665.755, -548.798, -431.57800000000003, -314.142, -196.543, -78.837, 38.914, 156.641, 274.268, 391.712, 508.88199999999995, 625.6759999999999, 741.9830000000001, 857.681, 972.6360000000001, 1086.701, 1199.711, 1311.49, 1421.842, 1530.5520000000001, 1637.3870000000002, 1742.092, 1844.385, 1943.964, 2040.503, 2133.644, 2223.009, 2308.19, 2388.754, 2464.248, 2534.195, 2598.106, 2655.4809999999998, 2705.816, 2748.619, 2783.4159999999997, 2809.76, 2827.2529999999997, 2835.552, 2834.385, 2823.5609999999997, 2802.98, 2772.638, 2732.631, 2683.1490000000003, 2624.4759999999997, 2556.974, 2481.078, 2397.277, 2306.1020000000003, 2208.112, 2103.879, 1993.974, 1878.963, 1759.392, 1635.7839999999999, 1508.635, 1378.406, 1245.529, 1110.401, 973.385, 834.814, 694.987, 554.178, 412.63199999999995, 270.569, 128.186, -14.341, -156.85399999999998, -299.21299999999997, -441.295, -582.989, -724.197, -864.835, -1004.824, -1144.1, -1282.604, -1420.283, -1557.094, -1692.9979999999998, -1827.961, -1961.954, -2094.951, -2226.933, -2357.881, -2487.78, -2616.619, -2744.386, -2871.075, -2996.6809999999996, -3121.196, -3244.62, -3366.9509999999996, -3488.188, -3608.3320000000003, -3727.385, -3845.349, -3962.2270000000003, -4078.0229999999997, -4192.7429999999995, -4306.388, -4418.965, -4530.481, -4640.939, -4750.348, -4858.713, -4966.04, -5072.337, -5177.612, -5281.869000000001, -5385.116999999999, -5487.361999999999, -5588.613, -5688.875, -5788.158, -5886.467, -5983.811, -6080.196, -6175.63, -6270.12, -6363.673000000001, -6456.297, -6547.9980000000005, -6638.784000000001, -6728.661, -6817.6359999999995, -6905.717, -6992.91, -7079.222, -7164.66, -7249.23, -7332.938, -7415.791, -7497.795, -7578.956999999999, -7659.281999999999, -7738.778, -7817.4490000000005, -7895.302, -7972.342, -8048.576, -8124.009, -8198.646999999999, -8272.494, -8345.556999999999, -8417.841, -8489.351, -8560.093, -8630.071, -8699.291, -8767.757, -8835.474, -8902.448, -8968.683, -9034.185, -9098.956, -9163.001, -9226.326, -9288.935, -9350.832, -9412.021, -9472.506, -9532.292, -9591.383, -9649.783000000001, -9707.495, -9764.523000000001, -9820.872, -9876.546, -9931.546999999999, -9985.88, -10039.546999999999, -10092.553, -10144.901, -10196.595, -10247.636999999999, -10298.030999999999, -10347.780999999999, -10396.89, -10445.36, -10493.196000000002, -10540.399, -10586.973999999998, -10632.921999999999, -10678.248, -10722.953000000001, -10767.041000000001, -10810.514, -10853.376, -10895.628, -10937.274, -10978.315, -11018.756000000001, -11058.598, -11097.844, -11136.495, -11174.556, -11212.028, -11248.912, -11285.213, -11320.931999999999, -11356.071000000002, -11390.632, -11424.618, -11458.03, -11490.871000000001, -11523.142, -11554.847, -11585.986, -11616.562, -11646.576000000001, -11676.032, -11704.928999999998, -11733.271, -11761.059, -11788.295, -11814.98, -11841.117, -11866.707, -11891.751, -11916.252, -11940.211000000001, -11963.628999999999, -11986.507, -12008.848, -12030.653, -12051.923999999999, -12072.661, -12092.867, -12112.542, -12131.688999999998, -12150.306999999999, -12168.399, -12185.966, -12203.01, -12219.531, -12235.53, -12251.01, -12265.97, -12280.413, -12294.338, -12307.748, -12320.643999999998, -12333.026000000002, -12344.895, -12356.253, -12367.1, -12377.438, -12387.267, -12396.589, -12405.403999999999, -12413.713, -12421.516000000001, -12428.816, -12435.613000000001, -12441.906, -12447.698999999999, -12452.99, -12457.781, -12462.072, -12465.865, -12469.159, -12471.955, -12474.255, -12476.059, -12477.367, -12478.18, -12478.498, -12478.322, -12477.653999999999, -12476.492, -12474.838, -12472.692, -12470.053999999998, -12466.926000000001, -12463.306999999999, -12459.197, -12454.598, -12449.51, -12443.933, -12437.867, -12431.313, -12424.27, -12416.74, -12408.722, -12400.216999999999, -12391.223999999998, -12381.745, -12371.778999999999, -12361.327, -12350.388, -12338.964, -12327.053, -12314.656, -12301.774, -12288.406, -12274.552, -12260.213, -12245.388, -12230.078000000001, -12214.282, -12198.0, -12181.232, -12163.979, -12146.24, -12128.016000000001, -12109.305, -12090.108, -12070.425, -12050.256000000001, -12029.6, -12008.457, -11986.828000000001, -11964.711000000001, -11942.107, -11919.015, -11895.435, -11871.367, -11846.811000000002, -11821.766000000001, -11796.232, -11770.208, -11743.693000000001, -11716.688999999998, -11689.194, -11661.208, -11632.73, -11603.76, -11574.296999999999, -11544.341999999999, -11513.892, -11482.948999999999, -11451.511, -11419.578000000001, -11387.149, -11354.223, -11320.801000000001, -11286.881000000001, -11252.462, -11217.545, -11182.128, -11146.21, -11109.791000000001, -11072.87, -11035.447, -10997.52, -10959.088, -10920.152, -10880.708999999999, -10840.76, -10800.302, -10759.337, -10717.861, -10675.875, -10633.378, -10590.368, -10546.844, -10502.806999999999, -10458.253, -10413.184000000001, -10367.596, -10321.489, -10274.863000000001, -10227.715, -10180.045, -10131.851999999999, -10083.134, -10033.89, -9984.118, -9933.819, -9882.989, -9831.629, -9779.735999999999, -9727.309000000001, -9674.347, -9620.849, -9566.813, -9512.237, -9457.12, -9401.461, -9345.258, -9288.509, -9231.213, -9173.369, -9114.974, -9056.027, -8996.527, -8936.472, -8875.859, -8814.688, -8752.957, -8690.663, -8627.805, -8564.382, -8500.39, -8435.83, -8370.698, -8304.993, -8238.713, -8171.855, -8104.418000000001, -8036.4, -7967.799, -7898.611999999999, -7828.839, -7758.476, -7687.521, -7615.973000000001, -7543.83, -7471.089, -7397.7480000000005, -7323.804, -7249.257, -7174.103, -7098.340999999999, -7021.967, -6944.98, -6867.3769999999995, -6789.156999999999, -6710.316999999999, -6630.855, -6550.768, -6470.054, -6388.7119999999995, -6306.738, -6224.13, -6140.887, -6057.005999999999, -5972.485, -5887.321999999999, -5801.513000000001, -5715.058000000001, -5627.954000000001, -5540.1990000000005, -5451.7919999999995, -5362.729, -5273.009, -5182.630999999999, -5091.592000000001, -4999.891, -4907.526, -4814.496, -4720.799, -4626.434, -4531.4, -4435.696, -4339.32, -4242.272, -4144.5509999999995, -4046.157, -3947.091, -3847.3509999999997, -3746.9390000000003, -3645.8559999999998, -3544.1009999999997, -3441.677, -3338.585, -3234.828, -3130.407, -3025.327, -2919.59, -2813.2009999999996, -2706.165, -2598.486, -2490.172, -2381.23, -2271.666, -2161.492, -2050.716, -1939.35, -1827.406, -1714.898, -1601.842, -1488.256, -1374.1570000000002, -1259.568, -1144.511, -1029.011, -913.0980000000001, -796.803, -680.16, -563.2080000000001, -445.98800000000006, -328.546, -210.93400000000003, -93.20700000000001, 24.572, 142.336, 260.01, 377.51099999999997, 494.749, 611.624, 728.0260000000001, 843.8330000000001, 958.914, 1073.122, 1186.295, 1298.258, 1408.817, 1517.76, 1624.855, 1729.849, 1832.464, 1932.401, 2029.335, 2122.913, 2212.756, 2298.4629999999997, 2379.6020000000003, 2455.722, 2526.348, 2590.992, 2649.1540000000005, 2700.333, 2744.033, 2779.776, 2807.114, 2825.6420000000003, 2835.009, 2834.935, 2825.223, 2805.759, 2776.531, 2737.6220000000003, 2689.2129999999997, 2631.5759999999996, 2565.0679999999998, 2490.115, 2407.202, 2316.855, 2219.631, 2116.098, 2006.8339999999998, 1892.401, 1773.348, 1650.203, 1523.461, 1393.5910000000001, 1261.027, 1126.167, 989.3810000000001, 851.003, 711.3380000000001, 570.661, 429.221, 287.238, 144.914, 2.426, -140.065, -282.418, -424.50800000000004, -566.2230000000001, -707.4639999999999, -848.1439999999999, -988.184, -1127.519, -1266.088, -1403.84, -1540.729, -1676.7160000000001, -1811.765, -1945.849, -2078.942, -2211.022, -2342.07, -2472.072, -2601.015, -2728.889, -2855.685, -2981.3990000000003, -3106.025, -3229.5609999999997, -3352.0029999999997, -3473.353, -3593.61, -3712.777, -3830.855, -3947.847, -4063.758, -4178.59, -4292.35, -4405.041, -4516.670999999999, -4627.2429999999995, -4736.765, -4845.2429999999995, -4952.685, -5059.095, -5164.481, -5268.85, -5372.209, -5474.566, -5575.927, -5676.3, -5775.693, -5874.111999999999, -5971.565, -6068.058000000001, -6163.6, -6258.198, -6351.858, -6444.588000000001, -6536.395, -6627.286, -6717.269, -6806.35, -6894.535, -6981.831999999999, -7068.246999999999, -7153.786999999999, -7238.459, -7322.269, -7405.223000000001, -7487.328, -7568.590999999999, -7649.017, -7728.611999999999, -7807.382, -7885.3330000000005, -7962.472, -8038.803000000001, -8114.3330000000005, -8189.066999999999, -8263.011, -8336.171, -8408.551, -8480.155999999999, -8550.993, -8621.065, -8690.379, -8758.938, -8826.749, -8893.815999999999, -8960.143, -9025.735999999999, -9090.599, -9154.735999999999, -9218.153, -9280.851999999999, -9342.839, -9404.118, -9464.693000000001, -9524.568000000001, -9583.748, -9642.235999999999, -9700.037, -9757.153, -9813.59, -9869.351, -9924.439, -9978.858, -10032.612, -10085.704, -10138.138, -10189.917, -10241.045, -10291.524, -10341.359, -10390.552, -10439.107, -10487.026000000002, -10534.313999999998, -10580.972, -10627.003, -10672.412, -10717.198999999999, -10761.37, -10804.925, -10847.868, -10890.202, -10931.928999999998, -10973.052, -11013.573999999999, -11053.497, -11092.823999999999, -11131.556, -11169.697, -11207.248, -11244.213, -11280.593, -11316.391000000001, -11351.608999999999, -11386.249, -11420.313, -11453.803999999998, -11486.723, -11519.073, -11550.855, -11582.072, -11612.726, -11642.818000000001, -11672.351, -11701.326000000001, -11729.745, -11757.61, -11784.921999999999, -11811.684, -11837.896999999999, -11863.563, -11888.683, -11913.258999999998, -11937.293, -11960.787, -11983.741000000002, -12006.157, -12028.037, -12049.383, -12070.196000000002, -12090.476, -12110.226, -12129.447, -12148.139, -12166.306, -12183.947, -12201.063999999998, -12217.659, -12233.732, -12249.284, -12264.318000000001, -12278.833999999999, -12292.832, -12306.315, -12319.284, -12331.739, -12343.681, -12355.112, -12366.031, -12376.442, -12386.343, -12395.737, -12404.624, -12413.005, -12420.88, -12428.252, -12435.12, -12441.485, -12447.348999999998, -12452.711000000001, -12457.573, -12461.936000000002, -12465.8, -12469.165, -12472.033000000001, -12474.403, -12476.278, -12477.656, -12478.54, -12478.928999999998, -12478.823, -12478.225, -12477.133, -12475.548999999999, -12473.473999999998, -12470.906, -12467.848, -12464.298999999999, -12460.26, -12455.731000000002, -12450.712, -12445.205, -12439.208, -12432.723, -12425.75, -12418.288999999999, -12410.34, -12401.903999999999, -12392.981000000002, -12383.571000000002, -12373.675, -12363.291000000001, -12352.421999999999, -12341.066, -12329.223999999998, -12316.896999999999, -12304.083999999999, -12290.785, -12276.999, -12262.729, -12247.972, -12232.73, -12217.003, -12200.788999999999, -12184.09, -12166.906, -12149.235, -12131.079, -12112.437, -12093.308, -12073.693000000001, -12053.591999999999, -12033.005, -12011.931, -11990.37, -11968.321000000002, -11945.785, -11922.761, -11899.25, -11875.25, -11850.761, -11825.784, -11800.317, -11774.361, -11747.915, -11720.978000000001, -11693.551000000001, -11665.633, -11637.223, -11608.32, -11578.926000000001, -11549.038999999999, -11518.658000000001, -11487.782, -11456.412, -11424.546, -11392.185, -11359.327, -11325.973, -11292.12, -11257.77, -11222.92, -11187.57, -11151.72, -11115.368999999999, -11078.516000000001, -11041.16, -11003.301000000001, -10964.937, -10926.069, -10886.694, -10846.813, -10806.423, -10765.525, -10724.118, -10682.2, -10639.77, -10596.828000000001, -10553.373, -10509.403, -10464.917, -10419.915, -10374.395, -10328.357, -10281.798, -10234.719000000001, -10187.117, -10138.992, -10090.341999999999, -10041.166, -9991.463, -9941.232, -9890.47, -9839.178, -9787.353000000001, -9734.995, -9682.101999999999, -9628.671, -9574.703000000001, -9520.196, -9465.148000000001, -9409.556999999999, -9353.423, -9296.743, -9239.516, -9181.74, -9123.414, -9064.536, -9005.104, -8945.118, -8884.574, -8823.472, -8761.809000000001, -8699.585, -8636.796, -8573.442, -8509.52, -8445.029, -8379.966, -8314.33, -8248.119, -8181.33, -8113.963000000001, -8046.014, -7977.483, -7908.366, -7838.661999999999, -7768.368, -7697.484, -7626.005, -7553.932, -7481.2609999999995, -7407.99, -7334.116, -7259.639, -7184.554, -7108.861, -7032.558000000001, -6955.641, -6878.108, -6799.9580000000005, -6721.188, -6641.795999999999, -6561.779, -6481.1359999999995, -6399.8640000000005, -6317.96, -6235.423000000001, -6152.25, -6068.439, -5983.986999999999, -5898.893, -5813.155, -5726.77, -5639.736, -5552.05, -5463.7119999999995, -5374.72, -5285.07, -5194.7609999999995, -5103.792, -5012.16, -4919.8640000000005, -4826.903, -4733.274, -4638.977, -4544.0109999999995, -4448.374, -4352.066, -4255.085, -4157.431, -4059.1040000000003, -3960.105, -3860.4309999999996, -3760.0840000000003, -3659.065, -3557.375, -3455.015, -3351.986, -3248.29, -3143.9309999999996, -3038.9109999999996, -2933.2340000000004, -2826.9040000000005, -2719.925, -2612.304, -2504.045, -2395.156, -2285.645, -2175.521, -2064.794, -1953.475, -1841.576, -1729.111, -1616.096, -1502.547, -1388.483, -1273.925, -1158.896, -1043.422, -927.53, -811.2510000000001, -694.62, -577.674, -460.455, -343.00800000000004, -225.38400000000001, -107.639, 10.168, 127.96799999999999, 245.687, 363.244, 480.548, 597.502, 713.997, 829.9119999999999, 945.117, 1059.4660000000001, 1172.8, 1284.944, 1395.7079999999999, 1504.881, 1612.235, 1717.516, 1820.451, 1920.743, 2018.069, 2112.08, 2202.401, 2288.631, 2370.343, 2447.085, 2518.388, 2583.764, 2642.7140000000004, 2694.7340000000004, 2739.3309999999997, 2776.0209999999997, 2804.355, 2823.9190000000003, 2834.36, 2835.387, 2826.792, 2808.454, 2780.347, 2742.546, 2695.22, 2638.633, 2573.132, 2499.135, 2417.1220000000003, 2327.617, 2231.1710000000003, 2128.353, 2019.74, 1905.8970000000002, 1787.3729999999998, 1664.6989999999998, 1538.375, 1408.872, 1276.627, 1142.0430000000001, 1005.493, 867.314, 727.815, 587.274, 445.94199999999995, 304.043, 161.78, 19.334, -123.133, -265.573, -407.57599999999996, -549.311, -690.5830000000001, -831.304, -971.395, -1110.789, -1249.424, -1387.2479999999998, -1524.2160000000001, -1660.285, -1795.4229999999998, -1929.598, -2062.786, -2194.965, -2326.114, -2456.219, -2585.268, -2713.2490000000003, -2840.1540000000005, -2965.978, -3090.716, -3214.364, -3336.9190000000003, -3458.383, -3578.7540000000004, -3698.035, -3816.228, -3933.335, -4049.362, -4164.31, -4278.185, -4390.991, -4502.736, -4613.423, -4723.06, -4831.653, -4939.208, -5045.732, -5151.232, -5255.714, -5359.186, -5461.655, -5563.128000000001, -5663.613, -5763.116999999999, -5861.647, -5959.209, -6055.813, -6151.464, -6246.17, -6339.938, -6432.775, -6524.69, -6615.687, -6705.776, -6794.9619999999995, -6883.253000000001, -6970.655, -7057.174, -7142.818, -7227.593000000001, -7311.505999999999, -7394.563, -7476.769, -7558.133000000001, -7638.66, -7718.356, -7797.226, -7875.276999999999, -7952.514, -8028.944, -8104.573, -8179.405, -8253.446, -8326.702, -8399.179, -8470.88, -8541.812, -8611.98, -8681.388, -8750.042, -8817.947, -8885.108, -8951.528, -9017.214, -9082.17, -9146.399, -9209.907, -9272.698, -9334.776, -9396.145, -9456.811, -9516.776, -9576.045, -9634.623, -9692.511999999999, -9749.718, -9806.243, -9862.091999999999, -9917.268, -9971.774, -10025.615, -10078.794, -10131.314, -10183.18, -10234.393, -10284.958, -10334.879, -10384.157, -10432.796999999999, -10480.801, -10528.171999999999, -10574.913999999999, -10621.028999999999, -10666.521, -10711.392, -10755.645, -10799.283000000001, -10842.309, -10884.726, -10926.535, -10967.74, -11008.343, -11048.348, -11087.755, -11126.568000000001, -11164.788999999999, -11202.421, -11239.466, -11275.926000000001, -11311.803999999998, -11347.101, -11381.821000000002, -11415.965, -11449.535, -11482.533000000001, -11514.961000000001, -11546.822, -11578.118, -11608.848999999998, -11639.018999999998, -11668.63, -11697.681999999999, -11726.178, -11754.12, -11781.51, -11808.348999999998, -11834.639, -11860.381000000001, -11885.578000000001, -11910.23, -11934.34, -11957.909, -11980.938999999998, -12003.431, -12025.386999999999, -12046.806999999999, -12067.695, -12088.05, -12107.875, -12127.17, -12145.938, -12164.178999999998, -12181.895, -12199.086000000001, -12215.755, -12231.902, -12247.528, -12262.635, -12277.223999999998, -12291.296999999999, -12304.853000000001, -12317.893999999998, -12330.421999999999, -12342.437, -12353.941, -12364.934, -12375.417, -12385.391000000001, -12394.857, -12403.816, -12412.268999999998, -12420.216999999999, -12427.66, -12434.6, -12441.037, -12446.972, -12452.406, -12457.34, -12461.774, -12465.708999999999, -12469.146, -12472.083999999999, -12474.526000000002, -12476.471000000001, -12477.921, -12478.875, -12479.333999999999, -12479.3, -12478.771999999999, -12477.751, -12476.237, -12474.232, -12471.735, -12468.746000000001, -12465.267, -12461.298, -12456.839, -12451.891000000001, -12446.453000000001, -12440.526000000002, -12434.111, -12427.207, -12419.816, -12411.936000000002, -12403.57, -12394.716, -12385.375, -12375.548, -12365.233999999999, -12354.434, -12343.146999999999, -12331.375, -12319.116000000002, -12306.372, -12293.141000000001, -12279.425, -12265.223, -12250.535, -12235.362, -12219.703000000001, -12203.558, -12186.928, -12169.811000000002, -12152.208999999999, -12134.122, -12115.548, -12096.488000000001, -12076.942, -12056.909, -12036.39, -12015.383, -11993.89, -11971.91, -11949.442, -11926.486, -11903.042, -11879.11, -11854.69, -11829.781, -11804.382, -11778.493999999999, -11752.116000000002, -11725.247, -11697.888, -11670.038, -11641.696000000002, -11612.861, -11583.534, -11553.714, -11523.401000000002, -11492.593, -11461.291000000001, -11429.493, -11397.2, -11364.41, -11331.123, -11297.338, -11263.056, -11228.274, -11192.992, -11157.208999999999, -11120.926000000001, -11084.141000000001, -11046.851999999999, -11009.061000000002, -10970.765, -10931.964, -10892.657, -10852.843, -10812.521, -10771.691, -10730.351, -10688.501, -10646.14, -10603.266000000001, -10559.878, -10515.976, -10471.558, -10426.624, -10381.171999999999, -10335.201, -10288.711, -10241.699, -10194.165, -10146.107, -10097.525, -10048.418, -9998.783000000001, -9948.62, -9897.927, -9846.703000000001, -9794.946, -9742.655999999999, -9689.831, -9636.469000000001, -9582.569, -9528.13, -9473.15, -9417.627, -9361.561, -9304.95, -9247.792, -9190.084, -9131.827, -9073.017, -9013.655, -8953.737, -8893.261999999999, -8832.228000000001, -8770.635, -8708.479, -8645.759, -8582.473, -8518.62, -8454.198, -8389.204, -8323.638, -8257.496, -8190.776, -8123.478, -8055.599, -7987.1359999999995, -7918.089, -7848.454000000001, -7778.23, -7707.415, -7636.005999999999, -7564.0019999999995, -7491.401, -7418.1990000000005, -7344.396, -7269.986999999999, -7194.973000000001, -7119.35, -7043.116, -6966.268, -6888.806, -6810.726, -6732.025, -6652.703, -6572.757, -6492.184, -6410.981, -6329.147, -6246.68, -6163.576, -6079.835, -5995.453, -5910.429, -5824.7609999999995, -5738.445, -5651.481, -5563.865, -5475.597, -5386.674, -5297.093000000001, -5206.853, -5115.9529999999995, -5024.39, -4932.163, -4839.27, -4745.71, -4651.482, -4556.584, -4461.015, -4364.774, -4267.86, -4170.274, -4072.013, -3973.079, -3873.4709999999995, -3773.1890000000003, -3672.235, -3570.6090000000004, -3468.312, -3365.3459999999995, -3261.7129999999997, -3157.4159999999997, -3052.4570000000003, -2946.8390000000004, -2840.567, -2733.6459999999997, -2626.08, -2517.877, -2409.042, -2299.584, -2189.511, -2078.833, -1967.5620000000001, -1855.7079999999999, -1743.286, -1630.3110000000001, -1516.8, -1402.7720000000002, -1288.246, -1173.246, -1057.796, -941.925, -825.663, -709.045, -592.106, -474.88800000000003, -357.43699999999995, -239.80200000000002, -122.039, -4.206, 113.62799999999999, 231.391, 349.00199999999995, 466.37199999999996, 583.403, 699.988, 816.0089999999999, 931.334, 1045.822, 1159.3139999999999, 1271.638, 1382.605, 1492.004, 1599.611, 1705.175, 1808.4260000000002, 1909.068, 2006.7820000000002, 2101.221, 2192.013, 2278.761, 2361.038, 2438.3979999999997, 2510.3720000000003, 2576.473, 2636.203, 2689.06, 2734.546, 2772.179, 2801.502, 2822.1, 2833.6090000000004, 2835.7340000000004, 2828.256, 2811.0429999999997, 2784.06, 2747.369, 2701.132, 2645.599, 2581.11, 2508.077, 2426.973, 2338.3160000000003, 2242.656, 2140.563, 2032.609, 1919.362, 1801.3770000000002, 1679.181, 1553.2820000000002, 1424.151, 1292.231, 1157.93, 1021.62, 883.6460000000001, 744.317, 603.915, 462.694, 320.882, 178.68400000000003, 36.282, -106.16, -248.49599999999998, -390.598, -532.351, -673.653, -814.414, -954.555, -1094.006, -1232.7069999999999, -1370.6029999999998, -1507.648, -1643.8, -1779.025, -1913.293, -2046.576, -2178.851, -2310.1020000000003, -2440.31, -2569.464, -2697.553, -2824.5679999999998, -2950.502, -3075.3509999999997, -3199.111, -3321.7790000000005, -3443.357, -3563.843, -3683.239, -3801.547, -3918.77, -4034.9109999999996, -4149.975, -4263.965, -4376.888, -4488.748, -4599.5509999999995, -4709.303, -4818.0109999999995, -4925.68, -5032.318, -5137.931, -5242.527, -5346.113, -5448.695, -5550.281, -5650.8769999999995, -5750.491999999999, -5849.132, -5946.806, -6043.519, -6139.28, -6234.096, -6327.973000000001, -6420.919, -6512.941, -6604.045999999999, -6694.241, -6783.533, -6871.93, -6959.437, -7046.061, -7131.809, -7216.687, -7300.703, -7383.861999999999, -7466.172, -7547.637, -7628.265, -7708.061, -7787.031999999999, -7865.183000000001, -7942.52, -8019.049, -8094.776, -8169.706, -8243.845, -8317.198, -8389.771, -8461.569, -8532.597, -8602.86, -8672.364]}, {\"marker\": {\"color\": \"yellow\", \"colorscale\": [[0.0, \"#440154\"], [0.1111111111111111, \"#482878\"], [0.2222222222222222, \"#3e4989\"], [0.3333333333333333, \"#31688e\"], [0.4444444444444444, \"#26828e\"], [0.5555555555555556, \"#1f9e89\"], [0.6666666666666666, \"#35b779\"], [0.7777777777777778, \"#6ece58\"], [0.8888888888888888, \"#b5de2b\"], [1.0, \"#fde725\"]], \"opacity\": 0.8, \"size\": 30}, \"mode\": \"markers\", \"type\": \"scatter3d\", \"x\": [0], \"y\": [0], \"z\": [0]}],                        {\"margin\": {\"b\": 0, \"l\": 0, \"r\": 0, \"t\": 0}, \"scene\": {\"aspectmode\": \"data\"}, \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"autotypenumbers\": \"strict\", \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('287814fa-7acb-4938-bd78-5af64e726595');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import plotly.graph_objects as go\n",
    "\n",
    "\n",
    "fig = go.Figure(data=[go.Scatter3d(\n",
    "    x=data[\"X_MSO\"][:-70000],\n",
    "    y=data[\"Y_MSO\"][:-70000],\n",
    "    z=data[\"Z_MSO\"][:-70000],\n",
    "    mode='lines',\n",
    "    marker=dict(\n",
    "        size=1,\n",
    "        color='blue',                # set color to an array/list of desired values\n",
    "        colorscale='Viridis',   # choose a colorscale\n",
    "        opacity=0.8\n",
    "    )\n",
    ")])\n",
    "\n",
    "fig.add_trace(go.Scatter3d(\n",
    "    x=[0],\n",
    "    y=[0],\n",
    "    z=[0],\n",
    "    mode='markers',\n",
    "    marker=dict(\n",
    "        size=30,\n",
    "        color='yellow',                # set color to an array/list of desired values\n",
    "        colorscale='Viridis',   # choose a colorscale\n",
    "        opacity=0.8\n",
    "    )\n",
    "))\n",
    "\n",
    "# tight layout\n",
    "fig.update_layout(margin=dict(l=0, r=0, b=0, t=0), scene=dict(aspectmode='data'))\n",
    "fig.show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 39,
   "metadata": {},
   "outputs": [],
   "source": [
    "def find_nodes(data):\n",
    "    extrema=pd.DataFrame(index=data.index)\n",
    "    extrema['TYPE']=0\n",
    "\n",
    "    apoapsis = find_peaks(data.R.values.round(0))[0]\n",
    "    periapsis = find_peaks(1/data.R.values.round(0))[0]\n",
    "\n",
    "    extrema.iloc[apoapsis] = 2\n",
    "    extrema.iloc[periapsis] = 1\n",
    "    return extrema, apoapsis, periapsis\n",
    "\n",
    "nodes, _, _ = find_nodes(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 40,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/vnd.plotly.v1+json": {
       "config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "data": [
        {
         "marker": {
          "color": "red"
         },
         "mode": "markers",
         "name": "APO",
         "type": "scatter",
         "x": [
          -1779.8110000000001,
          -1812.2220000000002,
          -1844.067,
          -1875.319,
          -1905.974,
          -1936.014,
          -1965.4189999999999,
          -1994.185,
          -2022.2939999999999,
          -2049.728,
          -2076.486,
          -2102.547,
          -2127.894,
          -2152.522,
          -2176.41,
          -2199.526,
          -2221.873,
          -2243.429,
          -2286.734,
          -2284.078,
          -2327.194,
          -2321.349,
          -2338.677,
          -2381.3360000000002,
          -2370.665,
          -2412.956,
          -2427.395,
          -2440.891,
          -2453.448,
          -2465.058,
          -2475.705,
          -2485.388,
          -2494.098,
          -2501.819,
          -2508.564,
          -2514.304,
          -2519.019,
          -2522.706,
          -2525.347,
          -2526.915,
          -2527.403,
          -2526.7889999999998,
          -2563.644,
          -2561.29,
          -2557.736,
          -2552.956,
          -2546.931,
          -2539.609,
          -2530.944,
          -2520.905,
          -2509.446,
          -2496.529,
          -2482.123,
          -2466.181,
          -2448.667,
          -2429.547,
          -2408.777,
          -2386.33,
          -2362.173,
          -2336.263,
          -2308.5860000000002,
          -2279.106,
          -2294.3579999999997,
          -2261.466,
          -2226.603,
          -2189.797,
          -2151.019,
          -2110.254,
          -2067.478,
          -2022.6779999999999,
          -1975.8410000000001,
          -1926.9460000000001,
          -1875.9920000000002,
          -1822.965,
          -1814.194,
          -1756.76,
          -1697.204,
          -1635.539,
          -1571.7879999999998,
          -1505.9720000000002,
          -1438.125,
          -1368.297,
          -1296.536,
          -1222.899,
          -1149.98,
          -1072.869,
          -994.1080000000001,
          -953.2139999999999,
          -870.582,
          -786.549,
          -701.235,
          -614.757,
          -527.248,
          -438.843,
          -349.685,
          -259.93,
          -169.74099999999999,
          -107.727,
          -15.817,
          76.055,
          167.71,
          258.96,
          349.62,
          439.50800000000004,
          528.436,
          615.9,
          702.322,
          774.003,
          858.8710000000001,
          941.883,
          1022.8660000000001,
          1101.657,
          1178.105,
          1252.0610000000001,
          1322.244,
          1392.5629999999999,
          1460.005,
          1524.4620000000002,
          1585.8429999999998,
          1644.0720000000001,
          1699.0870000000002,
          1750.838,
          1799.2879999999998,
          1844.415,
          1886.2120000000002,
          1942.082,
          1978.612,
          2011.9620000000002,
          2041.9879999999998,
          2068.737,
          2092.262,
          2112.61,
          2129.84,
          2172.803,
          2185.259,
          2194.7670000000003,
          2201.406,
          2205.264,
          2206.4210000000003,
          2204.984,
          2201.04,
          2194.69,
          2224.41,
          2214.396,
          2202.234,
          2188.027,
          2171.863,
          2152.939,
          2133.195,
          2111.7729999999997,
          2088.763,
          2064.258,
          2083.189,
          2056.365,
          2028.256,
          1952.9129999999998,
          1968.477,
          1936.954,
          1904.43,
          1870.97,
          1836.632,
          1848.806,
          1812.977,
          1728.852,
          1739.0710000000001,
          1701.067,
          1662.4070000000002,
          1623.126,
          1583.29,
          1542.828,
          1501.879,
          1460.467,
          1418.629,
          1376.3770000000002,
          1333.763,
          1290.835,
          1293.796,
          1250.093,
          1160.538,
          1162.077,
          1117.8519999999999,
          1073.5339999999999,
          1029.1589999999999,
          984.7589999999999,
          940.3580000000001,
          895.9860000000001,
          851.672,
          807.436,
          763.301,
          719.2310000000001,
          675.42,
          672.2660000000001,
          628.2959999999999,
          584.518,
          540.945,
          497.589,
          454.481,
          411.639,
          369.06300000000005,
          326.778,
          284.803,
          243.157,
          201.87400000000002,
          160.971,
          120.45,
          80.332,
          40.626,
          1.341,
          -37.515,
          -75.935,
          -114.014,
          -151.594,
          -188.732,
          -225.442,
          -261.723,
          -297.57599999999996,
          -307.415,
          -343.11300000000006,
          -378.399,
          -413.292,
          -447.805,
          -504.075,
          -515.705,
          -549.0980000000001,
          -582.117,
          -614.7719999999999,
          -647.064,
          -678.995,
          -710.571,
          -741.791,
          -772.6569999999999,
          -803.243,
          -833.426,
          -863.2560000000001,
          -892.7360000000001,
          -921.865,
          -950.64,
          -979.063,
          -1007.13,
          -1034.84,
          -1062.194,
          -1089.188,
          -1115.823,
          -1142.097,
          -1168.013,
          -1193.5739999999998,
          -1218.768,
          -1240.723,
          -1265.954,
          -1290.817,
          -1315.308,
          -1339.425,
          -1363.1629999999998,
          -1386.514,
          -1409.464,
          -1432.005,
          -1454.1270000000002,
          -1475.817,
          -1497.067,
          -1517.866,
          -1538.201,
          -1558.059,
          -1577.43,
          -1596.2979999999998
         ],
         "y": [
          -1985.2479999999998,
          -1951.8529999999998,
          -1917.721,
          -1882.839,
          -1847.265,
          -1810.994,
          -1774.0279999999998,
          -1736.412,
          -1698.134,
          -1659.194,
          -1619.636,
          -1579.442,
          -1538.6070000000002,
          -1497.172,
          -1455.118,
          -1412.421,
          -1369.136,
          -1325.253,
          -1321.7320000000002,
          -1235.702,
          -1230.238,
          -1143.948,
          -1097.401,
          -1089.1480000000001,
          -1002.813,
          -992.6310000000001,
          -943.68,
          -894.262,
          -844.42,
          -794.169,
          -743.507,
          -692.465,
          -641.057,
          -589.283,
          -537.182,
          -484.73900000000003,
          -431.957,
          -378.856,
          -325.441,
          -271.711,
          -217.685,
          -163.368,
          -135.391,
          -79.58800000000001,
          -23.479,
          32.929,
          89.60799999999999,
          146.562,
          203.78099999999998,
          261.24,
          318.923,
          376.80699999999996,
          434.858,
          493.05300000000005,
          551.357,
          609.732,
          668.1439999999999,
          726.548,
          784.895,
          843.1439999999999,
          901.24,
          959.128,
          1010.0830000000001,
          1068.488,
          1126.5919999999999,
          1184.286,
          1241.501,
          1298.163,
          1354.201,
          1409.536,
          1464.088,
          1517.775,
          1570.511,
          1622.201,
          1681.307,
          1731.971,
          1781.3,
          1829.1860000000001,
          1875.5220000000002,
          1920.19,
          1963.0770000000002,
          2004.069,
          2043.049,
          2079.905,
          2114.0029999999997,
          2146.31,
          2176.166,
          2229.474,
          2255.404,
          2278.5460000000003,
          2298.797,
          2316.058,
          2330.238,
          2341.249,
          2349.0029999999997,
          2353.44,
          2354.4970000000003,
          2389.861,
          2385.011,
          2376.616,
          2364.65,
          2349.115,
          2330.011,
          2307.337,
          2281.121,
          2251.55,
          2218.43,
          2227.351,
          2188.045,
          2145.4629999999997,
          2099.7,
          2050.877,
          1999.1029999999998,
          1944.4820000000002,
          1934.433,
          1874.588,
          1812.299,
          1747.729,
          1681.058,
          1612.473,
          1542.155,
          1470.293,
          1397.05,
          1322.61,
          1247.164,
          1214.899,
          1137.5,
          1059.384,
          980.8739999999999,
          902.135,
          823.332,
          744.5880000000001,
          666.041,
          625.484,
          546.742,
          468.524,
          390.94300000000004,
          314.103,
          238.09599999999998,
          163.026,
          88.96700000000001,
          15.998,
          -27.878,
          -99.648,
          -170.15200000000002,
          -239.33599999999998,
          -307.16900000000004,
          -369.369,
          -434.20099999999996,
          -497.584,
          -559.496,
          -619.913,
          -663.11,
          -721.763,
          -778.898,
          -846.5269999999999,
          -888.63,
          -941.2289999999999,
          -992.327,
          -1041.942,
          -1090.075,
          -1131.997,
          -1178.406,
          -1225.747,
          -1266.9,
          -1309.015,
          -1349.7179999999998,
          -1389.024,
          -1427.3270000000002,
          -1463.664,
          -1498.616,
          -1532.191,
          -1564.394,
          -1595.236,
          -1624.725,
          -1652.871,
          -1691.499,
          -1718.003,
          -1729.394,
          -1767.09,
          -1789.7179999999998,
          -1811.094,
          -1831.247,
          -1850.1970000000001,
          -1867.9620000000002,
          -1884.568,
          -1900.037,
          -1914.3829999999998,
          -1927.632,
          -1939.89,
          -1950.866,
          -1985.994,
          -1995.6660000000002,
          -2004.3110000000001,
          -2011.9479999999999,
          -2018.59,
          -2024.261,
          -2028.987,
          -2032.77,
          -2035.635,
          -2037.6070000000002,
          -2038.707,
          -2038.973,
          -2038.442,
          -2037.124,
          -2035.0520000000001,
          -2032.2579999999998,
          -2028.761,
          -2024.596,
          -2019.7920000000001,
          -2014.524,
          -2008.559,
          -2002.011,
          -1994.88,
          -1987.1879999999999,
          -1978.954,
          -2010.493,
          -2001.6429999999998,
          -1992.2910000000002,
          -1982.424,
          -1972.0410000000002,
          -1918.829,
          -1949.757,
          -1937.871,
          -1925.525,
          -1912.704,
          -1899.414,
          -1885.662,
          -1871.4460000000001,
          -1856.776,
          -1841.6570000000002,
          -1826.191,
          -1810.1370000000002,
          -1793.645,
          -1776.7020000000002,
          -1759.318,
          -1741.505,
          -1723.25,
          -1704.565,
          -1685.4589999999998,
          -1665.9229999999998,
          -1645.976,
          -1625.612,
          -1604.836,
          -1583.644,
          -1562.0079999999998,
          -1539.9489999999998,
          -1565.148,
          -1542.299,
          -1519.021,
          -1495.319,
          -1471.18,
          -1446.596,
          -1421.569,
          -1396.079,
          -1370.134,
          -1343.727,
          -1316.85,
          -1289.515,
          -1261.725,
          -1233.472,
          -1204.755,
          -1175.595,
          -1145.975
         ]
        },
        {
         "marker": {
          "color": "blue"
         },
         "mode": "markers",
         "name": "PERI",
         "type": "scatter",
         "x": [
          392.75199999999995,
          398.259,
          403.38,
          408.164,
          412.60400000000004,
          416.624,
          420.316,
          423.645,
          426.52,
          429.06699999999995,
          431.246,
          432.952,
          434.32,
          435.30800000000005,
          526.119,
          435.897,
          435.59,
          535.2919999999999,
          537.436,
          539.141,
          540.271,
          540.984,
          541.24,
          540.928,
          540.161,
          538.928,
          537.107,
          534.7819999999999,
          531.94,
          528.515,
          524.582,
          520.134,
          515.115,
          509.591,
          503.601,
          497.05800000000005,
          489.996,
          482.445,
          474.38300000000004,
          633.5840000000001,
          456.728,
          620.364,
          612.943,
          604.992,
          596.508,
          587.512,
          578.005,
          567.891,
          557.146,
          545.764,
          533.714,
          521,
          507.59,
          493.481,
          478.675,
          463.119,
          446.845,
          429.871,
          412.131,
          600.977,
          582.936,
          564.056,
          544.361,
          523.909,
          502.55400000000003,
          480.407,
          457.49699999999996,
          433.81199999999995,
          409.389,
          384.27,
          358.42800000000005,
          331.949,
          304.878,
          485.82800000000003,
          456.659,
          426.861,
          396.4,
          365.414,
          333.97900000000004,
          302.10200000000003,
          269.892,
          237.493,
          204.893,
          172.27900000000002,
          140.357,
          290.193,
          254.59400000000002,
          219.247,
          184.2,
          149.601,
          115.542,
          82.141,
          49.475,
          17.634,
          128.64,
          93.166,
          58.583999999999996,
          24.962,
          -7.608,
          -38.942,
          -69.043,
          -97.70700000000001,
          -124.85600000000001,
          -150.44899999999998,
          -96.382,
          -125.744,
          -153.51,
          -179.45,
          -203.47,
          -225.604,
          -245.72400000000002,
          -263.76599999999996,
          -279.724,
          -293.55,
          -303.517,
          -320.875,
          -335.978,
          -348.80699999999996,
          -359.348,
          -367.57800000000003,
          -373.55,
          -377.22,
          -378.629,
          -444.577,
          -448.916,
          -450.955,
          -450.773,
          -448.38300000000004,
          -443.86300000000006,
          -437.32800000000003,
          -428.75300000000004,
          -418.241,
          -405.93800000000005,
          -522.982,
          -512.725,
          -500.705,
          -486.93699999999995,
          -471.43,
          -454.42400000000004,
          -435.941,
          -416.056,
          -395.005,
          -545.577,
          -526.06,
          -505.538,
          -484.009,
          -461.49800000000005,
          -438.10699999999997,
          -414.10900000000004,
          -389.5,
          -364.47,
          -537.35,
          -513.499,
          -489.277,
          -464.67800000000005,
          -439.67,
          -414.51199999999994,
          -389.186,
          -363.665,
          -338.17,
          -312.673,
          -497.61,
          -472.73900000000003,
          -447.858,
          -422.981,
          -398.167,
          -373.465,
          -348.881,
          -324.42900000000003,
          -300.224,
          -276.233,
          -252.488,
          -229.02700000000002,
          -205.798,
          -182.882,
          -365.659,
          -342.401,
          -319.349,
          -296.635,
          -274.23900000000003,
          -252.15900000000002,
          -230.454,
          -209.128,
          -188.148,
          -167.593,
          -147.463,
          -127.686,
          -108.34700000000001,
          -89.395,
          -70.923,
          -233.437,
          -213.687,
          -194.283,
          -175.285,
          -156.623,
          -138.279,
          -120.34700000000001,
          -102.723,
          -85.399,
          -68.407,
          -51.751999999999995,
          -35.471,
          -19.652,
          -4.232,
          10.807,
          25.393,
          39.556999999999995,
          53.303000000000004,
          66.592,
          79.461,
          91.912,
          103.885,
          115.465,
          5.683,
          19.444000000000003,
          32.856,
          45.919,
          58.596000000000004,
          70.90899999999999,
          82.941,
          94.675,
          106.101,
          117.236,
          127.99700000000001,
          138.409,
          148.496,
          158.232,
          167.63099999999997,
          176.696,
          185.423,
          193.832,
          201.96,
          209.757,
          217.25,
          224.44400000000002,
          231.328,
          237.91400000000002,
          244.206,
          250.206,
          217.641,
          226.447,
          234.976,
          243.235,
          251.22099999999998,
          258.953,
          266.427,
          273.622,
          280.54,
          287.18,
          293.54,
          299.619,
          305.416,
          310.933,
          316.158,
          321.08799999999997,
          325.721,
          330.05,
          334.07,
          337.776,
          341.162,
          344.218,
          346.94,
          349.33,
          351.37800000000004
         ],
         "y": [
          417.533,
          404.228,
          390.543,
          376.765,
          362.876,
          348.639,
          334.41900000000004,
          320.106,
          305.457,
          290.878,
          276.256,
          261.347,
          246.52200000000002,
          231.675,
          408.463,
          201.49,
          186.395,
          357.98400000000004,
          340.92,
          323.806,
          306.435,
          289.14099999999996,
          271.835,
          254.37099999999998,
          236.94400000000002,
          219.553,
          202.05,
          184.578,
          167.138,
          149.672,
          132.29,
          115.00200000000001,
          97.76899999999999,
          80.681,
          63.783,
          47.011,
          30.415,
          14.034,
          -2.134,
          111.556,
          -33.77,
          73.373,
          54.567,
          35.98,
          17.63,
          -0.45399999999999996,
          -18.259,
          -35.821,
          -53.126999999999995,
          -70.154,
          -86.891,
          -103.303,
          -119.37700000000001,
          -135.078,
          -150.374,
          -165.24599999999998,
          -179.64700000000002,
          -193.533,
          -206.885,
          -176.127,
          -193.472,
          -210.22799999999998,
          -226.345,
          -241.735,
          -256.432,
          -270.344,
          -283.418,
          -295.60400000000004,
          -306.847,
          -317.091,
          -326.281,
          -334.361,
          -341.277,
          -381.926,
          -392.441,
          -401.668,
          -409.53,
          -415.98400000000004,
          -420.981,
          -424.449,
          -426.346,
          -426.652,
          -425.288,
          -422.25800000000004,
          -417.44800000000004,
          -518.3380000000001,
          -516.196,
          -512.325,
          -506.685,
          -499.306,
          -490.191,
          -479.36800000000005,
          -466.834,
          -452.6,
          -593.253,
          -580.703,
          -566.367,
          -550.231,
          -532.304,
          -512.747,
          -491.44599999999997,
          -468.631,
          -444.35,
          -418.57099999999997,
          -587.944,
          -562.649,
          -535.727,
          -507.55800000000005,
          -478.366,
          -447.846,
          -416.348,
          -384.12699999999995,
          -351,
          -316.976,
          -494.11199999999997,
          -459.12699999999995,
          -423.398,
          -387.215,
          -350.67800000000005,
          -313.816,
          -277.029,
          -240.135,
          -203.37599999999998,
          -367.958,
          -329.584,
          -291.369,
          -253.68599999999998,
          -216.31,
          -179.535,
          -143.556,
          -108.304,
          -73.938,
          -40.634,
          -174.649,
          -138.974,
          -104.40100000000001,
          -70.921,
          -38.527,
          -7.434,
          22.37,
          50.852,
          77.858,
          -18.658,
          10.819,
          38.766,
          65.235,
          90.25299999999999,
          112.73,
          134.681,
          155.12,
          174.019,
          118.46799999999999,
          140.034,
          160.124,
          178.78400000000002,
          196.067,
          211.947,
          226.47299999999998,
          239.692,
          251.606,
          262.263,
          252.972,
          266.545,
          278.92400000000004,
          290.14099999999996,
          300.23,
          309.22,
          317.145,
          324.11400000000003,
          329.958,
          334.82800000000003,
          338.756,
          341.775,
          343.9,
          345.17199999999997,
          395.56699999999995,
          399.77099999999996,
          403.126,
          405.69199999999995,
          407.48900000000003,
          408.539,
          408.884,
          408.55,
          407.548,
          405.931,
          403.724,
          400.914,
          397.56300000000005,
          393.665,
          389.30199999999996,
          494.06699999999995,
          492.23699999999997,
          489.875,
          487.036,
          483.689,
          479.835,
          475.55199999999996,
          470.778,
          465.51300000000003,
          459.792,
          453.626,
          447.059,
          440.18699999999995,
          432.97,
          425.403,
          417.575,
          409.473,
          401.11,
          392.551,
          383.77099999999996,
          374.86300000000006,
          365.79900000000004,
          356.537,
          520.57,
          513.076,
          505.344,
          497.395,
          489.301,
          481.04699999999997,
          472.504,
          463.705,
          454.671,
          445.38199999999995,
          436.00800000000004,
          426.52099999999996,
          416.88199999999995,
          407.167,
          397.36400000000003,
          387.47900000000004,
          377.54699999999997,
          367.531,
          357.425,
          347.221,
          336.935,
          326.57,
          316.168,
          305.70799999999997,
          295.195,
          284.628,
          482.066,
          472,
          461.842,
          451.56,
          441.18199999999996,
          430.54699999999997,
          419.63800000000003,
          408.62699999999995,
          397.48400000000004,
          386.223,
          374.844,
          363.36699999999996,
          351.751,
          340.01,
          328.14,
          316.137,
          304.012,
          291.736,
          279.318,
          266.774,
          254.09799999999998,
          241.27700000000002,
          228.322,
          215.291,
          202.149
         ]
        }
       ],
       "layout": {
        "shapes": [
         {
          "fillcolor": "orange",
          "layer": "below",
          "type": "circle",
          "x0": -2400,
          "x1": 2400,
          "xref": "x",
          "y0": -2400,
          "y1": 2400,
          "yref": "y"
         }
        ],
        "template": {
         "data": {
          "bar": [
           {
            "error_x": {
             "color": "#2a3f5f"
            },
            "error_y": {
             "color": "#2a3f5f"
            },
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "bar"
           }
          ],
          "barpolar": [
           {
            "marker": {
             "line": {
              "color": "#E5ECF6",
              "width": 0.5
             }
            },
            "type": "barpolar"
           }
          ],
          "carpet": [
           {
            "aaxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "baxis": {
             "endlinecolor": "#2a3f5f",
             "gridcolor": "white",
             "linecolor": "white",
             "minorgridcolor": "white",
             "startlinecolor": "#2a3f5f"
            },
            "type": "carpet"
           }
          ],
          "choropleth": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "choropleth"
           }
          ],
          "contour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "contour"
           }
          ],
          "contourcarpet": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "contourcarpet"
           }
          ],
          "heatmap": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmap"
           }
          ],
          "heatmapgl": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "heatmapgl"
           }
          ],
          "histogram": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "histogram"
           }
          ],
          "histogram2d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2d"
           }
          ],
          "histogram2dcontour": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "histogram2dcontour"
           }
          ],
          "mesh3d": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "type": "mesh3d"
           }
          ],
          "parcoords": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "parcoords"
           }
          ],
          "pie": [
           {
            "automargin": true,
            "type": "pie"
           }
          ],
          "scatter": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter"
           }
          ],
          "scatter3d": [
           {
            "line": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatter3d"
           }
          ],
          "scattercarpet": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattercarpet"
           }
          ],
          "scattergeo": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergeo"
           }
          ],
          "scattergl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattergl"
           }
          ],
          "scattermapbox": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scattermapbox"
           }
          ],
          "scatterpolar": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolar"
           }
          ],
          "scatterpolargl": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterpolargl"
           }
          ],
          "scatterternary": [
           {
            "marker": {
             "colorbar": {
              "outlinewidth": 0,
              "ticks": ""
             }
            },
            "type": "scatterternary"
           }
          ],
          "surface": [
           {
            "colorbar": {
             "outlinewidth": 0,
             "ticks": ""
            },
            "colorscale": [
             [
              0,
              "#0d0887"
             ],
             [
              0.1111111111111111,
              "#46039f"
             ],
             [
              0.2222222222222222,
              "#7201a8"
             ],
             [
              0.3333333333333333,
              "#9c179e"
             ],
             [
              0.4444444444444444,
              "#bd3786"
             ],
             [
              0.5555555555555556,
              "#d8576b"
             ],
             [
              0.6666666666666666,
              "#ed7953"
             ],
             [
              0.7777777777777778,
              "#fb9f3a"
             ],
             [
              0.8888888888888888,
              "#fdca26"
             ],
             [
              1,
              "#f0f921"
             ]
            ],
            "type": "surface"
           }
          ],
          "table": [
           {
            "cells": {
             "fill": {
              "color": "#EBF0F8"
             },
             "line": {
              "color": "white"
             }
            },
            "header": {
             "fill": {
              "color": "#C8D4E3"
             },
             "line": {
              "color": "white"
             }
            },
            "type": "table"
           }
          ]
         },
         "layout": {
          "annotationdefaults": {
           "arrowcolor": "#2a3f5f",
           "arrowhead": 0,
           "arrowwidth": 1
          },
          "autotypenumbers": "strict",
          "coloraxis": {
           "colorbar": {
            "outlinewidth": 0,
            "ticks": ""
           }
          },
          "colorscale": {
           "diverging": [
            [
             0,
             "#8e0152"
            ],
            [
             0.1,
             "#c51b7d"
            ],
            [
             0.2,
             "#de77ae"
            ],
            [
             0.3,
             "#f1b6da"
            ],
            [
             0.4,
             "#fde0ef"
            ],
            [
             0.5,
             "#f7f7f7"
            ],
            [
             0.6,
             "#e6f5d0"
            ],
            [
             0.7,
             "#b8e186"
            ],
            [
             0.8,
             "#7fbc41"
            ],
            [
             0.9,
             "#4d9221"
            ],
            [
             1,
             "#276419"
            ]
           ],
           "sequential": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ],
           "sequentialminus": [
            [
             0,
             "#0d0887"
            ],
            [
             0.1111111111111111,
             "#46039f"
            ],
            [
             0.2222222222222222,
             "#7201a8"
            ],
            [
             0.3333333333333333,
             "#9c179e"
            ],
            [
             0.4444444444444444,
             "#bd3786"
            ],
            [
             0.5555555555555556,
             "#d8576b"
            ],
            [
             0.6666666666666666,
             "#ed7953"
            ],
            [
             0.7777777777777778,
             "#fb9f3a"
            ],
            [
             0.8888888888888888,
             "#fdca26"
            ],
            [
             1,
             "#f0f921"
            ]
           ]
          },
          "colorway": [
           "#636efa",
           "#EF553B",
           "#00cc96",
           "#ab63fa",
           "#FFA15A",
           "#19d3f3",
           "#FF6692",
           "#B6E880",
           "#FF97FF",
           "#FECB52"
          ],
          "font": {
           "color": "#2a3f5f"
          },
          "geo": {
           "bgcolor": "white",
           "lakecolor": "white",
           "landcolor": "#E5ECF6",
           "showlakes": true,
           "showland": true,
           "subunitcolor": "white"
          },
          "hoverlabel": {
           "align": "left"
          },
          "hovermode": "closest",
          "mapbox": {
           "style": "light"
          },
          "paper_bgcolor": "white",
          "plot_bgcolor": "#E5ECF6",
          "polar": {
           "angularaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "radialaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "scene": {
           "xaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "yaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           },
           "zaxis": {
            "backgroundcolor": "#E5ECF6",
            "gridcolor": "white",
            "gridwidth": 2,
            "linecolor": "white",
            "showbackground": true,
            "ticks": "",
            "zerolinecolor": "white"
           }
          },
          "shapedefaults": {
           "line": {
            "color": "#2a3f5f"
           }
          },
          "ternary": {
           "aaxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "baxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           },
           "bgcolor": "#E5ECF6",
           "caxis": {
            "gridcolor": "white",
            "linecolor": "white",
            "ticks": ""
           }
          },
          "title": {
           "x": 0.05
          },
          "xaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          },
          "yaxis": {
           "automargin": true,
           "gridcolor": "white",
           "linecolor": "white",
           "ticks": "",
           "title": {
            "standoff": 15
           },
           "zerolinecolor": "white",
           "zerolinewidth": 2
          }
         }
        },
        "title": {
         "text": "$\\text{Проекция апсидов орбиты КА MESSENGER на плоскость XY (2012-07-19 - 2012-10-14). }$",
         "x": 0.5,
         "xanchor": "center"
        },
        "xaxis": {
         "title": {
          "text": "MSO X [км]"
         }
        },
        "yaxis": {
         "scaleanchor": "x",
         "scaleratio": 1,
         "title": {
          "text": "MSO Y [км]"
         }
        }
       }
      },
      "text/html": [
       "<div>                            <div id=\"bfeb13e5-3f44-4ebc-bd04-9a2c804fdd7f\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"bfeb13e5-3f44-4ebc-bd04-9a2c804fdd7f\")) {                    Plotly.newPlot(                        \"bfeb13e5-3f44-4ebc-bd04-9a2c804fdd7f\",                        [{\"marker\": {\"color\": \"red\"}, \"mode\": \"markers\", \"name\": \"APO\", \"type\": \"scatter\", \"x\": [-1779.8110000000001, -1812.2220000000002, -1844.067, -1875.319, -1905.974, -1936.014, -1965.4189999999999, -1994.185, -2022.2939999999999, -2049.728, -2076.486, -2102.547, -2127.894, -2152.522, -2176.41, -2199.526, -2221.873, -2243.429, -2286.734, -2284.078, -2327.194, -2321.349, -2338.677, -2381.3360000000002, -2370.665, -2412.956, -2427.395, -2440.891, -2453.448, -2465.058, -2475.705, -2485.388, -2494.098, -2501.819, -2508.564, -2514.304, -2519.019, -2522.706, -2525.347, -2526.915, -2527.403, -2526.7889999999998, -2563.644, -2561.29, -2557.736, -2552.956, -2546.931, -2539.609, -2530.944, -2520.905, -2509.446, -2496.529, -2482.123, -2466.181, -2448.667, -2429.547, -2408.777, -2386.33, -2362.173, -2336.263, -2308.5860000000002, -2279.106, -2294.3579999999997, -2261.466, -2226.603, -2189.797, -2151.019, -2110.254, -2067.478, -2022.6779999999999, -1975.8410000000001, -1926.9460000000001, -1875.9920000000002, -1822.965, -1814.194, -1756.76, -1697.204, -1635.539, -1571.7879999999998, -1505.9720000000002, -1438.125, -1368.297, -1296.536, -1222.899, -1149.98, -1072.869, -994.1080000000001, -953.2139999999999, -870.582, -786.549, -701.235, -614.757, -527.248, -438.843, -349.685, -259.93, -169.74099999999999, -107.727, -15.817, 76.055, 167.71, 258.96, 349.62, 439.50800000000004, 528.436, 615.9, 702.322, 774.003, 858.8710000000001, 941.883, 1022.8660000000001, 1101.657, 1178.105, 1252.0610000000001, 1322.244, 1392.5629999999999, 1460.005, 1524.4620000000002, 1585.8429999999998, 1644.0720000000001, 1699.0870000000002, 1750.838, 1799.2879999999998, 1844.415, 1886.2120000000002, 1942.082, 1978.612, 2011.9620000000002, 2041.9879999999998, 2068.737, 2092.262, 2112.61, 2129.84, 2172.803, 2185.259, 2194.7670000000003, 2201.406, 2205.264, 2206.4210000000003, 2204.984, 2201.04, 2194.69, 2224.41, 2214.396, 2202.234, 2188.027, 2171.863, 2152.939, 2133.195, 2111.7729999999997, 2088.763, 2064.258, 2083.189, 2056.365, 2028.256, 1952.9129999999998, 1968.477, 1936.954, 1904.43, 1870.97, 1836.632, 1848.806, 1812.977, 1728.852, 1739.0710000000001, 1701.067, 1662.4070000000002, 1623.126, 1583.29, 1542.828, 1501.879, 1460.467, 1418.629, 1376.3770000000002, 1333.763, 1290.835, 1293.796, 1250.093, 1160.538, 1162.077, 1117.8519999999999, 1073.5339999999999, 1029.1589999999999, 984.7589999999999, 940.3580000000001, 895.9860000000001, 851.672, 807.436, 763.301, 719.2310000000001, 675.42, 672.2660000000001, 628.2959999999999, 584.518, 540.945, 497.589, 454.481, 411.639, 369.06300000000005, 326.778, 284.803, 243.157, 201.87400000000002, 160.971, 120.45, 80.332, 40.626, 1.341, -37.515, -75.935, -114.014, -151.594, -188.732, -225.442, -261.723, -297.57599999999996, -307.415, -343.11300000000006, -378.399, -413.292, -447.805, -504.075, -515.705, -549.0980000000001, -582.117, -614.7719999999999, -647.064, -678.995, -710.571, -741.791, -772.6569999999999, -803.243, -833.426, -863.2560000000001, -892.7360000000001, -921.865, -950.64, -979.063, -1007.13, -1034.84, -1062.194, -1089.188, -1115.823, -1142.097, -1168.013, -1193.5739999999998, -1218.768, -1240.723, -1265.954, -1290.817, -1315.308, -1339.425, -1363.1629999999998, -1386.514, -1409.464, -1432.005, -1454.1270000000002, -1475.817, -1497.067, -1517.866, -1538.201, -1558.059, -1577.43, -1596.2979999999998], \"y\": [-1985.2479999999998, -1951.8529999999998, -1917.721, -1882.839, -1847.265, -1810.994, -1774.0279999999998, -1736.412, -1698.134, -1659.194, -1619.636, -1579.442, -1538.6070000000002, -1497.172, -1455.118, -1412.421, -1369.136, -1325.253, -1321.7320000000002, -1235.702, -1230.238, -1143.948, -1097.401, -1089.1480000000001, -1002.813, -992.6310000000001, -943.68, -894.262, -844.42, -794.169, -743.507, -692.465, -641.057, -589.283, -537.182, -484.73900000000003, -431.957, -378.856, -325.441, -271.711, -217.685, -163.368, -135.391, -79.58800000000001, -23.479, 32.929, 89.60799999999999, 146.562, 203.78099999999998, 261.24, 318.923, 376.80699999999996, 434.858, 493.05300000000005, 551.357, 609.732, 668.1439999999999, 726.548, 784.895, 843.1439999999999, 901.24, 959.128, 1010.0830000000001, 1068.488, 1126.5919999999999, 1184.286, 1241.501, 1298.163, 1354.201, 1409.536, 1464.088, 1517.775, 1570.511, 1622.201, 1681.307, 1731.971, 1781.3, 1829.1860000000001, 1875.5220000000002, 1920.19, 1963.0770000000002, 2004.069, 2043.049, 2079.905, 2114.0029999999997, 2146.31, 2176.166, 2229.474, 2255.404, 2278.5460000000003, 2298.797, 2316.058, 2330.238, 2341.249, 2349.0029999999997, 2353.44, 2354.4970000000003, 2389.861, 2385.011, 2376.616, 2364.65, 2349.115, 2330.011, 2307.337, 2281.121, 2251.55, 2218.43, 2227.351, 2188.045, 2145.4629999999997, 2099.7, 2050.877, 1999.1029999999998, 1944.4820000000002, 1934.433, 1874.588, 1812.299, 1747.729, 1681.058, 1612.473, 1542.155, 1470.293, 1397.05, 1322.61, 1247.164, 1214.899, 1137.5, 1059.384, 980.8739999999999, 902.135, 823.332, 744.5880000000001, 666.041, 625.484, 546.742, 468.524, 390.94300000000004, 314.103, 238.09599999999998, 163.026, 88.96700000000001, 15.998, -27.878, -99.648, -170.15200000000002, -239.33599999999998, -307.16900000000004, -369.369, -434.20099999999996, -497.584, -559.496, -619.913, -663.11, -721.763, -778.898, -846.5269999999999, -888.63, -941.2289999999999, -992.327, -1041.942, -1090.075, -1131.997, -1178.406, -1225.747, -1266.9, -1309.015, -1349.7179999999998, -1389.024, -1427.3270000000002, -1463.664, -1498.616, -1532.191, -1564.394, -1595.236, -1624.725, -1652.871, -1691.499, -1718.003, -1729.394, -1767.09, -1789.7179999999998, -1811.094, -1831.247, -1850.1970000000001, -1867.9620000000002, -1884.568, -1900.037, -1914.3829999999998, -1927.632, -1939.89, -1950.866, -1985.994, -1995.6660000000002, -2004.3110000000001, -2011.9479999999999, -2018.59, -2024.261, -2028.987, -2032.77, -2035.635, -2037.6070000000002, -2038.707, -2038.973, -2038.442, -2037.124, -2035.0520000000001, -2032.2579999999998, -2028.761, -2024.596, -2019.7920000000001, -2014.524, -2008.559, -2002.011, -1994.88, -1987.1879999999999, -1978.954, -2010.493, -2001.6429999999998, -1992.2910000000002, -1982.424, -1972.0410000000002, -1918.829, -1949.757, -1937.871, -1925.525, -1912.704, -1899.414, -1885.662, -1871.4460000000001, -1856.776, -1841.6570000000002, -1826.191, -1810.1370000000002, -1793.645, -1776.7020000000002, -1759.318, -1741.505, -1723.25, -1704.565, -1685.4589999999998, -1665.9229999999998, -1645.976, -1625.612, -1604.836, -1583.644, -1562.0079999999998, -1539.9489999999998, -1565.148, -1542.299, -1519.021, -1495.319, -1471.18, -1446.596, -1421.569, -1396.079, -1370.134, -1343.727, -1316.85, -1289.515, -1261.725, -1233.472, -1204.755, -1175.595, -1145.975]}, {\"marker\": {\"color\": \"blue\"}, \"mode\": \"markers\", \"name\": \"PERI\", \"type\": \"scatter\", \"x\": [392.75199999999995, 398.259, 403.38, 408.164, 412.60400000000004, 416.624, 420.316, 423.645, 426.52, 429.06699999999995, 431.246, 432.952, 434.32, 435.30800000000005, 526.119, 435.897, 435.59, 535.2919999999999, 537.436, 539.141, 540.271, 540.984, 541.24, 540.928, 540.161, 538.928, 537.107, 534.7819999999999, 531.94, 528.515, 524.582, 520.134, 515.115, 509.591, 503.601, 497.05800000000005, 489.996, 482.445, 474.38300000000004, 633.5840000000001, 456.728, 620.364, 612.943, 604.992, 596.508, 587.512, 578.005, 567.891, 557.146, 545.764, 533.714, 521.0, 507.59, 493.481, 478.675, 463.119, 446.845, 429.871, 412.131, 600.977, 582.936, 564.056, 544.361, 523.909, 502.55400000000003, 480.407, 457.49699999999996, 433.81199999999995, 409.389, 384.27, 358.42800000000005, 331.949, 304.878, 485.82800000000003, 456.659, 426.861, 396.4, 365.414, 333.97900000000004, 302.10200000000003, 269.892, 237.493, 204.893, 172.27900000000002, 140.357, 290.193, 254.59400000000002, 219.247, 184.2, 149.601, 115.542, 82.141, 49.475, 17.634, 128.64, 93.166, 58.583999999999996, 24.962, -7.608, -38.942, -69.043, -97.70700000000001, -124.85600000000001, -150.44899999999998, -96.382, -125.744, -153.51, -179.45, -203.47, -225.604, -245.72400000000002, -263.76599999999996, -279.724, -293.55, -303.517, -320.875, -335.978, -348.80699999999996, -359.348, -367.57800000000003, -373.55, -377.22, -378.629, -444.577, -448.916, -450.955, -450.773, -448.38300000000004, -443.86300000000006, -437.32800000000003, -428.75300000000004, -418.241, -405.93800000000005, -522.982, -512.725, -500.705, -486.93699999999995, -471.43, -454.42400000000004, -435.941, -416.056, -395.005, -545.577, -526.06, -505.538, -484.009, -461.49800000000005, -438.10699999999997, -414.10900000000004, -389.5, -364.47, -537.35, -513.499, -489.277, -464.67800000000005, -439.67, -414.51199999999994, -389.186, -363.665, -338.17, -312.673, -497.61, -472.73900000000003, -447.858, -422.981, -398.167, -373.465, -348.881, -324.42900000000003, -300.224, -276.233, -252.488, -229.02700000000002, -205.798, -182.882, -365.659, -342.401, -319.349, -296.635, -274.23900000000003, -252.15900000000002, -230.454, -209.128, -188.148, -167.593, -147.463, -127.686, -108.34700000000001, -89.395, -70.923, -233.437, -213.687, -194.283, -175.285, -156.623, -138.279, -120.34700000000001, -102.723, -85.399, -68.407, -51.751999999999995, -35.471, -19.652, -4.232, 10.807, 25.393, 39.556999999999995, 53.303000000000004, 66.592, 79.461, 91.912, 103.885, 115.465, 5.683, 19.444000000000003, 32.856, 45.919, 58.596000000000004, 70.90899999999999, 82.941, 94.675, 106.101, 117.236, 127.99700000000001, 138.409, 148.496, 158.232, 167.63099999999997, 176.696, 185.423, 193.832, 201.96, 209.757, 217.25, 224.44400000000002, 231.328, 237.91400000000002, 244.206, 250.206, 217.641, 226.447, 234.976, 243.235, 251.22099999999998, 258.953, 266.427, 273.622, 280.54, 287.18, 293.54, 299.619, 305.416, 310.933, 316.158, 321.08799999999997, 325.721, 330.05, 334.07, 337.776, 341.162, 344.218, 346.94, 349.33, 351.37800000000004], \"y\": [417.533, 404.228, 390.543, 376.765, 362.876, 348.639, 334.41900000000004, 320.106, 305.457, 290.878, 276.256, 261.347, 246.52200000000002, 231.675, 408.463, 201.49, 186.395, 357.98400000000004, 340.92, 323.806, 306.435, 289.14099999999996, 271.835, 254.37099999999998, 236.94400000000002, 219.553, 202.05, 184.578, 167.138, 149.672, 132.29, 115.00200000000001, 97.76899999999999, 80.681, 63.783, 47.011, 30.415, 14.034, -2.134, 111.556, -33.77, 73.373, 54.567, 35.98, 17.63, -0.45399999999999996, -18.259, -35.821, -53.126999999999995, -70.154, -86.891, -103.303, -119.37700000000001, -135.078, -150.374, -165.24599999999998, -179.64700000000002, -193.533, -206.885, -176.127, -193.472, -210.22799999999998, -226.345, -241.735, -256.432, -270.344, -283.418, -295.60400000000004, -306.847, -317.091, -326.281, -334.361, -341.277, -381.926, -392.441, -401.668, -409.53, -415.98400000000004, -420.981, -424.449, -426.346, -426.652, -425.288, -422.25800000000004, -417.44800000000004, -518.3380000000001, -516.196, -512.325, -506.685, -499.306, -490.191, -479.36800000000005, -466.834, -452.6, -593.253, -580.703, -566.367, -550.231, -532.304, -512.747, -491.44599999999997, -468.631, -444.35, -418.57099999999997, -587.944, -562.649, -535.727, -507.55800000000005, -478.366, -447.846, -416.348, -384.12699999999995, -351.0, -316.976, -494.11199999999997, -459.12699999999995, -423.398, -387.215, -350.67800000000005, -313.816, -277.029, -240.135, -203.37599999999998, -367.958, -329.584, -291.369, -253.68599999999998, -216.31, -179.535, -143.556, -108.304, -73.938, -40.634, -174.649, -138.974, -104.40100000000001, -70.921, -38.527, -7.434, 22.37, 50.852, 77.858, -18.658, 10.819, 38.766, 65.235, 90.25299999999999, 112.73, 134.681, 155.12, 174.019, 118.46799999999999, 140.034, 160.124, 178.78400000000002, 196.067, 211.947, 226.47299999999998, 239.692, 251.606, 262.263, 252.972, 266.545, 278.92400000000004, 290.14099999999996, 300.23, 309.22, 317.145, 324.11400000000003, 329.958, 334.82800000000003, 338.756, 341.775, 343.9, 345.17199999999997, 395.56699999999995, 399.77099999999996, 403.126, 405.69199999999995, 407.48900000000003, 408.539, 408.884, 408.55, 407.548, 405.931, 403.724, 400.914, 397.56300000000005, 393.665, 389.30199999999996, 494.06699999999995, 492.23699999999997, 489.875, 487.036, 483.689, 479.835, 475.55199999999996, 470.778, 465.51300000000003, 459.792, 453.626, 447.059, 440.18699999999995, 432.97, 425.403, 417.575, 409.473, 401.11, 392.551, 383.77099999999996, 374.86300000000006, 365.79900000000004, 356.537, 520.57, 513.076, 505.344, 497.395, 489.301, 481.04699999999997, 472.504, 463.705, 454.671, 445.38199999999995, 436.00800000000004, 426.52099999999996, 416.88199999999995, 407.167, 397.36400000000003, 387.47900000000004, 377.54699999999997, 367.531, 357.425, 347.221, 336.935, 326.57, 316.168, 305.70799999999997, 295.195, 284.628, 482.066, 472.0, 461.842, 451.56, 441.18199999999996, 430.54699999999997, 419.63800000000003, 408.62699999999995, 397.48400000000004, 386.223, 374.844, 363.36699999999996, 351.751, 340.01, 328.14, 316.137, 304.012, 291.736, 279.318, 266.774, 254.09799999999998, 241.27700000000002, 228.322, 215.291, 202.149]}],                        {\"shapes\": [{\"fillcolor\": \"orange\", \"layer\": \"below\", \"type\": \"circle\", \"x0\": -2400, \"x1\": 2400, \"xref\": \"x\", \"y0\": -2400, \"y1\": 2400, \"yref\": \"y\"}], \"template\": {\"data\": {\"bar\": [{\"error_x\": {\"color\": \"#2a3f5f\"}, \"error_y\": {\"color\": \"#2a3f5f\"}, \"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"bar\"}], \"barpolar\": [{\"marker\": {\"line\": {\"color\": \"#E5ECF6\", \"width\": 0.5}}, \"type\": \"barpolar\"}], \"carpet\": [{\"aaxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"baxis\": {\"endlinecolor\": \"#2a3f5f\", \"gridcolor\": \"white\", \"linecolor\": \"white\", \"minorgridcolor\": \"white\", \"startlinecolor\": \"#2a3f5f\"}, \"type\": \"carpet\"}], \"choropleth\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"choropleth\"}], \"contour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"contour\"}], \"contourcarpet\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"contourcarpet\"}], \"heatmap\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmap\"}], \"heatmapgl\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"heatmapgl\"}], \"histogram\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"histogram\"}], \"histogram2d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2d\"}], \"histogram2dcontour\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"histogram2dcontour\"}], \"mesh3d\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"type\": \"mesh3d\"}], \"parcoords\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"parcoords\"}], \"pie\": [{\"automargin\": true, \"type\": \"pie\"}], \"scatter\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter\"}], \"scatter3d\": [{\"line\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatter3d\"}], \"scattercarpet\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattercarpet\"}], \"scattergeo\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergeo\"}], \"scattergl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattergl\"}], \"scattermapbox\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scattermapbox\"}], \"scatterpolar\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolar\"}], \"scatterpolargl\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterpolargl\"}], \"scatterternary\": [{\"marker\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"type\": \"scatterternary\"}], \"surface\": [{\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}, \"colorscale\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"type\": \"surface\"}], \"table\": [{\"cells\": {\"fill\": {\"color\": \"#EBF0F8\"}, \"line\": {\"color\": \"white\"}}, \"header\": {\"fill\": {\"color\": \"#C8D4E3\"}, \"line\": {\"color\": \"white\"}}, \"type\": \"table\"}]}, \"layout\": {\"annotationdefaults\": {\"arrowcolor\": \"#2a3f5f\", \"arrowhead\": 0, \"arrowwidth\": 1}, \"autotypenumbers\": \"strict\", \"coloraxis\": {\"colorbar\": {\"outlinewidth\": 0, \"ticks\": \"\"}}, \"colorscale\": {\"diverging\": [[0, \"#8e0152\"], [0.1, \"#c51b7d\"], [0.2, \"#de77ae\"], [0.3, \"#f1b6da\"], [0.4, \"#fde0ef\"], [0.5, \"#f7f7f7\"], [0.6, \"#e6f5d0\"], [0.7, \"#b8e186\"], [0.8, \"#7fbc41\"], [0.9, \"#4d9221\"], [1, \"#276419\"]], \"sequential\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]], \"sequentialminus\": [[0.0, \"#0d0887\"], [0.1111111111111111, \"#46039f\"], [0.2222222222222222, \"#7201a8\"], [0.3333333333333333, \"#9c179e\"], [0.4444444444444444, \"#bd3786\"], [0.5555555555555556, \"#d8576b\"], [0.6666666666666666, \"#ed7953\"], [0.7777777777777778, \"#fb9f3a\"], [0.8888888888888888, \"#fdca26\"], [1.0, \"#f0f921\"]]}, \"colorway\": [\"#636efa\", \"#EF553B\", \"#00cc96\", \"#ab63fa\", \"#FFA15A\", \"#19d3f3\", \"#FF6692\", \"#B6E880\", \"#FF97FF\", \"#FECB52\"], \"font\": {\"color\": \"#2a3f5f\"}, \"geo\": {\"bgcolor\": \"white\", \"lakecolor\": \"white\", \"landcolor\": \"#E5ECF6\", \"showlakes\": true, \"showland\": true, \"subunitcolor\": \"white\"}, \"hoverlabel\": {\"align\": \"left\"}, \"hovermode\": \"closest\", \"mapbox\": {\"style\": \"light\"}, \"paper_bgcolor\": \"white\", \"plot_bgcolor\": \"#E5ECF6\", \"polar\": {\"angularaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"radialaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"scene\": {\"xaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"yaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}, \"zaxis\": {\"backgroundcolor\": \"#E5ECF6\", \"gridcolor\": \"white\", \"gridwidth\": 2, \"linecolor\": \"white\", \"showbackground\": true, \"ticks\": \"\", \"zerolinecolor\": \"white\"}}, \"shapedefaults\": {\"line\": {\"color\": \"#2a3f5f\"}}, \"ternary\": {\"aaxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"baxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}, \"bgcolor\": \"#E5ECF6\", \"caxis\": {\"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\"}}, \"title\": {\"x\": 0.05}, \"xaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}, \"yaxis\": {\"automargin\": true, \"gridcolor\": \"white\", \"linecolor\": \"white\", \"ticks\": \"\", \"title\": {\"standoff\": 15}, \"zerolinecolor\": \"white\", \"zerolinewidth\": 2}}}, \"title\": {\"text\": \"$\\\\text{\\u041f\\u0440\\u043e\\u0435\\u043a\\u0446\\u0438\\u044f \\u0430\\u043f\\u0441\\u0438\\u0434\\u043e\\u0432 \\u043e\\u0440\\u0431\\u0438\\u0442\\u044b \\u041a\\u0410 MESSENGER \\u043d\\u0430 \\u043f\\u043b\\u043e\\u0441\\u043a\\u043e\\u0441\\u0442\\u044c XY (2012-07-19 - 2012-10-14). }$\", \"x\": 0.5, \"xanchor\": \"center\"}, \"xaxis\": {\"title\": {\"text\": \"MSO X [\\u043a\\u043c]\"}}, \"yaxis\": {\"scaleanchor\": \"x\", \"scaleratio\": 1, \"title\": {\"text\": \"MSO Y [\\u043a\\u043c]\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('bfeb13e5-3f44-4ebc-bd04-9a2c804fdd7f');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def show_periapo(symbol=\"\", first=0, last=None):\n",
    "    nodes, apoapsis, periapsis = find_nodes(data)\n",
    "    \n",
    "    fig = go.Figure()\n",
    "    \n",
    "    xy = [[0, 0]]\n",
    "    r = 2400\n",
    "    kwargs = {'type': 'circle', 'xref': 'x', 'yref': 'y', 'fillcolor': 'orange', 'layer': 'below'}\n",
    "    points = [go.layout.Shape(x0=-r, y0=-r, x1=r, y1=r, **kwargs)]\n",
    "    fig.update_layout(shapes=points)\n",
    "\n",
    "    frag = data.iloc[apoapsis][first:last]\n",
    "    fig.add_trace(go.Scatter(\n",
    "        x=frag.X_MSO.values,\n",
    "        y=frag.Y_MSO.values,\n",
    "        name=\"APO\",\n",
    "        mode=\"markers\", marker={'color':'red'}\n",
    "    ))\n",
    "    \n",
    "    \n",
    "    frag = data.iloc[periapsis][first:last]\n",
    "    fig.add_trace(go.Scatter(\n",
    "        x=frag.X_MSO.values,\n",
    "        y=frag.Y_MSO.values,\n",
    "        name=\"PERI\",\n",
    "        mode=\"markers\", marker={'color':'blue'}\n",
    "    ))\n",
    "    \n",
    "    fig.update_layout(\n",
    "        title=go.layout.Title(\n",
    "            text=r\"$\\text{{Проекция апсидов орбиты КА MESSENGER на плоскость XY ({:%Y-%m-%d} - {:%Y-%m-%d}). }}$\".format(\n",
    "                min(data.index), max(data.index)\n",
    "            ), x=0.5, xanchor='center'),\n",
    "        xaxis=go.layout.XAxis(title=go.layout.xaxis.Title(text=r\"MSO\" + symbol + \" X [км]\")),\n",
    "        yaxis=go.layout.YAxis(\n",
    "            title=go.layout.yaxis.Title(text=r\"MSO\" + symbol + \" Y [км]\"),\n",
    "            scaleanchor=\"x\",\n",
    "            scaleratio=1\n",
    "        ),\n",
    "    )\n",
    "    fig.show()\n",
    "    \n",
    "    #plt.xlabel()\n",
    "    #plt.ylabel(r\"MSO\" + symbol + \" Y [км]\")\n",
    "    #plt.legend();\n",
    "    \n",
    "show_periapo()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We need to rotate the coordinate system in order to acknowledge the fact that Mercury's own velocity is about 10% of solar wind velocity and is directed normally to MSO X axis. Solar wind velocity is taken constant at this time."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# The distribution of solar wind speeds during solar minimum: Calibration for numerical solar wind modeling constraints on the source of the slow solar wind\n",
    "# S. L. McGregor  W. J. Hughes  C. N. Arge  M. J. Owens  D. Odstrcil\n",
    "# https://doi.org/10.1029/2010JA015881\n",
    "    \n",
    "sw_velocity = 350 # km/s\n",
    "# TODO: this is a crude approximation; investigate ways to improve it\n",
    "\n",
    "def rotation_matrix(theta):\n",
    "    c, s = np.cos(theta.values), np.sin(theta.values)\n",
    "    np.ndarray(shape=(c.shape[0], 3, 3), dtype=float, order='F')\n",
    "    R = np.vstack([[c, -s, [0]*c.shape[0]],\n",
    "                   [s, c, [0]*c.shape[0]],\n",
    "                   [[0]*c.shape[0], [0]*c.shape[0], [1]*c.shape[0]]\n",
    "                  ])\n",
    "    return R\n",
    "\n",
    "def aberrate(data, sw_velocity):\n",
    "    data = data.copy(True)\n",
    "    data['ABERRATION_ANGLE'] = -np.arctan2(sw_velocity, data.VABS)\n",
    "    rot = rotation_matrix(data['ABERRATION_ANGLE'][:data.shape[0]]).reshape(3, 3, data.shape[0]).transpose(2,0,1)\n",
    "\n",
    "    triads = [\n",
    "        ['X_MSO', 'Y_MSO', 'Z_MSO'],\n",
    "        ['BX_MSO', 'BY_MSO', 'BZ_MSO'],\n",
    "        ['DBX_MSO', 'DBY_MSO', 'DBZ_MSO']\n",
    "    ]\n",
    "\n",
    "    for t in triads:\n",
    "        vec = np.array([ data[t].values[:data.shape[0]] ]).transpose(0,2,1)\n",
    "        resx = np.matmul(rot, vec.T).reshape(data.shape[0], 3)\n",
    "        for i in range(len(t)):\n",
    "            data[t[i]] = resx.T[i]\n",
    "    return data\n",
    "\n",
    "#data = aberrate(data, sw_velocity)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# duskdawn = nodes[nodes[\"TYPE\"]==1]\n",
    "# coses = data.COSALPHA[(~np.isnan(data.COSALPHA.VALUE)) & (np.abs(data.COSALPHA.VALUE) < 0.05)].index\n",
    "# duskdawn = duskdawn.index.intersection(coses)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "def sw_orbit_data(data, nodes, orbit_no):\n",
    "    ep = 100\n",
    "    bx, by, bz = -43, 13, 0\n",
    "    periapsis = nodes[nodes[\"TYPE\"]==1]\n",
    "    dt00 = periapsis.index[orbit_no] - pd.Timedelta(\"4h\")\n",
    "    dt01 = periapsis.index[orbit_no] - pd.Timedelta(\"120m\")\n",
    "    dt10 = periapsis.index[orbit_no] + pd.Timedelta(\"120m\")\n",
    "    dt11 = periapsis.index[orbit_no] + pd.Timedelta(\"4h\")\n",
    "    fragment0 = data[dt00:dt01].copy(True)\n",
    "    fragment1 = data[dt10:dt11].copy(True)    \n",
    "    rmse=np.mean([\n",
    "        np.std(fragment0.BX_MSO),\n",
    "        np.std(fragment0.BY_MSO),\n",
    "        np.std(fragment0.BZ_MSO),\n",
    "        np.std(fragment1.BX_MSO),\n",
    "        np.std(fragment1.BY_MSO),\n",
    "        np.std(fragment1.BZ_MSO)\n",
    "                 ])\n",
    "\n",
    "    if (math.fabs(np.mean(fragment0.BX_MSO)-np.mean(fragment1.BX_MSO))<ep and \n",
    "        math.fabs(np.mean(fragment0.BY_MSO)-np.mean(fragment1.BY_MSO))<ep and \n",
    "        math.fabs(np.mean(fragment0.BZ_MSO)-np.mean(fragment1.BZ_MSO))<ep):\n",
    "        return rmse\n",
    "            \n",
    "        print(rmse)\n",
    "\n",
    "min_i, min_abs = -1, 9999\n",
    "for i in range(1090):\n",
    "    absx = sw_orbit_data(data, nodes, i)\n",
    "    if  absx < min_abs:\n",
    "        min_abs = absx\n",
    "        min_i = i\n",
    "        \n",
    "\n",
    "print(min_i, min_abs)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "exp = orbit_data(data, nodes, min_i)\n",
    "exp.X_MSO = exp.X_MSO*1e3\n",
    "exp.Y_MSO = exp.Y_MSO*1e3\n",
    "exp.Z_MSO = exp.Z_MSO*1e3"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "orbit_data(data, nodes, min_i)[[\"X_MSO\", \"Y_MSO\", \"Z_MSO\", \"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"]].to_csv(\"messenger_compare.csv\".format(xyear))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "def orbit_data(data, nodes, orbit_no):\n",
    "    periapsis = nodes[nodes[\"TYPE\"]==1]\n",
    "    dt1 = periapsis.index[orbit_no] - pd.Timedelta(\"120m\")\n",
    "    dt2 = periapsis.index[orbit_no] + pd.Timedelta(\"120m\")\n",
    "    fragment = data[dt1:dt2].copy(True)\n",
    "    fragment[\"BABS\"] = np.sqrt(fragment.BX_MSO**2 + fragment.BY_MSO**2 + fragment.BZ_MSO**2)\n",
    "    return fragment\n",
    "    \"\"\"\n",
    "    timex = list(\n",
    "        map(\n",
    "            lambda dt64: datetime.utcfromtimestamp((dt64 - np.datetime64('1970-01-01T00:00:00')) / np.timedelta64(1, 's')),\n",
    "            fragment.index.values\n",
    "        )\n",
    "    )\n",
    "    x, y, z = fragment.X_MSO, fragment.Y_MSO, fragment.Z_MSO\n",
    "    bx, by, bz = fragment.BX_MSO, fragment.BY_MSO, fragment.BZ_MSO\n",
    "    dbx, dby, dbz = fragment.DBX_MSO, fragment.DBY_MSO, fragment.DBZ_MSO\n",
    "    r, rxy = fragment.R, fragment.RXY\n",
    "            \n",
    "    coords = np.vstack([x, y, z])\n",
    "    values = np.vstack((bx, by, bz))\n",
    "    err  = np.vstack([dbx, dby, dbz])\n",
    "    babs = np.sqrt(bx**2 + by**2 + bz**2)\n",
    "    # lo, hi = values - err, values + err\n",
    "    return timex, coords, values, err, babs\"\"\"\n",
    "\n",
    "\n",
    "\n",
    "def advplot(fragment, more_title=\"\"):    \n",
    "    fig = make_subplots(rows=2,\n",
    "                        cols=1,\n",
    "                        subplot_titles=[\"Magnetic field\", \"Coordinates\"],\n",
    "                        shared_xaxes=False,\n",
    "                        shared_yaxes=False)\n",
    "    \n",
    "    \n",
    "    lo = fragment[[\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"]] - fragment[[\"DBX_MSO\", \"DBY_MSO\", \"DBZ_MSO\"]].to_numpy()\n",
    "    hi = fragment[[\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"]] + fragment[[\"DBX_MSO\", \"DBY_MSO\", \"DBZ_MSO\"]].to_numpy()\n",
    "    \n",
    "    s4=go.Scatter(\n",
    "            x=pd.concat([pd.Series(fragment.index.values), pd.Series(fragment.index.values)]),\n",
    "            y=pd.concat([fragment.BABS, -fragment.BABS]),\n",
    "            mode='lines',\n",
    "            name=r\"$|B|$\",\n",
    "            marker_color='black',\n",
    "        )\n",
    "    \n",
    "    fig.add_trace(\n",
    "        s4,\n",
    "        row=1,\n",
    "        col=1\n",
    "        )\n",
    "    s4.on_click(update_point)\n",
    "    \n",
    "    for i, j, c in zip([\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"], [\"X_MSO\", \"Y_MSO\", \"Z_MSO\"], ['red', 'green', 'blue']):\n",
    "        fig.add_trace(\n",
    "            go.Scatter(\n",
    "                x=fragment.index,\n",
    "                y=lo[i],\n",
    "                line=dict(width=0), \n",
    "                mode='lines',\n",
    "                opacity=0.0,\n",
    "                name=i.split(\"_\")[0][-1],\n",
    "                marker_color=c,\n",
    "                fillcolor=c,\n",
    "                showlegend=False,\n",
    "            ),\n",
    "            row=1,\n",
    "            col=1\n",
    "        )\n",
    "        \n",
    "        fig.add_trace(\n",
    "            go.Scatter(\n",
    "                x=fragment.index,\n",
    "                y=hi[i],\n",
    "                mode='lines',\n",
    "                line=dict(width=0),\n",
    "                opacity=0.0,\n",
    "                name=i.split(\"_\")[0][-1],\n",
    "                marker_color=c,\n",
    "                showlegend=False,\n",
    "                fill='tonexty'\n",
    "            ),\n",
    "            row=1,\n",
    "            col=1,\n",
    "        )\n",
    "    \n",
    "        s3=go.Scatter(\n",
    "                       x=fragment.index,\n",
    "                       y=fragment[i],\n",
    "                       mode='lines',\n",
    "                       name=i.split(\"_\")[0][-1],\n",
    "                       marker_color=c\n",
    "                      )  \n",
    "               \n",
    "        fig.add_trace(\n",
    "                   s3,\n",
    "                   row=1\n",
    "                   col=1\n",
    "                    )\n",
    "        s3.on_click(update_point)\n",
    "        \n",
    "        \n",
    "        fig.add_trace(\n",
    "            go.Scatter(\n",
    "                x=fragment.index,\n",
    "                y=fragment[j],\n",
    "                mode='lines',\n",
    "                name=j,\n",
    "                marker_color=c,\n",
    "                showlegend=False\n",
    "            ),\n",
    "            row=2,\n",
    "            col=1\n",
    "        )\n",
    "        \n",
    "    fig.show()\n",
    "   \n",
    "    \n",
    "def export_orbit(nodes, orbit_no, normalize=False, more_title=\"\"):\n",
    "    timex, coord, values, err, babs = orbit_data(nodes, orbit_no, normalize)\n",
    "    \n",
    "    pd.to_csv(\"orbit_{:04d}.dat\".format(orbit_no + 1), date_format=\"%Y %m %d %H %M %S\")\n",
    "    \n",
    "    f = open(fname, 'wb')\n",
    "    for i in range(len(fragment)):\n",
    "        line = \" {} {:>13} {:>9} {:>9} {:>7} {:>7} {:>7}\\n\".format(fragment.index[i].strftime(\"%Y %m %d %H %M %S\"), \"{:.2f}\".format(fragment.X_MSO[i]), \"{:.2f}\".format(fragment.Y_MSO[i]), \"{:.2f}\".format(fragment.Z_MSO[i]), \"{:.2f}\".format(fragment.BX_MSO[i]), \"{:.2f}\".format(fragment.BY_MSO[i]), \"{:.2f}\".format(fragment.BZ_MSO[i]))\n",
    "        f.write(line.encode('utf8'))\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "advplot(orbit_data(data, nodes, 1))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    " \n",
    "    \n",
    "    \"\"\"\n",
    "    with plt.style.context(('classic')):\n",
    "        mp.rcParams['font.size'] = 22\n",
    "        mp.rcParams['axes.labelsize'] = 32\n",
    "        #mp.rcParams['figure.figsize'] = (15, 10)\n",
    "        fig = plt.figure(num=None, figsize=(12, 6), dpi=80, facecolor='w', edgecolor='k')\n",
    "        ax = fig.add_subplot(211)\n",
    "        plt.grid(which='minor')\n",
    "        plt.grid(which='major')\n",
    "        plt.subplots_adjust(bottom=-1.0)\n",
    "        plt.setp(ax.xaxis.get_majorticklabels(), rotation=\"vertical\")\n",
    "        if more_title != \"\":\n",
    "            more_tile = \" :: \" + more_title\n",
    "        plt.title(\"%s%s\" % (timex[0].strftime(\"%Y-%m-%d\"), more_title))\n",
    "\n",
    "        #labels = { \"coord\": [r\"$X_{MSO}$\", r\"$Y_{MSO}$\", r\"$Z_{MSO}$\"], \"bfield\": [r\"$B_x$\", r\"$B_y$\", r\"$B_z$\"]}\n",
    "        #colors = [\"red\", \"green\", \"blue\"]\n",
    "        #lines = []\n",
    "        #for i in range(values.shape[0]):\n",
    "        #    line = ax.plot(timex, values[i], label=labels[\"bfield\"][i], color=colors[i])\n",
    "        #    lines.append(line)\n",
    "        #ax.plot(timex, babs, color='k', linewidth=1.4)\n",
    "        #ax.plot(timex, -babs, color='k', linewidth=1.4)\n",
    "        \n",
    "        \n",
    "        plt.ylabel(\"Магнитное поле [нТл]\")\n",
    "        diffax = ax.twinx()\n",
    "        \n",
    "\n",
    "        deltab = np.abs(np.diff(babs))\n",
    "        diffax.set_ylim((0, np.max(deltab)*2))\n",
    "        line = diffax.plot(timex[:-1], deltab, color='magenta', label=r'$\\Delta$B')\n",
    "        lines.append(line)\n",
    "        for tl in diffax.get_yticklabels():\n",
    "            tl.set_color('magenta')\n",
    "        diffax.set_ylabel(r'$|\\Delta B_{abs}|$ [нТл]', color='magenta')\n",
    "        #lines = lines[0] + lines[1] + lines[2] + lines[3]\n",
    "    \n",
    "        ax.xaxis.set_major_formatter(dates.DateFormatter('%H:%M'))\n",
    "        ax.xaxis.set_minor_locator(AutoMinorLocator(4))\n",
    "        \n",
    "        ax.legend()\n",
    "        \n",
    "\n",
    "        ax = fig.add_subplot(212)\n",
    "        plt.grid(which='minor')\n",
    "        plt.grid(which='major')\n",
    "        ax.xaxis.set_major_formatter(dates.DateFormatter('%H:%M'))\n",
    "        ax.xaxis.set_minor_locator(AutoMinorLocator(4))\n",
    "        plt.setp(ax.xaxis.get_majorticklabels(), rotation=\"vertical\")\n",
    "        plt.xlabel(\"Время\")\n",
    "        plt.ylabel(\"Расстояние [км]\")\n",
    "        #ax.plot(fragment.RHO_DIPOLE, color='k', linewidth=2, label=r'$\\rho_{D}$')\n",
    "        for i in range(coords.shape[0]):\n",
    "            line = ax.plot(timex, coords[i], label=labels[\"coord\"][i], color=colors[i])\n",
    "            lines.append(line)\n",
    "        ax.legend()\"\"\"\n",
    "    "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "first_orbit = 0\n",
    "for i in range(nodes[nodes.TYPE==1].shape[0]):\n",
    "    export_orbit(nodes, first_orbit + i, True, False)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "plt.plot(data[\"BZ_MSO\"])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# http://ccmc.gsfc.nasa.gov/RoR_WWW/presentations/Dipole.pdf\n",
    "# rho   - total distance of the spacecraft to Mercury's center in km\n",
    "# theta - hermomagnetic latitude in radians (NOT degrees)\n",
    "# B_0   - hermomagnetic dipole field approximation\n",
    "# Bx = 3M xz/r^5\n",
    "# By = 3M yz/r^5\n",
    "# Bz = M (3z^2-r^2)/r^5\n",
    "\n",
    "#data[\"BABS_DIPOLE\"]=np.abs(M_0)*np.sqrt(1 + 3*np.cos(data.THETA_DIPOLE)**2) / data.RHO_DIPOLE**3\n",
    "#data[\"BX_DIPOLE\"]=3*M_0*z*x / data.RHO_DIPOLE**5\n",
    "#data[\"BY_DIPOLE\"]=3*M_0*z*y / data.RHO_DIPOLE**5\n",
    "#data[\"BZ_DIPOLE\"]=M_0*(3*z**2 - data.RHO_DIPOLE**2)/data.RHO_DIPOLE**5\n",
    "    \n",
    "# Do not modify the data array, just calc along what's been given\n",
    "def dipole_profile(coords, psi, offset_x, offset_y, offset_z):\n",
    "    x, y, z = coords.X_AB + offset_x, coords.Y_AB + offset_y, coords.Z_AB + offset_z\n",
    "    #if aberrated:\n",
    "    #    x, y, z = data.X_AB + offset[0], data.Y_AB + offset[1], data.Z_AB + offset[2]\n",
    "    #else:\n",
    "    #    x, y, z = data.X_MSO + offset[0], data.Y_MSO + offset[1], data.Z_MSO + offset[2]\n",
    "    rho=np.sqrt(x**2 + y**2 + z**2)\n",
    "    theta=np.arcsin(z/rho)    \n",
    "    babs=np.abs(M_0)/ rho**4 * np.sqrt(3*z**2 + rho**2)\n",
    "    p=z*np.cos(psi) - x*np.sin(psi)\n",
    "    Br=M_0/rho**5\n",
    "    bx=-Br*(- rho**2 *np.sin(psi) - 3.*x*p)\n",
    "    by= Br*(3.*y*p)\n",
    "    bz=-Br*(rho**2 *np.cos(psi) - 3.*z*p)\n",
    "    return bx, by, bz\n",
    "\n",
    "\n",
    "def dipole_magnitude(coords, psi, offset_x, offset_y, offset_z):\n",
    "    bx, by, bz = dipole_profile(coords, psi, offset_x, offset_y, offset_z)\n",
    "    field_dipole = np.sqrt(bx**2 + by**2 + bz**2)\n",
    "    return field_dipole\n",
    "\n",
    "\n",
    "#dipole_profile(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "def exp_vs_dipole(nodes, orbit_no, aberrated=True, more_title=\"\", plot_enabled=True):\n",
    "    periapsis = nodes[nodes[\"TYPE\"]==1]\n",
    "    dt1 = periapsis.index[orbit_no] - pd.Timedelta(\"1h\")\n",
    "    dt2 = periapsis.index[orbit_no] + pd.Timedelta(\"1h\")\n",
    "    fragment = data[dt1 : dt2]\n",
    "    \n",
    "    if aberrated:\n",
    "        x, y, z = fragment[\"X_AB\"], fragment[\"Y_AB\"], fragment[\"Z_AB\"]\n",
    "        bx, by, bz = fragment[\"BX_AB\"], fragment[\"BY_AB\"], fragment[\"BZ_AB\"]\n",
    "        dbx, dby, dbz = fragment[\"DBX_AB\"], fragment[\"DBY_AB\"], fragment[\"DBZ_AB\"]\n",
    "        rho, rxy = fragment[\"RHO_AB\"], fragment[\"RXY_AB\"]\n",
    "    else:\n",
    "        x, y, z = fragment[\"X_MSO\"], fragment[\"Y_MSO\"], fragment[\"Z_MSO\"]\n",
    "        bx, by, bz = fragment[\"BX_MSO\"], fragment[\"BY_MSO\"], fragment[\"BZ_MSO\"]\n",
    "        dbx, dby, dbz = fragment[\"DBX_MSO\"], fragment[\"DBY_MSO\"], fragment[\"DBZ_MSO\"]\n",
    "        rho, rxy = fragment[\"RHO\"], fragment[\"RXY\"]\n",
    "    \n",
    "    coords = pd.concat([x, y, z], axis=1)\n",
    "    field_exp = np.sqrt(bx**2 + by**2 + bz**2)\n",
    "    \n",
    "    popt, pcov = curve_fit(dipole_magnitude, coords, field_exp)\n",
    "    #print(popt)\n",
    "    dipolex, dipoley, dipolez = dipole_profile(coords, popt[0], popt[1], popt[2], popt[3])\n",
    "    #fragment['BX_DIPOLE'], fragment['BY_DIPOLE'], fragment['BZ_DIPOLE']\n",
    "    \n",
    "    \n",
    "    field_dipole = np.sqrt(dipolex**2 + dipoley**2 + dipolez**2) # fragment['BABS_DIPOLE']\n",
    "    \n",
    "    #print(field_exp.idxmax(), field_dipole.idxmax())\n",
    "    if plot_enabled:\n",
    "        plt.plot(field_exp, color='b')\n",
    "        plt.plot(field_dipole, color='g')\n",
    "        plt.plot(fragment['RHO_DIPOLE']/100, color='k')\n",
    "        plt.xlabel(\"Время\")\n",
    "        plt.ylabel(\"Магнитное поле [нТл]\")\n",
    "        plt.gca().xaxis.set_major_formatter(dates.DateFormatter('%H:%M'))\n",
    "        plt.gca().xaxis.set_minor_locator(AutoMinorLocator(4))\n",
    "    return \n",
    "\n",
    "dipole_params = []\n",
    "\n",
    "for i in range(0, 4000):\n",
    "    dipole_params.append(exp_vs_dipole(nodes, i, ab, \"\", False))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "import sys,os,os.path\n",
    "from datetime import datetime\n",
    "from matplotlib import dates\n",
    "\n",
    "from matplotlib.ticker import AutoMinorLocator, LinearLocator, AutoLocator\n",
    "import matplotlib as mpl\n",
    "\n",
    "base_name = \"MAGMSOSCIAVG%s%03d_%s_V06.TAB\"\n",
    "data_limits = { 2011: [82, 365], 2012: [1, 366], 2013: [1, 365], 2014: [1, 365], 2015: [1, 120] }\n",
    "\n",
    "def advanced_plot(pictype, data, normalize=False, more_title=\"\"):\n",
    "    data_np=data.as_matrix().T\n",
    "    x, y, z = data_np[0], data_np[1], data_np[2]\n",
    "    if normalize:\n",
    "        bx, by, bz = data_np[3] - data_np[-3], data_np[4] - data_np[-2], data_np[5] - data_np[-1]\n",
    "    else:\n",
    "        bx, by, bz = data_np[3], data_np[4], data_np[5]\n",
    "    dbx, dby, dbz = data_np[6], data_np[7], data_np[8]\n",
    "    # We drop the last record from the input file as it belongs to the next day\n",
    "    timex = map(lambda dt64: datetime.utcfromtimestamp((dt64 - np.datetime64('1970-01-01T00:00:00')) / np.timedelta64(1, 's')), data.index.values)\n",
    "\n",
    "    if pictype == \"bfield\":\n",
    "        data = np.vstack([bx, by, bz])\n",
    "        err  = np.vstack([dbx, dby, dbz])\n",
    "        babs = np.apply_along_axis(lambda p: np.sqrt(sum(p**2)), 0, data)\n",
    "    elif pictype == \"coord\":\n",
    "        data = np.vstack([x, y, z])\n",
    "        err  = 0.0\n",
    "    \n",
    "    lo, hi = data - err, data + err\n",
    "    data, lo, hi = data, lo, hi\n",
    "\n",
    "    fig = plt.figure(num=None, figsize=(12, 6), dpi=80, facecolor='w', edgecolor='k')\n",
    "    ax = fig.add_subplot(111)\n",
    "    ax.xaxis.set_major_formatter(dates.DateFormatter('%H:%M'))\n",
    "    ax.xaxis.set_minor_locator(AutoMinorLocator(4))\n",
    "    plt.grid(which='minor')\n",
    "    plt.grid(which='major')\n",
    "    plt.setp(ax.xaxis.get_majorticklabels(), rotation=\"vertical\")\n",
    "    plt.subplots_adjust(bottom=.3)\n",
    "    plt.title(\"%s :: %s\" % (timex[0].strftime(\"%Y-%m-%d\"), more_title))\n",
    "\n",
    "\n",
    "    labels = { \"coord\": [\"x\", \"y\", \"z\"], \"bfield\": [\"Bx\", \"By\", \"Bz\"]}\n",
    "    colors = [\"blue\", \"magenta\", \"red\"]\n",
    "\n",
    "    lines = []\n",
    "    for i in range(data.shape[0]):\n",
    "        line = plt.plot(ax, timex, data[i], label=labels[pictype][i], color=colors[i])\n",
    "        lines.append(line)\n",
    "        plt.fill_between(timex, lo[i], hi[i], facecolor=colors[i], interpolate=True, alpha=0.3, color=\"none\", edgecolor=\"k\", linewidth=0.0)\n",
    "\n",
    "    if pictype == 'bfield':\n",
    "        plt.plot(ax, timex, babs, color='k', linewidth=1.4)\n",
    "        plt.plot(ax, timex, -babs, color='k', linewidth=1.4)\n",
    "        diffax = ax.twinx()\n",
    "        deltab = np.apply_along_axis(lambda p: np.sqrt(sum(p**2)), 0, np.diff(data, axis=1))\n",
    "        line = diffax.plot(timex[:-1], deltab, color='green', label=r'$\\Delta$B')\n",
    "        lines.append(line)\n",
    "        for tl in diffax.get_yticklabels():\n",
    "            tl.set_color('green')\n",
    "        ax.set_ylabel(r'$B$ [nT]', color='k')\n",
    "        diffax.set_ylabel(r'$|\\Delta B|$ [nT]', color='green')\n",
    "        lines = lines[0] + lines[1] + lines[2] + lines[3]\n",
    "    else:\n",
    "        ax.set_ylabel(r'Distance to Mercury center [km]', color='k')\n",
    "        lines = lines[0] + lines[1] + lines[2]\n",
    "\n",
    "    labels = [l.get_label() for l in lines]\n",
    "    ax.legend(lines, labels, loc=1)\n",
    "\n",
    "\n",
    "def a2000_vs_dipole_plot(data, component):\n",
    "    data_np=data.as_matrix().T\n",
    "    x, y, z = data_np[0], data_np[1], data_np[2]\n",
    "    if component == \"x\":\n",
    "        bx, by, bz = data_np[3], data_np[-3], data_np[3] - data_np[-3]\n",
    "    elif component == \"y\":\n",
    "        bx, by, bz = data_np[4], data_np[-2], data_np[4] - data_np[-2]\n",
    "    elif component == \"z\":\n",
    "        bx, by, bz = data_np[5], data_np[-1], data_np[5] - data_np[-1]\n",
    "    dbx, dby, dbz = data_np[6], data_np[7], data_np[8]\n",
    "    # We drop the last record from the input file as it belongs to the next day\n",
    "    timex = map(lambda dt64: datetime.utcfromtimestamp((dt64 - np.datetime64('1970-01-01T00:00:00')) / np.timedelta64(1, 's')), data.index.values)\n",
    "\n",
    "    data = np.vstack([bx, by, bz])\n",
    "    err  = np.vstack([dbx, dby, dbz])\n",
    "    babs = np.apply_along_axis(lambda p: np.sqrt(sum(p**2)), 0, data)\n",
    "    \n",
    "    lo, hi = data - err, data + err\n",
    "    data, lo, hi = data, lo, hi\n",
    "\n",
    "    fig = plt.figure(num=None, figsize=(12, 6), dpi=80, facecolor='w', edgecolor='k')\n",
    "    ax = fig.add_subplot(111)\n",
    "    ax.xaxis.set_major_formatter(dates.DateFormatter('%H:%M'))\n",
    "    ax.xaxis.set_minor_locator(AutoMinorLocator(4))\n",
    "    plt.grid(which='minor')\n",
    "    plt.grid(which='major')\n",
    "    plt.setp(ax.xaxis.get_majorticklabels(), rotation=\"vertical\")\n",
    "    plt.subplots_adjust(bottom=.3)\n",
    "    plt.title(timex[0].strftime(\"%Y-%m-%d\"))\n",
    "\n",
    "\n",
    "    labels = { \"bfield\": [\"$B_{data}$\", \"$B_{dipole}$\", \"$\\Delta B$\"]}\n",
    "    colors = [\"red\", \"blue\", \"magenta\"]\n",
    "\n",
    "    lines = []\n",
    "    for i in range(data.shape[0]):\n",
    "        line = ppl.plot(ax, timex, data[i], label=labels[\"bfield\"][i], color=colors[i])\n",
    "        lines.append(line)\n",
    "        ppl.fill_between(timex, lo[i], hi[i], facecolor=colors[i], interpolate=True, alpha=0.3, color=\"none\", edgecolor=\"k\", linewidth=0.0)\n",
    "\n",
    "    ax.set_ylabel(r'$B$ [nT]', color='k')\n",
    "    lines = lines[0] + lines[1] + lines[2]\n",
    "\n",
    "    labels = [l.get_label() for l in lines]\n",
    "    ax.legend(lines, labels, loc=1)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "def save_preprocessed(data):\n",
    "    data.to_csv(\"/home/dp/messenger/uru/data_disser.csv\")\n",
    "# save_preprocessed(data)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "# data = pd.read_csv(\"/home/dp/messenger/uru/data_disser.csv\")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "def select_orbit_section(base_cos, cos_spread):\n",
    "    threshold = np.where((cos_array < base_cos+cos_spread) & (cos_array > base_cos-cos_spread))[0]\n",
    "    return np.array(list(set(np.where(cerc_vec==-1)[0]).intersection(threshold)))\n",
    "        \n",
    "def compare_approach_types():\n",
    "    cos_spread = 0.002\n",
    "    for base_cos in np.arange(-0.95, 0.95, 0.05):\n",
    "        closest_approaches = select_orbit_section(base_cos, cos_spread)\n",
    "        for appr in closest_approaches[:1]:\n",
    "            advanced_plot(\"bfield\", data_ab[dt[appr-spread]:dt[appr+spread]], True, base_cos)\n",
    "            advanced_plot(\"coord\", data_ab[dt[appr-spread]:dt[appr+spread]], False, base_cos)\n",
    "        \n",
    "def get_x_spread(approaches):\n",
    "    deltas = []\n",
    "    for appr in approaches:\n",
    "        _min = data_ab[\"X_MSO\"][dt[appr-spread]:dt[appr+spread]].min()\n",
    "        _max = data_ab[\"X_MSO\"][dt[appr-spread]:dt[appr+spread]].max()\n",
    "        deltas.append(_max - _min)\n",
    "    return reduce(lambda x, y: x + y, deltas) / len(deltas)\n",
    "    \n",
    "# Selected manually to achieve minimum X_MSO spread between points of entry and departure\n",
    "base_cos = 0.0\n",
    "cos_spread = 0.3\n",
    "\n",
    "#for cos_spread in np.arange(0.1, 0.9, 0.1):\n",
    "#    closest_approaches = select_orbit_section(base_cos, cos_spread)\n",
    "#    print cos_spread, len(closest_approaches)*1.0/np.where(cerc_vec==-1)[0].shape[0], get_x_spread(closest_approaches)\n",
    "\n",
    "# Number of points around each closest approach\n",
    "spread = 100\n",
    "closest_approaches = select_orbit_section(base_cos, cos_spread)\n",
    "f1 = open(\"orbits-times.txt\", \"w\")\n",
    "f2 = open(\"orbits-to-cluster.csv\", \"w\")\n",
    "for appr in closest_approaches:\n",
    "    df1 = data_ab[[\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"]][dt[appr-spread]:dt[appr+spread]]\n",
    "    df2 = data_ab[[\"B_X\", \"B_Y\", \"B_Z\"]][dt[appr-spread]:dt[appr+spread]]\n",
    "    df = df1[[\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"]]\n",
    "    df['BX_MSO'] = df1.BX_MSO - df2.B_X\n",
    "    df['BY_MSO'] = df1.BY_MSO - df2.B_Y\n",
    "    df['BZ_MSO'] = df1.BZ_MSO - df2.B_Z\n",
    "    if not df.isnull().any().any():\n",
    "        f2.write(\",\".join(map(lambda x: str(x), df.values.flatten(order='F'))))\n",
    "        f2.write(\"\\n\")\n",
    "        f1.write(str(data_ab[[\"BX_MSO\", \"BY_MSO\", \"BZ_MSO\"]][dt[appr]:dt[appr]].index.values[0]))\n",
    "        f1.write(\"\\n\")\n",
    "f1.close()\n",
    "f2.close()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "periapsis, apoapsis = argrelextrema(data['RHO_DIPOLE'].values, np.greater), argrelextrema(data['RHO_DIPOLE'].values, np.less)\n",
    "\n",
    "peri = data.iloc[periapsis];\n",
    "babs = np.sqrt(peri.BX_AB**2 + peri.BY_AB**2 + peri.BZ_AB**2)\n",
    "\n",
    "apo = data.iloc[apoapsis];\n",
    "babs = np.sqrt(apo.BX_AB**2 + apo.BY_AB**2 + apo.BZ_AB**2)\n",
    "\n",
    "plt.hist(babs[~np.isnan(babs)], bins=100);"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Raw Cell Format",
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.8.11"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 1
}
